searchData={"content_type":"text/markdown","items":[{"doc":"Certificate Manager\n\nYou can use Certificate Manager (ACM) to manage SSL/TLS certificates for your\nAmazon Web Services-based websites and applications.\n\nFor more information about using ACM, see the [Certificate Manager User Guide](https://docs.aws.amazon.com/acm/latest/userguide/).","ref":"AWS.ACM.html","title":"AWS.ACM","type":"module"},{"doc":"Adds one or more tags to an ACM certificate.\n\nTags are labels that you can use to identify and organize your Amazon Web\nServices resources. Each tag consists of a `key` and an optional `value`. You\nspecify the certificate on input by its Amazon Resource Name (ARN). You specify\nthe tag by using a key-value pair.\n\nYou can apply a tag to just one certificate if you want to identify a specific\ncharacteristic of that certificate, or you can apply the same tag to multiple\ncertificates if you want to filter for a common relationship among those\ncertificates. Similarly, you can apply the same tag to multiple resources if you\nwant to specify a relationship among those resources. For example, you can add\nthe same tag to an ACM certificate and an Elastic Load Balancing load balancer\nto indicate that they are both used by the same website. For more information,\nsee [Tagging ACM certificates](https://docs.aws.amazon.com/acm/latest/userguide/tags.html).\n\nTo remove one or more tags, use the `RemoveTagsFromCertificate` action. To view\nall of the tags that have been applied to the certificate, use the\n`ListTagsForCertificate` action.","ref":"AWS.ACM.html#add_tags_to_certificate/3","title":"AWS.ACM.add_tags_to_certificate/3","type":"function"},{"doc":"Deletes a certificate and its associated private key.\n\nIf this action succeeds, the certificate no longer appears in the list that can\nbe displayed by calling the `ListCertificates` action or be retrieved by calling\nthe `GetCertificate` action. The certificate will not be available for use by\nAmazon Web Services services integrated with ACM.\n\nYou cannot delete an ACM certificate that is being used by another Amazon Web\nServices service. To delete a certificate that is in use, the certificate\nassociation must first be removed.","ref":"AWS.ACM.html#delete_certificate/3","title":"AWS.ACM.delete_certificate/3","type":"function"},{"doc":"Returns detailed metadata about the specified ACM certificate.\n\nIf you have just created a certificate using the `RequestCertificate` action,\nthere is a delay of several seconds before you can retrieve information about\nit.","ref":"AWS.ACM.html#describe_certificate/3","title":"AWS.ACM.describe_certificate/3","type":"function"},{"doc":"Exports a private certificate issued by a private certificate authority (CA) for\nuse anywhere.\n\nThe exported file contains the certificate, the certificate chain, and the\nencrypted private 2048-bit RSA key associated with the public key that is\nembedded in the certificate. For security, you must assign a passphrase for the\nprivate key when exporting it.\n\nFor information about exporting and formatting a certificate using the ACM\nconsole or CLI, see [Export a Private Certificate](https://docs.aws.amazon.com/acm/latest/userguide/gs-acm-export-private.html).","ref":"AWS.ACM.html#export_certificate/3","title":"AWS.ACM.export_certificate/3","type":"function"},{"doc":"Returns the account configuration options associated with an Amazon Web Services\naccount.","ref":"AWS.ACM.html#get_account_configuration/3","title":"AWS.ACM.get_account_configuration/3","type":"function"},{"doc":"Retrieves an Amazon-issued certificate and its certificate chain.\n\nThe chain consists of the certificate of the issuing CA and the intermediate\ncertificates of any other subordinate CAs. All of the certificates are base64\nencoded. You can use\n[OpenSSL](https://wiki.openssl.org/index.php/Command_Line_Utilities) to decode\nthe certificates and inspect individual fields.","ref":"AWS.ACM.html#get_certificate/3","title":"AWS.ACM.get_certificate/3","type":"function"},{"doc":"Imports a certificate into Certificate Manager (ACM) to use with services that\nare integrated with ACM.\n\nNote that [integrated services](https://docs.aws.amazon.com/acm/latest/userguide/acm-services.html)\nallow only certificate types and keys they support to be associated with their\nresources. Further, their support differs depending on whether the certificate\nis imported into IAM or into ACM. For more information, see the documentation\nfor each service. For more information about importing certificates into ACM,\nsee [Importing Certificates](https://docs.aws.amazon.com/acm/latest/userguide/import-certificate.html)\nin the *Certificate Manager User Guide*.\n\nACM does not provide [managed renewal](https://docs.aws.amazon.com/acm/latest/userguide/acm-renewal.html) for\ncertificates that you import.\n\nNote the following guidelines when importing third party certificates:\n\n  * You must enter the private key that matches the certificate you\nare importing.\n\n  * The private key must be unencrypted. You cannot import a private\nkey that is protected by a password or a passphrase.\n\n  * The private key must be no larger than 5 KB (5,120 bytes).\n\n  * If the certificate you are importing is not self-signed, you must\nenter its certificate chain.\n\n  * If a certificate chain is included, the issuer must be the subject\nof one of the certificates in the chain.\n\n  * The certificate, private key, and certificate chain must be\nPEM-encoded.\n\n  * The current time must be between the `Not Before` and `Not After`\ncertificate fields.\n\n  * The `Issuer` field must not be empty.\n\n  * The OCSP authority URL, if present, must not exceed 1000\ncharacters.\n\n  * To import a new certificate, omit the `CertificateArn` argument.\nInclude this argument only when you want to replace a previously imported\ncertificate.\n\n  * When you import a certificate by using the CLI, you must specify\nthe certificate, the certificate chain, and the private key by their file names\npreceded by `fileb://`. For example, you can specify a certificate saved in the\n`C:\temp` folder as `fileb://C:\tempcertificate_to_import.pem`. If you are\nmaking an HTTP or HTTPS Query request, include these arguments as BLOBs.\n\n  * When you import a certificate by using an SDK, you must specify\nthe certificate, the certificate chain, and the private key files in the manner\nrequired by the programming language you're using.\n\n  * The cryptographic algorithm of an imported certificate must match\nthe algorithm of the signing CA. For example, if the signing CA key type is RSA,\nthen the certificate key type must also be RSA.\n\nThis operation returns the [Amazon Resource Name (ARN)](https://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html)\nof the imported certificate.","ref":"AWS.ACM.html#import_certificate/3","title":"AWS.ACM.import_certificate/3","type":"function"},{"doc":"Retrieves a list of certificate ARNs and domain names.\n\nYou can request that only certificates that match a specific status be listed.\nYou can also filter by specific attributes of the certificate. Default filtering\nreturns only `RSA_2048` certificates. For more information, see `Filters`.","ref":"AWS.ACM.html#list_certificates/3","title":"AWS.ACM.list_certificates/3","type":"function"},{"doc":"Lists the tags that have been applied to the ACM certificate.\n\nUse the certificate's Amazon Resource Name (ARN) to specify the certificate. To\nadd a tag to an ACM certificate, use the `AddTagsToCertificate` action. To\ndelete a tag, use the `RemoveTagsFromCertificate` action.","ref":"AWS.ACM.html#list_tags_for_certificate/3","title":"AWS.ACM.list_tags_for_certificate/3","type":"function"},{"doc":"","ref":"AWS.ACM.html#metadata/0","title":"AWS.ACM.metadata/0","type":"function"},{"doc":"Adds or modifies account-level configurations in ACM.\n\nThe supported configuration option is `DaysBeforeExpiry`. This option specifies\nthe number of days prior to certificate expiration when ACM starts generating\n`EventBridge` events. ACM sends one event per day per certificate until the\ncertificate expires. By default, accounts receive events starting 45 days before\ncertificate expiration.","ref":"AWS.ACM.html#put_account_configuration/3","title":"AWS.ACM.put_account_configuration/3","type":"function"},{"doc":"Remove one or more tags from an ACM certificate.\n\nA tag consists of a key-value pair. If you do not specify the value portion of\nthe tag when calling this function, the tag will be removed regardless of value.\nIf you specify a value, the tag is removed only if it is associated with the\nspecified value.\n\nTo add tags to a certificate, use the `AddTagsToCertificate` action. To view all\nof the tags that have been applied to a specific ACM certificate, use the\n`ListTagsForCertificate` action.","ref":"AWS.ACM.html#remove_tags_from_certificate/3","title":"AWS.ACM.remove_tags_from_certificate/3","type":"function"},{"doc":"Renews an eligible ACM certificate.\n\nAt this time, only exported private certificates can be renewed with this\noperation. In order to renew your Amazon Web Services Private CA certificates\nwith ACM, you must first [grant the ACM service principal permission to do so](https://docs.aws.amazon.com/privateca/latest/userguide/PcaPermissions.html).\nFor more information, see [Testing Managed Renewal](https://docs.aws.amazon.com/acm/latest/userguide/manual-renewal.html)\nin the ACM User Guide.","ref":"AWS.ACM.html#renew_certificate/3","title":"AWS.ACM.renew_certificate/3","type":"function"},{"doc":"Requests an ACM certificate for use with other Amazon Web Services services.\n\nTo request an ACM certificate, you must specify a fully qualified domain name\n(FQDN) in the `DomainName` parameter. You can also specify additional FQDNs in\nthe `SubjectAlternativeNames` parameter.\n\nIf you are requesting a private certificate, domain validation is not required.\nIf you are requesting a public certificate, each domain name that you specify\nmust be validated to verify that you own or control the domain. You can use [DNS validation](https://docs.aws.amazon.com/acm/latest/userguide/gs-acm-validate-dns.html)\nor [email validation](https://docs.aws.amazon.com/acm/latest/userguide/gs-acm-validate-email.html).\nWe recommend that you use DNS validation. ACM issues public certificates after\nreceiving approval from the domain owner.\n\nACM behavior differs from the [RFC 6125](https://datatracker.ietf.org/doc/html/rfc6125#appendix-B.2) specification\nof the certificate validation process. ACM first checks for a Subject\nAlternative Name, and, if it finds one, ignores the common name (CN).\n\nAfter successful completion of the `RequestCertificate` action, there is a delay\nof several seconds before you can retrieve information about the new\ncertificate.","ref":"AWS.ACM.html#request_certificate/3","title":"AWS.ACM.request_certificate/3","type":"function"},{"doc":"Resends the email that requests domain ownership validation.\n\nThe domain owner or an authorized representative must approve the ACM\ncertificate before it can be issued. The certificate can be approved by clicking\na link in the mail to navigate to the Amazon certificate approval website and\nthen clicking **I Approve**. However, the validation email can be blocked by\nspam filters. Therefore, if you do not receive the original mail, you can\nrequest that the mail be resent within 72 hours of requesting the ACM\ncertificate. If more than 72 hours have elapsed since your original request or\nsince your last attempt to resend validation mail, you must request a new\ncertificate. For more information about setting up your contact email addresses,\nsee [Configure Email for your Domain](https://docs.aws.amazon.com/acm/latest/userguide/setup-email.html).","ref":"AWS.ACM.html#resend_validation_email/3","title":"AWS.ACM.resend_validation_email/3","type":"function"},{"doc":"Updates a certificate.\n\nCurrently, you can use this function to specify whether to opt in to or out of\nrecording your certificate in a certificate transparency log. For more\ninformation, see [ Opting Out of Certificate Transparency Logging](https://docs.aws.amazon.com/acm/latest/userguide/acm-bestpractices.html#best-practices-transparency).","ref":"AWS.ACM.html#update_certificate_options/3","title":"AWS.ACM.update_certificate_options/3","type":"function"},{"doc":"This is the *Amazon Web Services Private Certificate Authority API Reference*.\n\nIt provides descriptions, syntax, and usage examples for each of the actions and\ndata types involved in creating and managing a private certificate authority\n(CA) for your organization.\n\nThe documentation for each action shows the API request parameters and the JSON\nresponse. Alternatively, you can use one of the Amazon Web Services SDKs to\naccess an API that is tailored to the programming language or platform that you\nprefer. For more information, see [Amazon Web Services SDKs](https://aws.amazon.com/tools/#SDKs).\n\nEach Amazon Web Services Private CA API operation has a quota that determines\nthe number of times the operation can be called per second. Amazon Web Services\nPrivate CA throttles API requests at different rates depending on the operation.\nThrottling means that Amazon Web Services Private CA rejects an otherwise valid\nrequest because the request exceeds the operation's quota for the number of\nrequests per second. When a request is throttled, Amazon Web Services Private CA\nreturns a\n[ThrottlingException](https://docs.aws.amazon.com/privateca/latest/APIReference/CommonErrors.html) error. Amazon Web Services Private CA does not guarantee a minimum request rate\nfor APIs.\n\nTo see an up-to-date list of your Amazon Web Services Private CA quotas, or to\nrequest a quota increase, log into your Amazon Web Services account and visit\nthe [Service Quotas](https://console.aws.amazon.com/servicequotas/) console.","ref":"AWS.ACMPCA.html","title":"AWS.ACMPCA","type":"module"},{"doc":"Creates a root or subordinate private certificate authority (CA).\n\nYou must specify the CA configuration, an optional configuration for Online\nCertificate Status Protocol (OCSP) and/or a certificate revocation list (CRL),\nthe CA type, and an optional idempotency token to avoid accidental creation of\nmultiple CAs. The CA configuration specifies the name of the algorithm and key\nsize to be used to create the CA private key, the type of signing algorithm that\nthe CA uses, and X.500 subject information. The OCSP configuration can\noptionally specify a custom URL for the OCSP responder. The CRL configuration\nspecifies the CRL expiration period in days (the validity period of the CRL),\nthe Amazon S3 bucket that will contain the CRL, and a CNAME alias for the S3\nbucket that is included in certificates issued by the CA. If successful, this\naction returns the Amazon Resource Name (ARN) of the CA.\n\nBoth Amazon Web Services Private CA and the IAM principal must have permission\nto write to the S3 bucket that you specify. If the IAM principal making the call\ndoes not have permission to write to the bucket, then an exception is thrown.\nFor more information, see [Access policies for CRLs in Amazon S3](https://docs.aws.amazon.com/privateca/latest/userguide/crl-planning.html#s3-policies).\n\nAmazon Web Services Private CA assets that are stored in Amazon S3 can be\nprotected with encryption. For more information, see [Encrypting Your CRLs](https://docs.aws.amazon.com/privateca/latest/userguide/PcaCreateCa.html#crl-encryption).","ref":"AWS.ACMPCA.html#create_certificate_authority/3","title":"AWS.ACMPCA.create_certificate_authority/3","type":"function"},{"doc":"Creates an audit report that lists every time that your CA private key is used.\n\nThe report is saved in the Amazon S3 bucket that you specify on input. The\n[IssueCertificate](https://docs.aws.amazon.com/privateca/latest/APIReference/API_IssueCertificate.html) and\n[RevokeCertificate](https://docs.aws.amazon.com/privateca/latest/APIReference/API_RevokeCertificate.html)\nactions use the private key.\n\nBoth Amazon Web Services Private CA and the IAM principal must have permission\nto write to the S3 bucket that you specify. If the IAM principal making the call\ndoes not have permission to write to the bucket, then an exception is thrown.\nFor more information, see [Access policies for CRLs in Amazon S3](https://docs.aws.amazon.com/privateca/latest/userguide/crl-planning.html#s3-policies).\n\nAmazon Web Services Private CA assets that are stored in Amazon S3 can be\nprotected with encryption. For more information, see [Encrypting Your Audit Reports](https://docs.aws.amazon.com/privateca/latest/userguide/PcaAuditReport.html#audit-report-encryption).\n\nYou can generate a maximum of one report every 30 minutes.","ref":"AWS.ACMPCA.html#create_certificate_authority_audit_report/3","title":"AWS.ACMPCA.create_certificate_authority_audit_report/3","type":"function"},{"doc":"Grants one or more permissions on a private CA to the Certificate Manager (ACM)\nservice principal (`acm.amazonaws.com`).\n\nThese permissions allow ACM to issue and renew ACM certificates that reside in\nthe same Amazon Web Services account as the CA.\n\nYou can list current permissions with the\n[ListPermissions](https://docs.aws.amazon.com/privateca/latest/APIReference/API_ListPermissions.html) action and revoke them with the\n[DeletePermission](https://docs.aws.amazon.com/privateca/latest/APIReference/API_DeletePermission.html)\naction.","ref":"AWS.ACMPCA.html#create_permission/3","title":"AWS.ACMPCA.create_permission/3","type":"function"},{"doc":"* If the private CA and the certificates it issues reside in the\nsame account, you can use `CreatePermission` to grant permissions for ACM to\ncarry out automatic certificate renewals.\n\n  * For automatic certificate renewal to succeed, the ACM service\nprincipal needs permissions to create, retrieve, and list certificates.\n\n  * If the private CA and the ACM certificates reside in different\naccounts, then permissions cannot be used to enable automatic renewals. Instead,\nthe ACM certificate owner must set up a resource-based policy to enable\ncross-account issuance and renewals. For more information, see [Using a Resource Based Policy with Amazon Web Services Private\nCA](https://docs.aws.amazon.com/privateca/latest/userguide/pca-rbp.html).","ref":"AWS.ACMPCA.html#create_permission/3-about-permissions","title":"About Permissions - AWS.ACMPCA.create_permission/3","type":"function"},{"doc":"Deletes a private certificate authority (CA).\n\nYou must provide the Amazon Resource Name (ARN) of the private CA that you want\nto delete. You can find the ARN by calling the\n[ListCertificateAuthorities](https://docs.aws.amazon.com/privateca/latest/APIReference/API_ListCertificateAuthorities.html) action.\n\nDeleting a CA will invalidate other CAs and certificates below it in your CA\nhierarchy.\n\nBefore you can delete a CA that you have created and activated, you must disable\nit. To do this, call the\n[UpdateCertificateAuthority](https://docs.aws.amazon.com/privateca/latest/APIReference/API_UpdateCertificateAuthority.html)\naction and set the **CertificateAuthorityStatus** parameter to `DISABLED`.\n\nAdditionally, you can delete a CA if you are waiting for it to be created (that\nis, the status of the CA is `CREATING`). You can also delete it if the CA has\nbeen created but you haven't yet imported the signed certificate into Amazon Web\nServices Private CA (that is, the status of the CA is `PENDING_CERTIFICATE`).\n\nWhen you successfully call\n[DeleteCertificateAuthority](https://docs.aws.amazon.com/privateca/latest/APIReference/API_DeleteCertificateAuthority.html), the CA's status changes to `DELETED`. However, the CA won't be permanently\ndeleted until the restoration period has passed. By default, if you do not set\nthe `PermanentDeletionTimeInDays` parameter, the CA remains restorable for 30\ndays. You can set the parameter from 7 to 30 days. The\n[DescribeCertificateAuthority](https://docs.aws.amazon.com/privateca/latest/APIReference/API_DescribeCertificateAuthority.html)\naction returns the time remaining in the restoration window of a private CA in\nthe `DELETED` state. To restore an eligible CA, call the\n[RestoreCertificateAuthority](https://docs.aws.amazon.com/privateca/latest/APIReference/API_RestoreCertificateAuthority.html)\naction.","ref":"AWS.ACMPCA.html#delete_certificate_authority/3","title":"AWS.ACMPCA.delete_certificate_authority/3","type":"function"},{"doc":"Revokes permissions on a private CA granted to the Certificate Manager (ACM)\nservice principal (acm.amazonaws.com).\n\nThese permissions allow ACM to issue and renew ACM certificates that reside in\nthe same Amazon Web Services account as the CA. If you revoke these permissions,\nACM will no longer renew the affected certificates automatically.\n\nPermissions can be granted with the\n[CreatePermission](https://docs.aws.amazon.com/privateca/latest/APIReference/API_CreatePermission.html) action and listed with the\n[ListPermissions](https://docs.aws.amazon.com/privateca/latest/APIReference/API_ListPermissions.html)\naction.","ref":"AWS.ACMPCA.html#delete_permission/3","title":"AWS.ACMPCA.delete_permission/3","type":"function"},{"doc":"* If the private CA and the certificates it issues reside in the\nsame account, you can use `CreatePermission` to grant permissions for ACM to\ncarry out automatic certificate renewals.\n\n  * For automatic certificate renewal to succeed, the ACM service\nprincipal needs permissions to create, retrieve, and list certificates.\n\n  * If the private CA and the ACM certificates reside in different\naccounts, then permissions cannot be used to enable automatic renewals. Instead,\nthe ACM certificate owner must set up a resource-based policy to enable\ncross-account issuance and renewals. For more information, see [Using a Resource Based Policy with Amazon Web Services Private\nCA](https://docs.aws.amazon.com/privateca/latest/userguide/pca-rbp.html).","ref":"AWS.ACMPCA.html#delete_permission/3-about-permissions","title":"About Permissions - AWS.ACMPCA.delete_permission/3","type":"function"},{"doc":"Deletes the resource-based policy attached to a private CA.\n\nDeletion will remove any access that the policy has granted. If there is no\npolicy attached to the private CA, this action will return successful.\n\nIf you delete a policy that was applied through Amazon Web Services Resource\nAccess Manager (RAM), the CA will be removed from all shares in which it was\nincluded.\n\nThe Certificate Manager Service Linked Role that the policy supports is not\naffected when you delete the policy.\n\nThe current policy can be shown with\n[GetPolicy](https://docs.aws.amazon.com/privateca/latest/APIReference/API_GetPolicy.html) and updated with\n[PutPolicy](https://docs.aws.amazon.com/privateca/latest/APIReference/API_PutPolicy.html).","ref":"AWS.ACMPCA.html#delete_policy/3","title":"AWS.ACMPCA.delete_policy/3","type":"function"},{"doc":"* A policy grants access on a private CA to an Amazon Web Services\ncustomer account, to Amazon Web Services Organizations, or to an Amazon Web\nServices Organizations unit. Policies are under the control of a CA\nadministrator. For more information, see [Using a Resource Based Policy with Amazon Web Services Private\nCA](https://docs.aws.amazon.com/privateca/latest/userguide/pca-rbp.html).\n\n  * A policy permits a user of Certificate Manager (ACM) to issue ACM\ncertificates signed by a CA in another account.\n\n  * For ACM to manage automatic renewal of these certificates, the ACM\nuser must configure a Service Linked Role (SLR). The SLR allows the ACM service\nto assume the identity of the user, subject to confirmation against the Amazon\nWeb Services Private CA policy. For more information, see [Using a Service Linked Role with\nACM](https://docs.aws.amazon.com/acm/latest/userguide/acm-slr.html).\n\n  * Updates made in Amazon Web Services Resource Manager (RAM) are\nreflected in policies. For more information, see [Attach a Policy for Cross-Account\nAccess](https://docs.aws.amazon.com/privateca/latest/userguide/pca-ram.html).","ref":"AWS.ACMPCA.html#delete_policy/3-about-policies","title":"About Policies - AWS.ACMPCA.delete_policy/3","type":"function"},{"doc":"Lists information about your private certificate authority (CA) or one that has\nbeen shared with you.\n\nYou specify the private CA on input by its ARN (Amazon Resource Name). The\noutput contains the status of your CA. This can be any of the following:\n\n  * `CREATING` - Amazon Web Services Private CA is creating your\nprivate certificate authority.\n\n  * `PENDING_CERTIFICATE` - The certificate is pending. You must use\nyour Amazon Web Services Private CA-hosted or on-premises root or subordinate CA\nto sign your private CA CSR and then import it into Amazon Web Services Private\nCA.\n\n  * `ACTIVE` - Your private CA is active.\n\n  * `DISABLED` - Your private CA has been disabled.\n\n  * `EXPIRED` - Your private CA certificate has expired.\n\n  * `FAILED` - Your private CA has failed. Your CA can fail because of\nproblems such a network outage or back-end Amazon Web Services failure or other\nerrors. A failed CA can never return to the pending state. You must create a new\nCA.\n\n  * `DELETED` - Your private CA is within the restoration period,\nafter which it is permanently deleted. The length of time remaining in the CA's\nrestoration period is also included in this action's output.","ref":"AWS.ACMPCA.html#describe_certificate_authority/3","title":"AWS.ACMPCA.describe_certificate_authority/3","type":"function"},{"doc":"Lists information about a specific audit report created by calling the\n[CreateCertificateAuthorityAuditReport](https://docs.aws.amazon.com/privateca/latest/APIReference/API_CreateCertificateAuthorityAuditReport.html) action.\n\nAudit information is created every time the certificate authority (CA) private\nkey is used. The private key is used when you call the\n[IssueCertificate](https://docs.aws.amazon.com/privateca/latest/APIReference/API_IssueCertificate.html)\naction or the\n[RevokeCertificate](https://docs.aws.amazon.com/privateca/latest/APIReference/API_RevokeCertificate.html)\naction.","ref":"AWS.ACMPCA.html#describe_certificate_authority_audit_report/3","title":"AWS.ACMPCA.describe_certificate_authority_audit_report/3","type":"function"},{"doc":"Retrieves a certificate from your private CA or one that has been shared with\nyou.\n\nThe ARN of the certificate is returned when you call the\n[IssueCertificate](https://docs.aws.amazon.com/privateca/latest/APIReference/API_IssueCertificate.html) action. You must specify both the ARN of your private CA and the ARN of the\nissued certificate when calling the **GetCertificate** action. You can retrieve\nthe certificate if it is in the **ISSUED** state. You can call the\n[CreateCertificateAuthorityAuditReport](https://docs.aws.amazon.com/privateca/latest/APIReference/API_CreateCertificateAuthorityAuditReport.html)\naction to create a report that contains information about all of the\ncertificates issued and revoked by your private CA.","ref":"AWS.ACMPCA.html#get_certificate/3","title":"AWS.ACMPCA.get_certificate/3","type":"function"},{"doc":"Retrieves the certificate and certificate chain for your private certificate\nauthority (CA) or one that has been shared with you.\n\nBoth the certificate and the chain are base64 PEM-encoded. The chain does not\ninclude the CA certificate. Each certificate in the chain signs the one before\nit.","ref":"AWS.ACMPCA.html#get_certificate_authority_certificate/3","title":"AWS.ACMPCA.get_certificate_authority_certificate/3","type":"function"},{"doc":"Retrieves the certificate signing request (CSR) for your private certificate\nauthority (CA).\n\nThe CSR is created when you call the\n[CreateCertificateAuthority](https://docs.aws.amazon.com/privateca/latest/APIReference/API_CreateCertificateAuthority.html) action. Sign the CSR with your Amazon Web Services Private CA-hosted or\non-premises root or subordinate CA. Then import the signed certificate back into\nAmazon Web Services Private CA by calling the\n[ImportCertificateAuthorityCertificate](https://docs.aws.amazon.com/privateca/latest/APIReference/API_ImportCertificateAuthorityCertificate.html)\naction. The CSR is returned as a base64 PEM-encoded string.","ref":"AWS.ACMPCA.html#get_certificate_authority_csr/3","title":"AWS.ACMPCA.get_certificate_authority_csr/3","type":"function"},{"doc":"Retrieves the resource-based policy attached to a private CA.\n\nIf either the private CA resource or the policy cannot be found, this action\nreturns a `ResourceNotFoundException`.\n\nThe policy can be attached or updated with\n[PutPolicy](https://docs.aws.amazon.com/privateca/latest/APIReference/API_PutPolicy.html) and removed with\n[DeletePolicy](https://docs.aws.amazon.com/privateca/latest/APIReference/API_DeletePolicy.html).","ref":"AWS.ACMPCA.html#get_policy/3","title":"AWS.ACMPCA.get_policy/3","type":"function"},{"doc":"* A policy grants access on a private CA to an Amazon Web Services\ncustomer account, to Amazon Web Services Organizations, or to an Amazon Web\nServices Organizations unit. Policies are under the control of a CA\nadministrator. For more information, see [Using a Resource Based Policy with Amazon Web Services Private\nCA](https://docs.aws.amazon.com/privateca/latest/userguide/pca-rbp.html).\n\n  * A policy permits a user of Certificate Manager (ACM) to issue ACM\ncertificates signed by a CA in another account.\n\n  * For ACM to manage automatic renewal of these certificates, the ACM\nuser must configure a Service Linked Role (SLR). The SLR allows the ACM service\nto assume the identity of the user, subject to confirmation against the Amazon\nWeb Services Private CA policy. For more information, see [Using a Service Linked Role with\nACM](https://docs.aws.amazon.com/acm/latest/userguide/acm-slr.html).\n\n  * Updates made in Amazon Web Services Resource Manager (RAM) are\nreflected in policies. For more information, see [Attach a Policy for Cross-Account\nAccess](https://docs.aws.amazon.com/privateca/latest/userguide/pca-ram.html).","ref":"AWS.ACMPCA.html#get_policy/3-about-policies","title":"About Policies - AWS.ACMPCA.get_policy/3","type":"function"},{"doc":"Imports a signed private CA certificate into Amazon Web Services Private CA.\n\nThis action is used when you are using a chain of trust whose root is located\noutside Amazon Web Services Private CA. Before you can call this action, the\nfollowing preparations must in place:\n\n  1. In Amazon Web Services Private CA, call the\n[CreateCertificateAuthority](https://docs.aws.amazon.com/privateca/latest/APIReference/API_CreateCertificateAuthority.html) action to create the private CA that you plan to back with the imported\ncertificate.\n\n  2. Call the\n[GetCertificateAuthorityCsr](https://docs.aws.amazon.com/privateca/latest/APIReference/API_GetCertificateAuthorityCsr.html)\naction to generate a certificate signing request (CSR).\n\n  3. Sign the CSR using a root or intermediate CA hosted by either an\non-premises PKI hierarchy or by a commercial CA.\n\n  4. Create a certificate chain and copy the signed certificate and\nthe certificate chain to your working directory.\n\nAmazon Web Services Private CA supports three scenarios for installing a CA\ncertificate:\n\n  * Installing a certificate for a root CA hosted by Amazon Web\nServices Private CA.\n\n  * Installing a subordinate CA certificate whose parent authority is\nhosted by Amazon Web Services Private CA.\n\n  * Installing a subordinate CA certificate whose parent authority is\nexternally hosted.\n\nThe following additional requirements apply when you import a CA certificate.\n\n  * Only a self-signed certificate can be imported as a root CA.\n\n  * A self-signed certificate cannot be imported as a subordinate CA.\n\n  * Your certificate chain must not include the private CA certificate\nthat you are importing.\n\n  * Your root CA must be the last certificate in your chain. The\nsubordinate certificate, if any, that your root CA signed must be next to last.\nThe subordinate certificate signed by the preceding subordinate CA must come\nnext, and so on until your chain is built.\n\n  * The chain must be PEM-encoded.\n\n  * The maximum allowed size of a certificate is 32 KB.\n\n  * The maximum allowed size of a certificate chain is 2 MB.\n\n*Enforcement of Critical Constraints*\n\nAmazon Web Services Private CA allows the following extensions to be marked\ncritical in the imported CA certificate or chain.\n\n  * Basic constraints (*must* be marked critical)\n\n  * Subject alternative names\n\n  * Key usage\n\n  * Extended key usage\n\n  * Authority key identifier\n\n  * Subject key identifier\n\n  * Issuer alternative name\n\n  * Subject directory attributes\n\n  * Subject information access\n\n  * Certificate policies\n\n  * Policy mappings\n\n  * Inhibit anyPolicy\n\nAmazon Web Services Private CA rejects the following extensions when they are\nmarked critical in an imported CA certificate or chain.\n\n  * Name constraints\n\n  * Policy constraints\n\n  * CRL distribution points\n\n  * Authority information access\n\n  * Freshest CRL\n\n  * Any other extension","ref":"AWS.ACMPCA.html#import_certificate_authority_certificate/3","title":"AWS.ACMPCA.import_certificate_authority_certificate/3","type":"function"},{"doc":"Uses your private certificate authority (CA), or one that has been shared with\nyou, to issue a client certificate.\n\nThis action returns the Amazon Resource Name (ARN) of the certificate. You can\nretrieve the certificate by calling the\n[GetCertificate](https://docs.aws.amazon.com/privateca/latest/APIReference/API_GetCertificate.html)\naction and specifying the ARN.\n\nYou cannot use the ACM **ListCertificateAuthorities** action to retrieve the\nARNs of the certificates that you issue by using Amazon Web Services Private CA.","ref":"AWS.ACMPCA.html#issue_certificate/3","title":"AWS.ACMPCA.issue_certificate/3","type":"function"},{"doc":"Lists the private certificate authorities that you created by using the\n[CreateCertificateAuthority](https://docs.aws.amazon.com/privateca/latest/APIReference/API_CreateCertificateAuthority.html)\naction.","ref":"AWS.ACMPCA.html#list_certificate_authorities/3","title":"AWS.ACMPCA.list_certificate_authorities/3","type":"function"},{"doc":"List all permissions on a private CA, if any, granted to the Certificate Manager\n(ACM) service principal (acm.amazonaws.com).\n\nThese permissions allow ACM to issue and renew ACM certificates that reside in\nthe same Amazon Web Services account as the CA.\n\nPermissions can be granted with the\n[CreatePermission](https://docs.aws.amazon.com/privateca/latest/APIReference/API_CreatePermission.html) action and revoked with the\n[DeletePermission](https://docs.aws.amazon.com/privateca/latest/APIReference/API_DeletePermission.html)\naction.","ref":"AWS.ACMPCA.html#list_permissions/3","title":"AWS.ACMPCA.list_permissions/3","type":"function"},{"doc":"* If the private CA and the certificates it issues reside in the\nsame account, you can use `CreatePermission` to grant permissions for ACM to\ncarry out automatic certificate renewals.\n\n  * For automatic certificate renewal to succeed, the ACM service\nprincipal needs permissions to create, retrieve, and list certificates.\n\n  * If the private CA and the ACM certificates reside in different\naccounts, then permissions cannot be used to enable automatic renewals. Instead,\nthe ACM certificate owner must set up a resource-based policy to enable\ncross-account issuance and renewals. For more information, see [Using a Resource Based Policy with Amazon Web Services Private\nCA](https://docs.aws.amazon.com/privateca/latest/userguide/pca-rbp.html).","ref":"AWS.ACMPCA.html#list_permissions/3-about-permissions","title":"About Permissions - AWS.ACMPCA.list_permissions/3","type":"function"},{"doc":"Lists the tags, if any, that are associated with your private CA or one that has\nbeen shared with you.\n\nTags are labels that you can use to identify and organize your CAs. Each tag\nconsists of a key and an optional value. Call the\n[TagCertificateAuthority](https://docs.aws.amazon.com/privateca/latest/APIReference/API_TagCertificateAuthority.html) action to add one or more tags to your CA. Call the\n[UntagCertificateAuthority](https://docs.aws.amazon.com/privateca/latest/APIReference/API_UntagCertificateAuthority.html)\naction to remove tags.","ref":"AWS.ACMPCA.html#list_tags/3","title":"AWS.ACMPCA.list_tags/3","type":"function"},{"doc":"","ref":"AWS.ACMPCA.html#metadata/0","title":"AWS.ACMPCA.metadata/0","type":"function"},{"doc":"Attaches a resource-based policy to a private CA.\n\nA policy can also be applied by sharing a private CA through Amazon Web Services\nResource Access Manager (RAM). For more information, see [Attach a Policy for Cross-Account\nAccess](https://docs.aws.amazon.com/privateca/latest/userguide/pca-ram.html).\n\nThe policy can be displayed with\n[GetPolicy](https://docs.aws.amazon.com/privateca/latest/APIReference/API_GetPolicy.html) and removed with\n[DeletePolicy](https://docs.aws.amazon.com/privateca/latest/APIReference/API_DeletePolicy.html).","ref":"AWS.ACMPCA.html#put_policy/3","title":"AWS.ACMPCA.put_policy/3","type":"function"},{"doc":"* A policy grants access on a private CA to an Amazon Web Services\ncustomer account, to Amazon Web Services Organizations, or to an Amazon Web\nServices Organizations unit. Policies are under the control of a CA\nadministrator. For more information, see [Using a Resource Based Policy with Amazon Web Services Private\nCA](https://docs.aws.amazon.com/privateca/latest/userguide/pca-rbp.html).\n\n  * A policy permits a user of Certificate Manager (ACM) to issue ACM\ncertificates signed by a CA in another account.\n\n  * For ACM to manage automatic renewal of these certificates, the ACM\nuser must configure a Service Linked Role (SLR). The SLR allows the ACM service\nto assume the identity of the user, subject to confirmation against the Amazon\nWeb Services Private CA policy. For more information, see [Using a Service Linked Role with\nACM](https://docs.aws.amazon.com/acm/latest/userguide/acm-slr.html).\n\n  * Updates made in Amazon Web Services Resource Manager (RAM) are\nreflected in policies. For more information, see [Attach a Policy for Cross-Account\nAccess](https://docs.aws.amazon.com/privateca/latest/userguide/pca-ram.html).","ref":"AWS.ACMPCA.html#put_policy/3-about-policies","title":"About Policies - AWS.ACMPCA.put_policy/3","type":"function"},{"doc":"Restores a certificate authority (CA) that is in the `DELETED` state.\n\nYou can restore a CA during the period that you defined in the\n**PermanentDeletionTimeInDays** parameter of the\n[DeleteCertificateAuthority](https://docs.aws.amazon.com/privateca/latest/APIReference/API_DeleteCertificateAuthority.html) action. Currently, you can specify 7 to 30 days. If you did not specify a\n**PermanentDeletionTimeInDays** value, by default you can restore the CA at any\ntime in a 30 day period. You can check the time remaining in the restoration\nperiod of a private CA in the `DELETED` state by calling the\n[DescribeCertificateAuthority](https://docs.aws.amazon.com/privateca/latest/APIReference/API_DescribeCertificateAuthority.html)\nor\n[ListCertificateAuthorities](https://docs.aws.amazon.com/privateca/latest/APIReference/API_ListCertificateAuthorities.html) actions. The status of a restored CA is set to its pre-deletion status when the\n**RestoreCertificateAuthority** action returns. To change its status to\n`ACTIVE`, call the\n[UpdateCertificateAuthority](https://docs.aws.amazon.com/privateca/latest/APIReference/API_UpdateCertificateAuthority.html)\naction. If the private CA was in the `PENDING_CERTIFICATE` state at deletion,\nyou must use the\n[ImportCertificateAuthorityCertificate](https://docs.aws.amazon.com/privateca/latest/APIReference/API_ImportCertificateAuthorityCertificate.html)\naction to import a certificate authority into the private CA before it can be\nactivated. You cannot restore a CA after the restoration period has ended.","ref":"AWS.ACMPCA.html#restore_certificate_authority/3","title":"AWS.ACMPCA.restore_certificate_authority/3","type":"function"},{"doc":"Revokes a certificate that was issued inside Amazon Web Services Private CA.\n\nIf you enable a certificate revocation list (CRL) when you create or update your\nprivate CA, information about the revoked certificates will be included in the\nCRL. Amazon Web Services Private CA writes the CRL to an S3 bucket that you\nspecify. A CRL is typically updated approximately 30 minutes after a certificate\nis revoked. If for any reason the CRL update fails, Amazon Web Services Private\nCA attempts makes further attempts every 15 minutes. With Amazon CloudWatch, you\ncan create alarms for the metrics `CRLGenerated` and `MisconfiguredCRLBucket`.\nFor more information, see [Supported CloudWatch Metrics](https://docs.aws.amazon.com/privateca/latest/userguide/PcaCloudWatch.html).\n\nBoth Amazon Web Services Private CA and the IAM principal must have permission\nto write to the S3 bucket that you specify. If the IAM principal making the call\ndoes not have permission to write to the bucket, then an exception is thrown.\nFor more information, see [Access policies for CRLs in Amazon S3](https://docs.aws.amazon.com/privateca/latest/userguide/crl-planning.html#s3-policies).\n\nAmazon Web Services Private CA also writes revocation information to the audit\nreport. For more information, see\n[CreateCertificateAuthorityAuditReport](https://docs.aws.amazon.com/privateca/latest/APIReference/API_CreateCertificateAuthorityAuditReport.html).\n\nYou cannot revoke a root CA self-signed certificate.","ref":"AWS.ACMPCA.html#revoke_certificate/3","title":"AWS.ACMPCA.revoke_certificate/3","type":"function"},{"doc":"Adds one or more tags to your private CA.\n\nTags are labels that you can use to identify and organize your Amazon Web\nServices resources. Each tag consists of a key and an optional value. You\nspecify the private CA on input by its Amazon Resource Name (ARN). You specify\nthe tag by using a key-value pair. You can apply a tag to just one private CA if\nyou want to identify a specific characteristic of that CA, or you can apply the\nsame tag to multiple private CAs if you want to filter for a common relationship\namong those CAs. To remove one or more tags, use the\n[UntagCertificateAuthority](https://docs.aws.amazon.com/privateca/latest/APIReference/API_UntagCertificateAuthority.html) action. Call the\n[ListTags](https://docs.aws.amazon.com/privateca/latest/APIReference/API_ListTags.html)\naction to see what tags are associated with your CA.\n\nTo attach tags to a private CA during the creation procedure, a CA administrator\nmust first associate an inline IAM policy with the `CreateCertificateAuthority`\naction and explicitly allow tagging. For more information, see [Attaching tags to a CA at the time of\ncreation](https://docs.aws.amazon.com/privateca/latest/userguide/auth-InlinePolicies.html#policy-tag-ca).","ref":"AWS.ACMPCA.html#tag_certificate_authority/3","title":"AWS.ACMPCA.tag_certificate_authority/3","type":"function"},{"doc":"Remove one or more tags from your private CA.\n\nA tag consists of a key-value pair. If you do not specify the value portion of\nthe tag when calling this action, the tag will be removed regardless of value.\nIf you specify a value, the tag is removed only if it is associated with the\nspecified value. To add tags to a private CA, use the\n[TagCertificateAuthority](https://docs.aws.amazon.com/privateca/latest/APIReference/API_TagCertificateAuthority.html). Call the\n[ListTags](https://docs.aws.amazon.com/privateca/latest/APIReference/API_ListTags.html)\naction to see what tags are associated with your CA.","ref":"AWS.ACMPCA.html#untag_certificate_authority/3","title":"AWS.ACMPCA.untag_certificate_authority/3","type":"function"},{"doc":"Updates the status or configuration of a private certificate authority (CA).\n\nYour private CA must be in the `ACTIVE` or `DISABLED` state before you can\nupdate it. You can disable a private CA that is in the `ACTIVE` state or make a\nCA that is in the `DISABLED` state active again.\n\nBoth Amazon Web Services Private CA and the IAM principal must have permission\nto write to the S3 bucket that you specify. If the IAM principal making the call\ndoes not have permission to write to the bucket, then an exception is thrown.\nFor more information, see [Access policies for CRLs in Amazon S3](https://docs.aws.amazon.com/privateca/latest/userguide/crl-planning.html#s3-policies).","ref":"AWS.ACMPCA.html#update_certificate_authority/3","title":"AWS.ACMPCA.update_certificate_authority/3","type":"function"},{"doc":"Amazon API Gateway\n\nAmazon API Gateway helps developers deliver robust, secure, and scalable mobile\nand web application back ends.\n\nAPI Gateway allows developers to securely connect mobile and web applications to\nAPIs that run on Lambda, Amazon EC2, or other publicly addressable web services\nthat are hosted outside of AWS.","ref":"AWS.APIGateway.html","title":"AWS.APIGateway","type":"module"},{"doc":"Create an ApiKey resource.","ref":"AWS.APIGateway.html#create_api_key/3","title":"AWS.APIGateway.create_api_key/3","type":"function"},{"doc":"Adds a new Authorizer resource to an existing RestApi resource.","ref":"AWS.APIGateway.html#create_authorizer/4","title":"AWS.APIGateway.create_authorizer/4","type":"function"},{"doc":"Creates a new BasePathMapping resource.","ref":"AWS.APIGateway.html#create_base_path_mapping/4","title":"AWS.APIGateway.create_base_path_mapping/4","type":"function"},{"doc":"Creates a Deployment resource, which makes a specified RestApi callable over the\ninternet.","ref":"AWS.APIGateway.html#create_deployment/4","title":"AWS.APIGateway.create_deployment/4","type":"function"},{"doc":"Creates a documentation part.","ref":"AWS.APIGateway.html#create_documentation_part/4","title":"AWS.APIGateway.create_documentation_part/4","type":"function"},{"doc":"Creates a documentation version","ref":"AWS.APIGateway.html#create_documentation_version/4","title":"AWS.APIGateway.create_documentation_version/4","type":"function"},{"doc":"Creates a new domain name.","ref":"AWS.APIGateway.html#create_domain_name/3","title":"AWS.APIGateway.create_domain_name/3","type":"function"},{"doc":"Adds a new Model resource to an existing RestApi resource.","ref":"AWS.APIGateway.html#create_model/4","title":"AWS.APIGateway.create_model/4","type":"function"},{"doc":"Creates a RequestValidator of a given RestApi.","ref":"AWS.APIGateway.html#create_request_validator/4","title":"AWS.APIGateway.create_request_validator/4","type":"function"},{"doc":"Creates a Resource resource.","ref":"AWS.APIGateway.html#create_resource/5","title":"AWS.APIGateway.create_resource/5","type":"function"},{"doc":"Creates a new RestApi resource.","ref":"AWS.APIGateway.html#create_rest_api/3","title":"AWS.APIGateway.create_rest_api/3","type":"function"},{"doc":"Creates a new Stage resource that references a pre-existing Deployment for the\nAPI.","ref":"AWS.APIGateway.html#create_stage/4","title":"AWS.APIGateway.create_stage/4","type":"function"},{"doc":"Creates a usage plan with the throttle and quota limits, as well as the\nassociated API stages, specified in the payload.","ref":"AWS.APIGateway.html#create_usage_plan/3","title":"AWS.APIGateway.create_usage_plan/3","type":"function"},{"doc":"Creates a usage plan key for adding an existing API key to a usage plan.","ref":"AWS.APIGateway.html#create_usage_plan_key/4","title":"AWS.APIGateway.create_usage_plan_key/4","type":"function"},{"doc":"Creates a VPC link, under the caller's account in a selected region, in an\nasynchronous operation that typically takes 2-4 minutes to complete and become\noperational.\n\nThe caller must have permissions to create and update VPC Endpoint services.","ref":"AWS.APIGateway.html#create_vpc_link/3","title":"AWS.APIGateway.create_vpc_link/3","type":"function"},{"doc":"Deletes the ApiKey resource.","ref":"AWS.APIGateway.html#delete_api_key/4","title":"AWS.APIGateway.delete_api_key/4","type":"function"},{"doc":"Deletes an existing Authorizer resource.","ref":"AWS.APIGateway.html#delete_authorizer/5","title":"AWS.APIGateway.delete_authorizer/5","type":"function"},{"doc":"Deletes the BasePathMapping resource.","ref":"AWS.APIGateway.html#delete_base_path_mapping/5","title":"AWS.APIGateway.delete_base_path_mapping/5","type":"function"},{"doc":"Deletes the ClientCertificate resource.","ref":"AWS.APIGateway.html#delete_client_certificate/4","title":"AWS.APIGateway.delete_client_certificate/4","type":"function"},{"doc":"Deletes a Deployment resource.\n\nDeleting a deployment will only succeed if there are no Stage resources\nassociated with it.","ref":"AWS.APIGateway.html#delete_deployment/5","title":"AWS.APIGateway.delete_deployment/5","type":"function"},{"doc":"Deletes a documentation part","ref":"AWS.APIGateway.html#delete_documentation_part/5","title":"AWS.APIGateway.delete_documentation_part/5","type":"function"},{"doc":"Deletes a documentation version.","ref":"AWS.APIGateway.html#delete_documentation_version/5","title":"AWS.APIGateway.delete_documentation_version/5","type":"function"},{"doc":"Deletes the DomainName resource.","ref":"AWS.APIGateway.html#delete_domain_name/4","title":"AWS.APIGateway.delete_domain_name/4","type":"function"},{"doc":"Clears any customization of a GatewayResponse of a specified response type on\nthe given RestApi and resets it with the default settings.","ref":"AWS.APIGateway.html#delete_gateway_response/5","title":"AWS.APIGateway.delete_gateway_response/5","type":"function"},{"doc":"Represents a delete integration.","ref":"AWS.APIGateway.html#delete_integration/6","title":"AWS.APIGateway.delete_integration/6","type":"function"},{"doc":"Represents a delete integration response.","ref":"AWS.APIGateway.html#delete_integration_response/7","title":"AWS.APIGateway.delete_integration_response/7","type":"function"},{"doc":"Deletes an existing Method resource.","ref":"AWS.APIGateway.html#delete_method/6","title":"AWS.APIGateway.delete_method/6","type":"function"},{"doc":"Deletes an existing MethodResponse resource.","ref":"AWS.APIGateway.html#delete_method_response/7","title":"AWS.APIGateway.delete_method_response/7","type":"function"},{"doc":"Deletes a model.","ref":"AWS.APIGateway.html#delete_model/5","title":"AWS.APIGateway.delete_model/5","type":"function"},{"doc":"Deletes a RequestValidator of a given RestApi.","ref":"AWS.APIGateway.html#delete_request_validator/5","title":"AWS.APIGateway.delete_request_validator/5","type":"function"},{"doc":"Deletes a Resource resource.","ref":"AWS.APIGateway.html#delete_resource/5","title":"AWS.APIGateway.delete_resource/5","type":"function"},{"doc":"Deletes the specified API.","ref":"AWS.APIGateway.html#delete_rest_api/4","title":"AWS.APIGateway.delete_rest_api/4","type":"function"},{"doc":"Deletes a Stage resource.","ref":"AWS.APIGateway.html#delete_stage/5","title":"AWS.APIGateway.delete_stage/5","type":"function"},{"doc":"Deletes a usage plan of a given plan Id.","ref":"AWS.APIGateway.html#delete_usage_plan/4","title":"AWS.APIGateway.delete_usage_plan/4","type":"function"},{"doc":"Deletes a usage plan key and remove the underlying API key from the associated\nusage plan.","ref":"AWS.APIGateway.html#delete_usage_plan_key/5","title":"AWS.APIGateway.delete_usage_plan_key/5","type":"function"},{"doc":"Deletes an existing VpcLink of a specified identifier.","ref":"AWS.APIGateway.html#delete_vpc_link/4","title":"AWS.APIGateway.delete_vpc_link/4","type":"function"},{"doc":"Flushes all authorizer cache entries on a stage.","ref":"AWS.APIGateway.html#flush_stage_authorizers_cache/5","title":"AWS.APIGateway.flush_stage_authorizers_cache/5","type":"function"},{"doc":"Flushes a stage's cache.","ref":"AWS.APIGateway.html#flush_stage_cache/5","title":"AWS.APIGateway.flush_stage_cache/5","type":"function"},{"doc":"Generates a ClientCertificate resource.","ref":"AWS.APIGateway.html#generate_client_certificate/3","title":"AWS.APIGateway.generate_client_certificate/3","type":"function"},{"doc":"Gets information about the current Account resource.","ref":"AWS.APIGateway.html#get_account/2","title":"AWS.APIGateway.get_account/2","type":"function"},{"doc":"Gets information about the current ApiKey resource.","ref":"AWS.APIGateway.html#get_api_key/4","title":"AWS.APIGateway.get_api_key/4","type":"function"},{"doc":"Gets information about the current ApiKeys resource.","ref":"AWS.APIGateway.html#get_api_keys/7","title":"AWS.APIGateway.get_api_keys/7","type":"function"},{"doc":"Describe an existing Authorizer resource.","ref":"AWS.APIGateway.html#get_authorizer/4","title":"AWS.APIGateway.get_authorizer/4","type":"function"},{"doc":"Describe an existing Authorizers resource.","ref":"AWS.APIGateway.html#get_authorizers/5","title":"AWS.APIGateway.get_authorizers/5","type":"function"},{"doc":"Describe a BasePathMapping resource.","ref":"AWS.APIGateway.html#get_base_path_mapping/4","title":"AWS.APIGateway.get_base_path_mapping/4","type":"function"},{"doc":"Represents a collection of BasePathMapping resources.","ref":"AWS.APIGateway.html#get_base_path_mappings/5","title":"AWS.APIGateway.get_base_path_mappings/5","type":"function"},{"doc":"Gets information about the current ClientCertificate resource.","ref":"AWS.APIGateway.html#get_client_certificate/3","title":"AWS.APIGateway.get_client_certificate/3","type":"function"},{"doc":"Gets a collection of ClientCertificate resources.","ref":"AWS.APIGateway.html#get_client_certificates/4","title":"AWS.APIGateway.get_client_certificates/4","type":"function"},{"doc":"Gets information about a Deployment resource.","ref":"AWS.APIGateway.html#get_deployment/5","title":"AWS.APIGateway.get_deployment/5","type":"function"},{"doc":"Gets information about a Deployments collection.","ref":"AWS.APIGateway.html#get_deployments/5","title":"AWS.APIGateway.get_deployments/5","type":"function"},{"doc":"Gets a documentation part.","ref":"AWS.APIGateway.html#get_documentation_part/4","title":"AWS.APIGateway.get_documentation_part/4","type":"function"},{"doc":"Gets documentation parts.","ref":"AWS.APIGateway.html#get_documentation_parts/9","title":"AWS.APIGateway.get_documentation_parts/9","type":"function"},{"doc":"Gets a documentation version.","ref":"AWS.APIGateway.html#get_documentation_version/4","title":"AWS.APIGateway.get_documentation_version/4","type":"function"},{"doc":"Gets documentation versions.","ref":"AWS.APIGateway.html#get_documentation_versions/5","title":"AWS.APIGateway.get_documentation_versions/5","type":"function"},{"doc":"Represents a domain name that is contained in a simpler, more intuitive URL that\ncan be called.","ref":"AWS.APIGateway.html#get_domain_name/3","title":"AWS.APIGateway.get_domain_name/3","type":"function"},{"doc":"Represents a collection of DomainName resources.","ref":"AWS.APIGateway.html#get_domain_names/4","title":"AWS.APIGateway.get_domain_names/4","type":"function"},{"doc":"Exports a deployed version of a RestApi in a specified format.","ref":"AWS.APIGateway.html#get_export/7","title":"AWS.APIGateway.get_export/7","type":"function"},{"doc":"Gets a GatewayResponse of a specified response type on the given RestApi.","ref":"AWS.APIGateway.html#get_gateway_response/4","title":"AWS.APIGateway.get_gateway_response/4","type":"function"},{"doc":"Gets the GatewayResponses collection on the given RestApi.\n\nIf an API developer has not added any definitions for gateway responses, the\nresult will be the API Gateway-generated default GatewayResponses collection for\nthe supported response types.","ref":"AWS.APIGateway.html#get_gateway_responses/5","title":"AWS.APIGateway.get_gateway_responses/5","type":"function"},{"doc":"Get the integration settings.","ref":"AWS.APIGateway.html#get_integration/5","title":"AWS.APIGateway.get_integration/5","type":"function"},{"doc":"Represents a get integration response.","ref":"AWS.APIGateway.html#get_integration_response/6","title":"AWS.APIGateway.get_integration_response/6","type":"function"},{"doc":"Describe an existing Method resource.","ref":"AWS.APIGateway.html#get_method/5","title":"AWS.APIGateway.get_method/5","type":"function"},{"doc":"Describes a MethodResponse resource.","ref":"AWS.APIGateway.html#get_method_response/6","title":"AWS.APIGateway.get_method_response/6","type":"function"},{"doc":"Describes an existing model defined for a RestApi resource.","ref":"AWS.APIGateway.html#get_model/5","title":"AWS.APIGateway.get_model/5","type":"function"},{"doc":"Generates a sample mapping template that can be used to transform a payload into\nthe structure of a model.","ref":"AWS.APIGateway.html#get_model_template/4","title":"AWS.APIGateway.get_model_template/4","type":"function"},{"doc":"Describes existing Models defined for a RestApi resource.","ref":"AWS.APIGateway.html#get_models/5","title":"AWS.APIGateway.get_models/5","type":"function"},{"doc":"Gets a RequestValidator of a given RestApi.","ref":"AWS.APIGateway.html#get_request_validator/4","title":"AWS.APIGateway.get_request_validator/4","type":"function"},{"doc":"Gets the RequestValidators collection of a given RestApi.","ref":"AWS.APIGateway.html#get_request_validators/5","title":"AWS.APIGateway.get_request_validators/5","type":"function"},{"doc":"Lists information about a resource.","ref":"AWS.APIGateway.html#get_resource/5","title":"AWS.APIGateway.get_resource/5","type":"function"},{"doc":"Lists information about a collection of Resource resources.","ref":"AWS.APIGateway.html#get_resources/6","title":"AWS.APIGateway.get_resources/6","type":"function"},{"doc":"Lists the RestApi resource in the collection.","ref":"AWS.APIGateway.html#get_rest_api/3","title":"AWS.APIGateway.get_rest_api/3","type":"function"},{"doc":"Lists the RestApis resources for your collection.","ref":"AWS.APIGateway.html#get_rest_apis/4","title":"AWS.APIGateway.get_rest_apis/4","type":"function"},{"doc":"Generates a client SDK for a RestApi and Stage.","ref":"AWS.APIGateway.html#get_sdk/6","title":"AWS.APIGateway.get_sdk/6","type":"function"},{"doc":"Gets an SDK type.","ref":"AWS.APIGateway.html#get_sdk_type/3","title":"AWS.APIGateway.get_sdk_type/3","type":"function"},{"doc":"Gets SDK types","ref":"AWS.APIGateway.html#get_sdk_types/4","title":"AWS.APIGateway.get_sdk_types/4","type":"function"},{"doc":"Gets information about a Stage resource.","ref":"AWS.APIGateway.html#get_stage/4","title":"AWS.APIGateway.get_stage/4","type":"function"},{"doc":"Gets information about one or more Stage resources.","ref":"AWS.APIGateway.html#get_stages/4","title":"AWS.APIGateway.get_stages/4","type":"function"},{"doc":"Gets the Tags collection for a given resource.","ref":"AWS.APIGateway.html#get_tags/5","title":"AWS.APIGateway.get_tags/5","type":"function"},{"doc":"Gets the usage data of a usage plan in a specified time interval.","ref":"AWS.APIGateway.html#get_usage/8","title":"AWS.APIGateway.get_usage/8","type":"function"},{"doc":"Gets a usage plan of a given plan identifier.","ref":"AWS.APIGateway.html#get_usage_plan/3","title":"AWS.APIGateway.get_usage_plan/3","type":"function"},{"doc":"Gets a usage plan key of a given key identifier.","ref":"AWS.APIGateway.html#get_usage_plan_key/4","title":"AWS.APIGateway.get_usage_plan_key/4","type":"function"},{"doc":"Gets all the usage plan keys representing the API keys added to a specified\nusage plan.","ref":"AWS.APIGateway.html#get_usage_plan_keys/6","title":"AWS.APIGateway.get_usage_plan_keys/6","type":"function"},{"doc":"Gets all the usage plans of the caller's account.","ref":"AWS.APIGateway.html#get_usage_plans/5","title":"AWS.APIGateway.get_usage_plans/5","type":"function"},{"doc":"Gets a specified VPC link under the caller's account in a region.","ref":"AWS.APIGateway.html#get_vpc_link/3","title":"AWS.APIGateway.get_vpc_link/3","type":"function"},{"doc":"Gets the VpcLinks collection under the caller's account in a selected region.","ref":"AWS.APIGateway.html#get_vpc_links/4","title":"AWS.APIGateway.get_vpc_links/4","type":"function"},{"doc":"Import API keys from an external source, such as a CSV-formatted file.","ref":"AWS.APIGateway.html#import_api_keys/3","title":"AWS.APIGateway.import_api_keys/3","type":"function"},{"doc":"Imports documentation parts","ref":"AWS.APIGateway.html#import_documentation_parts/4","title":"AWS.APIGateway.import_documentation_parts/4","type":"function"},{"doc":"A feature of the API Gateway control service for creating a new API from an\nexternal API definition file.","ref":"AWS.APIGateway.html#import_rest_api/3","title":"AWS.APIGateway.import_rest_api/3","type":"function"},{"doc":"","ref":"AWS.APIGateway.html#metadata/0","title":"AWS.APIGateway.metadata/0","type":"function"},{"doc":"Creates a customization of a GatewayResponse of a specified response type and\nstatus code on the given RestApi.","ref":"AWS.APIGateway.html#put_gateway_response/5","title":"AWS.APIGateway.put_gateway_response/5","type":"function"},{"doc":"Sets up a method's integration.","ref":"AWS.APIGateway.html#put_integration/6","title":"AWS.APIGateway.put_integration/6","type":"function"},{"doc":"Represents a put integration.","ref":"AWS.APIGateway.html#put_integration_response/7","title":"AWS.APIGateway.put_integration_response/7","type":"function"},{"doc":"Add a method to an existing Resource resource.","ref":"AWS.APIGateway.html#put_method/6","title":"AWS.APIGateway.put_method/6","type":"function"},{"doc":"Adds a MethodResponse to an existing Method resource.","ref":"AWS.APIGateway.html#put_method_response/7","title":"AWS.APIGateway.put_method_response/7","type":"function"},{"doc":"A feature of the API Gateway control service for updating an existing API with\nan input of external API definitions.\n\nThe update can take the form of merging the supplied definition into the\nexisting API or overwriting the existing API.","ref":"AWS.APIGateway.html#put_rest_api/4","title":"AWS.APIGateway.put_rest_api/4","type":"function"},{"doc":"Adds or updates a tag on a given resource.","ref":"AWS.APIGateway.html#tag_resource/4","title":"AWS.APIGateway.tag_resource/4","type":"function"},{"doc":"Simulate the execution of an Authorizer in your RestApi with headers,\nparameters, and an incoming request body.","ref":"AWS.APIGateway.html#test_invoke_authorizer/5","title":"AWS.APIGateway.test_invoke_authorizer/5","type":"function"},{"doc":"Simulate the invocation of a Method in your RestApi with headers, parameters,\nand an incoming request body.","ref":"AWS.APIGateway.html#test_invoke_method/6","title":"AWS.APIGateway.test_invoke_method/6","type":"function"},{"doc":"Removes a tag from a given resource.","ref":"AWS.APIGateway.html#untag_resource/4","title":"AWS.APIGateway.untag_resource/4","type":"function"},{"doc":"Changes information about the current Account resource.","ref":"AWS.APIGateway.html#update_account/3","title":"AWS.APIGateway.update_account/3","type":"function"},{"doc":"Changes information about an ApiKey resource.","ref":"AWS.APIGateway.html#update_api_key/4","title":"AWS.APIGateway.update_api_key/4","type":"function"},{"doc":"Updates an existing Authorizer resource.","ref":"AWS.APIGateway.html#update_authorizer/5","title":"AWS.APIGateway.update_authorizer/5","type":"function"},{"doc":"Changes information about the BasePathMapping resource.","ref":"AWS.APIGateway.html#update_base_path_mapping/5","title":"AWS.APIGateway.update_base_path_mapping/5","type":"function"},{"doc":"Changes information about an ClientCertificate resource.","ref":"AWS.APIGateway.html#update_client_certificate/4","title":"AWS.APIGateway.update_client_certificate/4","type":"function"},{"doc":"Changes information about a Deployment resource.","ref":"AWS.APIGateway.html#update_deployment/5","title":"AWS.APIGateway.update_deployment/5","type":"function"},{"doc":"Updates a documentation part.","ref":"AWS.APIGateway.html#update_documentation_part/5","title":"AWS.APIGateway.update_documentation_part/5","type":"function"},{"doc":"Updates a documentation version.","ref":"AWS.APIGateway.html#update_documentation_version/5","title":"AWS.APIGateway.update_documentation_version/5","type":"function"},{"doc":"Changes information about the DomainName resource.","ref":"AWS.APIGateway.html#update_domain_name/4","title":"AWS.APIGateway.update_domain_name/4","type":"function"},{"doc":"Updates a GatewayResponse of a specified response type on the given RestApi.","ref":"AWS.APIGateway.html#update_gateway_response/5","title":"AWS.APIGateway.update_gateway_response/5","type":"function"},{"doc":"Represents an update integration.","ref":"AWS.APIGateway.html#update_integration/6","title":"AWS.APIGateway.update_integration/6","type":"function"},{"doc":"Represents an update integration response.","ref":"AWS.APIGateway.html#update_integration_response/7","title":"AWS.APIGateway.update_integration_response/7","type":"function"},{"doc":"Updates an existing Method resource.","ref":"AWS.APIGateway.html#update_method/6","title":"AWS.APIGateway.update_method/6","type":"function"},{"doc":"Updates an existing MethodResponse resource.","ref":"AWS.APIGateway.html#update_method_response/7","title":"AWS.APIGateway.update_method_response/7","type":"function"},{"doc":"Changes information about a model.","ref":"AWS.APIGateway.html#update_model/5","title":"AWS.APIGateway.update_model/5","type":"function"},{"doc":"Updates a RequestValidator of a given RestApi.","ref":"AWS.APIGateway.html#update_request_validator/5","title":"AWS.APIGateway.update_request_validator/5","type":"function"},{"doc":"Changes information about a Resource resource.","ref":"AWS.APIGateway.html#update_resource/5","title":"AWS.APIGateway.update_resource/5","type":"function"},{"doc":"Changes information about the specified API.","ref":"AWS.APIGateway.html#update_rest_api/4","title":"AWS.APIGateway.update_rest_api/4","type":"function"},{"doc":"Changes information about a Stage resource.","ref":"AWS.APIGateway.html#update_stage/5","title":"AWS.APIGateway.update_stage/5","type":"function"},{"doc":"Grants a temporary extension to the remaining quota of a usage plan associated\nwith a specified API key.","ref":"AWS.APIGateway.html#update_usage/5","title":"AWS.APIGateway.update_usage/5","type":"function"},{"doc":"Updates a usage plan of a given plan Id.","ref":"AWS.APIGateway.html#update_usage_plan/4","title":"AWS.APIGateway.update_usage_plan/4","type":"function"},{"doc":"Updates an existing VpcLink of a specified identifier.","ref":"AWS.APIGateway.html#update_vpc_link/4","title":"AWS.APIGateway.update_vpc_link/4","type":"function"},{"doc":"Welcome to the Zonal Shift API Reference Guide for Amazon Route 53 Application\nRecovery Controller (Route 53 ARC).\n\nYou can start a zonal shift to move traffic for a load balancer resource away\nfrom an Availability Zone to help your application recover quickly from an\nimpairment in an Availability Zone. For example, you can recover your\napplication from a developer's bad code deployment or from an Amazon Web\nServices infrastructure failure in a single Availability Zone.\n\nYou can also configure zonal autoshift for a load balancer resource. Zonal\nautoshift is a capability in Route 53 ARC where Amazon Web Services shifts away\napplication resource traffic from an Availability Zone, on your behalf, to help\nreduce your time to recovery during events. Amazon Web Services shifts away\ntraffic for resources that are enabled for zonal autoshift whenever Amazon Web\nServices determines that there's an issue in the Availability Zone that could\npotentially affect customers.\n\nTo ensure that zonal autoshift is safe for your application, you must also\nconfigure practice runs when you enable zonal autoshift for a resource. Practice\nruns start weekly zonal shifts for a resource, to shift traffic for the resource\nout of an Availability Zone. Practice runs make sure, on a regular basis, that\nyou have enough capacity in all the Availability Zones in an Amazon Web Services\nRegion for your application to continue to operate normally when traffic for a\nresource is shifted away from one Availability Zone.\n\nYou must prescale resource capacity in all Availability Zones in the Region\nwhere your application is deployed, before you configure practice runs or enable\nzonal autoshift for a resource. You should not rely on scaling on demand when an\nautoshift or practice run starts.\n\nFor more information about using zonal shift and zonal autoshift, see the\n[Amazon Route 53 Application Recovery Controller Developer Guide](https://docs.aws.amazon.com/r53recovery/latest/dg/what-is-route53-recovery.html).","ref":"AWS.ARCZonalShift.html","title":"AWS.ARCZonalShift","type":"module"},{"doc":"Cancel a zonal shift in Amazon Route 53 Application Recovery Controller.\n\nTo cancel the zonal shift, specify the zonal shift ID.\n\nA zonal shift can be one that you've started for a resource in your Amazon Web\nServices account in an Amazon Web Services Region, or it can be a zonal shift\nstarted by a practice run with zonal autoshift.","ref":"AWS.ARCZonalShift.html#cancel_zonal_shift/4","title":"AWS.ARCZonalShift.cancel_zonal_shift/4","type":"function"},{"doc":"A practice run configuration for zonal autoshift is required when you enable\nzonal autoshift.\n\nA practice run configuration includes specifications for blocked dates and\nblocked time windows, and for Amazon CloudWatch alarms that you create to use\nwith practice runs. The alarms that you specify are an *outcome alarm*, to\nmonitor application health during practice runs and, optionally, a *blocking\nalarm*, to block practice runs from starting.\n\nFor more information, see [ Considerations when you configure zonal autoshift](https://docs.aws.amazon.com/r53recovery/latest/dg/arc-zonal-autoshift.considerations.html)\nin the Amazon Route 53 Application Recovery Controller Developer Guide.","ref":"AWS.ARCZonalShift.html#create_practice_run_configuration/3","title":"AWS.ARCZonalShift.create_practice_run_configuration/3","type":"function"},{"doc":"Deletes the practice run configuration for a resource.\n\nBefore you can delete a practice run configuration for a resource., you must\ndisable zonal autoshift for the resource. Practice runs must be configured for\nzonal autoshift to be enabled.","ref":"AWS.ARCZonalShift.html#delete_practice_run_configuration/4","title":"AWS.ARCZonalShift.delete_practice_run_configuration/4","type":"function"},{"doc":"Get information about a resource that's been registered for zonal shifts with\nAmazon Route 53 Application Recovery Controller in this Amazon Web Services\nRegion.\n\nResources that are registered for zonal shifts are managed resources in Route 53\nARC. You can start zonal shifts and configure zonal autoshift for managed\nresources.\n\nAt this time, you can only start a zonal shift or configure zonal autoshift for\nNetwork Load Balancers and Application Load Balancers with cross-zone load\nbalancing turned off.","ref":"AWS.ARCZonalShift.html#get_managed_resource/3","title":"AWS.ARCZonalShift.get_managed_resource/3","type":"function"},{"doc":"Returns the active autoshifts for a specified resource.","ref":"AWS.ARCZonalShift.html#list_autoshifts/5","title":"AWS.ARCZonalShift.list_autoshifts/5","type":"function"},{"doc":"Lists all the resources in your Amazon Web Services account in this Amazon Web\nServices Region that are managed for zonal shifts in Amazon Route 53 Application\nRecovery Controller, and information about them.\n\nThe information includes the zonal autoshift status for the resource, as well as\nthe Amazon Resource Name (ARN), the Availability Zones that each resource is\ndeployed in, and the resource name.","ref":"AWS.ARCZonalShift.html#list_managed_resources/4","title":"AWS.ARCZonalShift.list_managed_resources/4","type":"function"},{"doc":"Lists all active and completed zonal shifts in Amazon Route 53 Application\nRecovery Controller in your Amazon Web Services account in this Amazon Web\nServices Region.\n\n`ListZonalShifts` returns customer-started zonal shifts, as well as practice run\nzonal shifts that Route 53 ARC started on your behalf for zonal autoshift.\n\nThe `ListZonalShifts` operation does not list autoshifts. For more information\nabout listing autoshifts, see\n[\">ListAutoshifts](https://docs.aws.amazon.com/arc-zonal-shift/latest/api/API_ListAutoshifts.html).","ref":"AWS.ARCZonalShift.html#list_zonal_shifts/6","title":"AWS.ARCZonalShift.list_zonal_shifts/6","type":"function"},{"doc":"","ref":"AWS.ARCZonalShift.html#metadata/0","title":"AWS.ARCZonalShift.metadata/0","type":"function"},{"doc":"You start a zonal shift to temporarily move load balancer traffic away from an\nAvailability Zone in an Amazon Web Services Region, to help your application\nrecover immediately, for example, from a developer's bad code deployment or from\nan Amazon Web Services infrastructure failure in a single Availability Zone.\n\nYou can start a zonal shift in Route 53 ARC only for managed resources in your\nAmazon Web Services account in an Amazon Web Services Region. Resources are\nautomatically registered with Route 53 ARC by Amazon Web Services services.\n\nAt this time, you can only start a zonal shift for Network Load Balancers and\nApplication Load Balancers with cross-zone load balancing turned off.\n\nWhen you start a zonal shift, traffic for the resource is no longer routed to\nthe Availability Zone. The zonal shift is created immediately in Route 53 ARC.\nHowever, it can take a short time, typically up to a few minutes, for existing,\nin-progress connections in the Availability Zone to complete.\n\nFor more information, see [Zonal shift](https://docs.aws.amazon.com/r53recovery/latest/dg/arc-zonal-shift.html)\nin the Amazon Route 53 Application Recovery Controller Developer Guide.","ref":"AWS.ARCZonalShift.html#start_zonal_shift/3","title":"AWS.ARCZonalShift.start_zonal_shift/3","type":"function"},{"doc":"Update a practice run configuration to change one or more of the following: add,\nchange, or remove the blocking alarm; change the outcome alarm; or add, change,\nor remove blocking dates or time windows.","ref":"AWS.ARCZonalShift.html#update_practice_run_configuration/4","title":"AWS.ARCZonalShift.update_practice_run_configuration/4","type":"function"},{"doc":"You can update the zonal autoshift status for a resource, to enable or disable\nzonal autoshift.\n\nWhen zonal autoshift is `ENABLED`, Amazon Web Services shifts away resource\ntraffic from an Availability Zone, on your behalf, when Amazon Web Services\ndetermines that there's an issue in the Availability Zone that could potentially\naffect customers.","ref":"AWS.ARCZonalShift.html#update_zonal_autoshift_configuration/4","title":"AWS.ARCZonalShift.update_zonal_autoshift_configuration/4","type":"function"},{"doc":"Update an active zonal shift in Amazon Route 53 Application Recovery Controller\nin your Amazon Web Services account.\n\nYou can update a zonal shift to set a new expiration, or edit or replace the\ncomment for the zonal shift.","ref":"AWS.ARCZonalShift.html#update_zonal_shift/4","title":"AWS.ARCZonalShift.update_zonal_shift/4","type":"function"},{"doc":"Identity and Access Management Access Analyzer helps you to set, verify, and\nrefine your IAM policies by providing a suite of capabilities.\n\nIts features include findings for external and unused access, basic and custom\npolicy checks for validating policies, and policy generation to generate\nfine-grained policies. To start using IAM Access Analyzer to identify external\nor unused access, you first need to create an analyzer.\n\n**External access analyzers** help identify potential risks of accessing\nresources by enabling you to identify any resource policies that grant access to\nan external principal. It does this by using logic-based reasoning to analyze\nresource-based policies in your Amazon Web Services environment. An external\nprincipal can be another Amazon Web Services account, a root user, an IAM user\nor role, a federated user, an Amazon Web Services service, or an anonymous user.\nYou can also use IAM Access Analyzer to preview public and cross-account access\nto your resources before deploying permissions changes.\n\n**Unused access analyzers** help identify potential identity access risks by\nenabling you to identify unused IAM roles, unused access keys, unused console\npasswords, and IAM principals with unused service and action-level permissions.\n\nBeyond findings, IAM Access Analyzer provides basic and custom policy checks to\nvalidate IAM policies before deploying permissions changes. You can use policy\ngeneration to refine permissions by attaching a policy generated using access\nactivity logged in CloudTrail logs.\n\nThis guide describes the IAM Access Analyzer operations that you can call\nprogrammatically. For general information about IAM Access Analyzer, see\n[Identity and Access Management Access Analyzer](https://docs.aws.amazon.com/IAM/latest/UserGuide/what-is-access-analyzer.html)\nin the **IAM User Guide**.","ref":"AWS.AccessAnalyzer.html","title":"AWS.AccessAnalyzer","type":"module"},{"doc":"Retroactively applies the archive rule to existing findings that meet the\narchive rule criteria.","ref":"AWS.AccessAnalyzer.html#apply_archive_rule/3","title":"AWS.AccessAnalyzer.apply_archive_rule/3","type":"function"},{"doc":"Cancels the requested policy generation.","ref":"AWS.AccessAnalyzer.html#cancel_policy_generation/4","title":"AWS.AccessAnalyzer.cancel_policy_generation/4","type":"function"},{"doc":"Checks whether the specified access isn't allowed by a policy.","ref":"AWS.AccessAnalyzer.html#check_access_not_granted/3","title":"AWS.AccessAnalyzer.check_access_not_granted/3","type":"function"},{"doc":"Checks whether new access is allowed for an updated policy when compared to the\nexisting policy.\n\nYou can find examples for reference policies and learn how to set up and run a\ncustom policy check for new access in the [IAM Access Analyzer custom policy checks\nsamples](https://github.com/aws-samples/iam-access-analyzer-custom-policy-check-samples)\nrepository on GitHub. The reference policies in this repository are meant to be\npassed to the `existingPolicyDocument` request parameter.","ref":"AWS.AccessAnalyzer.html#check_no_new_access/3","title":"AWS.AccessAnalyzer.check_no_new_access/3","type":"function"},{"doc":"Creates an access preview that allows you to preview IAM Access Analyzer\nfindings for your resource before deploying resource permissions.","ref":"AWS.AccessAnalyzer.html#create_access_preview/3","title":"AWS.AccessAnalyzer.create_access_preview/3","type":"function"},{"doc":"Creates an analyzer for your account.","ref":"AWS.AccessAnalyzer.html#create_analyzer/3","title":"AWS.AccessAnalyzer.create_analyzer/3","type":"function"},{"doc":"Creates an archive rule for the specified analyzer.\n\nArchive rules automatically archive new findings that meet the criteria you\ndefine when you create the rule.\n\nTo learn about filter keys that you can use to create an archive rule, see [IAM Access Analyzer filter\nkeys](https://docs.aws.amazon.com/IAM/latest/UserGuide/access-analyzer-reference-filter-keys.html)\nin the **IAM User Guide**.","ref":"AWS.AccessAnalyzer.html#create_archive_rule/4","title":"AWS.AccessAnalyzer.create_archive_rule/4","type":"function"},{"doc":"Deletes the specified analyzer.\n\nWhen you delete an analyzer, IAM Access Analyzer is disabled for the account or\norganization in the current or specific Region. All findings that were generated\nby the analyzer are deleted. You cannot undo this action.","ref":"AWS.AccessAnalyzer.html#delete_analyzer/4","title":"AWS.AccessAnalyzer.delete_analyzer/4","type":"function"},{"doc":"Deletes the specified archive rule.","ref":"AWS.AccessAnalyzer.html#delete_archive_rule/5","title":"AWS.AccessAnalyzer.delete_archive_rule/5","type":"function"},{"doc":"Retrieves information about an access preview for the specified analyzer.","ref":"AWS.AccessAnalyzer.html#get_access_preview/4","title":"AWS.AccessAnalyzer.get_access_preview/4","type":"function"},{"doc":"Retrieves information about a resource that was analyzed.","ref":"AWS.AccessAnalyzer.html#get_analyzed_resource/4","title":"AWS.AccessAnalyzer.get_analyzed_resource/4","type":"function"},{"doc":"Retrieves information about the specified analyzer.","ref":"AWS.AccessAnalyzer.html#get_analyzer/3","title":"AWS.AccessAnalyzer.get_analyzer/3","type":"function"},{"doc":"Retrieves information about an archive rule.\n\nTo learn about filter keys that you can use to create an archive rule, see [IAM Access Analyzer filter\nkeys](https://docs.aws.amazon.com/IAM/latest/UserGuide/access-analyzer-reference-filter-keys.html)\nin the **IAM User Guide**.","ref":"AWS.AccessAnalyzer.html#get_archive_rule/4","title":"AWS.AccessAnalyzer.get_archive_rule/4","type":"function"},{"doc":"Retrieves information about the specified finding.","ref":"AWS.AccessAnalyzer.html#get_finding/4","title":"AWS.AccessAnalyzer.get_finding/4","type":"function"},{"doc":"Retrieves information about the specified finding.","ref":"AWS.AccessAnalyzer.html#get_finding_v2/6","title":"AWS.AccessAnalyzer.get_finding_v2/6","type":"function"},{"doc":"Retrieves the policy that was generated using `StartPolicyGeneration`.","ref":"AWS.AccessAnalyzer.html#get_generated_policy/5","title":"AWS.AccessAnalyzer.get_generated_policy/5","type":"function"},{"doc":"Retrieves a list of access preview findings generated by the specified access\npreview.","ref":"AWS.AccessAnalyzer.html#list_access_preview_findings/4","title":"AWS.AccessAnalyzer.list_access_preview_findings/4","type":"function"},{"doc":"Retrieves a list of access previews for the specified analyzer.","ref":"AWS.AccessAnalyzer.html#list_access_previews/5","title":"AWS.AccessAnalyzer.list_access_previews/5","type":"function"},{"doc":"Retrieves a list of resources of the specified type that have been analyzed by\nthe specified analyzer..","ref":"AWS.AccessAnalyzer.html#list_analyzed_resources/3","title":"AWS.AccessAnalyzer.list_analyzed_resources/3","type":"function"},{"doc":"Retrieves a list of analyzers.","ref":"AWS.AccessAnalyzer.html#list_analyzers/5","title":"AWS.AccessAnalyzer.list_analyzers/5","type":"function"},{"doc":"Retrieves a list of archive rules created for the specified analyzer.","ref":"AWS.AccessAnalyzer.html#list_archive_rules/5","title":"AWS.AccessAnalyzer.list_archive_rules/5","type":"function"},{"doc":"Retrieves a list of findings generated by the specified analyzer.\n\nTo learn about filter keys that you can use to retrieve a list of findings, see\n[IAM Access Analyzer filter keys](https://docs.aws.amazon.com/IAM/latest/UserGuide/access-analyzer-reference-filter-keys.html)\nin the **IAM User Guide**.","ref":"AWS.AccessAnalyzer.html#list_findings/3","title":"AWS.AccessAnalyzer.list_findings/3","type":"function"},{"doc":"Retrieves a list of findings generated by the specified analyzer.\n\nTo learn about filter keys that you can use to retrieve a list of findings, see\n[IAM Access Analyzer filter keys](https://docs.aws.amazon.com/IAM/latest/UserGuide/access-analyzer-reference-filter-keys.html)\nin the **IAM User Guide**.","ref":"AWS.AccessAnalyzer.html#list_findings_v2/3","title":"AWS.AccessAnalyzer.list_findings_v2/3","type":"function"},{"doc":"Lists all of the policy generations requested in the last seven days.","ref":"AWS.AccessAnalyzer.html#list_policy_generations/5","title":"AWS.AccessAnalyzer.list_policy_generations/5","type":"function"},{"doc":"Retrieves a list of tags applied to the specified resource.","ref":"AWS.AccessAnalyzer.html#list_tags_for_resource/3","title":"AWS.AccessAnalyzer.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.AccessAnalyzer.html#metadata/0","title":"AWS.AccessAnalyzer.metadata/0","type":"function"},{"doc":"Starts the policy generation request.","ref":"AWS.AccessAnalyzer.html#start_policy_generation/3","title":"AWS.AccessAnalyzer.start_policy_generation/3","type":"function"},{"doc":"Immediately starts a scan of the policies applied to the specified resource.","ref":"AWS.AccessAnalyzer.html#start_resource_scan/3","title":"AWS.AccessAnalyzer.start_resource_scan/3","type":"function"},{"doc":"Adds a tag to the specified resource.","ref":"AWS.AccessAnalyzer.html#tag_resource/4","title":"AWS.AccessAnalyzer.tag_resource/4","type":"function"},{"doc":"Removes a tag from the specified resource.","ref":"AWS.AccessAnalyzer.html#untag_resource/4","title":"AWS.AccessAnalyzer.untag_resource/4","type":"function"},{"doc":"Updates the criteria and values for the specified archive rule.","ref":"AWS.AccessAnalyzer.html#update_archive_rule/5","title":"AWS.AccessAnalyzer.update_archive_rule/5","type":"function"},{"doc":"Updates the status for the specified findings.","ref":"AWS.AccessAnalyzer.html#update_findings/3","title":"AWS.AccessAnalyzer.update_findings/3","type":"function"},{"doc":"Requests the validation of a policy and returns a list of findings.\n\nThe findings help you identify issues and provide actionable recommendations to\nresolve the issue and enable you to author functional policies that meet\nsecurity best practices.","ref":"AWS.AccessAnalyzer.html#validate_policy/3","title":"AWS.AccessAnalyzer.validate_policy/3","type":"function"},{"doc":"Operations for Amazon Web Services Account Management","ref":"AWS.Account.html","title":"AWS.Account","type":"module"},{"doc":"Deletes the specified alternate contact from an Amazon Web Services account.\n\nFor complete details about how to use the alternate contact operations, see\n[Access or updating the alternate contacts](https://docs.aws.amazon.com/accounts/latest/reference/manage-acct-update-contact.html).\n\nBefore you can update the alternate contact information for an Amazon Web\nServices account that is managed by Organizations, you must first enable\nintegration between Amazon Web Services Account Management and Organizations.\nFor more information, see [Enabling trusted access for Amazon Web Services Account\nManagement](https://docs.aws.amazon.com/accounts/latest/reference/using-orgs-trusted-access.html).","ref":"AWS.Account.html#delete_alternate_contact/3","title":"AWS.Account.delete_alternate_contact/3","type":"function"},{"doc":"Disables (opts-out) a particular Region for an account.","ref":"AWS.Account.html#disable_region/3","title":"AWS.Account.disable_region/3","type":"function"},{"doc":"Enables (opts-in) a particular Region for an account.","ref":"AWS.Account.html#enable_region/3","title":"AWS.Account.enable_region/3","type":"function"},{"doc":"Retrieves the specified alternate contact attached to an Amazon Web Services\naccount.\n\nFor complete details about how to use the alternate contact operations, see\n[Access or updating the alternate contacts](https://docs.aws.amazon.com/accounts/latest/reference/manage-acct-update-contact.html).\n\nBefore you can update the alternate contact information for an Amazon Web\nServices account that is managed by Organizations, you must first enable\nintegration between Amazon Web Services Account Management and Organizations.\nFor more information, see [Enabling trusted access for Amazon Web Services Account\nManagement](https://docs.aws.amazon.com/accounts/latest/reference/using-orgs-trusted-access.html).","ref":"AWS.Account.html#get_alternate_contact/3","title":"AWS.Account.get_alternate_contact/3","type":"function"},{"doc":"Retrieves the primary contact information of an Amazon Web Services account.\n\nFor complete details about how to use the primary contact operations, see\n[Update the primary and alternate contact information](https://docs.aws.amazon.com/accounts/latest/reference/manage-acct-update-contact.html).","ref":"AWS.Account.html#get_contact_information/3","title":"AWS.Account.get_contact_information/3","type":"function"},{"doc":"Retrieves the opt-in status of a particular Region.","ref":"AWS.Account.html#get_region_opt_status/3","title":"AWS.Account.get_region_opt_status/3","type":"function"},{"doc":"Lists all the Regions for a given account and their respective opt-in statuses.\n\nOptionally, this list can be filtered by the `region-opt-status-contains`\nparameter.","ref":"AWS.Account.html#list_regions/3","title":"AWS.Account.list_regions/3","type":"function"},{"doc":"","ref":"AWS.Account.html#metadata/0","title":"AWS.Account.metadata/0","type":"function"},{"doc":"Modifies the specified alternate contact attached to an Amazon Web Services\naccount.\n\nFor complete details about how to use the alternate contact operations, see\n[Access or updating the alternate contacts](https://docs.aws.amazon.com/accounts/latest/reference/manage-acct-update-contact.html).\n\nBefore you can update the alternate contact information for an Amazon Web\nServices account that is managed by Organizations, you must first enable\nintegration between Amazon Web Services Account Management and Organizations.\nFor more information, see [Enabling trusted access for Amazon Web Services Account\nManagement](https://docs.aws.amazon.com/accounts/latest/reference/using-orgs-trusted-access.html).","ref":"AWS.Account.html#put_alternate_contact/3","title":"AWS.Account.put_alternate_contact/3","type":"function"},{"doc":"Updates the primary contact information of an Amazon Web Services account.\n\nFor complete details about how to use the primary contact operations, see\n[Update the primary and alternate contact information](https://docs.aws.amazon.com/accounts/latest/reference/manage-acct-update-contact.html).","ref":"AWS.Account.html#put_contact_information/3","title":"AWS.Account.put_contact_information/3","type":"function"},{"doc":"Alexa for Business has been retired and is no longer supported.","ref":"AWS.AlexaForBusiness.html","title":"AWS.AlexaForBusiness","type":"module"},{"doc":"Associates a skill with the organization under the customer's AWS account.\n\nIf a skill is private, the user implicitly accepts access to this skill during\nenablement.","ref":"AWS.AlexaForBusiness.html#approve_skill/3","title":"AWS.AlexaForBusiness.approve_skill/3","type":"function"},{"doc":"Associates a contact with a given address book.","ref":"AWS.AlexaForBusiness.html#associate_contact_with_address_book/3","title":"AWS.AlexaForBusiness.associate_contact_with_address_book/3","type":"function"},{"doc":"Associates a device with the specified network profile.","ref":"AWS.AlexaForBusiness.html#associate_device_with_network_profile/3","title":"AWS.AlexaForBusiness.associate_device_with_network_profile/3","type":"function"},{"doc":"Associates a device with a given room.\n\nThis applies all the settings from the room profile to the device, and all the\nskills in any skill groups added to that room. This operation requires the\ndevice to be online, or else a manual sync is required.","ref":"AWS.AlexaForBusiness.html#associate_device_with_room/3","title":"AWS.AlexaForBusiness.associate_device_with_room/3","type":"function"},{"doc":"Associates a skill group with a given room.\n\nThis enables all skills in the associated skill group on all devices in the\nroom.","ref":"AWS.AlexaForBusiness.html#associate_skill_group_with_room/3","title":"AWS.AlexaForBusiness.associate_skill_group_with_room/3","type":"function"},{"doc":"Associates a skill with a skill group.","ref":"AWS.AlexaForBusiness.html#associate_skill_with_skill_group/3","title":"AWS.AlexaForBusiness.associate_skill_with_skill_group/3","type":"function"},{"doc":"Makes a private skill available for enrolled users to enable on their devices.","ref":"AWS.AlexaForBusiness.html#associate_skill_with_users/3","title":"AWS.AlexaForBusiness.associate_skill_with_users/3","type":"function"},{"doc":"Creates an address book with the specified details.","ref":"AWS.AlexaForBusiness.html#create_address_book/3","title":"AWS.AlexaForBusiness.create_address_book/3","type":"function"},{"doc":"Creates a recurring schedule for usage reports to deliver to the specified S3\nlocation with a specified daily or weekly interval.","ref":"AWS.AlexaForBusiness.html#create_business_report_schedule/3","title":"AWS.AlexaForBusiness.create_business_report_schedule/3","type":"function"},{"doc":"Adds a new conference provider under the user's AWS account.","ref":"AWS.AlexaForBusiness.html#create_conference_provider/3","title":"AWS.AlexaForBusiness.create_conference_provider/3","type":"function"},{"doc":"Creates a contact with the specified details.","ref":"AWS.AlexaForBusiness.html#create_contact/3","title":"AWS.AlexaForBusiness.create_contact/3","type":"function"},{"doc":"Creates a gateway group with the specified details.","ref":"AWS.AlexaForBusiness.html#create_gateway_group/3","title":"AWS.AlexaForBusiness.create_gateway_group/3","type":"function"},{"doc":"Creates a network profile with the specified details.","ref":"AWS.AlexaForBusiness.html#create_network_profile/3","title":"AWS.AlexaForBusiness.create_network_profile/3","type":"function"},{"doc":"Creates a new room profile with the specified details.","ref":"AWS.AlexaForBusiness.html#create_profile/3","title":"AWS.AlexaForBusiness.create_profile/3","type":"function"},{"doc":"Creates a room with the specified details.","ref":"AWS.AlexaForBusiness.html#create_room/3","title":"AWS.AlexaForBusiness.create_room/3","type":"function"},{"doc":"Creates a skill group with a specified name and description.","ref":"AWS.AlexaForBusiness.html#create_skill_group/3","title":"AWS.AlexaForBusiness.create_skill_group/3","type":"function"},{"doc":"Creates a user.","ref":"AWS.AlexaForBusiness.html#create_user/3","title":"AWS.AlexaForBusiness.create_user/3","type":"function"},{"doc":"Deletes an address book by the address book ARN.","ref":"AWS.AlexaForBusiness.html#delete_address_book/3","title":"AWS.AlexaForBusiness.delete_address_book/3","type":"function"},{"doc":"Deletes the recurring report delivery schedule with the specified schedule ARN.","ref":"AWS.AlexaForBusiness.html#delete_business_report_schedule/3","title":"AWS.AlexaForBusiness.delete_business_report_schedule/3","type":"function"},{"doc":"Deletes a conference provider.","ref":"AWS.AlexaForBusiness.html#delete_conference_provider/3","title":"AWS.AlexaForBusiness.delete_conference_provider/3","type":"function"},{"doc":"Deletes a contact by the contact ARN.","ref":"AWS.AlexaForBusiness.html#delete_contact/3","title":"AWS.AlexaForBusiness.delete_contact/3","type":"function"},{"doc":"Removes a device from Alexa For Business.","ref":"AWS.AlexaForBusiness.html#delete_device/3","title":"AWS.AlexaForBusiness.delete_device/3","type":"function"},{"doc":"When this action is called for a specified shared device, it allows authorized\nusers to delete the device's entire previous history of voice input data and\nassociated response data.\n\nThis action can be called once every 24 hours for a specific shared device.","ref":"AWS.AlexaForBusiness.html#delete_device_usage_data/3","title":"AWS.AlexaForBusiness.delete_device_usage_data/3","type":"function"},{"doc":"Deletes a gateway group.","ref":"AWS.AlexaForBusiness.html#delete_gateway_group/3","title":"AWS.AlexaForBusiness.delete_gateway_group/3","type":"function"},{"doc":"Deletes a network profile by the network profile ARN.","ref":"AWS.AlexaForBusiness.html#delete_network_profile/3","title":"AWS.AlexaForBusiness.delete_network_profile/3","type":"function"},{"doc":"Deletes a room profile by the profile ARN.","ref":"AWS.AlexaForBusiness.html#delete_profile/3","title":"AWS.AlexaForBusiness.delete_profile/3","type":"function"},{"doc":"Deletes a room by the room ARN.","ref":"AWS.AlexaForBusiness.html#delete_room/3","title":"AWS.AlexaForBusiness.delete_room/3","type":"function"},{"doc":"Deletes room skill parameter details by room, skill, and parameter key ID.","ref":"AWS.AlexaForBusiness.html#delete_room_skill_parameter/3","title":"AWS.AlexaForBusiness.delete_room_skill_parameter/3","type":"function"},{"doc":"Unlinks a third-party account from a skill.","ref":"AWS.AlexaForBusiness.html#delete_skill_authorization/3","title":"AWS.AlexaForBusiness.delete_skill_authorization/3","type":"function"},{"doc":"Deletes a skill group by skill group ARN.","ref":"AWS.AlexaForBusiness.html#delete_skill_group/3","title":"AWS.AlexaForBusiness.delete_skill_group/3","type":"function"},{"doc":"Deletes a specified user by user ARN and enrollment ARN.","ref":"AWS.AlexaForBusiness.html#delete_user/3","title":"AWS.AlexaForBusiness.delete_user/3","type":"function"},{"doc":"Disassociates a contact from a given address book.","ref":"AWS.AlexaForBusiness.html#disassociate_contact_from_address_book/3","title":"AWS.AlexaForBusiness.disassociate_contact_from_address_book/3","type":"function"},{"doc":"Disassociates a device from its current room.\n\nThe device continues to be connected to the Wi-Fi network and is still\nregistered to the account. The device settings and skills are removed from the\nroom.","ref":"AWS.AlexaForBusiness.html#disassociate_device_from_room/3","title":"AWS.AlexaForBusiness.disassociate_device_from_room/3","type":"function"},{"doc":"Disassociates a skill from a skill group.","ref":"AWS.AlexaForBusiness.html#disassociate_skill_from_skill_group/3","title":"AWS.AlexaForBusiness.disassociate_skill_from_skill_group/3","type":"function"},{"doc":"Makes a private skill unavailable for enrolled users and prevents them from\nenabling it on their devices.","ref":"AWS.AlexaForBusiness.html#disassociate_skill_from_users/3","title":"AWS.AlexaForBusiness.disassociate_skill_from_users/3","type":"function"},{"doc":"Disassociates a skill group from a specified room.\n\nThis disables all skills in the skill group on all devices in the room.","ref":"AWS.AlexaForBusiness.html#disassociate_skill_group_from_room/3","title":"AWS.AlexaForBusiness.disassociate_skill_group_from_room/3","type":"function"},{"doc":"Forgets smart home appliances associated to a room.","ref":"AWS.AlexaForBusiness.html#forget_smart_home_appliances/3","title":"AWS.AlexaForBusiness.forget_smart_home_appliances/3","type":"function"},{"doc":"Gets address the book details by the address book ARN.","ref":"AWS.AlexaForBusiness.html#get_address_book/3","title":"AWS.AlexaForBusiness.get_address_book/3","type":"function"},{"doc":"Retrieves the existing conference preferences.","ref":"AWS.AlexaForBusiness.html#get_conference_preference/3","title":"AWS.AlexaForBusiness.get_conference_preference/3","type":"function"},{"doc":"Gets details about a specific conference provider.","ref":"AWS.AlexaForBusiness.html#get_conference_provider/3","title":"AWS.AlexaForBusiness.get_conference_provider/3","type":"function"},{"doc":"Gets the contact details by the contact ARN.","ref":"AWS.AlexaForBusiness.html#get_contact/3","title":"AWS.AlexaForBusiness.get_contact/3","type":"function"},{"doc":"Gets the details of a device by device ARN.","ref":"AWS.AlexaForBusiness.html#get_device/3","title":"AWS.AlexaForBusiness.get_device/3","type":"function"},{"doc":"Retrieves the details of a gateway.","ref":"AWS.AlexaForBusiness.html#get_gateway/3","title":"AWS.AlexaForBusiness.get_gateway/3","type":"function"},{"doc":"Retrieves the details of a gateway group.","ref":"AWS.AlexaForBusiness.html#get_gateway_group/3","title":"AWS.AlexaForBusiness.get_gateway_group/3","type":"function"},{"doc":"Retrieves the configured values for the user enrollment invitation email\ntemplate.","ref":"AWS.AlexaForBusiness.html#get_invitation_configuration/3","title":"AWS.AlexaForBusiness.get_invitation_configuration/3","type":"function"},{"doc":"Gets the network profile details by the network profile ARN.","ref":"AWS.AlexaForBusiness.html#get_network_profile/3","title":"AWS.AlexaForBusiness.get_network_profile/3","type":"function"},{"doc":"Gets the details of a room profile by profile ARN.","ref":"AWS.AlexaForBusiness.html#get_profile/3","title":"AWS.AlexaForBusiness.get_profile/3","type":"function"},{"doc":"Gets room details by room ARN.","ref":"AWS.AlexaForBusiness.html#get_room/3","title":"AWS.AlexaForBusiness.get_room/3","type":"function"},{"doc":"Gets room skill parameter details by room, skill, and parameter key ARN.","ref":"AWS.AlexaForBusiness.html#get_room_skill_parameter/3","title":"AWS.AlexaForBusiness.get_room_skill_parameter/3","type":"function"},{"doc":"Gets skill group details by skill group ARN.","ref":"AWS.AlexaForBusiness.html#get_skill_group/3","title":"AWS.AlexaForBusiness.get_skill_group/3","type":"function"},{"doc":"Lists the details of the schedules that a user configured.\n\nA download URL of the report associated with each schedule is returned every\ntime this action is called. A new download URL is returned each time, and is\nvalid for 24 hours.","ref":"AWS.AlexaForBusiness.html#list_business_report_schedules/3","title":"AWS.AlexaForBusiness.list_business_report_schedules/3","type":"function"},{"doc":"Lists conference providers under a specific AWS account.","ref":"AWS.AlexaForBusiness.html#list_conference_providers/3","title":"AWS.AlexaForBusiness.list_conference_providers/3","type":"function"},{"doc":"Lists the device event history, including device connection status, for up to 30\ndays.","ref":"AWS.AlexaForBusiness.html#list_device_events/3","title":"AWS.AlexaForBusiness.list_device_events/3","type":"function"},{"doc":"Retrieves a list of gateway group summaries.\n\nUse GetGatewayGroup to retrieve details of a specific gateway group.","ref":"AWS.AlexaForBusiness.html#list_gateway_groups/3","title":"AWS.AlexaForBusiness.list_gateway_groups/3","type":"function"},{"doc":"Retrieves a list of gateway summaries.\n\nUse GetGateway to retrieve details of a specific gateway. An optional gateway\ngroup ARN can be provided to only retrieve gateway summaries of gateways that\nare associated with that gateway group ARN.","ref":"AWS.AlexaForBusiness.html#list_gateways/3","title":"AWS.AlexaForBusiness.list_gateways/3","type":"function"},{"doc":"Lists all enabled skills in a specific skill group.","ref":"AWS.AlexaForBusiness.html#list_skills/3","title":"AWS.AlexaForBusiness.list_skills/3","type":"function"},{"doc":"Lists all categories in the Alexa skill store.","ref":"AWS.AlexaForBusiness.html#list_skills_store_categories/3","title":"AWS.AlexaForBusiness.list_skills_store_categories/3","type":"function"},{"doc":"Lists all skills in the Alexa skill store by category.","ref":"AWS.AlexaForBusiness.html#list_skills_store_skills_by_category/3","title":"AWS.AlexaForBusiness.list_skills_store_skills_by_category/3","type":"function"},{"doc":"Lists all of the smart home appliances associated with a room.","ref":"AWS.AlexaForBusiness.html#list_smart_home_appliances/3","title":"AWS.AlexaForBusiness.list_smart_home_appliances/3","type":"function"},{"doc":"Lists all tags for the specified resource.","ref":"AWS.AlexaForBusiness.html#list_tags/3","title":"AWS.AlexaForBusiness.list_tags/3","type":"function"},{"doc":"","ref":"AWS.AlexaForBusiness.html#metadata/0","title":"AWS.AlexaForBusiness.metadata/0","type":"function"},{"doc":"Sets the conference preferences on a specific conference provider at the account\nlevel.","ref":"AWS.AlexaForBusiness.html#put_conference_preference/3","title":"AWS.AlexaForBusiness.put_conference_preference/3","type":"function"},{"doc":"Configures the email template for the user enrollment invitation with the\nspecified attributes.","ref":"AWS.AlexaForBusiness.html#put_invitation_configuration/3","title":"AWS.AlexaForBusiness.put_invitation_configuration/3","type":"function"},{"doc":"Updates room skill parameter details by room, skill, and parameter key ID.\n\nNot all skills have a room skill parameter.","ref":"AWS.AlexaForBusiness.html#put_room_skill_parameter/3","title":"AWS.AlexaForBusiness.put_room_skill_parameter/3","type":"function"},{"doc":"Links a user's account to a third-party skill provider.\n\nIf this API operation is called by an assumed IAM role, the skill being linked\nmust be a private skill. Also, the skill must be owned by the AWS account that\nassumed the IAM role.","ref":"AWS.AlexaForBusiness.html#put_skill_authorization/3","title":"AWS.AlexaForBusiness.put_skill_authorization/3","type":"function"},{"doc":"Registers an Alexa-enabled device built by an Original Equipment Manufacturer\n(OEM) using Alexa Voice Service (AVS).","ref":"AWS.AlexaForBusiness.html#register_avs_device/3","title":"AWS.AlexaForBusiness.register_avs_device/3","type":"function"},{"doc":"Disassociates a skill from the organization under a user's AWS account.\n\nIf the skill is a private skill, it moves to an AcceptStatus of PENDING. Any\nprivate or public skill that is rejected can be added later by calling the\nApproveSkill API.","ref":"AWS.AlexaForBusiness.html#reject_skill/3","title":"AWS.AlexaForBusiness.reject_skill/3","type":"function"},{"doc":"Determines the details for the room from which a skill request was invoked.\n\nThis operation is used by skill developers.\n\nTo query ResolveRoom from an Alexa skill, the skill ID needs to be authorized.\nWhen the skill is using an AWS Lambda function, the skill is automatically\nauthorized when you publish your skill as a private skill to your AWS account.\nSkills that are hosted using a custom web service must be manually authorized.\nTo get your skill authorized, contact AWS Support with your AWS account ID that\nqueries the ResolveRoom API and skill ID.","ref":"AWS.AlexaForBusiness.html#resolve_room/3","title":"AWS.AlexaForBusiness.resolve_room/3","type":"function"},{"doc":"Revokes an invitation and invalidates the enrollment URL.","ref":"AWS.AlexaForBusiness.html#revoke_invitation/3","title":"AWS.AlexaForBusiness.revoke_invitation/3","type":"function"},{"doc":"Searches address books and lists the ones that meet a set of filter and sort\ncriteria.","ref":"AWS.AlexaForBusiness.html#search_address_books/3","title":"AWS.AlexaForBusiness.search_address_books/3","type":"function"},{"doc":"Searches contacts and lists the ones that meet a set of filter and sort\ncriteria.","ref":"AWS.AlexaForBusiness.html#search_contacts/3","title":"AWS.AlexaForBusiness.search_contacts/3","type":"function"},{"doc":"Searches devices and lists the ones that meet a set of filter criteria.","ref":"AWS.AlexaForBusiness.html#search_devices/3","title":"AWS.AlexaForBusiness.search_devices/3","type":"function"},{"doc":"Searches network profiles and lists the ones that meet a set of filter and sort\ncriteria.","ref":"AWS.AlexaForBusiness.html#search_network_profiles/3","title":"AWS.AlexaForBusiness.search_network_profiles/3","type":"function"},{"doc":"Searches room profiles and lists the ones that meet a set of filter criteria.","ref":"AWS.AlexaForBusiness.html#search_profiles/3","title":"AWS.AlexaForBusiness.search_profiles/3","type":"function"},{"doc":"Searches rooms and lists the ones that meet a set of filter and sort criteria.","ref":"AWS.AlexaForBusiness.html#search_rooms/3","title":"AWS.AlexaForBusiness.search_rooms/3","type":"function"},{"doc":"Searches skill groups and lists the ones that meet a set of filter and sort\ncriteria.","ref":"AWS.AlexaForBusiness.html#search_skill_groups/3","title":"AWS.AlexaForBusiness.search_skill_groups/3","type":"function"},{"doc":"Searches users and lists the ones that meet a set of filter and sort criteria.","ref":"AWS.AlexaForBusiness.html#search_users/3","title":"AWS.AlexaForBusiness.search_users/3","type":"function"},{"doc":"Triggers an asynchronous flow to send text, SSML, or audio announcements to\nrooms that are identified by a search or filter.","ref":"AWS.AlexaForBusiness.html#send_announcement/3","title":"AWS.AlexaForBusiness.send_announcement/3","type":"function"},{"doc":"Sends an enrollment invitation email with a URL to a user.\n\nThe URL is valid for 30 days or until you call this operation again, whichever\ncomes first.","ref":"AWS.AlexaForBusiness.html#send_invitation/3","title":"AWS.AlexaForBusiness.send_invitation/3","type":"function"},{"doc":"Resets a device and its account to the known default settings.\n\nThis clears all information and settings set by previous users in the following\nways:\n\n  * Bluetooth - This unpairs all bluetooth devices paired with your\necho device.\n\n  * Volume - This resets the echo device's volume to the default\nvalue.\n\n  * Notifications - This clears all notifications from your echo\ndevice.\n\n  * Lists - This clears all to-do items from your echo device.\n\n  * Settings - This internally syncs the room's profile (if the device\nis assigned to a room), contacts, address books, delegation access for account\nlinking, and communications (if enabled on the room profile).","ref":"AWS.AlexaForBusiness.html#start_device_sync/3","title":"AWS.AlexaForBusiness.start_device_sync/3","type":"function"},{"doc":"Initiates the discovery of any smart home appliances associated with the room.","ref":"AWS.AlexaForBusiness.html#start_smart_home_appliance_discovery/3","title":"AWS.AlexaForBusiness.start_smart_home_appliance_discovery/3","type":"function"},{"doc":"Adds metadata tags to a specified resource.","ref":"AWS.AlexaForBusiness.html#tag_resource/3","title":"AWS.AlexaForBusiness.tag_resource/3","type":"function"},{"doc":"Removes metadata tags from a specified resource.","ref":"AWS.AlexaForBusiness.html#untag_resource/3","title":"AWS.AlexaForBusiness.untag_resource/3","type":"function"},{"doc":"Updates address book details by the address book ARN.","ref":"AWS.AlexaForBusiness.html#update_address_book/3","title":"AWS.AlexaForBusiness.update_address_book/3","type":"function"},{"doc":"Updates the configuration of the report delivery schedule with the specified\nschedule ARN.","ref":"AWS.AlexaForBusiness.html#update_business_report_schedule/3","title":"AWS.AlexaForBusiness.update_business_report_schedule/3","type":"function"},{"doc":"Updates an existing conference provider's settings.","ref":"AWS.AlexaForBusiness.html#update_conference_provider/3","title":"AWS.AlexaForBusiness.update_conference_provider/3","type":"function"},{"doc":"Updates the contact details by the contact ARN.","ref":"AWS.AlexaForBusiness.html#update_contact/3","title":"AWS.AlexaForBusiness.update_contact/3","type":"function"},{"doc":"Updates the device name by device ARN.","ref":"AWS.AlexaForBusiness.html#update_device/3","title":"AWS.AlexaForBusiness.update_device/3","type":"function"},{"doc":"Updates the details of a gateway.\n\nIf any optional field is not provided, the existing corresponding value is left\nunmodified.","ref":"AWS.AlexaForBusiness.html#update_gateway/3","title":"AWS.AlexaForBusiness.update_gateway/3","type":"function"},{"doc":"Updates the details of a gateway group.\n\nIf any optional field is not provided, the existing corresponding value is left\nunmodified.","ref":"AWS.AlexaForBusiness.html#update_gateway_group/3","title":"AWS.AlexaForBusiness.update_gateway_group/3","type":"function"},{"doc":"Updates a network profile by the network profile ARN.","ref":"AWS.AlexaForBusiness.html#update_network_profile/3","title":"AWS.AlexaForBusiness.update_network_profile/3","type":"function"},{"doc":"Updates an existing room profile by room profile ARN.","ref":"AWS.AlexaForBusiness.html#update_profile/3","title":"AWS.AlexaForBusiness.update_profile/3","type":"function"},{"doc":"Updates room details by room ARN.","ref":"AWS.AlexaForBusiness.html#update_room/3","title":"AWS.AlexaForBusiness.update_room/3","type":"function"},{"doc":"Updates skill group details by skill group ARN.","ref":"AWS.AlexaForBusiness.html#update_skill_group/3","title":"AWS.AlexaForBusiness.update_skill_group/3","type":"function"},{"doc":"Amazon Managed Service for Prometheus is a serverless, Prometheus-compatible\nmonitoring service for container metrics that makes it easier to securely\nmonitor container environments at scale.\n\nWith Amazon Managed Service for Prometheus, you can use the same open-source\nPrometheus data model and query language that you use today to monitor the\nperformance of your containerized workloads, and also enjoy improved\nscalability, availability, and security without having to manage the underlying\ninfrastructure.\n\nFor more information about Amazon Managed Service for Prometheus, see the\n[Amazon Managed Service for Prometheus](https://docs.aws.amazon.com/prometheus/latest/userguide/what-is-Amazon-Managed-Service-Prometheus.html)\nUser Guide.\n\nAmazon Managed Service for Prometheus includes two APIs.\n\n  * Use the Amazon Web Services API described in this guide to manage\nAmazon Managed Service for Prometheus resources, such as workspaces, rule\ngroups, and alert managers.\n\n  * Use the [Prometheus-compatible API](https://docs.aws.amazon.com/prometheus/latest/userguide/AMP-APIReference.html#AMP-APIReference-Prometheus-Compatible-Apis)\nto work within your Prometheus workspace.","ref":"AWS.Amp.html","title":"AWS.Amp","type":"module"},{"doc":"The `CreateAlertManagerDefinition` operation creates the alert manager\ndefinition in a workspace.\n\nIf a workspace already has an alert manager definition, don't use this operation\nto update it. Instead, use `PutAlertManagerDefinition`.","ref":"AWS.Amp.html#create_alert_manager_definition/4","title":"AWS.Amp.create_alert_manager_definition/4","type":"function"},{"doc":"The `CreateLoggingConfiguration` operation creates a logging configuration for\nthe workspace.\n\nUse this operation to set the CloudWatch log group to which the logs will be\npublished to.","ref":"AWS.Amp.html#create_logging_configuration/4","title":"AWS.Amp.create_logging_configuration/4","type":"function"},{"doc":"The `CreateRuleGroupsNamespace` operation creates a rule groups namespace within\na workspace.\n\nA rule groups namespace is associated with exactly one rules file. A workspace\ncan have multiple rule groups namespaces.\n\nUse this operation only to create new rule groups namespaces. To update an\nexisting rule groups namespace, use `PutRuleGroupsNamespace`.","ref":"AWS.Amp.html#create_rule_groups_namespace/4","title":"AWS.Amp.create_rule_groups_namespace/4","type":"function"},{"doc":"The `CreateScraper` operation creates a scraper to collect metrics.\n\nA scraper pulls metrics from Prometheus-compatible sources within an Amazon EKS\ncluster, and sends them to your Amazon Managed Service for Prometheus workspace.\nYou can configure the scraper to control what metrics are collected, and what\ntransformations are applied prior to sending them to your workspace.\n\nIf needed, an IAM role will be created for you that gives Amazon Managed Service\nfor Prometheus access to the metrics in your cluster. For more information, see\n[Using roles for scraping metrics from EKS](https://docs.aws.amazon.com/prometheus/latest/userguide/using-service-linked-roles.html#using-service-linked-roles-prom-scraper)\nin the *Amazon Managed Service for Prometheus User Guide*.\n\nYou cannot update a scraper. If you want to change the configuration of the\nscraper, create a new scraper and delete the old one.\n\nThe `scrapeConfiguration` parameter contains the base64-encoded version of the\nYAML configuration file.\n\nFor more information about collectors, including what metrics are collected, and\nhow to configure the scraper, see [Amazon Web Services managed collectors](https://docs.aws.amazon.com/prometheus/latest/userguide/AMP-collector.html)\nin the *Amazon Managed Service for Prometheus User Guide*.","ref":"AWS.Amp.html#create_scraper/3","title":"AWS.Amp.create_scraper/3","type":"function"},{"doc":"Creates a Prometheus workspace.\n\nA workspace is a logical space dedicated to the storage and querying of\nPrometheus metrics. You can have one or more workspaces in each Region in your\naccount.","ref":"AWS.Amp.html#create_workspace/3","title":"AWS.Amp.create_workspace/3","type":"function"},{"doc":"Deletes the alert manager definition from a workspace.","ref":"AWS.Amp.html#delete_alert_manager_definition/4","title":"AWS.Amp.delete_alert_manager_definition/4","type":"function"},{"doc":"Deletes the logging configuration for a workspace.","ref":"AWS.Amp.html#delete_logging_configuration/4","title":"AWS.Amp.delete_logging_configuration/4","type":"function"},{"doc":"Deletes one rule groups namespace and its associated rule groups definition.","ref":"AWS.Amp.html#delete_rule_groups_namespace/5","title":"AWS.Amp.delete_rule_groups_namespace/5","type":"function"},{"doc":"The `DeleteScraper` operation deletes one scraper, and stops any metrics\ncollection that the scraper performs.","ref":"AWS.Amp.html#delete_scraper/4","title":"AWS.Amp.delete_scraper/4","type":"function"},{"doc":"Deletes an existing workspace.\n\nWhen you delete a workspace, the data that has been ingested into it is not\nimmediately deleted. It will be permanently deleted within one month.","ref":"AWS.Amp.html#delete_workspace/4","title":"AWS.Amp.delete_workspace/4","type":"function"},{"doc":"Retrieves the full information about the alert manager definition for a\nworkspace.","ref":"AWS.Amp.html#describe_alert_manager_definition/3","title":"AWS.Amp.describe_alert_manager_definition/3","type":"function"},{"doc":"Returns complete information about the current logging configuration of the\nworkspace.","ref":"AWS.Amp.html#describe_logging_configuration/3","title":"AWS.Amp.describe_logging_configuration/3","type":"function"},{"doc":"Returns complete information about one rule groups namespace.\n\nTo retrieve a list of rule groups namespaces, use `ListRuleGroupsNamespaces`.","ref":"AWS.Amp.html#describe_rule_groups_namespace/4","title":"AWS.Amp.describe_rule_groups_namespace/4","type":"function"},{"doc":"The `DescribeScraper` operation displays information about an existing scraper.","ref":"AWS.Amp.html#describe_scraper/3","title":"AWS.Amp.describe_scraper/3","type":"function"},{"doc":"Returns information about an existing workspace.","ref":"AWS.Amp.html#describe_workspace/3","title":"AWS.Amp.describe_workspace/3","type":"function"},{"doc":"The `GetDefaultScraperConfiguration` operation returns the default scraper\nconfiguration used when Amazon EKS creates a scraper for you.","ref":"AWS.Amp.html#get_default_scraper_configuration/2","title":"AWS.Amp.get_default_scraper_configuration/2","type":"function"},{"doc":"Returns a list of rule groups namespaces in a workspace.","ref":"AWS.Amp.html#list_rule_groups_namespaces/6","title":"AWS.Amp.list_rule_groups_namespaces/6","type":"function"},{"doc":"The `ListScrapers` operation lists all of the scrapers in your account.\n\nThis includes scrapers being created or deleted. You can optionally filter the\nreturned list.","ref":"AWS.Amp.html#list_scrapers/5","title":"AWS.Amp.list_scrapers/5","type":"function"},{"doc":"The `ListTagsForResource` operation returns the tags that are associated with an\nAmazon Managed Service for Prometheus resource.\n\nCurrently, the only resources that can be tagged are workspaces and rule groups\nnamespaces.","ref":"AWS.Amp.html#list_tags_for_resource/3","title":"AWS.Amp.list_tags_for_resource/3","type":"function"},{"doc":"Lists all of the Amazon Managed Service for Prometheus workspaces in your\naccount.\n\nThis includes workspaces being created or deleted.","ref":"AWS.Amp.html#list_workspaces/5","title":"AWS.Amp.list_workspaces/5","type":"function"},{"doc":"","ref":"AWS.Amp.html#metadata/0","title":"AWS.Amp.metadata/0","type":"function"},{"doc":"Updates an existing alert manager definition in a workspace.\n\nIf the workspace does not already have an alert manager definition, don't use\nthis operation to create it. Instead, use `CreateAlertManagerDefinition`.","ref":"AWS.Amp.html#put_alert_manager_definition/4","title":"AWS.Amp.put_alert_manager_definition/4","type":"function"},{"doc":"Updates an existing rule groups namespace within a workspace.\n\nA rule groups namespace is associated with exactly one rules file. A workspace\ncan have multiple rule groups namespaces.\n\nUse this operation only to update existing rule groups namespaces. To create a\nnew rule groups namespace, use `CreateRuleGroupsNamespace`.\n\nYou can't use this operation to add tags to an existing rule groups namespace.\nInstead, use `TagResource`.","ref":"AWS.Amp.html#put_rule_groups_namespace/5","title":"AWS.Amp.put_rule_groups_namespace/5","type":"function"},{"doc":"The `TagResource` operation associates tags with an Amazon Managed Service for\nPrometheus resource.\n\nThe only resources that can be tagged are workspaces and rule groups namespaces.\n\nIf you specify a new tag key for the resource, this tag is appended to the list\nof tags associated with the resource. If you specify a tag key that is already\nassociated with the resource, the new tag value that you specify replaces the\nprevious value for that tag.","ref":"AWS.Amp.html#tag_resource/4","title":"AWS.Amp.tag_resource/4","type":"function"},{"doc":"Removes the specified tags from an Amazon Managed Service for Prometheus\nresource.\n\nThe only resources that can be tagged are workspaces and rule groups namespaces.","ref":"AWS.Amp.html#untag_resource/4","title":"AWS.Amp.untag_resource/4","type":"function"},{"doc":"Updates the log group ARN or the workspace ID of the current logging\nconfiguration.","ref":"AWS.Amp.html#update_logging_configuration/4","title":"AWS.Amp.update_logging_configuration/4","type":"function"},{"doc":"Updates the alias of an existing workspace.","ref":"AWS.Amp.html#update_workspace_alias/4","title":"AWS.Amp.update_workspace_alias/4","type":"function"},{"doc":"Amplify enables developers to develop and deploy cloud-powered mobile and web\napps.\n\nAmplify Hosting provides a continuous delivery and hosting service for web\napplications. For more information, see the [Amplify Hosting User Guide](https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html). The\nAmplify Framework is a comprehensive set of SDKs, libraries, tools, and\ndocumentation for client app development. For more information, see the [Amplify Framework.](https://docs.amplify.aws/)","ref":"AWS.Amplify.html","title":"AWS.Amplify","type":"module"},{"doc":"Creates a new Amplify app.","ref":"AWS.Amplify.html#create_app/3","title":"AWS.Amplify.create_app/3","type":"function"},{"doc":"Creates a new backend environment for an Amplify app.","ref":"AWS.Amplify.html#create_backend_environment/4","title":"AWS.Amplify.create_backend_environment/4","type":"function"},{"doc":"Creates a new branch for an Amplify app.","ref":"AWS.Amplify.html#create_branch/4","title":"AWS.Amplify.create_branch/4","type":"function"},{"doc":"Creates a deployment for a manually deployed Amplify app.\n\nManually deployed apps are not connected to a repository.\n\nThe maximum duration between the `CreateDeployment` call and the\n`StartDeployment` call cannot exceed 8 hours. If the duration exceeds 8 hours,\nthe `StartDeployment` call and the associated `Job` will fail.","ref":"AWS.Amplify.html#create_deployment/5","title":"AWS.Amplify.create_deployment/5","type":"function"},{"doc":"Creates a new domain association for an Amplify app.\n\nThis action associates a custom domain with the Amplify app","ref":"AWS.Amplify.html#create_domain_association/4","title":"AWS.Amplify.create_domain_association/4","type":"function"},{"doc":"Creates a new webhook on an Amplify app.","ref":"AWS.Amplify.html#create_webhook/4","title":"AWS.Amplify.create_webhook/4","type":"function"},{"doc":"Deletes an existing Amplify app specified by an app ID.","ref":"AWS.Amplify.html#delete_app/4","title":"AWS.Amplify.delete_app/4","type":"function"},{"doc":"Deletes a backend environment for an Amplify app.","ref":"AWS.Amplify.html#delete_backend_environment/5","title":"AWS.Amplify.delete_backend_environment/5","type":"function"},{"doc":"Deletes a branch for an Amplify app.","ref":"AWS.Amplify.html#delete_branch/5","title":"AWS.Amplify.delete_branch/5","type":"function"},{"doc":"Deletes a domain association for an Amplify app.","ref":"AWS.Amplify.html#delete_domain_association/5","title":"AWS.Amplify.delete_domain_association/5","type":"function"},{"doc":"Deletes a job for a branch of an Amplify app.","ref":"AWS.Amplify.html#delete_job/6","title":"AWS.Amplify.delete_job/6","type":"function"},{"doc":"Deletes a webhook.","ref":"AWS.Amplify.html#delete_webhook/4","title":"AWS.Amplify.delete_webhook/4","type":"function"},{"doc":"Returns the website access logs for a specific time range using a presigned URL.","ref":"AWS.Amplify.html#generate_access_logs/4","title":"AWS.Amplify.generate_access_logs/4","type":"function"},{"doc":"Returns an existing Amplify app specified by an app ID.","ref":"AWS.Amplify.html#get_app/3","title":"AWS.Amplify.get_app/3","type":"function"},{"doc":"Returns the artifact info that corresponds to an artifact id.","ref":"AWS.Amplify.html#get_artifact_url/3","title":"AWS.Amplify.get_artifact_url/3","type":"function"},{"doc":"Returns a backend environment for an Amplify app.","ref":"AWS.Amplify.html#get_backend_environment/4","title":"AWS.Amplify.get_backend_environment/4","type":"function"},{"doc":"Returns a branch for an Amplify app.","ref":"AWS.Amplify.html#get_branch/4","title":"AWS.Amplify.get_branch/4","type":"function"},{"doc":"Returns the domain information for an Amplify app.","ref":"AWS.Amplify.html#get_domain_association/4","title":"AWS.Amplify.get_domain_association/4","type":"function"},{"doc":"Returns a job for a branch of an Amplify app.","ref":"AWS.Amplify.html#get_job/5","title":"AWS.Amplify.get_job/5","type":"function"},{"doc":"Returns the webhook information that corresponds to a specified webhook ID.","ref":"AWS.Amplify.html#get_webhook/3","title":"AWS.Amplify.get_webhook/3","type":"function"},{"doc":"Returns a list of the existing Amplify apps.","ref":"AWS.Amplify.html#list_apps/4","title":"AWS.Amplify.list_apps/4","type":"function"},{"doc":"Returns a list of artifacts for a specified app, branch, and job.","ref":"AWS.Amplify.html#list_artifacts/7","title":"AWS.Amplify.list_artifacts/7","type":"function"},{"doc":"Lists the backend environments for an Amplify app.","ref":"AWS.Amplify.html#list_backend_environments/6","title":"AWS.Amplify.list_backend_environments/6","type":"function"},{"doc":"Lists the branches of an Amplify app.","ref":"AWS.Amplify.html#list_branches/5","title":"AWS.Amplify.list_branches/5","type":"function"},{"doc":"Returns the domain associations for an Amplify app.","ref":"AWS.Amplify.html#list_domain_associations/5","title":"AWS.Amplify.list_domain_associations/5","type":"function"},{"doc":"Lists the jobs for a branch of an Amplify app.","ref":"AWS.Amplify.html#list_jobs/6","title":"AWS.Amplify.list_jobs/6","type":"function"},{"doc":"Returns a list of tags for a specified Amazon Resource Name (ARN).","ref":"AWS.Amplify.html#list_tags_for_resource/3","title":"AWS.Amplify.list_tags_for_resource/3","type":"function"},{"doc":"Returns a list of webhooks for an Amplify app.","ref":"AWS.Amplify.html#list_webhooks/5","title":"AWS.Amplify.list_webhooks/5","type":"function"},{"doc":"","ref":"AWS.Amplify.html#metadata/0","title":"AWS.Amplify.metadata/0","type":"function"},{"doc":"Starts a deployment for a manually deployed app.\n\nManually deployed apps are not connected to a repository.\n\nThe maximum duration between the `CreateDeployment` call and the\n`StartDeployment` call cannot exceed 8 hours. If the duration exceeds 8 hours,\nthe `StartDeployment` call and the associated `Job` will fail.","ref":"AWS.Amplify.html#start_deployment/5","title":"AWS.Amplify.start_deployment/5","type":"function"},{"doc":"Starts a new job for a branch of an Amplify app.","ref":"AWS.Amplify.html#start_job/5","title":"AWS.Amplify.start_job/5","type":"function"},{"doc":"Stops a job that is in progress for a branch of an Amplify app.","ref":"AWS.Amplify.html#stop_job/6","title":"AWS.Amplify.stop_job/6","type":"function"},{"doc":"Tags the resource with a tag key and value.","ref":"AWS.Amplify.html#tag_resource/4","title":"AWS.Amplify.tag_resource/4","type":"function"},{"doc":"Untags a resource with a specified Amazon Resource Name (ARN).","ref":"AWS.Amplify.html#untag_resource/4","title":"AWS.Amplify.untag_resource/4","type":"function"},{"doc":"Updates an existing Amplify app.","ref":"AWS.Amplify.html#update_app/4","title":"AWS.Amplify.update_app/4","type":"function"},{"doc":"Updates a branch for an Amplify app.","ref":"AWS.Amplify.html#update_branch/5","title":"AWS.Amplify.update_branch/5","type":"function"},{"doc":"Creates a new domain association for an Amplify app.","ref":"AWS.Amplify.html#update_domain_association/5","title":"AWS.Amplify.update_domain_association/5","type":"function"},{"doc":"Updates a webhook.","ref":"AWS.Amplify.html#update_webhook/4","title":"AWS.Amplify.update_webhook/4","type":"function"},{"doc":"AWS Amplify Admin API","ref":"AWS.AmplifyBackend.html","title":"AWS.AmplifyBackend","type":"module"},{"doc":"This operation clones an existing backend.","ref":"AWS.AmplifyBackend.html#clone_backend/5","title":"AWS.AmplifyBackend.clone_backend/5","type":"function"},{"doc":"This operation creates a backend for an Amplify app.\n\nBackends are automatically created at the time of app creation.","ref":"AWS.AmplifyBackend.html#create_backend/3","title":"AWS.AmplifyBackend.create_backend/3","type":"function"},{"doc":"Creates a new backend API resource.","ref":"AWS.AmplifyBackend.html#create_backend_api/4","title":"AWS.AmplifyBackend.create_backend_api/4","type":"function"},{"doc":"Creates a new backend authentication resource.","ref":"AWS.AmplifyBackend.html#create_backend_auth/4","title":"AWS.AmplifyBackend.create_backend_auth/4","type":"function"},{"doc":"Creates a config object for a backend.","ref":"AWS.AmplifyBackend.html#create_backend_config/4","title":"AWS.AmplifyBackend.create_backend_config/4","type":"function"},{"doc":"Creates a backend storage resource.","ref":"AWS.AmplifyBackend.html#create_backend_storage/4","title":"AWS.AmplifyBackend.create_backend_storage/4","type":"function"},{"doc":"Generates a one-time challenge code to authenticate a user into your Amplify\nAdmin UI.","ref":"AWS.AmplifyBackend.html#create_token/4","title":"AWS.AmplifyBackend.create_token/4","type":"function"},{"doc":"Removes an existing environment from your Amplify project.","ref":"AWS.AmplifyBackend.html#delete_backend/5","title":"AWS.AmplifyBackend.delete_backend/5","type":"function"},{"doc":"Deletes an existing backend API resource.","ref":"AWS.AmplifyBackend.html#delete_backend_api/5","title":"AWS.AmplifyBackend.delete_backend_api/5","type":"function"},{"doc":"Deletes an existing backend authentication resource.","ref":"AWS.AmplifyBackend.html#delete_backend_auth/5","title":"AWS.AmplifyBackend.delete_backend_auth/5","type":"function"},{"doc":"Removes the specified backend storage resource.","ref":"AWS.AmplifyBackend.html#delete_backend_storage/5","title":"AWS.AmplifyBackend.delete_backend_storage/5","type":"function"},{"doc":"Deletes the challenge token based on the given appId and sessionId.","ref":"AWS.AmplifyBackend.html#delete_token/5","title":"AWS.AmplifyBackend.delete_token/5","type":"function"},{"doc":"Generates a model schema for an existing backend API resource.","ref":"AWS.AmplifyBackend.html#generate_backend_api_models/5","title":"AWS.AmplifyBackend.generate_backend_api_models/5","type":"function"},{"doc":"Provides project-level details for your Amplify UI project.","ref":"AWS.AmplifyBackend.html#get_backend/4","title":"AWS.AmplifyBackend.get_backend/4","type":"function"},{"doc":"Gets the details for a backend API.","ref":"AWS.AmplifyBackend.html#get_backend_api/5","title":"AWS.AmplifyBackend.get_backend_api/5","type":"function"},{"doc":"Gets a model introspection schema for an existing backend API resource.","ref":"AWS.AmplifyBackend.html#get_backend_api_models/5","title":"AWS.AmplifyBackend.get_backend_api_models/5","type":"function"},{"doc":"Gets a backend auth details.","ref":"AWS.AmplifyBackend.html#get_backend_auth/5","title":"AWS.AmplifyBackend.get_backend_auth/5","type":"function"},{"doc":"Returns information about a specific job.","ref":"AWS.AmplifyBackend.html#get_backend_job/5","title":"AWS.AmplifyBackend.get_backend_job/5","type":"function"},{"doc":"Gets details for a backend storage resource.","ref":"AWS.AmplifyBackend.html#get_backend_storage/5","title":"AWS.AmplifyBackend.get_backend_storage/5","type":"function"},{"doc":"Gets the challenge token based on the given appId and sessionId.","ref":"AWS.AmplifyBackend.html#get_token/4","title":"AWS.AmplifyBackend.get_token/4","type":"function"},{"doc":"Imports an existing backend authentication resource.","ref":"AWS.AmplifyBackend.html#import_backend_auth/5","title":"AWS.AmplifyBackend.import_backend_auth/5","type":"function"},{"doc":"Imports an existing backend storage resource.","ref":"AWS.AmplifyBackend.html#import_backend_storage/5","title":"AWS.AmplifyBackend.import_backend_storage/5","type":"function"},{"doc":"Lists the jobs for the backend of an Amplify app.","ref":"AWS.AmplifyBackend.html#list_backend_jobs/5","title":"AWS.AmplifyBackend.list_backend_jobs/5","type":"function"},{"doc":"The list of S3 buckets in your account.","ref":"AWS.AmplifyBackend.html#list_s3_buckets/3","title":"AWS.AmplifyBackend.list_s3_buckets/3","type":"function"},{"doc":"","ref":"AWS.AmplifyBackend.html#metadata/0","title":"AWS.AmplifyBackend.metadata/0","type":"function"},{"doc":"Removes all backend environments from your Amplify project.","ref":"AWS.AmplifyBackend.html#remove_all_backends/4","title":"AWS.AmplifyBackend.remove_all_backends/4","type":"function"},{"doc":"Removes the AWS resources required to access the Amplify Admin UI.","ref":"AWS.AmplifyBackend.html#remove_backend_config/4","title":"AWS.AmplifyBackend.remove_backend_config/4","type":"function"},{"doc":"Updates an existing backend API resource.","ref":"AWS.AmplifyBackend.html#update_backend_api/5","title":"AWS.AmplifyBackend.update_backend_api/5","type":"function"},{"doc":"Updates an existing backend authentication resource.","ref":"AWS.AmplifyBackend.html#update_backend_auth/5","title":"AWS.AmplifyBackend.update_backend_auth/5","type":"function"},{"doc":"Updates the AWS resources required to access the Amplify Admin UI.","ref":"AWS.AmplifyBackend.html#update_backend_config/4","title":"AWS.AmplifyBackend.update_backend_config/4","type":"function"},{"doc":"Updates a specific job.","ref":"AWS.AmplifyBackend.html#update_backend_job/6","title":"AWS.AmplifyBackend.update_backend_job/6","type":"function"},{"doc":"Updates an existing backend storage resource.","ref":"AWS.AmplifyBackend.html#update_backend_storage/5","title":"AWS.AmplifyBackend.update_backend_storage/5","type":"function"},{"doc":"The Amplify UI Builder API provides a programmatic interface for creating and\nconfiguring user interface (UI) component libraries and themes for use in your\nAmplify applications.\n\nYou can then connect these UI components to an application's backend Amazon Web\nServices resources.\n\nYou can also use the Amplify Studio visual designer to create UI components and\nmodel data for an app. For more information, see\n[Introduction](https://docs.amplify.aws/console/adminui/intro) in the *Amplify Docs*.\n\nThe Amplify Framework is a comprehensive set of SDKs, libraries, tools, and\ndocumentation for client app development. For more information, see the [Amplify\nFramework](https://docs.amplify.aws/). For more information about deploying an\nAmplify application to Amazon Web Services, see the [Amplify User Guide](https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html).","ref":"AWS.AmplifyUIBuilder.html","title":"AWS.AmplifyUIBuilder","type":"module"},{"doc":"Creates a new component for an Amplify app.","ref":"AWS.AmplifyUIBuilder.html#create_component/5","title":"AWS.AmplifyUIBuilder.create_component/5","type":"function"},{"doc":"Creates a new form for an Amplify app.","ref":"AWS.AmplifyUIBuilder.html#create_form/5","title":"AWS.AmplifyUIBuilder.create_form/5","type":"function"},{"doc":"Creates a theme to apply to the components in an Amplify app.","ref":"AWS.AmplifyUIBuilder.html#create_theme/5","title":"AWS.AmplifyUIBuilder.create_theme/5","type":"function"},{"doc":"Deletes a component from an Amplify app.","ref":"AWS.AmplifyUIBuilder.html#delete_component/6","title":"AWS.AmplifyUIBuilder.delete_component/6","type":"function"},{"doc":"Deletes a form from an Amplify app.","ref":"AWS.AmplifyUIBuilder.html#delete_form/6","title":"AWS.AmplifyUIBuilder.delete_form/6","type":"function"},{"doc":"Deletes a theme from an Amplify app.","ref":"AWS.AmplifyUIBuilder.html#delete_theme/6","title":"AWS.AmplifyUIBuilder.delete_theme/6","type":"function"},{"doc":"This is for internal use.\n\nAmplify uses this action to exchange an access code for a token.","ref":"AWS.AmplifyUIBuilder.html#exchange_code_for_token/4","title":"AWS.AmplifyUIBuilder.exchange_code_for_token/4","type":"function"},{"doc":"Exports component configurations to code that is ready to integrate into an\nAmplify app.","ref":"AWS.AmplifyUIBuilder.html#export_components/5","title":"AWS.AmplifyUIBuilder.export_components/5","type":"function"},{"doc":"Exports form configurations to code that is ready to integrate into an Amplify\napp.","ref":"AWS.AmplifyUIBuilder.html#export_forms/5","title":"AWS.AmplifyUIBuilder.export_forms/5","type":"function"},{"doc":"Exports theme configurations to code that is ready to integrate into an Amplify\napp.","ref":"AWS.AmplifyUIBuilder.html#export_themes/5","title":"AWS.AmplifyUIBuilder.export_themes/5","type":"function"},{"doc":"Returns an existing code generation job.","ref":"AWS.AmplifyUIBuilder.html#get_codegen_job/5","title":"AWS.AmplifyUIBuilder.get_codegen_job/5","type":"function"},{"doc":"Returns an existing component for an Amplify app.","ref":"AWS.AmplifyUIBuilder.html#get_component/5","title":"AWS.AmplifyUIBuilder.get_component/5","type":"function"},{"doc":"Returns an existing form for an Amplify app.","ref":"AWS.AmplifyUIBuilder.html#get_form/5","title":"AWS.AmplifyUIBuilder.get_form/5","type":"function"},{"doc":"Returns existing metadata for an Amplify app.","ref":"AWS.AmplifyUIBuilder.html#get_metadata/4","title":"AWS.AmplifyUIBuilder.get_metadata/4","type":"function"},{"doc":"Returns an existing theme for an Amplify app.","ref":"AWS.AmplifyUIBuilder.html#get_theme/5","title":"AWS.AmplifyUIBuilder.get_theme/5","type":"function"},{"doc":"Retrieves a list of code generation jobs for a specified Amplify app and backend\nenvironment.","ref":"AWS.AmplifyUIBuilder.html#list_codegen_jobs/6","title":"AWS.AmplifyUIBuilder.list_codegen_jobs/6","type":"function"},{"doc":"Retrieves a list of components for a specified Amplify app and backend\nenvironment.","ref":"AWS.AmplifyUIBuilder.html#list_components/6","title":"AWS.AmplifyUIBuilder.list_components/6","type":"function"},{"doc":"Retrieves a list of forms for a specified Amplify app and backend environment.","ref":"AWS.AmplifyUIBuilder.html#list_forms/6","title":"AWS.AmplifyUIBuilder.list_forms/6","type":"function"},{"doc":"Retrieves a list of themes for a specified Amplify app and backend environment.","ref":"AWS.AmplifyUIBuilder.html#list_themes/6","title":"AWS.AmplifyUIBuilder.list_themes/6","type":"function"},{"doc":"","ref":"AWS.AmplifyUIBuilder.html#metadata/0","title":"AWS.AmplifyUIBuilder.metadata/0","type":"function"},{"doc":"Stores the metadata information about a feature on a form.","ref":"AWS.AmplifyUIBuilder.html#put_metadata_flag/6","title":"AWS.AmplifyUIBuilder.put_metadata_flag/6","type":"function"},{"doc":"This is for internal use.\n\nAmplify uses this action to refresh a previously issued access token that might\nhave expired.","ref":"AWS.AmplifyUIBuilder.html#refresh_token/4","title":"AWS.AmplifyUIBuilder.refresh_token/4","type":"function"},{"doc":"Starts a code generation job for a specified Amplify app and backend\nenvironment.","ref":"AWS.AmplifyUIBuilder.html#start_codegen_job/5","title":"AWS.AmplifyUIBuilder.start_codegen_job/5","type":"function"},{"doc":"Updates an existing component.","ref":"AWS.AmplifyUIBuilder.html#update_component/6","title":"AWS.AmplifyUIBuilder.update_component/6","type":"function"},{"doc":"Updates an existing form.","ref":"AWS.AmplifyUIBuilder.html#update_form/6","title":"AWS.AmplifyUIBuilder.update_form/6","type":"function"},{"doc":"Updates an existing theme.","ref":"AWS.AmplifyUIBuilder.html#update_theme/6","title":"AWS.AmplifyUIBuilder.update_theme/6","type":"function"},{"doc":"The Amazon API Gateway Management API allows you to directly manage runtime\naspects of your deployed APIs.\n\nTo use it, you must explicitly set the SDK's endpoint to point to the endpoint\nof your deployed API. The endpoint will be of the form\nhttps://{api-id}.execute-api.{region}.amazonaws.com/{stage}, or will be the\nendpoint corresponding to your API's custom domain and base path, if applicable.","ref":"AWS.ApiGatewayManagementApi.html","title":"AWS.ApiGatewayManagementApi","type":"module"},{"doc":"Delete the connection with the provided id.","ref":"AWS.ApiGatewayManagementApi.html#delete_connection/4","title":"AWS.ApiGatewayManagementApi.delete_connection/4","type":"function"},{"doc":"Get information about the connection with the provided id.","ref":"AWS.ApiGatewayManagementApi.html#get_connection/3","title":"AWS.ApiGatewayManagementApi.get_connection/3","type":"function"},{"doc":"","ref":"AWS.ApiGatewayManagementApi.html#metadata/0","title":"AWS.ApiGatewayManagementApi.metadata/0","type":"function"},{"doc":"Sends the provided data to the specified connection.","ref":"AWS.ApiGatewayManagementApi.html#post_to_connection/4","title":"AWS.ApiGatewayManagementApi.post_to_connection/4","type":"function"},{"doc":"Amazon API Gateway V2","ref":"AWS.ApiGatewayV2.html","title":"AWS.ApiGatewayV2","type":"module"},{"doc":"Creates an Api resource.","ref":"AWS.ApiGatewayV2.html#create_api/3","title":"AWS.ApiGatewayV2.create_api/3","type":"function"},{"doc":"Creates an API mapping.","ref":"AWS.ApiGatewayV2.html#create_api_mapping/4","title":"AWS.ApiGatewayV2.create_api_mapping/4","type":"function"},{"doc":"Creates an Authorizer for an API.","ref":"AWS.ApiGatewayV2.html#create_authorizer/4","title":"AWS.ApiGatewayV2.create_authorizer/4","type":"function"},{"doc":"Creates a Deployment for an API.","ref":"AWS.ApiGatewayV2.html#create_deployment/4","title":"AWS.ApiGatewayV2.create_deployment/4","type":"function"},{"doc":"Creates a domain name.","ref":"AWS.ApiGatewayV2.html#create_domain_name/3","title":"AWS.ApiGatewayV2.create_domain_name/3","type":"function"},{"doc":"Creates an Integration.","ref":"AWS.ApiGatewayV2.html#create_integration/4","title":"AWS.ApiGatewayV2.create_integration/4","type":"function"},{"doc":"Creates an IntegrationResponses.","ref":"AWS.ApiGatewayV2.html#create_integration_response/5","title":"AWS.ApiGatewayV2.create_integration_response/5","type":"function"},{"doc":"Creates a Model for an API.","ref":"AWS.ApiGatewayV2.html#create_model/4","title":"AWS.ApiGatewayV2.create_model/4","type":"function"},{"doc":"Creates a Route for an API.","ref":"AWS.ApiGatewayV2.html#create_route/4","title":"AWS.ApiGatewayV2.create_route/4","type":"function"},{"doc":"Creates a RouteResponse for a Route.","ref":"AWS.ApiGatewayV2.html#create_route_response/5","title":"AWS.ApiGatewayV2.create_route_response/5","type":"function"},{"doc":"Creates a Stage for an API.","ref":"AWS.ApiGatewayV2.html#create_stage/4","title":"AWS.ApiGatewayV2.create_stage/4","type":"function"},{"doc":"Creates a VPC link.","ref":"AWS.ApiGatewayV2.html#create_vpc_link/3","title":"AWS.ApiGatewayV2.create_vpc_link/3","type":"function"},{"doc":"Deletes the AccessLogSettings for a Stage.\n\nTo disable access logging for a Stage, delete its AccessLogSettings.","ref":"AWS.ApiGatewayV2.html#delete_access_log_settings/5","title":"AWS.ApiGatewayV2.delete_access_log_settings/5","type":"function"},{"doc":"Deletes an Api resource.","ref":"AWS.ApiGatewayV2.html#delete_api/4","title":"AWS.ApiGatewayV2.delete_api/4","type":"function"},{"doc":"Deletes an API mapping.","ref":"AWS.ApiGatewayV2.html#delete_api_mapping/5","title":"AWS.ApiGatewayV2.delete_api_mapping/5","type":"function"},{"doc":"Deletes an Authorizer.","ref":"AWS.ApiGatewayV2.html#delete_authorizer/5","title":"AWS.ApiGatewayV2.delete_authorizer/5","type":"function"},{"doc":"Deletes a CORS configuration.","ref":"AWS.ApiGatewayV2.html#delete_cors_configuration/4","title":"AWS.ApiGatewayV2.delete_cors_configuration/4","type":"function"},{"doc":"Deletes a Deployment.","ref":"AWS.ApiGatewayV2.html#delete_deployment/5","title":"AWS.ApiGatewayV2.delete_deployment/5","type":"function"},{"doc":"Deletes a domain name.","ref":"AWS.ApiGatewayV2.html#delete_domain_name/4","title":"AWS.ApiGatewayV2.delete_domain_name/4","type":"function"},{"doc":"Deletes an Integration.","ref":"AWS.ApiGatewayV2.html#delete_integration/5","title":"AWS.ApiGatewayV2.delete_integration/5","type":"function"},{"doc":"Deletes an IntegrationResponses.","ref":"AWS.ApiGatewayV2.html#delete_integration_response/6","title":"AWS.ApiGatewayV2.delete_integration_response/6","type":"function"},{"doc":"Deletes a Model.","ref":"AWS.ApiGatewayV2.html#delete_model/5","title":"AWS.ApiGatewayV2.delete_model/5","type":"function"},{"doc":"Deletes a Route.","ref":"AWS.ApiGatewayV2.html#delete_route/5","title":"AWS.ApiGatewayV2.delete_route/5","type":"function"},{"doc":"Deletes a route request parameter.","ref":"AWS.ApiGatewayV2.html#delete_route_request_parameter/6","title":"AWS.ApiGatewayV2.delete_route_request_parameter/6","type":"function"},{"doc":"Deletes a RouteResponse.","ref":"AWS.ApiGatewayV2.html#delete_route_response/6","title":"AWS.ApiGatewayV2.delete_route_response/6","type":"function"},{"doc":"Deletes the RouteSettings for a stage.","ref":"AWS.ApiGatewayV2.html#delete_route_settings/6","title":"AWS.ApiGatewayV2.delete_route_settings/6","type":"function"},{"doc":"Deletes a Stage.","ref":"AWS.ApiGatewayV2.html#delete_stage/5","title":"AWS.ApiGatewayV2.delete_stage/5","type":"function"},{"doc":"Deletes a VPC link.","ref":"AWS.ApiGatewayV2.html#delete_vpc_link/4","title":"AWS.ApiGatewayV2.delete_vpc_link/4","type":"function"},{"doc":"Exports a definition of an API in a particular output format and specification.","ref":"AWS.ApiGatewayV2.html#export_api/8","title":"AWS.ApiGatewayV2.export_api/8","type":"function"},{"doc":"Gets an Api resource.","ref":"AWS.ApiGatewayV2.html#get_api/3","title":"AWS.ApiGatewayV2.get_api/3","type":"function"},{"doc":"Gets an API mapping.","ref":"AWS.ApiGatewayV2.html#get_api_mapping/4","title":"AWS.ApiGatewayV2.get_api_mapping/4","type":"function"},{"doc":"Gets API mappings.","ref":"AWS.ApiGatewayV2.html#get_api_mappings/5","title":"AWS.ApiGatewayV2.get_api_mappings/5","type":"function"},{"doc":"Gets a collection of Api resources.","ref":"AWS.ApiGatewayV2.html#get_apis/4","title":"AWS.ApiGatewayV2.get_apis/4","type":"function"},{"doc":"Gets an Authorizer.","ref":"AWS.ApiGatewayV2.html#get_authorizer/4","title":"AWS.ApiGatewayV2.get_authorizer/4","type":"function"},{"doc":"Gets the Authorizers for an API.","ref":"AWS.ApiGatewayV2.html#get_authorizers/5","title":"AWS.ApiGatewayV2.get_authorizers/5","type":"function"},{"doc":"Gets a Deployment.","ref":"AWS.ApiGatewayV2.html#get_deployment/4","title":"AWS.ApiGatewayV2.get_deployment/4","type":"function"},{"doc":"Gets the Deployments for an API.","ref":"AWS.ApiGatewayV2.html#get_deployments/5","title":"AWS.ApiGatewayV2.get_deployments/5","type":"function"},{"doc":"Gets a domain name.","ref":"AWS.ApiGatewayV2.html#get_domain_name/3","title":"AWS.ApiGatewayV2.get_domain_name/3","type":"function"},{"doc":"Gets the domain names for an AWS account.","ref":"AWS.ApiGatewayV2.html#get_domain_names/4","title":"AWS.ApiGatewayV2.get_domain_names/4","type":"function"},{"doc":"Gets an Integration.","ref":"AWS.ApiGatewayV2.html#get_integration/4","title":"AWS.ApiGatewayV2.get_integration/4","type":"function"},{"doc":"Gets an IntegrationResponses.","ref":"AWS.ApiGatewayV2.html#get_integration_response/5","title":"AWS.ApiGatewayV2.get_integration_response/5","type":"function"},{"doc":"Gets the IntegrationResponses for an Integration.","ref":"AWS.ApiGatewayV2.html#get_integration_responses/6","title":"AWS.ApiGatewayV2.get_integration_responses/6","type":"function"},{"doc":"Gets the Integrations for an API.","ref":"AWS.ApiGatewayV2.html#get_integrations/5","title":"AWS.ApiGatewayV2.get_integrations/5","type":"function"},{"doc":"Gets a Model.","ref":"AWS.ApiGatewayV2.html#get_model/4","title":"AWS.ApiGatewayV2.get_model/4","type":"function"},{"doc":"Gets a model template.","ref":"AWS.ApiGatewayV2.html#get_model_template/4","title":"AWS.ApiGatewayV2.get_model_template/4","type":"function"},{"doc":"Gets the Models for an API.","ref":"AWS.ApiGatewayV2.html#get_models/5","title":"AWS.ApiGatewayV2.get_models/5","type":"function"},{"doc":"Gets a Route.","ref":"AWS.ApiGatewayV2.html#get_route/4","title":"AWS.ApiGatewayV2.get_route/4","type":"function"},{"doc":"Gets a RouteResponse.","ref":"AWS.ApiGatewayV2.html#get_route_response/5","title":"AWS.ApiGatewayV2.get_route_response/5","type":"function"},{"doc":"Gets the RouteResponses for a Route.","ref":"AWS.ApiGatewayV2.html#get_route_responses/6","title":"AWS.ApiGatewayV2.get_route_responses/6","type":"function"},{"doc":"Gets the Routes for an API.","ref":"AWS.ApiGatewayV2.html#get_routes/5","title":"AWS.ApiGatewayV2.get_routes/5","type":"function"},{"doc":"Gets a Stage.","ref":"AWS.ApiGatewayV2.html#get_stage/4","title":"AWS.ApiGatewayV2.get_stage/4","type":"function"},{"doc":"Gets the Stages for an API.","ref":"AWS.ApiGatewayV2.html#get_stages/5","title":"AWS.ApiGatewayV2.get_stages/5","type":"function"},{"doc":"Gets a collection of Tag resources.","ref":"AWS.ApiGatewayV2.html#get_tags/3","title":"AWS.ApiGatewayV2.get_tags/3","type":"function"},{"doc":"Gets a VPC link.","ref":"AWS.ApiGatewayV2.html#get_vpc_link/3","title":"AWS.ApiGatewayV2.get_vpc_link/3","type":"function"},{"doc":"Gets a collection of VPC links.","ref":"AWS.ApiGatewayV2.html#get_vpc_links/4","title":"AWS.ApiGatewayV2.get_vpc_links/4","type":"function"},{"doc":"Imports an API.","ref":"AWS.ApiGatewayV2.html#import_api/3","title":"AWS.ApiGatewayV2.import_api/3","type":"function"},{"doc":"","ref":"AWS.ApiGatewayV2.html#metadata/0","title":"AWS.ApiGatewayV2.metadata/0","type":"function"},{"doc":"Puts an Api resource.","ref":"AWS.ApiGatewayV2.html#reimport_api/4","title":"AWS.ApiGatewayV2.reimport_api/4","type":"function"},{"doc":"Resets all authorizer cache entries for the specified stage.\n\nSupported only for HTTP API Lambda authorizers.","ref":"AWS.ApiGatewayV2.html#reset_authorizers_cache/5","title":"AWS.ApiGatewayV2.reset_authorizers_cache/5","type":"function"},{"doc":"Creates a new Tag resource to represent a tag.","ref":"AWS.ApiGatewayV2.html#tag_resource/4","title":"AWS.ApiGatewayV2.tag_resource/4","type":"function"},{"doc":"Deletes a Tag.","ref":"AWS.ApiGatewayV2.html#untag_resource/4","title":"AWS.ApiGatewayV2.untag_resource/4","type":"function"},{"doc":"Updates an Api resource.","ref":"AWS.ApiGatewayV2.html#update_api/4","title":"AWS.ApiGatewayV2.update_api/4","type":"function"},{"doc":"The API mapping.","ref":"AWS.ApiGatewayV2.html#update_api_mapping/5","title":"AWS.ApiGatewayV2.update_api_mapping/5","type":"function"},{"doc":"Updates an Authorizer.","ref":"AWS.ApiGatewayV2.html#update_authorizer/5","title":"AWS.ApiGatewayV2.update_authorizer/5","type":"function"},{"doc":"Updates a Deployment.","ref":"AWS.ApiGatewayV2.html#update_deployment/5","title":"AWS.ApiGatewayV2.update_deployment/5","type":"function"},{"doc":"Updates a domain name.","ref":"AWS.ApiGatewayV2.html#update_domain_name/4","title":"AWS.ApiGatewayV2.update_domain_name/4","type":"function"},{"doc":"Updates an Integration.","ref":"AWS.ApiGatewayV2.html#update_integration/5","title":"AWS.ApiGatewayV2.update_integration/5","type":"function"},{"doc":"Updates an IntegrationResponses.","ref":"AWS.ApiGatewayV2.html#update_integration_response/6","title":"AWS.ApiGatewayV2.update_integration_response/6","type":"function"},{"doc":"Updates a Model.","ref":"AWS.ApiGatewayV2.html#update_model/5","title":"AWS.ApiGatewayV2.update_model/5","type":"function"},{"doc":"Updates a Route.","ref":"AWS.ApiGatewayV2.html#update_route/5","title":"AWS.ApiGatewayV2.update_route/5","type":"function"},{"doc":"Updates a RouteResponse.","ref":"AWS.ApiGatewayV2.html#update_route_response/6","title":"AWS.ApiGatewayV2.update_route_response/6","type":"function"},{"doc":"Updates a Stage.","ref":"AWS.ApiGatewayV2.html#update_stage/5","title":"AWS.ApiGatewayV2.update_stage/5","type":"function"},{"doc":"Updates a VPC link.","ref":"AWS.ApiGatewayV2.html#update_vpc_link/4","title":"AWS.ApiGatewayV2.update_vpc_link/4","type":"function"},{"doc":"Use AppConfig, a capability of Amazon Web Services Systems Manager, to create,\nmanage, and quickly deploy application configurations.\n\nAppConfig supports controlled deployments to applications of any size and\nincludes built-in validation checks and monitoring. You can use AppConfig with\napplications hosted on Amazon EC2 instances, Lambda, containers, mobile\napplications, or IoT devices.\n\nTo prevent errors when deploying application configurations, especially for\nproduction systems where a simple typo could cause an unexpected outage,\nAppConfig includes validators. A validator provides a syntactic or semantic\ncheck to ensure that the configuration you want to deploy works as intended. To\nvalidate your application configuration data, you provide a schema or an Amazon\nWeb Services Lambda function that runs against the configuration. The\nconfiguration deployment or update can only proceed when the configuration data\nis valid.\n\nDuring a configuration deployment, AppConfig monitors the application to ensure\nthat the deployment is successful. If the system encounters an error, AppConfig\nrolls back the change to minimize impact for your application users. You can\nconfigure a deployment strategy for each application or environment that\nincludes deployment criteria, including velocity, bake time, and alarms to\nmonitor. Similar to error monitoring, if a deployment triggers an alarm,\nAppConfig automatically rolls back to the previous version.\n\nAppConfig supports multiple use cases. Here are some examples:\n\n  * **Feature flags**: Use AppConfig to turn on new features that\nrequire a timely deployment, such as a product launch or announcement.\n\n  * **Application tuning**: Use AppConfig to carefully introduce\nchanges to your application that can only be tested with production traffic.\n\n  * **Allow list**: Use AppConfig to allow premium subscribers to\naccess paid content.\n\n  * **Operational issues**: Use AppConfig to reduce stress on your\napplication when a dependency or other external factor impacts the system.\n\nThis reference is intended to be used with the [AppConfig User Guide](http://docs.aws.amazon.com/appconfig/latest/userguide/what-is-appconfig.html).","ref":"AWS.AppConfig.html","title":"AWS.AppConfig","type":"module"},{"doc":"Creates an application.\n\nIn AppConfig, an application is simply an organizational construct like a\nfolder. This organizational construct has a relationship with some unit of\nexecutable code. For example, you could create an application called MyMobileApp\nto organize and manage configuration data for a mobile application installed by\nyour users.","ref":"AWS.AppConfig.html#create_application/3","title":"AWS.AppConfig.create_application/3","type":"function"},{"doc":"Creates a configuration profile, which is information that enables AppConfig to\naccess the configuration source.\n\nValid configuration sources include the following:\n\n  * Configuration data in YAML, JSON, and other formats stored in the\nAppConfig hosted configuration store\n\n  * Configuration data stored as objects in an Amazon Simple Storage\nService (Amazon S3) bucket\n\n  * Pipelines stored in CodePipeline\n\n  * Secrets stored in Secrets Manager\n\n  * Standard and secure string parameters stored in Amazon Web\nServices Systems Manager Parameter Store\n\n  * Configuration data in SSM documents stored in the Systems Manager\ndocument store\n\nA configuration profile includes the following information:\n\n  * The URI location of the configuration data.\n\n  * The Identity and Access Management (IAM) role that provides access\nto the configuration data.\n\n  * A validator for the configuration data. Available validators\ninclude either a JSON Schema or an Amazon Web Services Lambda function.\n\nFor more information, see [Create a Configuration and a Configuration Profile](http://docs.aws.amazon.com/appconfig/latest/userguide/appconfig-creating-configuration-and-profile.html)\nin the *AppConfig User Guide*.","ref":"AWS.AppConfig.html#create_configuration_profile/4","title":"AWS.AppConfig.create_configuration_profile/4","type":"function"},{"doc":"Creates a deployment strategy that defines important criteria for rolling out\nyour configuration to the designated targets.\n\nA deployment strategy includes the overall duration required, a percentage of\ntargets to receive the deployment during each interval, an algorithm that\ndefines how percentage grows, and bake time.","ref":"AWS.AppConfig.html#create_deployment_strategy/3","title":"AWS.AppConfig.create_deployment_strategy/3","type":"function"},{"doc":"Creates an environment.\n\nFor each application, you define one or more environments. An environment is a\ndeployment group of AppConfig targets, such as applications in a `Beta` or\n`Production` environment. You can also define environments for application\nsubcomponents such as the `Web`, `Mobile` and `Back-end` components for your\napplication. You can configure Amazon CloudWatch alarms for each environment.\nThe system monitors alarms during a configuration deployment. If an alarm is\ntriggered, the system rolls back the configuration.","ref":"AWS.AppConfig.html#create_environment/4","title":"AWS.AppConfig.create_environment/4","type":"function"},{"doc":"Creates an AppConfig extension.\n\nAn extension augments your ability to inject logic or behavior at different\npoints during the AppConfig workflow of creating or deploying a configuration.\n\nYou can create your own extensions or use the Amazon Web Services authored\nextensions provided by AppConfig. For an AppConfig extension that uses Lambda,\nyou must create a Lambda function to perform any computation and processing\ndefined in the extension. If you plan to create custom versions of the Amazon\nWeb Services authored notification extensions, you only need to specify an\nAmazon Resource Name (ARN) in the `Uri` field for the new extension version.\n\n  * For a custom EventBridge notification extension, enter the ARN of\nthe EventBridge default events in the `Uri` field.\n\n  * For a custom Amazon SNS notification extension, enter the ARN of\nan Amazon SNS topic in the `Uri` field.\n\n  * For a custom Amazon SQS notification extension, enter the ARN of\nan Amazon SQS message queue in the `Uri` field.\n\nFor more information about extensions, see [Working with AppConfig extensions](https://docs.aws.amazon.com/appconfig/latest/userguide/working-with-appconfig-extensions.html)\nin the *AppConfig User Guide*.","ref":"AWS.AppConfig.html#create_extension/3","title":"AWS.AppConfig.create_extension/3","type":"function"},{"doc":"When you create an extension or configure an Amazon Web Services authored\nextension, you associate the extension with an AppConfig application,\nenvironment, or configuration profile.\n\nFor example, you can choose to run the `AppConfig deployment events to Amazon\nSNS` Amazon Web Services authored extension and receive notifications on an\nAmazon SNS topic anytime a configuration deployment is started for a specific\napplication. Defining which extension to associate with an AppConfig resource is\ncalled an *extension association*. An extension association is a specified\nrelationship between an extension and an AppConfig resource, such as an\napplication or a configuration profile. For more information about extensions\nand associations, see [Working with AppConfig extensions](https://docs.aws.amazon.com/appconfig/latest/userguide/working-with-appconfig-extensions.html)\nin the *AppConfig User Guide*.","ref":"AWS.AppConfig.html#create_extension_association/3","title":"AWS.AppConfig.create_extension_association/3","type":"function"},{"doc":"Creates a new configuration in the AppConfig hosted configuration store.","ref":"AWS.AppConfig.html#create_hosted_configuration_version/5","title":"AWS.AppConfig.create_hosted_configuration_version/5","type":"function"},{"doc":"Deletes an application.\n\nDeleting an application does not delete a configuration from a host.","ref":"AWS.AppConfig.html#delete_application/4","title":"AWS.AppConfig.delete_application/4","type":"function"},{"doc":"Deletes a configuration profile.\n\nDeleting a configuration profile does not delete a configuration from a host.","ref":"AWS.AppConfig.html#delete_configuration_profile/5","title":"AWS.AppConfig.delete_configuration_profile/5","type":"function"},{"doc":"Deletes a deployment strategy.\n\nDeleting a deployment strategy does not delete a configuration from a host.","ref":"AWS.AppConfig.html#delete_deployment_strategy/4","title":"AWS.AppConfig.delete_deployment_strategy/4","type":"function"},{"doc":"Deletes an environment.\n\nDeleting an environment does not delete a configuration from a host.","ref":"AWS.AppConfig.html#delete_environment/5","title":"AWS.AppConfig.delete_environment/5","type":"function"},{"doc":"Deletes an AppConfig extension.\n\nYou must delete all associations to an extension before you delete the\nextension.","ref":"AWS.AppConfig.html#delete_extension/4","title":"AWS.AppConfig.delete_extension/4","type":"function"},{"doc":"Deletes an extension association.\n\nThis action doesn't delete extensions defined in the association.","ref":"AWS.AppConfig.html#delete_extension_association/4","title":"AWS.AppConfig.delete_extension_association/4","type":"function"},{"doc":"Deletes a version of a configuration from the AppConfig hosted configuration\nstore.","ref":"AWS.AppConfig.html#delete_hosted_configuration_version/6","title":"AWS.AppConfig.delete_hosted_configuration_version/6","type":"function"},{"doc":"Retrieves information about an application.","ref":"AWS.AppConfig.html#get_application/3","title":"AWS.AppConfig.get_application/3","type":"function"},{"doc":"(Deprecated) Retrieves the latest deployed configuration.\n\nNote the following important information.\n\n   This API action is deprecated. Calls to receive configuration data\nshould use the\n[StartConfigurationSession](https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_appconfigdata_StartConfigurationSession.html) and\n[GetLatestConfiguration](https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_appconfigdata_GetLatestConfiguration.html)\nAPIs instead.\n\n   `GetConfiguration` is a priced call. For more information, see\n[Pricing](https://aws.amazon.com/systems-manager/pricing/).","ref":"AWS.AppConfig.html#get_configuration/7","title":"AWS.AppConfig.get_configuration/7","type":"function"},{"doc":"Retrieves information about a configuration profile.","ref":"AWS.AppConfig.html#get_configuration_profile/4","title":"AWS.AppConfig.get_configuration_profile/4","type":"function"},{"doc":"Retrieves information about a configuration deployment.","ref":"AWS.AppConfig.html#get_deployment/5","title":"AWS.AppConfig.get_deployment/5","type":"function"},{"doc":"Retrieves information about a deployment strategy.\n\nA deployment strategy defines important criteria for rolling out your\nconfiguration to the designated targets. A deployment strategy includes the\noverall duration required, a percentage of targets to receive the deployment\nduring each interval, an algorithm that defines how percentage grows, and bake\ntime.","ref":"AWS.AppConfig.html#get_deployment_strategy/3","title":"AWS.AppConfig.get_deployment_strategy/3","type":"function"},{"doc":"Retrieves information about an environment.\n\nAn environment is a deployment group of AppConfig applications, such as\napplications in a `Production` environment or in an `EU_Region` environment.\nEach configuration deployment targets an environment. You can enable one or more\nAmazon CloudWatch alarms for an environment. If an alarm is triggered during a\ndeployment, AppConfig roles back the configuration.","ref":"AWS.AppConfig.html#get_environment/4","title":"AWS.AppConfig.get_environment/4","type":"function"},{"doc":"Returns information about an AppConfig extension.","ref":"AWS.AppConfig.html#get_extension/4","title":"AWS.AppConfig.get_extension/4","type":"function"},{"doc":"Returns information about an AppConfig extension association.\n\nFor more information about extensions and associations, see [Working with AppConfig\nextensions](https://docs.aws.amazon.com/appconfig/latest/userguide/working-with-appconfig-extensions.html)\nin the *AppConfig User Guide*.","ref":"AWS.AppConfig.html#get_extension_association/3","title":"AWS.AppConfig.get_extension_association/3","type":"function"},{"doc":"Retrieves information about a specific configuration version.","ref":"AWS.AppConfig.html#get_hosted_configuration_version/5","title":"AWS.AppConfig.get_hosted_configuration_version/5","type":"function"},{"doc":"Lists all applications in your Amazon Web Services account.","ref":"AWS.AppConfig.html#list_applications/4","title":"AWS.AppConfig.list_applications/4","type":"function"},{"doc":"Lists the configuration profiles for an application.","ref":"AWS.AppConfig.html#list_configuration_profiles/6","title":"AWS.AppConfig.list_configuration_profiles/6","type":"function"},{"doc":"Lists deployment strategies.","ref":"AWS.AppConfig.html#list_deployment_strategies/4","title":"AWS.AppConfig.list_deployment_strategies/4","type":"function"},{"doc":"Lists the deployments for an environment in descending deployment number order.","ref":"AWS.AppConfig.html#list_deployments/6","title":"AWS.AppConfig.list_deployments/6","type":"function"},{"doc":"Lists the environments for an application.","ref":"AWS.AppConfig.html#list_environments/5","title":"AWS.AppConfig.list_environments/5","type":"function"},{"doc":"Lists all AppConfig extension associations in the account.\n\nFor more information about extensions and associations, see [Working with AppConfig\nextensions](https://docs.aws.amazon.com/appconfig/latest/userguide/working-with-appconfig-extensions.html)\nin the *AppConfig User Guide*.","ref":"AWS.AppConfig.html#list_extension_associations/7","title":"AWS.AppConfig.list_extension_associations/7","type":"function"},{"doc":"Lists all custom and Amazon Web Services authored AppConfig extensions in the\naccount.\n\nFor more information about extensions, see [Working with AppConfig extensions](https://docs.aws.amazon.com/appconfig/latest/userguide/working-with-appconfig-extensions.html)\nin the *AppConfig User Guide*.","ref":"AWS.AppConfig.html#list_extensions/5","title":"AWS.AppConfig.list_extensions/5","type":"function"},{"doc":"Lists configurations stored in the AppConfig hosted configuration store by\nversion.","ref":"AWS.AppConfig.html#list_hosted_configuration_versions/7","title":"AWS.AppConfig.list_hosted_configuration_versions/7","type":"function"},{"doc":"Retrieves the list of key-value tags assigned to the resource.","ref":"AWS.AppConfig.html#list_tags_for_resource/3","title":"AWS.AppConfig.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.AppConfig.html#metadata/0","title":"AWS.AppConfig.metadata/0","type":"function"},{"doc":"Starts a deployment.","ref":"AWS.AppConfig.html#start_deployment/5","title":"AWS.AppConfig.start_deployment/5","type":"function"},{"doc":"Stops a deployment.\n\nThis API action works only on deployments that have a status of `DEPLOYING`.\nThis action moves the deployment to a status of `ROLLED_BACK`.","ref":"AWS.AppConfig.html#stop_deployment/6","title":"AWS.AppConfig.stop_deployment/6","type":"function"},{"doc":"Assigns metadata to an AppConfig resource.\n\nTags help organize and categorize your AppConfig resources. Each tag consists of\na key and an optional value, both of which you define. You can specify a maximum\nof 50 tags for a resource.","ref":"AWS.AppConfig.html#tag_resource/4","title":"AWS.AppConfig.tag_resource/4","type":"function"},{"doc":"Deletes a tag key and value from an AppConfig resource.","ref":"AWS.AppConfig.html#untag_resource/4","title":"AWS.AppConfig.untag_resource/4","type":"function"},{"doc":"Updates an application.","ref":"AWS.AppConfig.html#update_application/4","title":"AWS.AppConfig.update_application/4","type":"function"},{"doc":"Updates a configuration profile.","ref":"AWS.AppConfig.html#update_configuration_profile/5","title":"AWS.AppConfig.update_configuration_profile/5","type":"function"},{"doc":"Updates a deployment strategy.","ref":"AWS.AppConfig.html#update_deployment_strategy/4","title":"AWS.AppConfig.update_deployment_strategy/4","type":"function"},{"doc":"Updates an environment.","ref":"AWS.AppConfig.html#update_environment/5","title":"AWS.AppConfig.update_environment/5","type":"function"},{"doc":"Updates an AppConfig extension.\n\nFor more information about extensions, see [Working with AppConfig extensions](https://docs.aws.amazon.com/appconfig/latest/userguide/working-with-appconfig-extensions.html)\nin the *AppConfig User Guide*.","ref":"AWS.AppConfig.html#update_extension/4","title":"AWS.AppConfig.update_extension/4","type":"function"},{"doc":"Updates an association.\n\nFor more information about extensions and associations, see [Working with AppConfig\nextensions](https://docs.aws.amazon.com/appconfig/latest/userguide/working-with-appconfig-extensions.html)\nin the *AppConfig User Guide*.","ref":"AWS.AppConfig.html#update_extension_association/4","title":"AWS.AppConfig.update_extension_association/4","type":"function"},{"doc":"Uses the validators in a configuration profile to validate a configuration.","ref":"AWS.AppConfig.html#validate_configuration/5","title":"AWS.AppConfig.validate_configuration/5","type":"function"},{"doc":"AppConfig Data provides the data plane APIs your application uses to retrieve\nconfiguration data.\n\nHere's how it works:\n\nYour application retrieves configuration data by first establishing a\nconfiguration session using the AppConfig Data `StartConfigurationSession` API\naction. Your session's client then makes periodic calls to\n`GetLatestConfiguration` to check for and retrieve the latest data available.\n\nWhen calling `StartConfigurationSession`, your code sends the following\ninformation:\n\n  * Identifiers (ID or name) of an AppConfig application, environment,\nand configuration profile that the session tracks.\n\n  * (Optional) The minimum amount of time the session's client must\nwait between calls to `GetLatestConfiguration`.\n\nIn response, AppConfig provides an `InitialConfigurationToken` to be given to\nthe session's client and used the first time it calls `GetLatestConfiguration`\nfor that session.\n\nThis token should only be used once in your first call to\n`GetLatestConfiguration`. You *must* use the new token in the\n`GetLatestConfiguration` response (`NextPollConfigurationToken`) in each\nsubsequent call to `GetLatestConfiguration`.\n\nWhen calling `GetLatestConfiguration`, your client code sends the most recent\n`ConfigurationToken` value it has and receives in response:\n\n  * `NextPollConfigurationToken`: the `ConfigurationToken` value to\nuse on the next call to `GetLatestConfiguration`.\n\n  * `NextPollIntervalInSeconds`: the duration the client should wait\nbefore making its next call to `GetLatestConfiguration`. This duration may vary\nover the course of the session, so it should be used instead of the value sent\non the `StartConfigurationSession` call.\n\n  * The configuration: the latest data intended for the session. This\nmay be empty if the client already has the latest version of the configuration.\n\nThe `InitialConfigurationToken` and `NextPollConfigurationToken` should only be\nused once. To support long poll use cases, the tokens are valid for up to 24\nhours. If a `GetLatestConfiguration` call uses an expired token, the system\nreturns `BadRequestException`.\n\nFor more information and to view example CLI commands that show how to retrieve\na configuration using the AppConfig Data `StartConfigurationSession` and\n`GetLatestConfiguration` API actions, see [Retrieving the configuration](http://docs.aws.amazon.com/appconfig/latest/userguide/appconfig-retrieving-the-configuration)\nin the *AppConfig User Guide*.","ref":"AWS.AppConfigData.html","title":"AWS.AppConfigData","type":"module"},{"doc":"Retrieves the latest deployed configuration.\n\nThis API may return empty configuration data if the client already has the\nlatest version. For more information about this API action and to view example\nCLI commands that show how to use it with the `StartConfigurationSession` API\naction, see [Retrieving the configuration](http://docs.aws.amazon.com/appconfig/latest/userguide/appconfig-retrieving-the-configuration)\nin the *AppConfig User Guide*.\n\nNote the following important information.\n\n   Each configuration token is only valid for one call to\n`GetLatestConfiguration`. The `GetLatestConfiguration` response includes a\n`NextPollConfigurationToken` that should always replace the token used for the\njust-completed call in preparation for the next one.\n\n   `GetLatestConfiguration` is a priced call. For more information,\nsee [Pricing](https://aws.amazon.com/systems-manager/pricing/).","ref":"AWS.AppConfigData.html#get_latest_configuration/3","title":"AWS.AppConfigData.get_latest_configuration/3","type":"function"},{"doc":"","ref":"AWS.AppConfigData.html#metadata/0","title":"AWS.AppConfigData.metadata/0","type":"function"},{"doc":"Starts a configuration session used to retrieve a deployed configuration.\n\nFor more information about this API action and to view example CLI commands that\nshow how to use it with the `GetLatestConfiguration` API action, see [Retrieving the\nconfiguration](http://docs.aws.amazon.com/appconfig/latest/userguide/appconfig-retrieving-the-configuration)\nin the *AppConfig User Guide*.","ref":"AWS.AppConfigData.html#start_configuration_session/3","title":"AWS.AppConfigData.start_configuration_session/3","type":"function"},{"doc":"Amazon Web Services AppFabric quickly connects software as a service (SaaS)\napplications across your organization.\n\nThis allows IT and security teams to easily manage and secure applications using\na standard schema, and employees can complete everyday tasks faster using\ngenerative artificial intelligence (AI). You can use these APIs to complete\nAppFabric tasks, such as setting up audit log ingestions or viewing user access.\nFor more information about AppFabric, including the required permissions to use\nthe service, see the [Amazon Web Services AppFabric Administration Guide](https://docs.aws.amazon.com/appfabric/latest/adminguide/). For more\ninformation about using the Command Line Interface (CLI) to manage your\nAppFabric resources, see the [AppFabric section of the CLI Reference](https://docs.aws.amazon.com/cli/latest/reference/appfabric/index.html).","ref":"AWS.AppFabric.html","title":"AWS.AppFabric","type":"module"},{"doc":"Gets user access details in a batch request.\n\nThis action polls data from the tasks that are kicked off by the\n`StartUserAccessTasks` action.","ref":"AWS.AppFabric.html#batch_get_user_access_tasks/3","title":"AWS.AppFabric.batch_get_user_access_tasks/3","type":"function"},{"doc":"Establishes a connection between Amazon Web Services AppFabric and an\napplication, which allows AppFabric to call the APIs of the application.","ref":"AWS.AppFabric.html#connect_app_authorization/5","title":"AWS.AppFabric.connect_app_authorization/5","type":"function"},{"doc":"Creates an app authorization within an app bundle, which allows AppFabric to\nconnect to an application.","ref":"AWS.AppFabric.html#create_app_authorization/4","title":"AWS.AppFabric.create_app_authorization/4","type":"function"},{"doc":"Creates an app bundle to collect data from an application using AppFabric.","ref":"AWS.AppFabric.html#create_app_bundle/3","title":"AWS.AppFabric.create_app_bundle/3","type":"function"},{"doc":"Creates a data ingestion for an application.","ref":"AWS.AppFabric.html#create_ingestion/4","title":"AWS.AppFabric.create_ingestion/4","type":"function"},{"doc":"Creates an ingestion destination, which specifies how an application's ingested\ndata is processed by Amazon Web Services AppFabric and where it's delivered.","ref":"AWS.AppFabric.html#create_ingestion_destination/5","title":"AWS.AppFabric.create_ingestion_destination/5","type":"function"},{"doc":"Deletes an app authorization.\n\nYou must delete the associated ingestion before you can delete an app\nauthorization.","ref":"AWS.AppFabric.html#delete_app_authorization/5","title":"AWS.AppFabric.delete_app_authorization/5","type":"function"},{"doc":"Deletes an app bundle.\n\nYou must delete all associated app authorizations before you can delete an app\nbundle.","ref":"AWS.AppFabric.html#delete_app_bundle/4","title":"AWS.AppFabric.delete_app_bundle/4","type":"function"},{"doc":"Deletes an ingestion.\n\nYou must stop (disable) the ingestion and you must delete all associated\ningestion destinations before you can delete an app ingestion.","ref":"AWS.AppFabric.html#delete_ingestion/5","title":"AWS.AppFabric.delete_ingestion/5","type":"function"},{"doc":"Deletes an ingestion destination.\n\nThis deletes the association between an ingestion and it's destination. It\ndoesn't delete previously ingested data or the storage destination, such as the\nAmazon S3 bucket where the data is delivered. If the ingestion destination is\ndeleted while the associated ingestion is enabled, the ingestion will fail and\nis eventually disabled.","ref":"AWS.AppFabric.html#delete_ingestion_destination/6","title":"AWS.AppFabric.delete_ingestion_destination/6","type":"function"},{"doc":"Returns information about an app authorization.","ref":"AWS.AppFabric.html#get_app_authorization/4","title":"AWS.AppFabric.get_app_authorization/4","type":"function"},{"doc":"Returns information about an app bundle.","ref":"AWS.AppFabric.html#get_app_bundle/3","title":"AWS.AppFabric.get_app_bundle/3","type":"function"},{"doc":"Returns information about an ingestion.","ref":"AWS.AppFabric.html#get_ingestion/4","title":"AWS.AppFabric.get_ingestion/4","type":"function"},{"doc":"Returns information about an ingestion destination.","ref":"AWS.AppFabric.html#get_ingestion_destination/5","title":"AWS.AppFabric.get_ingestion_destination/5","type":"function"},{"doc":"Returns a list of all app authorizations configured for an app bundle.","ref":"AWS.AppFabric.html#list_app_authorizations/5","title":"AWS.AppFabric.list_app_authorizations/5","type":"function"},{"doc":"Returns a list of app bundles.","ref":"AWS.AppFabric.html#list_app_bundles/4","title":"AWS.AppFabric.list_app_bundles/4","type":"function"},{"doc":"Returns a list of all ingestion destinations configured for an ingestion.","ref":"AWS.AppFabric.html#list_ingestion_destinations/6","title":"AWS.AppFabric.list_ingestion_destinations/6","type":"function"},{"doc":"Returns a list of all ingestions configured for an app bundle.","ref":"AWS.AppFabric.html#list_ingestions/5","title":"AWS.AppFabric.list_ingestions/5","type":"function"},{"doc":"Returns a list of tags for a resource.","ref":"AWS.AppFabric.html#list_tags_for_resource/3","title":"AWS.AppFabric.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.AppFabric.html#metadata/0","title":"AWS.AppFabric.metadata/0","type":"function"},{"doc":"Starts (enables) an ingestion, which collects data from an application.","ref":"AWS.AppFabric.html#start_ingestion/5","title":"AWS.AppFabric.start_ingestion/5","type":"function"},{"doc":"Starts the tasks to search user access status for a specific email address.\n\nThe tasks are stopped when the user access status data is found. The tasks are\nterminated when the API calls to the application time out.","ref":"AWS.AppFabric.html#start_user_access_tasks/3","title":"AWS.AppFabric.start_user_access_tasks/3","type":"function"},{"doc":"Stops (disables) an ingestion.","ref":"AWS.AppFabric.html#stop_ingestion/5","title":"AWS.AppFabric.stop_ingestion/5","type":"function"},{"doc":"Assigns one or more tags (key-value pairs) to the specified resource.","ref":"AWS.AppFabric.html#tag_resource/4","title":"AWS.AppFabric.tag_resource/4","type":"function"},{"doc":"Removes a tag or tags from a resource.","ref":"AWS.AppFabric.html#untag_resource/4","title":"AWS.AppFabric.untag_resource/4","type":"function"},{"doc":"Updates an app authorization within an app bundle, which allows AppFabric to\nconnect to an application.\n\nIf the app authorization was in a `connected` state, updating the app\nauthorization will set it back to a `PendingConnect` state.","ref":"AWS.AppFabric.html#update_app_authorization/5","title":"AWS.AppFabric.update_app_authorization/5","type":"function"},{"doc":"Updates an ingestion destination, which specifies how an application's ingested\ndata is processed by Amazon Web Services AppFabric and where it's delivered.","ref":"AWS.AppFabric.html#update_ingestion_destination/6","title":"AWS.AppFabric.update_ingestion_destination/6","type":"function"},{"doc":"The Amazon AppIntegrations service enables you to configure and reuse\nconnections to external applications.\n\nFor information about how you can use external applications with Amazon Connect,\nsee [Set up pre-built integrations](https://docs.aws.amazon.com/connect/latest/adminguide/crm.html)\nand [Deliver information to agents using Amazon Connect Wisdom](https://docs.aws.amazon.com/connect/latest/adminguide/amazon-connect-wisdom.html)\nin the *Amazon Connect Administrator Guide*.","ref":"AWS.AppIntegrations.html","title":"AWS.AppIntegrations","type":"module"},{"doc":"This API is in preview release and subject to change.\n\nCreates and persists an Application resource.","ref":"AWS.AppIntegrations.html#create_application/3","title":"AWS.AppIntegrations.create_application/3","type":"function"},{"doc":"Creates and persists a DataIntegration resource.\n\nYou cannot create a DataIntegration association for a DataIntegration that has\nbeen previously associated. Use a different DataIntegration, or recreate the\nDataIntegration using the `CreateDataIntegration` API.","ref":"AWS.AppIntegrations.html#create_data_integration/3","title":"AWS.AppIntegrations.create_data_integration/3","type":"function"},{"doc":"Creates an EventIntegration, given a specified name, description, and a\nreference to an Amazon EventBridge bus in your account and a partner event\nsource that pushes events to that bus.\n\nNo objects are created in the your account, only metadata that is persisted on\nthe EventIntegration control plane.","ref":"AWS.AppIntegrations.html#create_event_integration/3","title":"AWS.AppIntegrations.create_event_integration/3","type":"function"},{"doc":"Deletes the Application.\n\nOnly Applications that don't have any Application Associations can be deleted.","ref":"AWS.AppIntegrations.html#delete_application/4","title":"AWS.AppIntegrations.delete_application/4","type":"function"},{"doc":"Deletes the DataIntegration.\n\nOnly DataIntegrations that don't have any DataIntegrationAssociations can be\ndeleted. Deleting a DataIntegration also deletes the underlying Amazon AppFlow\nflow and service linked role.\n\nYou cannot create a DataIntegration association for a DataIntegration that has\nbeen previously associated. Use a different DataIntegration, or recreate the\nDataIntegration using the\n[CreateDataIntegration](https://docs.aws.amazon.com/appintegrations/latest/APIReference/API_CreateDataIntegration.html)\nAPI.","ref":"AWS.AppIntegrations.html#delete_data_integration/4","title":"AWS.AppIntegrations.delete_data_integration/4","type":"function"},{"doc":"Deletes the specified existing event integration.\n\nIf the event integration is associated with clients, the request is rejected.","ref":"AWS.AppIntegrations.html#delete_event_integration/4","title":"AWS.AppIntegrations.delete_event_integration/4","type":"function"},{"doc":"This API is in preview release and subject to change.\n\nGet an Application resource.","ref":"AWS.AppIntegrations.html#get_application/3","title":"AWS.AppIntegrations.get_application/3","type":"function"},{"doc":"Returns information about the DataIntegration.\n\nYou cannot create a DataIntegration association for a DataIntegration that has\nbeen previously associated. Use a different DataIntegration, or recreate the\nDataIntegration using the\n[CreateDataIntegration](https://docs.aws.amazon.com/appintegrations/latest/APIReference/API_CreateDataIntegration.html)\nAPI.","ref":"AWS.AppIntegrations.html#get_data_integration/3","title":"AWS.AppIntegrations.get_data_integration/3","type":"function"},{"doc":"Returns information about the event integration.","ref":"AWS.AppIntegrations.html#get_event_integration/3","title":"AWS.AppIntegrations.get_event_integration/3","type":"function"},{"doc":"Returns a paginated list of application associations for an application.","ref":"AWS.AppIntegrations.html#list_application_associations/5","title":"AWS.AppIntegrations.list_application_associations/5","type":"function"},{"doc":"This API is in preview release and subject to change.\n\nLists applications in the account.","ref":"AWS.AppIntegrations.html#list_applications/4","title":"AWS.AppIntegrations.list_applications/4","type":"function"},{"doc":"Returns a paginated list of DataIntegration associations in the account.\n\nYou cannot create a DataIntegration association for a DataIntegration that has\nbeen previously associated. Use a different DataIntegration, or recreate the\nDataIntegration using the\n[CreateDataIntegration](https://docs.aws.amazon.com/appintegrations/latest/APIReference/API_CreateDataIntegration.html)\nAPI.","ref":"AWS.AppIntegrations.html#list_data_integration_associations/5","title":"AWS.AppIntegrations.list_data_integration_associations/5","type":"function"},{"doc":"Returns a paginated list of DataIntegrations in the account.\n\nYou cannot create a DataIntegration association for a DataIntegration that has\nbeen previously associated. Use a different DataIntegration, or recreate the\nDataIntegration using the\n[CreateDataIntegration](https://docs.aws.amazon.com/appintegrations/latest/APIReference/API_CreateDataIntegration.html)\nAPI.","ref":"AWS.AppIntegrations.html#list_data_integrations/4","title":"AWS.AppIntegrations.list_data_integrations/4","type":"function"},{"doc":"Returns a paginated list of event integration associations in the account.","ref":"AWS.AppIntegrations.html#list_event_integration_associations/5","title":"AWS.AppIntegrations.list_event_integration_associations/5","type":"function"},{"doc":"Returns a paginated list of event integrations in the account.","ref":"AWS.AppIntegrations.html#list_event_integrations/4","title":"AWS.AppIntegrations.list_event_integrations/4","type":"function"},{"doc":"Lists the tags for the specified resource.","ref":"AWS.AppIntegrations.html#list_tags_for_resource/3","title":"AWS.AppIntegrations.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.AppIntegrations.html#metadata/0","title":"AWS.AppIntegrations.metadata/0","type":"function"},{"doc":"Adds the specified tags to the specified resource.","ref":"AWS.AppIntegrations.html#tag_resource/4","title":"AWS.AppIntegrations.tag_resource/4","type":"function"},{"doc":"Removes the specified tags from the specified resource.","ref":"AWS.AppIntegrations.html#untag_resource/4","title":"AWS.AppIntegrations.untag_resource/4","type":"function"},{"doc":"This API is in preview release and subject to change.\n\nUpdates and persists an Application resource.","ref":"AWS.AppIntegrations.html#update_application/4","title":"AWS.AppIntegrations.update_application/4","type":"function"},{"doc":"Updates the description of a DataIntegration.\n\nYou cannot create a DataIntegration association for a DataIntegration that has\nbeen previously associated. Use a different DataIntegration, or recreate the\nDataIntegration using the\n[CreateDataIntegration](https://docs.aws.amazon.com/appintegrations/latest/APIReference/API_CreateDataIntegration.html)\nAPI.","ref":"AWS.AppIntegrations.html#update_data_integration/4","title":"AWS.AppIntegrations.update_data_integration/4","type":"function"},{"doc":"Updates the description of an event integration.","ref":"AWS.AppIntegrations.html#update_event_integration/4","title":"AWS.AppIntegrations.update_event_integration/4","type":"function"},{"doc":"App Mesh is a service mesh based on the Envoy proxy that makes it easy to\nmonitor and control microservices.\n\nApp Mesh standardizes how your microservices communicate, giving you end-to-end\nvisibility and helping to ensure high availability for your applications.\n\nApp Mesh gives you consistent visibility and network traffic controls for every\nmicroservice in an application. You can use App Mesh with Amazon Web Services\nFargate, Amazon ECS, Amazon EKS, Kubernetes on Amazon Web Services, and Amazon\nEC2.\n\nApp Mesh supports microservice applications that use service discovery naming\nfor their components. For more information about service discovery on Amazon\nECS, see [Service Discovery](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/service-discovery.html)\nin the *Amazon Elastic Container Service Developer Guide*. Kubernetes `kube-dns`\nand `coredns` are supported. For more information, see [DNS for Services and Pods](https://kubernetes.io/docs/concepts/services-networking/dns-pod-service/)\nin the Kubernetes documentation.","ref":"AWS.AppMesh.html","title":"AWS.AppMesh","type":"module"},{"doc":"Creates a gateway route.\n\nA gateway route is attached to a virtual gateway and routes traffic to an\nexisting virtual service. If a route matches a request, it can distribute\ntraffic to a target virtual service.\n\nFor more information about gateway routes, see [Gateway routes](https://docs.aws.amazon.com/app-mesh/latest/userguide/gateway-routes.html).","ref":"AWS.AppMesh.html#create_gateway_route/5","title":"AWS.AppMesh.create_gateway_route/5","type":"function"},{"doc":"Creates a service mesh.\n\nA service mesh is a logical boundary for network traffic between services that\nare represented by resources within the mesh. After you create your service\nmesh, you can create virtual services, virtual nodes, virtual routers, and\nroutes to distribute traffic between the applications in your mesh.\n\nFor more information about service meshes, see [Service meshes](https://docs.aws.amazon.com/app-mesh/latest/userguide/meshes.html).","ref":"AWS.AppMesh.html#create_mesh/3","title":"AWS.AppMesh.create_mesh/3","type":"function"},{"doc":"Creates a route that is associated with a virtual router.\n\nYou can route several different protocols and define a retry policy for a route.\nTraffic can be routed to one or more virtual nodes.\n\nFor more information about routes, see\n[Routes](https://docs.aws.amazon.com/app-mesh/latest/userguide/routes.html).","ref":"AWS.AppMesh.html#create_route/5","title":"AWS.AppMesh.create_route/5","type":"function"},{"doc":"Creates a virtual gateway.\n\nA virtual gateway allows resources outside your mesh to communicate to resources\nthat are inside your mesh. The virtual gateway represents an Envoy proxy running\nin an Amazon ECS task, in a Kubernetes service, or on an Amazon EC2 instance.\nUnlike a virtual node, which represents an Envoy running with an application, a\nvirtual gateway represents Envoy deployed by itself.\n\nFor more information about virtual gateways, see [Virtual gateways](https://docs.aws.amazon.com/app-mesh/latest/userguide/virtual_gateways.html).","ref":"AWS.AppMesh.html#create_virtual_gateway/4","title":"AWS.AppMesh.create_virtual_gateway/4","type":"function"},{"doc":"Creates a virtual node within a service mesh.\n\nA virtual node acts as a logical pointer to a particular task group, such as an\nAmazon ECS service or a Kubernetes deployment. When you create a virtual node,\nyou can specify the service discovery information for your task group, and\nwhether the proxy running in a task group will communicate with other proxies\nusing Transport Layer Security (TLS).\n\nYou define a `listener` for any inbound traffic that your virtual node expects.\nAny virtual service that your virtual node expects to communicate to is\nspecified as a `backend`.\n\nThe response metadata for your new virtual node contains the `arn` that is\nassociated with the virtual node. Set this value to the full ARN; for example,\n`arn:aws:appmesh:us-west-2:123456789012:myMesh/default/virtualNode/myApp`) as\nthe `APPMESH_RESOURCE_ARN` environment variable for your task group's Envoy\nproxy container in your task definition or pod spec. This is then mapped to the\n`node.id` and `node.cluster` Envoy parameters.\n\nBy default, App Mesh uses the name of the resource you specified in\n`APPMESH_RESOURCE_ARN` when Envoy is referring to itself in metrics and traces.\nYou can override this behavior by setting the `APPMESH_RESOURCE_CLUSTER`\nenvironment variable with your own name.\n\nFor more information about virtual nodes, see [Virtual nodes](https://docs.aws.amazon.com/app-mesh/latest/userguide/virtual_nodes.html).\nYou must be using `1.15.0` or later of the Envoy image when setting these\nvariables. For more information aboutApp Mesh Envoy variables, see [Envoy image](https://docs.aws.amazon.com/app-mesh/latest/userguide/envoy.html) in the\nApp Mesh User Guide.","ref":"AWS.AppMesh.html#create_virtual_node/4","title":"AWS.AppMesh.create_virtual_node/4","type":"function"},{"doc":"Creates a virtual router within a service mesh.\n\nSpecify a `listener` for any inbound traffic that your virtual router receives.\nCreate a virtual router for each protocol and port that you need to route.\nVirtual routers handle traffic for one or more virtual services within your\nmesh. After you create your virtual router, create and associate routes for your\nvirtual router that direct incoming requests to different virtual nodes.\n\nFor more information about virtual routers, see [Virtual routers](https://docs.aws.amazon.com/app-mesh/latest/userguide/virtual_routers.html).","ref":"AWS.AppMesh.html#create_virtual_router/4","title":"AWS.AppMesh.create_virtual_router/4","type":"function"},{"doc":"Creates a virtual service within a service mesh.\n\nA virtual service is an abstraction of a real service that is provided by a\nvirtual node directly or indirectly by means of a virtual router. Dependent\nservices call your virtual service by its `virtualServiceName`, and those\nrequests are routed to the virtual node or virtual router that is specified as\nthe provider for the virtual service.\n\nFor more information about virtual services, see [Virtual services](https://docs.aws.amazon.com/app-mesh/latest/userguide/virtual_services.html).","ref":"AWS.AppMesh.html#create_virtual_service/4","title":"AWS.AppMesh.create_virtual_service/4","type":"function"},{"doc":"Deletes an existing gateway route.","ref":"AWS.AppMesh.html#delete_gateway_route/6","title":"AWS.AppMesh.delete_gateway_route/6","type":"function"},{"doc":"Deletes an existing service mesh.\n\nYou must delete all resources (virtual services, routes, virtual routers, and\nvirtual nodes) in the service mesh before you can delete the mesh itself.","ref":"AWS.AppMesh.html#delete_mesh/4","title":"AWS.AppMesh.delete_mesh/4","type":"function"},{"doc":"Deletes an existing route.","ref":"AWS.AppMesh.html#delete_route/6","title":"AWS.AppMesh.delete_route/6","type":"function"},{"doc":"Deletes an existing virtual gateway.\n\nYou cannot delete a virtual gateway if any gateway routes are associated to it.","ref":"AWS.AppMesh.html#delete_virtual_gateway/5","title":"AWS.AppMesh.delete_virtual_gateway/5","type":"function"},{"doc":"Deletes an existing virtual node.\n\nYou must delete any virtual services that list a virtual node as a service\nprovider before you can delete the virtual node itself.","ref":"AWS.AppMesh.html#delete_virtual_node/5","title":"AWS.AppMesh.delete_virtual_node/5","type":"function"},{"doc":"Deletes an existing virtual router.\n\nYou must delete any routes associated with the virtual router before you can\ndelete the router itself.","ref":"AWS.AppMesh.html#delete_virtual_router/5","title":"AWS.AppMesh.delete_virtual_router/5","type":"function"},{"doc":"Deletes an existing virtual service.","ref":"AWS.AppMesh.html#delete_virtual_service/5","title":"AWS.AppMesh.delete_virtual_service/5","type":"function"},{"doc":"Describes an existing gateway route.","ref":"AWS.AppMesh.html#describe_gateway_route/6","title":"AWS.AppMesh.describe_gateway_route/6","type":"function"},{"doc":"Describes an existing service mesh.","ref":"AWS.AppMesh.html#describe_mesh/4","title":"AWS.AppMesh.describe_mesh/4","type":"function"},{"doc":"Describes an existing route.","ref":"AWS.AppMesh.html#describe_route/6","title":"AWS.AppMesh.describe_route/6","type":"function"},{"doc":"Describes an existing virtual gateway.","ref":"AWS.AppMesh.html#describe_virtual_gateway/5","title":"AWS.AppMesh.describe_virtual_gateway/5","type":"function"},{"doc":"Describes an existing virtual node.","ref":"AWS.AppMesh.html#describe_virtual_node/5","title":"AWS.AppMesh.describe_virtual_node/5","type":"function"},{"doc":"Describes an existing virtual router.","ref":"AWS.AppMesh.html#describe_virtual_router/5","title":"AWS.AppMesh.describe_virtual_router/5","type":"function"},{"doc":"Describes an existing virtual service.","ref":"AWS.AppMesh.html#describe_virtual_service/5","title":"AWS.AppMesh.describe_virtual_service/5","type":"function"},{"doc":"Returns a list of existing gateway routes that are associated to a virtual\ngateway.","ref":"AWS.AppMesh.html#list_gateway_routes/7","title":"AWS.AppMesh.list_gateway_routes/7","type":"function"},{"doc":"Returns a list of existing service meshes.","ref":"AWS.AppMesh.html#list_meshes/4","title":"AWS.AppMesh.list_meshes/4","type":"function"},{"doc":"Returns a list of existing routes in a service mesh.","ref":"AWS.AppMesh.html#list_routes/7","title":"AWS.AppMesh.list_routes/7","type":"function"},{"doc":"List the tags for an App Mesh resource.","ref":"AWS.AppMesh.html#list_tags_for_resource/5","title":"AWS.AppMesh.list_tags_for_resource/5","type":"function"},{"doc":"Returns a list of existing virtual gateways in a service mesh.","ref":"AWS.AppMesh.html#list_virtual_gateways/6","title":"AWS.AppMesh.list_virtual_gateways/6","type":"function"},{"doc":"Returns a list of existing virtual nodes.","ref":"AWS.AppMesh.html#list_virtual_nodes/6","title":"AWS.AppMesh.list_virtual_nodes/6","type":"function"},{"doc":"Returns a list of existing virtual routers in a service mesh.","ref":"AWS.AppMesh.html#list_virtual_routers/6","title":"AWS.AppMesh.list_virtual_routers/6","type":"function"},{"doc":"Returns a list of existing virtual services in a service mesh.","ref":"AWS.AppMesh.html#list_virtual_services/6","title":"AWS.AppMesh.list_virtual_services/6","type":"function"},{"doc":"","ref":"AWS.AppMesh.html#metadata/0","title":"AWS.AppMesh.metadata/0","type":"function"},{"doc":"Associates the specified tags to a resource with the specified `resourceArn`.\n\nIf existing tags on a resource aren't specified in the request parameters, they\naren't changed. When a resource is deleted, the tags associated with that\nresource are also deleted.","ref":"AWS.AppMesh.html#tag_resource/3","title":"AWS.AppMesh.tag_resource/3","type":"function"},{"doc":"Deletes specified tags from a resource.","ref":"AWS.AppMesh.html#untag_resource/3","title":"AWS.AppMesh.untag_resource/3","type":"function"},{"doc":"Updates an existing gateway route that is associated to a specified virtual\ngateway in a service mesh.","ref":"AWS.AppMesh.html#update_gateway_route/6","title":"AWS.AppMesh.update_gateway_route/6","type":"function"},{"doc":"Updates an existing service mesh.","ref":"AWS.AppMesh.html#update_mesh/4","title":"AWS.AppMesh.update_mesh/4","type":"function"},{"doc":"Updates an existing route for a specified service mesh and virtual router.","ref":"AWS.AppMesh.html#update_route/6","title":"AWS.AppMesh.update_route/6","type":"function"},{"doc":"Updates an existing virtual gateway in a specified service mesh.","ref":"AWS.AppMesh.html#update_virtual_gateway/5","title":"AWS.AppMesh.update_virtual_gateway/5","type":"function"},{"doc":"Updates an existing virtual node in a specified service mesh.","ref":"AWS.AppMesh.html#update_virtual_node/5","title":"AWS.AppMesh.update_virtual_node/5","type":"function"},{"doc":"Updates an existing virtual router in a specified service mesh.","ref":"AWS.AppMesh.html#update_virtual_router/5","title":"AWS.AppMesh.update_virtual_router/5","type":"function"},{"doc":"Updates an existing virtual service in a specified service mesh.","ref":"AWS.AppMesh.html#update_virtual_service/5","title":"AWS.AppMesh.update_virtual_service/5","type":"function"},{"doc":"App Runner\n\nApp Runner is an application service that provides a fast, simple, and\ncost-effective way to go directly from an existing container image or source\ncode to a running service in the Amazon Web Services Cloud in seconds.\n\nYou don't need to learn new technologies, decide which compute service to use,\nor understand how to provision and configure Amazon Web Services resources.\n\nApp Runner connects directly to your container registry or source code\nrepository. It provides an automatic delivery pipeline with fully managed\noperations, high performance, scalability, and security.\n\nFor more information about App Runner, see the [App Runner Developer Guide](https://docs.aws.amazon.com/apprunner/latest/dg/). For release\ninformation, see the [App Runner Release Notes](https://docs.aws.amazon.com/apprunner/latest/relnotes/).\n\nTo install the Software Development Kits (SDKs), Integrated Development\nEnvironment (IDE) Toolkits, and command line tools that you can use to access\nthe API, see [Tools for Amazon Web Services](http://aws.amazon.com/tools/).","ref":"AWS.AppRunner.html","title":"AWS.AppRunner","type":"module"},{"doc":"For a list of Region-specific endpoints that App Runner supports, see [App\nRunner endpoints and\nquotas](https://docs.aws.amazon.com/general/latest/gr/apprunner.html) in the\n*Amazon Web Services General Reference*.","ref":"AWS.AppRunner.html#module-endpoints","title":"Endpoints - AWS.AppRunner","type":"module"},{"doc":"Associate your own domain name with the App Runner subdomain URL of your App\nRunner service.\n\nAfter you call `AssociateCustomDomain` and receive a successful response, use\nthe information in the `CustomDomain` record that's returned to add CNAME\nrecords to your Domain Name System (DNS). For each mapped domain name, add a\nmapping to the target App Runner subdomain and one or more certificate\nvalidation records. App Runner then performs DNS validation to verify that you\nown or control the domain name that you associated. App Runner tracks domain\nvalidity in a certificate stored in [AWS Certificate Manager (ACM)](https://docs.aws.amazon.com/acm/latest/userguide).","ref":"AWS.AppRunner.html#associate_custom_domain/3","title":"AWS.AppRunner.associate_custom_domain/3","type":"function"},{"doc":"Create an App Runner automatic scaling configuration resource.\n\nApp Runner requires this resource when you create or update App Runner services\nand you require non-default auto scaling settings. You can share an auto scaling\nconfiguration across multiple services.\n\nCreate multiple revisions of a configuration by calling this action multiple\ntimes using the same `AutoScalingConfigurationName`. The call returns\nincremental `AutoScalingConfigurationRevision` values. When you create a service\nand configure an auto scaling configuration resource, the service uses the\nlatest active revision of the auto scaling configuration by default. You can\noptionally configure the service to use a specific revision.\n\nConfigure a higher `MinSize` to increase the spread of your App Runner service\nover more Availability Zones in the Amazon Web Services Region. The tradeoff is\na higher minimal cost.\n\nConfigure a lower `MaxSize` to control your cost. The tradeoff is lower\nresponsiveness during peak demand.","ref":"AWS.AppRunner.html#create_auto_scaling_configuration/3","title":"AWS.AppRunner.create_auto_scaling_configuration/3","type":"function"},{"doc":"Create an App Runner connection resource.\n\nApp Runner requires a connection resource when you create App Runner services\nthat access private repositories from certain third-party providers. You can\nshare a connection across multiple services.\n\nA connection resource is needed to access GitHub and Bitbucket repositories.\nBoth require a user interface approval process through the App Runner console\nbefore you can use the connection.","ref":"AWS.AppRunner.html#create_connection/3","title":"AWS.AppRunner.create_connection/3","type":"function"},{"doc":"Create an App Runner observability configuration resource.\n\nApp Runner requires this resource when you create or update App Runner services\nand you want to enable non-default observability features. You can share an\nobservability configuration across multiple services.\n\nCreate multiple revisions of a configuration by calling this action multiple\ntimes using the same `ObservabilityConfigurationName`. The call returns\nincremental `ObservabilityConfigurationRevision` values. When you create a\nservice and configure an observability configuration resource, the service uses\nthe latest active revision of the observability configuration by default. You\ncan optionally configure the service to use a specific revision.\n\nThe observability configuration resource is designed to configure multiple\nfeatures (currently one feature, tracing). This action takes optional parameters\nthat describe the configuration of these features (currently one parameter,\n`TraceConfiguration`). If you don't specify a feature parameter, App Runner\ndoesn't enable the feature.","ref":"AWS.AppRunner.html#create_observability_configuration/3","title":"AWS.AppRunner.create_observability_configuration/3","type":"function"},{"doc":"Create an App Runner service.\n\nAfter the service is created, the action also automatically starts a deployment.\n\nThis is an asynchronous operation. On a successful call, you can use the\nreturned `OperationId` and the\n[ListOperations](https://docs.aws.amazon.com/apprunner/latest/api/API_ListOperations.html)\ncall to track the operation's progress.","ref":"AWS.AppRunner.html#create_service/3","title":"AWS.AppRunner.create_service/3","type":"function"},{"doc":"Create an App Runner VPC connector resource.\n\nApp Runner requires this resource when you want to associate your App Runner\nservice to a custom Amazon Virtual Private Cloud (Amazon VPC).","ref":"AWS.AppRunner.html#create_vpc_connector/3","title":"AWS.AppRunner.create_vpc_connector/3","type":"function"},{"doc":"Create an App Runner VPC Ingress Connection resource.\n\nApp Runner requires this resource when you want to associate your App Runner\nservice with an Amazon VPC endpoint.","ref":"AWS.AppRunner.html#create_vpc_ingress_connection/3","title":"AWS.AppRunner.create_vpc_ingress_connection/3","type":"function"},{"doc":"Delete an App Runner automatic scaling configuration resource.\n\nYou can delete a top level auto scaling configuration, a specific revision of\none, or all revisions associated with the top level configuration. You can't\ndelete the default auto scaling configuration or a configuration that's used by\none or more App Runner services.","ref":"AWS.AppRunner.html#delete_auto_scaling_configuration/3","title":"AWS.AppRunner.delete_auto_scaling_configuration/3","type":"function"},{"doc":"Delete an App Runner connection.\n\nYou must first ensure that there are no running App Runner services that use\nthis connection. If there are any, the `DeleteConnection` action fails.","ref":"AWS.AppRunner.html#delete_connection/3","title":"AWS.AppRunner.delete_connection/3","type":"function"},{"doc":"Delete an App Runner observability configuration resource.\n\nYou can delete a specific revision or the latest active revision. You can't\ndelete a configuration that's used by one or more App Runner services.","ref":"AWS.AppRunner.html#delete_observability_configuration/3","title":"AWS.AppRunner.delete_observability_configuration/3","type":"function"},{"doc":"Delete an App Runner service.\n\nThis is an asynchronous operation. On a successful call, you can use the\nreturned `OperationId` and the `ListOperations` call to track the operation's\nprogress.\n\nMake sure that you don't have any active VPCIngressConnections associated with\nthe service you want to delete.","ref":"AWS.AppRunner.html#delete_service/3","title":"AWS.AppRunner.delete_service/3","type":"function"},{"doc":"Delete an App Runner VPC connector resource.\n\nYou can't delete a connector that's used by one or more App Runner services.","ref":"AWS.AppRunner.html#delete_vpc_connector/3","title":"AWS.AppRunner.delete_vpc_connector/3","type":"function"},{"doc":"Delete an App Runner VPC Ingress Connection resource that's associated with an\nApp Runner service.\n\nThe VPC Ingress Connection must be in one of the following states to be deleted:\n\n  * `AVAILABLE`\n\n  * `FAILED_CREATION`\n\n  * `FAILED_UPDATE`\n\n  * `FAILED_DELETION`","ref":"AWS.AppRunner.html#delete_vpc_ingress_connection/3","title":"AWS.AppRunner.delete_vpc_ingress_connection/3","type":"function"},{"doc":"Return a full description of an App Runner automatic scaling configuration\nresource.","ref":"AWS.AppRunner.html#describe_auto_scaling_configuration/3","title":"AWS.AppRunner.describe_auto_scaling_configuration/3","type":"function"},{"doc":"Return a description of custom domain names that are associated with an App\nRunner service.","ref":"AWS.AppRunner.html#describe_custom_domains/3","title":"AWS.AppRunner.describe_custom_domains/3","type":"function"},{"doc":"Return a full description of an App Runner observability configuration resource.","ref":"AWS.AppRunner.html#describe_observability_configuration/3","title":"AWS.AppRunner.describe_observability_configuration/3","type":"function"},{"doc":"Return a full description of an App Runner service.","ref":"AWS.AppRunner.html#describe_service/3","title":"AWS.AppRunner.describe_service/3","type":"function"},{"doc":"Return a description of an App Runner VPC connector resource.","ref":"AWS.AppRunner.html#describe_vpc_connector/3","title":"AWS.AppRunner.describe_vpc_connector/3","type":"function"},{"doc":"Return a full description of an App Runner VPC Ingress Connection resource.","ref":"AWS.AppRunner.html#describe_vpc_ingress_connection/3","title":"AWS.AppRunner.describe_vpc_ingress_connection/3","type":"function"},{"doc":"Disassociate a custom domain name from an App Runner service.\n\nCertificates tracking domain validity are associated with a custom domain and\nare stored in [AWS Certificate Manager (ACM)](https://docs.aws.amazon.com/acm/latest/userguide). These certificates\naren't deleted as part of this action. App Runner delays certificate deletion\nfor 30 days after a domain is disassociated from your service.","ref":"AWS.AppRunner.html#disassociate_custom_domain/3","title":"AWS.AppRunner.disassociate_custom_domain/3","type":"function"},{"doc":"Returns a list of active App Runner automatic scaling configurations in your\nAmazon Web Services account.\n\nYou can query the revisions for a specific configuration name or the revisions\nfor all active configurations in your account. You can optionally query only the\nlatest revision of each requested name.\n\nTo retrieve a full description of a particular configuration revision, call and\nprovide one of the ARNs returned by `ListAutoScalingConfigurations`.","ref":"AWS.AppRunner.html#list_auto_scaling_configurations/3","title":"AWS.AppRunner.list_auto_scaling_configurations/3","type":"function"},{"doc":"Returns a list of App Runner connections that are associated with your Amazon\nWeb Services account.","ref":"AWS.AppRunner.html#list_connections/3","title":"AWS.AppRunner.list_connections/3","type":"function"},{"doc":"Returns a list of active App Runner observability configurations in your Amazon\nWeb Services account.\n\nYou can query the revisions for a specific configuration name or the revisions\nfor all active configurations in your account. You can optionally query only the\nlatest revision of each requested name.\n\nTo retrieve a full description of a particular configuration revision, call and\nprovide one of the ARNs returned by `ListObservabilityConfigurations`.","ref":"AWS.AppRunner.html#list_observability_configurations/3","title":"AWS.AppRunner.list_observability_configurations/3","type":"function"},{"doc":"Return a list of operations that occurred on an App Runner service.\n\nThe resulting list of `OperationSummary` objects is sorted in reverse\nchronological order. The first object on the list represents the last started\noperation.","ref":"AWS.AppRunner.html#list_operations/3","title":"AWS.AppRunner.list_operations/3","type":"function"},{"doc":"Returns a list of running App Runner services in your Amazon Web Services\naccount.","ref":"AWS.AppRunner.html#list_services/3","title":"AWS.AppRunner.list_services/3","type":"function"},{"doc":"Returns a list of the associated App Runner services using an auto scaling\nconfiguration.","ref":"AWS.AppRunner.html#list_services_for_auto_scaling_configuration/3","title":"AWS.AppRunner.list_services_for_auto_scaling_configuration/3","type":"function"},{"doc":"List tags that are associated with for an App Runner resource.\n\nThe response contains a list of tag key-value pairs.","ref":"AWS.AppRunner.html#list_tags_for_resource/3","title":"AWS.AppRunner.list_tags_for_resource/3","type":"function"},{"doc":"Returns a list of App Runner VPC connectors in your Amazon Web Services account.","ref":"AWS.AppRunner.html#list_vpc_connectors/3","title":"AWS.AppRunner.list_vpc_connectors/3","type":"function"},{"doc":"Return a list of App Runner VPC Ingress Connections in your Amazon Web Services\naccount.","ref":"AWS.AppRunner.html#list_vpc_ingress_connections/3","title":"AWS.AppRunner.list_vpc_ingress_connections/3","type":"function"},{"doc":"","ref":"AWS.AppRunner.html#metadata/0","title":"AWS.AppRunner.metadata/0","type":"function"},{"doc":"Pause an active App Runner service.\n\nApp Runner reduces compute capacity for the service to zero and loses state (for\nexample, ephemeral storage is removed).\n\nThis is an asynchronous operation. On a successful call, you can use the\nreturned `OperationId` and the `ListOperations` call to track the operation's\nprogress.","ref":"AWS.AppRunner.html#pause_service/3","title":"AWS.AppRunner.pause_service/3","type":"function"},{"doc":"Resume an active App Runner service.\n\nApp Runner provisions compute capacity for the service.\n\nThis is an asynchronous operation. On a successful call, you can use the\nreturned `OperationId` and the `ListOperations` call to track the operation's\nprogress.","ref":"AWS.AppRunner.html#resume_service/3","title":"AWS.AppRunner.resume_service/3","type":"function"},{"doc":"Initiate a manual deployment of the latest commit in a source code repository or\nthe latest image in a source image repository to an App Runner service.\n\nFor a source code repository, App Runner retrieves the commit and builds a\nDocker image. For a source image repository, App Runner retrieves the latest\nDocker image. In both cases, App Runner then deploys the new image to your\nservice and starts a new container instance.\n\nThis is an asynchronous operation. On a successful call, you can use the\nreturned `OperationId` and the `ListOperations` call to track the operation's\nprogress.","ref":"AWS.AppRunner.html#start_deployment/3","title":"AWS.AppRunner.start_deployment/3","type":"function"},{"doc":"Add tags to, or update the tag values of, an App Runner resource.\n\nA tag is a key-value pair.","ref":"AWS.AppRunner.html#tag_resource/3","title":"AWS.AppRunner.tag_resource/3","type":"function"},{"doc":"Remove tags from an App Runner resource.","ref":"AWS.AppRunner.html#untag_resource/3","title":"AWS.AppRunner.untag_resource/3","type":"function"},{"doc":"Update an auto scaling configuration to be the default.\n\nThe existing default auto scaling configuration will be set to non-default\nautomatically.","ref":"AWS.AppRunner.html#update_default_auto_scaling_configuration/3","title":"AWS.AppRunner.update_default_auto_scaling_configuration/3","type":"function"},{"doc":"Update an App Runner service.\n\nYou can update the source configuration and instance configuration of the\nservice. You can also update the ARN of the auto scaling configuration resource\nthat's associated with the service. However, you can't change the name or the\nencryption configuration of the service. These can be set only when you create\nthe service.\n\nTo update the tags applied to your service, use the separate actions\n`TagResource` and `UntagResource`.\n\nThis is an asynchronous operation. On a successful call, you can use the\nreturned `OperationId` and the `ListOperations` call to track the operation's\nprogress.","ref":"AWS.AppRunner.html#update_service/3","title":"AWS.AppRunner.update_service/3","type":"function"},{"doc":"Update an existing App Runner VPC Ingress Connection resource.\n\nThe VPC Ingress Connection must be in one of the following states to be updated:\n\n  * AVAILABLE\n\n  * FAILED_CREATION\n\n  * FAILED_UPDATE","ref":"AWS.AppRunner.html#update_vpc_ingress_connection/3","title":"AWS.AppRunner.update_vpc_ingress_connection/3","type":"function"},{"doc":"Amazon AppStream 2.0\n\nThis is the *Amazon AppStream 2.0 API Reference*.\n\nThis documentation provides descriptions and syntax for each of the actions and\ndata types in AppStream 2.0. AppStream 2.0 is a fully managed, secure\napplication streaming service that lets you stream desktop applications to users\nwithout rewriting applications. AppStream 2.0 manages the AWS resources that are\nrequired to host and run your applications, scales automatically, and provides\naccess to your users on demand.\n\nYou can call the AppStream 2.0 API operations by using an interface VPC endpoint\n(interface endpoint). For more information, see [Access AppStream 2.0 API Operations and CLI Commands Through an Interface VPC\nEndpoint](https://docs.aws.amazon.com/appstream2/latest/developerguide/access-api-cli-through-interface-vpc-endpoint.html)\nin the *Amazon AppStream 2.0 Administration Guide*.\n\nTo learn more about AppStream 2.0, see the following resources:\n\n  * [Amazon AppStream 2.0 product page](http://aws.amazon.com/appstream2)\n\n  * [Amazon AppStream 2.0 documentation](http://aws.amazon.com/documentation/appstream2)","ref":"AWS.AppStream.html","title":"AWS.AppStream","type":"module"},{"doc":"Associates the specified app block builder with the specified app block.","ref":"AWS.AppStream.html#associate_app_block_builder_app_block/3","title":"AWS.AppStream.associate_app_block_builder_app_block/3","type":"function"},{"doc":"Associates the specified application with the specified fleet.\n\nThis is only supported for Elastic fleets.","ref":"AWS.AppStream.html#associate_application_fleet/3","title":"AWS.AppStream.associate_application_fleet/3","type":"function"},{"doc":"Associates an application to entitle.","ref":"AWS.AppStream.html#associate_application_to_entitlement/3","title":"AWS.AppStream.associate_application_to_entitlement/3","type":"function"},{"doc":"Associates the specified fleet with the specified stack.","ref":"AWS.AppStream.html#associate_fleet/3","title":"AWS.AppStream.associate_fleet/3","type":"function"},{"doc":"Associates the specified users with the specified stacks.\n\nUsers in a user pool cannot be assigned to stacks with fleets that are joined to\nan Active Directory domain.","ref":"AWS.AppStream.html#batch_associate_user_stack/3","title":"AWS.AppStream.batch_associate_user_stack/3","type":"function"},{"doc":"Disassociates the specified users from the specified stacks.","ref":"AWS.AppStream.html#batch_disassociate_user_stack/3","title":"AWS.AppStream.batch_disassociate_user_stack/3","type":"function"},{"doc":"Copies the image within the same region or to a new region within the same AWS\naccount.\n\nNote that any tags you added to the image will not be copied.","ref":"AWS.AppStream.html#copy_image/3","title":"AWS.AppStream.copy_image/3","type":"function"},{"doc":"Creates an app block.\n\nApp blocks are an Amazon AppStream 2.0 resource that stores the details about\nthe virtual hard disk in an S3 bucket. It also stores the setup script with\ndetails about how to mount the virtual hard disk. The virtual hard disk includes\nthe application binaries and other files necessary to launch your applications.\nMultiple applications can be assigned to a single app block.\n\nThis is only supported for Elastic fleets.","ref":"AWS.AppStream.html#create_app_block/3","title":"AWS.AppStream.create_app_block/3","type":"function"},{"doc":"Creates an app block builder.","ref":"AWS.AppStream.html#create_app_block_builder/3","title":"AWS.AppStream.create_app_block_builder/3","type":"function"},{"doc":"Creates a URL to start a create app block builder streaming session.","ref":"AWS.AppStream.html#create_app_block_builder_streaming_url/3","title":"AWS.AppStream.create_app_block_builder_streaming_url/3","type":"function"},{"doc":"Creates an application.\n\nApplications are an Amazon AppStream 2.0 resource that stores the details about\nhow to launch applications on Elastic fleet streaming instances. An application\nconsists of the launch details, icon, and display name. Applications are\nassociated with an app block that contains the application binaries and other\nfiles. The applications assigned to an Elastic fleet are the applications users\ncan launch.\n\nThis is only supported for Elastic fleets.","ref":"AWS.AppStream.html#create_application/3","title":"AWS.AppStream.create_application/3","type":"function"},{"doc":"Creates a Directory Config object in AppStream 2.0.\n\nThis object includes the configuration information required to join fleets and\nimage builders to Microsoft Active Directory domains.","ref":"AWS.AppStream.html#create_directory_config/3","title":"AWS.AppStream.create_directory_config/3","type":"function"},{"doc":"Creates a new entitlement.\n\nEntitlements control access to specific applications within a stack, based on\nuser attributes. Entitlements apply to SAML 2.0 federated user identities.\nAmazon AppStream 2.0 user pool and streaming URL users are entitled to all\napplications in a stack. Entitlements don't apply to the desktop stream view\napplication, or to applications managed by a dynamic app provider using the\nDynamic Application Framework.","ref":"AWS.AppStream.html#create_entitlement/3","title":"AWS.AppStream.create_entitlement/3","type":"function"},{"doc":"Creates a fleet.\n\nA fleet consists of streaming instances that your users access for their\napplications and desktops.","ref":"AWS.AppStream.html#create_fleet/3","title":"AWS.AppStream.create_fleet/3","type":"function"},{"doc":"Creates an image builder.\n\nAn image builder is a virtual machine that is used to create an image.\n\nThe initial state of the builder is `PENDING`. When it is ready, the state is\n`RUNNING`.","ref":"AWS.AppStream.html#create_image_builder/3","title":"AWS.AppStream.create_image_builder/3","type":"function"},{"doc":"Creates a URL to start an image builder streaming session.","ref":"AWS.AppStream.html#create_image_builder_streaming_url/3","title":"AWS.AppStream.create_image_builder_streaming_url/3","type":"function"},{"doc":"Creates a stack to start streaming applications to users.\n\nA stack consists of an associated fleet, user access policies, and storage\nconfigurations.","ref":"AWS.AppStream.html#create_stack/3","title":"AWS.AppStream.create_stack/3","type":"function"},{"doc":"Creates a temporary URL to start an AppStream 2.0 streaming session for the\nspecified user.\n\nA streaming URL enables application streaming to be tested without user setup.","ref":"AWS.AppStream.html#create_streaming_url/3","title":"AWS.AppStream.create_streaming_url/3","type":"function"},{"doc":"Creates a new image with the latest Windows operating system updates, driver\nupdates, and AppStream 2.0 agent software.\n\nFor more information, see the \"Update an Image by Using Managed AppStream 2.0\nImage Updates\" section in [Administer Your AppStream 2.0 Images](https://docs.aws.amazon.com/appstream2/latest/developerguide/administer-images.html),\nin the *Amazon AppStream 2.0 Administration Guide*.","ref":"AWS.AppStream.html#create_updated_image/3","title":"AWS.AppStream.create_updated_image/3","type":"function"},{"doc":"Creates a usage report subscription.\n\nUsage reports are generated daily.","ref":"AWS.AppStream.html#create_usage_report_subscription/3","title":"AWS.AppStream.create_usage_report_subscription/3","type":"function"},{"doc":"Creates a new user in the user pool.","ref":"AWS.AppStream.html#create_user/3","title":"AWS.AppStream.create_user/3","type":"function"},{"doc":"Deletes an app block.","ref":"AWS.AppStream.html#delete_app_block/3","title":"AWS.AppStream.delete_app_block/3","type":"function"},{"doc":"Deletes an app block builder.\n\nAn app block builder can only be deleted when it has no association with an app\nblock.","ref":"AWS.AppStream.html#delete_app_block_builder/3","title":"AWS.AppStream.delete_app_block_builder/3","type":"function"},{"doc":"Deletes an application.","ref":"AWS.AppStream.html#delete_application/3","title":"AWS.AppStream.delete_application/3","type":"function"},{"doc":"Deletes the specified Directory Config object from AppStream 2.0.\n\nThis object includes the information required to join streaming instances to an\nActive Directory domain.","ref":"AWS.AppStream.html#delete_directory_config/3","title":"AWS.AppStream.delete_directory_config/3","type":"function"},{"doc":"Deletes the specified entitlement.","ref":"AWS.AppStream.html#delete_entitlement/3","title":"AWS.AppStream.delete_entitlement/3","type":"function"},{"doc":"Deletes the specified fleet.","ref":"AWS.AppStream.html#delete_fleet/3","title":"AWS.AppStream.delete_fleet/3","type":"function"},{"doc":"Deletes the specified image.\n\nYou cannot delete an image when it is in use. After you delete an image, you\ncannot provision new capacity using the image.","ref":"AWS.AppStream.html#delete_image/3","title":"AWS.AppStream.delete_image/3","type":"function"},{"doc":"Deletes the specified image builder and releases the capacity.","ref":"AWS.AppStream.html#delete_image_builder/3","title":"AWS.AppStream.delete_image_builder/3","type":"function"},{"doc":"Deletes permissions for the specified private image.\n\nAfter you delete permissions for an image, AWS accounts to which you previously\ngranted these permissions can no longer use the image.","ref":"AWS.AppStream.html#delete_image_permissions/3","title":"AWS.AppStream.delete_image_permissions/3","type":"function"},{"doc":"Deletes the specified stack.\n\nAfter the stack is deleted, the application streaming environment provided by\nthe stack is no longer available to users. Also, any reservations made for\napplication streaming sessions for the stack are released.","ref":"AWS.AppStream.html#delete_stack/3","title":"AWS.AppStream.delete_stack/3","type":"function"},{"doc":"Disables usage report generation.","ref":"AWS.AppStream.html#delete_usage_report_subscription/3","title":"AWS.AppStream.delete_usage_report_subscription/3","type":"function"},{"doc":"Deletes a user from the user pool.","ref":"AWS.AppStream.html#delete_user/3","title":"AWS.AppStream.delete_user/3","type":"function"},{"doc":"Retrieves a list that describes one or more app block builder associations.","ref":"AWS.AppStream.html#describe_app_block_builder_app_block_associations/3","title":"AWS.AppStream.describe_app_block_builder_app_block_associations/3","type":"function"},{"doc":"Retrieves a list that describes one or more app block builders.","ref":"AWS.AppStream.html#describe_app_block_builders/3","title":"AWS.AppStream.describe_app_block_builders/3","type":"function"},{"doc":"Retrieves a list that describes one or more app blocks.","ref":"AWS.AppStream.html#describe_app_blocks/3","title":"AWS.AppStream.describe_app_blocks/3","type":"function"},{"doc":"Retrieves a list that describes one or more application fleet associations.\n\nEither ApplicationArn or FleetName must be specified.","ref":"AWS.AppStream.html#describe_application_fleet_associations/3","title":"AWS.AppStream.describe_application_fleet_associations/3","type":"function"},{"doc":"Retrieves a list that describes one or more applications.","ref":"AWS.AppStream.html#describe_applications/3","title":"AWS.AppStream.describe_applications/3","type":"function"},{"doc":"Retrieves a list that describes one or more specified Directory Config objects\nfor AppStream 2.0, if the names for these objects are provided.\n\nOtherwise, all Directory Config objects in the account are described. These\nobjects include the configuration information required to join fleets and image\nbuilders to Microsoft Active Directory domains.\n\nAlthough the response syntax in this topic includes the account password, this\npassword is not returned in the actual response.","ref":"AWS.AppStream.html#describe_directory_configs/3","title":"AWS.AppStream.describe_directory_configs/3","type":"function"},{"doc":"Retrieves a list that describes one of more entitlements.","ref":"AWS.AppStream.html#describe_entitlements/3","title":"AWS.AppStream.describe_entitlements/3","type":"function"},{"doc":"Retrieves a list that describes one or more specified fleets, if the fleet names\nare provided.\n\nOtherwise, all fleets in the account are described.","ref":"AWS.AppStream.html#describe_fleets/3","title":"AWS.AppStream.describe_fleets/3","type":"function"},{"doc":"Retrieves a list that describes one or more specified image builders, if the\nimage builder names are provided.\n\nOtherwise, all image builders in the account are described.","ref":"AWS.AppStream.html#describe_image_builders/3","title":"AWS.AppStream.describe_image_builders/3","type":"function"},{"doc":"Retrieves a list that describes the permissions for shared AWS account IDs on a\nprivate image that you own.","ref":"AWS.AppStream.html#describe_image_permissions/3","title":"AWS.AppStream.describe_image_permissions/3","type":"function"},{"doc":"Retrieves a list that describes one or more specified images, if the image names\nor image ARNs are provided.\n\nOtherwise, all images in the account are described.","ref":"AWS.AppStream.html#describe_images/3","title":"AWS.AppStream.describe_images/3","type":"function"},{"doc":"Retrieves a list that describes the streaming sessions for a specified stack and\nfleet.\n\nIf a UserId is provided for the stack and fleet, only streaming sessions for\nthat user are described. If an authentication type is not provided, the default\nis to authenticate users using a streaming URL.","ref":"AWS.AppStream.html#describe_sessions/3","title":"AWS.AppStream.describe_sessions/3","type":"function"},{"doc":"Retrieves a list that describes one or more specified stacks, if the stack names\nare provided.\n\nOtherwise, all stacks in the account are described.","ref":"AWS.AppStream.html#describe_stacks/3","title":"AWS.AppStream.describe_stacks/3","type":"function"},{"doc":"Retrieves a list that describes one or more usage report subscriptions.","ref":"AWS.AppStream.html#describe_usage_report_subscriptions/3","title":"AWS.AppStream.describe_usage_report_subscriptions/3","type":"function"},{"doc":"Retrieves a list that describes the UserStackAssociation objects.\n\nYou must specify either or both of the following:\n\n  * The stack name\n\n  * The user name (email address of the user associated with the\nstack) and the authentication type for the user","ref":"AWS.AppStream.html#describe_user_stack_associations/3","title":"AWS.AppStream.describe_user_stack_associations/3","type":"function"},{"doc":"Retrieves a list that describes one or more specified users in the user pool.","ref":"AWS.AppStream.html#describe_users/3","title":"AWS.AppStream.describe_users/3","type":"function"},{"doc":"Disables the specified user in the user pool.\n\nUsers can't sign in to AppStream 2.0 until they are re-enabled. This action does\nnot delete the user.","ref":"AWS.AppStream.html#disable_user/3","title":"AWS.AppStream.disable_user/3","type":"function"},{"doc":"Disassociates a specified app block builder from a specified app block.","ref":"AWS.AppStream.html#disassociate_app_block_builder_app_block/3","title":"AWS.AppStream.disassociate_app_block_builder_app_block/3","type":"function"},{"doc":"Disassociates the specified application from the fleet.","ref":"AWS.AppStream.html#disassociate_application_fleet/3","title":"AWS.AppStream.disassociate_application_fleet/3","type":"function"},{"doc":"Deletes the specified application from the specified entitlement.","ref":"AWS.AppStream.html#disassociate_application_from_entitlement/3","title":"AWS.AppStream.disassociate_application_from_entitlement/3","type":"function"},{"doc":"Disassociates the specified fleet from the specified stack.","ref":"AWS.AppStream.html#disassociate_fleet/3","title":"AWS.AppStream.disassociate_fleet/3","type":"function"},{"doc":"Enables a user in the user pool.\n\nAfter being enabled, users can sign in to AppStream 2.0 and open applications\nfrom the stacks to which they are assigned.","ref":"AWS.AppStream.html#enable_user/3","title":"AWS.AppStream.enable_user/3","type":"function"},{"doc":"Immediately stops the specified streaming session.","ref":"AWS.AppStream.html#expire_session/3","title":"AWS.AppStream.expire_session/3","type":"function"},{"doc":"Retrieves the name of the fleet that is associated with the specified stack.","ref":"AWS.AppStream.html#list_associated_fleets/3","title":"AWS.AppStream.list_associated_fleets/3","type":"function"},{"doc":"Retrieves the name of the stack with which the specified fleet is associated.","ref":"AWS.AppStream.html#list_associated_stacks/3","title":"AWS.AppStream.list_associated_stacks/3","type":"function"},{"doc":"Retrieves a list of entitled applications.","ref":"AWS.AppStream.html#list_entitled_applications/3","title":"AWS.AppStream.list_entitled_applications/3","type":"function"},{"doc":"Retrieves a list of all tags for the specified AppStream 2.0 resource.\n\nYou can tag AppStream 2.0 image builders, images, fleets, and stacks.\n\nFor more information about tags, see [Tagging Your Resources](https://docs.aws.amazon.com/appstream2/latest/developerguide/tagging-basic.html)\nin the *Amazon AppStream 2.0 Administration Guide*.","ref":"AWS.AppStream.html#list_tags_for_resource/3","title":"AWS.AppStream.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.AppStream.html#metadata/0","title":"AWS.AppStream.metadata/0","type":"function"},{"doc":"Starts an app block builder.\n\nAn app block builder can only be started when it's associated with an app block.\n\nStarting an app block builder starts a new instance, which is equivalent to an\nelastic fleet instance with application builder assistance functionality.","ref":"AWS.AppStream.html#start_app_block_builder/3","title":"AWS.AppStream.start_app_block_builder/3","type":"function"},{"doc":"Starts the specified fleet.","ref":"AWS.AppStream.html#start_fleet/3","title":"AWS.AppStream.start_fleet/3","type":"function"},{"doc":"Starts the specified image builder.","ref":"AWS.AppStream.html#start_image_builder/3","title":"AWS.AppStream.start_image_builder/3","type":"function"},{"doc":"Stops an app block builder.\n\nStopping an app block builder terminates the instance, and the instance state is\nnot persisted.","ref":"AWS.AppStream.html#stop_app_block_builder/3","title":"AWS.AppStream.stop_app_block_builder/3","type":"function"},{"doc":"Stops the specified fleet.","ref":"AWS.AppStream.html#stop_fleet/3","title":"AWS.AppStream.stop_fleet/3","type":"function"},{"doc":"Stops the specified image builder.","ref":"AWS.AppStream.html#stop_image_builder/3","title":"AWS.AppStream.stop_image_builder/3","type":"function"},{"doc":"Adds or overwrites one or more tags for the specified AppStream 2.0 resource.\n\nYou can tag AppStream 2.0 image builders, images, fleets, and stacks.\n\nEach tag consists of a key and an optional value. If a resource already has a\ntag with the same key, this operation updates its value.\n\nTo list the current tags for your resources, use `ListTagsForResource`. To\ndisassociate tags from your resources, use `UntagResource`.\n\nFor more information about tags, see [Tagging Your Resources](https://docs.aws.amazon.com/appstream2/latest/developerguide/tagging-basic.html)\nin the *Amazon AppStream 2.0 Administration Guide*.","ref":"AWS.AppStream.html#tag_resource/3","title":"AWS.AppStream.tag_resource/3","type":"function"},{"doc":"Disassociates one or more specified tags from the specified AppStream 2.0\nresource.\n\nTo list the current tags for your resources, use `ListTagsForResource`.\n\nFor more information about tags, see [Tagging Your Resources](https://docs.aws.amazon.com/appstream2/latest/developerguide/tagging-basic.html)\nin the *Amazon AppStream 2.0 Administration Guide*.","ref":"AWS.AppStream.html#untag_resource/3","title":"AWS.AppStream.untag_resource/3","type":"function"},{"doc":"Updates an app block builder.\n\nIf the app block builder is in the `STARTING` or `STOPPING` state, you can't\nupdate it. If the app block builder is in the `RUNNING` state, you can only\nupdate the DisplayName and Description. If the app block builder is in the\n`STOPPED` state, you can update any attribute except the Name.","ref":"AWS.AppStream.html#update_app_block_builder/3","title":"AWS.AppStream.update_app_block_builder/3","type":"function"},{"doc":"Updates the specified application.","ref":"AWS.AppStream.html#update_application/3","title":"AWS.AppStream.update_application/3","type":"function"},{"doc":"Updates the specified Directory Config object in AppStream 2.0.\n\nThis object includes the configuration information required to join fleets and\nimage builders to Microsoft Active Directory domains.","ref":"AWS.AppStream.html#update_directory_config/3","title":"AWS.AppStream.update_directory_config/3","type":"function"},{"doc":"Updates the specified entitlement.","ref":"AWS.AppStream.html#update_entitlement/3","title":"AWS.AppStream.update_entitlement/3","type":"function"},{"doc":"Updates the specified fleet.\n\nIf the fleet is in the `STOPPED` state, you can update any attribute except the\nfleet name.\n\nIf the fleet is in the `RUNNING` state, you can update the following based on\nthe fleet type:\n\n  * Always-On and On-Demand fleet types\n\nYou can update the `DisplayName`, `ComputeCapacity`, `ImageARN`, `ImageName`,\n`IdleDisconnectTimeoutInSeconds`, and `DisconnectTimeoutInSeconds` attributes.\n\n  * Elastic fleet type\n\nYou can update the `DisplayName`, `IdleDisconnectTimeoutInSeconds`,\n`DisconnectTimeoutInSeconds`, `MaxConcurrentSessions`, `SessionScriptS3Location`\nand `UsbDeviceFilterStrings` attributes.\n\nIf the fleet is in the `STARTING` or `STOPPED` state, you can't update it.","ref":"AWS.AppStream.html#update_fleet/3","title":"AWS.AppStream.update_fleet/3","type":"function"},{"doc":"Adds or updates permissions for the specified private image.","ref":"AWS.AppStream.html#update_image_permissions/3","title":"AWS.AppStream.update_image_permissions/3","type":"function"},{"doc":"Updates the specified fields for the specified stack.","ref":"AWS.AppStream.html#update_stack/3","title":"AWS.AppStream.update_stack/3","type":"function"},{"doc":"AppSync provides API actions for creating and interacting with data sources\nusing GraphQL from your application.","ref":"AWS.AppSync.html","title":"AWS.AppSync","type":"module"},{"doc":"Maps an endpoint to your custom domain.","ref":"AWS.AppSync.html#associate_api/4","title":"AWS.AppSync.associate_api/4","type":"function"},{"doc":"Creates an association between a Merged API and source API using the source\nAPI's identifier.","ref":"AWS.AppSync.html#associate_merged_graphql_api/4","title":"AWS.AppSync.associate_merged_graphql_api/4","type":"function"},{"doc":"Creates an association between a Merged API and source API using the Merged\nAPI's identifier.","ref":"AWS.AppSync.html#associate_source_graphql_api/4","title":"AWS.AppSync.associate_source_graphql_api/4","type":"function"},{"doc":"Creates a cache for the GraphQL API.","ref":"AWS.AppSync.html#create_api_cache/4","title":"AWS.AppSync.create_api_cache/4","type":"function"},{"doc":"Creates a unique key that you can distribute to clients who invoke your API.","ref":"AWS.AppSync.html#create_api_key/4","title":"AWS.AppSync.create_api_key/4","type":"function"},{"doc":"Creates a `DataSource` object.","ref":"AWS.AppSync.html#create_data_source/4","title":"AWS.AppSync.create_data_source/4","type":"function"},{"doc":"Creates a custom `DomainName` object.","ref":"AWS.AppSync.html#create_domain_name/3","title":"AWS.AppSync.create_domain_name/3","type":"function"},{"doc":"Creates a `Function` object.\n\nA function is a reusable entity. You can use multiple functions to compose the\nresolver logic.","ref":"AWS.AppSync.html#create_function/4","title":"AWS.AppSync.create_function/4","type":"function"},{"doc":"Creates a `GraphqlApi` object.","ref":"AWS.AppSync.html#create_graphql_api/3","title":"AWS.AppSync.create_graphql_api/3","type":"function"},{"doc":"Creates a `Resolver` object.\n\nA resolver converts incoming requests into a format that a data source can\nunderstand, and converts the data source's responses into GraphQL.","ref":"AWS.AppSync.html#create_resolver/5","title":"AWS.AppSync.create_resolver/5","type":"function"},{"doc":"Creates a `Type` object.","ref":"AWS.AppSync.html#create_type/4","title":"AWS.AppSync.create_type/4","type":"function"},{"doc":"Deletes an `ApiCache` object.","ref":"AWS.AppSync.html#delete_api_cache/4","title":"AWS.AppSync.delete_api_cache/4","type":"function"},{"doc":"Deletes an API key.","ref":"AWS.AppSync.html#delete_api_key/5","title":"AWS.AppSync.delete_api_key/5","type":"function"},{"doc":"Deletes a `DataSource` object.","ref":"AWS.AppSync.html#delete_data_source/5","title":"AWS.AppSync.delete_data_source/5","type":"function"},{"doc":"Deletes a custom `DomainName` object.","ref":"AWS.AppSync.html#delete_domain_name/4","title":"AWS.AppSync.delete_domain_name/4","type":"function"},{"doc":"Deletes a `Function`.","ref":"AWS.AppSync.html#delete_function/5","title":"AWS.AppSync.delete_function/5","type":"function"},{"doc":"Deletes a `GraphqlApi` object.","ref":"AWS.AppSync.html#delete_graphql_api/4","title":"AWS.AppSync.delete_graphql_api/4","type":"function"},{"doc":"Deletes a `Resolver` object.","ref":"AWS.AppSync.html#delete_resolver/6","title":"AWS.AppSync.delete_resolver/6","type":"function"},{"doc":"Deletes a `Type` object.","ref":"AWS.AppSync.html#delete_type/5","title":"AWS.AppSync.delete_type/5","type":"function"},{"doc":"Removes an `ApiAssociation` object from a custom domain.","ref":"AWS.AppSync.html#disassociate_api/4","title":"AWS.AppSync.disassociate_api/4","type":"function"},{"doc":"Deletes an association between a Merged API and source API using the source\nAPI's identifier and the association ID.","ref":"AWS.AppSync.html#disassociate_merged_graphql_api/5","title":"AWS.AppSync.disassociate_merged_graphql_api/5","type":"function"},{"doc":"Deletes an association between a Merged API and source API using the Merged\nAPI's identifier and the association ID.","ref":"AWS.AppSync.html#disassociate_source_graphql_api/5","title":"AWS.AppSync.disassociate_source_graphql_api/5","type":"function"},{"doc":"Evaluates the given code and returns the response.\n\nThe code definition requirements depend on the specified runtime. For\n`APPSYNC_JS` runtimes, the code defines the request and response functions. The\nrequest function takes the incoming request after a GraphQL operation is parsed\nand converts it into a request configuration for the selected data source\noperation. The response function interprets responses from the data source and\nmaps it to the shape of the GraphQL field output type.","ref":"AWS.AppSync.html#evaluate_code/3","title":"AWS.AppSync.evaluate_code/3","type":"function"},{"doc":"Evaluates a given template and returns the response.\n\nThe mapping template can be a request or response template.\n\nRequest templates take the incoming request after a GraphQL operation is parsed\nand convert it into a request configuration for the selected data source\noperation. Response templates interpret responses from the data source and map\nit to the shape of the GraphQL field output type.\n\nMapping templates are written in the Apache Velocity Template Language (VTL).","ref":"AWS.AppSync.html#evaluate_mapping_template/3","title":"AWS.AppSync.evaluate_mapping_template/3","type":"function"},{"doc":"Flushes an `ApiCache` object.","ref":"AWS.AppSync.html#flush_api_cache/4","title":"AWS.AppSync.flush_api_cache/4","type":"function"},{"doc":"Retrieves an `ApiAssociation` object.","ref":"AWS.AppSync.html#get_api_association/3","title":"AWS.AppSync.get_api_association/3","type":"function"},{"doc":"Retrieves an `ApiCache` object.","ref":"AWS.AppSync.html#get_api_cache/3","title":"AWS.AppSync.get_api_cache/3","type":"function"},{"doc":"Retrieves a `DataSource` object.","ref":"AWS.AppSync.html#get_data_source/4","title":"AWS.AppSync.get_data_source/4","type":"function"},{"doc":"Retrieves the record of an existing introspection.\n\nIf the retrieval is successful, the result of the instrospection will also be\nreturned. If the retrieval fails the operation, an error message will be\nreturned instead.","ref":"AWS.AppSync.html#get_data_source_introspection/6","title":"AWS.AppSync.get_data_source_introspection/6","type":"function"},{"doc":"Retrieves a custom `DomainName` object.","ref":"AWS.AppSync.html#get_domain_name/3","title":"AWS.AppSync.get_domain_name/3","type":"function"},{"doc":"Get a `Function`.","ref":"AWS.AppSync.html#get_function/4","title":"AWS.AppSync.get_function/4","type":"function"},{"doc":"Retrieves a `GraphqlApi` object.","ref":"AWS.AppSync.html#get_graphql_api/3","title":"AWS.AppSync.get_graphql_api/3","type":"function"},{"doc":"Retrieves the list of environmental variable key-value pairs associated with an\nAPI by its ID value.","ref":"AWS.AppSync.html#get_graphql_api_environment_variables/3","title":"AWS.AppSync.get_graphql_api_environment_variables/3","type":"function"},{"doc":"Retrieves the introspection schema for a GraphQL API.","ref":"AWS.AppSync.html#get_introspection_schema/5","title":"AWS.AppSync.get_introspection_schema/5","type":"function"},{"doc":"Retrieves a `Resolver` object.","ref":"AWS.AppSync.html#get_resolver/5","title":"AWS.AppSync.get_resolver/5","type":"function"},{"doc":"Retrieves the current status of a schema creation operation.","ref":"AWS.AppSync.html#get_schema_creation_status/3","title":"AWS.AppSync.get_schema_creation_status/3","type":"function"},{"doc":"Retrieves a `SourceApiAssociation` object.","ref":"AWS.AppSync.html#get_source_api_association/4","title":"AWS.AppSync.get_source_api_association/4","type":"function"},{"doc":"Retrieves a `Type` object.","ref":"AWS.AppSync.html#get_type/5","title":"AWS.AppSync.get_type/5","type":"function"},{"doc":"Lists the API keys for a given API.\n\nAPI keys are deleted automatically 60 days after they expire. However, they may\nstill be included in the response until they have actually been deleted. You can\nsafely call `DeleteApiKey` to manually delete a key before it's automatically\ndeleted.","ref":"AWS.AppSync.html#list_api_keys/5","title":"AWS.AppSync.list_api_keys/5","type":"function"},{"doc":"Lists the data sources for a given API.","ref":"AWS.AppSync.html#list_data_sources/5","title":"AWS.AppSync.list_data_sources/5","type":"function"},{"doc":"Lists multiple custom domain names.","ref":"AWS.AppSync.html#list_domain_names/4","title":"AWS.AppSync.list_domain_names/4","type":"function"},{"doc":"List multiple functions.","ref":"AWS.AppSync.html#list_functions/5","title":"AWS.AppSync.list_functions/5","type":"function"},{"doc":"Lists your GraphQL APIs.","ref":"AWS.AppSync.html#list_graphql_apis/6","title":"AWS.AppSync.list_graphql_apis/6","type":"function"},{"doc":"Lists the resolvers for a given API and type.","ref":"AWS.AppSync.html#list_resolvers/6","title":"AWS.AppSync.list_resolvers/6","type":"function"},{"doc":"List the resolvers that are associated with a specific function.","ref":"AWS.AppSync.html#list_resolvers_by_function/6","title":"AWS.AppSync.list_resolvers_by_function/6","type":"function"},{"doc":"Lists the `SourceApiAssociationSummary` data.","ref":"AWS.AppSync.html#list_source_api_associations/5","title":"AWS.AppSync.list_source_api_associations/5","type":"function"},{"doc":"Lists the tags for a resource.","ref":"AWS.AppSync.html#list_tags_for_resource/3","title":"AWS.AppSync.list_tags_for_resource/3","type":"function"},{"doc":"Lists the types for a given API.","ref":"AWS.AppSync.html#list_types/6","title":"AWS.AppSync.list_types/6","type":"function"},{"doc":"Lists `Type` objects by the source API association ID.","ref":"AWS.AppSync.html#list_types_by_association/7","title":"AWS.AppSync.list_types_by_association/7","type":"function"},{"doc":"","ref":"AWS.AppSync.html#metadata/0","title":"AWS.AppSync.metadata/0","type":"function"},{"doc":"Creates a list of environmental variables in an API by its ID value.\n\nWhen creating an environmental variable, it must follow the constraints below:\n\n  * Both JavaScript and VTL templates support environmental variables.\n\n  * Environmental variables are not evaluated before function\ninvocation.\n\n  * Environmental variables only support string values.\n\n  * Any defined value in an environmental variable is considered a\nstring literal and not expanded.\n\n  * Variable evaluations should ideally be performed in the function\ncode.\n\nWhen creating an environmental variable key-value pair, it must follow the\nadditional constraints below:\n\n  * Keys must begin with a letter.\n\n  * Keys must be at least two characters long.\n\n  * Keys can only contain letters, numbers, and the underscore\ncharacter (_).\n\n  * Values can be up to 512 characters long.\n\n  * You can configure up to 50 key-value pairs in a GraphQL API.\n\nYou can create a list of environmental variables by adding it to the\n`environmentVariables` payload as a list in the format\n`{\"key1\":\"value1\",\"key2\":\"value2\", …}`. Note that each call of the\n`PutGraphqlApiEnvironmentVariables` action will result in the overwriting of the\nexisting environmental variable list of that API. This means the existing\nenvironmental variables will be lost. To avoid this, you must include all\nexisting and new environmental variables in the list each time you call this\naction.","ref":"AWS.AppSync.html#put_graphql_api_environment_variables/4","title":"AWS.AppSync.put_graphql_api_environment_variables/4","type":"function"},{"doc":"Creates a new introspection.\n\nReturns the `introspectionId` of the new introspection after its creation.","ref":"AWS.AppSync.html#start_data_source_introspection/3","title":"AWS.AppSync.start_data_source_introspection/3","type":"function"},{"doc":"Adds a new schema to your GraphQL API.\n\nThis operation is asynchronous. Use to determine when it has completed.","ref":"AWS.AppSync.html#start_schema_creation/4","title":"AWS.AppSync.start_schema_creation/4","type":"function"},{"doc":"Initiates a merge operation.\n\nReturns a status that shows the result of the merge operation.","ref":"AWS.AppSync.html#start_schema_merge/5","title":"AWS.AppSync.start_schema_merge/5","type":"function"},{"doc":"Tags a resource with user-supplied tags.","ref":"AWS.AppSync.html#tag_resource/4","title":"AWS.AppSync.tag_resource/4","type":"function"},{"doc":"Untags a resource.","ref":"AWS.AppSync.html#untag_resource/4","title":"AWS.AppSync.untag_resource/4","type":"function"},{"doc":"Updates the cache for the GraphQL API.","ref":"AWS.AppSync.html#update_api_cache/4","title":"AWS.AppSync.update_api_cache/4","type":"function"},{"doc":"Updates an API key.\n\nYou can update the key as long as it's not deleted.","ref":"AWS.AppSync.html#update_api_key/5","title":"AWS.AppSync.update_api_key/5","type":"function"},{"doc":"Updates a `DataSource` object.","ref":"AWS.AppSync.html#update_data_source/5","title":"AWS.AppSync.update_data_source/5","type":"function"},{"doc":"Updates a custom `DomainName` object.","ref":"AWS.AppSync.html#update_domain_name/4","title":"AWS.AppSync.update_domain_name/4","type":"function"},{"doc":"Updates a `Function` object.","ref":"AWS.AppSync.html#update_function/5","title":"AWS.AppSync.update_function/5","type":"function"},{"doc":"Updates a `GraphqlApi` object.","ref":"AWS.AppSync.html#update_graphql_api/4","title":"AWS.AppSync.update_graphql_api/4","type":"function"},{"doc":"Updates a `Resolver` object.","ref":"AWS.AppSync.html#update_resolver/6","title":"AWS.AppSync.update_resolver/6","type":"function"},{"doc":"Updates some of the configuration choices of a particular source API\nassociation.","ref":"AWS.AppSync.html#update_source_api_association/5","title":"AWS.AppSync.update_source_api_association/5","type":"function"},{"doc":"Updates a `Type` object.","ref":"AWS.AppSync.html#update_type/5","title":"AWS.AppSync.update_type/5","type":"function"},{"doc":"Welcome to the Amazon AppFlow API reference.\n\nThis guide is for developers who need detailed information about the Amazon\nAppFlow API operations, data types, and errors.\n\nAmazon AppFlow is a fully managed integration service that enables you to\nsecurely transfer data between software as a service (SaaS) applications like\nSalesforce, Marketo, Slack, and ServiceNow, and Amazon Web Services like Amazon\nS3 and Amazon Redshift.\n\nUse the following links to get started on the Amazon AppFlow API:\n\n  *\n[Actions](https://docs.aws.amazon.com/appflow/1.0/APIReference/API_Operations.html): An alphabetical list of all Amazon AppFlow API operations.\n\n  * [Data\ntypes](https://docs.aws.amazon.com/appflow/1.0/APIReference/API_Types.html): An\nalphabetical list of all Amazon AppFlow data types.\n\n  * [Common parameters](https://docs.aws.amazon.com/appflow/1.0/APIReference/CommonParameters.html):\nParameters that all Query operations can use.\n\n  * [Common errors](https://docs.aws.amazon.com/appflow/1.0/APIReference/CommonErrors.html):\nClient and server errors that all operations can return.\n\nIf you're new to Amazon AppFlow, we recommend that you review the [Amazon AppFlow User\nGuide](https://docs.aws.amazon.com/appflow/latest/userguide/what-is-appflow.html).\n\nAmazon AppFlow API users can use vendor-specific mechanisms for OAuth, and\ninclude applicable OAuth attributes (such as `auth-code` and `redirecturi`) with\nthe connector-specific `ConnectorProfileProperties` when creating a new\nconnector profile using Amazon AppFlow API operations. For example, Salesforce\nusers can refer to the [ *Authorize Apps with OAuth*\n](https://help.salesforce.com/articleView?id=remoteaccess_authenticate.htm)\ndocumentation.","ref":"AWS.Appflow.html","title":"AWS.Appflow","type":"module"},{"doc":"Cancels active runs for a flow.\n\nYou can cancel all of the active runs for a flow, or you can cancel specific\nruns by providing their IDs.\n\nYou can cancel a flow run only when the run is in progress. You can't cancel a\nrun that has already completed or failed. You also can't cancel a run that's\nscheduled to occur but hasn't started yet. To prevent a scheduled run, you can\ndeactivate the flow with the `StopFlow` action.\n\nYou cannot resume a run after you cancel it.\n\nWhen you send your request, the status for each run becomes `CancelStarted`.\nWhen the cancellation completes, the status becomes `Canceled`.\n\nWhen you cancel a run, you still incur charges for any data that the run already\nprocessed before the cancellation. If the run had already written some data to\nthe flow destination, then that data remains in the destination. If you\nconfigured the flow to use a batch API (such as the Salesforce Bulk API 2.0),\nthen the run will finish reading or writing its entire batch of data after the\ncancellation. For these operations, the data processing charges for Amazon\nAppFlow apply. For the pricing information, see [Amazon AppFlow pricing](http://aws.amazon.com/appflow/pricing/).","ref":"AWS.Appflow.html#cancel_flow_executions/3","title":"AWS.Appflow.cancel_flow_executions/3","type":"function"},{"doc":"Creates a new connector profile associated with your Amazon Web Services\naccount.\n\nThere is a soft quota of 100 connector profiles per Amazon Web Services account.\nIf you need more connector profiles than this quota allows, you can submit a\nrequest to the Amazon AppFlow team through the Amazon AppFlow support channel.\nIn each connector profile that you create, you can provide the credentials and\nproperties for only one connector.","ref":"AWS.Appflow.html#create_connector_profile/3","title":"AWS.Appflow.create_connector_profile/3","type":"function"},{"doc":"Enables your application to create a new flow using Amazon AppFlow.\n\nYou must create a connector profile before calling this API. Please note that\nthe Request Syntax below shows syntax for multiple destinations, however, you\ncan only transfer data to one item in this list at a time. Amazon AppFlow does\nnot currently support flows to multiple destinations at once.","ref":"AWS.Appflow.html#create_flow/3","title":"AWS.Appflow.create_flow/3","type":"function"},{"doc":"Enables you to delete an existing connector profile.","ref":"AWS.Appflow.html#delete_connector_profile/3","title":"AWS.Appflow.delete_connector_profile/3","type":"function"},{"doc":"Enables your application to delete an existing flow.\n\nBefore deleting the flow, Amazon AppFlow validates the request by checking the\nflow configuration and status. You can delete flows one at a time.","ref":"AWS.Appflow.html#delete_flow/3","title":"AWS.Appflow.delete_flow/3","type":"function"},{"doc":"Describes the given custom connector registered in your Amazon Web Services\naccount.\n\nThis API can be used for custom connectors that are registered in your account\nand also for Amazon authored connectors.","ref":"AWS.Appflow.html#describe_connector/3","title":"AWS.Appflow.describe_connector/3","type":"function"},{"doc":"Provides details regarding the entity used with the connector, with a\ndescription of the data model for each field in that entity.","ref":"AWS.Appflow.html#describe_connector_entity/3","title":"AWS.Appflow.describe_connector_entity/3","type":"function"},{"doc":"Returns a list of `connector-profile` details matching the provided\n`connector-profile` names and `connector-types`.\n\nBoth input lists are optional, and you can use them to filter the result.\n\nIf no names or `connector-types` are provided, returns all connector profiles in\na paginated form. If there is no match, this operation returns an empty list.","ref":"AWS.Appflow.html#describe_connector_profiles/3","title":"AWS.Appflow.describe_connector_profiles/3","type":"function"},{"doc":"Describes the connectors vended by Amazon AppFlow for specified connector types.\n\nIf you don't specify a connector type, this operation describes all connectors\nvended by Amazon AppFlow. If there are more connectors than can be returned in\none page, the response contains a `nextToken` object, which can be be passed in\nto the next call to the `DescribeConnectors` API operation to retrieve the next\npage.","ref":"AWS.Appflow.html#describe_connectors/3","title":"AWS.Appflow.describe_connectors/3","type":"function"},{"doc":"Provides a description of the specified flow.","ref":"AWS.Appflow.html#describe_flow/3","title":"AWS.Appflow.describe_flow/3","type":"function"},{"doc":"Fetches the execution history of the flow.","ref":"AWS.Appflow.html#describe_flow_execution_records/3","title":"AWS.Appflow.describe_flow_execution_records/3","type":"function"},{"doc":"Returns the list of available connector entities supported by Amazon AppFlow.\n\nFor example, you can query Salesforce for *Account* and *Opportunity* entities,\nor query ServiceNow for the *Incident* entity.","ref":"AWS.Appflow.html#list_connector_entities/3","title":"AWS.Appflow.list_connector_entities/3","type":"function"},{"doc":"Returns the list of all registered custom connectors in your Amazon Web Services\naccount.\n\nThis API lists only custom connectors registered in this account, not the Amazon\nWeb Services authored connectors.","ref":"AWS.Appflow.html#list_connectors/3","title":"AWS.Appflow.list_connectors/3","type":"function"},{"doc":"Lists all of the flows associated with your account.","ref":"AWS.Appflow.html#list_flows/3","title":"AWS.Appflow.list_flows/3","type":"function"},{"doc":"Retrieves the tags that are associated with a specified flow.","ref":"AWS.Appflow.html#list_tags_for_resource/3","title":"AWS.Appflow.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.Appflow.html#metadata/0","title":"AWS.Appflow.metadata/0","type":"function"},{"doc":"Registers a new custom connector with your Amazon Web Services account.\n\nBefore you can register the connector, you must deploy the associated AWS lambda\nfunction in your account.","ref":"AWS.Appflow.html#register_connector/3","title":"AWS.Appflow.register_connector/3","type":"function"},{"doc":"Resets metadata about your connector entities that Amazon AppFlow stored in its\ncache.\n\nUse this action when you want Amazon AppFlow to return the latest information\nabout the data that you have in a source application.\n\nAmazon AppFlow returns metadata about your entities when you use the\nListConnectorEntities or DescribeConnectorEntities actions. Following these\nactions, Amazon AppFlow caches the metadata to reduce the number of API requests\nthat it must send to the source application. Amazon AppFlow automatically resets\nthe cache once every hour, but you can use this action when you want to get the\nlatest metadata right away.","ref":"AWS.Appflow.html#reset_connector_metadata_cache/3","title":"AWS.Appflow.reset_connector_metadata_cache/3","type":"function"},{"doc":"Activates an existing flow.\n\nFor on-demand flows, this operation runs the flow immediately. For schedule and\nevent-triggered flows, this operation activates the flow.","ref":"AWS.Appflow.html#start_flow/3","title":"AWS.Appflow.start_flow/3","type":"function"},{"doc":"Deactivates the existing flow.\n\nFor on-demand flows, this operation returns an `unsupportedOperationException`\nerror message. For schedule and event-triggered flows, this operation\ndeactivates the flow.","ref":"AWS.Appflow.html#stop_flow/3","title":"AWS.Appflow.stop_flow/3","type":"function"},{"doc":"Applies a tag to the specified flow.","ref":"AWS.Appflow.html#tag_resource/4","title":"AWS.Appflow.tag_resource/4","type":"function"},{"doc":"Unregisters the custom connector registered in your account that matches the\nconnector label provided in the request.","ref":"AWS.Appflow.html#unregister_connector/3","title":"AWS.Appflow.unregister_connector/3","type":"function"},{"doc":"Removes a tag from the specified flow.","ref":"AWS.Appflow.html#untag_resource/4","title":"AWS.Appflow.untag_resource/4","type":"function"},{"doc":"Updates a given connector profile associated with your account.","ref":"AWS.Appflow.html#update_connector_profile/3","title":"AWS.Appflow.update_connector_profile/3","type":"function"},{"doc":"Updates a custom connector that you've previously registered.\n\nThis operation updates the connector with one of the following:\n\n  * The latest version of the AWS Lambda function that's assigned to\nthe connector\n\n  * A new AWS Lambda function that you specify","ref":"AWS.Appflow.html#update_connector_registration/3","title":"AWS.Appflow.update_connector_registration/3","type":"function"},{"doc":"Updates an existing flow.","ref":"AWS.Appflow.html#update_flow/3","title":"AWS.Appflow.update_flow/3","type":"function"},{"doc":"With Application Auto Scaling, you can configure automatic scaling for the\nfollowing resources:\n\n  * Amazon AppStream 2.0 fleets\n\n  * Amazon Aurora Replicas\n\n  * Amazon Comprehend document classification and entity recognizer\nendpoints\n\n  * Amazon DynamoDB tables and global secondary indexes throughput\ncapacity\n\n  * Amazon ECS services\n\n  * Amazon ElastiCache for Redis clusters (replication groups)\n\n  * Amazon EMR clusters\n\n  * Amazon Keyspaces (for Apache Cassandra) tables\n\n  * Lambda function provisioned concurrency\n\n  * Amazon Managed Streaming for Apache Kafka broker storage\n\n  * Amazon Neptune clusters\n\n  * Amazon SageMaker endpoint variants\n\n  * Amazon SageMaker Serverless endpoint provisioned concurrency\n\n  * Amazon SageMaker inference components\n\n  * Spot Fleets (Amazon EC2)\n\n  * Custom resources provided by your own applications or services\n\nTo learn more about Application Auto Scaling, see the [Application Auto Scaling User\nGuide](https://docs.aws.amazon.com/autoscaling/application/userguide/what-is-application-auto-scaling.html).","ref":"AWS.ApplicationAutoScaling.html","title":"AWS.ApplicationAutoScaling","type":"module"},{"doc":"The Application Auto Scaling service API includes three key sets of actions:\n\n  * Register and manage scalable targets - Register Amazon Web\nServices or custom resources as scalable targets (a resource that Application\nAuto Scaling can scale), set minimum and maximum capacity limits, and retrieve\ninformation on existing scalable targets.\n\n  * Configure and manage automatic scaling - Define scaling policies\nto dynamically scale your resources in response to CloudWatch alarms, schedule\none-time or recurring scaling actions, and retrieve your recent scaling activity\nhistory.\n\n  * Suspend and resume scaling - Temporarily suspend and later resume\nautomatic scaling by calling the\n[RegisterScalableTarget](https://docs.aws.amazon.com/autoscaling/application/APIReference/API_RegisterScalableTarget.html)\nAPI action for any Application Auto Scaling scalable target. You can suspend and\nresume (individually or in combination) scale-out activities that are triggered\nby a scaling policy, scale-in activities that are triggered by a scaling policy,\nand scheduled scaling.","ref":"AWS.ApplicationAutoScaling.html#module-api-summary","title":"API Summary - AWS.ApplicationAutoScaling","type":"module"},{"doc":"Deletes the specified scaling policy for an Application Auto Scaling scalable\ntarget.\n\nDeleting a step scaling policy deletes the underlying alarm action, but does not\ndelete the CloudWatch alarm associated with the scaling policy, even if it no\nlonger has an associated action.\n\nFor more information, see [Delete a step scaling policy](https://docs.aws.amazon.com/autoscaling/application/userguide/create-step-scaling-policy-cli.html#delete-step-scaling-policy)\nand [Delete a target tracking scaling policy](https://docs.aws.amazon.com/autoscaling/application/userguide/create-target-tracking-policy-cli.html#delete-target-tracking-policy)\nin the *Application Auto Scaling User Guide*.","ref":"AWS.ApplicationAutoScaling.html#delete_scaling_policy/3","title":"AWS.ApplicationAutoScaling.delete_scaling_policy/3","type":"function"},{"doc":"Deletes the specified scheduled action for an Application Auto Scaling scalable\ntarget.\n\nFor more information, see [Delete a scheduled action](https://docs.aws.amazon.com/autoscaling/application/userguide/scheduled-scaling-additional-cli-commands.html#delete-scheduled-action)\nin the *Application Auto Scaling User Guide*.","ref":"AWS.ApplicationAutoScaling.html#delete_scheduled_action/3","title":"AWS.ApplicationAutoScaling.delete_scheduled_action/3","type":"function"},{"doc":"Deregisters an Application Auto Scaling scalable target when you have finished\nusing it.\n\nTo see which resources have been registered, use\n[DescribeScalableTargets](https://docs.aws.amazon.com/autoscaling/application/APIReference/API_DescribeScalableTargets.html).\n\nDeregistering a scalable target deletes the scaling policies and the scheduled\nactions that are associated with it.","ref":"AWS.ApplicationAutoScaling.html#deregister_scalable_target/3","title":"AWS.ApplicationAutoScaling.deregister_scalable_target/3","type":"function"},{"doc":"Gets information about the scalable targets in the specified namespace.\n\nYou can filter the results using `ResourceIds` and `ScalableDimension`.","ref":"AWS.ApplicationAutoScaling.html#describe_scalable_targets/3","title":"AWS.ApplicationAutoScaling.describe_scalable_targets/3","type":"function"},{"doc":"Provides descriptive information about the scaling activities in the specified\nnamespace from the previous six weeks.\n\nYou can filter the results using `ResourceId` and `ScalableDimension`.\n\nFor information about viewing scaling activities using the Amazon Web Services\nCLI, see [Scaling activities for Application Auto Scaling](https://docs.aws.amazon.com/autoscaling/application/userguide/application-auto-scaling-scaling-activities.html).","ref":"AWS.ApplicationAutoScaling.html#describe_scaling_activities/3","title":"AWS.ApplicationAutoScaling.describe_scaling_activities/3","type":"function"},{"doc":"Describes the Application Auto Scaling scaling policies for the specified\nservice namespace.\n\nYou can filter the results using `ResourceId`, `ScalableDimension`, and\n`PolicyNames`.\n\nFor more information, see [Target tracking scaling policies](https://docs.aws.amazon.com/autoscaling/application/userguide/application-auto-scaling-target-tracking.html)\nand [Step scaling policies](https://docs.aws.amazon.com/autoscaling/application/userguide/application-auto-scaling-step-scaling-policies.html)\nin the *Application Auto Scaling User Guide*.","ref":"AWS.ApplicationAutoScaling.html#describe_scaling_policies/3","title":"AWS.ApplicationAutoScaling.describe_scaling_policies/3","type":"function"},{"doc":"Describes the Application Auto Scaling scheduled actions for the specified\nservice namespace.\n\nYou can filter the results using the `ResourceId`, `ScalableDimension`, and\n`ScheduledActionNames` parameters.\n\nFor more information, see [Scheduled scaling](https://docs.aws.amazon.com/autoscaling/application/userguide/application-auto-scaling-scheduled-scaling.html)\nand [Managing scheduled scaling](https://docs.aws.amazon.com/autoscaling/application/userguide/scheduled-scaling-additional-cli-commands.html)\nin the *Application Auto Scaling User Guide*.","ref":"AWS.ApplicationAutoScaling.html#describe_scheduled_actions/3","title":"AWS.ApplicationAutoScaling.describe_scheduled_actions/3","type":"function"},{"doc":"Returns all the tags on the specified Application Auto Scaling scalable target.\n\nFor general information about tags, including the format and syntax, see\n[Tagging Amazon Web Services resources](https://docs.aws.amazon.com/general/latest/gr/aws_tagging.html) in\nthe *Amazon Web Services General Reference*.","ref":"AWS.ApplicationAutoScaling.html#list_tags_for_resource/3","title":"AWS.ApplicationAutoScaling.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.ApplicationAutoScaling.html#metadata/0","title":"AWS.ApplicationAutoScaling.metadata/0","type":"function"},{"doc":"Creates or updates a scaling policy for an Application Auto Scaling scalable\ntarget.\n\nEach scalable target is identified by a service namespace, resource ID, and\nscalable dimension. A scaling policy applies to the scalable target identified\nby those three attributes. You cannot create a scaling policy until you have\nregistered the resource as a scalable target.\n\nMultiple scaling policies can be in force at the same time for the same scalable\ntarget. You can have one or more target tracking scaling policies, one or more\nstep scaling policies, or both. However, there is a chance that multiple\npolicies could conflict, instructing the scalable target to scale out or in at\nthe same time. Application Auto Scaling gives precedence to the policy that\nprovides the largest capacity for both scale out and scale in. For example, if\none policy increases capacity by 3, another policy increases capacity by 200\npercent, and the current capacity is 10, Application Auto Scaling uses the\npolicy with the highest calculated capacity (200% of 10 = 20) and scales out to\n30.\n\nWe recommend caution, however, when using target tracking scaling policies with\nstep scaling policies because conflicts between these policies can cause\nundesirable behavior. For example, if the step scaling policy initiates a\nscale-in activity before the target tracking policy is ready to scale in, the\nscale-in activity will not be blocked. After the scale-in activity completes,\nthe target tracking policy could instruct the scalable target to scale out\nagain.\n\nFor more information, see [Target tracking scaling policies](https://docs.aws.amazon.com/autoscaling/application/userguide/application-auto-scaling-target-tracking.html)\nand [Step scaling policies](https://docs.aws.amazon.com/autoscaling/application/userguide/application-auto-scaling-step-scaling-policies.html)\nin the *Application Auto Scaling User Guide*.\n\nIf a scalable target is deregistered, the scalable target is no longer available\nto use scaling policies. Any scaling policies that were specified for the\nscalable target are deleted.","ref":"AWS.ApplicationAutoScaling.html#put_scaling_policy/3","title":"AWS.ApplicationAutoScaling.put_scaling_policy/3","type":"function"},{"doc":"Creates or updates a scheduled action for an Application Auto Scaling scalable\ntarget.\n\nEach scalable target is identified by a service namespace, resource ID, and\nscalable dimension. A scheduled action applies to the scalable target identified\nby those three attributes. You cannot create a scheduled action until you have\nregistered the resource as a scalable target.\n\nWhen you specify start and end times with a recurring schedule using a cron\nexpression or rates, they form the boundaries for when the recurring action\nstarts and stops.\n\nTo update a scheduled action, specify the parameters that you want to change. If\nyou don't specify start and end times, the old values are deleted.\n\nFor more information, see [Scheduled scaling](https://docs.aws.amazon.com/autoscaling/application/userguide/application-auto-scaling-scheduled-scaling.html)\nin the *Application Auto Scaling User Guide*.\n\nIf a scalable target is deregistered, the scalable target is no longer available\nto run scheduled actions. Any scheduled actions that were specified for the\nscalable target are deleted.","ref":"AWS.ApplicationAutoScaling.html#put_scheduled_action/3","title":"AWS.ApplicationAutoScaling.put_scheduled_action/3","type":"function"},{"doc":"Registers or updates a scalable target, which is the resource that you want to\nscale.\n\nScalable targets are uniquely identified by the combination of resource ID,\nscalable dimension, and namespace, which represents some capacity dimension of\nthe underlying service.\n\nWhen you register a new scalable target, you must specify values for the minimum\nand maximum capacity. If the specified resource is not active in the target\nservice, this operation does not change the resource's current capacity.\nOtherwise, it changes the resource's current capacity to a value that is inside\nof this range.\n\nIf you add a scaling policy, current capacity is adjustable within the specified\nrange when scaling starts. Application Auto Scaling scaling policies will not\nscale capacity to values that are outside of the minimum and maximum range.\n\nAfter you register a scalable target, you do not need to register it again to\nuse other Application Auto Scaling operations. To see which resources have been\nregistered, use\n[DescribeScalableTargets](https://docs.aws.amazon.com/autoscaling/application/APIReference/API_DescribeScalableTargets.html). You can also view the scaling policies for a service namespace by using\n[DescribeScalableTargets](https://docs.aws.amazon.com/autoscaling/application/APIReference/API_DescribeScalableTargets.html).\nIf you no longer need a scalable target, you can deregister it by using\n[DeregisterScalableTarget](https://docs.aws.amazon.com/autoscaling/application/APIReference/API_DeregisterScalableTarget.html).  To update a scalable target, specify the parameters that you want to change.\nInclude the parameters that identify the scalable target: resource ID, scalable\ndimension, and namespace. Any parameters that you don't specify are not changed\nby this update request.\n\nIf you call the `RegisterScalableTarget` API operation to create a scalable\ntarget, there might be a brief delay until the operation achieves [eventual\nconsistency](https://en.wikipedia.org/wiki/Eventual_consistency). You might\nbecome aware of this brief delay if you get unexpected errors when performing\nsequential operations. The typical strategy is to retry the request, and some\nAmazon Web Services SDKs include automatic backoff and retry logic.\n\nIf you call the `RegisterScalableTarget` API operation to update an existing\nscalable target, Application Auto Scaling retrieves the current capacity of the\nresource. If it's below the minimum capacity or above the maximum capacity,\nApplication Auto Scaling adjusts the capacity of the scalable target to place it\nwithin these bounds, even if you don't include the `MinCapacity` or\n`MaxCapacity` request parameters.","ref":"AWS.ApplicationAutoScaling.html#register_scalable_target/3","title":"AWS.ApplicationAutoScaling.register_scalable_target/3","type":"function"},{"doc":"Adds or edits tags on an Application Auto Scaling scalable target.\n\nEach tag consists of a tag key and a tag value, which are both case-sensitive\nstrings. To add a tag, specify a new tag key and a tag value. To edit a tag,\nspecify an existing tag key and a new tag value.\n\nYou can use this operation to tag an Application Auto Scaling scalable target,\nbut you cannot tag a scaling policy or scheduled action.\n\nYou can also add tags to an Application Auto Scaling scalable target while\ncreating it (`RegisterScalableTarget`).\n\nFor general information about tags, including the format and syntax, see\n[Tagging Amazon Web Services resources](https://docs.aws.amazon.com/general/latest/gr/aws_tagging.html) in\nthe *Amazon Web Services General Reference*.\n\nUse tags to control access to a scalable target. For more information, see\n[Tagging support for Application Auto Scaling](https://docs.aws.amazon.com/autoscaling/application/userguide/resource-tagging-support.html)\nin the *Application Auto Scaling User Guide*.","ref":"AWS.ApplicationAutoScaling.html#tag_resource/3","title":"AWS.ApplicationAutoScaling.tag_resource/3","type":"function"},{"doc":"Deletes tags from an Application Auto Scaling scalable target.\n\nTo delete a tag, specify the tag key and the Application Auto Scaling scalable\ntarget.","ref":"AWS.ApplicationAutoScaling.html#untag_resource/3","title":"AWS.ApplicationAutoScaling.untag_resource/3","type":"function"},{"doc":"This reference provides descriptions of the AWS Application Cost Profiler API.\n\nThe AWS Application Cost Profiler API provides programmatic access to view,\ncreate, update, and delete application cost report definitions, as well as to\nimport your usage data into the Application Cost Profiler service.\n\nFor more information about using this service, see the [AWS Application Cost Profiler User\nGuide](https://docs.aws.amazon.com/application-cost-profiler/latest/userguide/introduction.html).","ref":"AWS.ApplicationCostProfiler.html","title":"AWS.ApplicationCostProfiler","type":"module"},{"doc":"Deletes the specified report definition in AWS Application Cost Profiler.\n\nThis stops the report from being generated.","ref":"AWS.ApplicationCostProfiler.html#delete_report_definition/4","title":"AWS.ApplicationCostProfiler.delete_report_definition/4","type":"function"},{"doc":"Retrieves the definition of a report already configured in AWS Application Cost\nProfiler.","ref":"AWS.ApplicationCostProfiler.html#get_report_definition/3","title":"AWS.ApplicationCostProfiler.get_report_definition/3","type":"function"},{"doc":"Ingests application usage data from Amazon Simple Storage Service (Amazon S3).\n\nThe data must already exist in the S3 location. As part of the action, AWS\nApplication Cost Profiler copies the object from your S3 bucket to an S3 bucket\nowned by Amazon for processing asynchronously.","ref":"AWS.ApplicationCostProfiler.html#import_application_usage/3","title":"AWS.ApplicationCostProfiler.import_application_usage/3","type":"function"},{"doc":"Retrieves a list of all reports and their configurations for your AWS account.\n\nThe maximum number of reports is one.","ref":"AWS.ApplicationCostProfiler.html#list_report_definitions/4","title":"AWS.ApplicationCostProfiler.list_report_definitions/4","type":"function"},{"doc":"","ref":"AWS.ApplicationCostProfiler.html#metadata/0","title":"AWS.ApplicationCostProfiler.metadata/0","type":"function"},{"doc":"Creates the report definition for a report in Application Cost Profiler.","ref":"AWS.ApplicationCostProfiler.html#put_report_definition/3","title":"AWS.ApplicationCostProfiler.put_report_definition/3","type":"function"},{"doc":"Updates existing report in AWS Application Cost Profiler.","ref":"AWS.ApplicationCostProfiler.html#update_report_definition/4","title":"AWS.ApplicationCostProfiler.update_report_definition/4","type":"function"},{"doc":"Amazon Web Services Application Discovery Service\n\nAmazon Web Services Application Discovery Service (Application Discovery\nService) helps you plan application migration projects.\n\nIt automatically identifies servers, virtual machines (VMs), and network\ndependencies in your on-premises data centers. For more information, see the\n[Amazon Web Services Application Discovery Service FAQ](http://aws.amazon.com/application-discovery/faqs/).\n\nApplication Discovery Service offers three ways of performing discovery and\ncollecting data about your on-premises servers:\n\n  * **Agentless discovery** using Amazon Web Services Application\nDiscovery Service Agentless Collector (Agentless Collector), which doesn't\nrequire you to install an agent on each host.\n\n    * Agentless Collector gathers server information\nregardless of the operating systems, which minimizes the time required for\ninitial on-premises infrastructure assessment.\n\n    * Agentless Collector doesn't collect information about\nnetwork dependencies, only agent-based discovery collects that information.\n\n  * **Agent-based discovery** using the Amazon Web Services\nApplication Discovery Agent (Application Discovery Agent) collects a richer set\nof data than agentless discovery, which you install on one or more hosts in your\ndata center.\n\n    * The agent captures infrastructure and application\ninformation, including an inventory of running processes, system performance\ninformation, resource utilization, and network dependencies.\n\n    * The information collected by agents is secured at rest\nand in transit to the Application Discovery Service database in the Amazon Web\nServices cloud. For more information, see [Amazon Web Services Application Discovery\nAgent](https://docs.aws.amazon.com/application-discovery/latest/userguide/discovery-agent.html).\n\n  * **Amazon Web Services Partner Network (APN) solutions** integrate\nwith Application Discovery Service, enabling you to import details of your\non-premises environment directly into Amazon Web Services Migration Hub\n(Migration Hub) without using Agentless Collector or Application Discovery\nAgent.\n\n    * Third-party application discovery tools can query\nAmazon Web Services Application Discovery Service, and they can write to the\nApplication Discovery Service database using the public API.\n\n    * In this way, you can import data into Migration Hub\nand view it, so that you can associate applications with servers and track\nmigrations.","ref":"AWS.ApplicationDiscovery.html","title":"AWS.ApplicationDiscovery","type":"module"},{"doc":"This API reference provides descriptions, syntax, and usage examples for each of\nthe actions and data types for Application Discovery Service. The topic for each\naction shows the API request parameters and the response. Alternatively, you can\nuse one of the Amazon Web Services SDKs to access an API that is tailored to the\nprogramming language or platform that you're using. For more information, see\n[Amazon Web Services SDKs](http://aws.amazon.com/tools/#SDKs).     Remember that you must set your Migration Hub home Region before\nyou call any of these APIs.\n\n   You must make API calls for write actions (create, notify,\nassociate, disassociate, import, or put) while in your home Region, or a\n`HomeRegionNotSetException` error is returned.\n\n   API calls for read actions (list, describe, stop, and delete) are\npermitted outside of your home Region.\n\n   Although it is unlikely, the Migration Hub home Region could\nchange. If you call APIs outside the home Region, an `InvalidInputException` is\nreturned.\n\n   You must call `GetHomeRegion` to obtain the latest Migration Hub\nhome Region.\n\nThis guide is intended for use with the [Amazon Web Services Application\nDiscovery Service User\nGuide](https://docs.aws.amazon.com/application-discovery/latest/userguide/).\n\nAll data is handled according to the [Amazon Web Services Privacy Policy](https://aws.amazon.com/privacy/). You can operate Application Discovery\nService offline to inspect collected data before it is shared with the service.","ref":"AWS.ApplicationDiscovery.html#module-working-with-this-guide","title":"Working With This Guide - AWS.ApplicationDiscovery","type":"module"},{"doc":"Associates one or more configuration items with an application.","ref":"AWS.ApplicationDiscovery.html#associate_configuration_items_to_application/3","title":"AWS.ApplicationDiscovery.associate_configuration_items_to_application/3","type":"function"},{"doc":"Deletes one or more agents or collectors as specified by ID.\n\nDeleting an agent or collector does not delete the previously discovered data.\nTo delete the data collected, use `StartBatchDeleteConfigurationTask`.","ref":"AWS.ApplicationDiscovery.html#batch_delete_agents/3","title":"AWS.ApplicationDiscovery.batch_delete_agents/3","type":"function"},{"doc":"Deletes one or more import tasks, each identified by their import ID.\n\nEach import task has a number of records that can identify servers or\napplications.\n\nAmazon Web Services Application Discovery Service has built-in matching logic\nthat will identify when discovered servers match existing entries that you've\npreviously discovered, the information for the already-existing discovered\nserver is updated. When you delete an import task that contains records that\nwere used to match, the information in those matched records that comes from the\ndeleted records will also be deleted.","ref":"AWS.ApplicationDiscovery.html#batch_delete_import_data/3","title":"AWS.ApplicationDiscovery.batch_delete_import_data/3","type":"function"},{"doc":"Creates an application with the given name and description.","ref":"AWS.ApplicationDiscovery.html#create_application/3","title":"AWS.ApplicationDiscovery.create_application/3","type":"function"},{"doc":"Creates one or more tags for configuration items.\n\nTags are metadata that help you categorize IT assets. This API accepts a list of\nmultiple configuration items.\n\nDo not store sensitive information (like personal data) in tags.","ref":"AWS.ApplicationDiscovery.html#create_tags/3","title":"AWS.ApplicationDiscovery.create_tags/3","type":"function"},{"doc":"Deletes a list of applications and their associations with configuration items.","ref":"AWS.ApplicationDiscovery.html#delete_applications/3","title":"AWS.ApplicationDiscovery.delete_applications/3","type":"function"},{"doc":"Deletes the association between configuration items and one or more tags.\n\nThis API accepts a list of multiple configuration items.","ref":"AWS.ApplicationDiscovery.html#delete_tags/3","title":"AWS.ApplicationDiscovery.delete_tags/3","type":"function"},{"doc":"Lists agents or collectors as specified by ID or other filters.\n\nAll agents/collectors associated with your user can be listed if you call\n`DescribeAgents` as is without passing any parameters.","ref":"AWS.ApplicationDiscovery.html#describe_agents/3","title":"AWS.ApplicationDiscovery.describe_agents/3","type":"function"},{"doc":"Takes a unique deletion task identifier as input and returns metadata about a\nconfiguration deletion task.","ref":"AWS.ApplicationDiscovery.html#describe_batch_delete_configuration_task/3","title":"AWS.ApplicationDiscovery.describe_batch_delete_configuration_task/3","type":"function"},{"doc":"Retrieves attributes for a list of configuration item IDs.\n\nAll of the supplied IDs must be for the same asset type from one of the\nfollowing:\n\n   server\n\n   application\n\n   process\n\n   connection\n\nOutput fields are specific to the asset type specified. For example, the output\nfor a *server* configuration item includes a list of attributes about the\nserver, such as host name, operating system, number of network cards, etc.\n\nFor a complete list of outputs for each asset type, see [Using the DescribeConfigurations\nAction](https://docs.aws.amazon.com/application-discovery/latest/userguide/discovery-api-queries.html#DescribeConfigurations)\nin the *Amazon Web Services Application Discovery Service User Guide*.","ref":"AWS.ApplicationDiscovery.html#describe_configurations/3","title":"AWS.ApplicationDiscovery.describe_configurations/3","type":"function"},{"doc":"Lists exports as specified by ID.\n\nAll continuous exports associated with your user can be listed if you call\n`DescribeContinuousExports` as is without passing any parameters.","ref":"AWS.ApplicationDiscovery.html#describe_continuous_exports/3","title":"AWS.ApplicationDiscovery.describe_continuous_exports/3","type":"function"},{"doc":"`DescribeExportConfigurations` is deprecated.\n\nUse\n[DescribeExportTasks](https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_DescribeExportTasks.html),\ninstead.","ref":"AWS.ApplicationDiscovery.html#describe_export_configurations/3","title":"AWS.ApplicationDiscovery.describe_export_configurations/3","type":"function"},{"doc":"Retrieve status of one or more export tasks.\n\nYou can retrieve the status of up to 100 export tasks.","ref":"AWS.ApplicationDiscovery.html#describe_export_tasks/3","title":"AWS.ApplicationDiscovery.describe_export_tasks/3","type":"function"},{"doc":"Returns an array of import tasks for your account, including status information,\ntimes, IDs, the Amazon S3 Object URL for the import file, and more.","ref":"AWS.ApplicationDiscovery.html#describe_import_tasks/3","title":"AWS.ApplicationDiscovery.describe_import_tasks/3","type":"function"},{"doc":"Retrieves a list of configuration items that have tags as specified by the\nkey-value pairs, name and value, passed to the optional parameter `filters`.\n\nThere are three valid tag filter names:\n\n  * tagKey\n\n  * tagValue\n\n  * configurationId\n\nAlso, all configuration items associated with your user that have tags can be\nlisted if you call `DescribeTags` as is without passing any parameters.","ref":"AWS.ApplicationDiscovery.html#describe_tags/3","title":"AWS.ApplicationDiscovery.describe_tags/3","type":"function"},{"doc":"Disassociates one or more configuration items from an application.","ref":"AWS.ApplicationDiscovery.html#disassociate_configuration_items_from_application/3","title":"AWS.ApplicationDiscovery.disassociate_configuration_items_from_application/3","type":"function"},{"doc":"Deprecated.\n\nUse `StartExportTask` instead.\n\nExports all discovered configuration data to an Amazon S3 bucket or an\napplication that enables you to view and evaluate the data. Data includes tags\nand tag associations, processes, connections, servers, and system performance.\nThis API returns an export ID that you can query using the\n*DescribeExportConfigurations* API. The system imposes a limit of two\nconfiguration exports in six hours.","ref":"AWS.ApplicationDiscovery.html#export_configurations/3","title":"AWS.ApplicationDiscovery.export_configurations/3","type":"function"},{"doc":"Retrieves a short summary of discovered assets.\n\nThis API operation takes no request parameters and is called as is at the\ncommand prompt as shown in the example.","ref":"AWS.ApplicationDiscovery.html#get_discovery_summary/3","title":"AWS.ApplicationDiscovery.get_discovery_summary/3","type":"function"},{"doc":"Retrieves a list of configuration items as specified by the value passed to the\nrequired parameter `configurationType`.\n\nOptional filtering may be applied to refine search results.","ref":"AWS.ApplicationDiscovery.html#list_configurations/3","title":"AWS.ApplicationDiscovery.list_configurations/3","type":"function"},{"doc":"Retrieves a list of servers that are one network hop away from a specified\nserver.","ref":"AWS.ApplicationDiscovery.html#list_server_neighbors/3","title":"AWS.ApplicationDiscovery.list_server_neighbors/3","type":"function"},{"doc":"","ref":"AWS.ApplicationDiscovery.html#metadata/0","title":"AWS.ApplicationDiscovery.metadata/0","type":"function"},{"doc":"Takes a list of configurationId as input and starts an asynchronous deletion\ntask to remove the configurationItems.\n\nReturns a unique deletion task identifier.","ref":"AWS.ApplicationDiscovery.html#start_batch_delete_configuration_task/3","title":"AWS.ApplicationDiscovery.start_batch_delete_configuration_task/3","type":"function"},{"doc":"Start the continuous flow of agent's discovered data into Amazon Athena.","ref":"AWS.ApplicationDiscovery.html#start_continuous_export/3","title":"AWS.ApplicationDiscovery.start_continuous_export/3","type":"function"},{"doc":"Instructs the specified agents to start collecting data.","ref":"AWS.ApplicationDiscovery.html#start_data_collection_by_agent_ids/3","title":"AWS.ApplicationDiscovery.start_data_collection_by_agent_ids/3","type":"function"},{"doc":"Begins the export of a discovered data report to an Amazon S3 bucket managed by\nAmazon Web Services.\n\nExports might provide an estimate of fees and savings based on certain\ninformation that you provide. Fee estimates do not include any taxes that might\napply. Your actual fees and savings depend on a variety of factors, including\nyour actual usage of Amazon Web Services services, which might vary from the\nestimates provided in this report.\n\nIf you do not specify `preferences` or `agentIds` in the filter, a summary of\nall servers, applications, tags, and performance is generated. This data is an\naggregation of all server data collected through on-premises tooling, file\nimport, application grouping and applying tags.\n\nIf you specify `agentIds` in a filter, the task exports up to 72 hours of\ndetailed data collected by the identified Application Discovery Agent, including\nnetwork, process, and performance details. A time range for exported agent data\nmay be set by using `startTime` and `endTime`. Export of detailed agent data is\nlimited to five concurrently running exports. Export of detailed agent data is\nlimited to two exports per day.\n\nIf you enable `ec2RecommendationsPreferences` in `preferences` , an Amazon EC2\ninstance matching the characteristics of each server in Application Discovery\nService is generated. Changing the attributes of the\n`ec2RecommendationsPreferences` changes the criteria of the recommendation.","ref":"AWS.ApplicationDiscovery.html#start_export_task/3","title":"AWS.ApplicationDiscovery.start_export_task/3","type":"function"},{"doc":"Starts an import task, which allows you to import details of your on-premises\nenvironment directly into Amazon Web Services Migration Hub without having to\nuse the Amazon Web Services Application Discovery Service (Application Discovery\nService) tools such as the Amazon Web Services Application Discovery Service\nAgentless Collector or Application Discovery Agent.\n\nThis gives you the option to perform migration assessment and planning directly\nfrom your imported data, including the ability to group your devices as\napplications and track their migration status.\n\nTo start an import request, do this:\n\n  1. Download the specially formatted comma separated value (CSV)\nimport template, which you can find here:\n[https://s3.us-west-2.amazonaws.com/templates-7cffcf56-bd96-4b1c-b45b-a5b42f282e46/import_template.csv](https://s3.us-west-2.amazonaws.com/templates-7cffcf56-bd96-4b1c-b45b-a5b42f282e46/import_template.csv).     2. Fill out the template with your server and application data.\n\n  3. Upload your import file to an Amazon S3 bucket, and make a note\nof it's Object URL. Your import file must be in the CSV format.\n\n  4. Use the console or the `StartImportTask` command with the Amazon\nWeb Services CLI or one of the Amazon Web Services SDKs to import the records\nfrom your file.\n\nFor more information, including step-by-step procedures, see [Migration Hub\nImport](https://docs.aws.amazon.com/application-discovery/latest/userguide/discovery-import.html)\nin the *Amazon Web Services Application Discovery Service User Guide*.\n\nThere are limits to the number of import tasks you can create (and delete) in an\nAmazon Web Services account. For more information, see [Amazon Web Services Application Discovery Service\nLimits](https://docs.aws.amazon.com/application-discovery/latest/userguide/ads_service_limits.html)\nin the *Amazon Web Services Application Discovery Service User Guide*.","ref":"AWS.ApplicationDiscovery.html#start_import_task/3","title":"AWS.ApplicationDiscovery.start_import_task/3","type":"function"},{"doc":"Stop the continuous flow of agent's discovered data into Amazon Athena.","ref":"AWS.ApplicationDiscovery.html#stop_continuous_export/3","title":"AWS.ApplicationDiscovery.stop_continuous_export/3","type":"function"},{"doc":"Instructs the specified agents to stop collecting data.","ref":"AWS.ApplicationDiscovery.html#stop_data_collection_by_agent_ids/3","title":"AWS.ApplicationDiscovery.stop_data_collection_by_agent_ids/3","type":"function"},{"doc":"Updates metadata about an application.","ref":"AWS.ApplicationDiscovery.html#update_application/3","title":"AWS.ApplicationDiscovery.update_application/3","type":"function"},{"doc":"Amazon CloudWatch Application Insights\n\nAmazon CloudWatch Application Insights is a service that helps you detect common\nproblems with your applications.\n\nIt enables you to pinpoint the source of issues in your applications (built with\ntechnologies such as Microsoft IIS, .NET, and Microsoft SQL Server), by\nproviding key insights into detected problems.\n\nAfter you onboard your application, CloudWatch Application Insights identifies,\nrecommends, and sets up metrics and logs. It continuously analyzes and\ncorrelates your metrics and logs for unusual behavior to surface actionable\nproblems with your application. For example, if your application is slow and\nunresponsive and leading to HTTP 500 errors in your Application Load Balancer\n(ALB), Application Insights informs you that a memory pressure problem with your\nSQL Server database is occurring. It bases this analysis on impactful metrics\nand log errors.","ref":"AWS.ApplicationInsights.html","title":"AWS.ApplicationInsights","type":"module"},{"doc":"Adds a workload to a component.\n\nEach component can have at most five workloads.","ref":"AWS.ApplicationInsights.html#add_workload/3","title":"AWS.ApplicationInsights.add_workload/3","type":"function"},{"doc":"Adds an application that is created from a resource group.","ref":"AWS.ApplicationInsights.html#create_application/3","title":"AWS.ApplicationInsights.create_application/3","type":"function"},{"doc":"Creates a custom component by grouping similar standalone instances to monitor.","ref":"AWS.ApplicationInsights.html#create_component/3","title":"AWS.ApplicationInsights.create_component/3","type":"function"},{"doc":"Adds an log pattern to a `LogPatternSet`.","ref":"AWS.ApplicationInsights.html#create_log_pattern/3","title":"AWS.ApplicationInsights.create_log_pattern/3","type":"function"},{"doc":"Removes the specified application from monitoring.\n\nDoes not delete the application.","ref":"AWS.ApplicationInsights.html#delete_application/3","title":"AWS.ApplicationInsights.delete_application/3","type":"function"},{"doc":"Ungroups a custom component.\n\nWhen you ungroup custom components, all applicable monitors that are set up for\nthe component are removed and the instances revert to their standalone status.","ref":"AWS.ApplicationInsights.html#delete_component/3","title":"AWS.ApplicationInsights.delete_component/3","type":"function"},{"doc":"Removes the specified log pattern from a `LogPatternSet`.","ref":"AWS.ApplicationInsights.html#delete_log_pattern/3","title":"AWS.ApplicationInsights.delete_log_pattern/3","type":"function"},{"doc":"Describes the application.","ref":"AWS.ApplicationInsights.html#describe_application/3","title":"AWS.ApplicationInsights.describe_application/3","type":"function"},{"doc":"Describes a component and lists the resources that are grouped together in a\ncomponent.","ref":"AWS.ApplicationInsights.html#describe_component/3","title":"AWS.ApplicationInsights.describe_component/3","type":"function"},{"doc":"Describes the monitoring configuration of the component.","ref":"AWS.ApplicationInsights.html#describe_component_configuration/3","title":"AWS.ApplicationInsights.describe_component_configuration/3","type":"function"},{"doc":"Describes the recommended monitoring configuration of the component.","ref":"AWS.ApplicationInsights.html#describe_component_configuration_recommendation/3","title":"AWS.ApplicationInsights.describe_component_configuration_recommendation/3","type":"function"},{"doc":"Describe a specific log pattern from a `LogPatternSet`.","ref":"AWS.ApplicationInsights.html#describe_log_pattern/3","title":"AWS.ApplicationInsights.describe_log_pattern/3","type":"function"},{"doc":"Describes an anomaly or error with the application.","ref":"AWS.ApplicationInsights.html#describe_observation/3","title":"AWS.ApplicationInsights.describe_observation/3","type":"function"},{"doc":"Describes an application problem.","ref":"AWS.ApplicationInsights.html#describe_problem/3","title":"AWS.ApplicationInsights.describe_problem/3","type":"function"},{"doc":"Describes the anomalies or errors associated with the problem.","ref":"AWS.ApplicationInsights.html#describe_problem_observations/3","title":"AWS.ApplicationInsights.describe_problem_observations/3","type":"function"},{"doc":"Describes a workload and its configuration.","ref":"AWS.ApplicationInsights.html#describe_workload/3","title":"AWS.ApplicationInsights.describe_workload/3","type":"function"},{"doc":"Lists the IDs of the applications that you are monitoring.","ref":"AWS.ApplicationInsights.html#list_applications/3","title":"AWS.ApplicationInsights.list_applications/3","type":"function"},{"doc":"Lists the auto-grouped, standalone, and custom components of the application.","ref":"AWS.ApplicationInsights.html#list_components/3","title":"AWS.ApplicationInsights.list_components/3","type":"function"},{"doc":"Lists the INFO, WARN, and ERROR events for periodic configuration updates\nperformed by Application Insights.\n\nExamples of events represented are:\n\n  * INFO: creating a new alarm or updating an alarm threshold.\n\n  * WARN: alarm not created due to insufficient data points used to\npredict thresholds.\n\n  * ERROR: alarm not created due to permission errors or exceeding\nquotas.","ref":"AWS.ApplicationInsights.html#list_configuration_history/3","title":"AWS.ApplicationInsights.list_configuration_history/3","type":"function"},{"doc":"Lists the log pattern sets in the specific application.","ref":"AWS.ApplicationInsights.html#list_log_pattern_sets/3","title":"AWS.ApplicationInsights.list_log_pattern_sets/3","type":"function"},{"doc":"Lists the log patterns in the specific log `LogPatternSet`.","ref":"AWS.ApplicationInsights.html#list_log_patterns/3","title":"AWS.ApplicationInsights.list_log_patterns/3","type":"function"},{"doc":"Lists the problems with your application.","ref":"AWS.ApplicationInsights.html#list_problems/3","title":"AWS.ApplicationInsights.list_problems/3","type":"function"},{"doc":"Retrieve a list of the tags (keys and values) that are associated with a\nspecified application.\n\nA *tag* is a label that you optionally define and associate with an application.\nEach tag consists of a required *tag key* and an optional associated *tag\nvalue*. A tag key is a general label that acts as a category for more specific\ntag values. A tag value acts as a descriptor within a tag key.","ref":"AWS.ApplicationInsights.html#list_tags_for_resource/3","title":"AWS.ApplicationInsights.list_tags_for_resource/3","type":"function"},{"doc":"Lists the workloads that are configured on a given component.","ref":"AWS.ApplicationInsights.html#list_workloads/3","title":"AWS.ApplicationInsights.list_workloads/3","type":"function"},{"doc":"","ref":"AWS.ApplicationInsights.html#metadata/0","title":"AWS.ApplicationInsights.metadata/0","type":"function"},{"doc":"Remove workload from a component.","ref":"AWS.ApplicationInsights.html#remove_workload/3","title":"AWS.ApplicationInsights.remove_workload/3","type":"function"},{"doc":"Add one or more tags (keys and values) to a specified application.\n\nA *tag* is a label that you optionally define and associate with an application.\nTags can help you categorize and manage application in different ways, such as\nby purpose, owner, environment, or other criteria.\n\nEach tag consists of a required *tag key* and an associated *tag value*, both of\nwhich you define. A tag key is a general label that acts as a category for more\nspecific tag values. A tag value acts as a descriptor within a tag key.","ref":"AWS.ApplicationInsights.html#tag_resource/3","title":"AWS.ApplicationInsights.tag_resource/3","type":"function"},{"doc":"Remove one or more tags (keys and values) from a specified application.","ref":"AWS.ApplicationInsights.html#untag_resource/3","title":"AWS.ApplicationInsights.untag_resource/3","type":"function"},{"doc":"Updates the application.","ref":"AWS.ApplicationInsights.html#update_application/3","title":"AWS.ApplicationInsights.update_application/3","type":"function"},{"doc":"Updates the custom component name and/or the list of resources that make up the\ncomponent.","ref":"AWS.ApplicationInsights.html#update_component/3","title":"AWS.ApplicationInsights.update_component/3","type":"function"},{"doc":"Updates the monitoring configurations for the component.\n\nThe configuration input parameter is an escaped JSON of the configuration and\nshould match the schema of what is returned by\n`DescribeComponentConfigurationRecommendation`.","ref":"AWS.ApplicationInsights.html#update_component_configuration/3","title":"AWS.ApplicationInsights.update_component_configuration/3","type":"function"},{"doc":"Adds a log pattern to a `LogPatternSet`.","ref":"AWS.ApplicationInsights.html#update_log_pattern/3","title":"AWS.ApplicationInsights.update_log_pattern/3","type":"function"},{"doc":"Updates the visibility of the problem or specifies the problem as `RESOLVED`.","ref":"AWS.ApplicationInsights.html#update_problem/3","title":"AWS.ApplicationInsights.update_problem/3","type":"function"},{"doc":"Adds a workload to a component.\n\nEach component can have at most five workloads.","ref":"AWS.ApplicationInsights.html#update_workload/3","title":"AWS.ApplicationInsights.update_workload/3","type":"function"},{"doc":"Amazon Athena is an interactive query service that lets you use standard SQL to\nanalyze data directly in Amazon S3.\n\nYou can point Athena at your data in Amazon S3 and run ad-hoc queries and get\nresults in seconds. Athena is serverless, so there is no infrastructure to set\nup or manage. You pay only for the queries you run. Athena scales\nautomatically—executing queries in parallel—so results are fast, even with large\ndatasets and complex queries. For more information, see [What is Amazon Athena](http://docs.aws.amazon.com/athena/latest/ug/what-is.html) in the *Amazon\nAthena User Guide*.\n\nIf you connect to Athena using the JDBC driver, use version 1.1.0 of the driver\nor later with the Amazon Athena API. Earlier version drivers do not support the\nAPI. For more information and to download the driver, see [Accessing Amazon Athena with\nJDBC](https://docs.aws.amazon.com/athena/latest/ug/connect-with-jdbc.html).","ref":"AWS.Athena.html","title":"AWS.Athena","type":"module"},{"doc":"Returns the details of a single named query or a list of up to 50 queries, which\nyou provide as an array of query ID strings.\n\nRequires you to have access to the workgroup in which the queries were saved.\nUse `ListNamedQueriesInput` to get the list of named query IDs in the specified\nworkgroup. If information could not be retrieved for a submitted query ID,\ninformation about the query ID submitted is listed under\n`UnprocessedNamedQueryId`. Named queries differ from executed queries. Use\n`BatchGetQueryExecutionInput` to get details about each unique query execution,\nand `ListQueryExecutionsInput` to get a list of query execution IDs.","ref":"AWS.Athena.html#batch_get_named_query/3","title":"AWS.Athena.batch_get_named_query/3","type":"function"},{"doc":"Returns the details of a single prepared statement or a list of up to 256\nprepared statements for the array of prepared statement names that you provide.\n\nRequires you to have access to the workgroup to which the prepared statements\nbelong. If a prepared statement cannot be retrieved for the name specified, the\nstatement is listed in `UnprocessedPreparedStatementNames`.","ref":"AWS.Athena.html#batch_get_prepared_statement/3","title":"AWS.Athena.batch_get_prepared_statement/3","type":"function"},{"doc":"Returns the details of a single query execution or a list of up to 50 query\nexecutions, which you provide as an array of query execution ID strings.\n\nRequires you to have access to the workgroup in which the queries ran. To get a\nlist of query execution IDs, use `ListQueryExecutionsInput$WorkGroup`. Query\nexecutions differ from named (saved) queries. Use `BatchGetNamedQueryInput` to\nget details about named queries.","ref":"AWS.Athena.html#batch_get_query_execution/3","title":"AWS.Athena.batch_get_query_execution/3","type":"function"},{"doc":"Cancels the capacity reservation with the specified name.\n\nCancelled reservations remain in your account and will be deleted 45 days after\ncancellation. During the 45 days, you cannot re-purpose or reuse a reservation\nthat has been cancelled, but you can refer to its tags and view it for\nhistorical reference.","ref":"AWS.Athena.html#cancel_capacity_reservation/3","title":"AWS.Athena.cancel_capacity_reservation/3","type":"function"},{"doc":"Creates a capacity reservation with the specified name and number of requested\ndata processing units.","ref":"AWS.Athena.html#create_capacity_reservation/3","title":"AWS.Athena.create_capacity_reservation/3","type":"function"},{"doc":"Creates (registers) a data catalog with the specified name and properties.\n\nCatalogs created are visible to all users of the same Amazon Web Services\naccount.","ref":"AWS.Athena.html#create_data_catalog/3","title":"AWS.Athena.create_data_catalog/3","type":"function"},{"doc":"Creates a named query in the specified workgroup.\n\nRequires that you have access to the workgroup.","ref":"AWS.Athena.html#create_named_query/3","title":"AWS.Athena.create_named_query/3","type":"function"},{"doc":"Creates an empty `ipynb` file in the specified Apache Spark enabled workgroup.\n\nThrows an error if a file in the workgroup with the same name already exists.","ref":"AWS.Athena.html#create_notebook/3","title":"AWS.Athena.create_notebook/3","type":"function"},{"doc":"Creates a prepared statement for use with SQL queries in Athena.","ref":"AWS.Athena.html#create_prepared_statement/3","title":"AWS.Athena.create_prepared_statement/3","type":"function"},{"doc":"Gets an authentication token and the URL at which the notebook can be accessed.\n\nDuring programmatic access, `CreatePresignedNotebookUrl` must be called every 10\nminutes to refresh the authentication token. For information about granting\nprogrammatic access, see [Grant programmatic access](https://docs.aws.amazon.com/athena/latest/ug/setting-up.html#setting-up-grant-programmatic-access).","ref":"AWS.Athena.html#create_presigned_notebook_url/3","title":"AWS.Athena.create_presigned_notebook_url/3","type":"function"},{"doc":"Creates a workgroup with the specified name.\n\nA workgroup can be an Apache Spark enabled workgroup or an Athena SQL workgroup.","ref":"AWS.Athena.html#create_work_group/3","title":"AWS.Athena.create_work_group/3","type":"function"},{"doc":"Deletes a cancelled capacity reservation.\n\nA reservation must be cancelled before it can be deleted. A deleted reservation\nis immediately removed from your account and can no longer be referenced,\nincluding by its ARN. A deleted reservation cannot be called by\n`GetCapacityReservation`, and deleted reservations do not appear in the output\nof `ListCapacityReservations`.","ref":"AWS.Athena.html#delete_capacity_reservation/3","title":"AWS.Athena.delete_capacity_reservation/3","type":"function"},{"doc":"Deletes a data catalog.","ref":"AWS.Athena.html#delete_data_catalog/3","title":"AWS.Athena.delete_data_catalog/3","type":"function"},{"doc":"Deletes the named query if you have access to the workgroup in which the query\nwas saved.","ref":"AWS.Athena.html#delete_named_query/3","title":"AWS.Athena.delete_named_query/3","type":"function"},{"doc":"Deletes the specified notebook.","ref":"AWS.Athena.html#delete_notebook/3","title":"AWS.Athena.delete_notebook/3","type":"function"},{"doc":"Deletes the prepared statement with the specified name from the specified\nworkgroup.","ref":"AWS.Athena.html#delete_prepared_statement/3","title":"AWS.Athena.delete_prepared_statement/3","type":"function"},{"doc":"Deletes the workgroup with the specified name.\n\nThe primary workgroup cannot be deleted.","ref":"AWS.Athena.html#delete_work_group/3","title":"AWS.Athena.delete_work_group/3","type":"function"},{"doc":"Exports the specified notebook and its metadata.","ref":"AWS.Athena.html#export_notebook/3","title":"AWS.Athena.export_notebook/3","type":"function"},{"doc":"Describes a previously submitted calculation execution.","ref":"AWS.Athena.html#get_calculation_execution/3","title":"AWS.Athena.get_calculation_execution/3","type":"function"},{"doc":"Retrieves the unencrypted code that was executed for the calculation.","ref":"AWS.Athena.html#get_calculation_execution_code/3","title":"AWS.Athena.get_calculation_execution_code/3","type":"function"},{"doc":"Gets the status of a current calculation.","ref":"AWS.Athena.html#get_calculation_execution_status/3","title":"AWS.Athena.get_calculation_execution_status/3","type":"function"},{"doc":"Gets the capacity assignment configuration for a capacity reservation, if one\nexists.","ref":"AWS.Athena.html#get_capacity_assignment_configuration/3","title":"AWS.Athena.get_capacity_assignment_configuration/3","type":"function"},{"doc":"Returns information about the capacity reservation with the specified name.","ref":"AWS.Athena.html#get_capacity_reservation/3","title":"AWS.Athena.get_capacity_reservation/3","type":"function"},{"doc":"Returns the specified data catalog.","ref":"AWS.Athena.html#get_data_catalog/3","title":"AWS.Athena.get_data_catalog/3","type":"function"},{"doc":"Returns a database object for the specified database and data catalog.","ref":"AWS.Athena.html#get_database/3","title":"AWS.Athena.get_database/3","type":"function"},{"doc":"Returns information about a single query.\n\nRequires that you have access to the workgroup in which the query was saved.","ref":"AWS.Athena.html#get_named_query/3","title":"AWS.Athena.get_named_query/3","type":"function"},{"doc":"Retrieves notebook metadata for the specified notebook ID.","ref":"AWS.Athena.html#get_notebook_metadata/3","title":"AWS.Athena.get_notebook_metadata/3","type":"function"},{"doc":"Retrieves the prepared statement with the specified name from the specified\nworkgroup.","ref":"AWS.Athena.html#get_prepared_statement/3","title":"AWS.Athena.get_prepared_statement/3","type":"function"},{"doc":"Returns information about a single execution of a query if you have access to\nthe workgroup in which the query ran.\n\nEach time a query executes, information about the query execution is saved with\na unique ID.","ref":"AWS.Athena.html#get_query_execution/3","title":"AWS.Athena.get_query_execution/3","type":"function"},{"doc":"Streams the results of a single query execution specified by `QueryExecutionId`\nfrom the Athena query results location in Amazon S3.\n\nFor more information, see [Working with query results, recent queries, and output files](https://docs.aws.amazon.com/athena/latest/ug/querying.html) in the\n*Amazon Athena User Guide*. This request does not execute the query but returns\nresults. Use `StartQueryExecution` to run a query.\n\nTo stream query results successfully, the IAM principal with permission to call\n`GetQueryResults` also must have permissions to the Amazon S3 `GetObject` action\nfor the Athena query results location.\n\nIAM principals with permission to the Amazon S3 `GetObject` action for the query\nresults location are able to retrieve query results from Amazon S3 even if\npermission to the `GetQueryResults` action is denied. To restrict user or role\naccess, ensure that Amazon S3 permissions to the Athena query location are\ndenied.","ref":"AWS.Athena.html#get_query_results/3","title":"AWS.Athena.get_query_results/3","type":"function"},{"doc":"Returns query execution runtime statistics related to a single execution of a\nquery if you have access to the workgroup in which the query ran.\n\nQuery execution runtime statistics are returned only when\n`QueryExecutionStatus$State` is in a SUCCEEDED or FAILED state. Stage-level\ninput and output row count and data size statistics are not shown when a query\nhas row-level filters defined in Lake Formation.","ref":"AWS.Athena.html#get_query_runtime_statistics/3","title":"AWS.Athena.get_query_runtime_statistics/3","type":"function"},{"doc":"Gets the full details of a previously created session, including the session\nstatus and configuration.","ref":"AWS.Athena.html#get_session/3","title":"AWS.Athena.get_session/3","type":"function"},{"doc":"Gets the current status of a session.","ref":"AWS.Athena.html#get_session_status/3","title":"AWS.Athena.get_session_status/3","type":"function"},{"doc":"Returns table metadata for the specified catalog, database, and table.","ref":"AWS.Athena.html#get_table_metadata/3","title":"AWS.Athena.get_table_metadata/3","type":"function"},{"doc":"Returns information about the workgroup with the specified name.","ref":"AWS.Athena.html#get_work_group/3","title":"AWS.Athena.get_work_group/3","type":"function"},{"doc":"Imports a single `ipynb` file to a Spark enabled workgroup.\n\nTo import the notebook, the request must specify a value for either `Payload` or\n`NoteBookS3LocationUri`. If neither is specified or both are specified, an\n`InvalidRequestException` occurs. The maximum file size that can be imported is\n10 megabytes. If an `ipynb` file with the same name already exists in the\nworkgroup, throws an error.","ref":"AWS.Athena.html#import_notebook/3","title":"AWS.Athena.import_notebook/3","type":"function"},{"doc":"Returns the supported DPU sizes for the supported application runtimes (for\nexample, `Athena notebook version 1`).","ref":"AWS.Athena.html#list_application_d_p_u_sizes/3","title":"AWS.Athena.list_application_d_p_u_sizes/3","type":"function"},{"doc":"Lists the calculations that have been submitted to a session in descending\norder.\n\nNewer calculations are listed first; older calculations are listed later.","ref":"AWS.Athena.html#list_calculation_executions/3","title":"AWS.Athena.list_calculation_executions/3","type":"function"},{"doc":"Lists the capacity reservations for the current account.","ref":"AWS.Athena.html#list_capacity_reservations/3","title":"AWS.Athena.list_capacity_reservations/3","type":"function"},{"doc":"Lists the data catalogs in the current Amazon Web Services account.\n\nIn the Athena console, data catalogs are listed as \"data sources\" on the **Data\nsources** page under the **Data source name** column.","ref":"AWS.Athena.html#list_data_catalogs/3","title":"AWS.Athena.list_data_catalogs/3","type":"function"},{"doc":"Lists the databases in the specified data catalog.","ref":"AWS.Athena.html#list_databases/3","title":"AWS.Athena.list_databases/3","type":"function"},{"doc":"Returns a list of engine versions that are available to choose from, including\nthe Auto option.","ref":"AWS.Athena.html#list_engine_versions/3","title":"AWS.Athena.list_engine_versions/3","type":"function"},{"doc":"Lists, in descending order, the executors that joined a session.\n\nNewer executors are listed first; older executors are listed later. The result\ncan be optionally filtered by state.","ref":"AWS.Athena.html#list_executors/3","title":"AWS.Athena.list_executors/3","type":"function"},{"doc":"Provides a list of available query IDs only for queries saved in the specified\nworkgroup.\n\nRequires that you have access to the specified workgroup. If a workgroup is not\nspecified, lists the saved queries for the primary workgroup.","ref":"AWS.Athena.html#list_named_queries/3","title":"AWS.Athena.list_named_queries/3","type":"function"},{"doc":"Displays the notebook files for the specified workgroup in paginated format.","ref":"AWS.Athena.html#list_notebook_metadata/3","title":"AWS.Athena.list_notebook_metadata/3","type":"function"},{"doc":"Lists, in descending order, the sessions that have been created in a notebook\nthat are in an active state like `CREATING`, `CREATED`, `IDLE` or `BUSY`.\n\nNewer sessions are listed first; older sessions are listed later.","ref":"AWS.Athena.html#list_notebook_sessions/3","title":"AWS.Athena.list_notebook_sessions/3","type":"function"},{"doc":"Lists the prepared statements in the specified workgroup.","ref":"AWS.Athena.html#list_prepared_statements/3","title":"AWS.Athena.list_prepared_statements/3","type":"function"},{"doc":"Provides a list of available query execution IDs for the queries in the\nspecified workgroup.\n\nAthena keeps a query history for 45 days. If a workgroup is not specified,\nreturns a list of query execution IDs for the primary workgroup. Requires you to\nhave access to the workgroup in which the queries ran.","ref":"AWS.Athena.html#list_query_executions/3","title":"AWS.Athena.list_query_executions/3","type":"function"},{"doc":"Lists the sessions in a workgroup that are in an active state like `CREATING`,\n`CREATED`, `IDLE`, or `BUSY`.\n\nNewer sessions are listed first; older sessions are listed later.","ref":"AWS.Athena.html#list_sessions/3","title":"AWS.Athena.list_sessions/3","type":"function"},{"doc":"Lists the metadata for the tables in the specified data catalog database.","ref":"AWS.Athena.html#list_table_metadata/3","title":"AWS.Athena.list_table_metadata/3","type":"function"},{"doc":"Lists the tags associated with an Athena resource.","ref":"AWS.Athena.html#list_tags_for_resource/3","title":"AWS.Athena.list_tags_for_resource/3","type":"function"},{"doc":"Lists available workgroups for the account.","ref":"AWS.Athena.html#list_work_groups/3","title":"AWS.Athena.list_work_groups/3","type":"function"},{"doc":"","ref":"AWS.Athena.html#metadata/0","title":"AWS.Athena.metadata/0","type":"function"},{"doc":"Puts a new capacity assignment configuration for a specified capacity\nreservation.\n\nIf a capacity assignment configuration already exists for the capacity\nreservation, replaces the existing capacity assignment configuration.","ref":"AWS.Athena.html#put_capacity_assignment_configuration/3","title":"AWS.Athena.put_capacity_assignment_configuration/3","type":"function"},{"doc":"Submits calculations for execution within a session.\n\nYou can supply the code to run as an inline code block within the request.\n\nThe request syntax requires the `StartCalculationExecutionRequest$CodeBlock`\nparameter or the `CalculationConfiguration$CodeBlock` parameter, but not both.\nBecause `CalculationConfiguration$CodeBlock` is deprecated, use the\n`StartCalculationExecutionRequest$CodeBlock` parameter instead.","ref":"AWS.Athena.html#start_calculation_execution/3","title":"AWS.Athena.start_calculation_execution/3","type":"function"},{"doc":"Runs the SQL query statements contained in the `Query`.\n\nRequires you to have access to the workgroup in which the query ran. Running\nqueries against an external catalog requires `GetDataCatalog` permission to the\ncatalog. For code samples using the Amazon Web Services SDK for Java, see\n[Examples and Code Samples](http://docs.aws.amazon.com/athena/latest/ug/code-samples.html) in the\n*Amazon Athena User Guide*.","ref":"AWS.Athena.html#start_query_execution/3","title":"AWS.Athena.start_query_execution/3","type":"function"},{"doc":"Creates a session for running calculations within a workgroup.\n\nThe session is ready when it reaches an `IDLE` state.","ref":"AWS.Athena.html#start_session/3","title":"AWS.Athena.start_session/3","type":"function"},{"doc":"Requests the cancellation of a calculation.\n\nA `StopCalculationExecution` call on a calculation that is already in a terminal\nstate (for example, `STOPPED`, `FAILED`, or `COMPLETED`) succeeds but has no\neffect.\n\nCancelling a calculation is done on a best effort basis. If a calculation cannot\nbe cancelled, you can be charged for its completion. If you are concerned about\nbeing charged for a calculation that cannot be cancelled, consider terminating\nthe session in which the calculation is running.","ref":"AWS.Athena.html#stop_calculation_execution/3","title":"AWS.Athena.stop_calculation_execution/3","type":"function"},{"doc":"Stops a query execution.\n\nRequires you to have access to the workgroup in which the query ran.","ref":"AWS.Athena.html#stop_query_execution/3","title":"AWS.Athena.stop_query_execution/3","type":"function"},{"doc":"Adds one or more tags to an Athena resource.\n\nA tag is a label that you assign to a resource. Each tag consists of a key and\nan optional value, both of which you define. For example, you can use tags to\ncategorize Athena workgroups, data catalogs, or capacity reservations by\npurpose, owner, or environment. Use a consistent set of tag keys to make it\neasier to search and filter the resources in your account. For best practices,\nsee [Tagging Best Practices](https://docs.aws.amazon.com/whitepapers/latest/tagging-best-practices/tagging-best-practices.html).\nTag keys can be from 1 to 128 UTF-8 Unicode characters, and tag values can be\nfrom 0 to 256 UTF-8 Unicode characters. Tags can use letters and numbers\nrepresentable in UTF-8, and the following characters: + - = . _ : / @. Tag keys\nand values are case-sensitive. Tag keys must be unique per resource. If you\nspecify more than one tag, separate them by commas.","ref":"AWS.Athena.html#tag_resource/3","title":"AWS.Athena.tag_resource/3","type":"function"},{"doc":"Terminates an active session.\n\nA `TerminateSession` call on a session that is already inactive (for example, in\na `FAILED`, `TERMINATED` or `TERMINATING` state) succeeds but has no effect.\nCalculations running in the session when `TerminateSession` is called are\nforcefully stopped, but may display as `FAILED` instead of `STOPPED`.","ref":"AWS.Athena.html#terminate_session/3","title":"AWS.Athena.terminate_session/3","type":"function"},{"doc":"Removes one or more tags from an Athena resource.","ref":"AWS.Athena.html#untag_resource/3","title":"AWS.Athena.untag_resource/3","type":"function"},{"doc":"Updates the number of requested data processing units for the capacity\nreservation with the specified name.","ref":"AWS.Athena.html#update_capacity_reservation/3","title":"AWS.Athena.update_capacity_reservation/3","type":"function"},{"doc":"Updates the data catalog that has the specified name.","ref":"AWS.Athena.html#update_data_catalog/3","title":"AWS.Athena.update_data_catalog/3","type":"function"},{"doc":"Updates a `NamedQuery` object.\n\nThe database or workgroup cannot be updated.","ref":"AWS.Athena.html#update_named_query/3","title":"AWS.Athena.update_named_query/3","type":"function"},{"doc":"Updates the contents of a Spark notebook.","ref":"AWS.Athena.html#update_notebook/3","title":"AWS.Athena.update_notebook/3","type":"function"},{"doc":"Updates the metadata for a notebook.","ref":"AWS.Athena.html#update_notebook_metadata/3","title":"AWS.Athena.update_notebook_metadata/3","type":"function"},{"doc":"Updates a prepared statement.","ref":"AWS.Athena.html#update_prepared_statement/3","title":"AWS.Athena.update_prepared_statement/3","type":"function"},{"doc":"Updates the workgroup with the specified name.\n\nThe workgroup's name cannot be changed. Only `ConfigurationUpdates` can be\nspecified.","ref":"AWS.Athena.html#update_work_group/3","title":"AWS.Athena.update_work_group/3","type":"function"},{"doc":"Welcome to the Audit Manager API reference.\n\nThis guide is for developers who need detailed information about the Audit\nManager API operations, data types, and errors.\n\nAudit Manager is a service that provides automated evidence collection so that\nyou can continually audit your Amazon Web Services usage. You can use it to\nassess the effectiveness of your controls, manage risk, and simplify compliance.\n\nAudit Manager provides prebuilt frameworks that structure and automate\nassessments for a given compliance standard. Frameworks include a prebuilt\ncollection of controls with descriptions and testing procedures. These controls\nare grouped according to the requirements of the specified compliance standard\nor regulation. You can also customize frameworks and controls to support\ninternal audits with specific requirements.\n\nUse the following links to get started with the Audit Manager API:\n\n  *\n[Actions](https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_Operations.html): An alphabetical list of all Audit Manager API operations.\n\n  * [Data\ntypes](https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_Types.html):\nAn alphabetical list of all Audit Manager data types.\n\n  * [Common parameters](https://docs.aws.amazon.com/audit-manager/latest/APIReference/CommonParameters.html):\nParameters that all operations can use.\n\n  * [Common errors](https://docs.aws.amazon.com/audit-manager/latest/APIReference/CommonErrors.html):\nClient and server errors that all operations can return.\n\nIf you're new to Audit Manager, we recommend that you review the [ Audit Manager User\nGuide](https://docs.aws.amazon.com/audit-manager/latest/userguide/what-is.html).","ref":"AWS.AuditManager.html","title":"AWS.AuditManager","type":"module"},{"doc":"Associates an evidence folder to an assessment report in an Audit Manager\nassessment.","ref":"AWS.AuditManager.html#associate_assessment_report_evidence_folder/4","title":"AWS.AuditManager.associate_assessment_report_evidence_folder/4","type":"function"},{"doc":"Associates a list of evidence to an assessment report in an Audit Manager\nassessment.","ref":"AWS.AuditManager.html#batch_associate_assessment_report_evidence/4","title":"AWS.AuditManager.batch_associate_assessment_report_evidence/4","type":"function"},{"doc":"Creates a batch of delegations for an assessment in Audit Manager.","ref":"AWS.AuditManager.html#batch_create_delegation_by_assessment/4","title":"AWS.AuditManager.batch_create_delegation_by_assessment/4","type":"function"},{"doc":"Deletes a batch of delegations for an assessment in Audit Manager.","ref":"AWS.AuditManager.html#batch_delete_delegation_by_assessment/4","title":"AWS.AuditManager.batch_delete_delegation_by_assessment/4","type":"function"},{"doc":"Disassociates a list of evidence from an assessment report in Audit Manager.","ref":"AWS.AuditManager.html#batch_disassociate_assessment_report_evidence/4","title":"AWS.AuditManager.batch_disassociate_assessment_report_evidence/4","type":"function"},{"doc":"Adds one or more pieces of evidence to a control in an Audit Manager assessment.\n\nYou can import manual evidence from any S3 bucket by specifying the S3 URI of\nthe object. You can also upload a file from your browser, or enter plain text in\nresponse to a risk assessment question.\n\nThe following restrictions apply to this action:\n\n  * `manualEvidence` can be only one of the following:\n`evidenceFileName`, `s3ResourcePath`, or `textResponse`\n\n  * Maximum size of an individual evidence file: 100 MB\n\n  * Number of daily manual evidence uploads per control: 100\n\n  * Supported file formats: See [Supported file types for manual evidence](https://docs.aws.amazon.com/audit-manager/latest/userguide/upload-evidence.html#supported-manual-evidence-files)\nin the *Audit Manager User Guide*\n\nFor more information about Audit Manager service restrictions, see [Quotas and restrictions for Audit\nManager](https://docs.aws.amazon.com/audit-manager/latest/userguide/service-quotas.html).","ref":"AWS.AuditManager.html#batch_import_evidence_to_assessment_control/6","title":"AWS.AuditManager.batch_import_evidence_to_assessment_control/6","type":"function"},{"doc":"Creates an assessment in Audit Manager.","ref":"AWS.AuditManager.html#create_assessment/3","title":"AWS.AuditManager.create_assessment/3","type":"function"},{"doc":"Creates a custom framework in Audit Manager.","ref":"AWS.AuditManager.html#create_assessment_framework/3","title":"AWS.AuditManager.create_assessment_framework/3","type":"function"},{"doc":"Creates an assessment report for the specified assessment.","ref":"AWS.AuditManager.html#create_assessment_report/4","title":"AWS.AuditManager.create_assessment_report/4","type":"function"},{"doc":"Creates a new custom control in Audit Manager.","ref":"AWS.AuditManager.html#create_control/3","title":"AWS.AuditManager.create_control/3","type":"function"},{"doc":"Deletes an assessment in Audit Manager.","ref":"AWS.AuditManager.html#delete_assessment/4","title":"AWS.AuditManager.delete_assessment/4","type":"function"},{"doc":"Deletes a custom framework in Audit Manager.","ref":"AWS.AuditManager.html#delete_assessment_framework/4","title":"AWS.AuditManager.delete_assessment_framework/4","type":"function"},{"doc":"Deletes a share request for a custom framework in Audit Manager.","ref":"AWS.AuditManager.html#delete_assessment_framework_share/4","title":"AWS.AuditManager.delete_assessment_framework_share/4","type":"function"},{"doc":"Deletes an assessment report in Audit Manager.\n\nWhen you run the `DeleteAssessmentReport` operation, Audit Manager attempts to\ndelete the following data:\n\n  1. The specified assessment report that’s stored in your S3 bucket\n\n  2. The associated metadata that’s stored in Audit Manager\n\nIf Audit Manager can’t access the assessment report in your S3 bucket, the\nreport isn’t deleted. In this event, the `DeleteAssessmentReport` operation\ndoesn’t fail. Instead, it proceeds to delete the associated metadata only. You\nmust then delete the assessment report from the S3 bucket yourself.\n\nThis scenario happens when Audit Manager receives a `403 (Forbidden)` or `404\n(Not Found)` error from Amazon S3. To avoid this, make sure that your S3 bucket\nis available, and that you configured the correct permissions for Audit Manager\nto delete resources in your S3 bucket. For an example permissions policy that\nyou can use, see [Assessment report destination permissions](https://docs.aws.amazon.com/audit-manager/latest/userguide/security_iam_id-based-policy-examples.html#full-administrator-access-assessment-report-destination)\nin the *Audit Manager User Guide*. For information about the issues that could\ncause a `403 (Forbidden)` or `404 (Not Found`) error from Amazon S3, see [List of Error\nCodes](https://docs.aws.amazon.com/AmazonS3/latest/API/ErrorResponses.html#ErrorCodeList)\nin the *Amazon Simple Storage Service API Reference*.","ref":"AWS.AuditManager.html#delete_assessment_report/5","title":"AWS.AuditManager.delete_assessment_report/5","type":"function"},{"doc":"Deletes a custom control in Audit Manager.\n\nWhen you invoke this operation, the custom control is deleted from any\nframeworks or assessments that it’s currently part of. As a result, Audit\nManager will stop collecting evidence for that custom control in all of your\nassessments. This includes assessments that you previously created before you\ndeleted the custom control.","ref":"AWS.AuditManager.html#delete_control/4","title":"AWS.AuditManager.delete_control/4","type":"function"},{"doc":"Deregisters an account in Audit Manager.\n\nBefore you deregister, you can use the\n[UpdateSettings](https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_UpdateSettings.html) API operation to set your preferred data retention policy. By default, Audit\nManager retains your data. If you want to delete your data, you can use the\n`DeregistrationPolicy` attribute to request the deletion of your data.\n\nFor more information about data retention, see [Data\nProtection](https://docs.aws.amazon.com/audit-manager/latest/userguide/data-protection.html)\nin the *Audit Manager User Guide*.","ref":"AWS.AuditManager.html#deregister_account/3","title":"AWS.AuditManager.deregister_account/3","type":"function"},{"doc":"Removes the specified Amazon Web Services account as a delegated administrator\nfor Audit Manager.\n\nWhen you remove a delegated administrator from your Audit Manager settings, you\ncontinue to have access to the evidence that you previously collected under that\naccount. This is also the case when you deregister a delegated administrator\nfrom Organizations. However, Audit Manager stops collecting and attaching\nevidence to that delegated administrator account moving forward.\n\nKeep in mind the following cleanup task if you use evidence finder:\n\nBefore you use your management account to remove a delegated administrator, make\nsure that the current delegated administrator account signs in to Audit Manager\nand disables evidence finder first. Disabling evidence finder automatically\ndeletes the event data store that was created in their account when they enabled\nevidence finder. If this task isn’t completed, the event data store remains in\ntheir account. In this case, we recommend that the original delegated\nadministrator goes to CloudTrail Lake and manually [deletes the event data store](https://docs.aws.amazon.com/awscloudtrail/latest/userguide/query-eds-disable-termination.html).\n\nThis cleanup task is necessary to ensure that you don't end up with multiple\nevent data stores. Audit Manager ignores an unused event data store after you\nremove or change a delegated administrator account. However, the unused event\ndata store continues to incur storage costs from CloudTrail Lake if you don't\ndelete it.\n\nWhen you deregister a delegated administrator account for Audit Manager, the\ndata for that account isn’t deleted. If you want to delete resource data for a\ndelegated administrator account, you must perform that task separately before\nyou deregister the account. Either, you can do this in the Audit Manager\nconsole. Or, you can use one of the delete API operations that are provided by\nAudit Manager.\n\nTo delete your Audit Manager resource data, see the following instructions:\n\n  *\n[DeleteAssessment](https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_DeleteAssessment.html) (see also: [Deleting an\nassessment](https://docs.aws.amazon.com/audit-manager/latest/userguide/delete-assessment.html)\nin the *Audit Manager User Guide*)\n\n  *\n[DeleteAssessmentFramework](https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_DeleteAssessmentFramework.html) (see also: [Deleting a custom\nframework](https://docs.aws.amazon.com/audit-manager/latest/userguide/delete-custom-framework.html)\nin the *Audit Manager User Guide*)\n\n  *\n[DeleteAssessmentFrameworkShare](https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_DeleteAssessmentFrameworkShare.html) (see also: [Deleting a share\nrequest](https://docs.aws.amazon.com/audit-manager/latest/userguide/deleting-shared-framework-requests.html)\nin the *Audit Manager User Guide*)\n\n  *\n[DeleteAssessmentReport](https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_DeleteAssessmentReport.html) (see also: [Deleting an assessment\nreport](https://docs.aws.amazon.com/audit-manager/latest/userguide/generate-assessment-report.html#delete-assessment-report-steps)\nin the *Audit Manager User Guide*)\n\n  *\n[DeleteControl](https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_DeleteControl.html) (see also: [Deleting a custom\ncontrol](https://docs.aws.amazon.com/audit-manager/latest/userguide/delete-controls.html)\nin the *Audit Manager User Guide*)\n\nAt this time, Audit Manager doesn't provide an option to delete evidence for a\nspecific delegated administrator. Instead, when your management account\nderegisters Audit Manager, we perform a cleanup for the current delegated\nadministrator account at the time of deregistration.","ref":"AWS.AuditManager.html#deregister_organization_admin_account/3","title":"AWS.AuditManager.deregister_organization_admin_account/3","type":"function"},{"doc":"Disassociates an evidence folder from the specified assessment report in Audit\nManager.","ref":"AWS.AuditManager.html#disassociate_assessment_report_evidence_folder/4","title":"AWS.AuditManager.disassociate_assessment_report_evidence_folder/4","type":"function"},{"doc":"Gets the registration status of an account in Audit Manager.","ref":"AWS.AuditManager.html#get_account_status/2","title":"AWS.AuditManager.get_account_status/2","type":"function"},{"doc":"Gets information about a specified assessment.","ref":"AWS.AuditManager.html#get_assessment/3","title":"AWS.AuditManager.get_assessment/3","type":"function"},{"doc":"Gets information about a specified framework.","ref":"AWS.AuditManager.html#get_assessment_framework/3","title":"AWS.AuditManager.get_assessment_framework/3","type":"function"},{"doc":"Gets the URL of an assessment report in Audit Manager.","ref":"AWS.AuditManager.html#get_assessment_report_url/4","title":"AWS.AuditManager.get_assessment_report_url/4","type":"function"},{"doc":"Gets a list of changelogs from Audit Manager.","ref":"AWS.AuditManager.html#get_change_logs/7","title":"AWS.AuditManager.get_change_logs/7","type":"function"},{"doc":"Gets information about a specified control.","ref":"AWS.AuditManager.html#get_control/3","title":"AWS.AuditManager.get_control/3","type":"function"},{"doc":"Gets a list of delegations from an audit owner to a delegate.","ref":"AWS.AuditManager.html#get_delegations/4","title":"AWS.AuditManager.get_delegations/4","type":"function"},{"doc":"Gets information about a specified evidence item.","ref":"AWS.AuditManager.html#get_evidence/6","title":"AWS.AuditManager.get_evidence/6","type":"function"},{"doc":"Gets all evidence from a specified evidence folder in Audit Manager.","ref":"AWS.AuditManager.html#get_evidence_by_evidence_folder/7","title":"AWS.AuditManager.get_evidence_by_evidence_folder/7","type":"function"},{"doc":"Creates a presigned Amazon S3 URL that can be used to upload a file as manual\nevidence.\n\nFor instructions on how to use this operation, see [Upload a file from your browser\n](https://docs.aws.amazon.com/audit-manager/latest/userguide/upload-evidence.html#how-to-upload-manual-evidence-files)\nin the *Audit Manager User Guide*.\n\nThe following restrictions apply to this operation:\n\n  * Maximum size of an individual evidence file: 100 MB\n\n  * Number of daily manual evidence uploads per control: 100\n\n  * Supported file formats: See [Supported file types for manual evidence](https://docs.aws.amazon.com/audit-manager/latest/userguide/upload-evidence.html#supported-manual-evidence-files)\nin the *Audit Manager User Guide*\n\nFor more information about Audit Manager service restrictions, see [Quotas and restrictions for Audit\nManager](https://docs.aws.amazon.com/audit-manager/latest/userguide/service-quotas.html).","ref":"AWS.AuditManager.html#get_evidence_file_upload_url/3","title":"AWS.AuditManager.get_evidence_file_upload_url/3","type":"function"},{"doc":"Gets an evidence folder from a specified assessment in Audit Manager.","ref":"AWS.AuditManager.html#get_evidence_folder/5","title":"AWS.AuditManager.get_evidence_folder/5","type":"function"},{"doc":"Gets the evidence folders from a specified assessment in Audit Manager.","ref":"AWS.AuditManager.html#get_evidence_folders_by_assessment/5","title":"AWS.AuditManager.get_evidence_folders_by_assessment/5","type":"function"},{"doc":"Gets a list of evidence folders that are associated with a specified control in\nan Audit Manager assessment.","ref":"AWS.AuditManager.html#get_evidence_folders_by_assessment_control/7","title":"AWS.AuditManager.get_evidence_folders_by_assessment_control/7","type":"function"},{"doc":"Gets the latest analytics data for all your current active assessments.","ref":"AWS.AuditManager.html#get_insights/2","title":"AWS.AuditManager.get_insights/2","type":"function"},{"doc":"Gets the latest analytics data for a specific active assessment.","ref":"AWS.AuditManager.html#get_insights_by_assessment/3","title":"AWS.AuditManager.get_insights_by_assessment/3","type":"function"},{"doc":"Gets the name of the delegated Amazon Web Services administrator account for a\nspecified organization.","ref":"AWS.AuditManager.html#get_organization_admin_account/2","title":"AWS.AuditManager.get_organization_admin_account/2","type":"function"},{"doc":"Gets a list of all of the Amazon Web Services that you can choose to include in\nyour assessment.\n\nWhen you [create an assessment](https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_CreateAssessment.html),\nspecify which of these services you want to include to narrow the assessment's\n[scope](https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_Scope.html).","ref":"AWS.AuditManager.html#get_services_in_scope/2","title":"AWS.AuditManager.get_services_in_scope/2","type":"function"},{"doc":"Gets the settings for a specified Amazon Web Services account.","ref":"AWS.AuditManager.html#get_settings/3","title":"AWS.AuditManager.get_settings/3","type":"function"},{"doc":"Lists the latest analytics data for controls within a specific control domain\nand a specific active assessment.\n\nControl insights are listed only if the control belongs to the control domain\nand assessment that was specified. Moreover, the control must have collected\nevidence on the `lastUpdated` date of `controlInsightsByAssessment`. If neither\nof these conditions are met, no data is listed for that control.","ref":"AWS.AuditManager.html#list_assessment_control_insights_by_control_domain/6","title":"AWS.AuditManager.list_assessment_control_insights_by_control_domain/6","type":"function"},{"doc":"Returns a list of sent or received share requests for custom frameworks in Audit\nManager.","ref":"AWS.AuditManager.html#list_assessment_framework_share_requests/5","title":"AWS.AuditManager.list_assessment_framework_share_requests/5","type":"function"},{"doc":"Returns a list of the frameworks that are available in the Audit Manager\nframework library.","ref":"AWS.AuditManager.html#list_assessment_frameworks/5","title":"AWS.AuditManager.list_assessment_frameworks/5","type":"function"},{"doc":"Returns a list of assessment reports created in Audit Manager.","ref":"AWS.AuditManager.html#list_assessment_reports/4","title":"AWS.AuditManager.list_assessment_reports/4","type":"function"},{"doc":"Returns a list of current and past assessments from Audit Manager.","ref":"AWS.AuditManager.html#list_assessments/5","title":"AWS.AuditManager.list_assessments/5","type":"function"},{"doc":"Lists the latest analytics data for control domains across all of your active\nassessments.\n\nA control domain is listed only if at least one of the controls within that\ndomain collected evidence on the `lastUpdated` date of `controlDomainInsights`.\nIf this condition isn’t met, no data is listed for that control domain.","ref":"AWS.AuditManager.html#list_control_domain_insights/4","title":"AWS.AuditManager.list_control_domain_insights/4","type":"function"},{"doc":"Lists analytics data for control domains within a specified active assessment.\n\nA control domain is listed only if at least one of the controls within that\ndomain collected evidence on the `lastUpdated` date of `controlDomainInsights`.\nIf this condition isn’t met, no data is listed for that domain.","ref":"AWS.AuditManager.html#list_control_domain_insights_by_assessment/5","title":"AWS.AuditManager.list_control_domain_insights_by_assessment/5","type":"function"},{"doc":"Lists the latest analytics data for controls within a specific control domain\nacross all active assessments.\n\nControl insights are listed only if the control belongs to the control domain\nthat was specified and the control collected evidence on the `lastUpdated` date\nof `controlInsightsMetadata`. If neither of these conditions are met, no data is\nlisted for that control.","ref":"AWS.AuditManager.html#list_control_insights_by_control_domain/5","title":"AWS.AuditManager.list_control_insights_by_control_domain/5","type":"function"},{"doc":"Returns a list of controls from Audit Manager.","ref":"AWS.AuditManager.html#list_controls/5","title":"AWS.AuditManager.list_controls/5","type":"function"},{"doc":"Returns a list of keywords that are pre-mapped to the specified control data\nsource.","ref":"AWS.AuditManager.html#list_keywords_for_data_source/5","title":"AWS.AuditManager.list_keywords_for_data_source/5","type":"function"},{"doc":"Returns a list of all Audit Manager notifications.","ref":"AWS.AuditManager.html#list_notifications/4","title":"AWS.AuditManager.list_notifications/4","type":"function"},{"doc":"Returns a list of tags for the specified resource in Audit Manager.","ref":"AWS.AuditManager.html#list_tags_for_resource/3","title":"AWS.AuditManager.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.AuditManager.html#metadata/0","title":"AWS.AuditManager.metadata/0","type":"function"},{"doc":"Enables Audit Manager for the specified Amazon Web Services account.","ref":"AWS.AuditManager.html#register_account/3","title":"AWS.AuditManager.register_account/3","type":"function"},{"doc":"Enables an Amazon Web Services account within the organization as the delegated\nadministrator for Audit Manager.","ref":"AWS.AuditManager.html#register_organization_admin_account/3","title":"AWS.AuditManager.register_organization_admin_account/3","type":"function"},{"doc":"Creates a share request for a custom framework in Audit Manager.\n\nThe share request specifies a recipient and notifies them that a custom\nframework is available. Recipients have 120 days to accept or decline the\nrequest. If no action is taken, the share request expires.\n\nWhen you create a share request, Audit Manager stores a snapshot of your custom\nframework in the US East (N. Virginia) Amazon Web Services Region. Audit Manager\nalso stores a backup of the same snapshot in the US West (Oregon) Amazon Web\nServices Region.\n\nAudit Manager deletes the snapshot and the backup snapshot when one of the\nfollowing events occurs:\n\n  * The sender revokes the share request.\n\n  * The recipient declines the share request.\n\n  * The recipient encounters an error and doesn't successfully accept\nthe share request.\n\n  * The share request expires before the recipient responds to the\nrequest.\n\nWhen a sender [resends a share request](https://docs.aws.amazon.com/audit-manager/latest/userguide/framework-sharing.html#framework-sharing-resend),\nthe snapshot is replaced with an updated version that corresponds with the\nlatest version of the custom framework.\n\nWhen a recipient accepts a share request, the snapshot is replicated into their\nAmazon Web Services account under the Amazon Web Services Region that was\nspecified in the share request.\n\nWhen you invoke the `StartAssessmentFrameworkShare` API, you are about to share\na custom framework with another Amazon Web Services account. You may not share a\ncustom framework that is derived from a standard framework if the standard\nframework is designated as not eligible for sharing by Amazon Web Services,\nunless you have obtained permission to do so from the owner of the standard\nframework. To learn more about which standard frameworks are eligible for\nsharing, see [Framework sharing eligibility](https://docs.aws.amazon.com/audit-manager/latest/userguide/share-custom-framework-concepts-and-terminology.html#eligibility)\nin the *Audit Manager User Guide*.","ref":"AWS.AuditManager.html#start_assessment_framework_share/4","title":"AWS.AuditManager.start_assessment_framework_share/4","type":"function"},{"doc":"Tags the specified resource in Audit Manager.","ref":"AWS.AuditManager.html#tag_resource/4","title":"AWS.AuditManager.tag_resource/4","type":"function"},{"doc":"Removes a tag from a resource in Audit Manager.","ref":"AWS.AuditManager.html#untag_resource/4","title":"AWS.AuditManager.untag_resource/4","type":"function"},{"doc":"Edits an Audit Manager assessment.","ref":"AWS.AuditManager.html#update_assessment/4","title":"AWS.AuditManager.update_assessment/4","type":"function"},{"doc":"Updates a control within an assessment in Audit Manager.","ref":"AWS.AuditManager.html#update_assessment_control/6","title":"AWS.AuditManager.update_assessment_control/6","type":"function"},{"doc":"Updates the status of a control set in an Audit Manager assessment.","ref":"AWS.AuditManager.html#update_assessment_control_set_status/5","title":"AWS.AuditManager.update_assessment_control_set_status/5","type":"function"},{"doc":"Updates a custom framework in Audit Manager.","ref":"AWS.AuditManager.html#update_assessment_framework/4","title":"AWS.AuditManager.update_assessment_framework/4","type":"function"},{"doc":"Updates a share request for a custom framework in Audit Manager.","ref":"AWS.AuditManager.html#update_assessment_framework_share/4","title":"AWS.AuditManager.update_assessment_framework_share/4","type":"function"},{"doc":"Updates the status of an assessment in Audit Manager.","ref":"AWS.AuditManager.html#update_assessment_status/4","title":"AWS.AuditManager.update_assessment_status/4","type":"function"},{"doc":"Updates a custom control in Audit Manager.","ref":"AWS.AuditManager.html#update_control/4","title":"AWS.AuditManager.update_control/4","type":"function"},{"doc":"Updates Audit Manager settings for the current account.","ref":"AWS.AuditManager.html#update_settings/3","title":"AWS.AuditManager.update_settings/3","type":"function"},{"doc":"Validates the integrity of an assessment report in Audit Manager.","ref":"AWS.AuditManager.html#validate_assessment_report_integrity/3","title":"AWS.AuditManager.validate_assessment_report_integrity/3","type":"function"},{"doc":"Amazon EC2 Auto Scaling\n\nAmazon EC2 Auto Scaling is designed to automatically launch and terminate EC2\ninstances based on user-defined scaling policies, scheduled actions, and health\nchecks.\n\nFor more information, see the [Amazon EC2 Auto Scaling User Guide](https://docs.aws.amazon.com/autoscaling/ec2/userguide/) and the [Amazon EC2 Auto Scaling API\nReference](https://docs.aws.amazon.com/autoscaling/ec2/APIReference/Welcome.html).","ref":"AWS.AutoScaling.html","title":"AWS.AutoScaling","type":"module"},{"doc":"Attaches one or more EC2 instances to the specified Auto Scaling group.\n\nWhen you attach instances, Amazon EC2 Auto Scaling increases the desired\ncapacity of the group by the number of instances being attached. If the number\nof instances being attached plus the desired capacity of the group exceeds the\nmaximum size of the group, the operation fails.\n\nIf there is a Classic Load Balancer attached to your Auto Scaling group, the\ninstances are also registered with the load balancer. If there are target groups\nattached to your Auto Scaling group, the instances are also registered with the\ntarget groups.\n\nFor more information, see [Attach EC2 instances to your Auto Scaling group](https://docs.aws.amazon.com/autoscaling/ec2/userguide/attach-instance-asg.html)\nin the *Amazon EC2 Auto Scaling User Guide*.","ref":"AWS.AutoScaling.html#attach_instances/3","title":"AWS.AutoScaling.attach_instances/3","type":"function"},{"doc":"This API operation is superseded by `AttachTrafficSources`, which can attach\nmultiple traffic sources types.\n\nWe recommend using `AttachTrafficSources` to simplify how you manage traffic\nsources. However, we continue to support `AttachLoadBalancerTargetGroups`. You\ncan use both the original `AttachLoadBalancerTargetGroups` API operation and\n`AttachTrafficSources` on the same Auto Scaling group.\n\nAttaches one or more target groups to the specified Auto Scaling group.\n\nThis operation is used with the following load balancer types:\n\n  * Application Load Balancer - Operates at the application layer\n(layer 7) and supports HTTP and HTTPS.\n\n  * Network Load Balancer - Operates at the transport layer (layer 4)\nand supports TCP, TLS, and UDP.\n\n  * Gateway Load Balancer - Operates at the network layer (layer 3).\n\nTo describe the target groups for an Auto Scaling group, call the\n`DescribeLoadBalancerTargetGroups` API. To detach the target group from the Auto\nScaling group, call the `DetachLoadBalancerTargetGroups` API.\n\nThis operation is additive and does not detach existing target groups or Classic\nLoad Balancers from the Auto Scaling group.\n\nFor more information, see [Use Elastic Load Balancing to distribute traffic across the instances in your Auto Scaling\ngroup](https://docs.aws.amazon.com/autoscaling/ec2/userguide/autoscaling-load-balancer.html)\nin the *Amazon EC2 Auto Scaling User Guide*.","ref":"AWS.AutoScaling.html#attach_load_balancer_target_groups/3","title":"AWS.AutoScaling.attach_load_balancer_target_groups/3","type":"function"},{"doc":"This API operation is superseded by `AttachTrafficSources`, which can attach\nmultiple traffic sources types.\n\nWe recommend using `AttachTrafficSources` to simplify how you manage traffic\nsources. However, we continue to support `AttachLoadBalancers`. You can use both\nthe original `AttachLoadBalancers` API operation and `AttachTrafficSources` on\nthe same Auto Scaling group.\n\nAttaches one or more Classic Load Balancers to the specified Auto Scaling group.\nAmazon EC2 Auto Scaling registers the running instances with these Classic Load\nBalancers.\n\nTo describe the load balancers for an Auto Scaling group, call the\n`DescribeLoadBalancers` API. To detach a load balancer from the Auto Scaling\ngroup, call the `DetachLoadBalancers` API.\n\nThis operation is additive and does not detach existing Classic Load Balancers\nor target groups from the Auto Scaling group.\n\nFor more information, see [Use Elastic Load Balancing to distribute traffic across the instances in your Auto Scaling\ngroup](https://docs.aws.amazon.com/autoscaling/ec2/userguide/autoscaling-load-balancer.html)\nin the *Amazon EC2 Auto Scaling User Guide*.","ref":"AWS.AutoScaling.html#attach_load_balancers/3","title":"AWS.AutoScaling.attach_load_balancers/3","type":"function"},{"doc":"Attaches one or more traffic sources to the specified Auto Scaling group.\n\nYou can use any of the following as traffic sources for an Auto Scaling group:\n\n  * Application Load Balancer\n\n  * Classic Load Balancer\n\n  * Gateway Load Balancer\n\n  * Network Load Balancer\n\n  * VPC Lattice\n\nThis operation is additive and does not detach existing traffic sources from the\nAuto Scaling group.\n\nAfter the operation completes, use the `DescribeTrafficSources` API to return\ndetails about the state of the attachments between traffic sources and your Auto\nScaling group. To detach a traffic source from the Auto Scaling group, call the\n`DetachTrafficSources` API.","ref":"AWS.AutoScaling.html#attach_traffic_sources/3","title":"AWS.AutoScaling.attach_traffic_sources/3","type":"function"},{"doc":"Deletes one or more scheduled actions for the specified Auto Scaling group.","ref":"AWS.AutoScaling.html#batch_delete_scheduled_action/3","title":"AWS.AutoScaling.batch_delete_scheduled_action/3","type":"function"},{"doc":"Creates or updates one or more scheduled scaling actions for an Auto Scaling\ngroup.","ref":"AWS.AutoScaling.html#batch_put_scheduled_update_group_action/3","title":"AWS.AutoScaling.batch_put_scheduled_update_group_action/3","type":"function"},{"doc":"Cancels an instance refresh or rollback that is in progress.\n\nIf an instance refresh or rollback is not in progress, an\n`ActiveInstanceRefreshNotFound` error occurs.\n\nThis operation is part of the [instance refresh feature](https://docs.aws.amazon.com/autoscaling/ec2/userguide/asg-instance-refresh.html)\nin Amazon EC2 Auto Scaling, which helps you update instances in your Auto\nScaling group after you make configuration changes.\n\nWhen you cancel an instance refresh, this does not roll back any changes that it\nmade. Use the `RollbackInstanceRefresh` API to roll back instead.","ref":"AWS.AutoScaling.html#cancel_instance_refresh/3","title":"AWS.AutoScaling.cancel_instance_refresh/3","type":"function"},{"doc":"Completes the lifecycle action for the specified token or instance with the\nspecified result.\n\nThis step is a part of the procedure for adding a lifecycle hook to an Auto\nScaling group:\n\n  1. (Optional) Create a launch template or launch configuration with\na user data script that runs while an instance is in a wait state due to a\nlifecycle hook.\n\n  2. (Optional) Create a Lambda function and a rule that allows Amazon\nEventBridge to invoke your Lambda function when an instance is put into a wait\nstate due to a lifecycle hook.\n\n  3. (Optional) Create a notification target and an IAM role. The\ntarget can be either an Amazon SQS queue or an Amazon SNS topic. The role allows\nAmazon EC2 Auto Scaling to publish lifecycle notifications to the target.\n\n  4. Create the lifecycle hook. Specify whether the hook is used when\nthe instances launch or terminate.\n\n  5. If you need more time, record the lifecycle action heartbeat to\nkeep the instance in a wait state.\n\n  6.","ref":"AWS.AutoScaling.html#complete_lifecycle_action/3","title":"AWS.AutoScaling.complete_lifecycle_action/3","type":"function"},{"doc":"by using the `CompleteLifecycleAction` API call.\n\nFor more information, see [Complete a lifecycle action](https://docs.aws.amazon.com/autoscaling/ec2/userguide/completing-lifecycle-hooks.html)\nin the *Amazon EC2 Auto Scaling User Guide*.","ref":"AWS.AutoScaling.html#complete_lifecycle_action/3-if-you-finish-before-the-timeout-period-ends-send-a-callback","title":"If you finish before the timeout period ends, send a callback - AWS.AutoScaling.complete_lifecycle_action/3","type":"function"},{"doc":"","ref":"AWS.AutoScaling.html#create_auto_scaling_group/3","title":"AWS.AutoScaling.create_auto_scaling_group/3","type":"function"},{"doc":"ensure full functionality for Amazon EC2 Auto Scaling and Amazon EC2.\n\nCreates an Auto Scaling group with the specified name and attributes.\n\nIf you exceed your maximum limit of Auto Scaling groups, the call fails. To\nquery this limit, call the `DescribeAccountLimits` API. For information about\nupdating this limit, see [Quotas for Amazon EC2 Auto Scaling](https://docs.aws.amazon.com/autoscaling/ec2/userguide/ec2-auto-scaling-quotas.html)\nin the *Amazon EC2 Auto Scaling User Guide*.\n\nFor introductory exercises for creating an Auto Scaling group, see [Getting started with Amazon EC2 Auto\nScaling](https://docs.aws.amazon.com/autoscaling/ec2/userguide/GettingStartedTutorial.html)\nand [Tutorial: Set up a scaled and load-balanced application](https://docs.aws.amazon.com/autoscaling/ec2/userguide/as-register-lbs-with-asg.html)\nin the *Amazon EC2 Auto Scaling User Guide*. For more information, see [Auto Scaling\ngroups](https://docs.aws.amazon.com/autoscaling/ec2/userguide/AutoScalingGroup.html)\nin the *Amazon EC2 Auto Scaling User Guide*.\n\nEvery Auto Scaling group has three size properties (`DesiredCapacity`,\n`MaxSize`, and `MinSize`). Usually, you set these sizes based on a specific\nnumber of instances. However, if you configure a mixed instances policy that\ndefines weights for the instance types, you must specify these sizes with the\nsame units that you use for weighting instances.","ref":"AWS.AutoScaling.html#create_auto_scaling_group/3-we-strongly-recommend-using-a-launch-template-when-calling-this-operation-to","title":"We strongly recommend using a launch template when calling this operation to - AWS.AutoScaling.create_auto_scaling_group/3","type":"function"},{"doc":"Creates a launch configuration.\n\nIf you exceed your maximum limit of launch configurations, the call fails. To\nquery this limit, call the `DescribeAccountLimits` API. For information about\nupdating this limit, see [Quotas for Amazon EC2 Auto Scaling](https://docs.aws.amazon.com/autoscaling/ec2/userguide/ec2-auto-scaling-quotas.html)\nin the *Amazon EC2 Auto Scaling User Guide*.\n\nFor more information, see [Launch configurations](https://docs.aws.amazon.com/autoscaling/ec2/userguide/LaunchConfiguration.html)\nin the *Amazon EC2 Auto Scaling User Guide*.\n\nAmazon EC2 Auto Scaling configures instances launched as part of an Auto Scaling\ngroup using either a launch template or a launch configuration. We strongly\nrecommend that you do not use launch configurations. They do not provide full\nfunctionality for Amazon EC2 Auto Scaling or Amazon EC2. For information about\nusing launch templates, see [Launch templates](https://docs.aws.amazon.com/autoscaling/ec2/userguide/launch-templates.html)\nin the *Amazon EC2 Auto Scaling User Guide*.","ref":"AWS.AutoScaling.html#create_launch_configuration/3","title":"AWS.AutoScaling.create_launch_configuration/3","type":"function"},{"doc":"Creates or updates tags for the specified Auto Scaling group.\n\nWhen you specify a tag with a key that already exists, the operation overwrites\nthe previous tag definition, and you do not get an error message.\n\nFor more information, see [Tag Auto Scaling groups and instances](https://docs.aws.amazon.com/autoscaling/ec2/userguide/ec2-auto-scaling-tagging.html)\nin the *Amazon EC2 Auto Scaling User Guide*.","ref":"AWS.AutoScaling.html#create_or_update_tags/3","title":"AWS.AutoScaling.create_or_update_tags/3","type":"function"},{"doc":"Deletes the specified Auto Scaling group.\n\nIf the group has instances or scaling activities in progress, you must specify\nthe option to force the deletion in order for it to succeed. The force delete\noperation will also terminate the EC2 instances. If the group has a warm pool,\nthe force delete option also deletes the warm pool.\n\nTo remove instances from the Auto Scaling group before deleting it, call the\n`DetachInstances` API with the list of instances and the option to decrement the\ndesired capacity. This ensures that Amazon EC2 Auto Scaling does not launch\nreplacement instances.\n\nTo terminate all instances before deleting the Auto Scaling group, call the\n`UpdateAutoScalingGroup` API and set the minimum size and desired capacity of\nthe Auto Scaling group to zero.\n\nIf the group has scaling policies, deleting the group deletes the policies, the\nunderlying alarm actions, and any alarm that no longer has an associated action.\n\nFor more information, see [Delete your Auto Scaling infrastructure](https://docs.aws.amazon.com/autoscaling/ec2/userguide/as-process-shutdown.html)\nin the *Amazon EC2 Auto Scaling User Guide*.","ref":"AWS.AutoScaling.html#delete_auto_scaling_group/3","title":"AWS.AutoScaling.delete_auto_scaling_group/3","type":"function"},{"doc":"Deletes the specified launch configuration.\n\nThe launch configuration must not be attached to an Auto Scaling group. When\nthis call completes, the launch configuration is no longer available for use.","ref":"AWS.AutoScaling.html#delete_launch_configuration/3","title":"AWS.AutoScaling.delete_launch_configuration/3","type":"function"},{"doc":"Deletes the specified lifecycle hook.\n\nIf there are any outstanding lifecycle actions, they are completed first\n(`ABANDON` for launching instances, `CONTINUE` for terminating instances).","ref":"AWS.AutoScaling.html#delete_lifecycle_hook/3","title":"AWS.AutoScaling.delete_lifecycle_hook/3","type":"function"},{"doc":"Deletes the specified notification.","ref":"AWS.AutoScaling.html#delete_notification_configuration/3","title":"AWS.AutoScaling.delete_notification_configuration/3","type":"function"},{"doc":"Deletes the specified scaling policy.\n\nDeleting either a step scaling policy or a simple scaling policy deletes the\nunderlying alarm action, but does not delete the alarm, even if it no longer has\nan associated action.\n\nFor more information, see [Deleting a scaling policy](https://docs.aws.amazon.com/autoscaling/ec2/userguide/deleting-scaling-policy.html)\nin the *Amazon EC2 Auto Scaling User Guide*.","ref":"AWS.AutoScaling.html#delete_policy/3","title":"AWS.AutoScaling.delete_policy/3","type":"function"},{"doc":"Deletes the specified scheduled action.","ref":"AWS.AutoScaling.html#delete_scheduled_action/3","title":"AWS.AutoScaling.delete_scheduled_action/3","type":"function"},{"doc":"Deletes the specified tags.","ref":"AWS.AutoScaling.html#delete_tags/3","title":"AWS.AutoScaling.delete_tags/3","type":"function"},{"doc":"Deletes the warm pool for the specified Auto Scaling group.\n\nFor more information, see [Warm pools for Amazon EC2 Auto Scaling](https://docs.aws.amazon.com/autoscaling/ec2/userguide/ec2-auto-scaling-warm-pools.html)\nin the *Amazon EC2 Auto Scaling User Guide*.","ref":"AWS.AutoScaling.html#delete_warm_pool/3","title":"AWS.AutoScaling.delete_warm_pool/3","type":"function"},{"doc":"Describes the current Amazon EC2 Auto Scaling resource quotas for your account.\n\nWhen you establish an Amazon Web Services account, the account has initial\nquotas on the maximum number of Auto Scaling groups and launch configurations\nthat you can create in a given Region. For more information, see [Quotas for Amazon EC2 Auto\nScaling](https://docs.aws.amazon.com/autoscaling/ec2/userguide/ec2-auto-scaling-quotas.html)\nin the *Amazon EC2 Auto Scaling User Guide*.","ref":"AWS.AutoScaling.html#describe_account_limits/3","title":"AWS.AutoScaling.describe_account_limits/3","type":"function"},{"doc":"Describes the available adjustment types for step scaling and simple scaling\npolicies.\n\nThe following adjustment types are supported:\n\n  * `ChangeInCapacity`\n\n  * `ExactCapacity`\n\n  * `PercentChangeInCapacity`","ref":"AWS.AutoScaling.html#describe_adjustment_types/3","title":"AWS.AutoScaling.describe_adjustment_types/3","type":"function"},{"doc":"Gets information about the Auto Scaling groups in the account and Region.\n\nIf you specify Auto Scaling group names, the output includes information for\nonly the specified Auto Scaling groups. If you specify filters, the output\nincludes information for only those Auto Scaling groups that meet the filter\ncriteria. If you do not specify group names or filters, the output includes\ninformation for all Auto Scaling groups.\n\nThis operation also returns information about instances in Auto Scaling groups.\nTo retrieve information about the instances in a warm pool, you must call the\n`DescribeWarmPool` API.","ref":"AWS.AutoScaling.html#describe_auto_scaling_groups/3","title":"AWS.AutoScaling.describe_auto_scaling_groups/3","type":"function"},{"doc":"Gets information about the Auto Scaling instances in the account and Region.","ref":"AWS.AutoScaling.html#describe_auto_scaling_instances/3","title":"AWS.AutoScaling.describe_auto_scaling_instances/3","type":"function"},{"doc":"Describes the notification types that are supported by Amazon EC2 Auto Scaling.","ref":"AWS.AutoScaling.html#describe_auto_scaling_notification_types/3","title":"AWS.AutoScaling.describe_auto_scaling_notification_types/3","type":"function"},{"doc":"Gets information about the instance refreshes for the specified Auto Scaling\ngroup from the previous six weeks.\n\nThis operation is part of the [instance refresh feature](https://docs.aws.amazon.com/autoscaling/ec2/userguide/asg-instance-refresh.html)\nin Amazon EC2 Auto Scaling, which helps you update instances in your Auto\nScaling group after you make configuration changes.\n\nTo help you determine the status of an instance refresh, Amazon EC2 Auto Scaling\nreturns information about the instance refreshes you previously initiated,\nincluding their status, start time, end time, the percentage of the instance\nrefresh that is complete, and the number of instances remaining to update before\nthe instance refresh is complete. If a rollback is initiated while an instance\nrefresh is in progress, Amazon EC2 Auto Scaling also returns information about\nthe rollback of the instance refresh.","ref":"AWS.AutoScaling.html#describe_instance_refreshes/3","title":"AWS.AutoScaling.describe_instance_refreshes/3","type":"function"},{"doc":"Gets information about the launch configurations in the account and Region.","ref":"AWS.AutoScaling.html#describe_launch_configurations/3","title":"AWS.AutoScaling.describe_launch_configurations/3","type":"function"},{"doc":"Describes the available types of lifecycle hooks.\n\nThe following hook types are supported:\n\n  * `autoscaling:EC2_INSTANCE_LAUNCHING`\n\n  * `autoscaling:EC2_INSTANCE_TERMINATING`","ref":"AWS.AutoScaling.html#describe_lifecycle_hook_types/3","title":"AWS.AutoScaling.describe_lifecycle_hook_types/3","type":"function"},{"doc":"Gets information about the lifecycle hooks for the specified Auto Scaling group.","ref":"AWS.AutoScaling.html#describe_lifecycle_hooks/3","title":"AWS.AutoScaling.describe_lifecycle_hooks/3","type":"function"},{"doc":"This API operation is superseded by `DescribeTrafficSources`, which can describe\nmultiple traffic sources types.\n\nWe recommend using `DetachTrafficSources` to simplify how you manage traffic\nsources. However, we continue to support `DescribeLoadBalancerTargetGroups`. You\ncan use both the original `DescribeLoadBalancerTargetGroups` API operation and\n`DescribeTrafficSources` on the same Auto Scaling group.\n\nGets information about the Elastic Load Balancing target groups for the\nspecified Auto Scaling group.\n\nTo determine the attachment status of the target group, use the `State` element\nin the response. When you attach a target group to an Auto Scaling group, the\ninitial `State` value is `Adding`. The state transitions to `Added` after all\nAuto Scaling instances are registered with the target group. If Elastic Load\nBalancing health checks are enabled for the Auto Scaling group, the state\ntransitions to `InService` after at least one Auto Scaling instance passes the\nhealth check. When the target group is in the `InService` state, Amazon EC2 Auto\nScaling can terminate and replace any instances that are reported as unhealthy.\nIf no registered instances pass the health checks, the target group doesn't\nenter the `InService` state.\n\nTarget groups also have an `InService` state if you attach them in the\n`CreateAutoScalingGroup` API call. If your target group state is `InService`,\nbut it is not working properly, check the scaling activities by calling\n`DescribeScalingActivities` and take any corrective actions necessary.\n\nFor help with failed health checks, see [Troubleshooting Amazon EC2 Auto Scaling: Health\nchecks](https://docs.aws.amazon.com/autoscaling/ec2/userguide/ts-as-healthchecks.html)\nin the *Amazon EC2 Auto Scaling User Guide*. For more information, see [Use Elastic Load Balancing to distribute traffic across the instances in your Auto\nScaling\ngroup](https://docs.aws.amazon.com/autoscaling/ec2/userguide/autoscaling-load-balancer.html)\nin the *Amazon EC2 Auto Scaling User Guide*.\n\nYou can use this operation to describe target groups that were attached by using\n`AttachLoadBalancerTargetGroups`, but not for target groups that were attached\nby using `AttachTrafficSources`.","ref":"AWS.AutoScaling.html#describe_load_balancer_target_groups/3","title":"AWS.AutoScaling.describe_load_balancer_target_groups/3","type":"function"},{"doc":"This API operation is superseded by `DescribeTrafficSources`, which can describe\nmultiple traffic sources types.\n\nWe recommend using `DescribeTrafficSources` to simplify how you manage traffic\nsources. However, we continue to support `DescribeLoadBalancers`. You can use\nboth the original `DescribeLoadBalancers` API operation and\n`DescribeTrafficSources` on the same Auto Scaling group.\n\nGets information about the load balancers for the specified Auto Scaling group.\n\nThis operation describes only Classic Load Balancers. If you have Application\nLoad Balancers, Network Load Balancers, or Gateway Load Balancers, use the\n`DescribeLoadBalancerTargetGroups` API instead.\n\nTo determine the attachment status of the load balancer, use the `State` element\nin the response. When you attach a load balancer to an Auto Scaling group, the\ninitial `State` value is `Adding`. The state transitions to `Added` after all\nAuto Scaling instances are registered with the load balancer. If Elastic Load\nBalancing health checks are enabled for the Auto Scaling group, the state\ntransitions to `InService` after at least one Auto Scaling instance passes the\nhealth check. When the load balancer is in the `InService` state, Amazon EC2\nAuto Scaling can terminate and replace any instances that are reported as\nunhealthy. If no registered instances pass the health checks, the load balancer\ndoesn't enter the `InService` state.\n\nLoad balancers also have an `InService` state if you attach them in the\n`CreateAutoScalingGroup` API call. If your load balancer state is `InService`,\nbut it is not working properly, check the scaling activities by calling\n`DescribeScalingActivities` and take any corrective actions necessary.\n\nFor help with failed health checks, see [Troubleshooting Amazon EC2 Auto Scaling: Health\nchecks](https://docs.aws.amazon.com/autoscaling/ec2/userguide/ts-as-healthchecks.html)\nin the *Amazon EC2 Auto Scaling User Guide*. For more information, see [Use Elastic Load Balancing to distribute traffic across the instances in your Auto\nScaling\ngroup](https://docs.aws.amazon.com/autoscaling/ec2/userguide/autoscaling-load-balancer.html)\nin the *Amazon EC2 Auto Scaling User Guide*.","ref":"AWS.AutoScaling.html#describe_load_balancers/3","title":"AWS.AutoScaling.describe_load_balancers/3","type":"function"},{"doc":"Describes the available CloudWatch metrics for Amazon EC2 Auto Scaling.","ref":"AWS.AutoScaling.html#describe_metric_collection_types/3","title":"AWS.AutoScaling.describe_metric_collection_types/3","type":"function"},{"doc":"Gets information about the Amazon SNS notifications that are configured for one\nor more Auto Scaling groups.","ref":"AWS.AutoScaling.html#describe_notification_configurations/3","title":"AWS.AutoScaling.describe_notification_configurations/3","type":"function"},{"doc":"Gets information about the scaling policies in the account and Region.","ref":"AWS.AutoScaling.html#describe_policies/3","title":"AWS.AutoScaling.describe_policies/3","type":"function"},{"doc":"Gets information about the scaling activities in the account and Region.\n\nWhen scaling events occur, you see a record of the scaling activity in the\nscaling activities. For more information, see [Verifying a scaling activity for an Auto Scaling\ngroup](https://docs.aws.amazon.com/autoscaling/ec2/userguide/as-verify-scaling-activity.html)\nin the *Amazon EC2 Auto Scaling User Guide*.\n\nIf the scaling event succeeds, the value of the `StatusCode` element in the\nresponse is `Successful`. If an attempt to launch instances failed, the\n`StatusCode` value is `Failed` or `Cancelled` and the `StatusMessage` element in\nthe response indicates the cause of the failure. For help interpreting the\n`StatusMessage`, see [Troubleshooting Amazon EC2 Auto Scaling](https://docs.aws.amazon.com/autoscaling/ec2/userguide/CHAP_Troubleshooting.html)\nin the *Amazon EC2 Auto Scaling User Guide*.","ref":"AWS.AutoScaling.html#describe_scaling_activities/3","title":"AWS.AutoScaling.describe_scaling_activities/3","type":"function"},{"doc":"Describes the scaling process types for use with the `ResumeProcesses` and\n`SuspendProcesses` APIs.","ref":"AWS.AutoScaling.html#describe_scaling_process_types/3","title":"AWS.AutoScaling.describe_scaling_process_types/3","type":"function"},{"doc":"Gets information about the scheduled actions that haven't run or that have not\nreached their end time.\n\nTo describe the scaling activities for scheduled actions that have already run,\ncall the `DescribeScalingActivities` API.","ref":"AWS.AutoScaling.html#describe_scheduled_actions/3","title":"AWS.AutoScaling.describe_scheduled_actions/3","type":"function"},{"doc":"Describes the specified tags.\n\nYou can use filters to limit the results. For example, you can query for the\ntags for a specific Auto Scaling group. You can specify multiple values for a\nfilter. A tag must match at least one of the specified values for it to be\nincluded in the results.\n\nYou can also specify multiple filters. The result includes information for a\nparticular tag only if it matches all the filters. If there's no match, no\nspecial message is returned.\n\nFor more information, see [Tag Auto Scaling groups and instances](https://docs.aws.amazon.com/autoscaling/ec2/userguide/ec2-auto-scaling-tagging.html)\nin the *Amazon EC2 Auto Scaling User Guide*.","ref":"AWS.AutoScaling.html#describe_tags/3","title":"AWS.AutoScaling.describe_tags/3","type":"function"},{"doc":"Describes the termination policies supported by Amazon EC2 Auto Scaling.\n\nFor more information, see [Work with Amazon EC2 Auto Scaling termination policies](https://docs.aws.amazon.com/autoscaling/ec2/userguide/ec2-auto-scaling-termination-policies.html)\nin the *Amazon EC2 Auto Scaling User Guide*.","ref":"AWS.AutoScaling.html#describe_termination_policy_types/3","title":"AWS.AutoScaling.describe_termination_policy_types/3","type":"function"},{"doc":"Gets information about the traffic sources for the specified Auto Scaling group.\n\nYou can optionally provide a traffic source type. If you provide a traffic\nsource type, then the results only include that traffic source type.\n\nIf you do not provide a traffic source type, then the results include all the\ntraffic sources for the specified Auto Scaling group.","ref":"AWS.AutoScaling.html#describe_traffic_sources/3","title":"AWS.AutoScaling.describe_traffic_sources/3","type":"function"},{"doc":"Gets information about a warm pool and its instances.\n\nFor more information, see [Warm pools for Amazon EC2 Auto Scaling](https://docs.aws.amazon.com/autoscaling/ec2/userguide/ec2-auto-scaling-warm-pools.html)\nin the *Amazon EC2 Auto Scaling User Guide*.","ref":"AWS.AutoScaling.html#describe_warm_pool/3","title":"AWS.AutoScaling.describe_warm_pool/3","type":"function"},{"doc":"Removes one or more instances from the specified Auto Scaling group.\n\nAfter the instances are detached, you can manage them independent of the Auto\nScaling group.\n\nIf you do not specify the option to decrement the desired capacity, Amazon EC2\nAuto Scaling launches instances to replace the ones that are detached.\n\nIf there is a Classic Load Balancer attached to the Auto Scaling group, the\ninstances are deregistered from the load balancer. If there are target groups\nattached to the Auto Scaling group, the instances are deregistered from the\ntarget groups.\n\nFor more information, see [Detach EC2 instances from your Auto Scaling group](https://docs.aws.amazon.com/autoscaling/ec2/userguide/detach-instance-asg.html)\nin the *Amazon EC2 Auto Scaling User Guide*.","ref":"AWS.AutoScaling.html#detach_instances/3","title":"AWS.AutoScaling.detach_instances/3","type":"function"},{"doc":"This API operation is superseded by `DetachTrafficSources`, which can detach\nmultiple traffic sources types.\n\nWe recommend using `DetachTrafficSources` to simplify how you manage traffic\nsources. However, we continue to support `DetachLoadBalancerTargetGroups`. You\ncan use both the original `DetachLoadBalancerTargetGroups` API operation and\n`DetachTrafficSources` on the same Auto Scaling group.\n\nDetaches one or more target groups from the specified Auto Scaling group.\n\nWhen you detach a target group, it enters the `Removing` state while\nderegistering the instances in the group. When all instances are deregistered,\nthen you can no longer describe the target group using the\n`DescribeLoadBalancerTargetGroups` API call. The instances remain running.\n\nYou can use this operation to detach target groups that were attached by using\n`AttachLoadBalancerTargetGroups`, but not for target groups that were attached\nby using `AttachTrafficSources`.","ref":"AWS.AutoScaling.html#detach_load_balancer_target_groups/3","title":"AWS.AutoScaling.detach_load_balancer_target_groups/3","type":"function"},{"doc":"This API operation is superseded by `DetachTrafficSources`, which can detach\nmultiple traffic sources types.\n\nWe recommend using `DetachTrafficSources` to simplify how you manage traffic\nsources. However, we continue to support `DetachLoadBalancers`. You can use both\nthe original `DetachLoadBalancers` API operation and `DetachTrafficSources` on\nthe same Auto Scaling group.\n\nDetaches one or more Classic Load Balancers from the specified Auto Scaling\ngroup.\n\nThis operation detaches only Classic Load Balancers. If you have Application\nLoad Balancers, Network Load Balancers, or Gateway Load Balancers, use the\n`DetachLoadBalancerTargetGroups` API instead.\n\nWhen you detach a load balancer, it enters the `Removing` state while\nderegistering the instances in the group. When all instances are deregistered,\nthen you can no longer describe the load balancer using the\n`DescribeLoadBalancers` API call. The instances remain running.","ref":"AWS.AutoScaling.html#detach_load_balancers/3","title":"AWS.AutoScaling.detach_load_balancers/3","type":"function"},{"doc":"Detaches one or more traffic sources from the specified Auto Scaling group.\n\nWhen you detach a traffic source, it enters the `Removing` state while\nderegistering the instances in the group. When all instances are deregistered,\nthen you can no longer describe the traffic source using the\n`DescribeTrafficSources` API call. The instances continue to run.","ref":"AWS.AutoScaling.html#detach_traffic_sources/3","title":"AWS.AutoScaling.detach_traffic_sources/3","type":"function"},{"doc":"Disables group metrics collection for the specified Auto Scaling group.","ref":"AWS.AutoScaling.html#disable_metrics_collection/3","title":"AWS.AutoScaling.disable_metrics_collection/3","type":"function"},{"doc":"Enables group metrics collection for the specified Auto Scaling group.\n\nYou can use these metrics to track changes in an Auto Scaling group and to set\nalarms on threshold values. You can view group metrics using the Amazon EC2 Auto\nScaling console or the CloudWatch console. For more information, see [Monitor CloudWatch metrics for your Auto Scaling groups and\ninstances](https://docs.aws.amazon.com/autoscaling/ec2/userguide/ec2-auto-scaling-cloudwatch-monitoring.html)\nin the *Amazon EC2 Auto Scaling User Guide*.","ref":"AWS.AutoScaling.html#enable_metrics_collection/3","title":"AWS.AutoScaling.enable_metrics_collection/3","type":"function"},{"doc":"Moves the specified instances into the standby state.\n\nIf you choose to decrement the desired capacity of the Auto Scaling group, the\ninstances can enter standby as long as the desired capacity of the Auto Scaling\ngroup after the instances are placed into standby is equal to or greater than\nthe minimum capacity of the group.\n\nIf you choose not to decrement the desired capacity of the Auto Scaling group,\nthe Auto Scaling group launches new instances to replace the instances on\nstandby.\n\nFor more information, see [Temporarily removing instances from your Auto Scaling group](https://docs.aws.amazon.com/autoscaling/ec2/userguide/as-enter-exit-standby.html)\nin the *Amazon EC2 Auto Scaling User Guide*.","ref":"AWS.AutoScaling.html#enter_standby/3","title":"AWS.AutoScaling.enter_standby/3","type":"function"},{"doc":"Executes the specified policy.\n\nThis can be useful for testing the design of your scaling policy.","ref":"AWS.AutoScaling.html#execute_policy/3","title":"AWS.AutoScaling.execute_policy/3","type":"function"},{"doc":"Moves the specified instances out of the standby state.\n\nAfter you put the instances back in service, the desired capacity is\nincremented.\n\nFor more information, see [Temporarily removing instances from your Auto Scaling group](https://docs.aws.amazon.com/autoscaling/ec2/userguide/as-enter-exit-standby.html)\nin the *Amazon EC2 Auto Scaling User Guide*.","ref":"AWS.AutoScaling.html#exit_standby/3","title":"AWS.AutoScaling.exit_standby/3","type":"function"},{"doc":"Retrieves the forecast data for a predictive scaling policy.\n\nLoad forecasts are predictions of the hourly load values using historical load\ndata from CloudWatch and an analysis of historical trends. Capacity forecasts\nare represented as predicted values for the minimum capacity that is needed on\nan hourly basis, based on the hourly load forecast.\n\nA minimum of 24 hours of data is required to create the initial forecasts.\nHowever, having a full 14 days of historical data results in more accurate\nforecasts.\n\nFor more information, see [Predictive scaling for Amazon EC2 Auto Scaling](https://docs.aws.amazon.com/autoscaling/ec2/userguide/ec2-auto-scaling-predictive-scaling.html)\nin the *Amazon EC2 Auto Scaling User Guide*.","ref":"AWS.AutoScaling.html#get_predictive_scaling_forecast/3","title":"AWS.AutoScaling.get_predictive_scaling_forecast/3","type":"function"},{"doc":"","ref":"AWS.AutoScaling.html#metadata/0","title":"AWS.AutoScaling.metadata/0","type":"function"},{"doc":"Creates or updates a lifecycle hook for the specified Auto Scaling group.\n\nLifecycle hooks let you create solutions that are aware of events in the Auto\nScaling instance lifecycle, and then perform a custom action on instances when\nthe corresponding lifecycle event occurs.\n\nThis step is a part of the procedure for adding a lifecycle hook to an Auto\nScaling group:\n\n  1. (Optional) Create a launch template or launch configuration with\na user data script that runs while an instance is in a wait state due to a\nlifecycle hook.\n\n  2. (Optional) Create a Lambda function and a rule that allows Amazon\nEventBridge to invoke your Lambda function when an instance is put into a wait\nstate due to a lifecycle hook.\n\n  3. (Optional) Create a notification target and an IAM role. The\ntarget can be either an Amazon SQS queue or an Amazon SNS topic. The role allows\nAmazon EC2 Auto Scaling to publish lifecycle notifications to the target.\n\n  4.","ref":"AWS.AutoScaling.html#put_lifecycle_hook/3","title":"AWS.AutoScaling.put_lifecycle_hook/3","type":"function"},{"doc":"when the instances launch or terminate.\n\n  5. If you need more time, record the lifecycle action heartbeat to\nkeep the instance in a wait state using the `RecordLifecycleActionHeartbeat` API\ncall.\n\n  6. If you finish before the timeout period ends, send a callback by\nusing the `CompleteLifecycleAction` API call.\n\nFor more information, see [Amazon EC2 Auto Scaling lifecycle hooks](https://docs.aws.amazon.com/autoscaling/ec2/userguide/lifecycle-hooks.html)\nin the *Amazon EC2 Auto Scaling User Guide*.\n\nIf you exceed your maximum limit of lifecycle hooks, which by default is 50 per\nAuto Scaling group, the call fails.\n\nYou can view the lifecycle hooks for an Auto Scaling group using the\n`DescribeLifecycleHooks` API call. If you are no longer using a lifecycle hook,\nyou can delete it by calling the `DeleteLifecycleHook` API.","ref":"AWS.AutoScaling.html#put_lifecycle_hook/3-create-the-lifecycle-hook-specify-whether-the-hook-is-used","title":"Create the lifecycle hook. Specify whether the hook is used - AWS.AutoScaling.put_lifecycle_hook/3","type":"function"},{"doc":"Configures an Auto Scaling group to send notifications when specified events\ntake place.\n\nSubscribers to the specified topic can have messages delivered to an endpoint\nsuch as a web server or an email address.\n\nThis configuration overwrites any existing configuration.\n\nFor more information, see [Getting Amazon SNS notifications when your Auto Scaling group\nscales](https://docs.aws.amazon.com/autoscaling/ec2/userguide/ASGettingNotifications.html)\nin the *Amazon EC2 Auto Scaling User Guide*.\n\nIf you exceed your maximum limit of SNS topics, which is 10 per Auto Scaling\ngroup, the call fails.","ref":"AWS.AutoScaling.html#put_notification_configuration/3","title":"AWS.AutoScaling.put_notification_configuration/3","type":"function"},{"doc":"Creates or updates a scaling policy for an Auto Scaling group.\n\nScaling policies are used to scale an Auto Scaling group based on configurable\nmetrics. If no policies are defined, the dynamic scaling and predictive scaling\nfeatures are not used.\n\nFor more information about using dynamic scaling, see [Target tracking scaling policies](https://docs.aws.amazon.com/autoscaling/ec2/userguide/as-scaling-target-tracking.html)\nand [Step and simple scaling policies](https://docs.aws.amazon.com/autoscaling/ec2/userguide/as-scaling-simple-step.html)\nin the *Amazon EC2 Auto Scaling User Guide*.\n\nFor more information about using predictive scaling, see [Predictive scaling for Amazon EC2 Auto\nScaling](https://docs.aws.amazon.com/autoscaling/ec2/userguide/ec2-auto-scaling-predictive-scaling.html)\nin the *Amazon EC2 Auto Scaling User Guide*.\n\nYou can view the scaling policies for an Auto Scaling group using the\n`DescribePolicies` API call. If you are no longer using a scaling policy, you\ncan delete it by calling the `DeletePolicy` API.","ref":"AWS.AutoScaling.html#put_scaling_policy/3","title":"AWS.AutoScaling.put_scaling_policy/3","type":"function"},{"doc":"Creates or updates a scheduled scaling action for an Auto Scaling group.\n\nFor more information, see [Scheduled scaling](https://docs.aws.amazon.com/autoscaling/ec2/userguide/schedule_time.html)\nin the *Amazon EC2 Auto Scaling User Guide*.\n\nYou can view the scheduled actions for an Auto Scaling group using the\n`DescribeScheduledActions` API call. If you are no longer using a scheduled\naction, you can delete it by calling the `DeleteScheduledAction` API.\n\nIf you try to schedule your action in the past, Amazon EC2 Auto Scaling returns\nan error message.","ref":"AWS.AutoScaling.html#put_scheduled_update_group_action/3","title":"AWS.AutoScaling.put_scheduled_update_group_action/3","type":"function"},{"doc":"Creates or updates a warm pool for the specified Auto Scaling group.\n\nA warm pool is a pool of pre-initialized EC2 instances that sits alongside the\nAuto Scaling group. Whenever your application needs to scale out, the Auto\nScaling group can draw on the warm pool to meet its new desired capacity. For\nmore information and example configurations, see [Warm pools for Amazon EC2 Auto Scaling](https://docs.aws.amazon.com/autoscaling/ec2/userguide/ec2-auto-scaling-warm-pools.html)\nin the *Amazon EC2 Auto Scaling User Guide*.\n\nThis operation must be called from the Region in which the Auto Scaling group\nwas created. This operation cannot be called on an Auto Scaling group that has a\nmixed instances policy or a launch template or launch configuration that\nrequests Spot Instances.\n\nYou can view the instances in the warm pool using the `DescribeWarmPool` API\ncall. If you are no longer using a warm pool, you can delete it by calling the\n`DeleteWarmPool` API.","ref":"AWS.AutoScaling.html#put_warm_pool/3","title":"AWS.AutoScaling.put_warm_pool/3","type":"function"},{"doc":"Records a heartbeat for the lifecycle action associated with the specified token\nor instance.\n\nThis extends the timeout by the length of time defined using the\n`PutLifecycleHook` API call.\n\nThis step is a part of the procedure for adding a lifecycle hook to an Auto\nScaling group:\n\n  1. (Optional) Create a launch template or launch configuration with\na user data script that runs while an instance is in a wait state due to a\nlifecycle hook.\n\n  2. (Optional) Create a Lambda function and a rule that allows Amazon\nEventBridge to invoke your Lambda function when an instance is put into a wait\nstate due to a lifecycle hook.\n\n  3. (Optional) Create a notification target and an IAM role. The\ntarget can be either an Amazon SQS queue or an Amazon SNS topic. The role allows\nAmazon EC2 Auto Scaling to publish lifecycle notifications to the target.\n\n  4. Create the lifecycle hook. Specify whether the hook is used when\nthe instances launch or terminate.\n\n  5.","ref":"AWS.AutoScaling.html#record_lifecycle_action_heartbeat/3","title":"AWS.AutoScaling.record_lifecycle_action_heartbeat/3","type":"function"},{"doc":"keep the instance in a wait state.\n\n  6. If you finish before the timeout period ends, send a callback by\nusing the `CompleteLifecycleAction` API call.\n\nFor more information, see [Amazon EC2 Auto Scaling lifecycle hooks](https://docs.aws.amazon.com/autoscaling/ec2/userguide/lifecycle-hooks.html)\nin the *Amazon EC2 Auto Scaling User Guide*.","ref":"AWS.AutoScaling.html#record_lifecycle_action_heartbeat/3-if-you-need-more-time-record-the-lifecycle-action-heartbeat-to","title":"If you need more time, record the lifecycle action heartbeat to - AWS.AutoScaling.record_lifecycle_action_heartbeat/3","type":"function"},{"doc":"Resumes the specified suspended auto scaling processes, or all suspended\nprocess, for the specified Auto Scaling group.\n\nFor more information, see [Suspending and resuming scaling processes](https://docs.aws.amazon.com/autoscaling/ec2/userguide/as-suspend-resume-processes.html)\nin the *Amazon EC2 Auto Scaling User Guide*.","ref":"AWS.AutoScaling.html#resume_processes/3","title":"AWS.AutoScaling.resume_processes/3","type":"function"},{"doc":"Cancels an instance refresh that is in progress and rolls back any changes that\nit made.\n\nAmazon EC2 Auto Scaling replaces any instances that were replaced during the\ninstance refresh. This restores your Auto Scaling group to the configuration\nthat it was using before the start of the instance refresh.\n\nThis operation is part of the [instance refresh feature](https://docs.aws.amazon.com/autoscaling/ec2/userguide/asg-instance-refresh.html)\nin Amazon EC2 Auto Scaling, which helps you update instances in your Auto\nScaling group after you make configuration changes.\n\nA rollback is not supported in the following situations:\n\n  * There is no desired configuration specified for the instance\nrefresh.\n\n  * The Auto Scaling group has a launch template that uses an Amazon\nWeb Services Systems Manager parameter instead of an AMI ID for the `ImageId`\nproperty.\n\n  * The Auto Scaling group uses the launch template's `$Latest` or\n`$Default` version.\n\nWhen you receive a successful response from this operation, Amazon EC2 Auto\nScaling immediately begins replacing instances. You can check the status of this\noperation through the `DescribeInstanceRefreshes` API operation.","ref":"AWS.AutoScaling.html#rollback_instance_refresh/3","title":"AWS.AutoScaling.rollback_instance_refresh/3","type":"function"},{"doc":"Sets the size of the specified Auto Scaling group.\n\nIf a scale-in activity occurs as a result of a new `DesiredCapacity` value that\nis lower than the current size of the group, the Auto Scaling group uses its\ntermination policy to determine which instances to terminate.\n\nFor more information, see [Manual scaling](https://docs.aws.amazon.com/autoscaling/ec2/userguide/as-manual-scaling.html)\nin the *Amazon EC2 Auto Scaling User Guide*.","ref":"AWS.AutoScaling.html#set_desired_capacity/3","title":"AWS.AutoScaling.set_desired_capacity/3","type":"function"},{"doc":"Sets the health status of the specified instance.\n\nFor more information, see [Health checks for Auto Scaling instances](https://docs.aws.amazon.com/autoscaling/ec2/userguide/healthcheck.html)\nin the *Amazon EC2 Auto Scaling User Guide*.","ref":"AWS.AutoScaling.html#set_instance_health/3","title":"AWS.AutoScaling.set_instance_health/3","type":"function"},{"doc":"Updates the instance protection settings of the specified instances.\n\nThis operation cannot be called on instances in a warm pool.\n\nFor more information about preventing instances that are part of an Auto Scaling\ngroup from terminating on scale in, see [Using instance scale-in protection](https://docs.aws.amazon.com/autoscaling/ec2/userguide/ec2-auto-scaling-instance-protection.html)\nin the *Amazon EC2 Auto Scaling User Guide*.\n\nIf you exceed your maximum limit of instance IDs, which is 50 per Auto Scaling\ngroup, the call fails.","ref":"AWS.AutoScaling.html#set_instance_protection/3","title":"AWS.AutoScaling.set_instance_protection/3","type":"function"},{"doc":"Starts an instance refresh.\n\nThis operation is part of the [instance refresh feature](https://docs.aws.amazon.com/autoscaling/ec2/userguide/asg-instance-refresh.html)\nin Amazon EC2 Auto Scaling, which helps you update instances in your Auto\nScaling group. This feature is helpful, for example, when you have a new AMI or\na new user data script. You just need to create a new launch template that\nspecifies the new AMI or user data script. Then start an instance refresh to\nimmediately begin the process of updating instances in the group.\n\nIf successful, the request's response contains a unique ID that you can use to\ntrack the progress of the instance refresh. To query its status, call the\n`DescribeInstanceRefreshes` API. To describe the instance refreshes that have\nalready run, call the `DescribeInstanceRefreshes` API. To cancel an instance\nrefresh that is in progress, use the `CancelInstanceRefresh` API.\n\nAn instance refresh might fail for several reasons, such as EC2 launch failures,\nmisconfigured health checks, or not ignoring or allowing the termination of\ninstances that are in `Standby` state or protected from scale in. You can\nmonitor for failed EC2 launches using the scaling activities. To find the\nscaling activities, call the `DescribeScalingActivities` API.\n\nIf you enable auto rollback, your Auto Scaling group will be rolled back\nautomatically when the instance refresh fails. You can enable this feature\nbefore starting an instance refresh by specifying the `AutoRollback` property in\nthe instance refresh preferences. Otherwise, to roll back an instance refresh\nbefore it finishes, use the `RollbackInstanceRefresh` API.","ref":"AWS.AutoScaling.html#start_instance_refresh/3","title":"AWS.AutoScaling.start_instance_refresh/3","type":"function"},{"doc":"Suspends the specified auto scaling processes, or all processes, for the\nspecified Auto Scaling group.\n\nIf you suspend either the `Launch` or `Terminate` process types, it can prevent\nother process types from functioning properly. For more information, see\n[Suspending and resuming scaling processes](https://docs.aws.amazon.com/autoscaling/ec2/userguide/as-suspend-resume-processes.html)\nin the *Amazon EC2 Auto Scaling User Guide*.\n\nTo resume processes that have been suspended, call the `ResumeProcesses` API.","ref":"AWS.AutoScaling.html#suspend_processes/3","title":"AWS.AutoScaling.suspend_processes/3","type":"function"},{"doc":"Terminates the specified instance and optionally adjusts the desired group size.\n\nThis operation cannot be called on instances in a warm pool.\n\nThis call simply makes a termination request. The instance is not terminated\nimmediately. When an instance is terminated, the instance status changes to\n`terminated`. You can't connect to or start an instance after you've terminated\nit.\n\nIf you do not specify the option to decrement the desired capacity, Amazon EC2\nAuto Scaling launches instances to replace the ones that are terminated.\n\nBy default, Amazon EC2 Auto Scaling balances instances across all Availability\nZones. If you decrement the desired capacity, your Auto Scaling group can become\nunbalanced between Availability Zones. Amazon EC2 Auto Scaling tries to\nrebalance the group, and rebalancing might terminate instances in other zones.\nFor more information, see [Rebalancing activities](https://docs.aws.amazon.com/autoscaling/ec2/userguide/auto-scaling-benefits.html#AutoScalingBehavior.InstanceUsage)\nin the *Amazon EC2 Auto Scaling User Guide*.","ref":"AWS.AutoScaling.html#terminate_instance_in_auto_scaling_group/3","title":"AWS.AutoScaling.terminate_instance_in_auto_scaling_group/3","type":"function"},{"doc":"","ref":"AWS.AutoScaling.html#update_auto_scaling_group/3","title":"AWS.AutoScaling.update_auto_scaling_group/3","type":"function"},{"doc":"ensure full functionality for Amazon EC2 Auto Scaling and Amazon EC2.\n\nUpdates the configuration for the specified Auto Scaling group.\n\nTo update an Auto Scaling group, specify the name of the group and the property\nthat you want to change. Any properties that you don't specify are not changed\nby this update request. The new settings take effect on any scaling activities\nafter this call returns.\n\nIf you associate a new launch configuration or template with an Auto Scaling\ngroup, all new instances will get the updated configuration. Existing instances\ncontinue to run with the configuration that they were originally launched with.\nWhen you update a group to specify a mixed instances policy instead of a launch\nconfiguration or template, existing instances may be replaced to match the new\npurchasing options that you specified in the policy. For example, if the group\ncurrently has 100% On-Demand capacity and the policy specifies 50% Spot\ncapacity, this means that half of your instances will be gradually terminated\nand relaunched as Spot Instances. When replacing instances, Amazon EC2 Auto\nScaling launches new instances before terminating the old ones, so that updating\nyour group does not compromise the performance or availability of your\napplication.\n\nNote the following about changing `DesiredCapacity`, `MaxSize`, or `MinSize`:\n\n  * If a scale-in activity occurs as a result of a new\n`DesiredCapacity` value that is lower than the current size of the group, the\nAuto Scaling group uses its termination policy to determine which instances to\nterminate.\n\n  * If you specify a new value for `MinSize` without specifying a\nvalue for `DesiredCapacity`, and the new `MinSize` is larger than the current\nsize of the group, this sets the group's `DesiredCapacity` to the new `MinSize`\nvalue.\n\n  * If you specify a new value for `MaxSize` without specifying a\nvalue for `DesiredCapacity`, and the new `MaxSize` is smaller than the current\nsize of the group, this sets the group's `DesiredCapacity` to the new `MaxSize`\nvalue.\n\nTo see which properties have been set, call the `DescribeAutoScalingGroups` API.\nTo view the scaling policies for an Auto Scaling group, call the\n`DescribePolicies` API. If the group has scaling policies, you can update them\nby calling the `PutScalingPolicy` API.","ref":"AWS.AutoScaling.html#update_auto_scaling_group/3-we-strongly-recommend-that-all-auto-scaling-groups-use-launch-templates-to","title":"We strongly recommend that all Auto Scaling groups use launch templates to - AWS.AutoScaling.update_auto_scaling_group/3","type":"function"},{"doc":"AWS Auto Scaling\n\nUse AWS Auto Scaling to create scaling plans for your applications to\nautomatically scale your scalable AWS resources.","ref":"AWS.AutoScalingPlans.html","title":"AWS.AutoScalingPlans","type":"module"},{"doc":"You can use the AWS Auto Scaling service API to accomplish the following tasks:\n\n  * Create and manage scaling plans\n\n  * Define target tracking scaling policies to dynamically scale your\nresources based on utilization\n\n  * Scale Amazon EC2 Auto Scaling groups using predictive scaling and\ndynamic scaling to scale your Amazon EC2 capacity faster\n\n  * Set minimum and maximum capacity limits\n\n  * Retrieve information on existing scaling plans\n\n  * Access current forecast data and historical forecast data for up\nto 56 days previous\n\nTo learn more about AWS Auto Scaling, including information about granting IAM\nusers required permissions for AWS Auto Scaling actions, see the [AWS Auto Scaling User\nGuide](https://docs.aws.amazon.com/autoscaling/plans/userguide/what-is-aws-auto-scaling.html).","ref":"AWS.AutoScalingPlans.html#module-api-summary","title":"API Summary - AWS.AutoScalingPlans","type":"module"},{"doc":"Creates a scaling plan.","ref":"AWS.AutoScalingPlans.html#create_scaling_plan/3","title":"AWS.AutoScalingPlans.create_scaling_plan/3","type":"function"},{"doc":"Deletes the specified scaling plan.\n\nDeleting a scaling plan deletes the underlying `ScalingInstruction` for all of\nthe scalable resources that are covered by the plan.\n\nIf the plan has launched resources or has scaling activities in progress, you\nmust delete those resources separately.","ref":"AWS.AutoScalingPlans.html#delete_scaling_plan/3","title":"AWS.AutoScalingPlans.delete_scaling_plan/3","type":"function"},{"doc":"Describes the scalable resources in the specified scaling plan.","ref":"AWS.AutoScalingPlans.html#describe_scaling_plan_resources/3","title":"AWS.AutoScalingPlans.describe_scaling_plan_resources/3","type":"function"},{"doc":"Describes one or more of your scaling plans.","ref":"AWS.AutoScalingPlans.html#describe_scaling_plans/3","title":"AWS.AutoScalingPlans.describe_scaling_plans/3","type":"function"},{"doc":"Retrieves the forecast data for a scalable resource.\n\nCapacity forecasts are represented as predicted values, or data points, that are\ncalculated using historical data points from a specified CloudWatch load metric.\nData points are available for up to 56 days.","ref":"AWS.AutoScalingPlans.html#get_scaling_plan_resource_forecast_data/3","title":"AWS.AutoScalingPlans.get_scaling_plan_resource_forecast_data/3","type":"function"},{"doc":"","ref":"AWS.AutoScalingPlans.html#metadata/0","title":"AWS.AutoScalingPlans.metadata/0","type":"function"},{"doc":"Updates the specified scaling plan.\n\nYou cannot update a scaling plan if it is in the process of being created,\nupdated, or deleted.","ref":"AWS.AutoScalingPlans.html#update_scaling_plan/3","title":"AWS.AutoScalingPlans.update_scaling_plan/3","type":"function"},{"doc":"This is the *Amazon Web Services B2B Data Interchange API Reference*.\n\nIt provides descriptions, API request parameters, and the XML response for each\nof the B2BI API actions.\n\nB2BI enables automated exchange of EDI (electronic data interchange) based\nbusiness-critical transactions at cloud scale, with elasticity and pay-as-you-go\npricing. Businesses use EDI documents to exchange transactional data with\ntrading partners, such as suppliers and end customers, using standardized\nformats such as X12.\n\nRather than actually running a command, you can use the\n`--generate-cli-skeleton` parameter with any API call to generate and display a\nparameter template. You can then use the generated template to customize and use\nas input on a later command. For details, see [Generate and use a parameter skeleton\nfile](https://docs.aws.amazon.com/cli/latest/userguide/cli-usage-skeleton.html#cli-usage-skeleton-generate).","ref":"AWS.B2bi.html","title":"AWS.B2bi","type":"module"},{"doc":"Instantiates a capability based on the specified parameters.\n\nA trading capability contains the information required to transform incoming EDI\ndocuments into JSON or XML outputs.","ref":"AWS.B2bi.html#create_capability/3","title":"AWS.B2bi.create_capability/3","type":"function"},{"doc":"Creates a partnership between a customer and a trading partner, based on the\nsupplied parameters.\n\nA partnership represents the connection between you and your trading partner. It\nties together a profile and one or more trading capabilities.","ref":"AWS.B2bi.html#create_partnership/3","title":"AWS.B2bi.create_partnership/3","type":"function"},{"doc":"Creates a customer profile.\n\nYou can have up to five customer profiles, each representing a distinct private\nnetwork. A profile is the mechanism used to create the concept of a private\nnetwork.","ref":"AWS.B2bi.html#create_profile/3","title":"AWS.B2bi.create_profile/3","type":"function"},{"doc":"Creates a transformer.\n\nA transformer describes how to process the incoming EDI documents and extract\nthe necessary information to the output file.","ref":"AWS.B2bi.html#create_transformer/3","title":"AWS.B2bi.create_transformer/3","type":"function"},{"doc":"Deletes the specified capability.\n\nA trading capability contains the information required to transform incoming EDI\ndocuments into JSON or XML outputs.","ref":"AWS.B2bi.html#delete_capability/3","title":"AWS.B2bi.delete_capability/3","type":"function"},{"doc":"Deletes the specified partnership.\n\nA partnership represents the connection between you and your trading partner. It\nties together a profile and one or more trading capabilities.","ref":"AWS.B2bi.html#delete_partnership/3","title":"AWS.B2bi.delete_partnership/3","type":"function"},{"doc":"Deletes the specified profile.\n\nA profile is the mechanism used to create the concept of a private network.","ref":"AWS.B2bi.html#delete_profile/3","title":"AWS.B2bi.delete_profile/3","type":"function"},{"doc":"Deletes the specified transformer.\n\nA transformer describes how to process the incoming EDI documents and extract\nthe necessary information to the output file.","ref":"AWS.B2bi.html#delete_transformer/3","title":"AWS.B2bi.delete_transformer/3","type":"function"},{"doc":"Retrieves the details for the specified capability.\n\nA trading capability contains the information required to transform incoming EDI\ndocuments into JSON or XML outputs.","ref":"AWS.B2bi.html#get_capability/3","title":"AWS.B2bi.get_capability/3","type":"function"},{"doc":"Retrieves the details for a partnership, based on the partner and profile IDs\nspecified.\n\nA partnership represents the connection between you and your trading partner. It\nties together a profile and one or more trading capabilities.","ref":"AWS.B2bi.html#get_partnership/3","title":"AWS.B2bi.get_partnership/3","type":"function"},{"doc":"Retrieves the details for the profile specified by the profile ID.\n\nA profile is the mechanism used to create the concept of a private network.","ref":"AWS.B2bi.html#get_profile/3","title":"AWS.B2bi.get_profile/3","type":"function"},{"doc":"Retrieves the details for the transformer specified by the transformer ID.\n\nA transformer describes how to process the incoming EDI documents and extract\nthe necessary information to the output file.","ref":"AWS.B2bi.html#get_transformer/3","title":"AWS.B2bi.get_transformer/3","type":"function"},{"doc":"Returns the details of the transformer run, based on the Transformer job ID.","ref":"AWS.B2bi.html#get_transformer_job/3","title":"AWS.B2bi.get_transformer_job/3","type":"function"},{"doc":"Lists the capabilities associated with your Amazon Web Services account for your\ncurrent or specified region.\n\nA trading capability contains the information required to transform incoming EDI\ndocuments into JSON or XML outputs.","ref":"AWS.B2bi.html#list_capabilities/3","title":"AWS.B2bi.list_capabilities/3","type":"function"},{"doc":"Lists the partnerships associated with your Amazon Web Services account for your\ncurrent or specified region.\n\nA partnership represents the connection between you and your trading partner. It\nties together a profile and one or more trading capabilities.","ref":"AWS.B2bi.html#list_partnerships/3","title":"AWS.B2bi.list_partnerships/3","type":"function"},{"doc":"Lists the profiles associated with your Amazon Web Services account for your\ncurrent or specified region.\n\nA profile is the mechanism used to create the concept of a private network.","ref":"AWS.B2bi.html#list_profiles/3","title":"AWS.B2bi.list_profiles/3","type":"function"},{"doc":"Lists all of the tags associated with the Amazon Resource Name (ARN) that you\nspecify.\n\nThe resource can be a capability, partnership, profile, or transformer.","ref":"AWS.B2bi.html#list_tags_for_resource/3","title":"AWS.B2bi.list_tags_for_resource/3","type":"function"},{"doc":"Lists the available transformers.\n\nA transformer describes how to process the incoming EDI documents and extract\nthe necessary information to the output file.","ref":"AWS.B2bi.html#list_transformers/3","title":"AWS.B2bi.list_transformers/3","type":"function"},{"doc":"","ref":"AWS.B2bi.html#metadata/0","title":"AWS.B2bi.metadata/0","type":"function"},{"doc":"Runs a job, using a transformer, to parse input EDI (electronic data\ninterchange) file into the output structures used by Amazon Web Services B2BI\nData Interchange.\n\nIf you only want to transform EDI (electronic data interchange) documents, you\ndon't need to create profiles, partnerships or capabilities. Just create and\nconfigure a transformer, and then run the `StartTransformerJob` API to process\nyour files.","ref":"AWS.B2bi.html#start_transformer_job/3","title":"AWS.B2bi.start_transformer_job/3","type":"function"},{"doc":"Attaches a key-value pair to a resource, as identified by its Amazon Resource\nName (ARN).\n\nResources are capability, partnership, profile, transformers and other entities.\n\nThere is no response returned from this call.","ref":"AWS.B2bi.html#tag_resource/3","title":"AWS.B2bi.tag_resource/3","type":"function"},{"doc":"Maps the input file according to the provided template file.\n\nThe API call downloads the file contents from the Amazon S3 location, and passes\nthe contents in as a string, to the `inputFileContent` parameter.","ref":"AWS.B2bi.html#test_mapping/3","title":"AWS.B2bi.test_mapping/3","type":"function"},{"doc":"Parses the input EDI (electronic data interchange) file.\n\nThe input file has a file size limit of 250 KB.","ref":"AWS.B2bi.html#test_parsing/3","title":"AWS.B2bi.test_parsing/3","type":"function"},{"doc":"Detaches a key-value pair from the specified resource, as identified by its\nAmazon Resource Name (ARN).\n\nResources are capability, partnership, profile, transformers and other entities.","ref":"AWS.B2bi.html#untag_resource/3","title":"AWS.B2bi.untag_resource/3","type":"function"},{"doc":"Updates some of the parameters for a capability, based on the specified\nparameters.\n\nA trading capability contains the information required to transform incoming EDI\ndocuments into JSON or XML outputs.","ref":"AWS.B2bi.html#update_capability/3","title":"AWS.B2bi.update_capability/3","type":"function"},{"doc":"Updates some of the parameters for a partnership between a customer and trading\npartner.\n\nA partnership represents the connection between you and your trading partner. It\nties together a profile and one or more trading capabilities.","ref":"AWS.B2bi.html#update_partnership/3","title":"AWS.B2bi.update_partnership/3","type":"function"},{"doc":"Updates the specified parameters for a profile.\n\nA profile is the mechanism used to create the concept of a private network.","ref":"AWS.B2bi.html#update_profile/3","title":"AWS.B2bi.update_profile/3","type":"function"},{"doc":"Updates the specified parameters for a transformer.\n\nA transformer describes how to process the incoming EDI documents and extract\nthe necessary information to the output file.","ref":"AWS.B2bi.html#update_transformer/3","title":"AWS.B2bi.update_transformer/3","type":"function"},{"doc":"You can use the Data Exports API to create customized exports from multiple\nAmazon Web Services cost management and billing datasets, such as cost and usage\ndata and cost optimization recommendations.\n\nThe Data Exports API provides the following endpoint:\n\n  * https://bcm-data-exports.us-east-1.api.aws","ref":"AWS.BCMDataExports.html","title":"AWS.BCMDataExports","type":"module"},{"doc":"Creates a data export and specifies the data query, the delivery preference, and\nany optional resource tags.\n\nA `DataQuery` consists of both a `QueryStatement` and `TableConfigurations`.\n\nThe `QueryStatement` is an SQL statement. Data Exports only supports a limited\nsubset of the SQL syntax. For more information on the SQL syntax that is\nsupported, see [Data query](https://docs.aws.amazon.com/cur/latest/userguide/de-data-query.html). To\nview the available tables and columns, see the [Data Exports table dictionary](https://docs.aws.amazon.com/cur/latest/userguide/de-table-dictionary.html).\n\nThe `TableConfigurations` is a collection of specified `TableProperties` for the\ntable being queried in the `QueryStatement`. TableProperties are additional\nconfigurations you can provide to change the data and schema of a table. Each\ntable can have different TableProperties. However, tables are not required to\nhave any TableProperties. Each table property has a default value that it\nassumes if not specified. For more information on table configurations, see\n[Data query](https://docs.aws.amazon.com/cur/latest/userguide/de-data-query.html). To\nview the table properties available for each table, see the [Data Exports table dictionary](https://docs.aws.amazon.com/cur/latest/userguide/de-table-dictionary.html)\nor use the `ListTables` API to get a response of all tables and their available\nproperties.","ref":"AWS.BCMDataExports.html#create_export/3","title":"AWS.BCMDataExports.create_export/3","type":"function"},{"doc":"Deletes an existing data export.","ref":"AWS.BCMDataExports.html#delete_export/3","title":"AWS.BCMDataExports.delete_export/3","type":"function"},{"doc":"Exports data based on the source data update.","ref":"AWS.BCMDataExports.html#get_execution/3","title":"AWS.BCMDataExports.get_execution/3","type":"function"},{"doc":"Views the definition of an existing data export.","ref":"AWS.BCMDataExports.html#get_export/3","title":"AWS.BCMDataExports.get_export/3","type":"function"},{"doc":"Returns the metadata for the specified table and table properties.\n\nThis includes the list of columns in the table schema, their data types, and\ncolumn descriptions.","ref":"AWS.BCMDataExports.html#get_table/3","title":"AWS.BCMDataExports.get_table/3","type":"function"},{"doc":"Lists the historical executions for the export.","ref":"AWS.BCMDataExports.html#list_executions/3","title":"AWS.BCMDataExports.list_executions/3","type":"function"},{"doc":"Lists all data export definitions.","ref":"AWS.BCMDataExports.html#list_exports/3","title":"AWS.BCMDataExports.list_exports/3","type":"function"},{"doc":"Lists all available tables in data exports.","ref":"AWS.BCMDataExports.html#list_tables/3","title":"AWS.BCMDataExports.list_tables/3","type":"function"},{"doc":"List tags associated with an existing data export.","ref":"AWS.BCMDataExports.html#list_tags_for_resource/3","title":"AWS.BCMDataExports.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.BCMDataExports.html#metadata/0","title":"AWS.BCMDataExports.metadata/0","type":"function"},{"doc":"Adds tags for an existing data export definition.","ref":"AWS.BCMDataExports.html#tag_resource/3","title":"AWS.BCMDataExports.tag_resource/3","type":"function"},{"doc":"Deletes tags associated with an existing data export definition.","ref":"AWS.BCMDataExports.html#untag_resource/3","title":"AWS.BCMDataExports.untag_resource/3","type":"function"},{"doc":"Updates an existing data export by overwriting all export parameters.\n\nAll export parameters must be provided in the UpdateExport request.","ref":"AWS.BCMDataExports.html#update_export/3","title":"AWS.BCMDataExports.update_export/3","type":"function"},{"doc":"Backup\n\nBackup is a unified backup service designed to protect Amazon Web Services\nservices and their associated data.\n\nBackup simplifies the creation, migration, restoration, and deletion of backups,\nwhile also providing reporting and auditing.","ref":"AWS.Backup.html","title":"AWS.Backup","type":"module"},{"doc":"This action removes the specified legal hold on a recovery point.\n\nThis action can only be performed by a user with sufficient permissions.","ref":"AWS.Backup.html#cancel_legal_hold/4","title":"AWS.Backup.cancel_legal_hold/4","type":"function"},{"doc":"Creates a backup plan using a backup plan name and backup rules.\n\nA backup plan is a document that contains information that Backup uses to\nschedule tasks that create recovery points for resources.\n\nIf you call `CreateBackupPlan` with a plan that already exists, you receive an\n`AlreadyExistsException` exception.","ref":"AWS.Backup.html#create_backup_plan/3","title":"AWS.Backup.create_backup_plan/3","type":"function"},{"doc":"Creates a JSON document that specifies a set of resources to assign to a backup\nplan.\n\nFor examples, see [Assigning resources programmatically](https://docs.aws.amazon.com/aws-backup/latest/devguide/assigning-resources.html#assigning-resources-json).","ref":"AWS.Backup.html#create_backup_selection/4","title":"AWS.Backup.create_backup_selection/4","type":"function"},{"doc":"Creates a logical container where backups are stored.\n\nA `CreateBackupVault` request includes a name, optionally one or more resource\ntags, an encryption key, and a request ID.\n\nDo not include sensitive data, such as passport numbers, in the name of a backup\nvault.","ref":"AWS.Backup.html#create_backup_vault/4","title":"AWS.Backup.create_backup_vault/4","type":"function"},{"doc":"Creates a framework with one or more controls.\n\nA framework is a collection of controls that you can use to evaluate your backup\npractices. By using pre-built customizable controls to define your policies, you\ncan evaluate whether your backup practices comply with your policies and which\nresources are not yet in compliance.","ref":"AWS.Backup.html#create_framework/3","title":"AWS.Backup.create_framework/3","type":"function"},{"doc":"This action creates a legal hold on a recovery point (backup).\n\nA legal hold is a restraint on altering or deleting a backup until an authorized\nuser cancels the legal hold. Any actions to delete or disassociate a recovery\npoint will fail with an error if one or more active legal holds are on the\nrecovery point.","ref":"AWS.Backup.html#create_legal_hold/3","title":"AWS.Backup.create_legal_hold/3","type":"function"},{"doc":"This request creates a logical container to where backups may be copied.\n\nThis request includes a name, the Region, the maximum number of retention days,\nthe minimum number of retention days, and optionally can include tags and a\ncreator request ID.\n\nDo not include sensitive data, such as passport numbers, in the name of a backup\nvault.","ref":"AWS.Backup.html#create_logically_air_gapped_backup_vault/4","title":"AWS.Backup.create_logically_air_gapped_backup_vault/4","type":"function"},{"doc":"Creates a report plan.\n\nA report plan is a document that contains information about the contents of the\nreport and where Backup will deliver it.\n\nIf you call `CreateReportPlan` with a plan that already exists, you receive an\n`AlreadyExistsException` exception.","ref":"AWS.Backup.html#create_report_plan/3","title":"AWS.Backup.create_report_plan/3","type":"function"},{"doc":"This is the first of two steps to create a restore testing plan; once this\nrequest is successful, finish the procedure with request\nCreateRestoreTestingSelection.\n\nYou must include the parameter RestoreTestingPlan. You may optionally include\nCreatorRequestId and Tags.","ref":"AWS.Backup.html#create_restore_testing_plan/3","title":"AWS.Backup.create_restore_testing_plan/3","type":"function"},{"doc":"This request can be sent after CreateRestoreTestingPlan request returns\nsuccessfully.\n\nThis is the second part of creating a resource testing plan, and it must be\ncompleted sequentially.\n\nThis consists of `RestoreTestingSelectionName`, `ProtectedResourceType`, and one\nof the following:\n\n  * `ProtectedResourceArns`\n\n  * `ProtectedResourceConditions`\n\nEach protected resource type can have one single value.\n\nA restore testing selection can include a wildcard value (\"*\") for\n`ProtectedResourceArns` along with `ProtectedResourceConditions`. Alternatively,\nyou can include up to 30 specific protected resource ARNs in\n`ProtectedResourceArns`.\n\nCannot select by both protected resource types AND specific ARNs. Request will\nfail if both are included.","ref":"AWS.Backup.html#create_restore_testing_selection/4","title":"AWS.Backup.create_restore_testing_selection/4","type":"function"},{"doc":"Deletes a backup plan.\n\nA backup plan can only be deleted after all associated selections of resources\nhave been deleted. Deleting a backup plan deletes the current version of a\nbackup plan. Previous versions, if any, will still exist.","ref":"AWS.Backup.html#delete_backup_plan/4","title":"AWS.Backup.delete_backup_plan/4","type":"function"},{"doc":"Deletes the resource selection associated with a backup plan that is specified\nby the `SelectionId`.","ref":"AWS.Backup.html#delete_backup_selection/5","title":"AWS.Backup.delete_backup_selection/5","type":"function"},{"doc":"Deletes the backup vault identified by its name.\n\nA vault can be deleted only if it is empty.","ref":"AWS.Backup.html#delete_backup_vault/4","title":"AWS.Backup.delete_backup_vault/4","type":"function"},{"doc":"Deletes the policy document that manages permissions on a backup vault.","ref":"AWS.Backup.html#delete_backup_vault_access_policy/4","title":"AWS.Backup.delete_backup_vault_access_policy/4","type":"function"},{"doc":"Deletes Backup Vault Lock from a backup vault specified by a backup vault name.\n\nIf the Vault Lock configuration is immutable, then you cannot delete Vault Lock\nusing API operations, and you will receive an `InvalidRequestException` if you\nattempt to do so. For more information, see [Vault Lock](https://docs.aws.amazon.com/aws-backup/latest/devguide/vault-lock.html) in\nthe *Backup Developer Guide*.","ref":"AWS.Backup.html#delete_backup_vault_lock_configuration/4","title":"AWS.Backup.delete_backup_vault_lock_configuration/4","type":"function"},{"doc":"Deletes event notifications for the specified backup vault.","ref":"AWS.Backup.html#delete_backup_vault_notifications/4","title":"AWS.Backup.delete_backup_vault_notifications/4","type":"function"},{"doc":"Deletes the framework specified by a framework name.","ref":"AWS.Backup.html#delete_framework/4","title":"AWS.Backup.delete_framework/4","type":"function"},{"doc":"Deletes the recovery point specified by a recovery point ID.\n\nIf the recovery point ID belongs to a continuous backup, calling this endpoint\ndeletes the existing continuous backup and stops future continuous backup.\n\nWhen an IAM role's permissions are insufficient to call this API, the service\nsends back an HTTP 200 response with an empty HTTP body, but the recovery point\nis not deleted. Instead, it enters an `EXPIRED` state.\n\n`EXPIRED` recovery points can be deleted with this API once the IAM role has the\n`iam:CreateServiceLinkedRole` action. To learn more about adding this role, see\n[ Troubleshooting manual deletions](https://docs.aws.amazon.com/aws-backup/latest/devguide/deleting-backups.html#deleting-backups-troubleshooting).\n\nIf the user or role is deleted or the permission within the role is removed, the\ndeletion will not be successful and will enter an `EXPIRED` state.","ref":"AWS.Backup.html#delete_recovery_point/5","title":"AWS.Backup.delete_recovery_point/5","type":"function"},{"doc":"Deletes the report plan specified by a report plan name.","ref":"AWS.Backup.html#delete_report_plan/4","title":"AWS.Backup.delete_report_plan/4","type":"function"},{"doc":"This request deletes the specified restore testing plan.\n\nDeletion can only successfully occur if all associated restore testing\nselections are deleted first.","ref":"AWS.Backup.html#delete_restore_testing_plan/4","title":"AWS.Backup.delete_restore_testing_plan/4","type":"function"},{"doc":"Input the Restore Testing Plan name and Restore Testing Selection name.\n\nAll testing selections associated with a restore testing plan must be deleted\nbefore the restore testing plan can be deleted.","ref":"AWS.Backup.html#delete_restore_testing_selection/5","title":"AWS.Backup.delete_restore_testing_selection/5","type":"function"},{"doc":"Returns backup job details for the specified `BackupJobId`.","ref":"AWS.Backup.html#describe_backup_job/3","title":"AWS.Backup.describe_backup_job/3","type":"function"},{"doc":"Returns metadata about a backup vault specified by its name.","ref":"AWS.Backup.html#describe_backup_vault/4","title":"AWS.Backup.describe_backup_vault/4","type":"function"},{"doc":"Returns metadata associated with creating a copy of a resource.","ref":"AWS.Backup.html#describe_copy_job/3","title":"AWS.Backup.describe_copy_job/3","type":"function"},{"doc":"Returns the framework details for the specified `FrameworkName`.","ref":"AWS.Backup.html#describe_framework/3","title":"AWS.Backup.describe_framework/3","type":"function"},{"doc":"Describes whether the Amazon Web Services account is opted in to cross-account\nbackup.\n\nReturns an error if the account is not a member of an Organizations\norganization. Example: `describe-global-settings --region us-west-2`","ref":"AWS.Backup.html#describe_global_settings/2","title":"AWS.Backup.describe_global_settings/2","type":"function"},{"doc":"Returns information about a saved resource, including the last time it was\nbacked up, its Amazon Resource Name (ARN), and the Amazon Web Services service\ntype of the saved resource.","ref":"AWS.Backup.html#describe_protected_resource/3","title":"AWS.Backup.describe_protected_resource/3","type":"function"},{"doc":"Returns metadata associated with a recovery point, including ID, status,\nencryption, and lifecycle.","ref":"AWS.Backup.html#describe_recovery_point/5","title":"AWS.Backup.describe_recovery_point/5","type":"function"},{"doc":"Returns the current service opt-in settings for the Region.\n\nIf service opt-in is enabled for a service, Backup tries to protect that\nservice's resources in this Region, when the resource is included in an\non-demand backup or scheduled backup plan. Otherwise, Backup does not try to\nprotect that service's resources in this Region.","ref":"AWS.Backup.html#describe_region_settings/2","title":"AWS.Backup.describe_region_settings/2","type":"function"},{"doc":"Returns the details associated with creating a report as specified by its\n`ReportJobId`.","ref":"AWS.Backup.html#describe_report_job/3","title":"AWS.Backup.describe_report_job/3","type":"function"},{"doc":"Returns a list of all report plans for an Amazon Web Services account and Amazon\nWeb Services Region.","ref":"AWS.Backup.html#describe_report_plan/3","title":"AWS.Backup.describe_report_plan/3","type":"function"},{"doc":"Returns metadata associated with a restore job that is specified by a job ID.","ref":"AWS.Backup.html#describe_restore_job/3","title":"AWS.Backup.describe_restore_job/3","type":"function"},{"doc":"Deletes the specified continuous backup recovery point from Backup and releases\ncontrol of that continuous backup to the source service, such as Amazon RDS.\n\nThe source service will continue to create and retain continuous backups using\nthe lifecycle that you specified in your original backup plan.\n\nDoes not support snapshot backup recovery points.","ref":"AWS.Backup.html#disassociate_recovery_point/5","title":"AWS.Backup.disassociate_recovery_point/5","type":"function"},{"doc":"This action to a specific child (nested) recovery point removes the relationship\nbetween the specified recovery point and its parent (composite) recovery point.","ref":"AWS.Backup.html#disassociate_recovery_point_from_parent/5","title":"AWS.Backup.disassociate_recovery_point_from_parent/5","type":"function"},{"doc":"Returns the backup plan that is specified by the plan ID as a backup template.","ref":"AWS.Backup.html#export_backup_plan_template/3","title":"AWS.Backup.export_backup_plan_template/3","type":"function"},{"doc":"Returns `BackupPlan` details for the specified `BackupPlanId`.\n\nThe details are the body of a backup plan in JSON format, in addition to plan\nmetadata.","ref":"AWS.Backup.html#get_backup_plan/4","title":"AWS.Backup.get_backup_plan/4","type":"function"},{"doc":"Returns a valid JSON document specifying a backup plan or an error.","ref":"AWS.Backup.html#get_backup_plan_from_json/3","title":"AWS.Backup.get_backup_plan_from_json/3","type":"function"},{"doc":"Returns the template specified by its `templateId` as a backup plan.","ref":"AWS.Backup.html#get_backup_plan_from_template/3","title":"AWS.Backup.get_backup_plan_from_template/3","type":"function"},{"doc":"Returns selection metadata and a document in JSON format that specifies a list\nof resources that are associated with a backup plan.","ref":"AWS.Backup.html#get_backup_selection/4","title":"AWS.Backup.get_backup_selection/4","type":"function"},{"doc":"Returns the access policy document that is associated with the named backup\nvault.","ref":"AWS.Backup.html#get_backup_vault_access_policy/3","title":"AWS.Backup.get_backup_vault_access_policy/3","type":"function"},{"doc":"Returns event notifications for the specified backup vault.","ref":"AWS.Backup.html#get_backup_vault_notifications/3","title":"AWS.Backup.get_backup_vault_notifications/3","type":"function"},{"doc":"This action returns details for a specified legal hold.\n\nThe details are the body of a legal hold in JSON format, in addition to\nmetadata.","ref":"AWS.Backup.html#get_legal_hold/3","title":"AWS.Backup.get_legal_hold/3","type":"function"},{"doc":"Returns a set of metadata key-value pairs that were used to create the backup.","ref":"AWS.Backup.html#get_recovery_point_restore_metadata/5","title":"AWS.Backup.get_recovery_point_restore_metadata/5","type":"function"},{"doc":"This request returns the metadata for the specified restore job.","ref":"AWS.Backup.html#get_restore_job_metadata/3","title":"AWS.Backup.get_restore_job_metadata/3","type":"function"},{"doc":"This request returns the minimal required set of metadata needed to start a\nrestore job with secure default settings.\n\n`BackupVaultName` and `RecoveryPointArn` are required parameters.\n`BackupVaultAccountId` is an optional parameter.","ref":"AWS.Backup.html#get_restore_testing_inferred_metadata/5","title":"AWS.Backup.get_restore_testing_inferred_metadata/5","type":"function"},{"doc":"Returns `RestoreTestingPlan` details for the specified `RestoreTestingPlanName`.\n\nThe details are the body of a restore testing plan in JSON format, in addition\nto plan metadata.","ref":"AWS.Backup.html#get_restore_testing_plan/3","title":"AWS.Backup.get_restore_testing_plan/3","type":"function"},{"doc":"Returns RestoreTestingSelection, which displays resources and elements of the\nrestore testing plan.","ref":"AWS.Backup.html#get_restore_testing_selection/4","title":"AWS.Backup.get_restore_testing_selection/4","type":"function"},{"doc":"Returns the Amazon Web Services resource types supported by Backup.","ref":"AWS.Backup.html#get_supported_resource_types/2","title":"AWS.Backup.get_supported_resource_types/2","type":"function"},{"doc":"This is a request for a summary of backup jobs created or running within the\nmost recent 30 days.\n\nYou can include parameters AccountID, State, ResourceType, MessageCategory,\nAggregationPeriod, MaxResults, or NextToken to filter results.\n\nThis request returns a summary that contains Region, Account, State,\nResourceType, MessageCategory, StartTime, EndTime, and Count of included jobs.","ref":"AWS.Backup.html#list_backup_job_summaries/9","title":"AWS.Backup.list_backup_job_summaries/9","type":"function"},{"doc":"Returns a list of existing backup jobs for an authenticated account for the last\n30 days.\n\nFor a longer period of time, consider using these [monitoring tools](https://docs.aws.amazon.com/aws-backup/latest/devguide/monitoring.html).","ref":"AWS.Backup.html#list_backup_jobs/15","title":"AWS.Backup.list_backup_jobs/15","type":"function"},{"doc":"Returns metadata of your saved backup plan templates, including the template ID,\nname, and the creation and deletion dates.","ref":"AWS.Backup.html#list_backup_plan_templates/4","title":"AWS.Backup.list_backup_plan_templates/4","type":"function"},{"doc":"Returns version metadata of your backup plans, including Amazon Resource Names\n(ARNs), backup plan IDs, creation and deletion dates, plan names, and version\nIDs.","ref":"AWS.Backup.html#list_backup_plan_versions/5","title":"AWS.Backup.list_backup_plan_versions/5","type":"function"},{"doc":"Returns a list of all active backup plans for an authenticated account.\n\nThe list contains information such as Amazon Resource Names (ARNs), plan IDs,\ncreation and deletion dates, version IDs, plan names, and creator request IDs.","ref":"AWS.Backup.html#list_backup_plans/5","title":"AWS.Backup.list_backup_plans/5","type":"function"},{"doc":"Returns an array containing metadata of the resources associated with the target\nbackup plan.","ref":"AWS.Backup.html#list_backup_selections/5","title":"AWS.Backup.list_backup_selections/5","type":"function"},{"doc":"Returns a list of recovery point storage containers along with information about\nthem.","ref":"AWS.Backup.html#list_backup_vaults/6","title":"AWS.Backup.list_backup_vaults/6","type":"function"},{"doc":"This request obtains a list of copy jobs created or running within the the most\nrecent 30 days.\n\nYou can include parameters AccountID, State, ResourceType, MessageCategory,\nAggregationPeriod, MaxResults, or NextToken to filter results.\n\nThis request returns a summary that contains Region, Account, State,\nRestourceType, MessageCategory, StartTime, EndTime, and Count of included jobs.","ref":"AWS.Backup.html#list_copy_job_summaries/9","title":"AWS.Backup.list_copy_job_summaries/9","type":"function"},{"doc":"Returns metadata about your copy jobs.","ref":"AWS.Backup.html#list_copy_jobs/15","title":"AWS.Backup.list_copy_jobs/15","type":"function"},{"doc":"Returns a list of all frameworks for an Amazon Web Services account and Amazon\nWeb Services Region.","ref":"AWS.Backup.html#list_frameworks/4","title":"AWS.Backup.list_frameworks/4","type":"function"},{"doc":"This action returns metadata about active and previous legal holds.","ref":"AWS.Backup.html#list_legal_holds/4","title":"AWS.Backup.list_legal_holds/4","type":"function"},{"doc":"Returns an array of resources successfully backed up by Backup, including the\ntime the resource was saved, an Amazon Resource Name (ARN) of the resource, and\na resource type.","ref":"AWS.Backup.html#list_protected_resources/4","title":"AWS.Backup.list_protected_resources/4","type":"function"},{"doc":"This request lists the protected resources corresponding to each backup vault.","ref":"AWS.Backup.html#list_protected_resources_by_backup_vault/6","title":"AWS.Backup.list_protected_resources_by_backup_vault/6","type":"function"},{"doc":"Returns detailed information about the recovery points stored in a backup vault.","ref":"AWS.Backup.html#list_recovery_points_by_backup_vault/12","title":"AWS.Backup.list_recovery_points_by_backup_vault/12","type":"function"},{"doc":"This action returns recovery point ARNs (Amazon Resource Names) of the specified\nlegal hold.","ref":"AWS.Backup.html#list_recovery_points_by_legal_hold/5","title":"AWS.Backup.list_recovery_points_by_legal_hold/5","type":"function"},{"doc":"Returns detailed information about all the recovery points of the type specified\nby a resource Amazon Resource Name (ARN).\n\nFor Amazon EFS and Amazon EC2, this action only lists recovery points created by\nBackup.","ref":"AWS.Backup.html#list_recovery_points_by_resource/5","title":"AWS.Backup.list_recovery_points_by_resource/5","type":"function"},{"doc":"Returns details about your report jobs.","ref":"AWS.Backup.html#list_report_jobs/8","title":"AWS.Backup.list_report_jobs/8","type":"function"},{"doc":"Returns a list of your report plans.\n\nFor detailed information about a single report plan, use `DescribeReportPlan`.","ref":"AWS.Backup.html#list_report_plans/4","title":"AWS.Backup.list_report_plans/4","type":"function"},{"doc":"This request obtains a summary of restore jobs created or running within the the\nmost recent 30 days.\n\nYou can include parameters AccountID, State, ResourceType, AggregationPeriod,\nMaxResults, or NextToken to filter results.\n\nThis request returns a summary that contains Region, Account, State,\nRestourceType, MessageCategory, StartTime, EndTime, and Count of included jobs.","ref":"AWS.Backup.html#list_restore_job_summaries/8","title":"AWS.Backup.list_restore_job_summaries/8","type":"function"},{"doc":"Returns a list of jobs that Backup initiated to restore a saved resource,\nincluding details about the recovery process.","ref":"AWS.Backup.html#list_restore_jobs/12","title":"AWS.Backup.list_restore_jobs/12","type":"function"},{"doc":"This returns restore jobs that contain the specified protected resource.\n\nYou must include `ResourceArn`. You can optionally include `NextToken`,\n`ByStatus`, `MaxResults`, `ByRecoveryPointCreationDateAfter` , and\n`ByRecoveryPointCreationDateBefore`.","ref":"AWS.Backup.html#list_restore_jobs_by_protected_resource/8","title":"AWS.Backup.list_restore_jobs_by_protected_resource/8","type":"function"},{"doc":"Returns a list of restore testing plans.","ref":"AWS.Backup.html#list_restore_testing_plans/4","title":"AWS.Backup.list_restore_testing_plans/4","type":"function"},{"doc":"Returns a list of restore testing selections.\n\nCan be filtered by `MaxResults` and `RestoreTestingPlanName`.","ref":"AWS.Backup.html#list_restore_testing_selections/5","title":"AWS.Backup.list_restore_testing_selections/5","type":"function"},{"doc":"Returns a list of key-value pairs assigned to a target recovery point, backup\nplan, or backup vault.\n\n`ListTags` only works for resource types that support full Backup management of\ntheir backups. Those resource types are listed in the \"Full Backup management\"\nsection of the [ Feature availability by resource](https://docs.aws.amazon.com/aws-backup/latest/devguide/whatisbackup.html#features-by-resource)\ntable.","ref":"AWS.Backup.html#list_tags/5","title":"AWS.Backup.list_tags/5","type":"function"},{"doc":"","ref":"AWS.Backup.html#metadata/0","title":"AWS.Backup.metadata/0","type":"function"},{"doc":"Sets a resource-based policy that is used to manage access permissions on the\ntarget backup vault.\n\nRequires a backup vault name and an access policy document in JSON format.","ref":"AWS.Backup.html#put_backup_vault_access_policy/4","title":"AWS.Backup.put_backup_vault_access_policy/4","type":"function"},{"doc":"Applies Backup Vault Lock to a backup vault, preventing attempts to delete any\nrecovery point stored in or created in a backup vault.\n\nVault Lock also prevents attempts to update the lifecycle policy that controls\nthe retention period of any recovery point currently stored in a backup vault.\nIf specified, Vault Lock enforces a minimum and maximum retention period for\nfuture backup and copy jobs that target a backup vault.\n\nBackup Vault Lock has been assessed by Cohasset Associates for use in\nenvironments that are subject to SEC 17a-4, CFTC, and FINRA regulations. For\nmore information about how Backup Vault Lock relates to these regulations, see\nthe [Cohasset Associates Compliance Assessment.](samples/cohassetreport.zip)","ref":"AWS.Backup.html#put_backup_vault_lock_configuration/4","title":"AWS.Backup.put_backup_vault_lock_configuration/4","type":"function"},{"doc":"Turns on notifications on a backup vault for the specified topic and events.","ref":"AWS.Backup.html#put_backup_vault_notifications/4","title":"AWS.Backup.put_backup_vault_notifications/4","type":"function"},{"doc":"This request allows you to send your independent self-run restore test\nvalidation results.\n\n`RestoreJobId` and `ValidationStatus` are required. Optionally, you can input a\n`ValidationStatusMessage`.","ref":"AWS.Backup.html#put_restore_validation_result/4","title":"AWS.Backup.put_restore_validation_result/4","type":"function"},{"doc":"Starts an on-demand backup job for the specified resource.","ref":"AWS.Backup.html#start_backup_job/3","title":"AWS.Backup.start_backup_job/3","type":"function"},{"doc":"Starts a job to create a one-time copy of the specified resource.\n\nDoes not support continuous backups.","ref":"AWS.Backup.html#start_copy_job/3","title":"AWS.Backup.start_copy_job/3","type":"function"},{"doc":"Starts an on-demand report job for the specified report plan.","ref":"AWS.Backup.html#start_report_job/4","title":"AWS.Backup.start_report_job/4","type":"function"},{"doc":"Recovers the saved resource identified by an Amazon Resource Name (ARN).","ref":"AWS.Backup.html#start_restore_job/3","title":"AWS.Backup.start_restore_job/3","type":"function"},{"doc":"Attempts to cancel a job to create a one-time backup of a resource.\n\nThis action is not supported for the following services: Amazon FSx for Windows\nFile Server, Amazon FSx for Lustre, FSx for ONTAP , Amazon FSx for OpenZFS,\nAmazon DocumentDB (with MongoDB compatibility), Amazon RDS, Amazon Aurora, and\nAmazon Neptune.","ref":"AWS.Backup.html#stop_backup_job/4","title":"AWS.Backup.stop_backup_job/4","type":"function"},{"doc":"Assigns a set of key-value pairs to a recovery point, backup plan, or backup\nvault identified by an Amazon Resource Name (ARN).","ref":"AWS.Backup.html#tag_resource/4","title":"AWS.Backup.tag_resource/4","type":"function"},{"doc":"Removes a set of key-value pairs from a recovery point, backup plan, or backup\nvault identified by an Amazon Resource Name (ARN)","ref":"AWS.Backup.html#untag_resource/4","title":"AWS.Backup.untag_resource/4","type":"function"},{"doc":"Updates an existing backup plan identified by its `backupPlanId` with the input\ndocument in JSON format.\n\nThe new version is uniquely identified by a `VersionId`.","ref":"AWS.Backup.html#update_backup_plan/4","title":"AWS.Backup.update_backup_plan/4","type":"function"},{"doc":"Updates an existing framework identified by its `FrameworkName` with the input\ndocument in JSON format.","ref":"AWS.Backup.html#update_framework/4","title":"AWS.Backup.update_framework/4","type":"function"},{"doc":"Updates whether the Amazon Web Services account is opted in to cross-account\nbackup.\n\nReturns an error if the account is not an Organizations management account. Use\nthe `DescribeGlobalSettings` API to determine the current settings.","ref":"AWS.Backup.html#update_global_settings/3","title":"AWS.Backup.update_global_settings/3","type":"function"},{"doc":"Sets the transition lifecycle of a recovery point.\n\nThe lifecycle defines when a protected resource is transitioned to cold storage\nand when it expires. Backup transitions and expires backups automatically\naccording to the lifecycle that you define.\n\nBackups transitioned to cold storage must be stored in cold storage for a\nminimum of 90 days. Therefore, the “retention” setting must be 90 days greater\nthan the “transition to cold after days” setting. The “transition to cold after\ndays” setting cannot be changed after a backup has been transitioned to cold.\n\nResource types that are able to be transitioned to cold storage are listed in\nthe \"Lifecycle to cold storage\" section of the [ Feature availability by resource](https://docs.aws.amazon.com/aws-backup/latest/devguide/whatisbackup.html#features-by-resource)\ntable. Backup ignores this expression for other resource types.\n\nThis operation does not support continuous backups.","ref":"AWS.Backup.html#update_recovery_point_lifecycle/5","title":"AWS.Backup.update_recovery_point_lifecycle/5","type":"function"},{"doc":"Updates the current service opt-in settings for the Region.\n\nUse the `DescribeRegionSettings` API to determine the resource types that are\nsupported.","ref":"AWS.Backup.html#update_region_settings/3","title":"AWS.Backup.update_region_settings/3","type":"function"},{"doc":"Updates an existing report plan identified by its `ReportPlanName` with the\ninput document in JSON format.","ref":"AWS.Backup.html#update_report_plan/4","title":"AWS.Backup.update_report_plan/4","type":"function"},{"doc":"This request will send changes to your specified restore testing plan.\n\n`RestoreTestingPlanName` cannot be updated after it is created.\n\n`RecoveryPointSelection` can contain:\n\n  * `Algorithm`\n\n  * `ExcludeVaults`\n\n  * `IncludeVaults`\n\n  * `RecoveryPointTypes`\n\n  * `SelectionWindowDays`","ref":"AWS.Backup.html#update_restore_testing_plan/4","title":"AWS.Backup.update_restore_testing_plan/4","type":"function"},{"doc":"Most elements except the `RestoreTestingSelectionName` can be updated with this\nrequest.\n\n`RestoreTestingSelection` can use either protected resource ARNs or conditions,\nbut not both. That is, if your selection has `ProtectedResourceArns`, requesting\nan update with the parameter `ProtectedResourceConditions` will be unsuccessful.","ref":"AWS.Backup.html#update_restore_testing_selection/5","title":"AWS.Backup.update_restore_testing_selection/5","type":"function"},{"doc":"Backup gateway\n\nBackup gateway connects Backup to your hypervisor, so you can create, store, and\nrestore backups of your virtual machines (VMs) anywhere, whether on-premises or\nin the VMware Cloud (VMC) on Amazon Web Services.\n\nAdd on-premises resources by connecting to a hypervisor through a gateway.\nBackup will automatically discover the resources in your hypervisor.\n\nUse Backup to assign virtual or on-premises resources to a backup plan, or run\non-demand backups. Once you have backed up your resources, you can view them and\nrestore them like any resource supported by Backup.\n\nTo download the Amazon Web Services software to get started, navigate to the\nBackup console, choose **Gateways**, then choose **Create gateway**.","ref":"AWS.BackupGateway.html","title":"AWS.BackupGateway","type":"module"},{"doc":"Associates a backup gateway with your server.\n\nAfter you complete the association process, you can back up and restore your VMs\nthrough the gateway.","ref":"AWS.BackupGateway.html#associate_gateway_to_server/3","title":"AWS.BackupGateway.associate_gateway_to_server/3","type":"function"},{"doc":"Creates a backup gateway.\n\nAfter you create a gateway, you can associate it with a server using the\n`AssociateGatewayToServer` operation.","ref":"AWS.BackupGateway.html#create_gateway/3","title":"AWS.BackupGateway.create_gateway/3","type":"function"},{"doc":"Deletes a backup gateway.","ref":"AWS.BackupGateway.html#delete_gateway/3","title":"AWS.BackupGateway.delete_gateway/3","type":"function"},{"doc":"Deletes a hypervisor.","ref":"AWS.BackupGateway.html#delete_hypervisor/3","title":"AWS.BackupGateway.delete_hypervisor/3","type":"function"},{"doc":"Disassociates a backup gateway from the specified server.\n\nAfter the disassociation process finishes, the gateway can no longer access the\nvirtual machines on the server.","ref":"AWS.BackupGateway.html#disassociate_gateway_from_server/3","title":"AWS.BackupGateway.disassociate_gateway_from_server/3","type":"function"},{"doc":"Retrieves the bandwidth rate limit schedule for a specified gateway.\n\nBy default, gateways do not have bandwidth rate limit schedules, which means no\nbandwidth rate limiting is in effect. Use this to get a gateway's bandwidth rate\nlimit schedule.","ref":"AWS.BackupGateway.html#get_bandwidth_rate_limit_schedule/3","title":"AWS.BackupGateway.get_bandwidth_rate_limit_schedule/3","type":"function"},{"doc":"By providing the ARN (Amazon Resource Name), this API returns the gateway.","ref":"AWS.BackupGateway.html#get_gateway/3","title":"AWS.BackupGateway.get_gateway/3","type":"function"},{"doc":"This action requests information about the specified hypervisor to which the\ngateway will connect.\n\nA hypervisor is hardware, software, or firmware that creates and manages virtual\nmachines, and allocates resources to them.","ref":"AWS.BackupGateway.html#get_hypervisor/3","title":"AWS.BackupGateway.get_hypervisor/3","type":"function"},{"doc":"This action retrieves the property mappings for the specified hypervisor.\n\nA hypervisor property mapping displays the relationship of entity properties\navailable from the on-premises hypervisor to the properties available in Amazon\nWeb Services.","ref":"AWS.BackupGateway.html#get_hypervisor_property_mappings/3","title":"AWS.BackupGateway.get_hypervisor_property_mappings/3","type":"function"},{"doc":"By providing the ARN (Amazon Resource Name), this API returns the virtual\nmachine.","ref":"AWS.BackupGateway.html#get_virtual_machine/3","title":"AWS.BackupGateway.get_virtual_machine/3","type":"function"},{"doc":"Connect to a hypervisor by importing its configuration.","ref":"AWS.BackupGateway.html#import_hypervisor_configuration/3","title":"AWS.BackupGateway.import_hypervisor_configuration/3","type":"function"},{"doc":"Lists backup gateways owned by an Amazon Web Services account in an Amazon Web\nServices Region.\n\nThe returned list is ordered by gateway Amazon Resource Name (ARN).","ref":"AWS.BackupGateway.html#list_gateways/3","title":"AWS.BackupGateway.list_gateways/3","type":"function"},{"doc":"Lists your hypervisors.","ref":"AWS.BackupGateway.html#list_hypervisors/3","title":"AWS.BackupGateway.list_hypervisors/3","type":"function"},{"doc":"Lists the tags applied to the resource identified by its Amazon Resource Name\n(ARN).","ref":"AWS.BackupGateway.html#list_tags_for_resource/3","title":"AWS.BackupGateway.list_tags_for_resource/3","type":"function"},{"doc":"Lists your virtual machines.","ref":"AWS.BackupGateway.html#list_virtual_machines/3","title":"AWS.BackupGateway.list_virtual_machines/3","type":"function"},{"doc":"","ref":"AWS.BackupGateway.html#metadata/0","title":"AWS.BackupGateway.metadata/0","type":"function"},{"doc":"This action sets the bandwidth rate limit schedule for a specified gateway.\n\nBy default, gateways do not have a bandwidth rate limit schedule, which means no\nbandwidth rate limiting is in effect. Use this to initiate a gateway's bandwidth\nrate limit schedule.","ref":"AWS.BackupGateway.html#put_bandwidth_rate_limit_schedule/3","title":"AWS.BackupGateway.put_bandwidth_rate_limit_schedule/3","type":"function"},{"doc":"This action sets the property mappings for the specified hypervisor.\n\nA hypervisor property mapping displays the relationship of entity properties\navailable from the on-premises hypervisor to the properties available in Amazon\nWeb Services.","ref":"AWS.BackupGateway.html#put_hypervisor_property_mappings/3","title":"AWS.BackupGateway.put_hypervisor_property_mappings/3","type":"function"},{"doc":"Set the maintenance start time for a gateway.","ref":"AWS.BackupGateway.html#put_maintenance_start_time/3","title":"AWS.BackupGateway.put_maintenance_start_time/3","type":"function"},{"doc":"This action sends a request to sync metadata across the specified virtual\nmachines.","ref":"AWS.BackupGateway.html#start_virtual_machines_metadata_sync/3","title":"AWS.BackupGateway.start_virtual_machines_metadata_sync/3","type":"function"},{"doc":"Tag the resource.","ref":"AWS.BackupGateway.html#tag_resource/3","title":"AWS.BackupGateway.tag_resource/3","type":"function"},{"doc":"Tests your hypervisor configuration to validate that backup gateway can connect\nwith the hypervisor and its resources.","ref":"AWS.BackupGateway.html#test_hypervisor_configuration/3","title":"AWS.BackupGateway.test_hypervisor_configuration/3","type":"function"},{"doc":"Removes tags from the resource.","ref":"AWS.BackupGateway.html#untag_resource/3","title":"AWS.BackupGateway.untag_resource/3","type":"function"},{"doc":"Updates a gateway's name.\n\nSpecify which gateway to update using the Amazon Resource Name (ARN) of the\ngateway in your request.","ref":"AWS.BackupGateway.html#update_gateway_information/3","title":"AWS.BackupGateway.update_gateway_information/3","type":"function"},{"doc":"Updates the gateway virtual machine (VM) software.\n\nThe request immediately triggers the software update.\n\nWhen you make this request, you get a `200 OK` success response immediately.\nHowever, it might take some time for the update to complete.","ref":"AWS.BackupGateway.html#update_gateway_software_now/3","title":"AWS.BackupGateway.update_gateway_software_now/3","type":"function"},{"doc":"Updates a hypervisor metadata, including its host, username, and password.\n\nSpecify which hypervisor to update using the Amazon Resource Name (ARN) of the\nhypervisor in your request.","ref":"AWS.BackupGateway.html#update_hypervisor/3","title":"AWS.BackupGateway.update_hypervisor/3","type":"function"},{"doc":"The frontend service for Cryo Storage.","ref":"AWS.BackupStorage.html","title":"AWS.BackupStorage","type":"module"},{"doc":"Delete Object from the incremental base Backup.","ref":"AWS.BackupStorage.html#delete_object/5","title":"AWS.BackupStorage.delete_object/5","type":"function"},{"doc":"Gets the specified object's chunk.","ref":"AWS.BackupStorage.html#get_chunk/4","title":"AWS.BackupStorage.get_chunk/4","type":"function"},{"doc":"Get metadata associated with an Object.","ref":"AWS.BackupStorage.html#get_object_metadata/4","title":"AWS.BackupStorage.get_object_metadata/4","type":"function"},{"doc":"List chunks in a given Object","ref":"AWS.BackupStorage.html#list_chunks/6","title":"AWS.BackupStorage.list_chunks/6","type":"function"},{"doc":"List all Objects in a given Backup.","ref":"AWS.BackupStorage.html#list_objects/9","title":"AWS.BackupStorage.list_objects/9","type":"function"},{"doc":"","ref":"AWS.BackupStorage.html#metadata/0","title":"AWS.BackupStorage.metadata/0","type":"function"},{"doc":"Complete upload","ref":"AWS.BackupStorage.html#notify_object_complete/5","title":"AWS.BackupStorage.notify_object_complete/5","type":"function"},{"doc":"Upload chunk.","ref":"AWS.BackupStorage.html#put_chunk/6","title":"AWS.BackupStorage.put_chunk/6","type":"function"},{"doc":"Upload object that can store object metadata String and data blob in single API\ncall using inline chunk field.","ref":"AWS.BackupStorage.html#put_object/5","title":"AWS.BackupStorage.put_object/5","type":"function"},{"doc":"Start upload containing one or many chunks.","ref":"AWS.BackupStorage.html#start_object/5","title":"AWS.BackupStorage.start_object/5","type":"function"},{"doc":"Batch\n\nUsing Batch, you can run batch computing workloads on the Amazon Web Services\nCloud.\n\nBatch computing is a common means for developers, scientists, and engineers to\naccess large amounts of compute resources. Batch uses the advantages of the\nbatch computing to remove the undifferentiated heavy lifting of configuring and\nmanaging required infrastructure. At the same time, it also adopts a familiar\nbatch computing software approach. You can use Batch to efficiently provision\nresources d, and work toward eliminating capacity constraints, reducing your\noverall compute costs, and delivering results more quickly.\n\nAs a fully managed service, Batch can run batch computing workloads of any\nscale. Batch automatically provisions compute resources and optimizes workload\ndistribution based on the quantity and scale of your specific workloads. With\nBatch, there's no need to install or manage batch computing software. This means\nthat you can focus on analyzing results and solving your specific problems\ninstead.","ref":"AWS.Batch.html","title":"AWS.Batch","type":"module"},{"doc":"Cancels a job in an Batch job queue.\n\nJobs that are in the `SUBMITTED` or `PENDING` are canceled. A job in`RUNNABLE`\nremains in `RUNNABLE` until it reaches the head of the job queue. Then the job\nstatus is updated to `FAILED`.\n\nA `PENDING` job is canceled after all dependency jobs are completed. Therefore,\nit may take longer than expected to cancel a job in `PENDING` status.\n\nWhen you try to cancel an array parent job in `PENDING`, Batch attempts to\ncancel all child jobs. The array parent job is canceled when all child jobs are\ncompleted.\n\nJobs that progressed to the `STARTING` or `RUNNING` state aren't canceled.\nHowever, the API operation still succeeds, even if no job is canceled. These\njobs must be terminated with the `TerminateJob` operation.","ref":"AWS.Batch.html#cancel_job/3","title":"AWS.Batch.cancel_job/3","type":"function"},{"doc":"Creates an Batch compute environment.\n\nYou can create `MANAGED` or `UNMANAGED` compute environments. `MANAGED` compute\nenvironments can use Amazon EC2 or Fargate resources. `UNMANAGED` compute\nenvironments can only use EC2 resources.\n\nIn a managed compute environment, Batch manages the capacity and instance types\nof the compute resources within the environment. This is based on the compute\nresource specification that you define or the [launch template](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-launch-templates.html)\nthat you specify when you create the compute environment. Either, you can choose\nto use EC2 On-Demand Instances and EC2 Spot Instances. Or, you can use Fargate\nand Fargate Spot capacity in your managed compute environment. You can\noptionally set a maximum price so that Spot Instances only launch when the Spot\nInstance price is less than a specified percentage of the On-Demand price.\n\nMulti-node parallel jobs aren't supported on Spot Instances.\n\nIn an unmanaged compute environment, you can manage your own EC2 compute\nresources and have flexibility with how you configure your compute resources.\nFor example, you can use custom AMIs. However, you must verify that each of your\nAMIs meet the Amazon ECS container instance AMI specification. For more\ninformation, see [container instance AMIs](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/container_instance_AMIs.html)\nin the *Amazon Elastic Container Service Developer Guide*. After you created\nyour unmanaged compute environment, you can use the\n`DescribeComputeEnvironments` operation to find the Amazon ECS cluster that's\nassociated with it. Then, launch your container instances into that Amazon ECS\ncluster. For more information, see [Launching an Amazon ECS container instance](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/launch_container_instance.html)\nin the *Amazon Elastic Container Service Developer Guide*.\n\nTo create a compute environment that uses EKS resources, the caller must have\npermissions to call `eks:DescribeCluster`.\n\nBatch doesn't automatically upgrade the AMIs in a compute environment after it's\ncreated. For example, it also doesn't update the AMIs in your compute\nenvironment when a newer version of the Amazon ECS optimized AMI is available.\nYou're responsible for the management of the guest operating system. This\nincludes any updates and security patches. You're also responsible for any\nadditional application software or utilities that you install on the compute\nresources. There are two ways to use a new AMI for your Batch jobs. The original\nmethod is to complete these steps:\n\n   Create a new compute environment with the new AMI.\n\n   Add the compute environment to an existing job queue.\n\n   Remove the earlier compute environment from your job queue.\n\n   Delete the earlier compute environment.\n\nIn April 2022, Batch added enhanced support for updating compute environments.\nFor more information, see [Updating compute environments](https://docs.aws.amazon.com/batch/latest/userguide/updating-compute-environments.html).\nTo use the enhanced updating of compute environments to update AMIs, follow\nthese rules:\n\n   Either don't set the service role (`serviceRole`) parameter or set\nit to the **AWSBatchServiceRole** service-linked role.\n\n   Set the allocation strategy (`allocationStrategy`) parameter to\n`BEST_FIT_PROGRESSIVE`, `SPOT_CAPACITY_OPTIMIZED`, or\n`SPOT_PRICE_CAPACITY_OPTIMIZED`.\n\n   Set the update to latest image version\n(`updateToLatestImageVersion`) parameter to `true`. The\n`updateToLatestImageVersion` parameter is used when you update a compute\nenvironment. This parameter is ignored when you create a compute environment.\n\n   Don't specify an AMI ID in `imageId`, `imageIdOverride` (in [\n`ec2Configuration`\n](https://docs.aws.amazon.com/batch/latest/APIReference/API_Ec2Configuration.html)),\nor in the launch template (`launchTemplate`). In that case, Batch selects the\nlatest Amazon ECS optimized AMI that's supported by Batch at the time the\ninfrastructure update is initiated. Alternatively, you can specify the AMI ID in\nthe `imageId` or `imageIdOverride` parameters, or the launch template identified\nby the `LaunchTemplate` properties. Changing any of these properties starts an\ninfrastructure update. If the AMI ID is specified in the launch template, it\ncan't be replaced by specifying an AMI ID in either the `imageId` or\n`imageIdOverride` parameters. It can only be replaced by specifying a different\nlaunch template, or if the launch template version is set to `$Default` or\n`$Latest`, by setting either a new default version for the launch template (if\n`$Default`) or by adding a new version to the launch template (if `$Latest`).\n\nIf these rules are followed, any update that starts an infrastructure update\ncauses the AMI ID to be re-selected. If the `version` setting in the launch\ntemplate (`launchTemplate`) is set to `$Latest` or `$Default`, the latest or\ndefault version of the launch template is evaluated up at the time of the\ninfrastructure update, even if the `launchTemplate` wasn't updated.","ref":"AWS.Batch.html#create_compute_environment/3","title":"AWS.Batch.create_compute_environment/3","type":"function"},{"doc":"Creates an Batch job queue.\n\nWhen you create a job queue, you associate one or more compute environments to\nthe queue and assign an order of preference for the compute environments.\n\nYou also set a priority to the job queue that determines the order that the\nBatch scheduler places jobs onto its associated compute environments. For\nexample, if a compute environment is associated with more than one job queue,\nthe job queue with a higher priority is given preference for scheduling jobs to\nthat compute environment.","ref":"AWS.Batch.html#create_job_queue/3","title":"AWS.Batch.create_job_queue/3","type":"function"},{"doc":"Creates an Batch scheduling policy.","ref":"AWS.Batch.html#create_scheduling_policy/3","title":"AWS.Batch.create_scheduling_policy/3","type":"function"},{"doc":"Deletes an Batch compute environment.\n\nBefore you can delete a compute environment, you must set its state to\n`DISABLED` with the `UpdateComputeEnvironment` API operation and disassociate it\nfrom any job queues with the `UpdateJobQueue` API operation. Compute\nenvironments that use Fargate resources must terminate all active jobs on that\ncompute environment before deleting the compute environment. If this isn't done,\nthe compute environment enters an invalid state.","ref":"AWS.Batch.html#delete_compute_environment/3","title":"AWS.Batch.delete_compute_environment/3","type":"function"},{"doc":"Deletes the specified job queue.\n\nYou must first disable submissions for a queue with the `UpdateJobQueue`\noperation. All jobs in the queue are eventually terminated when you delete a job\nqueue. The jobs are terminated at a rate of about 16 jobs each second.\n\nIt's not necessary to disassociate compute environments from a queue before\nsubmitting a `DeleteJobQueue` request.","ref":"AWS.Batch.html#delete_job_queue/3","title":"AWS.Batch.delete_job_queue/3","type":"function"},{"doc":"Deletes the specified scheduling policy.\n\nYou can't delete a scheduling policy that's used in any job queues.","ref":"AWS.Batch.html#delete_scheduling_policy/3","title":"AWS.Batch.delete_scheduling_policy/3","type":"function"},{"doc":"Deregisters an Batch job definition.\n\nJob definitions are permanently deleted after 180 days.","ref":"AWS.Batch.html#deregister_job_definition/3","title":"AWS.Batch.deregister_job_definition/3","type":"function"},{"doc":"Describes one or more of your compute environments.\n\nIf you're using an unmanaged compute environment, you can use the\n`DescribeComputeEnvironment` operation to determine the `ecsClusterArn` that you\nlaunch your Amazon ECS container instances into.","ref":"AWS.Batch.html#describe_compute_environments/3","title":"AWS.Batch.describe_compute_environments/3","type":"function"},{"doc":"Describes a list of job definitions.\n\nYou can specify a `status` (such as `ACTIVE`) to only return job definitions\nthat match that status.","ref":"AWS.Batch.html#describe_job_definitions/3","title":"AWS.Batch.describe_job_definitions/3","type":"function"},{"doc":"Describes one or more of your job queues.","ref":"AWS.Batch.html#describe_job_queues/3","title":"AWS.Batch.describe_job_queues/3","type":"function"},{"doc":"Describes a list of Batch jobs.","ref":"AWS.Batch.html#describe_jobs/3","title":"AWS.Batch.describe_jobs/3","type":"function"},{"doc":"Describes one or more of your scheduling policies.","ref":"AWS.Batch.html#describe_scheduling_policies/3","title":"AWS.Batch.describe_scheduling_policies/3","type":"function"},{"doc":"Returns a list of Batch jobs.\n\nYou must specify only one of the following items:\n\n  * A job queue ID to return a list of jobs in that job queue\n\n  * A multi-node parallel job ID to return a list of nodes for that\njob\n\n  * An array job ID to return a list of the children for that job\n\nYou can filter the results by job status with the `jobStatus` parameter. If you\ndon't specify a status, only `RUNNING` jobs are returned.","ref":"AWS.Batch.html#list_jobs/3","title":"AWS.Batch.list_jobs/3","type":"function"},{"doc":"Returns a list of Batch scheduling policies.","ref":"AWS.Batch.html#list_scheduling_policies/3","title":"AWS.Batch.list_scheduling_policies/3","type":"function"},{"doc":"Lists the tags for an Batch resource.\n\nBatch resources that support tags are compute environments, jobs, job\ndefinitions, job queues, and scheduling policies. ARNs for child jobs of array\nand multi-node parallel (MNP) jobs aren't supported.","ref":"AWS.Batch.html#list_tags_for_resource/3","title":"AWS.Batch.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.Batch.html#metadata/0","title":"AWS.Batch.metadata/0","type":"function"},{"doc":"Registers an Batch job definition.","ref":"AWS.Batch.html#register_job_definition/3","title":"AWS.Batch.register_job_definition/3","type":"function"},{"doc":"Submits an Batch job from a job definition.\n\nParameters that are specified during `SubmitJob` override parameters defined in\nthe job definition. vCPU and memory requirements that are specified in the\n`resourceRequirements` objects in the job definition are the exception. They\ncan't be overridden this way using the `memory` and `vcpus` parameters. Rather,\nyou must specify updates to job definition parameters in a\n`resourceRequirements` object that's included in the `containerOverrides`\nparameter.\n\nJob queues with a scheduling policy are limited to 500 active fair share\nidentifiers at a time.\n\nJobs that run on Fargate resources can't be guaranteed to run for more than 14\ndays. This is because, after 14 days, Fargate resources might become unavailable\nand job might be terminated.","ref":"AWS.Batch.html#submit_job/3","title":"AWS.Batch.submit_job/3","type":"function"},{"doc":"Associates the specified tags to a resource with the specified `resourceArn`.\n\nIf existing tags on a resource aren't specified in the request parameters, they\naren't changed. When a resource is deleted, the tags that are associated with\nthat resource are deleted as well. Batch resources that support tags are compute\nenvironments, jobs, job definitions, job queues, and scheduling policies. ARNs\nfor child jobs of array and multi-node parallel (MNP) jobs aren't supported.","ref":"AWS.Batch.html#tag_resource/4","title":"AWS.Batch.tag_resource/4","type":"function"},{"doc":"Terminates a job in a job queue.\n\nJobs that are in the `STARTING` or `RUNNING` state are terminated, which causes\nthem to transition to `FAILED`. Jobs that have not progressed to the `STARTING`\nstate are cancelled.","ref":"AWS.Batch.html#terminate_job/3","title":"AWS.Batch.terminate_job/3","type":"function"},{"doc":"Deletes specified tags from an Batch resource.","ref":"AWS.Batch.html#untag_resource/4","title":"AWS.Batch.untag_resource/4","type":"function"},{"doc":"Updates an Batch compute environment.","ref":"AWS.Batch.html#update_compute_environment/3","title":"AWS.Batch.update_compute_environment/3","type":"function"},{"doc":"Updates a job queue.","ref":"AWS.Batch.html#update_job_queue/3","title":"AWS.Batch.update_job_queue/3","type":"function"},{"doc":"Updates a scheduling policy.","ref":"AWS.Batch.html#update_scheduling_policy/3","title":"AWS.Batch.update_scheduling_policy/3","type":"function"},{"doc":"Describes the API operations for creating and managing Amazon Bedrock models.","ref":"AWS.Bedrock.html","title":"AWS.Bedrock","type":"module"},{"doc":"Creates a fine-tuning job to customize a base model.\n\nYou specify the base foundation model and the location of the training data.\nAfter the model-customization job completes successfully, your custom model\nresource will be ready to use. Training data contains input and output text for\neach record in a JSONL format. Optionally, you can specify validation data in\nthe same format as the training data. Amazon Bedrock returns validation loss\nmetrics and output generations after the job completes.\n\nModel-customization jobs are asynchronous and the completion time depends on the\nbase model and the training/validation data size. To monitor a job, use the\n`GetModelCustomizationJob` operation to retrieve the job status.\n\nFor more information, see [Custom models](https://docs.aws.amazon.com/bedrock/latest/userguide/custom-models.html)\nin the Bedrock User Guide.","ref":"AWS.Bedrock.html#create_model_customization_job/3","title":"AWS.Bedrock.create_model_customization_job/3","type":"function"},{"doc":"Creates a provisioned throughput with dedicated capacity for a foundation model\nor a fine-tuned model.\n\nFor more information, see [Provisioned throughput](https://docs.aws.amazon.com/bedrock/latest/userguide/what-is-service.html)\nin the Bedrock User Guide.","ref":"AWS.Bedrock.html#create_provisioned_model_throughput/3","title":"AWS.Bedrock.create_provisioned_model_throughput/3","type":"function"},{"doc":"Deletes a custom model that you created earlier.\n\nFor more information, see [Custom models](https://docs.aws.amazon.com/bedrock/latest/userguide/custom-models.html)\nin the Bedrock User Guide.","ref":"AWS.Bedrock.html#delete_custom_model/4","title":"AWS.Bedrock.delete_custom_model/4","type":"function"},{"doc":"Delete the invocation logging.","ref":"AWS.Bedrock.html#delete_model_invocation_logging_configuration/3","title":"AWS.Bedrock.delete_model_invocation_logging_configuration/3","type":"function"},{"doc":"Deletes a provisioned throughput.\n\nFor more information, see [Provisioned throughput](https://docs.aws.amazon.com/bedrock/latest/userguide/what-is-service.html)\nin the Bedrock User Guide.","ref":"AWS.Bedrock.html#delete_provisioned_model_throughput/4","title":"AWS.Bedrock.delete_provisioned_model_throughput/4","type":"function"},{"doc":"Get the properties associated with a Amazon Bedrock custom model that you have\ncreated.For more information, see [Custom models](https://docs.aws.amazon.com/bedrock/latest/userguide/custom-models.html)\nin the Bedrock User Guide.","ref":"AWS.Bedrock.html#get_custom_model/3","title":"AWS.Bedrock.get_custom_model/3","type":"function"},{"doc":"Get details about a Amazon Bedrock foundation model.","ref":"AWS.Bedrock.html#get_foundation_model/3","title":"AWS.Bedrock.get_foundation_model/3","type":"function"},{"doc":"Retrieves the properties associated with a model-customization job, including\nthe status of the job.\n\nFor more information, see [Custom models](https://docs.aws.amazon.com/bedrock/latest/userguide/custom-models.html)\nin the Bedrock User Guide.","ref":"AWS.Bedrock.html#get_model_customization_job/3","title":"AWS.Bedrock.get_model_customization_job/3","type":"function"},{"doc":"Get the current configuration values for model invocation logging.","ref":"AWS.Bedrock.html#get_model_invocation_logging_configuration/2","title":"AWS.Bedrock.get_model_invocation_logging_configuration/2","type":"function"},{"doc":"Get details for a provisioned throughput.\n\nFor more information, see [Provisioned throughput](https://docs.aws.amazon.com/bedrock/latest/userguide/what-is-service.html)\nin the Bedrock User Guide.","ref":"AWS.Bedrock.html#get_provisioned_model_throughput/3","title":"AWS.Bedrock.get_provisioned_model_throughput/3","type":"function"},{"doc":"Returns a list of the custom models that you have created with the\n`CreateModelCustomizationJob` operation.\n\nFor more information, see [Custom models](https://docs.aws.amazon.com/bedrock/latest/userguide/custom-models.html)\nin the Bedrock User Guide.","ref":"AWS.Bedrock.html#list_custom_models/11","title":"AWS.Bedrock.list_custom_models/11","type":"function"},{"doc":"List of Amazon Bedrock foundation models that you can use.\n\nFor more information, see [Foundation models](https://docs.aws.amazon.com/bedrock/latest/userguide/foundation-models.html)\nin the Bedrock User Guide.","ref":"AWS.Bedrock.html#list_foundation_models/6","title":"AWS.Bedrock.list_foundation_models/6","type":"function"},{"doc":"Returns a list of model customization jobs that you have submitted.\n\nYou can filter the jobs to return based on one or more criteria.\n\nFor more information, see [Custom models](https://docs.aws.amazon.com/bedrock/latest/userguide/custom-models.html)\nin the Bedrock User Guide.","ref":"AWS.Bedrock.html#list_model_customization_jobs/10","title":"AWS.Bedrock.list_model_customization_jobs/10","type":"function"},{"doc":"List the provisioned capacities.\n\nFor more information, see [Provisioned throughput](https://docs.aws.amazon.com/bedrock/latest/userguide/what-is-service.html)\nin the Bedrock User Guide.","ref":"AWS.Bedrock.html#list_provisioned_model_throughputs/11","title":"AWS.Bedrock.list_provisioned_model_throughputs/11","type":"function"},{"doc":"List the tags associated with the specified resource.\n\nFor more information, see [Tagging resources](https://docs.aws.amazon.com/bedrock/latest/userguide/what-is-service.html)\nin the Bedrock User Guide.","ref":"AWS.Bedrock.html#list_tags_for_resource/3","title":"AWS.Bedrock.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.Bedrock.html#metadata/0","title":"AWS.Bedrock.metadata/0","type":"function"},{"doc":"Set the configuration values for model invocation logging.","ref":"AWS.Bedrock.html#put_model_invocation_logging_configuration/3","title":"AWS.Bedrock.put_model_invocation_logging_configuration/3","type":"function"},{"doc":"Stops an active model customization job.\n\nFor more information, see [Custom models](https://docs.aws.amazon.com/bedrock/latest/userguide/custom-models.html)\nin the Bedrock User Guide.","ref":"AWS.Bedrock.html#stop_model_customization_job/4","title":"AWS.Bedrock.stop_model_customization_job/4","type":"function"},{"doc":"Associate tags with a resource.\n\nFor more information, see [Tagging resources](https://docs.aws.amazon.com/bedrock/latest/userguide/what-is-service.html)\nin the Bedrock User Guide.","ref":"AWS.Bedrock.html#tag_resource/3","title":"AWS.Bedrock.tag_resource/3","type":"function"},{"doc":"Remove one or more tags from a resource.\n\nFor more information, see [Tagging resources](https://docs.aws.amazon.com/bedrock/latest/userguide/what-is-service.html)\nin the Bedrock User Guide.","ref":"AWS.Bedrock.html#untag_resource/3","title":"AWS.Bedrock.untag_resource/3","type":"function"},{"doc":"Update a provisioned throughput.\n\nFor more information, see [Provisioned throughput](https://docs.aws.amazon.com/bedrock/latest/userguide/what-is-service.html)\nin the Bedrock User Guide.","ref":"AWS.Bedrock.html#update_provisioned_model_throughput/4","title":"AWS.Bedrock.update_provisioned_model_throughput/4","type":"function"},{"doc":"An example service, deployed with the Octane Service creator, which will echo\nthe string","ref":"AWS.BedrockAgent.html","title":"AWS.BedrockAgent","type":"module"},{"doc":"Associate a Knowledge Base to an existing Amazon Bedrock Agent","ref":"AWS.BedrockAgent.html#associate_agent_knowledge_base/5","title":"AWS.BedrockAgent.associate_agent_knowledge_base/5","type":"function"},{"doc":"Creates an Amazon Bedrock Agent","ref":"AWS.BedrockAgent.html#create_agent/3","title":"AWS.BedrockAgent.create_agent/3","type":"function"},{"doc":"Creates an Action Group for existing Amazon Bedrock Agent","ref":"AWS.BedrockAgent.html#create_agent_action_group/5","title":"AWS.BedrockAgent.create_agent_action_group/5","type":"function"},{"doc":"Creates an Alias for an existing Amazon Bedrock Agent","ref":"AWS.BedrockAgent.html#create_agent_alias/4","title":"AWS.BedrockAgent.create_agent_alias/4","type":"function"},{"doc":"Create a new data source","ref":"AWS.BedrockAgent.html#create_data_source/4","title":"AWS.BedrockAgent.create_data_source/4","type":"function"},{"doc":"Create a new knowledge base","ref":"AWS.BedrockAgent.html#create_knowledge_base/3","title":"AWS.BedrockAgent.create_knowledge_base/3","type":"function"},{"doc":"Deletes an Agent for existing Amazon Bedrock Agent","ref":"AWS.BedrockAgent.html#delete_agent/4","title":"AWS.BedrockAgent.delete_agent/4","type":"function"},{"doc":"Deletes an Action Group for existing Amazon Bedrock Agent.","ref":"AWS.BedrockAgent.html#delete_agent_action_group/6","title":"AWS.BedrockAgent.delete_agent_action_group/6","type":"function"},{"doc":"Deletes an Alias for a Amazon Bedrock Agent","ref":"AWS.BedrockAgent.html#delete_agent_alias/5","title":"AWS.BedrockAgent.delete_agent_alias/5","type":"function"},{"doc":"Deletes an Agent version for existing Amazon Bedrock Agent","ref":"AWS.BedrockAgent.html#delete_agent_version/5","title":"AWS.BedrockAgent.delete_agent_version/5","type":"function"},{"doc":"Delete an existing data source","ref":"AWS.BedrockAgent.html#delete_data_source/5","title":"AWS.BedrockAgent.delete_data_source/5","type":"function"},{"doc":"Delete an existing knowledge base","ref":"AWS.BedrockAgent.html#delete_knowledge_base/4","title":"AWS.BedrockAgent.delete_knowledge_base/4","type":"function"},{"doc":"Disassociate an existing Knowledge Base from an Amazon Bedrock Agent","ref":"AWS.BedrockAgent.html#disassociate_agent_knowledge_base/6","title":"AWS.BedrockAgent.disassociate_agent_knowledge_base/6","type":"function"},{"doc":"Gets an Agent for existing Amazon Bedrock Agent","ref":"AWS.BedrockAgent.html#get_agent/3","title":"AWS.BedrockAgent.get_agent/3","type":"function"},{"doc":"Gets an Action Group for existing Amazon Bedrock Agent Version","ref":"AWS.BedrockAgent.html#get_agent_action_group/5","title":"AWS.BedrockAgent.get_agent_action_group/5","type":"function"},{"doc":"Describes an Alias for a Amazon Bedrock Agent","ref":"AWS.BedrockAgent.html#get_agent_alias/4","title":"AWS.BedrockAgent.get_agent_alias/4","type":"function"},{"doc":"Gets a knowledge base associated to an existing Amazon Bedrock Agent Version","ref":"AWS.BedrockAgent.html#get_agent_knowledge_base/5","title":"AWS.BedrockAgent.get_agent_knowledge_base/5","type":"function"},{"doc":"Gets an Agent version for existing Amazon Bedrock Agent","ref":"AWS.BedrockAgent.html#get_agent_version/4","title":"AWS.BedrockAgent.get_agent_version/4","type":"function"},{"doc":"Get an existing data source","ref":"AWS.BedrockAgent.html#get_data_source/4","title":"AWS.BedrockAgent.get_data_source/4","type":"function"},{"doc":"Get an ingestion job","ref":"AWS.BedrockAgent.html#get_ingestion_job/5","title":"AWS.BedrockAgent.get_ingestion_job/5","type":"function"},{"doc":"Get an existing knowledge base","ref":"AWS.BedrockAgent.html#get_knowledge_base/3","title":"AWS.BedrockAgent.get_knowledge_base/3","type":"function"},{"doc":"Lists an Action Group for existing Amazon Bedrock Agent Version","ref":"AWS.BedrockAgent.html#list_agent_action_groups/5","title":"AWS.BedrockAgent.list_agent_action_groups/5","type":"function"},{"doc":"Lists all the Aliases for an Amazon Bedrock Agent","ref":"AWS.BedrockAgent.html#list_agent_aliases/4","title":"AWS.BedrockAgent.list_agent_aliases/4","type":"function"},{"doc":"List of Knowledge Bases associated to an existing Amazon Bedrock Agent Version","ref":"AWS.BedrockAgent.html#list_agent_knowledge_bases/5","title":"AWS.BedrockAgent.list_agent_knowledge_bases/5","type":"function"},{"doc":"Lists Agent Versions","ref":"AWS.BedrockAgent.html#list_agent_versions/4","title":"AWS.BedrockAgent.list_agent_versions/4","type":"function"},{"doc":"Lists Agents","ref":"AWS.BedrockAgent.html#list_agents/3","title":"AWS.BedrockAgent.list_agents/3","type":"function"},{"doc":"List data sources","ref":"AWS.BedrockAgent.html#list_data_sources/4","title":"AWS.BedrockAgent.list_data_sources/4","type":"function"},{"doc":"List ingestion jobs","ref":"AWS.BedrockAgent.html#list_ingestion_jobs/5","title":"AWS.BedrockAgent.list_ingestion_jobs/5","type":"function"},{"doc":"List Knowledge Bases","ref":"AWS.BedrockAgent.html#list_knowledge_bases/3","title":"AWS.BedrockAgent.list_knowledge_bases/3","type":"function"},{"doc":"List tags for a resource","ref":"AWS.BedrockAgent.html#list_tags_for_resource/3","title":"AWS.BedrockAgent.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.BedrockAgent.html#metadata/0","title":"AWS.BedrockAgent.metadata/0","type":"function"},{"doc":"Prepares an existing Amazon Bedrock Agent to receive runtime requests","ref":"AWS.BedrockAgent.html#prepare_agent/4","title":"AWS.BedrockAgent.prepare_agent/4","type":"function"},{"doc":"Start a new ingestion job","ref":"AWS.BedrockAgent.html#start_ingestion_job/5","title":"AWS.BedrockAgent.start_ingestion_job/5","type":"function"},{"doc":"Tag a resource","ref":"AWS.BedrockAgent.html#tag_resource/4","title":"AWS.BedrockAgent.tag_resource/4","type":"function"},{"doc":"Untag a resource","ref":"AWS.BedrockAgent.html#untag_resource/4","title":"AWS.BedrockAgent.untag_resource/4","type":"function"},{"doc":"Updates an existing Amazon Bedrock Agent","ref":"AWS.BedrockAgent.html#update_agent/4","title":"AWS.BedrockAgent.update_agent/4","type":"function"},{"doc":"Updates an existing Action Group for Amazon Bedrock Agent","ref":"AWS.BedrockAgent.html#update_agent_action_group/6","title":"AWS.BedrockAgent.update_agent_action_group/6","type":"function"},{"doc":"Updates an existing Alias for an Amazon Bedrock Agent","ref":"AWS.BedrockAgent.html#update_agent_alias/5","title":"AWS.BedrockAgent.update_agent_alias/5","type":"function"},{"doc":"Updates an existing Knowledge Base associated to an Amazon Bedrock Agent","ref":"AWS.BedrockAgent.html#update_agent_knowledge_base/6","title":"AWS.BedrockAgent.update_agent_knowledge_base/6","type":"function"},{"doc":"Update an existing data source","ref":"AWS.BedrockAgent.html#update_data_source/5","title":"AWS.BedrockAgent.update_data_source/5","type":"function"},{"doc":"Update an existing knowledge base","ref":"AWS.BedrockAgent.html#update_knowledge_base/4","title":"AWS.BedrockAgent.update_knowledge_base/4","type":"function"},{"doc":"Amazon Bedrock Agent","ref":"AWS.BedrockAgentRuntime.html","title":"AWS.BedrockAgentRuntime","type":"module"},{"doc":"Invokes the specified Bedrock model to run inference using the input provided in\nthe request body.","ref":"AWS.BedrockAgentRuntime.html#invoke_agent/6","title":"AWS.BedrockAgentRuntime.invoke_agent/6","type":"function"},{"doc":"","ref":"AWS.BedrockAgentRuntime.html#metadata/0","title":"AWS.BedrockAgentRuntime.metadata/0","type":"function"},{"doc":"Retrieve from knowledge base.","ref":"AWS.BedrockAgentRuntime.html#retrieve/4","title":"AWS.BedrockAgentRuntime.retrieve/4","type":"function"},{"doc":"RetrieveAndGenerate API","ref":"AWS.BedrockAgentRuntime.html#retrieve_and_generate/3","title":"AWS.BedrockAgentRuntime.retrieve_and_generate/3","type":"function"},{"doc":"Describes the API operations for running inference using Bedrock models.","ref":"AWS.BedrockRuntime.html","title":"AWS.BedrockRuntime","type":"module"},{"doc":"Invokes the specified Bedrock model to run inference using the input provided in\nthe request body.\n\nYou use InvokeModel to run inference for text models, image models, and\nembedding models.\n\nFor more information, see [Run inference](https://docs.aws.amazon.com/bedrock/latest/userguide/api-methods-run.html)\nin the Bedrock User Guide.\n\nFor example requests, see Examples (after the Errors section).","ref":"AWS.BedrockRuntime.html#invoke_model/4","title":"AWS.BedrockRuntime.invoke_model/4","type":"function"},{"doc":"Invoke the specified Bedrock model to run inference using the input provided.\n\nReturn the response in a stream.\n\nFor more information, see [Run inference](https://docs.aws.amazon.com/bedrock/latest/userguide/api-methods-run.html)\nin the Bedrock User Guide.\n\nFor an example request and response, see Examples (after the Errors section).","ref":"AWS.BedrockRuntime.html#invoke_model_with_response_stream/4","title":"AWS.BedrockRuntime.invoke_model_with_response_stream/4","type":"function"},{"doc":"","ref":"AWS.BedrockRuntime.html#metadata/0","title":"AWS.BedrockRuntime.metadata/0","type":"function"},{"doc":"Amazon Web Services Billing Conductor is a fully managed service that you can\nuse to customize a\n[proforma](https://docs.aws.amazon.com/billingconductor/latest/userguide/understanding-eb.html#eb-other-definitions) version of your billing data each month, to accurately show or chargeback your\nend customers.\n\nAmazon Web Services Billing Conductor doesn't change the way you're billed by\nAmazon Web Services each month by design. Instead, it provides you with a\nmechanism to configure, generate, and display rates to certain customers over a\ngiven billing period. You can also analyze the difference between the rates you\napply to your accounting groupings relative to your actual rates from Amazon Web\nServices. As a result of your Amazon Web Services Billing Conductor\nconfiguration, the payer account can also see the custom rate applied on the\nbilling details page of the [Amazon Web Services Billing\nconsole](https://console.aws.amazon.com/billing), or configure a cost and usage\nreport per billing group.\n\nThis documentation shows how you can configure Amazon Web Services Billing\nConductor using its API. For more information about using the [Amazon Web Services Billing Conductor](https://console.aws.amazon.com/billingconductor/)\nuser interface, see the [ Amazon Web Services Billing Conductor User Guide](https://docs.aws.amazon.com/billingconductor/latest/userguide/what-is-billingconductor.html).","ref":"AWS.Billingconductor.html","title":"AWS.Billingconductor","type":"module"},{"doc":"Connects an array of account IDs in a consolidated billing family to a\npredefined billing group.\n\nThe account IDs must be a part of the consolidated billing family during the\ncurrent month, and not already associated with another billing group. The\nmaximum number of accounts that can be associated in one call is 30.","ref":"AWS.Billingconductor.html#associate_accounts/3","title":"AWS.Billingconductor.associate_accounts/3","type":"function"},{"doc":"Connects an array of `PricingRuleArns` to a defined `PricingPlan`.\n\nThe maximum number `PricingRuleArn` that can be associated in one call is 30.","ref":"AWS.Billingconductor.html#associate_pricing_rules/3","title":"AWS.Billingconductor.associate_pricing_rules/3","type":"function"},{"doc":"Associates a batch of resources to a percentage custom line item.","ref":"AWS.Billingconductor.html#batch_associate_resources_to_custom_line_item/3","title":"AWS.Billingconductor.batch_associate_resources_to_custom_line_item/3","type":"function"},{"doc":"Disassociates a batch of resources from a percentage custom line item.","ref":"AWS.Billingconductor.html#batch_disassociate_resources_from_custom_line_item/3","title":"AWS.Billingconductor.batch_disassociate_resources_from_custom_line_item/3","type":"function"},{"doc":"Creates a billing group that resembles a consolidated billing family that Amazon\nWeb Services charges, based off of the predefined pricing plan computation.","ref":"AWS.Billingconductor.html#create_billing_group/3","title":"AWS.Billingconductor.create_billing_group/3","type":"function"},{"doc":"Creates a custom line item that can be used to create a one-time fixed charge\nthat can be applied to a single billing group for the current or previous\nbilling period.\n\nThe one-time fixed charge is either a fee or discount.","ref":"AWS.Billingconductor.html#create_custom_line_item/3","title":"AWS.Billingconductor.create_custom_line_item/3","type":"function"},{"doc":"Creates a pricing plan that is used for computing Amazon Web Services charges\nfor billing groups.","ref":"AWS.Billingconductor.html#create_pricing_plan/3","title":"AWS.Billingconductor.create_pricing_plan/3","type":"function"},{"doc":"Creates a pricing rule can be associated to a pricing plan, or a set of pricing\nplans.","ref":"AWS.Billingconductor.html#create_pricing_rule/3","title":"AWS.Billingconductor.create_pricing_rule/3","type":"function"},{"doc":"Deletes a billing group.","ref":"AWS.Billingconductor.html#delete_billing_group/3","title":"AWS.Billingconductor.delete_billing_group/3","type":"function"},{"doc":"Deletes the custom line item identified by the given ARN in the current, or\nprevious billing period.","ref":"AWS.Billingconductor.html#delete_custom_line_item/3","title":"AWS.Billingconductor.delete_custom_line_item/3","type":"function"},{"doc":"Deletes a pricing plan.\n\nThe pricing plan must not be associated with any billing groups to delete\nsuccessfully.","ref":"AWS.Billingconductor.html#delete_pricing_plan/3","title":"AWS.Billingconductor.delete_pricing_plan/3","type":"function"},{"doc":"Deletes the pricing rule that's identified by the input Amazon Resource Name\n(ARN).","ref":"AWS.Billingconductor.html#delete_pricing_rule/3","title":"AWS.Billingconductor.delete_pricing_rule/3","type":"function"},{"doc":"Removes the specified list of account IDs from the given billing group.","ref":"AWS.Billingconductor.html#disassociate_accounts/3","title":"AWS.Billingconductor.disassociate_accounts/3","type":"function"},{"doc":"Disassociates a list of pricing rules from a pricing plan.","ref":"AWS.Billingconductor.html#disassociate_pricing_rules/3","title":"AWS.Billingconductor.disassociate_pricing_rules/3","type":"function"},{"doc":"Retrieves the margin summary report, which includes the Amazon Web Services cost\nand charged amount (pro forma cost) by Amazon Web Service for a specific billing\ngroup.","ref":"AWS.Billingconductor.html#get_billing_group_cost_report/3","title":"AWS.Billingconductor.get_billing_group_cost_report/3","type":"function"},{"doc":"This is a paginated call to list linked accounts that are linked to the payer\naccount for the specified time period.\n\nIf no information is provided, the current billing period is used. The response\nwill optionally include the billing group that's associated with the linked\naccount.","ref":"AWS.Billingconductor.html#list_account_associations/3","title":"AWS.Billingconductor.list_account_associations/3","type":"function"},{"doc":"A paginated call to retrieve a summary report of actual Amazon Web Services\ncharges and the calculated Amazon Web Services charges based on the associated\npricing plan of a billing group.","ref":"AWS.Billingconductor.html#list_billing_group_cost_reports/3","title":"AWS.Billingconductor.list_billing_group_cost_reports/3","type":"function"},{"doc":"A paginated call to retrieve a list of billing groups for the given billing\nperiod.\n\nIf you don't provide a billing group, the current billing period is used.","ref":"AWS.Billingconductor.html#list_billing_groups/3","title":"AWS.Billingconductor.list_billing_groups/3","type":"function"},{"doc":"A paginated call to get a list of all custom line item versions.","ref":"AWS.Billingconductor.html#list_custom_line_item_versions/3","title":"AWS.Billingconductor.list_custom_line_item_versions/3","type":"function"},{"doc":"A paginated call to get a list of all custom line items (FFLIs) for the given\nbilling period.\n\nIf you don't provide a billing period, the current billing period is used.","ref":"AWS.Billingconductor.html#list_custom_line_items/3","title":"AWS.Billingconductor.list_custom_line_items/3","type":"function"},{"doc":"A paginated call to get pricing plans for the given billing period.\n\nIf you don't provide a billing period, the current billing period is used.","ref":"AWS.Billingconductor.html#list_pricing_plans/3","title":"AWS.Billingconductor.list_pricing_plans/3","type":"function"},{"doc":"A list of the pricing plans that are associated with a pricing rule.","ref":"AWS.Billingconductor.html#list_pricing_plans_associated_with_pricing_rule/3","title":"AWS.Billingconductor.list_pricing_plans_associated_with_pricing_rule/3","type":"function"},{"doc":"Describes a pricing rule that can be associated to a pricing plan, or set of\npricing plans.","ref":"AWS.Billingconductor.html#list_pricing_rules/3","title":"AWS.Billingconductor.list_pricing_rules/3","type":"function"},{"doc":"Lists the pricing rules that are associated with a pricing plan.","ref":"AWS.Billingconductor.html#list_pricing_rules_associated_to_pricing_plan/3","title":"AWS.Billingconductor.list_pricing_rules_associated_to_pricing_plan/3","type":"function"},{"doc":"List the resources that are associated to a custom line item.","ref":"AWS.Billingconductor.html#list_resources_associated_to_custom_line_item/3","title":"AWS.Billingconductor.list_resources_associated_to_custom_line_item/3","type":"function"},{"doc":"A list the tags for a resource.","ref":"AWS.Billingconductor.html#list_tags_for_resource/3","title":"AWS.Billingconductor.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.Billingconductor.html#metadata/0","title":"AWS.Billingconductor.metadata/0","type":"function"},{"doc":"Associates the specified tags to a resource with the specified `resourceArn`.\n\nIf existing tags on a resource are not specified in the request parameters, they\nare not changed.","ref":"AWS.Billingconductor.html#tag_resource/4","title":"AWS.Billingconductor.tag_resource/4","type":"function"},{"doc":"Deletes specified tags from a resource.","ref":"AWS.Billingconductor.html#untag_resource/4","title":"AWS.Billingconductor.untag_resource/4","type":"function"},{"doc":"This updates an existing billing group.","ref":"AWS.Billingconductor.html#update_billing_group/3","title":"AWS.Billingconductor.update_billing_group/3","type":"function"},{"doc":"Update an existing custom line item in the current or previous billing period.","ref":"AWS.Billingconductor.html#update_custom_line_item/3","title":"AWS.Billingconductor.update_custom_line_item/3","type":"function"},{"doc":"This updates an existing pricing plan.","ref":"AWS.Billingconductor.html#update_pricing_plan/3","title":"AWS.Billingconductor.update_pricing_plan/3","type":"function"},{"doc":"Updates an existing pricing rule.","ref":"AWS.Billingconductor.html#update_pricing_rule/3","title":"AWS.Billingconductor.update_pricing_rule/3","type":"function"},{"doc":"The Amazon Braket API Reference provides information about the operations and\nstructures supported in Amazon Braket.\n\nAdditional Resources:\n\n  * [Amazon Braket Developer Guide](https://docs.aws.amazon.com/braket/latest/developerguide/what-is-braket.html)","ref":"AWS.Braket.html","title":"AWS.Braket","type":"module"},{"doc":"Cancels an Amazon Braket job.","ref":"AWS.Braket.html#cancel_job/4","title":"AWS.Braket.cancel_job/4","type":"function"},{"doc":"Cancels the specified task.","ref":"AWS.Braket.html#cancel_quantum_task/4","title":"AWS.Braket.cancel_quantum_task/4","type":"function"},{"doc":"Creates an Amazon Braket job.","ref":"AWS.Braket.html#create_job/3","title":"AWS.Braket.create_job/3","type":"function"},{"doc":"Creates a quantum task.","ref":"AWS.Braket.html#create_quantum_task/3","title":"AWS.Braket.create_quantum_task/3","type":"function"},{"doc":"Retrieves the devices available in Amazon Braket.\n\nFor backwards compatibility with older versions of BraketSchemas, OpenQASM\ninformation is omitted from GetDevice API calls. To get this information the\nuser-agent needs to present a recent version of the BraketSchemas (1.8.0 or\nlater). The Braket SDK automatically reports this for you. If you do not see\nOpenQASM results in the GetDevice response when using a Braket SDK, you may need\nto set AWS_EXECUTION_ENV environment variable to configure user-agent. See the\ncode examples provided below for how to do this for the AWS CLI, Boto3, and the\nGo, Java, and JavaScript/TypeScript SDKs.","ref":"AWS.Braket.html#get_device/3","title":"AWS.Braket.get_device/3","type":"function"},{"doc":"Retrieves the specified Amazon Braket job.","ref":"AWS.Braket.html#get_job/4","title":"AWS.Braket.get_job/4","type":"function"},{"doc":"Retrieves the specified quantum task.","ref":"AWS.Braket.html#get_quantum_task/4","title":"AWS.Braket.get_quantum_task/4","type":"function"},{"doc":"Shows the tags associated with this resource.","ref":"AWS.Braket.html#list_tags_for_resource/3","title":"AWS.Braket.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.Braket.html#metadata/0","title":"AWS.Braket.metadata/0","type":"function"},{"doc":"Searches for devices using the specified filters.","ref":"AWS.Braket.html#search_devices/3","title":"AWS.Braket.search_devices/3","type":"function"},{"doc":"Searches for Amazon Braket jobs that match the specified filter values.","ref":"AWS.Braket.html#search_jobs/3","title":"AWS.Braket.search_jobs/3","type":"function"},{"doc":"Searches for tasks that match the specified filter values.","ref":"AWS.Braket.html#search_quantum_tasks/3","title":"AWS.Braket.search_quantum_tasks/3","type":"function"},{"doc":"Add a tag to the specified resource.","ref":"AWS.Braket.html#tag_resource/4","title":"AWS.Braket.tag_resource/4","type":"function"},{"doc":"Remove tags from a resource.","ref":"AWS.Braket.html#untag_resource/4","title":"AWS.Braket.untag_resource/4","type":"function"},{"doc":"Use the Amazon Web Services Budgets API to plan your service usage, service\ncosts, and instance reservations.\n\nThis API reference provides descriptions, syntax, and usage examples for each of\nthe actions and data types for the Amazon Web Services Budgets feature.\n\nBudgets provide you with a way to see the following information:\n\n  * How close your plan is to your budgeted amount or to the free tier\nlimits\n\n  * Your usage-to-date, including how much you've used of your\nReserved Instances (RIs)\n\n  * Your current estimated charges from Amazon Web Services, and how\nmuch your predicted usage will accrue in charges by the end of the month\n\n  * How much of your budget has been used\n\nAmazon Web Services updates your budget status several times a day. Budgets\ntrack your unblended costs, subscriptions, refunds, and RIs. You can create the\nfollowing types of budgets:\n\n  * **Cost budgets** - Plan how much you want to spend on a service.\n\n  * **Usage budgets** - Plan how much you want to use one or more\nservices.\n\n  * **RI utilization budgets** - Define a utilization threshold, and\nreceive alerts when your RI usage falls below that threshold. This lets you see\nif your RIs are unused or under-utilized.\n\n  * **RI coverage budgets** - Define a coverage threshold, and receive\nalerts when the number of your instance hours that are covered by RIs fall below\nthat threshold. This lets you see how much of your instance usage is covered by\na reservation.\n\nService Endpoint\n\nThe Amazon Web Services Budgets API provides the following endpoint:\n\n  * https://budgets.amazonaws.com\n\nFor information about costs that are associated with the Amazon Web Services\nBudgets API, see [Amazon Web Services Cost Management Pricing](https://aws.amazon.com/aws-cost-management/pricing/).","ref":"AWS.Budgets.html","title":"AWS.Budgets","type":"module"},{"doc":"Creates a budget and, if included, notifications and subscribers.\n\nOnly one of `BudgetLimit` or `PlannedBudgetLimits` can be present in the syntax\nat one time. Use the syntax that matches your case. The Request Syntax section\nshows the `BudgetLimit` syntax. For `PlannedBudgetLimits`, see the\n[Examples](https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_budgets_CreateBudget.html#API_CreateBudget_Examples)\nsection.","ref":"AWS.Budgets.html#create_budget/3","title":"AWS.Budgets.create_budget/3","type":"function"},{"doc":"Creates a budget action.","ref":"AWS.Budgets.html#create_budget_action/3","title":"AWS.Budgets.create_budget_action/3","type":"function"},{"doc":"Creates a notification.\n\nYou must create the budget before you create the associated notification.","ref":"AWS.Budgets.html#create_notification/3","title":"AWS.Budgets.create_notification/3","type":"function"},{"doc":"Creates a subscriber.\n\nYou must create the associated budget and notification before you create the\nsubscriber.","ref":"AWS.Budgets.html#create_subscriber/3","title":"AWS.Budgets.create_subscriber/3","type":"function"},{"doc":"Deletes a budget.\n\nYou can delete your budget at any time.\n\nDeleting a budget also deletes the notifications and subscribers that are\nassociated with that budget.","ref":"AWS.Budgets.html#delete_budget/3","title":"AWS.Budgets.delete_budget/3","type":"function"},{"doc":"Deletes a budget action.","ref":"AWS.Budgets.html#delete_budget_action/3","title":"AWS.Budgets.delete_budget_action/3","type":"function"},{"doc":"Deletes a notification.\n\nDeleting a notification also deletes the subscribers that are associated with\nthe notification.","ref":"AWS.Budgets.html#delete_notification/3","title":"AWS.Budgets.delete_notification/3","type":"function"},{"doc":"Deletes a subscriber.\n\nDeleting the last subscriber to a notification also deletes the notification.","ref":"AWS.Budgets.html#delete_subscriber/3","title":"AWS.Budgets.delete_subscriber/3","type":"function"},{"doc":"Describes a budget.\n\nThe Request Syntax section shows the `BudgetLimit` syntax. For\n`PlannedBudgetLimits`, see the\n[Examples](https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_budgets_DescribeBudget.html#API_DescribeBudget_Examples)\nsection.","ref":"AWS.Budgets.html#describe_budget/3","title":"AWS.Budgets.describe_budget/3","type":"function"},{"doc":"Describes a budget action detail.","ref":"AWS.Budgets.html#describe_budget_action/3","title":"AWS.Budgets.describe_budget_action/3","type":"function"},{"doc":"Describes a budget action history detail.","ref":"AWS.Budgets.html#describe_budget_action_histories/3","title":"AWS.Budgets.describe_budget_action_histories/3","type":"function"},{"doc":"Describes all of the budget actions for an account.","ref":"AWS.Budgets.html#describe_budget_actions_for_account/3","title":"AWS.Budgets.describe_budget_actions_for_account/3","type":"function"},{"doc":"Describes all of the budget actions for a budget.","ref":"AWS.Budgets.html#describe_budget_actions_for_budget/3","title":"AWS.Budgets.describe_budget_actions_for_budget/3","type":"function"},{"doc":"Lists the budget names and notifications that are associated with an account.","ref":"AWS.Budgets.html#describe_budget_notifications_for_account/3","title":"AWS.Budgets.describe_budget_notifications_for_account/3","type":"function"},{"doc":"Describes the history for `DAILY`, `MONTHLY`, and `QUARTERLY` budgets.\n\nBudget history isn't available for `ANNUAL` budgets.","ref":"AWS.Budgets.html#describe_budget_performance_history/3","title":"AWS.Budgets.describe_budget_performance_history/3","type":"function"},{"doc":"Lists the budgets that are associated with an account.\n\nThe Request Syntax section shows the `BudgetLimit` syntax. For\n`PlannedBudgetLimits`, see the\n[Examples](https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_budgets_DescribeBudgets.html#API_DescribeBudgets_Examples)\nsection.","ref":"AWS.Budgets.html#describe_budgets/3","title":"AWS.Budgets.describe_budgets/3","type":"function"},{"doc":"Lists the notifications that are associated with a budget.","ref":"AWS.Budgets.html#describe_notifications_for_budget/3","title":"AWS.Budgets.describe_notifications_for_budget/3","type":"function"},{"doc":"Lists the subscribers that are associated with a notification.","ref":"AWS.Budgets.html#describe_subscribers_for_notification/3","title":"AWS.Budgets.describe_subscribers_for_notification/3","type":"function"},{"doc":"Executes a budget action.","ref":"AWS.Budgets.html#execute_budget_action/3","title":"AWS.Budgets.execute_budget_action/3","type":"function"},{"doc":"","ref":"AWS.Budgets.html#metadata/0","title":"AWS.Budgets.metadata/0","type":"function"},{"doc":"Updates a budget.\n\nYou can change every part of a budget except for the `budgetName` and the\n`calculatedSpend`. When you modify a budget, the `calculatedSpend` drops to zero\nuntil Amazon Web Services has new usage data to use for forecasting.\n\nOnly one of `BudgetLimit` or `PlannedBudgetLimits` can be present in the syntax\nat one time. Use the syntax that matches your case. The Request Syntax section\nshows the `BudgetLimit` syntax. For `PlannedBudgetLimits`, see the\n[Examples](https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_budgets_UpdateBudget.html#API_UpdateBudget_Examples)\nsection.","ref":"AWS.Budgets.html#update_budget/3","title":"AWS.Budgets.update_budget/3","type":"function"},{"doc":"Updates a budget action.","ref":"AWS.Budgets.html#update_budget_action/3","title":"AWS.Budgets.update_budget_action/3","type":"function"},{"doc":"Updates a notification.","ref":"AWS.Budgets.html#update_notification/3","title":"AWS.Budgets.update_notification/3","type":"function"},{"doc":"Updates a subscriber.","ref":"AWS.Budgets.html#update_subscriber/3","title":"AWS.Budgets.update_subscriber/3","type":"function"},{"doc":"**Most of these APIs are no longer supported and will not be updated.** We\nrecommend using the latest versions in the [Amazon Chime SDK API reference](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/welcome.html),\nin the Amazon Chime SDK.\n\nUsing the latest versions requires migrating to dedicated namespaces. For more\ninformation, refer to [Migrating from the Amazon Chime namespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.\n\nThe Amazon Chime application programming interface (API) is designed so\nadministrators can perform key tasks, such as creating and managing Amazon Chime\naccounts, users, and Voice Connectors. This guide provides detailed information\nabout the Amazon Chime API, including operations, types, inputs and outputs, and\nerror codes.\n\nYou can use an AWS SDK, the AWS Command Line Interface (AWS CLI), or the REST\nAPI to make API calls for Amazon Chime. We recommend using an AWS SDK or the AWS\nCLI. The page for each API action contains a *See Also* section that includes\nlinks to information about using the action with a language-specific AWS SDK or\nthe AWS CLI.","ref":"AWS.Chime.html","title":"AWS.Chime","type":"module"},{"doc":"#","ref":"AWS.Chime.html#module-definitions","title":"Definitions - AWS.Chime","type":"module"},{"doc":"You don't need to write code to calculate a signature for request\nauthentication. The SDK clients authenticate your requests by using access keys\nthat you provide. For more information about AWS SDKs, see the [AWS Developer Center](http://aws.amazon.com/developer/).\n\n#","ref":"AWS.Chime.html#module-using-an-aws-sdk","title":"Using an AWS SDK - AWS.Chime","type":"module"},{"doc":"Use your access keys with the AWS CLI to make API calls. For information about\nsetting up the AWS CLI, see [Installing the AWS Command Line Interface](https://docs.aws.amazon.com/cli/latest/userguide/installing.html) in\nthe *AWS Command Line Interface User Guide*. For a list of available Amazon\nChime commands, see the [Amazon Chime commands](https://docs.aws.amazon.com/cli/latest/reference/chime/index.html) in\nthe *AWS CLI Command Reference*.\n\n#","ref":"AWS.Chime.html#module-using-the-aws-cli","title":"Using the AWS CLI - AWS.Chime","type":"module"},{"doc":"If you use REST to make API calls, you must authenticate your request by\nproviding a signature. Amazon Chime supports Signature Version 4. For more\ninformation, see [Signature Version 4 Signing Process](https://docs.aws.amazon.com/general/latest/gr/signature-version-4.html)\nin the *Amazon Web Services General Reference*.\n\nWhen making REST API calls, use the service name `chime` and REST endpoint\n`https://service.chime.aws.amazon.com`.\n\nAdministrative permissions are controlled using AWS Identity and Access\nManagement (IAM). For more information, see [Identity and Access Management for Amazon Chime](https://docs.aws.amazon.com/chime/latest/ag/security-iam.html) in\nthe *Amazon Chime Administration Guide*.","ref":"AWS.Chime.html#module-using-rest-apis","title":"Using REST APIs - AWS.Chime","type":"module"},{"doc":"Associates a phone number with the specified Amazon Chime user.","ref":"AWS.Chime.html#associate_phone_number_with_user/5","title":"AWS.Chime.associate_phone_number_with_user/5","type":"function"},{"doc":"Associates phone numbers with the specified Amazon Chime Voice Connector.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[AssociatePhoneNumbersWithVoiceConnector](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_AssociatePhoneNumbersWithVoiceConnector.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#associate_phone_numbers_with_voice_connector/4","title":"AWS.Chime.associate_phone_numbers_with_voice_connector/4","type":"function"},{"doc":"Associates phone numbers with the specified Amazon Chime Voice Connector group.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[AssociatePhoneNumbersWithVoiceConnectorGroup](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_AssociatePhoneNumbersWithVoiceConnectorGroup.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#associate_phone_numbers_with_voice_connector_group/4","title":"AWS.Chime.associate_phone_numbers_with_voice_connector_group/4","type":"function"},{"doc":"Associates the specified sign-in delegate groups with the specified Amazon Chime\naccount.","ref":"AWS.Chime.html#associate_signin_delegate_groups_with_account/4","title":"AWS.Chime.associate_signin_delegate_groups_with_account/4","type":"function"},{"doc":"Creates up to 100 new attendees for an active Amazon Chime SDK meeting.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[BatchCreateAttendee](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_meeting-chime_BatchCreateAttendee.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.\n\nFor more information about the Amazon Chime SDK, see [Using the Amazon Chime SDK](https://docs.aws.amazon.com/chime-sdk/latest/dg/meetings-sdk.html) in the\n*Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#batch_create_attendee/4","title":"AWS.Chime.batch_create_attendee/4","type":"function"},{"doc":"Adds a specified number of users to a channel.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[BatchCreateChannelMembership](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_BatchCreateChannelMembership.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#batch_create_channel_membership/4","title":"AWS.Chime.batch_create_channel_membership/4","type":"function"},{"doc":"Adds up to 50 members to a chat room in an Amazon Chime Enterprise account.\n\nMembers can be users or bots. The member role designates whether the member is a\nchat room administrator or a general chat room member.","ref":"AWS.Chime.html#batch_create_room_membership/5","title":"AWS.Chime.batch_create_room_membership/5","type":"function"},{"doc":"Moves phone numbers into the **Deletion queue**.\n\nPhone numbers must be disassociated from any users or Amazon Chime Voice\nConnectors before they can be deleted.\n\nPhone numbers remain in the **Deletion queue** for 7 days before they are\ndeleted permanently.","ref":"AWS.Chime.html#batch_delete_phone_number/3","title":"AWS.Chime.batch_delete_phone_number/3","type":"function"},{"doc":"Suspends up to 50 users from a `Team` or `EnterpriseLWA` Amazon Chime account.\n\nFor more information about different account types, see [Managing Your Amazon Chime\nAccounts](https://docs.aws.amazon.com/chime/latest/ag/manage-chime-account.html)\nin the *Amazon Chime Administration Guide*.\n\nUsers suspended from a `Team` account are disassociated from the account,but\nthey can continue to use Amazon Chime as free users. To remove the suspension\nfrom suspended `Team` account users, invite them to the `Team` account again.\nYou can use the `InviteUsers` action to do so.\n\nUsers suspended from an `EnterpriseLWA` account are immediately signed out of\nAmazon Chime and can no longer sign in. To remove the suspension from suspended\n`EnterpriseLWA` account users, use the `BatchUnsuspendUser` action.\n\nTo sign out users without suspending them, use the `LogoutUser` action.","ref":"AWS.Chime.html#batch_suspend_user/4","title":"AWS.Chime.batch_suspend_user/4","type":"function"},{"doc":"Removes the suspension from up to 50 previously suspended users for the\nspecified Amazon Chime `EnterpriseLWA` account.\n\nOnly users on `EnterpriseLWA` accounts can be unsuspended using this action. For\nmore information about different account types, see [ Managing Your Amazon Chime Accounts\n](https://docs.aws.amazon.com/chime/latest/ag/manage-chime-account.html) in the\naccount types, in the *Amazon Chime Administration Guide*.\n\nPreviously suspended users who are unsuspended using this action are returned to\n`Registered` status. Users who are not previously suspended are ignored.","ref":"AWS.Chime.html#batch_unsuspend_user/4","title":"AWS.Chime.batch_unsuspend_user/4","type":"function"},{"doc":"Updates phone number product types or calling names.\n\nYou can update one attribute at a time for each `UpdatePhoneNumberRequestItem`.\nFor example, you can update the product type or the calling name.\n\nFor toll-free numbers, you cannot use the Amazon Chime Business Calling product\ntype. For numbers outside the U.S., you must use the Amazon Chime SIP Media\nApplication Dial-In product type.\n\nUpdates to outbound calling names can take up to 72 hours to complete. Pending\nupdates to outbound calling names must be complete before you can request\nanother update.","ref":"AWS.Chime.html#batch_update_phone_number/3","title":"AWS.Chime.batch_update_phone_number/3","type":"function"},{"doc":"Updates user details within the `UpdateUserRequestItem` object for up to 20\nusers for the specified Amazon Chime account.\n\nCurrently, only `LicenseType` updates are supported for this action.","ref":"AWS.Chime.html#batch_update_user/4","title":"AWS.Chime.batch_update_user/4","type":"function"},{"doc":"Creates an Amazon Chime account under the administrator's AWS account.\n\nOnly `Team` account types are currently supported for this action. For more\ninformation about different account types, see [Managing Your Amazon Chime Accounts](https://docs.aws.amazon.com/chime/latest/ag/manage-chime-account.html)\nin the *Amazon Chime Administration Guide*.","ref":"AWS.Chime.html#create_account/3","title":"AWS.Chime.create_account/3","type":"function"},{"doc":"Creates an Amazon Chime SDK messaging `AppInstance` under an AWS account.\n\nOnly SDK messaging customers use this API. `CreateAppInstance` supports\nidempotency behavior as described in the AWS API Standard.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[CreateAppInstance](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_identity-chime_CreateAppInstance.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#create_app_instance/3","title":"AWS.Chime.create_app_instance/3","type":"function"},{"doc":"Promotes an `AppInstanceUser` to an `AppInstanceAdmin`.\n\nThe promoted user can perform the following actions.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[CreateAppInstanceAdmin](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_identity-chime_CreateAppInstanceAdmin.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.\n\n  * `ChannelModerator` actions across all channels in the\n`AppInstance`.\n\n  * `DeleteChannelMessage` actions.\n\nOnly an `AppInstanceUser` can be promoted to an `AppInstanceAdmin` role.","ref":"AWS.Chime.html#create_app_instance_admin/4","title":"AWS.Chime.create_app_instance_admin/4","type":"function"},{"doc":"Creates a user under an Amazon Chime `AppInstance`.\n\nThe request consists of a unique `appInstanceUserId` and `Name` for that user.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[CreateAppInstanceUser](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_identity-chime_CreateAppInstanceUser.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#create_app_instance_user/3","title":"AWS.Chime.create_app_instance_user/3","type":"function"},{"doc":"Creates a new attendee for an active Amazon Chime SDK meeting.\n\nFor more information about the Amazon Chime SDK, see [Using the Amazon Chime SDK](https://docs.aws.amazon.com/chime-sdk/latest/dg/meetings-sdk.html) in the\n*Amazon Chime SDK Developer Guide*.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[CreateAttendee](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_meeting-chime_CreateAttendee.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#create_attendee/4","title":"AWS.Chime.create_attendee/4","type":"function"},{"doc":"Creates a bot for an Amazon Chime Enterprise account.","ref":"AWS.Chime.html#create_bot/4","title":"AWS.Chime.create_bot/4","type":"function"},{"doc":"Creates a channel to which you can add users and send messages.\n\n**Restriction**: You can't change a channel's privacy.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the\n`AppInstanceUserArn` of the user that makes the API call as the value in the\nheader.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[CreateChannel](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_CreateChannel.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#create_channel/3","title":"AWS.Chime.create_channel/3","type":"function"},{"doc":"Permanently bans a member from a channel.\n\nModerators can't add banned members to a channel. To undo a ban, you first have\nto `DeleteChannelBan`, and then `CreateChannelMembership`. Bans are cleaned up\nwhen you delete users or channels.\n\nIf you ban a user who is already part of a channel, that user is automatically\nkicked from the channel.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the\n`AppInstanceUserArn` of the user that makes the API call as the value in the\nheader.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[CreateChannelBan](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_CreateChannelBan.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#create_channel_ban/4","title":"AWS.Chime.create_channel_ban/4","type":"function"},{"doc":"Adds a user to a channel.\n\nThe `InvitedBy` response field is derived from the request header. A channel\nmember can:\n\n  * List messages\n\n  * Send messages\n\n  * Receive messages\n\n  * Edit their own messages\n\n  * Leave the channel\n\nPrivacy settings impact this action as follows:\n\n  * Public Channels: You do not need to be a member to list messages,\nbut you must be a member to send messages.\n\n  * Private Channels: You must be a member to list or send messages.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the\n`AppInstanceUserArn` of the user that makes the API call as the value in the\nheader.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[CreateChannelMembership](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_CreateChannelMembership.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#create_channel_membership/4","title":"AWS.Chime.create_channel_membership/4","type":"function"},{"doc":"Creates a new `ChannelModerator`.\n\nA channel moderator can:\n\n  * Add and remove other members of the channel.\n\n  * Add and remove other moderators of the channel.\n\n  * Add and remove user bans for the channel.\n\n  * Redact messages in the channel.\n\n  * List messages in the channel.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the\n`AppInstanceUserArn` of the user that makes the API call as the value in the\nheader.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[CreateChannelModerator](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_CreateChannelModerator.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#create_channel_moderator/4","title":"AWS.Chime.create_channel_moderator/4","type":"function"},{"doc":"Creates a media capture pipeline.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[CreateMediaCapturePipeline](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_media-pipelines-chime_CreateMediaCapturePipeline), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#create_media_capture_pipeline/3","title":"AWS.Chime.create_media_capture_pipeline/3","type":"function"},{"doc":"Creates a new Amazon Chime SDK meeting in the specified media Region with no\ninitial attendees.\n\nFor more information about specifying media Regions, see [Amazon Chime SDK Media Regions](https://docs.aws.amazon.com/chime-sdk/latest/dg/chime-sdk-meetings-regions.html)\nin the *Amazon Chime SDK Developer Guide* . For more information about the\nAmazon Chime SDK, see [Using the Amazon Chime SDK](https://docs.aws.amazon.com/chime-sdk/latest/dg/meetings-sdk.html) in the\n*Amazon Chime SDK Developer Guide*.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[CreateMeeting](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_meeting-chime_CreateMeeting.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#create_meeting/3","title":"AWS.Chime.create_meeting/3","type":"function"},{"doc":"Uses the join token and call metadata in a meeting request (From number, To\nnumber, and so forth) to initiate an outbound call to a public switched\ntelephone network (PSTN) and join them into a Chime meeting.\n\nAlso ensures that the From number belongs to the customer.\n\nTo play welcome audio or implement an interactive voice response (IVR), use the\n`CreateSipMediaApplicationCall` action with the corresponding SIP media\napplication ID.","ref":"AWS.Chime.html#create_meeting_dial_out/4","title":"AWS.Chime.create_meeting_dial_out/4","type":"function"},{"doc":"","ref":"AWS.Chime.html#create_meeting_dial_out/4-this-api-is-is-not-available-in-a-dedicated-namespace","title":"This API is is not available in a dedicated namespace. - AWS.Chime.create_meeting_dial_out/4","type":"function"},{"doc":"Creates a new Amazon Chime SDK meeting in the specified media Region, with\nattendees.\n\nFor more information about specifying media Regions, see [Amazon Chime SDK Media Regions](https://docs.aws.amazon.com/chime-sdk/latest/dg/chime-sdk-meetings-regions.html)\nin the *Amazon Chime SDK Developer Guide* . For more information about the\nAmazon Chime SDK, see [Using the Amazon Chime SDK](https://docs.aws.amazon.com/chime-sdk/latest/dg/meetings-sdk.html) in the\n*Amazon Chime SDK Developer Guide* .\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[CreateMeetingWithAttendees](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_meeting-chime_CreateMeetingWithAttendees.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#create_meeting_with_attendees/3","title":"AWS.Chime.create_meeting_with_attendees/3","type":"function"},{"doc":"Creates an order for phone numbers to be provisioned.\n\nFor toll-free numbers, you cannot use the Amazon Chime Business Calling product\ntype. For numbers outside the U.S., you must use the Amazon Chime SIP Media\nApplication Dial-In product type.","ref":"AWS.Chime.html#create_phone_number_order/3","title":"AWS.Chime.create_phone_number_order/3","type":"function"},{"doc":"Creates a proxy session on the specified Amazon Chime Voice Connector for the\nspecified participant phone numbers.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[CreateProxySession](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_CreateProxySession.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#create_proxy_session/4","title":"AWS.Chime.create_proxy_session/4","type":"function"},{"doc":"Creates a chat room for the specified Amazon Chime Enterprise account.","ref":"AWS.Chime.html#create_room/4","title":"AWS.Chime.create_room/4","type":"function"},{"doc":"Adds a member to a chat room in an Amazon Chime Enterprise account.\n\nA member can be either a user or a bot. The member role designates whether the\nmember is a chat room administrator or a general chat room member.","ref":"AWS.Chime.html#create_room_membership/5","title":"AWS.Chime.create_room_membership/5","type":"function"},{"doc":"Creates a SIP media application.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[CreateSipMediaApplication](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_CreateSipMediaApplication.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#create_sip_media_application/3","title":"AWS.Chime.create_sip_media_application/3","type":"function"},{"doc":"Creates an outbound call to a phone number from the phone number specified in\nthe request, and it invokes the endpoint of the specified\n`sipMediaApplicationId`.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[CreateSipMediaApplicationCall](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_CreateSipMediaApplicationCall.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#create_sip_media_application_call/4","title":"AWS.Chime.create_sip_media_application_call/4","type":"function"},{"doc":"Creates a SIP rule which can be used to run a SIP media application as a target\nfor a specific trigger type.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[CreateSipRule](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_CreateSipRule.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#create_sip_rule/3","title":"AWS.Chime.create_sip_rule/3","type":"function"},{"doc":"Creates a user under the specified Amazon Chime account.","ref":"AWS.Chime.html#create_user/4","title":"AWS.Chime.create_user/4","type":"function"},{"doc":"Creates an Amazon Chime Voice Connector under the administrator's AWS account.\n\nYou can choose to create an Amazon Chime Voice Connector in a specific AWS\nRegion.\n\nEnabling `CreateVoiceConnectorRequest$RequireEncryption` configures your Amazon\nChime Voice Connector to use TLS transport for SIP signaling and Secure RTP\n(SRTP) for media. Inbound calls use TLS transport, and unencrypted outbound\ncalls are blocked.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[CreateVoiceConnector](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_CreateVoiceConnector.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#create_voice_connector/3","title":"AWS.Chime.create_voice_connector/3","type":"function"},{"doc":"Creates an Amazon Chime Voice Connector group under the administrator's AWS\naccount.\n\nYou can associate Amazon Chime Voice Connectors with the Amazon Chime Voice\nConnector group by including `VoiceConnectorItems` in the request.\n\nYou can include Amazon Chime Voice Connectors from different AWS Regions in your\ngroup. This creates a fault tolerant mechanism for fallback in case of\navailability events.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[CreateVoiceConnectorGroup](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_CreateVoiceConnectorGroup.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#create_voice_connector_group/3","title":"AWS.Chime.create_voice_connector_group/3","type":"function"},{"doc":"Deletes the specified Amazon Chime account.\n\nYou must suspend all users before deleting `Team` account. You can use the\n`BatchSuspendUser` action to dodo.\n\nFor `EnterpriseLWA` and `EnterpriseAD` accounts, you must release the claimed\ndomains for your Amazon Chime account before deletion. As soon as you release\nthe domain, all users under that account are suspended.\n\nDeleted accounts appear in your `Disabled` accounts list for 90 days. To restore\ndeleted account from your `Disabled` accounts list, you must contact AWS\nSupport.\n\nAfter 90 days, deleted accounts are permanently removed from your `Disabled`\naccounts list.","ref":"AWS.Chime.html#delete_account/4","title":"AWS.Chime.delete_account/4","type":"function"},{"doc":"Deletes an `AppInstance` and all associated data asynchronously.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[DeleteAppInstance](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_identity-chime_DeleteAppInstance.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#delete_app_instance/4","title":"AWS.Chime.delete_app_instance/4","type":"function"},{"doc":"Demotes an `AppInstanceAdmin` to an `AppInstanceUser`.\n\nThis action does not delete the user.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[DeleteAppInstanceAdmin](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_identity-chime_DeleteAppInstanceAdmin.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#delete_app_instance_admin/5","title":"AWS.Chime.delete_app_instance_admin/5","type":"function"},{"doc":"Deletes the streaming configurations of an `AppInstance`.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[DeleteAppInstanceStreamingConfigurations](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_identity-chime_DeleteAppInstanceStreamingConfigurations.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#delete_app_instance_streaming_configurations/4","title":"AWS.Chime.delete_app_instance_streaming_configurations/4","type":"function"},{"doc":"Deletes an `AppInstanceUser`.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[DeleteAppInstanceUser](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_identity-chime_DeleteAppInstanceUser.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#delete_app_instance_user/4","title":"AWS.Chime.delete_app_instance_user/4","type":"function"},{"doc":"Deletes an attendee from the specified Amazon Chime SDK meeting and deletes\ntheir `JoinToken`.\n\nAttendees are automatically deleted when a Amazon Chime SDK meeting is deleted.\nFor more information about the Amazon Chime SDK, see [Using the Amazon Chime SDK](https://docs.aws.amazon.com/chime-sdk/latest/dg/meetings-sdk.html) in the\n*Amazon Chime SDK Developer Guide*.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[DeleteAttendee](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_meeting-chime_DeleteAttendee.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#delete_attendee/5","title":"AWS.Chime.delete_attendee/5","type":"function"},{"doc":"Immediately makes a channel and its memberships inaccessible and marks them for\ndeletion.\n\nThis is an irreversible process.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the\n`AppInstanceUserArn` of the user that makes the API call as the value in the\nheader.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[DeleteChannel](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_DeleteChannel.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#delete_channel/4","title":"AWS.Chime.delete_channel/4","type":"function"},{"doc":"Removes a user from a channel's ban list.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the\n`AppInstanceUserArn` of the user that makes the API call as the value in the\nheader.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[DeleteChannelBan](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_DeleteChannelBan.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#delete_channel_ban/5","title":"AWS.Chime.delete_channel_ban/5","type":"function"},{"doc":"Removes a member from a channel.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the\n`AppInstanceUserArn` of the user that makes the API call as the value in the\nheader.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[DeleteChannelMembership](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_DeleteChannelMembership.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#delete_channel_membership/5","title":"AWS.Chime.delete_channel_membership/5","type":"function"},{"doc":"Deletes a channel message.\n\nOnly admins can perform this action. Deletion makes messages inaccessible\nimmediately. A background process deletes any revisions created by\n`UpdateChannelMessage`.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the\n`AppInstanceUserArn` of the user that makes the API call as the value in the\nheader.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[DeleteChannelMessage](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_DeleteChannelMessage.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#delete_channel_message/5","title":"AWS.Chime.delete_channel_message/5","type":"function"},{"doc":"Deletes a channel moderator.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the\n`AppInstanceUserArn` of the user that makes the API call as the value in the\nheader.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[DeleteChannelModerator](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_DeleteChannelModerator.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#delete_channel_moderator/5","title":"AWS.Chime.delete_channel_moderator/5","type":"function"},{"doc":"Deletes the events configuration that allows a bot to receive outgoing events.","ref":"AWS.Chime.html#delete_events_configuration/5","title":"AWS.Chime.delete_events_configuration/5","type":"function"},{"doc":"Deletes the media capture pipeline.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[DeleteMediaCapturePipeline](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_media-pipelines-chime_DeleteMediaCapturePipeline.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#delete_media_capture_pipeline/4","title":"AWS.Chime.delete_media_capture_pipeline/4","type":"function"},{"doc":"Deletes the specified Amazon Chime SDK meeting.\n\nThe operation deletes all attendees, disconnects all clients, and prevents new\nclients from joining the meeting. For more information about the Amazon Chime\nSDK, see [Using the Amazon Chime SDK](https://docs.aws.amazon.com/chime-sdk/latest/dg/meetings-sdk.html) in the\n*Amazon Chime SDK Developer Guide*.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[DeleteMeeting](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_meeting-chime_DeleteMeeting.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#delete_meeting/4","title":"AWS.Chime.delete_meeting/4","type":"function"},{"doc":"Moves the specified phone number into the **Deletion queue**.\n\nA phone number must be disassociated from any users or Amazon Chime Voice\nConnectors before it can be deleted.\n\nDeleted phone numbers remain in the **Deletion queue** for 7 days before they\nare deleted permanently.","ref":"AWS.Chime.html#delete_phone_number/4","title":"AWS.Chime.delete_phone_number/4","type":"function"},{"doc":"Deletes the specified proxy session from the specified Amazon Chime Voice\nConnector.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[DeleteProxySession](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_DeleteProxySession.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#delete_proxy_session/5","title":"AWS.Chime.delete_proxy_session/5","type":"function"},{"doc":"Deletes a chat room in an Amazon Chime Enterprise account.","ref":"AWS.Chime.html#delete_room/5","title":"AWS.Chime.delete_room/5","type":"function"},{"doc":"Removes a member from a chat room in an Amazon Chime Enterprise account.","ref":"AWS.Chime.html#delete_room_membership/6","title":"AWS.Chime.delete_room_membership/6","type":"function"},{"doc":"Deletes a SIP media application.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[DeleteSipMediaApplication](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_DeleteSipMediaApplication.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#delete_sip_media_application/4","title":"AWS.Chime.delete_sip_media_application/4","type":"function"},{"doc":"Deletes a SIP rule.\n\nYou must disable a SIP rule before you can delete it.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[DeleteSipRule](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_DeleteSipRule.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#delete_sip_rule/4","title":"AWS.Chime.delete_sip_rule/4","type":"function"},{"doc":"Deletes the specified Amazon Chime Voice Connector.\n\nAny phone numbers associated with the Amazon Chime Voice Connector must be\ndisassociated from it before it can be deleted.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[DeleteVoiceConnector](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_DeleteVoiceConnector.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#delete_voice_connector/4","title":"AWS.Chime.delete_voice_connector/4","type":"function"},{"doc":"Deletes the emergency calling configuration details from the specified Amazon\nChime Voice Connector.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[DeleteVoiceConnectorEmergencyCallingConfiguration](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_DeleteVoiceConnectorEmergencyCallingConfiguration.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#delete_voice_connector_emergency_calling_configuration/4","title":"AWS.Chime.delete_voice_connector_emergency_calling_configuration/4","type":"function"},{"doc":"Deletes the specified Amazon Chime Voice Connector group.\n\nAny `VoiceConnectorItems` and phone numbers associated with the group must be\nremoved before it can be deleted.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[DeleteVoiceConnectorGroup](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_DeleteVoiceConnectorGroup.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#delete_voice_connector_group/4","title":"AWS.Chime.delete_voice_connector_group/4","type":"function"},{"doc":"Deletes the origination settings for the specified Amazon Chime Voice Connector.\n\nIf emergency calling is configured for the Amazon Chime Voice Connector, it must\nbe deleted prior to deleting the origination settings.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[DeleteVoiceConnectorOrigination](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_DeleteVoiceConnectorOrigination.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#delete_voice_connector_origination/4","title":"AWS.Chime.delete_voice_connector_origination/4","type":"function"},{"doc":"Deletes the proxy configuration from the specified Amazon Chime Voice Connector.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[DeleteVoiceProxy](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_DeleteVoiceConnectorProxy.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#delete_voice_connector_proxy/4","title":"AWS.Chime.delete_voice_connector_proxy/4","type":"function"},{"doc":"Deletes the streaming configuration for the specified Amazon Chime Voice\nConnector.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[DeleteVoiceConnectorStreamingConfiguration](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_DeleteVoiceConnectorStreamingConfiguration.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#delete_voice_connector_streaming_configuration/4","title":"AWS.Chime.delete_voice_connector_streaming_configuration/4","type":"function"},{"doc":"Deletes the termination settings for the specified Amazon Chime Voice Connector.\n\nIf emergency calling is configured for the Amazon Chime Voice Connector, it must\nbe deleted prior to deleting the termination settings.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[DeleteVoiceConnectorTermination](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_DeleteVoiceConnectorTermination.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#delete_voice_connector_termination/4","title":"AWS.Chime.delete_voice_connector_termination/4","type":"function"},{"doc":"Deletes the specified SIP credentials used by your equipment to authenticate\nduring call termination.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[DeleteVoiceConnectorTerminationCredentials](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_DeleteVoiceConnectorTerminationCredentials.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#delete_voice_connector_termination_credentials/4","title":"AWS.Chime.delete_voice_connector_termination_credentials/4","type":"function"},{"doc":"Returns the full details of an `AppInstance`.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[DescribeAppInstance](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_identity-chime_DescribeAppInstance.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#describe_app_instance/3","title":"AWS.Chime.describe_app_instance/3","type":"function"},{"doc":"Returns the full details of an `AppInstanceAdmin`.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[DescribeAppInstanceAdmin](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_identity-chime_DescribeAppInstanceAdmin.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#describe_app_instance_admin/4","title":"AWS.Chime.describe_app_instance_admin/4","type":"function"},{"doc":"Returns the full details of an `AppInstanceUser`.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[DescribeAppInstanceUser](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_identity-chime_DescribeAppInstanceUser.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#describe_app_instance_user/3","title":"AWS.Chime.describe_app_instance_user/3","type":"function"},{"doc":"Returns the full details of a channel in an Amazon Chime `AppInstance`.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the\n`AppInstanceUserArn` of the user that makes the API call as the value in the\nheader.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[DescribeChannel](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_DescribeChannel.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#describe_channel/4","title":"AWS.Chime.describe_channel/4","type":"function"},{"doc":"Returns the full details of a channel ban.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the\n`AppInstanceUserArn` of the user that makes the API call as the value in the\nheader.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[DescribeChannelBan](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_DescribeChannelBan.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#describe_channel_ban/5","title":"AWS.Chime.describe_channel_ban/5","type":"function"},{"doc":"Returns the full details of a user's channel membership.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the\n`AppInstanceUserArn` of the user that makes the API call as the value in the\nheader.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[DescribeChannelMembership](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_DescribeChannelMembership.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#describe_channel_membership/5","title":"AWS.Chime.describe_channel_membership/5","type":"function"},{"doc":"Returns the details of a channel based on the membership of the specified\n`AppInstanceUser`.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the\n`AppInstanceUserArn` of the user that makes the API call as the value in the\nheader.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[DescribeChannelMembershipForAppInstanceUser](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_DescribeChannelMembershipForAppInstanceUser.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#describe_channel_membership_for_app_instance_user/5","title":"AWS.Chime.describe_channel_membership_for_app_instance_user/5","type":"function"},{"doc":"Returns the full details of a channel moderated by the specified\n`AppInstanceUser`.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the\n`AppInstanceUserArn` of the user that makes the API call as the value in the\nheader.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[DescribeChannelModeratedByAppInstanceUser](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_DescribeChannelModeratedByAppInstanceUser.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#describe_channel_moderated_by_app_instance_user/5","title":"AWS.Chime.describe_channel_moderated_by_app_instance_user/5","type":"function"},{"doc":"Returns the full details of a single ChannelModerator.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the\n`AppInstanceUserArn` of the user that makes the API call as the value in the\nheader.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[DescribeChannelModerator](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_DescribeChannelModerator.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#describe_channel_moderator/5","title":"AWS.Chime.describe_channel_moderator/5","type":"function"},{"doc":"Disassociates the primary provisioned phone number from the specified Amazon\nChime user.","ref":"AWS.Chime.html#disassociate_phone_number_from_user/5","title":"AWS.Chime.disassociate_phone_number_from_user/5","type":"function"},{"doc":"Disassociates the specified phone numbers from the specified Amazon Chime Voice\nConnector.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[DisassociatePhoneNumbersFromVoiceConnector](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_DisassociatePhoneNumbersFromVoiceConnector.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#disassociate_phone_numbers_from_voice_connector/4","title":"AWS.Chime.disassociate_phone_numbers_from_voice_connector/4","type":"function"},{"doc":"Disassociates the specified phone numbers from the specified Amazon Chime Voice\nConnector group.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[DisassociatePhoneNumbersFromVoiceConnectorGroup](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_DisassociatePhoneNumbersFromVoiceConnectorGroup.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#disassociate_phone_numbers_from_voice_connector_group/4","title":"AWS.Chime.disassociate_phone_numbers_from_voice_connector_group/4","type":"function"},{"doc":"Disassociates the specified sign-in delegate groups from the specified Amazon\nChime account.","ref":"AWS.Chime.html#disassociate_signin_delegate_groups_from_account/4","title":"AWS.Chime.disassociate_signin_delegate_groups_from_account/4","type":"function"},{"doc":"Retrieves details for the specified Amazon Chime account, such as account type\nand supported licenses.","ref":"AWS.Chime.html#get_account/3","title":"AWS.Chime.get_account/3","type":"function"},{"doc":"Retrieves account settings for the specified Amazon Chime account ID, such as\nremote control and dialout settings.\n\nFor more information about these settings, see [Use the Policies Page](https://docs.aws.amazon.com/chime/latest/ag/policies.html) in the *Amazon\nChime Administration Guide*.","ref":"AWS.Chime.html#get_account_settings/3","title":"AWS.Chime.get_account_settings/3","type":"function"},{"doc":"Gets the retention settings for an `AppInstance`.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[GetMessagingRetentionSettings](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_identity-chime_GetAppInstanceRetentionSettings.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#get_app_instance_retention_settings/3","title":"AWS.Chime.get_app_instance_retention_settings/3","type":"function"},{"doc":"Gets the streaming settings for an `AppInstance`.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[GetMessagingStreamingConfigurations](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_GetMessagingStreamingConfigurations.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#get_app_instance_streaming_configurations/3","title":"AWS.Chime.get_app_instance_streaming_configurations/3","type":"function"},{"doc":"Gets the Amazon Chime SDK attendee details for a specified meeting ID and\nattendee ID.\n\nFor more information about the Amazon Chime SDK, see [Using the Amazon Chime SDK](https://docs.aws.amazon.com/chime-sdk/latest/dg/meetings-sdk.html) in the\n*Amazon Chime SDK Developer Guide*.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[GetAttendee](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_meeting-chime_GetAttendee.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#get_attendee/4","title":"AWS.Chime.get_attendee/4","type":"function"},{"doc":"Retrieves details for the specified bot, such as bot email address, bot type,\nstatus, and display name.","ref":"AWS.Chime.html#get_bot/4","title":"AWS.Chime.get_bot/4","type":"function"},{"doc":"Gets the full details of a channel message.\n\nThe x-amz-chime-bearer request header is mandatory. Use the `AppInstanceUserArn`\nof the user that makes the API call as the value in the header.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[GetChannelMessage](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_GetChannelMessage.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#get_channel_message/5","title":"AWS.Chime.get_channel_message/5","type":"function"},{"doc":"Gets details for an events configuration that allows a bot to receive outgoing\nevents, such as an HTTPS endpoint or Lambda function ARN.","ref":"AWS.Chime.html#get_events_configuration/4","title":"AWS.Chime.get_events_configuration/4","type":"function"},{"doc":"Retrieves global settings for the administrator's AWS account, such as Amazon\nChime Business Calling and Amazon Chime Voice Connector settings.","ref":"AWS.Chime.html#get_global_settings/2","title":"AWS.Chime.get_global_settings/2","type":"function"},{"doc":"Gets an existing media capture pipeline.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[GetMediaCapturePipeline](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_media-pipelines-chime_GetMediaCapturePipeline.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#get_media_capture_pipeline/3","title":"AWS.Chime.get_media_capture_pipeline/3","type":"function"},{"doc":"**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[GetMeeting](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_meeting-chime_GetMeeting.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.\n\nGets the Amazon Chime SDK meeting details for the specified meeting ID. For more\ninformation about the Amazon Chime SDK, see [Using the Amazon Chime SDK](https://docs.aws.amazon.com/chime-sdk/latest/dg/meetings-sdk.html) in the\n*Amazon Chime SDK Developer Guide* .","ref":"AWS.Chime.html#get_meeting/3","title":"AWS.Chime.get_meeting/3","type":"function"},{"doc":"The details of the endpoint for the messaging session.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[GetMessagingSessionEndpoint](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_GetMessagingSessionEndpoint.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#get_messaging_session_endpoint/2","title":"AWS.Chime.get_messaging_session_endpoint/2","type":"function"},{"doc":"Retrieves details for the specified phone number ID, such as associations,\ncapabilities, and product type.","ref":"AWS.Chime.html#get_phone_number/3","title":"AWS.Chime.get_phone_number/3","type":"function"},{"doc":"Retrieves details for the specified phone number order, such as the order\ncreation timestamp, phone numbers in E.164 format, product type, and order\nstatus.","ref":"AWS.Chime.html#get_phone_number_order/3","title":"AWS.Chime.get_phone_number_order/3","type":"function"},{"doc":"Retrieves the phone number settings for the administrator's AWS account, such as\nthe default outbound calling name.","ref":"AWS.Chime.html#get_phone_number_settings/2","title":"AWS.Chime.get_phone_number_settings/2","type":"function"},{"doc":"Gets the specified proxy session details for the specified Amazon Chime Voice\nConnector.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[GetProxySession](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_GetProxySession.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#get_proxy_session/4","title":"AWS.Chime.get_proxy_session/4","type":"function"},{"doc":"Gets the retention settings for the specified Amazon Chime Enterprise account.\n\nFor more information about retention settings, see [Managing Chat Retention Policies](https://docs.aws.amazon.com/chime/latest/ag/chat-retention.html) in\nthe *Amazon Chime Administration Guide*.","ref":"AWS.Chime.html#get_retention_settings/3","title":"AWS.Chime.get_retention_settings/3","type":"function"},{"doc":"Retrieves room details, such as the room name, for a room in an Amazon Chime\nEnterprise account.","ref":"AWS.Chime.html#get_room/4","title":"AWS.Chime.get_room/4","type":"function"},{"doc":"Retrieves the information for a SIP media application, including name, AWS\nRegion, and endpoints.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[GetSipMediaApplication](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_GetSipMediaApplication.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#get_sip_media_application/3","title":"AWS.Chime.get_sip_media_application/3","type":"function"},{"doc":"Returns the logging configuration for the specified SIP media application.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[GetSipMediaApplicationLoggingConfiguration](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_GetSipMediaApplicationLoggingConfiguration.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#get_sip_media_application_logging_configuration/3","title":"AWS.Chime.get_sip_media_application_logging_configuration/3","type":"function"},{"doc":"Retrieves the details of a SIP rule, such as the rule ID, name, triggers, and\ntarget endpoints.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[GetSipRule](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_GetSipRule.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#get_sip_rule/3","title":"AWS.Chime.get_sip_rule/3","type":"function"},{"doc":"Retrieves details for the specified user ID, such as primary email address,\nlicense type,and personal meeting PIN.\n\nTo retrieve user details with an email address instead of a user ID, use the\n`ListUsers` action, and then filter by email address.","ref":"AWS.Chime.html#get_user/4","title":"AWS.Chime.get_user/4","type":"function"},{"doc":"Retrieves settings for the specified user ID, such as any associated phone\nnumber settings.","ref":"AWS.Chime.html#get_user_settings/4","title":"AWS.Chime.get_user_settings/4","type":"function"},{"doc":"Retrieves details for the specified Amazon Chime Voice Connector, such as\ntimestamps,name, outbound host, and encryption requirements.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[GetVoiceConnector](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_GetVoiceConnector.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#get_voice_connector/3","title":"AWS.Chime.get_voice_connector/3","type":"function"},{"doc":"Gets the emergency calling configuration details for the specified Amazon Chime\nVoice Connector.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[GetVoiceConnectorEmergencyCallingConfiguration](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_GetVoiceConnectorEmergencyCallingConfiguration.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#get_voice_connector_emergency_calling_configuration/3","title":"AWS.Chime.get_voice_connector_emergency_calling_configuration/3","type":"function"},{"doc":"Retrieves details for the specified Amazon Chime Voice Connector group, such as\ntimestamps,name, and associated `VoiceConnectorItems`.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[GetVoiceConnectorGroup](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_GetVoiceConnectorGroup.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#get_voice_connector_group/3","title":"AWS.Chime.get_voice_connector_group/3","type":"function"},{"doc":"Retrieves the logging configuration details for the specified Amazon Chime Voice\nConnector.\n\nShows whether SIP message logs are enabled for sending to Amazon CloudWatch\nLogs.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[GetVoiceConnectorLoggingConfiguration](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_GetVoiceConnectorLoggingConfiguration.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#get_voice_connector_logging_configuration/3","title":"AWS.Chime.get_voice_connector_logging_configuration/3","type":"function"},{"doc":"Retrieves origination setting details for the specified Amazon Chime Voice\nConnector.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[GetVoiceConnectorOrigination](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_GetVoiceConnectorOrigination.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#get_voice_connector_origination/3","title":"AWS.Chime.get_voice_connector_origination/3","type":"function"},{"doc":"Gets the proxy configuration details for the specified Amazon Chime Voice\nConnector.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[GetVoiceConnectorProxy](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_GetVoiceConnectorProxy.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#get_voice_connector_proxy/3","title":"AWS.Chime.get_voice_connector_proxy/3","type":"function"},{"doc":"Retrieves the streaming configuration details for the specified Amazon Chime\nVoice Connector.\n\nShows whether media streaming is enabled for sending to Amazon Kinesis. It also\nshows the retention period, in hours, for the Amazon Kinesis data.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[GetVoiceConnectorStreamingConfiguration](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_GetVoiceConnectorStreamingConfiguration.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#get_voice_connector_streaming_configuration/3","title":"AWS.Chime.get_voice_connector_streaming_configuration/3","type":"function"},{"doc":"Retrieves termination setting details for the specified Amazon Chime Voice\nConnector.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[GetVoiceConnectorTermination](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_GetVoiceConnectorTermination.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#get_voice_connector_termination/3","title":"AWS.Chime.get_voice_connector_termination/3","type":"function"},{"doc":"**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[GetVoiceConnectorTerminationHealth](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_GetVoiceConnectorTerminationHealth.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.\n\nRetrieves information about the last time a SIP `OPTIONS` ping was received from\nyour SIP infrastructure for the specified Amazon Chime Voice Connector.","ref":"AWS.Chime.html#get_voice_connector_termination_health/3","title":"AWS.Chime.get_voice_connector_termination_health/3","type":"function"},{"doc":"Sends email to a maximum of 50 users, inviting them to the specified Amazon\nChime `Team` account.\n\nOnly `Team` account types are currently supported for this action.","ref":"AWS.Chime.html#invite_users/4","title":"AWS.Chime.invite_users/4","type":"function"},{"doc":"Lists the Amazon Chime accounts under the administrator's AWS account.\n\nYou can filter accounts by account name prefix. To find out which Amazon Chime\naccount a user belongs to, you can filter by the user's email address, which\nreturns one account result.","ref":"AWS.Chime.html#list_accounts/6","title":"AWS.Chime.list_accounts/6","type":"function"},{"doc":"Returns a list of the administrators in the `AppInstance`.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[ListAppInstanceAdmins](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_identity-chime_ListAppInstanceAdmins.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#list_app_instance_admins/5","title":"AWS.Chime.list_app_instance_admins/5","type":"function"},{"doc":"List all `AppInstanceUsers` created under a single `AppInstance`.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[ListAppInstanceUsers](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_identity-chime_ListAppInstanceUsers.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#list_app_instance_users/5","title":"AWS.Chime.list_app_instance_users/5","type":"function"},{"doc":"Lists all Amazon Chime `AppInstance`s created under a single AWS account.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[ListAppInstances](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_identity-chime_ListAppInstances.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#list_app_instances/4","title":"AWS.Chime.list_app_instances/4","type":"function"},{"doc":"Lists the tags applied to an Amazon Chime SDK attendee resource.\n\nListAttendeeTags is not supported in the Amazon Chime SDK Meetings Namespace.\nUpdate your application to remove calls to this API.","ref":"AWS.Chime.html#list_attendee_tags/4","title":"AWS.Chime.list_attendee_tags/4","type":"function"},{"doc":"Lists the attendees for the specified Amazon Chime SDK meeting.\n\nFor more information about the Amazon Chime SDK, see [Using the Amazon Chime SDK](https://docs.aws.amazon.com/chime-sdk/latest/dg/meetings-sdk.html) in the\n*Amazon Chime SDK Developer Guide*.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[ListAttendees](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_meeting-chime_ListAttendees.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#list_attendees/5","title":"AWS.Chime.list_attendees/5","type":"function"},{"doc":"Lists the bots associated with the administrator's Amazon Chime Enterprise\naccount ID.","ref":"AWS.Chime.html#list_bots/5","title":"AWS.Chime.list_bots/5","type":"function"},{"doc":"Lists all the users banned from a particular channel.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the\n`AppInstanceUserArn` of the user that makes the API call as the value in the\nheader.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[ListChannelBans](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_ListChannelBans.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#list_channel_bans/6","title":"AWS.Chime.list_channel_bans/6","type":"function"},{"doc":"Lists all channel memberships in a channel.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the\n`AppInstanceUserArn` of the user that makes the API call as the value in the\nheader.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[ListChannelMemberships](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_ListChannelMemberships.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#list_channel_memberships/7","title":"AWS.Chime.list_channel_memberships/7","type":"function"},{"doc":"Lists all channels that a particular `AppInstanceUser` is a part of.\n\nOnly an `AppInstanceAdmin` can call the API with a user ARN that is not their\nown.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the\n`AppInstanceUserArn` of the user that makes the API call as the value in the\nheader.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[ListChannelMembershipsForAppInstanceUser](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_ListChannelMembershipsForAppInstanceUser.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#list_channel_memberships_for_app_instance_user/6","title":"AWS.Chime.list_channel_memberships_for_app_instance_user/6","type":"function"},{"doc":"List all the messages in a channel.\n\nReturns a paginated list of `ChannelMessages`. By default, sorted by creation\ntimestamp in descending order.\n\nRedacted messages appear in the results as empty, since they are only redacted,\nnot deleted. Deleted messages do not appear in the results. This action always\nreturns the latest version of an edited message.\n\nAlso, the x-amz-chime-bearer request header is mandatory. Use the\n`AppInstanceUserArn` of the user that makes the API call as the value in the\nheader.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[ListChannelMessages](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_ListChannelMessages.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#list_channel_messages/9","title":"AWS.Chime.list_channel_messages/9","type":"function"},{"doc":"Lists all the moderators for a channel.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the\n`AppInstanceUserArn` of the user that makes the API call as the value in the\nheader.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[ListChannelModerators](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_ListChannelModerators.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#list_channel_moderators/6","title":"AWS.Chime.list_channel_moderators/6","type":"function"},{"doc":"Lists all Channels created under a single Chime App as a paginated list.\n\nYou can specify filters to narrow results.","ref":"AWS.Chime.html#list_channels/7","title":"AWS.Chime.list_channels/7","type":"function"},{"doc":"* Use privacy = `PUBLIC` to retrieve all public channels in the\naccount.\n\n  * Only an `AppInstanceAdmin` can set privacy = `PRIVATE` to list the\nprivate channels in an account.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the\n`AppInstanceUserArn` of the user that makes the API call as the value in the\nheader.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[ListChannels](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_ListChannels.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#list_channels/7-functionality-restrictions","title":"Functionality & restrictions - AWS.Chime.list_channels/7","type":"function"},{"doc":"A list of the channels moderated by an `AppInstanceUser`.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the\n`AppInstanceUserArn` of the user that makes the API call as the value in the\nheader.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[ListChannelsModeratedByAppInstanceUser](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_ListChannelsModeratedByAppInstanceUser.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#list_channels_moderated_by_app_instance_user/6","title":"AWS.Chime.list_channels_moderated_by_app_instance_user/6","type":"function"},{"doc":"Returns a list of media capture pipelines.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[ListMediaCapturePipelines](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_media-pipelines-chime_ListMediaCapturePipelines.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#list_media_capture_pipelines/4","title":"AWS.Chime.list_media_capture_pipelines/4","type":"function"},{"doc":"Lists the tags applied to an Amazon Chime SDK meeting resource.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[ListTagsForResource](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_meeting-chime_ListTagsForResource.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#list_meeting_tags/3","title":"AWS.Chime.list_meeting_tags/3","type":"function"},{"doc":"Lists up to 100 active Amazon Chime SDK meetings.\n\nListMeetings is not supported in the Amazon Chime SDK Meetings Namespace. Update\nyour application to remove calls to this API.\n\nFor more information about the Amazon Chime SDK, see [Using the Amazon Chime SDK](https://docs.aws.amazon.com/chime-sdk/latest/dg/meetings-sdk.html) in the\n*Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#list_meetings/4","title":"AWS.Chime.list_meetings/4","type":"function"},{"doc":"Lists the phone number orders for the administrator's Amazon Chime account.","ref":"AWS.Chime.html#list_phone_number_orders/4","title":"AWS.Chime.list_phone_number_orders/4","type":"function"},{"doc":"Lists the phone numbers for the specified Amazon Chime account, Amazon Chime\nuser, Amazon Chime Voice Connector, or Amazon Chime Voice Connector group.","ref":"AWS.Chime.html#list_phone_numbers/8","title":"AWS.Chime.list_phone_numbers/8","type":"function"},{"doc":"Lists the proxy sessions for the specified Amazon Chime Voice Connector.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[ListProxySessions](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_ListProxySessions.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#list_proxy_sessions/6","title":"AWS.Chime.list_proxy_sessions/6","type":"function"},{"doc":"Lists the membership details for the specified room in an Amazon Chime\nEnterprise account, such as the members' IDs, email addresses, and names.","ref":"AWS.Chime.html#list_room_memberships/6","title":"AWS.Chime.list_room_memberships/6","type":"function"},{"doc":"Lists the room details for the specified Amazon Chime Enterprise account.\n\nOptionally, filter the results by a member ID (user ID or bot ID) to see a list\nof rooms that the member belongs to.","ref":"AWS.Chime.html#list_rooms/6","title":"AWS.Chime.list_rooms/6","type":"function"},{"doc":"Lists the SIP media applications under the administrator's AWS account.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[ListSipMediaApplications](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_ListSipMediaApplications.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#list_sip_media_applications/4","title":"AWS.Chime.list_sip_media_applications/4","type":"function"},{"doc":"Lists the SIP rules under the administrator's AWS account.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[ListSipRules](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_ListSipRules.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#list_sip_rules/5","title":"AWS.Chime.list_sip_rules/5","type":"function"},{"doc":"Lists supported phone number countries.","ref":"AWS.Chime.html#list_supported_phone_number_countries/3","title":"AWS.Chime.list_supported_phone_number_countries/3","type":"function"},{"doc":"Lists the tags applied to an Amazon Chime SDK meeting and messaging resources.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the applicable latest version in the Amazon Chime SDK.\n\n   For meetings:\n[ListTagsForResource](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_meeting-chime_ListTagsForResource.html).     For messaging:\n[ListTagsForResource](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_ListTagsForResource.html).\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime namespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#list_tags_for_resource/3","title":"AWS.Chime.list_tags_for_resource/3","type":"function"},{"doc":"Lists the users that belong to the specified Amazon Chime account.\n\nYou can specify an email address to list only the user that the email address\nbelongs to.","ref":"AWS.Chime.html#list_users/7","title":"AWS.Chime.list_users/7","type":"function"},{"doc":"Lists the Amazon Chime Voice Connector groups for the administrator's AWS\naccount.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[ListVoiceConnectorGroups](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_ListVoiceConnectorGroups.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#list_voice_connector_groups/4","title":"AWS.Chime.list_voice_connector_groups/4","type":"function"},{"doc":"Lists the SIP credentials for the specified Amazon Chime Voice Connector.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[ListVoiceConnectorTerminationCredentials](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_ListVoiceConnectorTerminationCredentials.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#list_voice_connector_termination_credentials/3","title":"AWS.Chime.list_voice_connector_termination_credentials/3","type":"function"},{"doc":"Lists the Amazon Chime Voice Connectors for the administrator's AWS account.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[ListVoiceConnectors](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_ListVoiceConnectors.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#list_voice_connectors/4","title":"AWS.Chime.list_voice_connectors/4","type":"function"},{"doc":"Logs out the specified user from all of the devices they are currently logged\ninto.","ref":"AWS.Chime.html#logout_user/5","title":"AWS.Chime.logout_user/5","type":"function"},{"doc":"","ref":"AWS.Chime.html#metadata/0","title":"AWS.Chime.metadata/0","type":"function"},{"doc":"Sets the amount of time in days that a given `AppInstance` retains data.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[PutAppInstanceRetentionSettings](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_identity-chime_PutAppInstanceRetentionSettings.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#put_app_instance_retention_settings/4","title":"AWS.Chime.put_app_instance_retention_settings/4","type":"function"},{"doc":"The data streaming configurations of an `AppInstance`.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[PutMessagingStreamingConfigurations](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_PutMessagingStreamingConfigurations.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#put_app_instance_streaming_configurations/4","title":"AWS.Chime.put_app_instance_streaming_configurations/4","type":"function"},{"doc":"Creates an events configuration that allows a bot to receive outgoing events\nsent by Amazon Chime.\n\nChoose either an HTTPS endpoint or a Lambda function ARN. For more information,\nsee `Bot`.","ref":"AWS.Chime.html#put_events_configuration/5","title":"AWS.Chime.put_events_configuration/5","type":"function"},{"doc":"Puts retention settings for the specified Amazon Chime Enterprise account.\n\nWe recommend using AWS CloudTrail to monitor usage of this API for your account.\nFor more information, see [Logging Amazon Chime API Calls with AWS CloudTrail](https://docs.aws.amazon.com/chime/latest/ag/cloudtrail.html) in the\n*Amazon Chime Administration Guide*.\n\nTo turn off existing retention settings, remove the number of days from the\ncorresponding **RetentionDays** field in the **RetentionSettings** object. For\nmore information about retention settings, see [Managing Chat Retention Policies](https://docs.aws.amazon.com/chime/latest/ag/chat-retention.html) in\nthe *Amazon Chime Administration Guide*.","ref":"AWS.Chime.html#put_retention_settings/4","title":"AWS.Chime.put_retention_settings/4","type":"function"},{"doc":"Updates the logging configuration for the specified SIP media application.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[PutSipMediaApplicationLoggingConfiguration](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_PutSipMediaApplicationLoggingConfiguration.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#put_sip_media_application_logging_configuration/4","title":"AWS.Chime.put_sip_media_application_logging_configuration/4","type":"function"},{"doc":"Puts emergency calling configuration details to the specified Amazon Chime Voice\nConnector, such as emergency phone numbers and calling countries.\n\nOrigination and termination settings must be enabled for the Amazon Chime Voice\nConnector before emergency calling can be configured.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[PutVoiceConnectorEmergencyCallingConfiguration](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_PutVoiceConnectorEmergencyCallingConfiguration.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#put_voice_connector_emergency_calling_configuration/4","title":"AWS.Chime.put_voice_connector_emergency_calling_configuration/4","type":"function"},{"doc":"Adds a logging configuration for the specified Amazon Chime Voice Connector.\n\nThe logging configuration specifies whether SIP message logs are enabled for\nsending to Amazon CloudWatch Logs.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[PutVoiceConnectorLoggingConfiguration](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_PutVoiceConnectorLoggingConfiguration.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#put_voice_connector_logging_configuration/4","title":"AWS.Chime.put_voice_connector_logging_configuration/4","type":"function"},{"doc":"Adds origination settings for the specified Amazon Chime Voice Connector.\n\nIf emergency calling is configured for the Amazon Chime Voice Connector, it must\nbe deleted prior to turning off origination settings.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[PutVoiceConnectorOrigination](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_PutVoiceConnectorOrigination.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#put_voice_connector_origination/4","title":"AWS.Chime.put_voice_connector_origination/4","type":"function"},{"doc":"Puts the specified proxy configuration to the specified Amazon Chime Voice\nConnector.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[PutVoiceConnectorProxy](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_PutVoiceConnectorProxy.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#put_voice_connector_proxy/4","title":"AWS.Chime.put_voice_connector_proxy/4","type":"function"},{"doc":"Adds a streaming configuration for the specified Amazon Chime Voice Connector.\n\nThe streaming configuration specifies whether media streaming is enabled for\nsending to Kinesis. It also sets the retention period, in hours, for the Amazon\nKinesis data.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[PutVoiceConnectorStreamingConfiguration](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_PutVoiceConnectorStreamingConfiguration.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#put_voice_connector_streaming_configuration/4","title":"AWS.Chime.put_voice_connector_streaming_configuration/4","type":"function"},{"doc":"Adds termination settings for the specified Amazon Chime Voice Connector.\n\nIf emergency calling is configured for the Amazon Chime Voice Connector, it must\nbe deleted prior to turning off termination settings.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[PutVoiceConnectorTermination](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_PutVoiceConnectorTermination.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#put_voice_connector_termination/4","title":"AWS.Chime.put_voice_connector_termination/4","type":"function"},{"doc":"Adds termination SIP credentials for the specified Amazon Chime Voice Connector.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[PutVoiceConnectorTerminationCredentials](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_PutVoiceConnectorTerminationCredentials.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#put_voice_connector_termination_credentials/4","title":"AWS.Chime.put_voice_connector_termination_credentials/4","type":"function"},{"doc":"Redacts message content, but not metadata.\n\nThe message exists in the back end, but the action returns null content, and the\nstate shows as redacted.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the\n`AppInstanceUserArn` of the user that makes the API call as the value in the\nheader.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[RedactChannelMessage](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_RedactChannelMessage.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#redact_channel_message/5","title":"AWS.Chime.redact_channel_message/5","type":"function"},{"doc":"Redacts the specified message from the specified Amazon Chime conversation.","ref":"AWS.Chime.html#redact_conversation_message/6","title":"AWS.Chime.redact_conversation_message/6","type":"function"},{"doc":"Redacts the specified message from the specified Amazon Chime channel.","ref":"AWS.Chime.html#redact_room_message/6","title":"AWS.Chime.redact_room_message/6","type":"function"},{"doc":"Regenerates the security token for a bot.","ref":"AWS.Chime.html#regenerate_security_token/5","title":"AWS.Chime.regenerate_security_token/5","type":"function"},{"doc":"Resets the personal meeting PIN for the specified user on an Amazon Chime\naccount.\n\nReturns the `User` object with the updated personal meeting PIN.","ref":"AWS.Chime.html#reset_personal_pin/5","title":"AWS.Chime.reset_personal_pin/5","type":"function"},{"doc":"Moves a phone number from the **Deletion queue** back into the phone number\n**Inventory**.","ref":"AWS.Chime.html#restore_phone_number/4","title":"AWS.Chime.restore_phone_number/4","type":"function"},{"doc":"Searches for phone numbers that can be ordered.\n\nFor US numbers, provide at least one of the following search filters:\n`AreaCode`, `City`, `State`, or `TollFreePrefix`. If you provide `City`, you\nmust also provide `State`. Numbers outside the US only support the\n`PhoneNumberType` filter, which you must use.","ref":"AWS.Chime.html#search_available_phone_numbers/10","title":"AWS.Chime.search_available_phone_numbers/10","type":"function"},{"doc":"Sends a message to a particular channel that the member is a part of.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the\n`AppInstanceUserArn` of the user that makes the API call as the value in the\nheader.\n\nAlso, `STANDARD` messages can contain 4KB of data and the 1KB of metadata.\n`CONTROL` messages can contain 30 bytes of data and no metadata.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[SendChannelMessage](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_SendChannelMessage.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#send_channel_message/4","title":"AWS.Chime.send_channel_message/4","type":"function"},{"doc":"Starts transcription for the specified `meetingId`.\n\nFor more information, refer to [ Using Amazon Chime SDK live transcription\n](https://docs.aws.amazon.com/chime-sdk/latest/dg/meeting-transcription.html) in\nthe *Amazon Chime SDK Developer Guide*.\n\nIf you specify an invalid configuration, a `TranscriptFailed` event will be sent\nwith the contents of the `BadRequestException` generated by Amazon Transcribe.\nFor more information on each parameter and which combinations are valid, refer\nto the\n[StartStreamTranscription](https://docs.aws.amazon.com/transcribe/latest/APIReference/API_streaming_StartStreamTranscription.html) API in the *Amazon Transcribe Developer Guide*.\n\nAmazon Chime SDK live transcription is powered by Amazon Transcribe. Use of\nAmazon Transcribe is subject to the [AWS Service\nTerms](https://aws.amazon.com/service-terms/), including the terms specific to\nthe AWS Machine Learning and Artificial Intelligence Services.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[StartMeetingTranscription](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_meeting-chime_StartMeetingTranscription.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#start_meeting_transcription/4","title":"AWS.Chime.start_meeting_transcription/4","type":"function"},{"doc":"Stops transcription for the specified `meetingId`.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[StopMeetingTranscription](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_meeting-chime_StopMeetingTranscription.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#stop_meeting_transcription/4","title":"AWS.Chime.stop_meeting_transcription/4","type":"function"},{"doc":"Applies the specified tags to the specified Amazon Chime attendee.\n\nTagAttendee is not supported in the Amazon Chime SDK Meetings Namespace. Update\nyour application to remove calls to this API.","ref":"AWS.Chime.html#tag_attendee/5","title":"AWS.Chime.tag_attendee/5","type":"function"},{"doc":"Applies the specified tags to the specified Amazon Chime SDK meeting.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[TagResource](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_meeting-chime_TagResource.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#tag_meeting/4","title":"AWS.Chime.tag_meeting/4","type":"function"},{"doc":"Applies the specified tags to the specified Amazon Chime SDK meeting resource.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[TagResource](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_meeting-chime_TagResource.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#tag_resource/3","title":"AWS.Chime.tag_resource/3","type":"function"},{"doc":"Untags the specified tags from the specified Amazon Chime SDK attendee.\n\nUntagAttendee is not supported in the Amazon Chime SDK Meetings Namespace.\nUpdate your application to remove calls to this API.","ref":"AWS.Chime.html#untag_attendee/5","title":"AWS.Chime.untag_attendee/5","type":"function"},{"doc":"Untags the specified tags from the specified Amazon Chime SDK meeting.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[UntagResource](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_meeting-chime_UntagResource.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#untag_meeting/4","title":"AWS.Chime.untag_meeting/4","type":"function"},{"doc":"Untags the specified tags from the specified Amazon Chime SDK meeting resource.\n\nApplies the specified tags to the specified Amazon Chime SDK meeting resource.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[UntagResource](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_meeting-chime_UntagResource.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#untag_resource/3","title":"AWS.Chime.untag_resource/3","type":"function"},{"doc":"Updates account details for the specified Amazon Chime account.\n\nCurrently, only account name and default license updates are supported for this\naction.","ref":"AWS.Chime.html#update_account/4","title":"AWS.Chime.update_account/4","type":"function"},{"doc":"Updates the settings for the specified Amazon Chime account.\n\nYou can update settings for remote control of shared screens, or for the\ndial-out option. For more information about these settings, see [Use the Policies Page](https://docs.aws.amazon.com/chime/latest/ag/policies.html) in the\n*Amazon Chime Administration Guide*.","ref":"AWS.Chime.html#update_account_settings/4","title":"AWS.Chime.update_account_settings/4","type":"function"},{"doc":"Updates `AppInstance` metadata.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[UpdateAppInstance](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_identity-chime_UpdateAppInstance.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#update_app_instance/4","title":"AWS.Chime.update_app_instance/4","type":"function"},{"doc":"Updates the details of an `AppInstanceUser`.\n\nYou can update names and metadata.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[UpdateAppInstanceUser](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_identity-chime_UpdateAppInstanceUser.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#update_app_instance_user/4","title":"AWS.Chime.update_app_instance_user/4","type":"function"},{"doc":"Updates the status of the specified bot, such as starting or stopping the bot\nfrom running in your Amazon Chime Enterprise account.","ref":"AWS.Chime.html#update_bot/5","title":"AWS.Chime.update_bot/5","type":"function"},{"doc":"Update a channel's attributes.\n\n**Restriction**: You can't change a channel's privacy.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the\n`AppInstanceUserArn` of the user that makes the API call as the value in the\nheader.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[UpdateChannel](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_UpdateChannel.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#update_channel/4","title":"AWS.Chime.update_channel/4","type":"function"},{"doc":"Updates the content of a message.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the\n`AppInstanceUserArn` of the user that makes the API call as the value in the\nheader.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[UpdateChannelMessage](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_UpdateChannelMessage.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#update_channel_message/5","title":"AWS.Chime.update_channel_message/5","type":"function"},{"doc":"The details of the time when a user last read messages in a channel.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the\n`AppInstanceUserArn` of the user that makes the API call as the value in the\nheader.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[UpdateChannelReadMarker](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_messaging-chime_UpdateChannelReadMarker.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#update_channel_read_marker/4","title":"AWS.Chime.update_channel_read_marker/4","type":"function"},{"doc":"Updates global settings for the administrator's AWS account, such as Amazon\nChime Business Calling and Amazon Chime Voice Connector settings.","ref":"AWS.Chime.html#update_global_settings/3","title":"AWS.Chime.update_global_settings/3","type":"function"},{"doc":"Updates phone number details, such as product type or calling name, for the\nspecified phone number ID.\n\nYou can update one phone number detail at a time. For example, you can update\neither the product type or the calling name in one action.\n\nFor toll-free numbers, you cannot use the Amazon Chime Business Calling product\ntype. For numbers outside the U.S., you must use the Amazon Chime SIP Media\nApplication Dial-In product type.\n\nUpdates to outbound calling names can take 72 hours to complete. Pending updates\nto outbound calling names must be complete before you can request another\nupdate.","ref":"AWS.Chime.html#update_phone_number/4","title":"AWS.Chime.update_phone_number/4","type":"function"},{"doc":"Updates the phone number settings for the administrator's AWS account, such as\nthe default outbound calling name.\n\nYou can update the default outbound calling name once every seven days. Outbound\ncalling names can take up to 72 hours to update.","ref":"AWS.Chime.html#update_phone_number_settings/3","title":"AWS.Chime.update_phone_number_settings/3","type":"function"},{"doc":"Updates the specified proxy session details, such as voice or SMS capabilities.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[UpdateProxySession](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_UpdateProxySession.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#update_proxy_session/5","title":"AWS.Chime.update_proxy_session/5","type":"function"},{"doc":"Updates room details, such as the room name, for a room in an Amazon Chime\nEnterprise account.","ref":"AWS.Chime.html#update_room/5","title":"AWS.Chime.update_room/5","type":"function"},{"doc":"Updates room membership details, such as the member role, for a room in an\nAmazon Chime Enterprise account.\n\nThe member role designates whether the member is a chat room administrator or a\ngeneral chat room member. The member role can be updated only for user IDs.","ref":"AWS.Chime.html#update_room_membership/6","title":"AWS.Chime.update_room_membership/6","type":"function"},{"doc":"Updates the details of the specified SIP media application.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[UpdateSipMediaApplication](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_UpdateSipMediaApplication.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#update_sip_media_application/4","title":"AWS.Chime.update_sip_media_application/4","type":"function"},{"doc":"Invokes the AWS Lambda function associated with the SIP media application and\ntransaction ID in an update request.\n\nThe Lambda function can then return a new set of actions.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[UpdateSipMediaApplicationCall](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_UpdateSipMediaApplicationCall.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#update_sip_media_application_call/5","title":"AWS.Chime.update_sip_media_application_call/5","type":"function"},{"doc":"Updates the details of the specified SIP rule.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[UpdateSipRule](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_UpdateSipRule.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#update_sip_rule/4","title":"AWS.Chime.update_sip_rule/4","type":"function"},{"doc":"Updates user details for a specified user ID.\n\nCurrently, only `LicenseType` updates are supported for this action.","ref":"AWS.Chime.html#update_user/5","title":"AWS.Chime.update_user/5","type":"function"},{"doc":"Updates the settings for the specified user, such as phone number settings.","ref":"AWS.Chime.html#update_user_settings/5","title":"AWS.Chime.update_user_settings/5","type":"function"},{"doc":"Updates details for the specified Amazon Chime Voice Connector.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[UpdateVoiceConnector](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_UpdateVoiceConnector.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#update_voice_connector/4","title":"AWS.Chime.update_voice_connector/4","type":"function"},{"doc":"Updates details of the specified Amazon Chime Voice Connector group, such as the\nname and Amazon Chime Voice Connector priority ranking.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[UpdateVoiceConnectorGroup](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_UpdateVoiceConnectorGroup.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#update_voice_connector_group/4","title":"AWS.Chime.update_voice_connector_group/4","type":"function"},{"doc":"Validates an address to be used for 911 calls made with Amazon Chime Voice\nConnectors.\n\nYou can use validated addresses in a Presence Information Data Format Location\nObject file that you include in SIP requests. That helps ensure that addresses\nare routed to the appropriate Public Safety Answering Point.\n\n**This API is is no longer supported and will not be updated.** We recommend\nusing the latest version,\n[ValidateE911Address](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_voice-chime_ValidateE911Address.html), in the Amazon Chime SDK.\n\nUsing the latest version requires migrating to a dedicated namespace. For more\ninformation, refer to [Migrating from the Amazon Chime\nnamespace](https://docs.aws.amazon.com/chime-sdk/latest/dg/migrate-from-chm-namespace.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.Chime.html#validate_e911_address/3","title":"AWS.Chime.validate_e911_address/3","type":"function"},{"doc":"The Amazon Chime SDK Identity APIs in this section allow software developers to\ncreate and manage unique instances of their messaging applications.\n\nThese APIs provide the overarching framework for creating and sending messages.\nFor more information about the identity APIs, refer to [Amazon Chime SDK identity](https://docs.aws.amazon.com/chime/latest/APIReference/API_Operations_Amazon_Chime_SDK_Identity.html).","ref":"AWS.ChimeSDKIdentity.html","title":"AWS.ChimeSDKIdentity","type":"module"},{"doc":"Creates an Amazon Chime SDK messaging `AppInstance` under an AWS account.\n\nOnly SDK messaging customers use this API. `CreateAppInstance` supports\nidempotency behavior as described in the AWS API Standard.\n\nidentity","ref":"AWS.ChimeSDKIdentity.html#create_app_instance/3","title":"AWS.ChimeSDKIdentity.create_app_instance/3","type":"function"},{"doc":"Promotes an `AppInstanceUser` or `AppInstanceBot` to an `AppInstanceAdmin`.\n\nThe promoted entity can perform the following actions.\n\n  * `ChannelModerator` actions across all channels in the\n`AppInstance`.\n\n  * `DeleteChannelMessage` actions.\n\nOnly an `AppInstanceUser` and `AppInstanceBot` can be promoted to an\n`AppInstanceAdmin` role.","ref":"AWS.ChimeSDKIdentity.html#create_app_instance_admin/4","title":"AWS.ChimeSDKIdentity.create_app_instance_admin/4","type":"function"},{"doc":"Creates a bot under an Amazon Chime `AppInstance`.\n\nThe request consists of a unique `Configuration` and `Name` for that bot.","ref":"AWS.ChimeSDKIdentity.html#create_app_instance_bot/3","title":"AWS.ChimeSDKIdentity.create_app_instance_bot/3","type":"function"},{"doc":"Creates a user under an Amazon Chime `AppInstance`.\n\nThe request consists of a unique `appInstanceUserId` and `Name` for that user.","ref":"AWS.ChimeSDKIdentity.html#create_app_instance_user/3","title":"AWS.ChimeSDKIdentity.create_app_instance_user/3","type":"function"},{"doc":"Deletes an `AppInstance` and all associated data asynchronously.","ref":"AWS.ChimeSDKIdentity.html#delete_app_instance/4","title":"AWS.ChimeSDKIdentity.delete_app_instance/4","type":"function"},{"doc":"Demotes an `AppInstanceAdmin` to an `AppInstanceUser` or `AppInstanceBot`.\n\nThis action does not delete the user.","ref":"AWS.ChimeSDKIdentity.html#delete_app_instance_admin/5","title":"AWS.ChimeSDKIdentity.delete_app_instance_admin/5","type":"function"},{"doc":"Deletes an `AppInstanceBot`.","ref":"AWS.ChimeSDKIdentity.html#delete_app_instance_bot/4","title":"AWS.ChimeSDKIdentity.delete_app_instance_bot/4","type":"function"},{"doc":"Deletes an `AppInstanceUser`.","ref":"AWS.ChimeSDKIdentity.html#delete_app_instance_user/4","title":"AWS.ChimeSDKIdentity.delete_app_instance_user/4","type":"function"},{"doc":"Deregisters an `AppInstanceUserEndpoint`.","ref":"AWS.ChimeSDKIdentity.html#deregister_app_instance_user_endpoint/5","title":"AWS.ChimeSDKIdentity.deregister_app_instance_user_endpoint/5","type":"function"},{"doc":"Returns the full details of an `AppInstance`.","ref":"AWS.ChimeSDKIdentity.html#describe_app_instance/3","title":"AWS.ChimeSDKIdentity.describe_app_instance/3","type":"function"},{"doc":"Returns the full details of an `AppInstanceAdmin`.","ref":"AWS.ChimeSDKIdentity.html#describe_app_instance_admin/4","title":"AWS.ChimeSDKIdentity.describe_app_instance_admin/4","type":"function"},{"doc":"The `AppInstanceBot's` information.","ref":"AWS.ChimeSDKIdentity.html#describe_app_instance_bot/3","title":"AWS.ChimeSDKIdentity.describe_app_instance_bot/3","type":"function"},{"doc":"Returns the full details of an `AppInstanceUser`.","ref":"AWS.ChimeSDKIdentity.html#describe_app_instance_user/3","title":"AWS.ChimeSDKIdentity.describe_app_instance_user/3","type":"function"},{"doc":"Returns the full details of an `AppInstanceUserEndpoint`.","ref":"AWS.ChimeSDKIdentity.html#describe_app_instance_user_endpoint/4","title":"AWS.ChimeSDKIdentity.describe_app_instance_user_endpoint/4","type":"function"},{"doc":"Gets the retention settings for an `AppInstance`.","ref":"AWS.ChimeSDKIdentity.html#get_app_instance_retention_settings/3","title":"AWS.ChimeSDKIdentity.get_app_instance_retention_settings/3","type":"function"},{"doc":"Returns a list of the administrators in the `AppInstance`.","ref":"AWS.ChimeSDKIdentity.html#list_app_instance_admins/5","title":"AWS.ChimeSDKIdentity.list_app_instance_admins/5","type":"function"},{"doc":"Lists all `AppInstanceBots` created under a single `AppInstance`.","ref":"AWS.ChimeSDKIdentity.html#list_app_instance_bots/5","title":"AWS.ChimeSDKIdentity.list_app_instance_bots/5","type":"function"},{"doc":"Lists all the `AppInstanceUserEndpoints` created under a single\n`AppInstanceUser`.","ref":"AWS.ChimeSDKIdentity.html#list_app_instance_user_endpoints/5","title":"AWS.ChimeSDKIdentity.list_app_instance_user_endpoints/5","type":"function"},{"doc":"List all `AppInstanceUsers` created under a single `AppInstance`.","ref":"AWS.ChimeSDKIdentity.html#list_app_instance_users/5","title":"AWS.ChimeSDKIdentity.list_app_instance_users/5","type":"function"},{"doc":"Lists all Amazon Chime `AppInstance`s created under a single AWS account.","ref":"AWS.ChimeSDKIdentity.html#list_app_instances/4","title":"AWS.ChimeSDKIdentity.list_app_instances/4","type":"function"},{"doc":"Lists the tags applied to an Amazon Chime SDK identity resource.","ref":"AWS.ChimeSDKIdentity.html#list_tags_for_resource/3","title":"AWS.ChimeSDKIdentity.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.ChimeSDKIdentity.html#metadata/0","title":"AWS.ChimeSDKIdentity.metadata/0","type":"function"},{"doc":"Sets the amount of time in days that a given `AppInstance` retains data.","ref":"AWS.ChimeSDKIdentity.html#put_app_instance_retention_settings/4","title":"AWS.ChimeSDKIdentity.put_app_instance_retention_settings/4","type":"function"},{"doc":"Sets the number of days before the `AppInstanceUser` is automatically deleted.\n\nA background process deletes expired `AppInstanceUsers` within 6 hours of\nexpiration. Actual deletion times may vary.\n\nExpired `AppInstanceUsers` that have not yet been deleted appear as active, and\nyou can update their expiration settings. The system honors the new settings.","ref":"AWS.ChimeSDKIdentity.html#put_app_instance_user_expiration_settings/4","title":"AWS.ChimeSDKIdentity.put_app_instance_user_expiration_settings/4","type":"function"},{"doc":"Registers an endpoint under an Amazon Chime `AppInstanceUser`.\n\nThe endpoint receives messages for a user. For push notifications, the endpoint\nis a mobile device used to receive mobile push notifications for a user.","ref":"AWS.ChimeSDKIdentity.html#register_app_instance_user_endpoint/4","title":"AWS.ChimeSDKIdentity.register_app_instance_user_endpoint/4","type":"function"},{"doc":"Applies the specified tags to the specified Amazon Chime SDK identity resource.","ref":"AWS.ChimeSDKIdentity.html#tag_resource/3","title":"AWS.ChimeSDKIdentity.tag_resource/3","type":"function"},{"doc":"Removes the specified tags from the specified Amazon Chime SDK identity\nresource.","ref":"AWS.ChimeSDKIdentity.html#untag_resource/3","title":"AWS.ChimeSDKIdentity.untag_resource/3","type":"function"},{"doc":"Updates `AppInstance` metadata.","ref":"AWS.ChimeSDKIdentity.html#update_app_instance/4","title":"AWS.ChimeSDKIdentity.update_app_instance/4","type":"function"},{"doc":"Updates the name and metadata of an `AppInstanceBot`.","ref":"AWS.ChimeSDKIdentity.html#update_app_instance_bot/4","title":"AWS.ChimeSDKIdentity.update_app_instance_bot/4","type":"function"},{"doc":"Updates the details of an `AppInstanceUser`.\n\nYou can update names and metadata.","ref":"AWS.ChimeSDKIdentity.html#update_app_instance_user/4","title":"AWS.ChimeSDKIdentity.update_app_instance_user/4","type":"function"},{"doc":"Updates the details of an `AppInstanceUserEndpoint`.\n\nYou can update the name and `AllowMessage` values.","ref":"AWS.ChimeSDKIdentity.html#update_app_instance_user_endpoint/5","title":"AWS.ChimeSDKIdentity.update_app_instance_user_endpoint/5","type":"function"},{"doc":"The Amazon Chime SDK media pipeline APIs in this section allow software\ndevelopers to create Amazon Chime SDK media pipelines that capture, concatenate,\nor stream your Amazon Chime SDK meetings.\n\nFor more information about media pipelines, see [Amazon Chime SDK media pipelines](https://docs.aws.amazon.com/chime-sdk/latest/APIReference/API_Operations_Amazon_Chime_SDK_Media_Pipelines.html).","ref":"AWS.ChimeSDKMediaPipelines.html","title":"AWS.ChimeSDKMediaPipelines","type":"module"},{"doc":"Creates a media pipeline.","ref":"AWS.ChimeSDKMediaPipelines.html#create_media_capture_pipeline/3","title":"AWS.ChimeSDKMediaPipelines.create_media_capture_pipeline/3","type":"function"},{"doc":"Creates a media concatenation pipeline.","ref":"AWS.ChimeSDKMediaPipelines.html#create_media_concatenation_pipeline/3","title":"AWS.ChimeSDKMediaPipelines.create_media_concatenation_pipeline/3","type":"function"},{"doc":"Creates a media insights pipeline.","ref":"AWS.ChimeSDKMediaPipelines.html#create_media_insights_pipeline/3","title":"AWS.ChimeSDKMediaPipelines.create_media_insights_pipeline/3","type":"function"},{"doc":"A structure that contains the static configurations for a media insights\npipeline.","ref":"AWS.ChimeSDKMediaPipelines.html#create_media_insights_pipeline_configuration/3","title":"AWS.ChimeSDKMediaPipelines.create_media_insights_pipeline_configuration/3","type":"function"},{"doc":"Creates a media live connector pipeline in an Amazon Chime SDK meeting.","ref":"AWS.ChimeSDKMediaPipelines.html#create_media_live_connector_pipeline/3","title":"AWS.ChimeSDKMediaPipelines.create_media_live_connector_pipeline/3","type":"function"},{"doc":"Creates an Kinesis video stream pool for the media pipeline.","ref":"AWS.ChimeSDKMediaPipelines.html#create_media_pipeline_kinesis_video_stream_pool/3","title":"AWS.ChimeSDKMediaPipelines.create_media_pipeline_kinesis_video_stream_pool/3","type":"function"},{"doc":"Creates a streaming media pipeline.","ref":"AWS.ChimeSDKMediaPipelines.html#create_media_stream_pipeline/3","title":"AWS.ChimeSDKMediaPipelines.create_media_stream_pipeline/3","type":"function"},{"doc":"Deletes the media pipeline.","ref":"AWS.ChimeSDKMediaPipelines.html#delete_media_capture_pipeline/4","title":"AWS.ChimeSDKMediaPipelines.delete_media_capture_pipeline/4","type":"function"},{"doc":"Deletes the specified configuration settings.","ref":"AWS.ChimeSDKMediaPipelines.html#delete_media_insights_pipeline_configuration/4","title":"AWS.ChimeSDKMediaPipelines.delete_media_insights_pipeline_configuration/4","type":"function"},{"doc":"Deletes the media pipeline.","ref":"AWS.ChimeSDKMediaPipelines.html#delete_media_pipeline/4","title":"AWS.ChimeSDKMediaPipelines.delete_media_pipeline/4","type":"function"},{"doc":"Deletes an Kinesis video stream pool.","ref":"AWS.ChimeSDKMediaPipelines.html#delete_media_pipeline_kinesis_video_stream_pool/4","title":"AWS.ChimeSDKMediaPipelines.delete_media_pipeline_kinesis_video_stream_pool/4","type":"function"},{"doc":"Gets an existing media pipeline.","ref":"AWS.ChimeSDKMediaPipelines.html#get_media_capture_pipeline/3","title":"AWS.ChimeSDKMediaPipelines.get_media_capture_pipeline/3","type":"function"},{"doc":"Gets the configuration settings for a media insights pipeline.","ref":"AWS.ChimeSDKMediaPipelines.html#get_media_insights_pipeline_configuration/3","title":"AWS.ChimeSDKMediaPipelines.get_media_insights_pipeline_configuration/3","type":"function"},{"doc":"Gets an existing media pipeline.","ref":"AWS.ChimeSDKMediaPipelines.html#get_media_pipeline/3","title":"AWS.ChimeSDKMediaPipelines.get_media_pipeline/3","type":"function"},{"doc":"Gets an Kinesis video stream pool.","ref":"AWS.ChimeSDKMediaPipelines.html#get_media_pipeline_kinesis_video_stream_pool/3","title":"AWS.ChimeSDKMediaPipelines.get_media_pipeline_kinesis_video_stream_pool/3","type":"function"},{"doc":"Retrieves the details of the specified speaker search task.","ref":"AWS.ChimeSDKMediaPipelines.html#get_speaker_search_task/4","title":"AWS.ChimeSDKMediaPipelines.get_speaker_search_task/4","type":"function"},{"doc":"Retrieves the details of a voice tone analysis task.","ref":"AWS.ChimeSDKMediaPipelines.html#get_voice_tone_analysis_task/4","title":"AWS.ChimeSDKMediaPipelines.get_voice_tone_analysis_task/4","type":"function"},{"doc":"Returns a list of media pipelines.","ref":"AWS.ChimeSDKMediaPipelines.html#list_media_capture_pipelines/4","title":"AWS.ChimeSDKMediaPipelines.list_media_capture_pipelines/4","type":"function"},{"doc":"Lists the available media insights pipeline configurations.","ref":"AWS.ChimeSDKMediaPipelines.html#list_media_insights_pipeline_configurations/4","title":"AWS.ChimeSDKMediaPipelines.list_media_insights_pipeline_configurations/4","type":"function"},{"doc":"Lists the video stream pools in the media pipeline.","ref":"AWS.ChimeSDKMediaPipelines.html#list_media_pipeline_kinesis_video_stream_pools/4","title":"AWS.ChimeSDKMediaPipelines.list_media_pipeline_kinesis_video_stream_pools/4","type":"function"},{"doc":"Returns a list of media pipelines.","ref":"AWS.ChimeSDKMediaPipelines.html#list_media_pipelines/4","title":"AWS.ChimeSDKMediaPipelines.list_media_pipelines/4","type":"function"},{"doc":"Lists the tags available for a media pipeline.","ref":"AWS.ChimeSDKMediaPipelines.html#list_tags_for_resource/3","title":"AWS.ChimeSDKMediaPipelines.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.ChimeSDKMediaPipelines.html#metadata/0","title":"AWS.ChimeSDKMediaPipelines.metadata/0","type":"function"},{"doc":"Starts a speaker search task.\n\nBefore starting any speaker search tasks, you must provide all notices and\nobtain all consents from the speaker as required under applicable privacy and\nbiometrics laws, and as required under the [AWS service terms](https://aws.amazon.com/service-terms/) for the Amazon Chime SDK.","ref":"AWS.ChimeSDKMediaPipelines.html#start_speaker_search_task/4","title":"AWS.ChimeSDKMediaPipelines.start_speaker_search_task/4","type":"function"},{"doc":"Starts a voice tone analysis task.\n\nFor more information about voice tone analysis, see [Using Amazon Chime SDK voice\nanalytics](https://docs.aws.amazon.com/chime-sdk/latest/dg/voice-analytics.html)\nin the *Amazon Chime SDK Developer Guide*.\n\nBefore starting any voice tone analysis tasks, you must provide all notices and\nobtain all consents from the speaker as required under applicable privacy and\nbiometrics laws, and as required under the [AWS service terms](https://aws.amazon.com/service-terms/) for the Amazon Chime SDK.","ref":"AWS.ChimeSDKMediaPipelines.html#start_voice_tone_analysis_task/4","title":"AWS.ChimeSDKMediaPipelines.start_voice_tone_analysis_task/4","type":"function"},{"doc":"Stops a speaker search task.","ref":"AWS.ChimeSDKMediaPipelines.html#stop_speaker_search_task/5","title":"AWS.ChimeSDKMediaPipelines.stop_speaker_search_task/5","type":"function"},{"doc":"Stops a voice tone analysis task.","ref":"AWS.ChimeSDKMediaPipelines.html#stop_voice_tone_analysis_task/5","title":"AWS.ChimeSDKMediaPipelines.stop_voice_tone_analysis_task/5","type":"function"},{"doc":"The ARN of the media pipeline that you want to tag.\n\nConsists of the pipeline's endpoint region, resource ID, and pipeline ID.","ref":"AWS.ChimeSDKMediaPipelines.html#tag_resource/3","title":"AWS.ChimeSDKMediaPipelines.tag_resource/3","type":"function"},{"doc":"Removes any tags from a media pipeline.","ref":"AWS.ChimeSDKMediaPipelines.html#untag_resource/3","title":"AWS.ChimeSDKMediaPipelines.untag_resource/3","type":"function"},{"doc":"Updates the media insights pipeline's configuration settings.","ref":"AWS.ChimeSDKMediaPipelines.html#update_media_insights_pipeline_configuration/4","title":"AWS.ChimeSDKMediaPipelines.update_media_insights_pipeline_configuration/4","type":"function"},{"doc":"Updates the status of a media insights pipeline.","ref":"AWS.ChimeSDKMediaPipelines.html#update_media_insights_pipeline_status/4","title":"AWS.ChimeSDKMediaPipelines.update_media_insights_pipeline_status/4","type":"function"},{"doc":"Updates an Kinesis video stream pool in a media pipeline.","ref":"AWS.ChimeSDKMediaPipelines.html#update_media_pipeline_kinesis_video_stream_pool/4","title":"AWS.ChimeSDKMediaPipelines.update_media_pipeline_kinesis_video_stream_pool/4","type":"function"},{"doc":"The Amazon Chime SDK meetings APIs in this section allow software developers to\ncreate Amazon Chime SDK meetings, set the Amazon Web Services Regions for\nmeetings, create and manage users, and send and receive meeting notifications.\n\nFor more information about the meeting APIs, see [Amazon Chime SDK meetings](https://docs.aws.amazon.com/chime/latest/APIReference/API_Operations_Amazon_Chime_SDK_Meetings.html).","ref":"AWS.ChimeSDKMeetings.html","title":"AWS.ChimeSDKMeetings","type":"module"},{"doc":"Creates up to 100 attendees for an active Amazon Chime SDK meeting.\n\nFor more information about the Amazon Chime SDK, see [Using the Amazon Chime SDK](https://docs.aws.amazon.com/chime/latest/dg/meetings-sdk.html) in the\n*Amazon Chime Developer Guide*.","ref":"AWS.ChimeSDKMeetings.html#batch_create_attendee/4","title":"AWS.ChimeSDKMeetings.batch_create_attendee/4","type":"function"},{"doc":"Updates `AttendeeCapabilities` except the capabilities listed in an\n`ExcludedAttendeeIds` table.\n\nYou use the capabilities with a set of values that control what the capabilities\ncan do, such as `SendReceive` data. For more information about those values, see\n.\n\nWhen using capabilities, be aware of these corner cases:\n\n  * If you specify `MeetingFeatures:Video:MaxResolution:None` when you\ncreate a meeting, all API requests that include `SendReceive`, `Send`, or\n`Receive` for `AttendeeCapabilities:Video` will be rejected with\n`ValidationError 400`.\n\n  * If you specify `MeetingFeatures:Content:MaxResolution:None` when\nyou create a meeting, all API requests that include `SendReceive`, `Send`, or\n`Receive` for `AttendeeCapabilities:Content` will be rejected with\n`ValidationError 400`.\n\n  * You can't set `content` capabilities to `SendReceive` or `Receive`\nunless you also set `video` capabilities to `SendReceive` or `Receive`. If you\ndon't set the `video` capability to receive, the response will contain an HTTP\n400 Bad Request status code. However, you can set your `video` capability to\nreceive and you set your `content` capability to not receive.\n\n  * When you change an `audio` capability from `None` or `Receive` to\n`Send` or `SendReceive` , and if the attendee left their microphone unmuted,\naudio will flow from the attendee to the other meeting participants.\n\n  * When you change a `video` or `content` capability from `None` or\n`Receive` to `Send` or `SendReceive` , and if the attendee turned on their video\nor content streams, remote attendees can receive those streams, but only after\nmedia renegotiation between the client and the Amazon Chime back-end server.","ref":"AWS.ChimeSDKMeetings.html#batch_update_attendee_capabilities_except/4","title":"AWS.ChimeSDKMeetings.batch_update_attendee_capabilities_except/4","type":"function"},{"doc":"Creates a new attendee for an active Amazon Chime SDK meeting.\n\nFor more information about the Amazon Chime SDK, see [Using the Amazon Chime SDK](https://docs.aws.amazon.com/chime/latest/dg/meetings-sdk.html) in the\n*Amazon Chime Developer Guide*.","ref":"AWS.ChimeSDKMeetings.html#create_attendee/4","title":"AWS.ChimeSDKMeetings.create_attendee/4","type":"function"},{"doc":"Creates a new Amazon Chime SDK meeting in the specified media Region with no\ninitial attendees.\n\nFor more information about specifying media Regions, see [Amazon Chime SDK Media Regions](https://docs.aws.amazon.com/chime/latest/dg/chime-sdk-meetings-regions.html)\nin the *Amazon Chime Developer Guide*. For more information about the Amazon\nChime SDK, see [Using the Amazon Chime SDK](https://docs.aws.amazon.com/chime/latest/dg/meetings-sdk.html) in the\n*Amazon Chime Developer Guide*.","ref":"AWS.ChimeSDKMeetings.html#create_meeting/3","title":"AWS.ChimeSDKMeetings.create_meeting/3","type":"function"},{"doc":"Creates a new Amazon Chime SDK meeting in the specified media Region, with\nattendees.\n\nFor more information about specifying media Regions, see [Amazon Chime SDK Media Regions](https://docs.aws.amazon.com/chime/latest/dg/chime-sdk-meetings-regions.html)\nin the *Amazon Chime Developer Guide*. For more information about the Amazon\nChime SDK, see [Using the Amazon Chime SDK](https://docs.aws.amazon.com/chime/latest/dg/meetings-sdk.html) in the\n*Amazon Chime Developer Guide*.","ref":"AWS.ChimeSDKMeetings.html#create_meeting_with_attendees/3","title":"AWS.ChimeSDKMeetings.create_meeting_with_attendees/3","type":"function"},{"doc":"Deletes an attendee from the specified Amazon Chime SDK meeting and deletes\ntheir `JoinToken`.\n\nAttendees are automatically deleted when a Amazon Chime SDK meeting is deleted.\nFor more information about the Amazon Chime SDK, see [Using the Amazon Chime SDK](https://docs.aws.amazon.com/chime/latest/dg/meetings-sdk.html) in the\n*Amazon Chime Developer Guide*.","ref":"AWS.ChimeSDKMeetings.html#delete_attendee/5","title":"AWS.ChimeSDKMeetings.delete_attendee/5","type":"function"},{"doc":"Deletes the specified Amazon Chime SDK meeting.\n\nThe operation deletes all attendees, disconnects all clients, and prevents new\nclients from joining the meeting. For more information about the Amazon Chime\nSDK, see [Using the Amazon Chime SDK](https://docs.aws.amazon.com/chime/latest/dg/meetings-sdk.html) in the\n*Amazon Chime Developer Guide*.","ref":"AWS.ChimeSDKMeetings.html#delete_meeting/4","title":"AWS.ChimeSDKMeetings.delete_meeting/4","type":"function"},{"doc":"Gets the Amazon Chime SDK attendee details for a specified meeting ID and\nattendee ID.\n\nFor more information about the Amazon Chime SDK, see [Using the Amazon Chime SDK](https://docs.aws.amazon.com/chime/latest/dg/meetings-sdk.html) in the\n*Amazon Chime Developer Guide*.","ref":"AWS.ChimeSDKMeetings.html#get_attendee/4","title":"AWS.ChimeSDKMeetings.get_attendee/4","type":"function"},{"doc":"Gets the Amazon Chime SDK meeting details for the specified meeting ID.\n\nFor more information about the Amazon Chime SDK, see [Using the Amazon Chime SDK](https://docs.aws.amazon.com/chime/latest/dg/meetings-sdk.html) in the\n*Amazon Chime Developer Guide*.","ref":"AWS.ChimeSDKMeetings.html#get_meeting/3","title":"AWS.ChimeSDKMeetings.get_meeting/3","type":"function"},{"doc":"Lists the attendees for the specified Amazon Chime SDK meeting.\n\nFor more information about the Amazon Chime SDK, see [Using the Amazon Chime SDK](https://docs.aws.amazon.com/chime/latest/dg/meetings-sdk.html) in the\n*Amazon Chime Developer Guide*.","ref":"AWS.ChimeSDKMeetings.html#list_attendees/5","title":"AWS.ChimeSDKMeetings.list_attendees/5","type":"function"},{"doc":"Returns a list of the tags available for the specified resource.","ref":"AWS.ChimeSDKMeetings.html#list_tags_for_resource/3","title":"AWS.ChimeSDKMeetings.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.ChimeSDKMeetings.html#metadata/0","title":"AWS.ChimeSDKMeetings.metadata/0","type":"function"},{"doc":"Starts transcription for the specified `meetingId`.\n\nFor more information, refer to [ Using Amazon Chime SDK live transcription\n](https://docs.aws.amazon.com/chime-sdk/latest/dg/meeting-transcription.html) in\nthe *Amazon Chime SDK Developer Guide*.\n\nIf you specify an invalid configuration, a `TranscriptFailed` event will be sent\nwith the contents of the `BadRequestException` generated by Amazon Transcribe.\nFor more information on each parameter and which combinations are valid, refer\nto the\n[StartStreamTranscription](https://docs.aws.amazon.com/transcribe/latest/APIReference/API_streaming_StartStreamTranscription.html) API in the *Amazon Transcribe Developer Guide*.\n\nBy default, Amazon Transcribe may use and store audio content processed by the\nservice to develop and improve Amazon Web Services AI/ML services as further\ndescribed in section 50 of the [Amazon Web Services Service\nTerms](https://aws.amazon.com/service-terms/). Using Amazon Transcribe may be\nsubject to federal and state laws or regulations regarding the recording or\ninterception of electronic communications. It is your and your end users’\nresponsibility to comply with all applicable laws regarding the recording,\nincluding properly notifying all participants in a recorded session or\ncommunication that the session or communication is being recorded, and obtaining\nall necessary consents. You can opt out from Amazon Web Services using audio\ncontent to develop and improve AWS AI/ML services by configuring an AI services\nopt out policy using Amazon Web Services Organizations.","ref":"AWS.ChimeSDKMeetings.html#start_meeting_transcription/4","title":"AWS.ChimeSDKMeetings.start_meeting_transcription/4","type":"function"},{"doc":"Stops transcription for the specified `meetingId`.\n\nFor more information, refer to [ Using Amazon Chime SDK live transcription\n](https://docs.aws.amazon.com/chime-sdk/latest/dg/meeting-transcription.html) in\nthe *Amazon Chime SDK Developer Guide*.\n\nBy default, Amazon Transcribe may use and store audio content processed by the\nservice to develop and improve Amazon Web Services AI/ML services as further\ndescribed in section 50 of the [Amazon Web Services Service Terms](https://aws.amazon.com/service-terms/). Using Amazon Transcribe may be\nsubject to federal and state laws or regulations regarding the recording or\ninterception of electronic communications. It is your and your end users’\nresponsibility to comply with all applicable laws regarding the recording,\nincluding properly notifying all participants in a recorded session or\ncommunication that the session or communication is being recorded, and obtaining\nall necessary consents. You can opt out from Amazon Web Services using audio\ncontent to develop and improve Amazon Web Services AI/ML services by configuring\nan AI services opt out policy using Amazon Web Services Organizations.","ref":"AWS.ChimeSDKMeetings.html#stop_meeting_transcription/4","title":"AWS.ChimeSDKMeetings.stop_meeting_transcription/4","type":"function"},{"doc":"The resource that supports tags.","ref":"AWS.ChimeSDKMeetings.html#tag_resource/3","title":"AWS.ChimeSDKMeetings.tag_resource/3","type":"function"},{"doc":"Removes the specified tags from the specified resources.\n\nWhen you specify a tag key, the action removes both that key and its associated\nvalue. The operation succeeds even if you attempt to remove tags from a resource\nthat were already removed. Note the following:\n\n  * To remove tags from a resource, you need the necessary permissions\nfor the service that the resource belongs to as well as permissions for removing\ntags. For more information, see the documentation for the service whose resource\nyou want to untag.\n\n  * You can only tag resources that are located in the specified\nAmazon Web Services Region for the calling Amazon Web Services account.","ref":"AWS.ChimeSDKMeetings.html#untag_resource/3","title":"AWS.ChimeSDKMeetings.untag_resource/3","type":"function"},{"doc":"In addition to the `tag:UntagResources` permission required by this operation,\nyou must also have the remove tags permission defined by the service that\ncreated the resource. For example, to remove the tags from an Amazon EC2\ninstance using the `UntagResources` operation, you must have both of the\nfollowing permissions:\n\n`tag:UntagResource`\n\n`ChimeSDKMeetings:DeleteTags`","ref":"AWS.ChimeSDKMeetings.html#untag_resource/3-minimum-permissions","title":"Minimum permissions - AWS.ChimeSDKMeetings.untag_resource/3","type":"function"},{"doc":"The capabilities that you want to update.\n\nYou use the capabilities with a set of values that control what the capabilities\ncan do, such as `SendReceive` data. For more information about those values, see\n.\n\nWhen using capabilities, be aware of these corner cases:\n\n  * If you specify `MeetingFeatures:Video:MaxResolution:None` when you\ncreate a meeting, all API requests that include `SendReceive`, `Send`, or\n`Receive` for `AttendeeCapabilities:Video` will be rejected with\n`ValidationError 400`.\n\n  * If you specify `MeetingFeatures:Content:MaxResolution:None` when\nyou create a meeting, all API requests that include `SendReceive`, `Send`, or\n`Receive` for `AttendeeCapabilities:Content` will be rejected with\n`ValidationError 400`.\n\n  * You can't set `content` capabilities to `SendReceive` or `Receive`\nunless you also set `video` capabilities to `SendReceive` or `Receive`. If you\ndon't set the `video` capability to receive, the response will contain an HTTP\n400 Bad Request status code. However, you can set your `video` capability to\nreceive and you set your `content` capability to not receive.\n\n  * When you change an `audio` capability from `None` or `Receive` to\n`Send` or `SendReceive` , and if the attendee left their microphone unmuted,\naudio will flow from the attendee to the other meeting participants.\n\n  * When you change a `video` or `content` capability from `None` or\n`Receive` to `Send` or `SendReceive` , and if the attendee turned on their video\nor content streams, remote attendees can receive those streams, but only after\nmedia renegotiation between the client and the Amazon Chime back-end server.","ref":"AWS.ChimeSDKMeetings.html#update_attendee_capabilities/5","title":"AWS.ChimeSDKMeetings.update_attendee_capabilities/5","type":"function"},{"doc":"The Amazon Chime SDK messaging APIs in this section allow software developers to\nsend and receive messages in custom messaging applications.\n\nThese APIs depend on the frameworks provided by the Amazon Chime SDK identity\nAPIs. For more information about the messaging APIs, see [Amazon Chime SDK messaging](https://docs.aws.amazon.com/chime/latest/APIReference/API_Operations_Amazon_Chime_SDK_Messaging.html).","ref":"AWS.ChimeSDKMessaging.html","title":"AWS.ChimeSDKMessaging","type":"module"},{"doc":"Associates a channel flow with a channel.\n\nOnce associated, all messages to that channel go through channel flow\nprocessors. To stop processing, use the `DisassociateChannelFlow` API.\n\nOnly administrators or channel moderators can associate a channel flow. The\n`x-amz-chime-bearer` request header is mandatory. Use the ARN of the\n`AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in\nthe header.","ref":"AWS.ChimeSDKMessaging.html#associate_channel_flow/4","title":"AWS.ChimeSDKMessaging.associate_channel_flow/4","type":"function"},{"doc":"Adds a specified number of users and bots to a channel.","ref":"AWS.ChimeSDKMessaging.html#batch_create_channel_membership/4","title":"AWS.ChimeSDKMessaging.batch_create_channel_membership/4","type":"function"},{"doc":"Calls back Amazon Chime SDK messaging with a processing response message.\n\nThis should be invoked from the processor Lambda. This is a developer API.\n\nYou can return one of the following processing responses:\n\n  * Update message content or metadata\n\n  * Deny a message\n\n  * Make no changes to the message","ref":"AWS.ChimeSDKMessaging.html#channel_flow_callback/4","title":"AWS.ChimeSDKMessaging.channel_flow_callback/4","type":"function"},{"doc":"Creates a channel to which you can add users and send messages.\n\n**Restriction**: You can't change a channel's privacy.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the ARN of the\n`AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in\nthe header.","ref":"AWS.ChimeSDKMessaging.html#create_channel/3","title":"AWS.ChimeSDKMessaging.create_channel/3","type":"function"},{"doc":"Permanently bans a member from a channel.\n\nModerators can't add banned members to a channel. To undo a ban, you first have\nto `DeleteChannelBan`, and then `CreateChannelMembership`. Bans are cleaned up\nwhen you delete users or channels.\n\nIf you ban a user who is already part of a channel, that user is automatically\nkicked from the channel.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the ARN of the\n`AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in\nthe header.","ref":"AWS.ChimeSDKMessaging.html#create_channel_ban/4","title":"AWS.ChimeSDKMessaging.create_channel_ban/4","type":"function"},{"doc":"Creates a channel flow, a container for processors.\n\nProcessors are AWS Lambda functions that perform actions on chat messages, such\nas stripping out profanity. You can associate channel flows with channels, and\nthe processors in the channel flow then take action on all messages sent to that\nchannel. This is a developer API.\n\nChannel flows process the following items:\n\n  1. New and updated messages\n\n  2. Persistent and non-persistent messages\n\n  3. The Standard message type\n\nChannel flows don't process Control or System messages. For more information\nabout the message types provided by Chime SDK messaging, refer to [Message types](https://docs.aws.amazon.com/chime/latest/dg/using-the-messaging-sdk.html#msg-types)\nin the *Amazon Chime developer guide*.","ref":"AWS.ChimeSDKMessaging.html#create_channel_flow/3","title":"AWS.ChimeSDKMessaging.create_channel_flow/3","type":"function"},{"doc":"Adds a member to a channel.\n\nThe `InvitedBy` field in `ChannelMembership` is derived from the request header.\nA channel member can:\n\n  * List messages\n\n  * Send messages\n\n  * Receive messages\n\n  * Edit their own messages\n\n  * Leave the channel\n\nPrivacy settings impact this action as follows:\n\n  * Public Channels: You do not need to be a member to list messages,\nbut you must be a member to send messages.\n\n  * Private Channels: You must be a member to list or send messages.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the ARN of the\n`AppInstanceUserArn` or `AppInstanceBot` that makes the API call as the value in\nthe header.","ref":"AWS.ChimeSDKMessaging.html#create_channel_membership/4","title":"AWS.ChimeSDKMessaging.create_channel_membership/4","type":"function"},{"doc":"Creates a new `ChannelModerator`.\n\nA channel moderator can:\n\n  * Add and remove other members of the channel.\n\n  * Add and remove other moderators of the channel.\n\n  * Add and remove user bans for the channel.\n\n  * Redact messages in the channel.\n\n  * List messages in the channel.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the ARN of the\n`AppInstanceUser` or `AppInstanceBot`of the user that makes the API call as the\nvalue in the header.","ref":"AWS.ChimeSDKMessaging.html#create_channel_moderator/4","title":"AWS.ChimeSDKMessaging.create_channel_moderator/4","type":"function"},{"doc":"Immediately makes a channel and its memberships inaccessible and marks them for\ndeletion.\n\nThis is an irreversible process.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the ARN of the\n`AppInstanceUserArn` or `AppInstanceBot` that makes the API call as the value in\nthe header.","ref":"AWS.ChimeSDKMessaging.html#delete_channel/4","title":"AWS.ChimeSDKMessaging.delete_channel/4","type":"function"},{"doc":"Removes a member from a channel's ban list.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the ARN of the\n`AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in\nthe header.","ref":"AWS.ChimeSDKMessaging.html#delete_channel_ban/5","title":"AWS.ChimeSDKMessaging.delete_channel_ban/5","type":"function"},{"doc":"Deletes a channel flow, an irreversible process.\n\nThis is a developer API.\n\nThis API works only when the channel flow is not associated with any channel. To\nget a list of all channels that a channel flow is associated with, use the\n`ListChannelsAssociatedWithChannelFlow` API. Use the `DisassociateChannelFlow`\nAPI to disassociate a channel flow from all channels.","ref":"AWS.ChimeSDKMessaging.html#delete_channel_flow/4","title":"AWS.ChimeSDKMessaging.delete_channel_flow/4","type":"function"},{"doc":"Removes a member from a channel.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the\n`AppInstanceUserArn` of the user that makes the API call as the value in the\nheader.","ref":"AWS.ChimeSDKMessaging.html#delete_channel_membership/5","title":"AWS.ChimeSDKMessaging.delete_channel_membership/5","type":"function"},{"doc":"Deletes a channel message.\n\nOnly admins can perform this action. Deletion makes messages inaccessible\nimmediately. A background process deletes any revisions created by\n`UpdateChannelMessage`.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the ARN of the\n`AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in\nthe header.","ref":"AWS.ChimeSDKMessaging.html#delete_channel_message/5","title":"AWS.ChimeSDKMessaging.delete_channel_message/5","type":"function"},{"doc":"Deletes a channel moderator.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the ARN of the\n`AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in\nthe header.","ref":"AWS.ChimeSDKMessaging.html#delete_channel_moderator/5","title":"AWS.ChimeSDKMessaging.delete_channel_moderator/5","type":"function"},{"doc":"Deletes the streaming configurations for an `AppInstance`.\n\nFor more information, see [Streaming messaging data](https://docs.aws.amazon.com/chime-sdk/latest/dg/streaming-export.html) in\nthe *Amazon Chime SDK Developer Guide*.","ref":"AWS.ChimeSDKMessaging.html#delete_messaging_streaming_configurations/4","title":"AWS.ChimeSDKMessaging.delete_messaging_streaming_configurations/4","type":"function"},{"doc":"Returns the full details of a channel in an Amazon Chime `AppInstance`.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the ARN of the\n`AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in\nthe header.","ref":"AWS.ChimeSDKMessaging.html#describe_channel/4","title":"AWS.ChimeSDKMessaging.describe_channel/4","type":"function"},{"doc":"Returns the full details of a channel ban.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the ARN of the\n`AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in\nthe header.","ref":"AWS.ChimeSDKMessaging.html#describe_channel_ban/5","title":"AWS.ChimeSDKMessaging.describe_channel_ban/5","type":"function"},{"doc":"Returns the full details of a channel flow in an Amazon Chime `AppInstance`.\n\nThis is a developer API.","ref":"AWS.ChimeSDKMessaging.html#describe_channel_flow/3","title":"AWS.ChimeSDKMessaging.describe_channel_flow/3","type":"function"},{"doc":"Returns the full details of a user's channel membership.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the ARN of the\n`AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in\nthe header.","ref":"AWS.ChimeSDKMessaging.html#describe_channel_membership/6","title":"AWS.ChimeSDKMessaging.describe_channel_membership/6","type":"function"},{"doc":"Returns the details of a channel based on the membership of the specified\n`AppInstanceUser` or `AppInstanceBot`.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the ARN of the\n`AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in\nthe header.","ref":"AWS.ChimeSDKMessaging.html#describe_channel_membership_for_app_instance_user/5","title":"AWS.ChimeSDKMessaging.describe_channel_membership_for_app_instance_user/5","type":"function"},{"doc":"Returns the full details of a channel moderated by the specified\n`AppInstanceUser` or `AppInstanceBot`.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the ARN of the\n`AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in\nthe header.","ref":"AWS.ChimeSDKMessaging.html#describe_channel_moderated_by_app_instance_user/5","title":"AWS.ChimeSDKMessaging.describe_channel_moderated_by_app_instance_user/5","type":"function"},{"doc":"Returns the full details of a single ChannelModerator.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the\n`AppInstanceUserArn` of the user that makes the API call as the value in the\nheader.","ref":"AWS.ChimeSDKMessaging.html#describe_channel_moderator/5","title":"AWS.ChimeSDKMessaging.describe_channel_moderator/5","type":"function"},{"doc":"Disassociates a channel flow from all its channels.\n\nOnce disassociated, all messages to that channel stop going through the channel\nflow processor.\n\nOnly administrators or channel moderators can disassociate a channel flow.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the ARN of the\n`AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in\nthe header.","ref":"AWS.ChimeSDKMessaging.html#disassociate_channel_flow/5","title":"AWS.ChimeSDKMessaging.disassociate_channel_flow/5","type":"function"},{"doc":"Gets the membership preferences of an `AppInstanceUser` or `AppInstanceBot` for\nthe specified channel.\n\nA user or a bot must be a member of the channel and own the membership in order\nto retrieve membership preferences. Users or bots in the `AppInstanceAdmin` and\nchannel moderator roles can't retrieve preferences for other users or bots.\nBanned users or bots can't retrieve membership preferences for the channel from\nwhich they are banned.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the ARN of the\n`AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in\nthe header.","ref":"AWS.ChimeSDKMessaging.html#get_channel_membership_preferences/5","title":"AWS.ChimeSDKMessaging.get_channel_membership_preferences/5","type":"function"},{"doc":"Gets the full details of a channel message.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the ARN of the\n`AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in\nthe header.","ref":"AWS.ChimeSDKMessaging.html#get_channel_message/6","title":"AWS.ChimeSDKMessaging.get_channel_message/6","type":"function"},{"doc":"Gets message status for a specified `messageId`.\n\nUse this API to determine the intermediate status of messages going through\nchannel flow processing. The API provides an alternative to retrieving message\nstatus if the event was not received because a client wasn't connected to a\nwebsocket.\n\nMessages can have any one of these statuses.","ref":"AWS.ChimeSDKMessaging.html#get_channel_message_status/6","title":"AWS.ChimeSDKMessaging.get_channel_message_status/6","type":"function"},{"doc":"#","ref":"AWS.ChimeSDKMessaging.html#get_channel_message_status/6-definitions","title":"Definitions - AWS.ChimeSDKMessaging.get_channel_message_status/6","type":"function"},{"doc":"Message processed successfully\n\n#","ref":"AWS.ChimeSDKMessaging.html#get_channel_message_status/6-sent","title":"SENT - AWS.ChimeSDKMessaging.get_channel_message_status/6","type":"function"},{"doc":"Ongoing processing\n\n#","ref":"AWS.ChimeSDKMessaging.html#get_channel_message_status/6-pending","title":"PENDING - AWS.ChimeSDKMessaging.get_channel_message_status/6","type":"function"},{"doc":"Processing failed\n\n#","ref":"AWS.ChimeSDKMessaging.html#get_channel_message_status/6-failed","title":"FAILED - AWS.ChimeSDKMessaging.get_channel_message_status/6","type":"function"},{"doc":"Message denied by the processor\n\n   This API does not return statuses for denied messages, because we\ndon't store them once the processor denies them.\n\n   Only the message sender can invoke this API.\n\n   The `x-amz-chime-bearer` request header is mandatory. Use the ARN\nof the `AppInstanceUser` or `AppInstanceBot` that makes the API call as the\nvalue in the header.","ref":"AWS.ChimeSDKMessaging.html#get_channel_message_status/6-denied","title":"DENIED - AWS.ChimeSDKMessaging.get_channel_message_status/6","type":"function"},{"doc":"The details of the endpoint for the messaging session.","ref":"AWS.ChimeSDKMessaging.html#get_messaging_session_endpoint/2","title":"AWS.ChimeSDKMessaging.get_messaging_session_endpoint/2","type":"function"},{"doc":"Retrieves the data streaming configuration for an `AppInstance`.\n\nFor more information, see [Streaming messaging data](https://docs.aws.amazon.com/chime-sdk/latest/dg/streaming-export.html) in\nthe *Amazon Chime SDK Developer Guide*.","ref":"AWS.ChimeSDKMessaging.html#get_messaging_streaming_configurations/3","title":"AWS.ChimeSDKMessaging.get_messaging_streaming_configurations/3","type":"function"},{"doc":"Lists all the users and bots banned from a particular channel.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the ARN of the\n`AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in\nthe header.","ref":"AWS.ChimeSDKMessaging.html#list_channel_bans/6","title":"AWS.ChimeSDKMessaging.list_channel_bans/6","type":"function"},{"doc":"Returns a paginated lists of all the channel flows created under a single Chime.\n\nThis is a developer API.","ref":"AWS.ChimeSDKMessaging.html#list_channel_flows/5","title":"AWS.ChimeSDKMessaging.list_channel_flows/5","type":"function"},{"doc":"Lists all channel memberships in a channel.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the ARN of the\n`AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in\nthe header.\n\nIf you want to list the channels to which a specific app instance user belongs,\nsee the\n[ListChannelMembershipsForAppInstanceUser](https://docs.aws.amazon.com/chime/latest/APIReference/API_messaging-chime_ListChannelMembershipsForAppInstanceUser.html)\nAPI.","ref":"AWS.ChimeSDKMessaging.html#list_channel_memberships/8","title":"AWS.ChimeSDKMessaging.list_channel_memberships/8","type":"function"},{"doc":"Lists all channels that an `AppInstanceUser` or `AppInstanceBot` is a part of.\n\nOnly an `AppInstanceAdmin` can call the API with a user ARN that is not their\nown.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the ARN of the\n`AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in\nthe header.","ref":"AWS.ChimeSDKMessaging.html#list_channel_memberships_for_app_instance_user/6","title":"AWS.ChimeSDKMessaging.list_channel_memberships_for_app_instance_user/6","type":"function"},{"doc":"List all the messages in a channel.\n\nReturns a paginated list of `ChannelMessages`. By default, sorted by creation\ntimestamp in descending order.\n\nRedacted messages appear in the results as empty, since they are only redacted,\nnot deleted. Deleted messages do not appear in the results. This action always\nreturns the latest version of an edited message.\n\nAlso, the `x-amz-chime-bearer` request header is mandatory. Use the ARN of the\n`AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in\nthe header.","ref":"AWS.ChimeSDKMessaging.html#list_channel_messages/10","title":"AWS.ChimeSDKMessaging.list_channel_messages/10","type":"function"},{"doc":"Lists all the moderators for a channel.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the ARN of the\n`AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in\nthe header.","ref":"AWS.ChimeSDKMessaging.html#list_channel_moderators/6","title":"AWS.ChimeSDKMessaging.list_channel_moderators/6","type":"function"},{"doc":"Lists all Channels created under a single Chime App as a paginated list.\n\nYou can specify filters to narrow results.","ref":"AWS.ChimeSDKMessaging.html#list_channels/7","title":"AWS.ChimeSDKMessaging.list_channels/7","type":"function"},{"doc":"* Use privacy = `PUBLIC` to retrieve all public channels in the\naccount.\n\n  * Only an `AppInstanceAdmin` can set privacy = `PRIVATE` to list the\nprivate channels in an account.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the ARN of the\n`AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in\nthe header.","ref":"AWS.ChimeSDKMessaging.html#list_channels/7-functionality-restrictions","title":"Functionality & restrictions - AWS.ChimeSDKMessaging.list_channels/7","type":"function"},{"doc":"Lists all channels associated with a specified channel flow.\n\nYou can associate a channel flow with multiple channels, but you can only\nassociate a channel with one channel flow. This is a developer API.","ref":"AWS.ChimeSDKMessaging.html#list_channels_associated_with_channel_flow/5","title":"AWS.ChimeSDKMessaging.list_channels_associated_with_channel_flow/5","type":"function"},{"doc":"A list of the channels moderated by an `AppInstanceUser`.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the ARN of the\n`AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in\nthe header.","ref":"AWS.ChimeSDKMessaging.html#list_channels_moderated_by_app_instance_user/6","title":"AWS.ChimeSDKMessaging.list_channels_moderated_by_app_instance_user/6","type":"function"},{"doc":"Lists all the SubChannels in an elastic channel when given a channel ID.\n\nAvailable only to the app instance admins and channel moderators of elastic\nchannels.","ref":"AWS.ChimeSDKMessaging.html#list_sub_channels/6","title":"AWS.ChimeSDKMessaging.list_sub_channels/6","type":"function"},{"doc":"Lists the tags applied to an Amazon Chime SDK messaging resource.","ref":"AWS.ChimeSDKMessaging.html#list_tags_for_resource/3","title":"AWS.ChimeSDKMessaging.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.ChimeSDKMessaging.html#metadata/0","title":"AWS.ChimeSDKMessaging.metadata/0","type":"function"},{"doc":"Sets the number of days before the channel is automatically deleted.\n\n   A background process deletes expired channels within 6 hours of\nexpiration. Actual deletion times may vary.\n\n   Expired channels that have not yet been deleted appear as active,\nand you can update their expiration settings. The system honors the new\nsettings.\n\n   The `x-amz-chime-bearer` request header is mandatory. Use the ARN\nof the `AppInstanceUser` or `AppInstanceBot` that makes the API call as the\nvalue in the header.","ref":"AWS.ChimeSDKMessaging.html#put_channel_expiration_settings/4","title":"AWS.ChimeSDKMessaging.put_channel_expiration_settings/4","type":"function"},{"doc":"Sets the membership preferences of an `AppInstanceUser` or `AppInstanceBot` for\nthe specified channel.\n\nThe user or bot must be a member of the channel. Only the user or bot who owns\nthe membership can set preferences. Users or bots in the `AppInstanceAdmin` and\nchannel moderator roles can't set preferences for other users. Banned users or\nbots can't set membership preferences for the channel from which they are\nbanned.\n\nThe x-amz-chime-bearer request header is mandatory. Use the ARN of an\n`AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in\nthe header.","ref":"AWS.ChimeSDKMessaging.html#put_channel_membership_preferences/5","title":"AWS.ChimeSDKMessaging.put_channel_membership_preferences/5","type":"function"},{"doc":"Sets the data streaming configuration for an `AppInstance`.\n\nFor more information, see [Streaming messaging data](https://docs.aws.amazon.com/chime-sdk/latest/dg/streaming-export.html) in\nthe *Amazon Chime SDK Developer Guide*.","ref":"AWS.ChimeSDKMessaging.html#put_messaging_streaming_configurations/4","title":"AWS.ChimeSDKMessaging.put_messaging_streaming_configurations/4","type":"function"},{"doc":"Redacts message content, but not metadata.\n\nThe message exists in the back end, but the action returns null content, and the\nstate shows as redacted.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the ARN of the\n`AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in\nthe header.","ref":"AWS.ChimeSDKMessaging.html#redact_channel_message/5","title":"AWS.ChimeSDKMessaging.redact_channel_message/5","type":"function"},{"doc":"Allows the `ChimeBearer` to search channels by channel members.\n\nUsers or bots can search across the channels that they belong to. Users in the\n`AppInstanceAdmin` role can search across all channels.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the ARN of the\n`AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in\nthe header.","ref":"AWS.ChimeSDKMessaging.html#search_channels/3","title":"AWS.ChimeSDKMessaging.search_channels/3","type":"function"},{"doc":"Sends a message to a particular channel that the member is a part of.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the ARN of the\n`AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in\nthe header.\n\nAlso, `STANDARD` messages can be up to 4KB in size and contain metadata.\nMetadata is arbitrary, and you can use it in a variety of ways, such as\ncontaining a link to an attachment.\n\n`CONTROL` messages are limited to 30 bytes and do not contain metadata.","ref":"AWS.ChimeSDKMessaging.html#send_channel_message/4","title":"AWS.ChimeSDKMessaging.send_channel_message/4","type":"function"},{"doc":"Applies the specified tags to the specified Amazon Chime SDK messaging resource.","ref":"AWS.ChimeSDKMessaging.html#tag_resource/3","title":"AWS.ChimeSDKMessaging.tag_resource/3","type":"function"},{"doc":"Removes the specified tags from the specified Amazon Chime SDK messaging\nresource.","ref":"AWS.ChimeSDKMessaging.html#untag_resource/3","title":"AWS.ChimeSDKMessaging.untag_resource/3","type":"function"},{"doc":"Update a channel's attributes.\n\n**Restriction**: You can't change a channel's privacy.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the ARN of the\n`AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in\nthe header.","ref":"AWS.ChimeSDKMessaging.html#update_channel/4","title":"AWS.ChimeSDKMessaging.update_channel/4","type":"function"},{"doc":"Updates channel flow attributes.\n\nThis is a developer API.","ref":"AWS.ChimeSDKMessaging.html#update_channel_flow/4","title":"AWS.ChimeSDKMessaging.update_channel_flow/4","type":"function"},{"doc":"Updates the content of a message.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the ARN of the\n`AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in\nthe header.","ref":"AWS.ChimeSDKMessaging.html#update_channel_message/5","title":"AWS.ChimeSDKMessaging.update_channel_message/5","type":"function"},{"doc":"The details of the time when a user last read messages in a channel.\n\nThe `x-amz-chime-bearer` request header is mandatory. Use the ARN of the\n`AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in\nthe header.","ref":"AWS.ChimeSDKMessaging.html#update_channel_read_marker/4","title":"AWS.ChimeSDKMessaging.update_channel_read_marker/4","type":"function"},{"doc":"The Amazon Chime SDK telephony APIs in this section enable developers to create\nPSTN calling solutions that use Amazon Chime SDK Voice Connectors, and Amazon\nChime SDK SIP media applications.\n\nDevelopers can also order and manage phone numbers, create and manage Voice\nConnectors and SIP media applications, and run voice analytics.","ref":"AWS.ChimeSDKVoice.html","title":"AWS.ChimeSDKVoice","type":"module"},{"doc":"Associates phone numbers with the specified Amazon Chime SDK Voice Connector.","ref":"AWS.ChimeSDKVoice.html#associate_phone_numbers_with_voice_connector/4","title":"AWS.ChimeSDKVoice.associate_phone_numbers_with_voice_connector/4","type":"function"},{"doc":"Associates phone numbers with the specified Amazon Chime SDK Voice Connector\ngroup.","ref":"AWS.ChimeSDKVoice.html#associate_phone_numbers_with_voice_connector_group/4","title":"AWS.ChimeSDKVoice.associate_phone_numbers_with_voice_connector_group/4","type":"function"},{"doc":"Moves phone numbers into the **Deletion queue**.\n\nPhone numbers must be disassociated from any users or Amazon Chime SDK Voice\nConnectors before they can be deleted.\n\nPhone numbers remain in the **Deletion queue** for 7 days before they are\ndeleted permanently.","ref":"AWS.ChimeSDKVoice.html#batch_delete_phone_number/3","title":"AWS.ChimeSDKVoice.batch_delete_phone_number/3","type":"function"},{"doc":"Updates one or more phone numbers.","ref":"AWS.ChimeSDKVoice.html#batch_update_phone_number/3","title":"AWS.ChimeSDKVoice.batch_update_phone_number/3","type":"function"},{"doc":"Creates an order for phone numbers to be provisioned.\n\nFor numbers outside the U.S., you must use the Amazon Chime SDK SIP media\napplication dial-in product type.","ref":"AWS.ChimeSDKVoice.html#create_phone_number_order/3","title":"AWS.ChimeSDKVoice.create_phone_number_order/3","type":"function"},{"doc":"Creates a proxy session for the specified Amazon Chime SDK Voice Connector for\nthe specified participant phone numbers.","ref":"AWS.ChimeSDKVoice.html#create_proxy_session/4","title":"AWS.ChimeSDKVoice.create_proxy_session/4","type":"function"},{"doc":"Creates a SIP media application.\n\nFor more information about SIP media applications, see [Managing SIP media applications and\nrules](https://docs.aws.amazon.com/chime-sdk/latest/ag/manage-sip-applications.html)\nin the *Amazon Chime SDK Administrator Guide*.","ref":"AWS.ChimeSDKVoice.html#create_sip_media_application/3","title":"AWS.ChimeSDKVoice.create_sip_media_application/3","type":"function"},{"doc":"Creates an outbound call to a phone number from the phone number specified in\nthe request, and it invokes the endpoint of the specified\n`sipMediaApplicationId`.","ref":"AWS.ChimeSDKVoice.html#create_sip_media_application_call/4","title":"AWS.ChimeSDKVoice.create_sip_media_application_call/4","type":"function"},{"doc":"Creates a SIP rule, which can be used to run a SIP media application as a target\nfor a specific trigger type.\n\nFor more information about SIP rules, see [Managing SIP media applications and rules](https://docs.aws.amazon.com/chime-sdk/latest/ag/manage-sip-applications.html)\nin the *Amazon Chime SDK Administrator Guide*.","ref":"AWS.ChimeSDKVoice.html#create_sip_rule/3","title":"AWS.ChimeSDKVoice.create_sip_rule/3","type":"function"},{"doc":"Creates an Amazon Chime SDK Voice Connector.\n\nFor more information about Voice Connectors, see [Managing Amazon Chime SDK Voice Connector\ngroups](https://docs.aws.amazon.com/chime-sdk/latest/ag/voice-connector-groups.html)\nin the *Amazon Chime SDK Administrator Guide*.","ref":"AWS.ChimeSDKVoice.html#create_voice_connector/3","title":"AWS.ChimeSDKVoice.create_voice_connector/3","type":"function"},{"doc":"Creates an Amazon Chime SDK Voice Connector group under the administrator's AWS\naccount.\n\nYou can associate Amazon Chime SDK Voice Connectors with the Voice Connector\ngroup by including `VoiceConnectorItems` in the request.\n\nYou can include Voice Connectors from different AWS Regions in your group. This\ncreates a fault tolerant mechanism for fallback in case of availability events.","ref":"AWS.ChimeSDKVoice.html#create_voice_connector_group/3","title":"AWS.ChimeSDKVoice.create_voice_connector_group/3","type":"function"},{"doc":"Creates a voice profile, which consists of an enrolled user and their latest\nvoice print.\n\nBefore creating any voice profiles, you must provide all notices and obtain all\nconsents from the speaker as required under applicable privacy and biometrics\nlaws, and as required under the [AWS service terms](https://aws.amazon.com/service-terms/) for the Amazon Chime SDK.\n\nFor more information about voice profiles and voice analytics, see [Using Amazon Chime SDK Voice\nAnalytics](https://docs.aws.amazon.com/chime-sdk/latest/dg/pstn-voice-analytics.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.ChimeSDKVoice.html#create_voice_profile/3","title":"AWS.ChimeSDKVoice.create_voice_profile/3","type":"function"},{"doc":"Creates a voice profile domain, a collection of voice profiles, their voice\nprints, and encrypted enrollment audio.\n\nBefore creating any voice profiles, you must provide all notices and obtain all\nconsents from the speaker as required under applicable privacy and biometrics\nlaws, and as required under the [AWS service terms](https://aws.amazon.com/service-terms/) for the Amazon Chime SDK.\n\nFor more information about voice profile domains, see [Using Amazon Chime SDK Voice\nAnalytics](https://docs.aws.amazon.com/chime-sdk/latest/dg/pstn-voice-analytics.html)\nin the *Amazon Chime SDK Developer Guide*.","ref":"AWS.ChimeSDKVoice.html#create_voice_profile_domain/3","title":"AWS.ChimeSDKVoice.create_voice_profile_domain/3","type":"function"},{"doc":"Moves the specified phone number into the **Deletion queue**.\n\nA phone number must be disassociated from any users or Amazon Chime SDK Voice\nConnectors before it can be deleted.\n\nDeleted phone numbers remain in the **Deletion queue** queue for 7 days before\nthey are deleted permanently.","ref":"AWS.ChimeSDKVoice.html#delete_phone_number/4","title":"AWS.ChimeSDKVoice.delete_phone_number/4","type":"function"},{"doc":"Deletes the specified proxy session from the specified Amazon Chime SDK Voice\nConnector.","ref":"AWS.ChimeSDKVoice.html#delete_proxy_session/5","title":"AWS.ChimeSDKVoice.delete_proxy_session/5","type":"function"},{"doc":"Deletes a SIP media application.","ref":"AWS.ChimeSDKVoice.html#delete_sip_media_application/4","title":"AWS.ChimeSDKVoice.delete_sip_media_application/4","type":"function"},{"doc":"Deletes a SIP rule.","ref":"AWS.ChimeSDKVoice.html#delete_sip_rule/4","title":"AWS.ChimeSDKVoice.delete_sip_rule/4","type":"function"},{"doc":"Deletes an Amazon Chime SDK Voice Connector.\n\nAny phone numbers associated with the Amazon Chime SDK Voice Connector must be\ndisassociated from it before it can be deleted.","ref":"AWS.ChimeSDKVoice.html#delete_voice_connector/4","title":"AWS.ChimeSDKVoice.delete_voice_connector/4","type":"function"},{"doc":"Deletes the emergency calling details from the specified Amazon Chime SDK Voice\nConnector.","ref":"AWS.ChimeSDKVoice.html#delete_voice_connector_emergency_calling_configuration/4","title":"AWS.ChimeSDKVoice.delete_voice_connector_emergency_calling_configuration/4","type":"function"},{"doc":"Deletes an Amazon Chime SDK Voice Connector group.\n\nAny `VoiceConnectorItems` and phone numbers associated with the group must be\nremoved before it can be deleted.","ref":"AWS.ChimeSDKVoice.html#delete_voice_connector_group/4","title":"AWS.ChimeSDKVoice.delete_voice_connector_group/4","type":"function"},{"doc":"Deletes the origination settings for the specified Amazon Chime SDK Voice\nConnector.\n\nIf emergency calling is configured for the Voice Connector, it must be deleted\nprior to deleting the origination settings.","ref":"AWS.ChimeSDKVoice.html#delete_voice_connector_origination/4","title":"AWS.ChimeSDKVoice.delete_voice_connector_origination/4","type":"function"},{"doc":"Deletes the proxy configuration from the specified Amazon Chime SDK Voice\nConnector.","ref":"AWS.ChimeSDKVoice.html#delete_voice_connector_proxy/4","title":"AWS.ChimeSDKVoice.delete_voice_connector_proxy/4","type":"function"},{"doc":"Deletes a Voice Connector's streaming configuration.","ref":"AWS.ChimeSDKVoice.html#delete_voice_connector_streaming_configuration/4","title":"AWS.ChimeSDKVoice.delete_voice_connector_streaming_configuration/4","type":"function"},{"doc":"Deletes the termination settings for the specified Amazon Chime SDK Voice\nConnector.\n\nIf emergency calling is configured for the Voice Connector, it must be deleted\nprior to deleting the termination settings.","ref":"AWS.ChimeSDKVoice.html#delete_voice_connector_termination/4","title":"AWS.ChimeSDKVoice.delete_voice_connector_termination/4","type":"function"},{"doc":"Deletes the specified SIP credentials used by your equipment to authenticate\nduring call termination.","ref":"AWS.ChimeSDKVoice.html#delete_voice_connector_termination_credentials/4","title":"AWS.ChimeSDKVoice.delete_voice_connector_termination_credentials/4","type":"function"},{"doc":"Deletes a voice profile, including its voice print and enrollment data.\n\nWARNING: This action is not reversible.","ref":"AWS.ChimeSDKVoice.html#delete_voice_profile/4","title":"AWS.ChimeSDKVoice.delete_voice_profile/4","type":"function"},{"doc":"Deletes all voice profiles in the domain.\n\nWARNING: This action is not reversible.","ref":"AWS.ChimeSDKVoice.html#delete_voice_profile_domain/4","title":"AWS.ChimeSDKVoice.delete_voice_profile_domain/4","type":"function"},{"doc":"Disassociates the specified phone numbers from the specified Amazon Chime SDK\nVoice Connector.","ref":"AWS.ChimeSDKVoice.html#disassociate_phone_numbers_from_voice_connector/4","title":"AWS.ChimeSDKVoice.disassociate_phone_numbers_from_voice_connector/4","type":"function"},{"doc":"Disassociates the specified phone numbers from the specified Amazon Chime SDK\nVoice Connector group.","ref":"AWS.ChimeSDKVoice.html#disassociate_phone_numbers_from_voice_connector_group/4","title":"AWS.ChimeSDKVoice.disassociate_phone_numbers_from_voice_connector_group/4","type":"function"},{"doc":"Retrieves the global settings for the Amazon Chime SDK Voice Connectors in an\nAWS account.","ref":"AWS.ChimeSDKVoice.html#get_global_settings/2","title":"AWS.ChimeSDKVoice.get_global_settings/2","type":"function"},{"doc":"Retrieves details for the specified phone number ID, such as associations,\ncapabilities, and product type.","ref":"AWS.ChimeSDKVoice.html#get_phone_number/3","title":"AWS.ChimeSDKVoice.get_phone_number/3","type":"function"},{"doc":"Retrieves details for the specified phone number order, such as the order\ncreation timestamp, phone numbers in E.164 format, product type, and order\nstatus.","ref":"AWS.ChimeSDKVoice.html#get_phone_number_order/3","title":"AWS.ChimeSDKVoice.get_phone_number_order/3","type":"function"},{"doc":"Retrieves the phone number settings for the administrator's AWS account, such as\nthe default outbound calling name.","ref":"AWS.ChimeSDKVoice.html#get_phone_number_settings/2","title":"AWS.ChimeSDKVoice.get_phone_number_settings/2","type":"function"},{"doc":"Retrieves the specified proxy session details for the specified Amazon Chime SDK\nVoice Connector.","ref":"AWS.ChimeSDKVoice.html#get_proxy_session/4","title":"AWS.ChimeSDKVoice.get_proxy_session/4","type":"function"},{"doc":"Retrieves the information for a SIP media application, including name, AWS\nRegion, and endpoints.","ref":"AWS.ChimeSDKVoice.html#get_sip_media_application/3","title":"AWS.ChimeSDKVoice.get_sip_media_application/3","type":"function"},{"doc":"Gets the Alexa Skill configuration for the SIP media application.","ref":"AWS.ChimeSDKVoice.html#get_sip_media_application_alexa_skill_configuration/3","title":"AWS.ChimeSDKVoice.get_sip_media_application_alexa_skill_configuration/3","type":"function"},{"doc":"Retrieves the logging configuration for the specified SIP media application.","ref":"AWS.ChimeSDKVoice.html#get_sip_media_application_logging_configuration/3","title":"AWS.ChimeSDKVoice.get_sip_media_application_logging_configuration/3","type":"function"},{"doc":"Retrieves the details of a SIP rule, such as the rule ID, name, triggers, and\ntarget endpoints.","ref":"AWS.ChimeSDKVoice.html#get_sip_rule/3","title":"AWS.ChimeSDKVoice.get_sip_rule/3","type":"function"},{"doc":"Retrieves the details of the specified speaker search task.","ref":"AWS.ChimeSDKVoice.html#get_speaker_search_task/4","title":"AWS.ChimeSDKVoice.get_speaker_search_task/4","type":"function"},{"doc":"Retrieves details for the specified Amazon Chime SDK Voice Connector, such as\ntimestamps,name, outbound host, and encryption requirements.","ref":"AWS.ChimeSDKVoice.html#get_voice_connector/3","title":"AWS.ChimeSDKVoice.get_voice_connector/3","type":"function"},{"doc":"Retrieves the emergency calling configuration details for the specified Voice\nConnector.","ref":"AWS.ChimeSDKVoice.html#get_voice_connector_emergency_calling_configuration/3","title":"AWS.ChimeSDKVoice.get_voice_connector_emergency_calling_configuration/3","type":"function"},{"doc":"Retrieves details for the specified Amazon Chime SDK Voice Connector group, such\nas timestamps,name, and associated `VoiceConnectorItems`.","ref":"AWS.ChimeSDKVoice.html#get_voice_connector_group/3","title":"AWS.ChimeSDKVoice.get_voice_connector_group/3","type":"function"},{"doc":"Retrieves the logging configuration settings for the specified Voice Connector.\n\nShows whether SIP message logs are enabled for sending to Amazon CloudWatch\nLogs.","ref":"AWS.ChimeSDKVoice.html#get_voice_connector_logging_configuration/3","title":"AWS.ChimeSDKVoice.get_voice_connector_logging_configuration/3","type":"function"},{"doc":"Retrieves the origination settings for the specified Voice Connector.","ref":"AWS.ChimeSDKVoice.html#get_voice_connector_origination/3","title":"AWS.ChimeSDKVoice.get_voice_connector_origination/3","type":"function"},{"doc":"Retrieves the proxy configuration details for the specified Amazon Chime SDK\nVoice Connector.","ref":"AWS.ChimeSDKVoice.html#get_voice_connector_proxy/3","title":"AWS.ChimeSDKVoice.get_voice_connector_proxy/3","type":"function"},{"doc":"Retrieves the streaming configuration details for the specified Amazon Chime SDK\nVoice Connector.\n\nShows whether media streaming is enabled for sending to Amazon Kinesis. It also\nshows the retention period, in hours, for the Amazon Kinesis data.","ref":"AWS.ChimeSDKVoice.html#get_voice_connector_streaming_configuration/3","title":"AWS.ChimeSDKVoice.get_voice_connector_streaming_configuration/3","type":"function"},{"doc":"Retrieves the termination setting details for the specified Voice Connector.","ref":"AWS.ChimeSDKVoice.html#get_voice_connector_termination/3","title":"AWS.ChimeSDKVoice.get_voice_connector_termination/3","type":"function"},{"doc":"Retrieves information about the last time a `SIP OPTIONS` ping was received from\nyour SIP infrastructure for the specified Amazon Chime SDK Voice Connector.","ref":"AWS.ChimeSDKVoice.html#get_voice_connector_termination_health/3","title":"AWS.ChimeSDKVoice.get_voice_connector_termination_health/3","type":"function"},{"doc":"Retrieves the details of the specified voice profile.","ref":"AWS.ChimeSDKVoice.html#get_voice_profile/3","title":"AWS.ChimeSDKVoice.get_voice_profile/3","type":"function"},{"doc":"Retrieves the details of the specified voice profile domain.","ref":"AWS.ChimeSDKVoice.html#get_voice_profile_domain/3","title":"AWS.ChimeSDKVoice.get_voice_profile_domain/3","type":"function"},{"doc":"Retrieves the details of a voice tone analysis task.","ref":"AWS.ChimeSDKVoice.html#get_voice_tone_analysis_task/5","title":"AWS.ChimeSDKVoice.get_voice_tone_analysis_task/5","type":"function"},{"doc":"Lists the available AWS Regions in which you can create an Amazon Chime SDK\nVoice Connector.","ref":"AWS.ChimeSDKVoice.html#list_available_voice_connector_regions/2","title":"AWS.ChimeSDKVoice.list_available_voice_connector_regions/2","type":"function"},{"doc":"Lists the phone numbers for an administrator's Amazon Chime SDK account.","ref":"AWS.ChimeSDKVoice.html#list_phone_number_orders/4","title":"AWS.ChimeSDKVoice.list_phone_number_orders/4","type":"function"},{"doc":"Lists the phone numbers for the specified Amazon Chime SDK account, Amazon Chime\nSDK user, Amazon Chime SDK Voice Connector, or Amazon Chime SDK Voice Connector\ngroup.","ref":"AWS.ChimeSDKVoice.html#list_phone_numbers/8","title":"AWS.ChimeSDKVoice.list_phone_numbers/8","type":"function"},{"doc":"Lists the proxy sessions for the specified Amazon Chime SDK Voice Connector.","ref":"AWS.ChimeSDKVoice.html#list_proxy_sessions/6","title":"AWS.ChimeSDKVoice.list_proxy_sessions/6","type":"function"},{"doc":"Lists the SIP media applications under the administrator's AWS account.","ref":"AWS.ChimeSDKVoice.html#list_sip_media_applications/4","title":"AWS.ChimeSDKVoice.list_sip_media_applications/4","type":"function"},{"doc":"Lists the SIP rules under the administrator's AWS account.","ref":"AWS.ChimeSDKVoice.html#list_sip_rules/5","title":"AWS.ChimeSDKVoice.list_sip_rules/5","type":"function"},{"doc":"Lists the countries that you can order phone numbers from.","ref":"AWS.ChimeSDKVoice.html#list_supported_phone_number_countries/3","title":"AWS.ChimeSDKVoice.list_supported_phone_number_countries/3","type":"function"},{"doc":"Returns a list of the tags in a given resource.","ref":"AWS.ChimeSDKVoice.html#list_tags_for_resource/3","title":"AWS.ChimeSDKVoice.list_tags_for_resource/3","type":"function"},{"doc":"Lists the Amazon Chime SDK Voice Connector groups in the administrator's AWS\naccount.","ref":"AWS.ChimeSDKVoice.html#list_voice_connector_groups/4","title":"AWS.ChimeSDKVoice.list_voice_connector_groups/4","type":"function"},{"doc":"Lists the SIP credentials for the specified Amazon Chime SDK Voice Connector.","ref":"AWS.ChimeSDKVoice.html#list_voice_connector_termination_credentials/3","title":"AWS.ChimeSDKVoice.list_voice_connector_termination_credentials/3","type":"function"},{"doc":"Lists the Amazon Chime SDK Voice Connectors in the administrators AWS account.","ref":"AWS.ChimeSDKVoice.html#list_voice_connectors/4","title":"AWS.ChimeSDKVoice.list_voice_connectors/4","type":"function"},{"doc":"Lists the specified voice profile domains in the administrator's AWS account.","ref":"AWS.ChimeSDKVoice.html#list_voice_profile_domains/4","title":"AWS.ChimeSDKVoice.list_voice_profile_domains/4","type":"function"},{"doc":"Lists the voice profiles in a voice profile domain.","ref":"AWS.ChimeSDKVoice.html#list_voice_profiles/5","title":"AWS.ChimeSDKVoice.list_voice_profiles/5","type":"function"},{"doc":"","ref":"AWS.ChimeSDKVoice.html#metadata/0","title":"AWS.ChimeSDKVoice.metadata/0","type":"function"},{"doc":"Updates the Alexa Skill configuration for the SIP media application.","ref":"AWS.ChimeSDKVoice.html#put_sip_media_application_alexa_skill_configuration/4","title":"AWS.ChimeSDKVoice.put_sip_media_application_alexa_skill_configuration/4","type":"function"},{"doc":"Updates the logging configuration for the specified SIP media application.","ref":"AWS.ChimeSDKVoice.html#put_sip_media_application_logging_configuration/4","title":"AWS.ChimeSDKVoice.put_sip_media_application_logging_configuration/4","type":"function"},{"doc":"Updates a Voice Connector's emergency calling configuration.","ref":"AWS.ChimeSDKVoice.html#put_voice_connector_emergency_calling_configuration/4","title":"AWS.ChimeSDKVoice.put_voice_connector_emergency_calling_configuration/4","type":"function"},{"doc":"Updates a Voice Connector's logging configuration.","ref":"AWS.ChimeSDKVoice.html#put_voice_connector_logging_configuration/4","title":"AWS.ChimeSDKVoice.put_voice_connector_logging_configuration/4","type":"function"},{"doc":"Updates a Voice Connector's origination settings.","ref":"AWS.ChimeSDKVoice.html#put_voice_connector_origination/4","title":"AWS.ChimeSDKVoice.put_voice_connector_origination/4","type":"function"},{"doc":"Puts the specified proxy configuration to the specified Amazon Chime SDK Voice\nConnector.","ref":"AWS.ChimeSDKVoice.html#put_voice_connector_proxy/4","title":"AWS.ChimeSDKVoice.put_voice_connector_proxy/4","type":"function"},{"doc":"Updates a Voice Connector's streaming configuration settings.","ref":"AWS.ChimeSDKVoice.html#put_voice_connector_streaming_configuration/4","title":"AWS.ChimeSDKVoice.put_voice_connector_streaming_configuration/4","type":"function"},{"doc":"Updates a Voice Connector's termination settings.","ref":"AWS.ChimeSDKVoice.html#put_voice_connector_termination/4","title":"AWS.ChimeSDKVoice.put_voice_connector_termination/4","type":"function"},{"doc":"Updates a Voice Connector's termination credentials.","ref":"AWS.ChimeSDKVoice.html#put_voice_connector_termination_credentials/4","title":"AWS.ChimeSDKVoice.put_voice_connector_termination_credentials/4","type":"function"},{"doc":"Restores a deleted phone number.","ref":"AWS.ChimeSDKVoice.html#restore_phone_number/4","title":"AWS.ChimeSDKVoice.restore_phone_number/4","type":"function"},{"doc":"Searches the provisioned phone numbers in an organization.","ref":"AWS.ChimeSDKVoice.html#search_available_phone_numbers/10","title":"AWS.ChimeSDKVoice.search_available_phone_numbers/10","type":"function"},{"doc":"Starts a speaker search task.\n\nBefore starting any speaker search tasks, you must provide all notices and\nobtain all consents from the speaker as required under applicable privacy and\nbiometrics laws, and as required under the [AWS service terms](https://aws.amazon.com/service-terms/) for the Amazon Chime SDK.","ref":"AWS.ChimeSDKVoice.html#start_speaker_search_task/4","title":"AWS.ChimeSDKVoice.start_speaker_search_task/4","type":"function"},{"doc":"Starts a voice tone analysis task.\n\nFor more information about voice tone analysis, see [Using Amazon Chime SDK voice\nanalytics](https://docs.aws.amazon.com/chime-sdk/latest/dg/pstn-voice-analytics.html)\nin the *Amazon Chime SDK Developer Guide*.\n\nBefore starting any voice tone analysis tasks, you must provide all notices and\nobtain all consents from the speaker as required under applicable privacy and\nbiometrics laws, and as required under the [AWS service terms](https://aws.amazon.com/service-terms/) for the Amazon Chime SDK.","ref":"AWS.ChimeSDKVoice.html#start_voice_tone_analysis_task/4","title":"AWS.ChimeSDKVoice.start_voice_tone_analysis_task/4","type":"function"},{"doc":"Stops a speaker search task.","ref":"AWS.ChimeSDKVoice.html#stop_speaker_search_task/5","title":"AWS.ChimeSDKVoice.stop_speaker_search_task/5","type":"function"},{"doc":"Stops a voice tone analysis task.","ref":"AWS.ChimeSDKVoice.html#stop_voice_tone_analysis_task/5","title":"AWS.ChimeSDKVoice.stop_voice_tone_analysis_task/5","type":"function"},{"doc":"Adds a tag to the specified resource.","ref":"AWS.ChimeSDKVoice.html#tag_resource/3","title":"AWS.ChimeSDKVoice.tag_resource/3","type":"function"},{"doc":"Removes tags from a resource.","ref":"AWS.ChimeSDKVoice.html#untag_resource/3","title":"AWS.ChimeSDKVoice.untag_resource/3","type":"function"},{"doc":"Updates global settings for the Amazon Chime SDK Voice Connectors in an AWS\naccount.","ref":"AWS.ChimeSDKVoice.html#update_global_settings/3","title":"AWS.ChimeSDKVoice.update_global_settings/3","type":"function"},{"doc":"Updates phone number details, such as product type or calling name, for the\nspecified phone number ID.\n\nYou can update one phone number detail at a time. For example, you can update\neither the product type or the calling name in one action.\n\nFor numbers outside the U.S., you must use the Amazon Chime SDK SIP Media\nApplication Dial-In product type.\n\nUpdates to outbound calling names can take 72 hours to complete. Pending updates\nto outbound calling names must be complete before you can request another\nupdate.","ref":"AWS.ChimeSDKVoice.html#update_phone_number/4","title":"AWS.ChimeSDKVoice.update_phone_number/4","type":"function"},{"doc":"Updates the phone number settings for the administrator's AWS account, such as\nthe default outbound calling name.\n\nYou can update the default outbound calling name once every seven days. Outbound\ncalling names can take up to 72 hours to update.","ref":"AWS.ChimeSDKVoice.html#update_phone_number_settings/3","title":"AWS.ChimeSDKVoice.update_phone_number_settings/3","type":"function"},{"doc":"Updates the specified proxy session details, such as voice or SMS capabilities.","ref":"AWS.ChimeSDKVoice.html#update_proxy_session/5","title":"AWS.ChimeSDKVoice.update_proxy_session/5","type":"function"},{"doc":"Updates the details of the specified SIP media application.","ref":"AWS.ChimeSDKVoice.html#update_sip_media_application/4","title":"AWS.ChimeSDKVoice.update_sip_media_application/4","type":"function"},{"doc":"Invokes the AWS Lambda function associated with the SIP media application and\ntransaction ID in an update request.\n\nThe Lambda function can then return a new set of actions.","ref":"AWS.ChimeSDKVoice.html#update_sip_media_application_call/5","title":"AWS.ChimeSDKVoice.update_sip_media_application_call/5","type":"function"},{"doc":"Updates the details of the specified SIP rule.","ref":"AWS.ChimeSDKVoice.html#update_sip_rule/4","title":"AWS.ChimeSDKVoice.update_sip_rule/4","type":"function"},{"doc":"Updates the details for the specified Amazon Chime SDK Voice Connector.","ref":"AWS.ChimeSDKVoice.html#update_voice_connector/4","title":"AWS.ChimeSDKVoice.update_voice_connector/4","type":"function"},{"doc":"Updates the settings for the specified Amazon Chime SDK Voice Connector group.","ref":"AWS.ChimeSDKVoice.html#update_voice_connector_group/4","title":"AWS.ChimeSDKVoice.update_voice_connector_group/4","type":"function"},{"doc":"Updates the specified voice profile’s voice print and refreshes its expiration\ntimestamp.\n\nAs a condition of using this feature, you acknowledge that the collection, use,\nstorage, and retention of your caller’s biometric identifiers and biometric\ninformation (“biometric data”) in the form of a digital voiceprint requires the\ncaller’s informed consent via a written release. Such consent is required under\nvarious state laws, including biometrics laws in Illinois, Texas, Washington and\nother state privacy laws.\n\nYou must provide a written release to each caller through a process that clearly\nreflects each caller’s informed consent before using Amazon Chime SDK Voice\nInsights service, as required under the terms of your agreement with AWS\ngoverning your use of the service.","ref":"AWS.ChimeSDKVoice.html#update_voice_profile/4","title":"AWS.ChimeSDKVoice.update_voice_profile/4","type":"function"},{"doc":"Updates the settings for the specified voice profile domain.","ref":"AWS.ChimeSDKVoice.html#update_voice_profile_domain/4","title":"AWS.ChimeSDKVoice.update_voice_profile_domain/4","type":"function"},{"doc":"Validates an address to be used for 911 calls made with Amazon Chime SDK Voice\nConnectors.\n\nYou can use validated addresses in a Presence Information Data Format Location\nObject file that you include in SIP requests. That helps ensure that addresses\nare routed to the appropriate Public Safety Answering Point.","ref":"AWS.ChimeSDKVoice.html#validate_e911_address/3","title":"AWS.ChimeSDKVoice.validate_e911_address/3","type":"function"},{"doc":"Welcome to the *Clean Rooms API Reference*.\n\nClean Rooms is an Amazon Web Services service that helps multiple parties to\njoin their data together in a secure collaboration workspace. In the\ncollaboration, members who can query and receive results can get insights into\nthe collective datasets without either party getting access to the other party's\nraw data.\n\nTo learn more about Clean Rooms concepts, procedures, and best practices, see\nthe [Clean Rooms User Guide](https://docs.aws.amazon.com/clean-rooms/latest/userguide/what-is.html).\n\nTo learn more about SQL commands, functions, and conditions supported in Clean\nRooms, see the [Clean Rooms SQL Reference](https://docs.aws.amazon.com/clean-rooms/latest/sql-reference/sql-reference.html).","ref":"AWS.CleanRooms.html","title":"AWS.CleanRooms","type":"module"},{"doc":"Retrieves multiple analysis templates within a collaboration by their Amazon\nResource Names (ARNs).","ref":"AWS.CleanRooms.html#batch_get_collaboration_analysis_template/4","title":"AWS.CleanRooms.batch_get_collaboration_analysis_template/4","type":"function"},{"doc":"Retrieves multiple schemas by their identifiers.","ref":"AWS.CleanRooms.html#batch_get_schema/4","title":"AWS.CleanRooms.batch_get_schema/4","type":"function"},{"doc":"Creates a new analysis template.","ref":"AWS.CleanRooms.html#create_analysis_template/4","title":"AWS.CleanRooms.create_analysis_template/4","type":"function"},{"doc":"Creates a new collaboration.","ref":"AWS.CleanRooms.html#create_collaboration/3","title":"AWS.CleanRooms.create_collaboration/3","type":"function"},{"doc":"Provides the details necessary to create a configured audience model\nassociation.","ref":"AWS.CleanRooms.html#create_configured_audience_model_association/4","title":"AWS.CleanRooms.create_configured_audience_model_association/4","type":"function"},{"doc":"Creates a new configured table resource.","ref":"AWS.CleanRooms.html#create_configured_table/3","title":"AWS.CleanRooms.create_configured_table/3","type":"function"},{"doc":"Creates a new analysis rule for a configured table.\n\nCurrently, only one analysis rule can be created for a given configured table.","ref":"AWS.CleanRooms.html#create_configured_table_analysis_rule/4","title":"AWS.CleanRooms.create_configured_table_analysis_rule/4","type":"function"},{"doc":"Creates a configured table association.\n\nA configured table association links a configured table with a collaboration.","ref":"AWS.CleanRooms.html#create_configured_table_association/4","title":"AWS.CleanRooms.create_configured_table_association/4","type":"function"},{"doc":"Creates a membership for a specific collaboration identifier and joins the\ncollaboration.","ref":"AWS.CleanRooms.html#create_membership/3","title":"AWS.CleanRooms.create_membership/3","type":"function"},{"doc":"Creates a privacy budget template for a specified membership.\n\nEach membership can have only one privacy budget template, but it can be deleted\nand recreated. If you need to change the privacy budget template for a\nmembership, use the `UpdatePrivacyBudgetTemplate` operation.","ref":"AWS.CleanRooms.html#create_privacy_budget_template/4","title":"AWS.CleanRooms.create_privacy_budget_template/4","type":"function"},{"doc":"Deletes an analysis template.","ref":"AWS.CleanRooms.html#delete_analysis_template/5","title":"AWS.CleanRooms.delete_analysis_template/5","type":"function"},{"doc":"Deletes a collaboration.\n\nIt can only be called by the collaboration owner.","ref":"AWS.CleanRooms.html#delete_collaboration/4","title":"AWS.CleanRooms.delete_collaboration/4","type":"function"},{"doc":"Provides the information necessary to delete a configured audience model\nassociation.","ref":"AWS.CleanRooms.html#delete_configured_audience_model_association/5","title":"AWS.CleanRooms.delete_configured_audience_model_association/5","type":"function"},{"doc":"Deletes a configured table.","ref":"AWS.CleanRooms.html#delete_configured_table/4","title":"AWS.CleanRooms.delete_configured_table/4","type":"function"},{"doc":"Deletes a configured table analysis rule.","ref":"AWS.CleanRooms.html#delete_configured_table_analysis_rule/5","title":"AWS.CleanRooms.delete_configured_table_analysis_rule/5","type":"function"},{"doc":"Deletes a configured table association.","ref":"AWS.CleanRooms.html#delete_configured_table_association/5","title":"AWS.CleanRooms.delete_configured_table_association/5","type":"function"},{"doc":"Removes the specified member from a collaboration.\n\nThe removed member is placed in the Removed status and can't interact with the\ncollaboration. The removed member's data is inaccessible to active members of\nthe collaboration.","ref":"AWS.CleanRooms.html#delete_member/5","title":"AWS.CleanRooms.delete_member/5","type":"function"},{"doc":"Deletes a specified membership.\n\nAll resources under a membership must be deleted.","ref":"AWS.CleanRooms.html#delete_membership/4","title":"AWS.CleanRooms.delete_membership/4","type":"function"},{"doc":"Deletes a privacy budget template for a specified membership.","ref":"AWS.CleanRooms.html#delete_privacy_budget_template/5","title":"AWS.CleanRooms.delete_privacy_budget_template/5","type":"function"},{"doc":"Retrieves an analysis template.","ref":"AWS.CleanRooms.html#get_analysis_template/4","title":"AWS.CleanRooms.get_analysis_template/4","type":"function"},{"doc":"Returns metadata about a collaboration.","ref":"AWS.CleanRooms.html#get_collaboration/3","title":"AWS.CleanRooms.get_collaboration/3","type":"function"},{"doc":"Retrieves an analysis template within a collaboration.","ref":"AWS.CleanRooms.html#get_collaboration_analysis_template/4","title":"AWS.CleanRooms.get_collaboration_analysis_template/4","type":"function"},{"doc":"Retrieves a configured audience model association within a collaboration.","ref":"AWS.CleanRooms.html#get_collaboration_configured_audience_model_association/4","title":"AWS.CleanRooms.get_collaboration_configured_audience_model_association/4","type":"function"},{"doc":"Returns details about a specified privacy budget template.","ref":"AWS.CleanRooms.html#get_collaboration_privacy_budget_template/4","title":"AWS.CleanRooms.get_collaboration_privacy_budget_template/4","type":"function"},{"doc":"Returns information about a configured audience model association.","ref":"AWS.CleanRooms.html#get_configured_audience_model_association/4","title":"AWS.CleanRooms.get_configured_audience_model_association/4","type":"function"},{"doc":"Retrieves a configured table.","ref":"AWS.CleanRooms.html#get_configured_table/3","title":"AWS.CleanRooms.get_configured_table/3","type":"function"},{"doc":"Retrieves a configured table analysis rule.","ref":"AWS.CleanRooms.html#get_configured_table_analysis_rule/4","title":"AWS.CleanRooms.get_configured_table_analysis_rule/4","type":"function"},{"doc":"Retrieves a configured table association.","ref":"AWS.CleanRooms.html#get_configured_table_association/4","title":"AWS.CleanRooms.get_configured_table_association/4","type":"function"},{"doc":"Retrieves a specified membership for an identifier.","ref":"AWS.CleanRooms.html#get_membership/3","title":"AWS.CleanRooms.get_membership/3","type":"function"},{"doc":"Returns details for a specified privacy budget template.","ref":"AWS.CleanRooms.html#get_privacy_budget_template/4","title":"AWS.CleanRooms.get_privacy_budget_template/4","type":"function"},{"doc":"Returns query processing metadata.","ref":"AWS.CleanRooms.html#get_protected_query/4","title":"AWS.CleanRooms.get_protected_query/4","type":"function"},{"doc":"Retrieves the schema for a relation within a collaboration.","ref":"AWS.CleanRooms.html#get_schema/4","title":"AWS.CleanRooms.get_schema/4","type":"function"},{"doc":"Retrieves a schema analysis rule.","ref":"AWS.CleanRooms.html#get_schema_analysis_rule/5","title":"AWS.CleanRooms.get_schema_analysis_rule/5","type":"function"},{"doc":"Lists analysis templates that the caller owns.","ref":"AWS.CleanRooms.html#list_analysis_templates/5","title":"AWS.CleanRooms.list_analysis_templates/5","type":"function"},{"doc":"Lists analysis templates within a collaboration.","ref":"AWS.CleanRooms.html#list_collaboration_analysis_templates/5","title":"AWS.CleanRooms.list_collaboration_analysis_templates/5","type":"function"},{"doc":"Lists configured audience model associations within a collaboration.","ref":"AWS.CleanRooms.html#list_collaboration_configured_audience_model_associations/5","title":"AWS.CleanRooms.list_collaboration_configured_audience_model_associations/5","type":"function"},{"doc":"Returns an array that summarizes each privacy budget template in a specified\ncollaboration.","ref":"AWS.CleanRooms.html#list_collaboration_privacy_budget_templates/5","title":"AWS.CleanRooms.list_collaboration_privacy_budget_templates/5","type":"function"},{"doc":"Returns an array that summarizes each privacy budget in a specified\ncollaboration.\n\nThe summary includes the collaboration ARN, creation time, creating account, and\nprivacy budget details.","ref":"AWS.CleanRooms.html#list_collaboration_privacy_budgets/6","title":"AWS.CleanRooms.list_collaboration_privacy_budgets/6","type":"function"},{"doc":"Lists collaborations the caller owns, is active in, or has been invited to.","ref":"AWS.CleanRooms.html#list_collaborations/5","title":"AWS.CleanRooms.list_collaborations/5","type":"function"},{"doc":"Lists information about requested configured audience model associations.","ref":"AWS.CleanRooms.html#list_configured_audience_model_associations/5","title":"AWS.CleanRooms.list_configured_audience_model_associations/5","type":"function"},{"doc":"Lists configured table associations for a membership.","ref":"AWS.CleanRooms.html#list_configured_table_associations/5","title":"AWS.CleanRooms.list_configured_table_associations/5","type":"function"},{"doc":"Lists configured tables.","ref":"AWS.CleanRooms.html#list_configured_tables/4","title":"AWS.CleanRooms.list_configured_tables/4","type":"function"},{"doc":"Lists all members within a collaboration.","ref":"AWS.CleanRooms.html#list_members/5","title":"AWS.CleanRooms.list_members/5","type":"function"},{"doc":"Lists all memberships resources within the caller's account.","ref":"AWS.CleanRooms.html#list_memberships/5","title":"AWS.CleanRooms.list_memberships/5","type":"function"},{"doc":"Returns detailed information about the privacy budget templates in a specified\nmembership.","ref":"AWS.CleanRooms.html#list_privacy_budget_templates/5","title":"AWS.CleanRooms.list_privacy_budget_templates/5","type":"function"},{"doc":"Returns detailed information about the privacy budgets in a specified\nmembership.","ref":"AWS.CleanRooms.html#list_privacy_budgets/6","title":"AWS.CleanRooms.list_privacy_budgets/6","type":"function"},{"doc":"Lists protected queries, sorted by the most recent query.","ref":"AWS.CleanRooms.html#list_protected_queries/6","title":"AWS.CleanRooms.list_protected_queries/6","type":"function"},{"doc":"Lists the schemas for relations within a collaboration.","ref":"AWS.CleanRooms.html#list_schemas/6","title":"AWS.CleanRooms.list_schemas/6","type":"function"},{"doc":"Lists all of the tags that have been added to a resource.","ref":"AWS.CleanRooms.html#list_tags_for_resource/3","title":"AWS.CleanRooms.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.CleanRooms.html#metadata/0","title":"AWS.CleanRooms.metadata/0","type":"function"},{"doc":"An estimate of the number of aggregation functions that the member who can query\ncan run given epsilon and noise parameters.","ref":"AWS.CleanRooms.html#preview_privacy_impact/4","title":"AWS.CleanRooms.preview_privacy_impact/4","type":"function"},{"doc":"Creates a protected query that is started by Clean Rooms.","ref":"AWS.CleanRooms.html#start_protected_query/4","title":"AWS.CleanRooms.start_protected_query/4","type":"function"},{"doc":"Tags a resource.","ref":"AWS.CleanRooms.html#tag_resource/4","title":"AWS.CleanRooms.tag_resource/4","type":"function"},{"doc":"Removes a tag or list of tags from a resource.","ref":"AWS.CleanRooms.html#untag_resource/4","title":"AWS.CleanRooms.untag_resource/4","type":"function"},{"doc":"Updates the analysis template metadata.","ref":"AWS.CleanRooms.html#update_analysis_template/5","title":"AWS.CleanRooms.update_analysis_template/5","type":"function"},{"doc":"Updates collaboration metadata and can only be called by the collaboration\nowner.","ref":"AWS.CleanRooms.html#update_collaboration/4","title":"AWS.CleanRooms.update_collaboration/4","type":"function"},{"doc":"Provides the details necessary to update a configured audience model\nassociation.","ref":"AWS.CleanRooms.html#update_configured_audience_model_association/5","title":"AWS.CleanRooms.update_configured_audience_model_association/5","type":"function"},{"doc":"Updates a configured table.","ref":"AWS.CleanRooms.html#update_configured_table/4","title":"AWS.CleanRooms.update_configured_table/4","type":"function"},{"doc":"Updates a configured table analysis rule.","ref":"AWS.CleanRooms.html#update_configured_table_analysis_rule/5","title":"AWS.CleanRooms.update_configured_table_analysis_rule/5","type":"function"},{"doc":"Updates a configured table association.","ref":"AWS.CleanRooms.html#update_configured_table_association/5","title":"AWS.CleanRooms.update_configured_table_association/5","type":"function"},{"doc":"Updates a membership.","ref":"AWS.CleanRooms.html#update_membership/4","title":"AWS.CleanRooms.update_membership/4","type":"function"},{"doc":"Updates the privacy budget template for the specified membership.","ref":"AWS.CleanRooms.html#update_privacy_budget_template/5","title":"AWS.CleanRooms.update_privacy_budget_template/5","type":"function"},{"doc":"Updates the processing of a currently running query.","ref":"AWS.CleanRooms.html#update_protected_query/5","title":"AWS.CleanRooms.update_protected_query/5","type":"function"},{"doc":"Welcome to the *Amazon Web Services Clean Rooms ML API Reference*.\n\nAmazon Web Services Clean Rooms ML provides a privacy-enhancing method for two\nparties to identify similar users in their data without the need to share their\ndata with each other. The first party brings the training data to Clean Rooms so\nthat they can create and configure an audience model (lookalike model) and\nassociate it with a collaboration. The second party then brings their seed data\nto Clean Rooms and generates an audience (lookalike segment) that resembles the\ntraining data.\n\nTo learn more about Amazon Web Services Clean Rooms ML concepts, procedures, and\nbest practices, see the [Clean Rooms User Guide](https://docs.aws.amazon.com/clean-rooms/latest/userguide/machine-learning.html).\n\nTo learn more about SQL commands, functions, and conditions supported in Clean\nRooms, see the [Clean Rooms SQL Reference](https://docs.aws.amazon.com/clean-rooms/latest/sql-reference/sql-reference.html).","ref":"AWS.CleanRoomsML.html","title":"AWS.CleanRoomsML","type":"module"},{"doc":"Defines the information necessary to create an audience model.\n\nAn audience model is a machine learning model that Clean Rooms ML trains to\nmeasure similarity between users. Clean Rooms ML manages training and storing\nthe audience model. The audience model can be used in multiple calls to the\n`StartAudienceGenerationJob` API.","ref":"AWS.CleanRoomsML.html#create_audience_model/3","title":"AWS.CleanRoomsML.create_audience_model/3","type":"function"},{"doc":"Defines the information necessary to create a configured audience model.","ref":"AWS.CleanRoomsML.html#create_configured_audience_model/3","title":"AWS.CleanRoomsML.create_configured_audience_model/3","type":"function"},{"doc":"Defines the information necessary to create a training dataset, or seed\naudience.\n\nIn Clean Rooms ML, the `TrainingDataset` is metadata that points to a Glue\ntable, which is read only during `AudienceModel` creation.","ref":"AWS.CleanRoomsML.html#create_training_dataset/3","title":"AWS.CleanRoomsML.create_training_dataset/3","type":"function"},{"doc":"Deletes the specified audience generation job, and removes all data associated\nwith the job.","ref":"AWS.CleanRoomsML.html#delete_audience_generation_job/4","title":"AWS.CleanRoomsML.delete_audience_generation_job/4","type":"function"},{"doc":"Specifies an audience model that you want to delete.\n\nYou can't delete an audience model if there are any configured audience models\nthat depend on the audience model.","ref":"AWS.CleanRoomsML.html#delete_audience_model/4","title":"AWS.CleanRoomsML.delete_audience_model/4","type":"function"},{"doc":"Deletes the specified configured audience model.\n\nYou can't delete a configured audience model if there are any lookalike models\nthat use the configured audience model. If you delete a configured audience\nmodel, it will be removed from any collaborations that it is associated to.","ref":"AWS.CleanRoomsML.html#delete_configured_audience_model/4","title":"AWS.CleanRoomsML.delete_configured_audience_model/4","type":"function"},{"doc":"Deletes the specified configured audience model policy.","ref":"AWS.CleanRoomsML.html#delete_configured_audience_model_policy/4","title":"AWS.CleanRoomsML.delete_configured_audience_model_policy/4","type":"function"},{"doc":"Specifies a training dataset that you want to delete.\n\nYou can't delete a training dataset if there are any audience models that depend\non the training dataset. In Clean Rooms ML, the `TrainingDataset` is metadata\nthat points to a Glue table, which is read only during `AudienceModel` creation.\nThis action deletes the metadata.","ref":"AWS.CleanRoomsML.html#delete_training_dataset/4","title":"AWS.CleanRoomsML.delete_training_dataset/4","type":"function"},{"doc":"Returns information about an audience generation job.","ref":"AWS.CleanRoomsML.html#get_audience_generation_job/3","title":"AWS.CleanRoomsML.get_audience_generation_job/3","type":"function"},{"doc":"Returns information about an audience model","ref":"AWS.CleanRoomsML.html#get_audience_model/3","title":"AWS.CleanRoomsML.get_audience_model/3","type":"function"},{"doc":"Returns information about a specified configured audience model.","ref":"AWS.CleanRoomsML.html#get_configured_audience_model/3","title":"AWS.CleanRoomsML.get_configured_audience_model/3","type":"function"},{"doc":"Returns information about a configured audience model policy.","ref":"AWS.CleanRoomsML.html#get_configured_audience_model_policy/3","title":"AWS.CleanRoomsML.get_configured_audience_model_policy/3","type":"function"},{"doc":"Returns information about a training dataset.","ref":"AWS.CleanRoomsML.html#get_training_dataset/3","title":"AWS.CleanRoomsML.get_training_dataset/3","type":"function"},{"doc":"Returns a list of the audience export jobs.","ref":"AWS.CleanRoomsML.html#list_audience_export_jobs/5","title":"AWS.CleanRoomsML.list_audience_export_jobs/5","type":"function"},{"doc":"Returns a list of audience generation jobs.","ref":"AWS.CleanRoomsML.html#list_audience_generation_jobs/6","title":"AWS.CleanRoomsML.list_audience_generation_jobs/6","type":"function"},{"doc":"Returns a list of audience models.","ref":"AWS.CleanRoomsML.html#list_audience_models/4","title":"AWS.CleanRoomsML.list_audience_models/4","type":"function"},{"doc":"Returns a list of the configured audience models.","ref":"AWS.CleanRoomsML.html#list_configured_audience_models/4","title":"AWS.CleanRoomsML.list_configured_audience_models/4","type":"function"},{"doc":"Returns a list of tags for a provided resource.","ref":"AWS.CleanRoomsML.html#list_tags_for_resource/3","title":"AWS.CleanRoomsML.list_tags_for_resource/3","type":"function"},{"doc":"Returns a list of training datasets.","ref":"AWS.CleanRoomsML.html#list_training_datasets/4","title":"AWS.CleanRoomsML.list_training_datasets/4","type":"function"},{"doc":"","ref":"AWS.CleanRoomsML.html#metadata/0","title":"AWS.CleanRoomsML.metadata/0","type":"function"},{"doc":"Create or update the resource policy for a configured audience model.","ref":"AWS.CleanRoomsML.html#put_configured_audience_model_policy/4","title":"AWS.CleanRoomsML.put_configured_audience_model_policy/4","type":"function"},{"doc":"Export an audience of a specified size after you have generated an audience.","ref":"AWS.CleanRoomsML.html#start_audience_export_job/3","title":"AWS.CleanRoomsML.start_audience_export_job/3","type":"function"},{"doc":"Information necessary to start the audience generation job.","ref":"AWS.CleanRoomsML.html#start_audience_generation_job/3","title":"AWS.CleanRoomsML.start_audience_generation_job/3","type":"function"},{"doc":"Adds metadata tags to a specified resource.","ref":"AWS.CleanRoomsML.html#tag_resource/4","title":"AWS.CleanRoomsML.tag_resource/4","type":"function"},{"doc":"Removes metadata tags from a specified resource.","ref":"AWS.CleanRoomsML.html#untag_resource/4","title":"AWS.CleanRoomsML.untag_resource/4","type":"function"},{"doc":"Provides the information necessary to update a configured audience model.\n\nUpdates that impact audience generation jobs take effect when a new job starts,\nbut do not impact currently running jobs.","ref":"AWS.CleanRoomsML.html#update_configured_audience_model/4","title":"AWS.CleanRoomsML.update_configured_audience_model/4","type":"function"},{"doc":"Cloud9\n\nCloud9 is a collection of tools that you can use to code, build, run, test,\ndebug, and release software in the cloud.\n\nFor more information about Cloud9, see the [Cloud9 User Guide](https://docs.aws.amazon.com/cloud9/latest/user-guide).\n\nCloud9 supports these operations:\n\n  * `CreateEnvironmentEC2`: Creates an Cloud9 development environment,\nlaunches an Amazon EC2 instance, and then connects from the instance to the\nenvironment.\n\n  * `CreateEnvironmentMembership`: Adds an environment member to an\nenvironment.\n\n  * `DeleteEnvironment`: Deletes an environment. If an Amazon EC2\ninstance is connected to the environment, also terminates the instance.\n\n  * `DeleteEnvironmentMembership`: Deletes an environment member from\nan environment.\n\n  * `DescribeEnvironmentMemberships`: Gets information about\nenvironment members for an environment.\n\n  * `DescribeEnvironments`: Gets information about environments.\n\n  * `DescribeEnvironmentStatus`: Gets status information for an\nenvironment.\n\n  * `ListEnvironments`: Gets a list of environment identifiers.\n\n  * `ListTagsForResource`: Gets the tags for an environment.\n\n  * `TagResource`: Adds tags to an environment.\n\n  * `UntagResource`: Removes tags from an environment.\n\n  * `UpdateEnvironment`: Changes the settings of an existing\nenvironment.\n\n  * `UpdateEnvironmentMembership`: Changes the settings of an existing\nenvironment member for an environment.","ref":"AWS.Cloud9.html","title":"AWS.Cloud9","type":"module"},{"doc":"Creates an Cloud9 development environment, launches an Amazon Elastic Compute\nCloud (Amazon EC2) instance, and then connects from the instance to the\nenvironment.","ref":"AWS.Cloud9.html#create_environment_ec2/3","title":"AWS.Cloud9.create_environment_ec2/3","type":"function"},{"doc":"Adds an environment member to an Cloud9 development environment.","ref":"AWS.Cloud9.html#create_environment_membership/3","title":"AWS.Cloud9.create_environment_membership/3","type":"function"},{"doc":"Deletes an Cloud9 development environment.\n\nIf an Amazon EC2 instance is connected to the environment, also terminates the\ninstance.","ref":"AWS.Cloud9.html#delete_environment/3","title":"AWS.Cloud9.delete_environment/3","type":"function"},{"doc":"Deletes an environment member from a development environment.","ref":"AWS.Cloud9.html#delete_environment_membership/3","title":"AWS.Cloud9.delete_environment_membership/3","type":"function"},{"doc":"Gets information about environment members for an Cloud9 development\nenvironment.","ref":"AWS.Cloud9.html#describe_environment_memberships/3","title":"AWS.Cloud9.describe_environment_memberships/3","type":"function"},{"doc":"Gets status information for an Cloud9 development environment.","ref":"AWS.Cloud9.html#describe_environment_status/3","title":"AWS.Cloud9.describe_environment_status/3","type":"function"},{"doc":"Gets information about Cloud9 development environments.","ref":"AWS.Cloud9.html#describe_environments/3","title":"AWS.Cloud9.describe_environments/3","type":"function"},{"doc":"Gets a list of Cloud9 development environment identifiers.","ref":"AWS.Cloud9.html#list_environments/3","title":"AWS.Cloud9.list_environments/3","type":"function"},{"doc":"Gets a list of the tags associated with an Cloud9 development environment.","ref":"AWS.Cloud9.html#list_tags_for_resource/3","title":"AWS.Cloud9.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.Cloud9.html#metadata/0","title":"AWS.Cloud9.metadata/0","type":"function"},{"doc":"Adds tags to an Cloud9 development environment.\n\nTags that you add to an Cloud9 environment by using this method will NOT be\nautomatically propagated to underlying resources.","ref":"AWS.Cloud9.html#tag_resource/3","title":"AWS.Cloud9.tag_resource/3","type":"function"},{"doc":"Removes tags from an Cloud9 development environment.","ref":"AWS.Cloud9.html#untag_resource/3","title":"AWS.Cloud9.untag_resource/3","type":"function"},{"doc":"Changes the settings of an existing Cloud9 development environment.","ref":"AWS.Cloud9.html#update_environment/3","title":"AWS.Cloud9.update_environment/3","type":"function"},{"doc":"Changes the settings of an existing environment member for an Cloud9 development\nenvironment.","ref":"AWS.Cloud9.html#update_environment_membership/3","title":"AWS.Cloud9.update_environment_membership/3","type":"function"},{"doc":"For more information about Amazon Web Services Cloud Control API, see the\n[Amazon Web Services Cloud Control API User Guide](https://docs.aws.amazon.com/cloudcontrolapi/latest/userguide/what-is-cloudcontrolapi.html).","ref":"AWS.CloudControl.html","title":"AWS.CloudControl","type":"module"},{"doc":"Cancels the specified resource operation request.\n\nFor more information, see [Canceling resource operation requests](https://docs.aws.amazon.com/cloudcontrolapi/latest/userguide/resource-operations-manage-requests.html#resource-operations-manage-requests-cancel)\nin the *Amazon Web Services Cloud Control API User Guide*.\n\nOnly resource operations requests with a status of `PENDING` or `IN_PROGRESS`\ncan be canceled.","ref":"AWS.CloudControl.html#cancel_resource_request/3","title":"AWS.CloudControl.cancel_resource_request/3","type":"function"},{"doc":"Creates the specified resource.\n\nFor more information, see [Creating a resource](https://docs.aws.amazon.com/cloudcontrolapi/latest/userguide/resource-operations-create.html)\nin the *Amazon Web Services Cloud Control API User Guide*.\n\nAfter you have initiated a resource creation request, you can monitor the\nprogress of your request by calling\n[GetResourceRequestStatus](https://docs.aws.amazon.com/cloudcontrolapi/latest/APIReference/API_GetResourceRequestStatus.html)\nusing the `RequestToken` of the `ProgressEvent` type returned by\n`CreateResource`.","ref":"AWS.CloudControl.html#create_resource/3","title":"AWS.CloudControl.create_resource/3","type":"function"},{"doc":"Deletes the specified resource.\n\nFor details, see [Deleting a resource](https://docs.aws.amazon.com/cloudcontrolapi/latest/userguide/resource-operations-delete.html)\nin the *Amazon Web Services Cloud Control API User Guide*.\n\nAfter you have initiated a resource deletion request, you can monitor the\nprogress of your request by calling\n[GetResourceRequestStatus](https://docs.aws.amazon.com/cloudcontrolapi/latest/APIReference/API_GetResourceRequestStatus.html)\nusing the `RequestToken` of the `ProgressEvent` returned by `DeleteResource`.","ref":"AWS.CloudControl.html#delete_resource/3","title":"AWS.CloudControl.delete_resource/3","type":"function"},{"doc":"Returns information about the current state of the specified resource.\n\nFor details, see [Reading a resource's current state](https://docs.aws.amazon.com/cloudcontrolapi/latest/userguide/resource-operations-read.html).\n\nYou can use this action to return information about an existing resource in your\naccount and Amazon Web Services Region, whether those resources were provisioned\nusing Cloud Control API.","ref":"AWS.CloudControl.html#get_resource/3","title":"AWS.CloudControl.get_resource/3","type":"function"},{"doc":"Returns the current status of a resource operation request.\n\nFor more information, see [Tracking the progress of resource operation requests](https://docs.aws.amazon.com/cloudcontrolapi/latest/userguide/resource-operations-manage-requests.html#resource-operations-manage-requests-track)\nin the *Amazon Web Services Cloud Control API User Guide*.","ref":"AWS.CloudControl.html#get_resource_request_status/3","title":"AWS.CloudControl.get_resource_request_status/3","type":"function"},{"doc":"Returns existing resource operation requests.\n\nThis includes requests of all status types. For more information, see [Listing active resource operation\nrequests](https://docs.aws.amazon.com/cloudcontrolapi/latest/userguide/resource-operations-manage-requests.html#resource-operations-manage-requests-list)\nin the *Amazon Web Services Cloud Control API User Guide*.\n\nResource operation requests expire after 7 days.","ref":"AWS.CloudControl.html#list_resource_requests/3","title":"AWS.CloudControl.list_resource_requests/3","type":"function"},{"doc":"Returns information about the specified resources.\n\nFor more information, see [Discovering resources](https://docs.aws.amazon.com/cloudcontrolapi/latest/userguide/resource-operations-list.html)\nin the *Amazon Web Services Cloud Control API User Guide*.\n\nYou can use this action to return information about existing resources in your\naccount and Amazon Web Services Region, whether those resources were provisioned\nusing Cloud Control API.","ref":"AWS.CloudControl.html#list_resources/3","title":"AWS.CloudControl.list_resources/3","type":"function"},{"doc":"","ref":"AWS.CloudControl.html#metadata/0","title":"AWS.CloudControl.metadata/0","type":"function"},{"doc":"Updates the specified property values in the resource.\n\nYou specify your resource property updates as a list of patch operations\ncontained in a JSON patch document that adheres to the [ *RFC 6902 - JavaScript Object Notation (JSON) Patch* ](https://datatracker.ietf.org/doc/html/rfc6902)\nstandard.\n\nFor details on how Cloud Control API performs resource update operations, see\n[Updating a resource](https://docs.aws.amazon.com/cloudcontrolapi/latest/userguide/resource-operations-update.html)\nin the *Amazon Web Services Cloud Control API User Guide*.\n\nAfter you have initiated a resource update request, you can monitor the progress\nof your request by calling\n[GetResourceRequestStatus](https://docs.aws.amazon.com/cloudcontrolapi/latest/APIReference/API_GetResourceRequestStatus.html) using the `RequestToken` of the `ProgressEvent` returned by `UpdateResource`.\n\nFor more information about the properties of a specific resource, refer to the\nrelated topic for the resource in the [Resource and property types\nreference](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-template-resource-type-ref.html)\nin the *CloudFormation Users Guide*.","ref":"AWS.CloudControl.html#update_resource/3","title":"AWS.CloudControl.update_resource/3","type":"function"},{"doc":"Amazon Cloud Directory\n\nAmazon Cloud Directory is a component of the AWS Directory Service that\nsimplifies the development and management of cloud-scale web, mobile, and IoT\napplications.\n\nThis guide describes the Cloud Directory operations that you can call\nprogrammatically and includes detailed information on data types and errors. For\ninformation about Cloud Directory features, see [AWS Directory Service](https://aws.amazon.com/directoryservice/) and the [Amazon Cloud Directory Developer\nGuide](https://docs.aws.amazon.com/clouddirectory/latest/developerguide/what_is_cloud_directory.html).","ref":"AWS.CloudDirectory.html","title":"AWS.CloudDirectory","type":"module"},{"doc":"Adds a new `Facet` to an object.\n\nAn object can have more than one facet applied on it.","ref":"AWS.CloudDirectory.html#add_facet_to_object/3","title":"AWS.CloudDirectory.add_facet_to_object/3","type":"function"},{"doc":"Copies the input published schema, at the specified version, into the\n`Directory` with the same name and version as that of the published schema.","ref":"AWS.CloudDirectory.html#apply_schema/3","title":"AWS.CloudDirectory.apply_schema/3","type":"function"},{"doc":"Attaches an existing object to another object.\n\nAn object can be accessed in two ways:\n\n  1. Using the path\n\n  2. Using `ObjectIdentifier`","ref":"AWS.CloudDirectory.html#attach_object/3","title":"AWS.CloudDirectory.attach_object/3","type":"function"},{"doc":"Attaches a policy object to a regular object.\n\nAn object can have a limited number of attached policies.","ref":"AWS.CloudDirectory.html#attach_policy/3","title":"AWS.CloudDirectory.attach_policy/3","type":"function"},{"doc":"Attaches the specified object to the specified index.","ref":"AWS.CloudDirectory.html#attach_to_index/3","title":"AWS.CloudDirectory.attach_to_index/3","type":"function"},{"doc":"Attaches a typed link to a specified source and target object.\n\nFor more information, see [Typed Links](https://docs.aws.amazon.com/clouddirectory/latest/developerguide/directory_objects_links.html#directory_objects_links_typedlink).","ref":"AWS.CloudDirectory.html#attach_typed_link/3","title":"AWS.CloudDirectory.attach_typed_link/3","type":"function"},{"doc":"Performs all the read operations in a batch.","ref":"AWS.CloudDirectory.html#batch_read/3","title":"AWS.CloudDirectory.batch_read/3","type":"function"},{"doc":"Performs all the write operations in a batch.\n\nEither all the operations succeed or none.","ref":"AWS.CloudDirectory.html#batch_write/3","title":"AWS.CloudDirectory.batch_write/3","type":"function"},{"doc":"Creates a `Directory` by copying the published schema into the directory.\n\nA directory cannot be created without a schema.\n\nYou can also quickly create a directory using a managed schema, called the\n`QuickStartSchema`. For more information, see [Managed Schema](https://docs.aws.amazon.com/clouddirectory/latest/developerguide/schemas_managed.html)\nin the *Amazon Cloud Directory Developer Guide*.","ref":"AWS.CloudDirectory.html#create_directory/3","title":"AWS.CloudDirectory.create_directory/3","type":"function"},{"doc":"Creates a new `Facet` in a schema.\n\nFacet creation is allowed only in development or applied schemas.","ref":"AWS.CloudDirectory.html#create_facet/3","title":"AWS.CloudDirectory.create_facet/3","type":"function"},{"doc":"Creates an index object.\n\nSee [Indexing and search](https://docs.aws.amazon.com/clouddirectory/latest/developerguide/indexing_search.html)\nfor more information.","ref":"AWS.CloudDirectory.html#create_index/3","title":"AWS.CloudDirectory.create_index/3","type":"function"},{"doc":"Creates an object in a `Directory`.\n\nAdditionally attaches the object to a parent, if a parent reference and\n`LinkName` is specified. An object is simply a collection of `Facet` attributes.\nYou can also use this API call to create a policy object, if the facet from\nwhich you create the object is a policy facet.","ref":"AWS.CloudDirectory.html#create_object/3","title":"AWS.CloudDirectory.create_object/3","type":"function"},{"doc":"Creates a new schema in a development state.\n\nA schema can exist in three phases:\n\n  * *Development:* This is a mutable phase of the schema. All new\nschemas are in the development phase. Once the schema is finalized, it can be\npublished.\n\n  * *Published:* Published schemas are immutable and have a version\nassociated with them.\n\n  * *Applied:* Applied schemas are mutable in a way that allows you to\nadd new schema facets. You can also add new, nonrequired attributes to existing\nschema facets. You can apply only published schemas to directories.","ref":"AWS.CloudDirectory.html#create_schema/3","title":"AWS.CloudDirectory.create_schema/3","type":"function"},{"doc":"Creates a `TypedLinkFacet`.\n\nFor more information, see [Typed Links](https://docs.aws.amazon.com/clouddirectory/latest/developerguide/directory_objects_links.html#directory_objects_links_typedlink).","ref":"AWS.CloudDirectory.html#create_typed_link_facet/3","title":"AWS.CloudDirectory.create_typed_link_facet/3","type":"function"},{"doc":"Deletes a directory.\n\nOnly disabled directories can be deleted. A deleted directory cannot be undone.\nExercise extreme caution when deleting directories.","ref":"AWS.CloudDirectory.html#delete_directory/3","title":"AWS.CloudDirectory.delete_directory/3","type":"function"},{"doc":"Deletes a given `Facet`.\n\nAll attributes and `Rule`s that are associated with the facet will be deleted.\nOnly development schema facets are allowed deletion.","ref":"AWS.CloudDirectory.html#delete_facet/3","title":"AWS.CloudDirectory.delete_facet/3","type":"function"},{"doc":"Deletes an object and its associated attributes.\n\nOnly objects with no children and no parents can be deleted. The maximum number\nof attributes that can be deleted during an object deletion is 30. For more\ninformation, see [Amazon Cloud Directory Limits](https://docs.aws.amazon.com/clouddirectory/latest/developerguide/limits.html).","ref":"AWS.CloudDirectory.html#delete_object/3","title":"AWS.CloudDirectory.delete_object/3","type":"function"},{"doc":"Deletes a given schema.\n\nSchemas in a development and published state can only be deleted.","ref":"AWS.CloudDirectory.html#delete_schema/3","title":"AWS.CloudDirectory.delete_schema/3","type":"function"},{"doc":"Deletes a `TypedLinkFacet`.\n\nFor more information, see [Typed Links](https://docs.aws.amazon.com/clouddirectory/latest/developerguide/directory_objects_links.html#directory_objects_links_typedlink).","ref":"AWS.CloudDirectory.html#delete_typed_link_facet/3","title":"AWS.CloudDirectory.delete_typed_link_facet/3","type":"function"},{"doc":"Detaches the specified object from the specified index.","ref":"AWS.CloudDirectory.html#detach_from_index/3","title":"AWS.CloudDirectory.detach_from_index/3","type":"function"},{"doc":"Detaches a given object from the parent object.\n\nThe object that is to be detached from the parent is specified by the link name.","ref":"AWS.CloudDirectory.html#detach_object/3","title":"AWS.CloudDirectory.detach_object/3","type":"function"},{"doc":"Detaches a policy from an object.","ref":"AWS.CloudDirectory.html#detach_policy/3","title":"AWS.CloudDirectory.detach_policy/3","type":"function"},{"doc":"Detaches a typed link from a specified source and target object.\n\nFor more information, see [Typed Links](https://docs.aws.amazon.com/clouddirectory/latest/developerguide/directory_objects_links.html#directory_objects_links_typedlink).","ref":"AWS.CloudDirectory.html#detach_typed_link/3","title":"AWS.CloudDirectory.detach_typed_link/3","type":"function"},{"doc":"Disables the specified directory.\n\nDisabled directories cannot be read or written to. Only enabled directories can\nbe disabled. Disabled directories may be reenabled.","ref":"AWS.CloudDirectory.html#disable_directory/3","title":"AWS.CloudDirectory.disable_directory/3","type":"function"},{"doc":"Enables the specified directory.\n\nOnly disabled directories can be enabled. Once enabled, the directory can then\nbe read and written to.","ref":"AWS.CloudDirectory.html#enable_directory/3","title":"AWS.CloudDirectory.enable_directory/3","type":"function"},{"doc":"Returns current applied schema version ARN, including the minor version in use.","ref":"AWS.CloudDirectory.html#get_applied_schema_version/3","title":"AWS.CloudDirectory.get_applied_schema_version/3","type":"function"},{"doc":"Retrieves metadata about a directory.","ref":"AWS.CloudDirectory.html#get_directory/3","title":"AWS.CloudDirectory.get_directory/3","type":"function"},{"doc":"Gets details of the `Facet`, such as facet name, attributes, `Rule`s, or\n`ObjectType`.\n\nYou can call this on all kinds of schema facets -- published, development, or\napplied.","ref":"AWS.CloudDirectory.html#get_facet/3","title":"AWS.CloudDirectory.get_facet/3","type":"function"},{"doc":"Retrieves attributes that are associated with a typed link.","ref":"AWS.CloudDirectory.html#get_link_attributes/3","title":"AWS.CloudDirectory.get_link_attributes/3","type":"function"},{"doc":"Retrieves attributes within a facet that are associated with an object.","ref":"AWS.CloudDirectory.html#get_object_attributes/3","title":"AWS.CloudDirectory.get_object_attributes/3","type":"function"},{"doc":"Retrieves metadata about an object.","ref":"AWS.CloudDirectory.html#get_object_information/3","title":"AWS.CloudDirectory.get_object_information/3","type":"function"},{"doc":"Retrieves a JSON representation of the schema.\n\nSee [JSON Schema Format](https://docs.aws.amazon.com/clouddirectory/latest/developerguide/schemas_jsonformat.html#schemas_json)\nfor more information.","ref":"AWS.CloudDirectory.html#get_schema_as_json/3","title":"AWS.CloudDirectory.get_schema_as_json/3","type":"function"},{"doc":"Returns the identity attribute order for a specific `TypedLinkFacet`.\n\nFor more information, see [Typed Links](https://docs.aws.amazon.com/clouddirectory/latest/developerguide/directory_objects_links.html#directory_objects_links_typedlink).","ref":"AWS.CloudDirectory.html#get_typed_link_facet_information/3","title":"AWS.CloudDirectory.get_typed_link_facet_information/3","type":"function"},{"doc":"Lists schema major versions applied to a directory.\n\nIf `SchemaArn` is provided, lists the minor version.","ref":"AWS.CloudDirectory.html#list_applied_schema_arns/3","title":"AWS.CloudDirectory.list_applied_schema_arns/3","type":"function"},{"doc":"Lists indices attached to the specified object.","ref":"AWS.CloudDirectory.html#list_attached_indices/3","title":"AWS.CloudDirectory.list_attached_indices/3","type":"function"},{"doc":"Retrieves each Amazon Resource Name (ARN) of schemas in the development state.","ref":"AWS.CloudDirectory.html#list_development_schema_arns/3","title":"AWS.CloudDirectory.list_development_schema_arns/3","type":"function"},{"doc":"Lists directories created within an account.","ref":"AWS.CloudDirectory.html#list_directories/3","title":"AWS.CloudDirectory.list_directories/3","type":"function"},{"doc":"Retrieves attributes attached to the facet.","ref":"AWS.CloudDirectory.html#list_facet_attributes/3","title":"AWS.CloudDirectory.list_facet_attributes/3","type":"function"},{"doc":"Retrieves the names of facets that exist in a schema.","ref":"AWS.CloudDirectory.html#list_facet_names/3","title":"AWS.CloudDirectory.list_facet_names/3","type":"function"},{"doc":"Returns a paginated list of all the incoming `TypedLinkSpecifier` information\nfor an object.\n\nIt also supports filtering by typed link facet and identity attributes. For more\ninformation, see [Typed Links](https://docs.aws.amazon.com/clouddirectory/latest/developerguide/directory_objects_links.html#directory_objects_links_typedlink).","ref":"AWS.CloudDirectory.html#list_incoming_typed_links/3","title":"AWS.CloudDirectory.list_incoming_typed_links/3","type":"function"},{"doc":"Lists objects attached to the specified index.","ref":"AWS.CloudDirectory.html#list_index/3","title":"AWS.CloudDirectory.list_index/3","type":"function"},{"doc":"Lists the major version families of each managed schema.\n\nIf a major version ARN is provided as SchemaArn, the minor version revisions in\nthat family are listed instead.","ref":"AWS.CloudDirectory.html#list_managed_schema_arns/3","title":"AWS.CloudDirectory.list_managed_schema_arns/3","type":"function"},{"doc":"Lists all attributes that are associated with an object.","ref":"AWS.CloudDirectory.html#list_object_attributes/3","title":"AWS.CloudDirectory.list_object_attributes/3","type":"function"},{"doc":"Returns a paginated list of child objects that are associated with a given\nobject.","ref":"AWS.CloudDirectory.html#list_object_children/3","title":"AWS.CloudDirectory.list_object_children/3","type":"function"},{"doc":"Retrieves all available parent paths for any object type such as node, leaf\nnode, policy node, and index node objects.\n\nFor more information about objects, see [Directory Structure](https://docs.aws.amazon.com/clouddirectory/latest/developerguide/key_concepts_directorystructure.html).\n\nUse this API to evaluate all parents for an object. The call returns all objects\nfrom the root of the directory up to the requested object. The API returns the\nnumber of paths based on user-defined `MaxResults`, in case there are multiple\npaths to the parent. The order of the paths and nodes returned is consistent\namong multiple API calls unless the objects are deleted or moved. Paths not\nleading to the directory root are ignored from the target object.","ref":"AWS.CloudDirectory.html#list_object_parent_paths/3","title":"AWS.CloudDirectory.list_object_parent_paths/3","type":"function"},{"doc":"Lists parent objects that are associated with a given object in pagination\nfashion.","ref":"AWS.CloudDirectory.html#list_object_parents/3","title":"AWS.CloudDirectory.list_object_parents/3","type":"function"},{"doc":"Returns policies attached to an object in pagination fashion.","ref":"AWS.CloudDirectory.html#list_object_policies/3","title":"AWS.CloudDirectory.list_object_policies/3","type":"function"},{"doc":"Returns a paginated list of all the outgoing `TypedLinkSpecifier` information\nfor an object.\n\nIt also supports filtering by typed link facet and identity attributes. For more\ninformation, see [Typed Links](https://docs.aws.amazon.com/clouddirectory/latest/developerguide/directory_objects_links.html#directory_objects_links_typedlink).","ref":"AWS.CloudDirectory.html#list_outgoing_typed_links/3","title":"AWS.CloudDirectory.list_outgoing_typed_links/3","type":"function"},{"doc":"Returns all of the `ObjectIdentifiers` to which a given policy is attached.","ref":"AWS.CloudDirectory.html#list_policy_attachments/3","title":"AWS.CloudDirectory.list_policy_attachments/3","type":"function"},{"doc":"Lists the major version families of each published schema.\n\nIf a major version ARN is provided as `SchemaArn`, the minor version revisions\nin that family are listed instead.","ref":"AWS.CloudDirectory.html#list_published_schema_arns/3","title":"AWS.CloudDirectory.list_published_schema_arns/3","type":"function"},{"doc":"Returns tags for a resource.\n\nTagging is currently supported only for directories with a limit of 50 tags per\ndirectory. All 50 tags are returned for a given directory with this API call.","ref":"AWS.CloudDirectory.html#list_tags_for_resource/3","title":"AWS.CloudDirectory.list_tags_for_resource/3","type":"function"},{"doc":"Returns a paginated list of all attribute definitions for a particular\n`TypedLinkFacet`.\n\nFor more information, see [Typed Links](https://docs.aws.amazon.com/clouddirectory/latest/developerguide/directory_objects_links.html#directory_objects_links_typedlink).","ref":"AWS.CloudDirectory.html#list_typed_link_facet_attributes/3","title":"AWS.CloudDirectory.list_typed_link_facet_attributes/3","type":"function"},{"doc":"Returns a paginated list of `TypedLink` facet names for a particular schema.\n\nFor more information, see [Typed Links](https://docs.aws.amazon.com/clouddirectory/latest/developerguide/directory_objects_links.html#directory_objects_links_typedlink).","ref":"AWS.CloudDirectory.html#list_typed_link_facet_names/3","title":"AWS.CloudDirectory.list_typed_link_facet_names/3","type":"function"},{"doc":"Lists all policies from the root of the `Directory` to the object specified.\n\nIf there are no policies present, an empty list is returned. If policies are\npresent, and if some objects don't have the policies attached, it returns the\n`ObjectIdentifier` for such objects. If policies are present, it returns\n`ObjectIdentifier`, `policyId`, and `policyType`. Paths that don't lead to the\nroot from the target object are ignored. For more information, see\n[Policies](https://docs.aws.amazon.com/clouddirectory/latest/developerguide/key_concepts_directory.html#key_concepts_policies).","ref":"AWS.CloudDirectory.html#lookup_policy/3","title":"AWS.CloudDirectory.lookup_policy/3","type":"function"},{"doc":"","ref":"AWS.CloudDirectory.html#metadata/0","title":"AWS.CloudDirectory.metadata/0","type":"function"},{"doc":"Publishes a development schema with a major version and a recommended minor\nversion.","ref":"AWS.CloudDirectory.html#publish_schema/3","title":"AWS.CloudDirectory.publish_schema/3","type":"function"},{"doc":"Allows a schema to be updated using JSON upload.\n\nOnly available for development schemas. See [JSON Schema Format](https://docs.aws.amazon.com/clouddirectory/latest/developerguide/schemas_jsonformat.html#schemas_json)\nfor more information.","ref":"AWS.CloudDirectory.html#put_schema_from_json/3","title":"AWS.CloudDirectory.put_schema_from_json/3","type":"function"},{"doc":"Removes the specified facet from the specified object.","ref":"AWS.CloudDirectory.html#remove_facet_from_object/3","title":"AWS.CloudDirectory.remove_facet_from_object/3","type":"function"},{"doc":"An API operation for adding tags to a resource.","ref":"AWS.CloudDirectory.html#tag_resource/3","title":"AWS.CloudDirectory.tag_resource/3","type":"function"},{"doc":"An API operation for removing tags from a resource.","ref":"AWS.CloudDirectory.html#untag_resource/3","title":"AWS.CloudDirectory.untag_resource/3","type":"function"},{"doc":"Does the following:\n\n  1.\n\nAdds new `Attributes`, `Rules`, or `ObjectTypes`.\n\n  2. Updates existing `Attributes`, `Rules`, or `ObjectTypes`.\n\n  3. Deletes existing `Attributes`, `Rules`, or `ObjectTypes`.","ref":"AWS.CloudDirectory.html#update_facet/3","title":"AWS.CloudDirectory.update_facet/3","type":"function"},{"doc":"Updates a given typed link’s attributes.\n\nAttributes to be updated must not contribute to the typed link’s identity, as\ndefined by its `IdentityAttributeOrder`.","ref":"AWS.CloudDirectory.html#update_link_attributes/3","title":"AWS.CloudDirectory.update_link_attributes/3","type":"function"},{"doc":"Updates a given object's attributes.","ref":"AWS.CloudDirectory.html#update_object_attributes/3","title":"AWS.CloudDirectory.update_object_attributes/3","type":"function"},{"doc":"Updates the schema name with a new name.\n\nOnly development schema names can be updated.","ref":"AWS.CloudDirectory.html#update_schema/3","title":"AWS.CloudDirectory.update_schema/3","type":"function"},{"doc":"Updates a `TypedLinkFacet`.\n\nFor more information, see [Typed Links](https://docs.aws.amazon.com/clouddirectory/latest/developerguide/directory_objects_links.html#directory_objects_links_typedlink).","ref":"AWS.CloudDirectory.html#update_typed_link_facet/3","title":"AWS.CloudDirectory.update_typed_link_facet/3","type":"function"},{"doc":"Upgrades a single directory in-place using the `PublishedSchemaArn` with schema\nupdates found in `MinorVersion`.\n\nBackwards-compatible minor version upgrades are instantaneously available for\nreaders on all objects in the directory. Note: This is a synchronous API call\nand upgrades only one schema on a given directory per call. To upgrade multiple\ndirectories from one schema, you would need to call this API on each directory.","ref":"AWS.CloudDirectory.html#upgrade_applied_schema/3","title":"AWS.CloudDirectory.upgrade_applied_schema/3","type":"function"},{"doc":"Upgrades a published schema under a new minor version revision using the current\ncontents of `DevelopmentSchemaArn`.","ref":"AWS.CloudDirectory.html#upgrade_published_schema/3","title":"AWS.CloudDirectory.upgrade_published_schema/3","type":"function"},{"doc":"CloudFormation\n\nCloudFormation allows you to create and manage Amazon Web Services\ninfrastructure deployments predictably and repeatedly.\n\nYou can use CloudFormation to leverage Amazon Web Services products, such as\nAmazon Elastic Compute Cloud, Amazon Elastic Block Store, Amazon Simple\nNotification Service, Elastic Load Balancing, and Auto Scaling to build highly\nreliable, highly scalable, cost-effective applications without creating or\nconfiguring the underlying Amazon Web Services infrastructure.\n\nWith CloudFormation, you declare all your resources and dependencies in a\ntemplate file. The template defines a collection of resources as a single unit\ncalled a stack. CloudFormation creates and deletes all member resources of the\nstack together and manages all dependencies between the resources for you.\n\nFor more information about CloudFormation, see the [CloudFormation product page](http://aws.amazon.com/cloudformation/).\n\nCloudFormation makes use of other Amazon Web Services products. If you need\nadditional technical information about a specific Amazon Web Services product,\nyou can find the product's technical documentation at\n[docs.aws.amazon.com](https://docs.aws.amazon.com/).","ref":"AWS.CloudFormation.html","title":"AWS.CloudFormation","type":"module"},{"doc":"Activate trusted access with Organizations.\n\nWith trusted access between StackSets and Organizations activated, the\nmanagement account has permissions to create and manage StackSets for your\norganization.","ref":"AWS.CloudFormation.html#activate_organizations_access/3","title":"AWS.CloudFormation.activate_organizations_access/3","type":"function"},{"doc":"Activates a public third-party extension, making it available for use in stack\ntemplates.\n\nFor more information, see [Using public extensions](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/registry-public.html)\nin the *CloudFormation User Guide*.\n\nOnce you have activated a public third-party extension in your account and\nRegion, use\n[SetTypeConfiguration](https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_SetTypeConfiguration.html) to specify configuration properties for the extension. For more information, see\n[Configuring extensions at the account\nlevel](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/registry-register.html#registry-set-configuration)\nin the *CloudFormation User Guide*.","ref":"AWS.CloudFormation.html#activate_type/3","title":"AWS.CloudFormation.activate_type/3","type":"function"},{"doc":"Returns configuration data for the specified CloudFormation extensions, from the\nCloudFormation registry for the account and Region.\n\nFor more information, see [Configuring extensions at the account level](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/registry-register.html#registry-set-configuration)\nin the *CloudFormation User Guide*.","ref":"AWS.CloudFormation.html#batch_describe_type_configurations/3","title":"AWS.CloudFormation.batch_describe_type_configurations/3","type":"function"},{"doc":"Cancels an update on the specified stack.\n\nIf the call completes successfully, the stack rolls back the update and reverts\nto the previous stack configuration.\n\nYou can cancel only stacks that are in the `UPDATE_IN_PROGRESS` state.","ref":"AWS.CloudFormation.html#cancel_update_stack/3","title":"AWS.CloudFormation.cancel_update_stack/3","type":"function"},{"doc":"For a specified stack that's in the `UPDATE_ROLLBACK_FAILED` state, continues\nrolling it back to the `UPDATE_ROLLBACK_COMPLETE` state.\n\nDepending on the cause of the failure, you can manually [ fix the error](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/troubleshooting.html#troubleshooting-errors-update-rollback-failed)\nand continue the rollback. By continuing the rollback, you can return your stack\nto a working state (the `UPDATE_ROLLBACK_COMPLETE` state), and then try to\nupdate the stack again.\n\nA stack goes into the `UPDATE_ROLLBACK_FAILED` state when CloudFormation can't\nroll back all changes after a failed stack update. For example, you might have a\nstack that's rolling back to an old database instance that was deleted outside\nof CloudFormation. Because CloudFormation doesn't know the database was deleted,\nit assumes that the database instance still exists and attempts to roll back to\nit, causing the update rollback to fail.","ref":"AWS.CloudFormation.html#continue_update_rollback/3","title":"AWS.CloudFormation.continue_update_rollback/3","type":"function"},{"doc":"Creates a list of changes that will be applied to a stack so that you can review\nthe changes before executing them.\n\nYou can create a change set for a stack that doesn't exist or an existing stack.\nIf you create a change set for a stack that doesn't exist, the change set shows\nall of the resources that CloudFormation will create. If you create a change set\nfor an existing stack, CloudFormation compares the stack's information with the\ninformation that you submit in the change set and lists the differences. Use\nchange sets to understand which resources CloudFormation will create or change,\nand how it will change resources in an existing stack, before you create or\nupdate a stack.\n\nTo create a change set for a stack that doesn't exist, for the `ChangeSetType`\nparameter, specify `CREATE`. To create a change set for an existing stack,\nspecify `UPDATE` for the `ChangeSetType` parameter. To create a change set for\nan import operation, specify `IMPORT` for the `ChangeSetType` parameter. After\nthe `CreateChangeSet` call successfully completes, CloudFormation starts\ncreating the change set. To check the status of the change set or to review it,\nuse the `DescribeChangeSet` action.\n\nWhen you are satisfied with the changes the change set will make, execute the\nchange set by using the `ExecuteChangeSet` action. CloudFormation doesn't make\nchanges until you execute the change set.\n\nTo create a change set for the entire stack hierarchy, set `IncludeNestedStacks`\nto `True`.","ref":"AWS.CloudFormation.html#create_change_set/3","title":"AWS.CloudFormation.create_change_set/3","type":"function"},{"doc":"Creates a template from existing resources that are not already managed with\nCloudFormation.\n\nYou can check the status of the template generation using the\n`DescribeGeneratedTemplate` API action.","ref":"AWS.CloudFormation.html#create_generated_template/3","title":"AWS.CloudFormation.create_generated_template/3","type":"function"},{"doc":"Creates a stack as specified in the template.\n\nAfter the call completes successfully, the stack creation starts. You can check\nthe status of the stack through the `DescribeStacks` operation.","ref":"AWS.CloudFormation.html#create_stack/3","title":"AWS.CloudFormation.create_stack/3","type":"function"},{"doc":"Creates stack instances for the specified accounts, within the specified Amazon\nWeb Services Regions.\n\nA stack instance refers to a stack in a specific account and Region. You must\nspecify at least one value for either `Accounts` or `DeploymentTargets`, and you\nmust specify at least one value for `Regions`.","ref":"AWS.CloudFormation.html#create_stack_instances/3","title":"AWS.CloudFormation.create_stack_instances/3","type":"function"},{"doc":"Creates a stack set.","ref":"AWS.CloudFormation.html#create_stack_set/3","title":"AWS.CloudFormation.create_stack_set/3","type":"function"},{"doc":"Deactivates trusted access with Organizations.\n\nIf trusted access is deactivated, the management account does not have\npermissions to create and manage service-managed StackSets for your\norganization.","ref":"AWS.CloudFormation.html#deactivate_organizations_access/3","title":"AWS.CloudFormation.deactivate_organizations_access/3","type":"function"},{"doc":"Deactivates a public extension that was previously activated in this account and\nRegion.\n\nOnce deactivated, an extension can't be used in any CloudFormation operation.\nThis includes stack update operations where the stack template includes the\nextension, even if no updates are being made to the extension. In addition,\ndeactivated extensions aren't automatically updated if a new version of the\nextension is released.","ref":"AWS.CloudFormation.html#deactivate_type/3","title":"AWS.CloudFormation.deactivate_type/3","type":"function"},{"doc":"Deletes the specified change set.\n\nDeleting change sets ensures that no one executes the wrong change set.\n\nIf the call successfully completes, CloudFormation successfully deleted the\nchange set.\n\nIf `IncludeNestedStacks` specifies `True` during the creation of the nested\nchange set, then `DeleteChangeSet` will delete all change sets that belong to\nthe stacks hierarchy and will also delete all change sets for nested stacks with\nthe status of `REVIEW_IN_PROGRESS`.","ref":"AWS.CloudFormation.html#delete_change_set/3","title":"AWS.CloudFormation.delete_change_set/3","type":"function"},{"doc":"Deleted a generated template.","ref":"AWS.CloudFormation.html#delete_generated_template/3","title":"AWS.CloudFormation.delete_generated_template/3","type":"function"},{"doc":"Deletes a specified stack.\n\nOnce the call completes successfully, stack deletion starts. Deleted stacks\ndon't show up in the `DescribeStacks` operation if the deletion has been\ncompleted successfully.","ref":"AWS.CloudFormation.html#delete_stack/3","title":"AWS.CloudFormation.delete_stack/3","type":"function"},{"doc":"Deletes stack instances for the specified accounts, in the specified Amazon Web\nServices Regions.","ref":"AWS.CloudFormation.html#delete_stack_instances/3","title":"AWS.CloudFormation.delete_stack_instances/3","type":"function"},{"doc":"Deletes a stack set.\n\nBefore you can delete a stack set, all its member stack instances must be\ndeleted. For more information about how to complete this, see\n`DeleteStackInstances`.","ref":"AWS.CloudFormation.html#delete_stack_set/3","title":"AWS.CloudFormation.delete_stack_set/3","type":"function"},{"doc":"Marks an extension or extension version as `DEPRECATED` in the CloudFormation\nregistry, removing it from active use.\n\nDeprecated extensions or extension versions cannot be used in CloudFormation\noperations.\n\nTo deregister an entire extension, you must individually deregister all active\nversions of that extension. If an extension has only a single active version,\nderegistering that version results in the extension itself being deregistered\nand marked as deprecated in the registry.\n\nYou can't deregister the default version of an extension if there are other\nactive version of that extension. If you do deregister the default version of an\nextension, the extension type itself is deregistered as well and marked as\ndeprecated.\n\nTo view the deprecation status of an extension or extension version, use\n[DescribeType](https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DescribeType.html).","ref":"AWS.CloudFormation.html#deregister_type/3","title":"AWS.CloudFormation.deregister_type/3","type":"function"},{"doc":"Retrieves your account's CloudFormation limits, such as the maximum number of\nstacks that you can create in your account.\n\nFor more information about account limits, see [CloudFormation Quotas](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/cloudformation-limits.html)\nin the *CloudFormation User Guide*.","ref":"AWS.CloudFormation.html#describe_account_limits/3","title":"AWS.CloudFormation.describe_account_limits/3","type":"function"},{"doc":"Returns the inputs for the change set and a list of changes that CloudFormation\nwill make if you execute the change set.\n\nFor more information, see [Updating Stacks Using Change Sets](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/using-cfn-updating-stacks-changesets.html)\nin the *CloudFormation User Guide*.","ref":"AWS.CloudFormation.html#describe_change_set/3","title":"AWS.CloudFormation.describe_change_set/3","type":"function"},{"doc":"Returns hook-related information for the change set and a list of changes that\nCloudFormation makes when you run the change set.","ref":"AWS.CloudFormation.html#describe_change_set_hooks/3","title":"AWS.CloudFormation.describe_change_set_hooks/3","type":"function"},{"doc":"Describes a generated template.\n\nThe output includes details about the progress of the creation of a generated\ntemplate started by a `CreateGeneratedTemplate` API action or the update of a\ngenerated template started with an `UpdateGeneratedTemplate` API action.","ref":"AWS.CloudFormation.html#describe_generated_template/3","title":"AWS.CloudFormation.describe_generated_template/3","type":"function"},{"doc":"Retrieves information about the account's `OrganizationAccess` status.\n\nThis API can be called either by the management account or the delegated\nadministrator by using the `CallAs` parameter. This API can also be called\nwithout the `CallAs` parameter by the management account.","ref":"AWS.CloudFormation.html#describe_organizations_access/3","title":"AWS.CloudFormation.describe_organizations_access/3","type":"function"},{"doc":"Returns information about a CloudFormation extension publisher.\n\nIf you don't supply a `PublisherId`, and you have registered as an extension\npublisher, `DescribePublisher` returns information about your own publisher\naccount.\n\nFor more information about registering as a publisher, see:\n\n  *\n[RegisterPublisher](https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_RegisterPublisher.html)     * [Publishing extensions to make them available for public\nuse](https://docs.aws.amazon.com/cloudformation-cli/latest/userguide/publish-extension.html)\nin the *CloudFormation CLI User Guide*","ref":"AWS.CloudFormation.html#describe_publisher/3","title":"AWS.CloudFormation.describe_publisher/3","type":"function"},{"doc":"Describes details of a resource scan.","ref":"AWS.CloudFormation.html#describe_resource_scan/3","title":"AWS.CloudFormation.describe_resource_scan/3","type":"function"},{"doc":"Returns information about a stack drift detection operation.\n\nA stack drift detection operation detects whether a stack's actual configuration\ndiffers, or has *drifted*, from its expected configuration, as defined in the\nstack template and any values specified as template parameters. A stack is\nconsidered to have drifted if one or more of its resources have drifted. For\nmore information about stack and resource drift, see [Detecting Unregulated Configuration Changes to Stacks and\nResources](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/using-cfn-stack-drift.html).\n\nUse `DetectStackDrift` to initiate a stack drift detection operation.\n`DetectStackDrift` returns a `StackDriftDetectionId` you can use to monitor the\nprogress of the operation using `DescribeStackDriftDetectionStatus`. Once the\ndrift detection operation has completed, use `DescribeStackResourceDrifts` to\nreturn drift information about the stack and its resources.","ref":"AWS.CloudFormation.html#describe_stack_drift_detection_status/3","title":"AWS.CloudFormation.describe_stack_drift_detection_status/3","type":"function"},{"doc":"Returns all stack related events for a specified stack in reverse chronological\norder.\n\nFor more information about a stack's event history, go to\n[Stacks](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/concept-stack.html)\nin the *CloudFormation User Guide*.\n\nYou can list events for stacks that have failed to create or have been deleted\nby specifying the unique stack identifier (stack ID).","ref":"AWS.CloudFormation.html#describe_stack_events/3","title":"AWS.CloudFormation.describe_stack_events/3","type":"function"},{"doc":"Returns the stack instance that's associated with the specified StackSet, Amazon\nWeb Services account, and Amazon Web Services Region.\n\nFor a list of stack instances that are associated with a specific StackSet, use\n`ListStackInstances`.","ref":"AWS.CloudFormation.html#describe_stack_instance/3","title":"AWS.CloudFormation.describe_stack_instance/3","type":"function"},{"doc":"Returns a description of the specified resource in the specified stack.\n\nFor deleted stacks, DescribeStackResource returns resource information for up to\n90 days after the stack has been deleted.","ref":"AWS.CloudFormation.html#describe_stack_resource/3","title":"AWS.CloudFormation.describe_stack_resource/3","type":"function"},{"doc":"Returns drift information for the resources that have been checked for drift in\nthe specified stack.\n\nThis includes actual and expected configuration values for resources where\nCloudFormation detects configuration drift.\n\nFor a given stack, there will be one `StackResourceDrift` for each stack\nresource that has been checked for drift. Resources that haven't yet been\nchecked for drift aren't included. Resources that don't currently support drift\ndetection aren't checked, and so not included. For a list of resources that\nsupport drift detection, see [Resources that Support Drift Detection](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/using-cfn-stack-drift-resource-list.html).\n\nUse `DetectStackResourceDrift` to detect drift on individual resources, or\n`DetectStackDrift` to detect drift on all supported resources for a given stack.","ref":"AWS.CloudFormation.html#describe_stack_resource_drifts/3","title":"AWS.CloudFormation.describe_stack_resource_drifts/3","type":"function"},{"doc":"Returns Amazon Web Services resource descriptions for running and deleted\nstacks.\n\nIf `StackName` is specified, all the associated resources that are part of the\nstack are returned. If `PhysicalResourceId` is specified, the associated\nresources of the stack that the resource belongs to are returned.\n\nOnly the first 100 resources will be returned. If your stack has more resources\nthan this, you should use `ListStackResources` instead.\n\nFor deleted stacks, `DescribeStackResources` returns resource information for up\nto 90 days after the stack has been deleted.\n\nYou must specify either `StackName` or `PhysicalResourceId`, but not both. In\naddition, you can specify `LogicalResourceId` to filter the returned result. For\nmore information about resources, the `LogicalResourceId` and\n`PhysicalResourceId`, go to the [CloudFormation User Guide](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/).\n\nA `ValidationError` is returned if you specify both `StackName` and\n`PhysicalResourceId` in the same request.","ref":"AWS.CloudFormation.html#describe_stack_resources/3","title":"AWS.CloudFormation.describe_stack_resources/3","type":"function"},{"doc":"Returns the description of the specified StackSet.","ref":"AWS.CloudFormation.html#describe_stack_set/3","title":"AWS.CloudFormation.describe_stack_set/3","type":"function"},{"doc":"Returns the description of the specified StackSet operation.","ref":"AWS.CloudFormation.html#describe_stack_set_operation/3","title":"AWS.CloudFormation.describe_stack_set_operation/3","type":"function"},{"doc":"Returns the description for the specified stack; if no stack name was specified,\nthen it returns the description for all the stacks created.\n\nIf the stack doesn't exist, a `ValidationError` is returned.","ref":"AWS.CloudFormation.html#describe_stacks/3","title":"AWS.CloudFormation.describe_stacks/3","type":"function"},{"doc":"Returns detailed information about an extension that has been registered.\n\nIf you specify a `VersionId`, `DescribeType` returns information about that\nspecific extension version. Otherwise, it returns information about the default\nextension version.","ref":"AWS.CloudFormation.html#describe_type/3","title":"AWS.CloudFormation.describe_type/3","type":"function"},{"doc":"Returns information about an extension's registration, including its current\nstatus and type and version identifiers.\n\nWhen you initiate a registration request using `RegisterType`, you can then use\n`DescribeTypeRegistration` to monitor the progress of that registration request.\n\nOnce the registration request has completed, use `DescribeType` to return\ndetailed information about an extension.","ref":"AWS.CloudFormation.html#describe_type_registration/3","title":"AWS.CloudFormation.describe_type_registration/3","type":"function"},{"doc":"Detects whether a stack's actual configuration differs, or has *drifted*, from\nits expected configuration, as defined in the stack template and any values\nspecified as template parameters.\n\nFor each resource in the stack that supports drift detection, CloudFormation\ncompares the actual configuration of the resource with its expected template\nconfiguration. Only resource properties explicitly defined in the stack template\nare checked for drift. A stack is considered to have drifted if one or more of\nits resources differ from their expected template configurations. For more\ninformation, see [Detecting Unregulated Configuration Changes to Stacks and Resources](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/using-cfn-stack-drift.html).\n\nUse `DetectStackDrift` to detect drift on all supported resources for a given\nstack, or `DetectStackResourceDrift` to detect drift on individual resources.\n\nFor a list of stack resources that currently support drift detection, see\n[Resources that Support Drift Detection](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/using-cfn-stack-drift-resource-list.html).\n\n`DetectStackDrift` can take up to several minutes, depending on the number of\nresources contained within the stack. Use `DescribeStackDriftDetectionStatus` to\nmonitor the progress of a detect stack drift operation. Once the drift detection\noperation has completed, use `DescribeStackResourceDrifts` to return drift\ninformation about the stack and its resources.\n\nWhen detecting drift on a stack, CloudFormation doesn't detect drift on any\nnested stacks belonging to that stack. Perform `DetectStackDrift` directly on\nthe nested stack itself.","ref":"AWS.CloudFormation.html#detect_stack_drift/3","title":"AWS.CloudFormation.detect_stack_drift/3","type":"function"},{"doc":"Returns information about whether a resource's actual configuration differs, or\nhas *drifted*, from its expected configuration, as defined in the stack template\nand any values specified as template parameters.\n\nThis information includes actual and expected property values for resources in\nwhich CloudFormation detects drift. Only resource properties explicitly defined\nin the stack template are checked for drift. For more information about stack\nand resource drift, see [Detecting Unregulated Configuration Changes to Stacks and\nResources](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/using-cfn-stack-drift.html).\n\nUse `DetectStackResourceDrift` to detect drift on individual resources, or\n`DetectStackDrift` to detect drift on all resources in a given stack that\nsupport drift detection.\n\nResources that don't currently support drift detection can't be checked. For a\nlist of resources that support drift detection, see [Resources that Support Drift\nDetection](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/using-cfn-stack-drift-resource-list.html).","ref":"AWS.CloudFormation.html#detect_stack_resource_drift/3","title":"AWS.CloudFormation.detect_stack_resource_drift/3","type":"function"},{"doc":"Detect drift on a stack set.\n\nWhen CloudFormation performs drift detection on a stack set, it performs drift\ndetection on the stack associated with each stack instance in the stack set. For\nmore information, see [How CloudFormation performs drift detection on a stack set](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/stacksets-drift.html).\n\n`DetectStackSetDrift` returns the `OperationId` of the stack set drift detection\noperation. Use this operation id with `DescribeStackSetOperation` to monitor the\nprogress of the drift detection operation. The drift detection operation may\ntake some time, depending on the number of stack instances included in the stack\nset, in addition to the number of resources included in each stack.\n\nOnce the operation has completed, use the following actions to return drift\ninformation:\n\n  * Use `DescribeStackSet` to return detailed information about the\nstack set, including detailed information about the last *completed* drift\noperation performed on the stack set. (Information about drift operations that\nare in progress isn't included.)\n\n  * Use `ListStackInstances` to return a list of stack instances\nbelonging to the stack set, including the drift status and last drift time\nchecked of each instance.\n\n  * Use `DescribeStackInstance` to return detailed information about a\nspecific stack instance, including its drift status and last drift time checked.\n\nFor more information about performing a drift detection operation on a stack\nset, see [Detecting unmanaged changes in stack sets](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/stacksets-drift.html).\n\nYou can only run a single drift detection operation on a given stack set at one\ntime.\n\nTo stop a drift detection stack set operation, use `StopStackSetOperation`.","ref":"AWS.CloudFormation.html#detect_stack_set_drift/3","title":"AWS.CloudFormation.detect_stack_set_drift/3","type":"function"},{"doc":"Returns the estimated monthly cost of a template.\n\nThe return value is an Amazon Web Services Simple Monthly Calculator URL with a\nquery string that describes the resources required to run the template.","ref":"AWS.CloudFormation.html#estimate_template_cost/3","title":"AWS.CloudFormation.estimate_template_cost/3","type":"function"},{"doc":"Updates a stack using the input information that was provided when the specified\nchange set was created.\n\nAfter the call successfully completes, CloudFormation starts updating the stack.\nUse the `DescribeStacks` action to view the status of the update.\n\nWhen you execute a change set, CloudFormation deletes all other change sets\nassociated with the stack because they aren't valid for the updated stack.\n\nIf a stack policy is associated with the stack, CloudFormation enforces the\npolicy during the update. You can't specify a temporary stack policy that\noverrides the current policy.\n\nTo create a change set for the entire stack hierarchy, `IncludeNestedStacks`\nmust have been set to `True`.","ref":"AWS.CloudFormation.html#execute_change_set/3","title":"AWS.CloudFormation.execute_change_set/3","type":"function"},{"doc":"Retrieves a generated template.\n\nIf the template is in an `InProgress` or `Pending` status then the template\nreturned will be the template when the template was last in a `Complete` status.\nIf the template has not yet been in a `Complete` status then an empty template\nwill be returned.","ref":"AWS.CloudFormation.html#get_generated_template/3","title":"AWS.CloudFormation.get_generated_template/3","type":"function"},{"doc":"Returns the stack policy for a specified stack.\n\nIf a stack doesn't have a policy, a null value is returned.","ref":"AWS.CloudFormation.html#get_stack_policy/3","title":"AWS.CloudFormation.get_stack_policy/3","type":"function"},{"doc":"Returns the template body for a specified stack.\n\nYou can get the template for running or deleted stacks.\n\nFor deleted stacks, `GetTemplate` returns the template for up to 90 days after\nthe stack has been deleted.\n\nIf the template doesn't exist, a `ValidationError` is returned.","ref":"AWS.CloudFormation.html#get_template/3","title":"AWS.CloudFormation.get_template/3","type":"function"},{"doc":"Returns information about a new or existing template.\n\nThe `GetTemplateSummary` action is useful for viewing parameter information,\nsuch as default parameter values and parameter types, before you create or\nupdate a stack or stack set.\n\nYou can use the `GetTemplateSummary` action when you submit a template, or you\ncan get template information for a stack set, or a running or deleted stack.\n\nFor deleted stacks, `GetTemplateSummary` returns the template information for up\nto 90 days after the stack has been deleted. If the template doesn't exist, a\n`ValidationError` is returned.","ref":"AWS.CloudFormation.html#get_template_summary/3","title":"AWS.CloudFormation.get_template_summary/3","type":"function"},{"doc":"Import existing stacks into a new stack sets.\n\nUse the stack import operation to import up to 10 stacks into a new stack set in\nthe same account as the source stack or in a different administrator account and\nRegion, by specifying the stack ID of the stack you intend to import.","ref":"AWS.CloudFormation.html#import_stacks_to_stack_set/3","title":"AWS.CloudFormation.import_stacks_to_stack_set/3","type":"function"},{"doc":"Returns the ID and status of each active change set for a stack.\n\nFor example, CloudFormation lists change sets that are in the\n`CREATE_IN_PROGRESS` or `CREATE_PENDING` state.","ref":"AWS.CloudFormation.html#list_change_sets/3","title":"AWS.CloudFormation.list_change_sets/3","type":"function"},{"doc":"Lists all exported output values in the account and Region in which you call\nthis action.\n\nUse this action to see the exported output values that you can import into other\nstacks. To import values, use the [\nFn::ImportValue](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/intrinsic-function-reference-importvalue.html)\nfunction.\n\nFor more information, see [ CloudFormation export stack output values](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/using-cfn-stack-exports.html).","ref":"AWS.CloudFormation.html#list_exports/3","title":"AWS.CloudFormation.list_exports/3","type":"function"},{"doc":"Lists your generated templates in this Region.","ref":"AWS.CloudFormation.html#list_generated_templates/3","title":"AWS.CloudFormation.list_generated_templates/3","type":"function"},{"doc":"Lists all stacks that are importing an exported output value.\n\nTo modify or remove an exported output value, first use this action to see which\nstacks are using it. To see the exported output values in your account, see\n`ListExports`.\n\nFor more information about importing an exported output value, see the\n[Fn::ImportValue](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/intrinsic-function-reference-importvalue.html)\nfunction.","ref":"AWS.CloudFormation.html#list_imports/3","title":"AWS.CloudFormation.list_imports/3","type":"function"},{"doc":"Lists the related resources for a list of resources from a resource scan.\n\nThe response indicates whether each returned resource is already managed by\nCloudFormation.","ref":"AWS.CloudFormation.html#list_resource_scan_related_resources/3","title":"AWS.CloudFormation.list_resource_scan_related_resources/3","type":"function"},{"doc":"Lists the resources from a resource scan.\n\nThe results can be filtered by resource identifier, resource type prefix, tag\nkey, and tag value. Only resources that match all specified filters are\nreturned. The response indicates whether each returned resource is already\nmanaged by CloudFormation.","ref":"AWS.CloudFormation.html#list_resource_scan_resources/3","title":"AWS.CloudFormation.list_resource_scan_resources/3","type":"function"},{"doc":"List the resource scans from newest to oldest.\n\nBy default it will return up to 10 resource scans.","ref":"AWS.CloudFormation.html#list_resource_scans/3","title":"AWS.CloudFormation.list_resource_scans/3","type":"function"},{"doc":"Returns drift information for resources in a stack instance.\n\n`ListStackInstanceResourceDrifts` returns drift information for the most recent\ndrift detection operation. If an operation is in progress, it may only return\npartial results.","ref":"AWS.CloudFormation.html#list_stack_instance_resource_drifts/3","title":"AWS.CloudFormation.list_stack_instance_resource_drifts/3","type":"function"},{"doc":"Returns summary information about stack instances that are associated with the\nspecified stack set.\n\nYou can filter for stack instances that are associated with a specific Amazon\nWeb Services account name or Region, or that have a specific status.","ref":"AWS.CloudFormation.html#list_stack_instances/3","title":"AWS.CloudFormation.list_stack_instances/3","type":"function"},{"doc":"Returns descriptions of all resources of the specified stack.\n\nFor deleted stacks, ListStackResources returns resource information for up to 90\ndays after the stack has been deleted.","ref":"AWS.CloudFormation.html#list_stack_resources/3","title":"AWS.CloudFormation.list_stack_resources/3","type":"function"},{"doc":"Returns summary information about the results of a stack set operation.","ref":"AWS.CloudFormation.html#list_stack_set_operation_results/3","title":"AWS.CloudFormation.list_stack_set_operation_results/3","type":"function"},{"doc":"Returns summary information about operations performed on a stack set.","ref":"AWS.CloudFormation.html#list_stack_set_operations/3","title":"AWS.CloudFormation.list_stack_set_operations/3","type":"function"},{"doc":"Returns summary information about stack sets that are associated with the user.\n\n  * [Self-managed permissions] If you set the `CallAs` parameter to `SELF` while signed in to your Amazon Web Services account, `ListStackSets`\nreturns all self-managed stack sets in your Amazon Web Services account.\n\n  * [Service-managed permissions] If you set the `CallAs` parameter to\n`SELF` while signed in to the organization's management account, `ListStackSets`\nreturns all stack sets in the management account.\n\n  * [Service-managed permissions] If you set the `CallAs` parameter to\n`DELEGATED_ADMIN` while signed in to your member account, `ListStackSets`\nreturns all stack sets with service-managed permissions in the management\naccount.","ref":"AWS.CloudFormation.html#list_stack_sets/3","title":"AWS.CloudFormation.list_stack_sets/3","type":"function"},{"doc":"Returns the summary information for stacks whose status matches the specified\nStackStatusFilter.\n\nSummary information for stacks that have been deleted is kept for 90 days after\nthe stack is deleted. If no StackStatusFilter is specified, summary information\nfor all stacks is returned (including existing stacks and stacks that have been\ndeleted).","ref":"AWS.CloudFormation.html#list_stacks/3","title":"AWS.CloudFormation.list_stacks/3","type":"function"},{"doc":"Returns a list of registration tokens for the specified extension(s).","ref":"AWS.CloudFormation.html#list_type_registrations/3","title":"AWS.CloudFormation.list_type_registrations/3","type":"function"},{"doc":"Returns summary information about the versions of an extension.","ref":"AWS.CloudFormation.html#list_type_versions/3","title":"AWS.CloudFormation.list_type_versions/3","type":"function"},{"doc":"Returns summary information about extension that have been registered with\nCloudFormation.","ref":"AWS.CloudFormation.html#list_types/3","title":"AWS.CloudFormation.list_types/3","type":"function"},{"doc":"","ref":"AWS.CloudFormation.html#metadata/0","title":"AWS.CloudFormation.metadata/0","type":"function"},{"doc":"Publishes the specified extension to the CloudFormation registry as a public\nextension in this Region.\n\nPublic extensions are available for use by all CloudFormation users. For more\ninformation about publishing extensions, see [Publishing extensions to make them available for public\nuse](https://docs.aws.amazon.com/cloudformation-cli/latest/userguide/publish-extension.html)\nin the *CloudFormation CLI User Guide*.\n\nTo publish an extension, you must be registered as a publisher with\nCloudFormation. For more information, see\n[RegisterPublisher](https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_RegisterPublisher.html).","ref":"AWS.CloudFormation.html#publish_type/3","title":"AWS.CloudFormation.publish_type/3","type":"function"},{"doc":"Reports progress of a resource handler to CloudFormation.\n\nReserved for use by the [CloudFormation CLI](https://docs.aws.amazon.com/cloudformation-cli/latest/userguide/what-is-cloudformation-cli.html).\nDon't use this API in your code.","ref":"AWS.CloudFormation.html#record_handler_progress/3","title":"AWS.CloudFormation.record_handler_progress/3","type":"function"},{"doc":"Registers your account as a publisher of public extensions in the CloudFormation\nregistry.\n\nPublic extensions are available for use by all CloudFormation users. This\npublisher ID applies to your account in all Amazon Web Services Regions.\n\nFor information about requirements for registering as a public extension\npublisher, see [Registering your account to publish CloudFormation extensions](https://docs.aws.amazon.com/cloudformation-cli/latest/userguide/publish-extension.html#publish-extension-prereqs)\nin the *CloudFormation CLI User Guide*.","ref":"AWS.CloudFormation.html#register_publisher/3","title":"AWS.CloudFormation.register_publisher/3","type":"function"},{"doc":"Registers an extension with the CloudFormation service.\n\nRegistering an extension makes it available for use in CloudFormation templates\nin your Amazon Web Services account, and includes:\n\n  * Validating the extension schema.\n\n  * Determining which handlers, if any, have been specified for the\nextension.\n\n  * Making the extension available for use in your account.\n\nFor more information about how to develop extensions and ready them for\nregistration, see [Creating Resource Providers](https://docs.aws.amazon.com/cloudformation-cli/latest/userguide/resource-types.html)\nin the *CloudFormation CLI User Guide*.\n\nYou can have a maximum of 50 resource extension versions registered at a time.\nThis maximum is per account and per Region. Use\n[DeregisterType](https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DeregisterType.html) to deregister specific extension versions if necessary.\n\nOnce you have initiated a registration request using `RegisterType`, you can use\n`DescribeTypeRegistration` to monitor the progress of the registration request.\n\nOnce you have registered a private extension in your account and Region, use\n[SetTypeConfiguration](https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_SetTypeConfiguration.html)\nto specify configuration properties for the extension. For more information, see\n[Configuring extensions at the account level](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/registry-register.html#registry-set-configuration)\nin the *CloudFormation User Guide*.","ref":"AWS.CloudFormation.html#register_type/3","title":"AWS.CloudFormation.register_type/3","type":"function"},{"doc":"When specifying `RollbackStack`, you preserve the state of previously\nprovisioned resources when an operation fails.\n\nYou can check the status of the stack through the `DescribeStacks` operation.\n\nRolls back the specified stack to the last known stable state from\n`CREATE_FAILED` or `UPDATE_FAILED` stack statuses.\n\nThis operation will delete a stack if it doesn't contain a last known stable\nstate. A last known stable state includes any status in a `*_COMPLETE`. This\nincludes the following stack statuses.\n\n  * `CREATE_COMPLETE`\n\n  * `UPDATE_COMPLETE`\n\n  * `UPDATE_ROLLBACK_COMPLETE`\n\n  * `IMPORT_COMPLETE`\n\n  * `IMPORT_ROLLBACK_COMPLETE`","ref":"AWS.CloudFormation.html#rollback_stack/3","title":"AWS.CloudFormation.rollback_stack/3","type":"function"},{"doc":"Sets a stack policy for a specified stack.","ref":"AWS.CloudFormation.html#set_stack_policy/3","title":"AWS.CloudFormation.set_stack_policy/3","type":"function"},{"doc":"Specifies the configuration data for a registered CloudFormation extension, in\nthe given account and Region.\n\nTo view the current configuration data for an extension, refer to the\n`ConfigurationSchema` element of\n[DescribeType](https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DescribeType.html). For more information, see [Configuring extensions at the account\nlevel](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/registry-register.html#registry-set-configuration)\nin the *CloudFormation User Guide*.\n\nIt's strongly recommended that you use dynamic references to restrict sensitive\nconfiguration definitions, such as third-party credentials. For more details on\ndynamic references, see [Using dynamic references to specify template values](https://docs.aws.amazon.com/) in the *CloudFormation User Guide*.","ref":"AWS.CloudFormation.html#set_type_configuration/3","title":"AWS.CloudFormation.set_type_configuration/3","type":"function"},{"doc":"Specify the default version of an extension.\n\nThe default version of an extension will be used in CloudFormation operations.","ref":"AWS.CloudFormation.html#set_type_default_version/3","title":"AWS.CloudFormation.set_type_default_version/3","type":"function"},{"doc":"Sends a signal to the specified resource with a success or failure status.\n\nYou can use the `SignalResource` operation in conjunction with a creation policy\nor update policy. CloudFormation doesn't proceed with a stack creation or update\nuntil resources receive the required number of signals or the timeout period is\nexceeded. The `SignalResource` operation is useful in cases where you want to\nsend signals from anywhere other than an Amazon EC2 instance.","ref":"AWS.CloudFormation.html#signal_resource/3","title":"AWS.CloudFormation.signal_resource/3","type":"function"},{"doc":"Starts a scan of the resources in this account in this Region.\n\nYou can the status of a scan using the `ListResourceScans` API action.","ref":"AWS.CloudFormation.html#start_resource_scan/3","title":"AWS.CloudFormation.start_resource_scan/3","type":"function"},{"doc":"Stops an in-progress operation on a stack set and its associated stack\ninstances.\n\nStackSets will cancel all the unstarted stack instance deployments and wait for\nthose are in-progress to complete.","ref":"AWS.CloudFormation.html#stop_stack_set_operation/3","title":"AWS.CloudFormation.stop_stack_set_operation/3","type":"function"},{"doc":"Tests a registered extension to make sure it meets all necessary requirements\nfor being published in the CloudFormation registry.\n\n  * For resource types, this includes passing all contracts tests\ndefined for the type.\n\n  * For modules, this includes determining if the module's model meets\nall necessary requirements.\n\nFor more information, see [Testing your public extension prior to publishing](https://docs.aws.amazon.com/cloudformation-cli/latest/userguide/publish-extension.html#publish-extension-testing)\nin the *CloudFormation CLI User Guide*.\n\nIf you don't specify a version, CloudFormation uses the default version of the\nextension in your account and Region for testing.\n\nTo perform testing, CloudFormation assumes the execution role specified when the\ntype was registered. For more information, see\n[RegisterType](https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_RegisterType.html).  Once you've initiated testing on an extension using `TestType`, you can pass the\nreturned `TypeVersionArn` into\n[DescribeType](https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DescribeType.html)\nto monitor the current test status and test status description for the\nextension.\n\nAn extension must have a test status of `PASSED` before it can be published. For\nmore information, see [Publishing extensions to make them available for public use](https://docs.aws.amazon.com/cloudformation-cli/latest/userguide/resource-type-publish.html)\nin the *CloudFormation CLI User Guide*.","ref":"AWS.CloudFormation.html#test_type/3","title":"AWS.CloudFormation.test_type/3","type":"function"},{"doc":"Updates a generated template.\n\nThis can be used to change the name, add and remove resources, refresh\nresources, and change the `DeletionPolicy` and `UpdateReplacePolicy` settings.\nYou can check the status of the update to the generated template using the\n`DescribeGeneratedTemplate` API action.","ref":"AWS.CloudFormation.html#update_generated_template/3","title":"AWS.CloudFormation.update_generated_template/3","type":"function"},{"doc":"Updates a stack as specified in the template.\n\nAfter the call completes successfully, the stack update starts. You can check\nthe status of the stack through the `DescribeStacks` action.\n\nTo get a copy of the template for an existing stack, you can use the\n`GetTemplate` action.\n\nFor more information about creating an update template, updating a stack, and\nmonitoring the progress of the update, see [Updating a Stack](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/using-cfn-updating-stacks.html).","ref":"AWS.CloudFormation.html#update_stack/3","title":"AWS.CloudFormation.update_stack/3","type":"function"},{"doc":"Updates the parameter values for stack instances for the specified accounts,\nwithin the specified Amazon Web Services Regions.\n\nA stack instance refers to a stack in a specific account and Region.\n\nYou can only update stack instances in Amazon Web Services Regions and accounts\nwhere they already exist; to create additional stack instances, use\n[CreateStackInstances](https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_CreateStackInstances.html).  During stack set updates, any parameters overridden for a stack instance aren't\nupdated, but retain their overridden value.\n\nYou can only update the parameter *values* that are specified in the stack set;\nto add or delete a parameter itself, use\n[UpdateStackSet](https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_UpdateStackSet.html)\nto update the stack set template. If you add a parameter to a template, before\nyou can override the parameter value specified in the stack set you must first\nuse\n[UpdateStackSet](https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_UpdateStackSet.html)\nto update all stack instances with the updated template and parameter value\nspecified in the stack set. Once a stack instance has been updated with the new\nparameter, you can then override the parameter value using\n`UpdateStackInstances`.","ref":"AWS.CloudFormation.html#update_stack_instances/3","title":"AWS.CloudFormation.update_stack_instances/3","type":"function"},{"doc":"Updates the stack set, and associated stack instances in the specified accounts\nand Amazon Web Services Regions.\n\nEven if the stack set operation created by updating the stack set fails\n(completely or partially, below or above a specified failure tolerance), the\nstack set is updated with your changes. Subsequent `CreateStackInstances` calls\non the specified stack set use the updated stack set.","ref":"AWS.CloudFormation.html#update_stack_set/3","title":"AWS.CloudFormation.update_stack_set/3","type":"function"},{"doc":"Updates termination protection for the specified stack.\n\nIf a user attempts to delete a stack with termination protection enabled, the\noperation fails and the stack remains unchanged. For more information, see\n[Protecting a Stack From Being Deleted](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/using-cfn-protect-stacks.html)\nin the *CloudFormation User Guide*.\n\nFor [nested stacks](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/using-cfn-nested-stacks.html),\ntermination protection is set on the root stack and can't be changed directly on\nthe nested stack.","ref":"AWS.CloudFormation.html#update_termination_protection/3","title":"AWS.CloudFormation.update_termination_protection/3","type":"function"},{"doc":"Validates a specified template.\n\nCloudFormation first checks if the template is valid JSON. If it isn't,\nCloudFormation checks if the template is valid YAML. If both these checks fail,\nCloudFormation returns a template validation error.","ref":"AWS.CloudFormation.html#validate_template/3","title":"AWS.CloudFormation.validate_template/3","type":"function"},{"doc":"Amazon CloudFront\n\nThis is the *Amazon CloudFront API Reference*.\n\nThis guide is for developers who need detailed information about CloudFront API\nactions, data types, and errors. For detailed information about CloudFront\nfeatures, see the *Amazon CloudFront Developer Guide*.","ref":"AWS.CloudFront.html","title":"AWS.CloudFront","type":"module"},{"doc":"Associates an alias (also known as a CNAME or an alternate domain name) with a\nCloudFront distribution.\n\nWith this operation you can move an alias that's already in use on a CloudFront\ndistribution to a different distribution in one step. This prevents the downtime\nthat could occur if you first remove the alias from one distribution and then\nseparately add the alias to another distribution.\n\nTo use this operation to associate an alias with a distribution, you provide the\nalias and the ID of the target distribution for the alias. For more information,\nincluding how to set up the target distribution, prerequisites that you must\ncomplete, and other restrictions, see [Moving an alternate domain name to a different\ndistribution](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/CNAMEs.html#alternate-domain-names-move)\nin the *Amazon CloudFront Developer Guide*.","ref":"AWS.CloudFront.html#associate_alias/4","title":"AWS.CloudFront.associate_alias/4","type":"function"},{"doc":"Creates a staging distribution using the configuration of the provided primary\ndistribution.\n\nA staging distribution is a copy of an existing distribution (called the primary\ndistribution) that you can use in a continuous deployment workflow.\n\nAfter you create a staging distribution, you can use `UpdateDistribution` to\nmodify the staging distribution's configuration. Then you can use\n`CreateContinuousDeploymentPolicy` to incrementally move traffic to the staging\ndistribution.\n\nThis API operation requires the following IAM permissions:\n\n  *\n[GetDistribution](https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_GetDistribution.html)     *\n[CreateDistribution](https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_CreateDistribution.html)\n\n  *\n[CopyDistribution](https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_CopyDistribution.html)","ref":"AWS.CloudFront.html#copy_distribution/4","title":"AWS.CloudFront.copy_distribution/4","type":"function"},{"doc":"Creates a cache policy.\n\nAfter you create a cache policy, you can attach it to one or more cache\nbehaviors. When it's attached to a cache behavior, the cache policy determines\nthe following:\n\n  * The values that CloudFront includes in the *cache key*. These\nvalues can include HTTP headers, cookies, and URL query strings. CloudFront uses\nthe cache key to find an object in its cache that it can return to the viewer.\n\n  * The default, minimum, and maximum time to live (TTL) values that\nyou want objects to stay in the CloudFront cache.\n\nThe headers, cookies, and query strings that are included in the cache key are\nalso included in requests that CloudFront sends to the origin. CloudFront sends\na request when it can't find an object in its cache that matches the request's\ncache key. If you want to send values to the origin but *not* include them in\nthe cache key, use `OriginRequestPolicy`.\n\nFor more information about cache policies, see [Controlling the cache key](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/controlling-the-cache-key.html)\nin the *Amazon CloudFront Developer Guide*.","ref":"AWS.CloudFront.html#create_cache_policy/3","title":"AWS.CloudFront.create_cache_policy/3","type":"function"},{"doc":"Creates a new origin access identity.\n\nIf you're using Amazon S3 for your origin, you can use an origin access identity\nto require users to access your content using a CloudFront URL instead of the\nAmazon S3 URL. For more information about how to use origin access identities,\nsee [Serving Private Content through CloudFront](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/PrivateContent.html)\nin the *Amazon CloudFront Developer Guide*.","ref":"AWS.CloudFront.html#create_cloud_front_origin_access_identity/3","title":"AWS.CloudFront.create_cloud_front_origin_access_identity/3","type":"function"},{"doc":"Creates a continuous deployment policy that distributes traffic for a custom\ndomain name to two different CloudFront distributions.\n\nTo use a continuous deployment policy, first use `CopyDistribution` to create a\nstaging distribution, then use `UpdateDistribution` to modify the staging\ndistribution's configuration.\n\nAfter you create and update a staging distribution, you can use a continuous\ndeployment policy to incrementally move traffic to the staging distribution.\nThis workflow enables you to test changes to a distribution's configuration\nbefore moving all of your domain's production traffic to the new configuration.","ref":"AWS.CloudFront.html#create_continuous_deployment_policy/3","title":"AWS.CloudFront.create_continuous_deployment_policy/3","type":"function"},{"doc":"Creates a CloudFront distribution.","ref":"AWS.CloudFront.html#create_distribution/3","title":"AWS.CloudFront.create_distribution/3","type":"function"},{"doc":"Create a new distribution with tags.\n\nThis API operation requires the following IAM permissions:\n\n  *\n[CreateDistribution](https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_CreateDistribution.html)     *\n[TagResource](https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_TagResource.html)","ref":"AWS.CloudFront.html#create_distribution_with_tags/3","title":"AWS.CloudFront.create_distribution_with_tags/3","type":"function"},{"doc":"Create a new field-level encryption configuration.","ref":"AWS.CloudFront.html#create_field_level_encryption_config/3","title":"AWS.CloudFront.create_field_level_encryption_config/3","type":"function"},{"doc":"Create a field-level encryption profile.","ref":"AWS.CloudFront.html#create_field_level_encryption_profile/3","title":"AWS.CloudFront.create_field_level_encryption_profile/3","type":"function"},{"doc":"Creates a CloudFront function.\n\nTo create a function, you provide the function code and some configuration\ninformation about the function. The response contains an Amazon Resource Name\n(ARN) that uniquely identifies the function.\n\nWhen you create a function, it's in the `DEVELOPMENT` stage. In this stage, you\ncan test the function with `TestFunction`, and update it with `UpdateFunction`.\n\nWhen you're ready to use your function with a CloudFront distribution, use\n`PublishFunction` to copy the function from the `DEVELOPMENT` stage to `LIVE`.\nWhen it's live, you can attach the function to a distribution's cache behavior,\nusing the function's ARN.","ref":"AWS.CloudFront.html#create_function/3","title":"AWS.CloudFront.create_function/3","type":"function"},{"doc":"Create a new invalidation.","ref":"AWS.CloudFront.html#create_invalidation/4","title":"AWS.CloudFront.create_invalidation/4","type":"function"},{"doc":"Creates a key group that you can use with [CloudFront signed URLs and signed cookies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/PrivateContent.html).\n\nTo create a key group, you must specify at least one public key for the key\ngroup. After you create a key group, you can reference it from one or more cache\nbehaviors. When you reference a key group in a cache behavior, CloudFront\nrequires signed URLs or signed cookies for all requests that match the cache\nbehavior. The URLs or cookies must be signed with a private key whose\ncorresponding public key is in the key group. The signed URL or cookie contains\ninformation about which public key CloudFront should use to verify the\nsignature. For more information, see [Serving private content](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/PrivateContent.html)\nin the *Amazon CloudFront Developer Guide*.","ref":"AWS.CloudFront.html#create_key_group/3","title":"AWS.CloudFront.create_key_group/3","type":"function"},{"doc":"Specifies the Key Value Store resource to add to your account.\n\nIn your account, the Key Value Store names must be unique. You can also import\nKey Value Store data in JSON format from an S3 bucket by providing a valid\n`ImportSource` that you own.","ref":"AWS.CloudFront.html#create_key_value_store/3","title":"AWS.CloudFront.create_key_value_store/3","type":"function"},{"doc":"Enables additional CloudWatch metrics for the specified CloudFront distribution.\n\nThe additional metrics incur an additional cost.\n\nFor more information, see [Viewing additional CloudFront distribution metrics](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/viewing-cloudfront-metrics.html#monitoring-console.distributions-additional)\nin the *Amazon CloudFront Developer Guide*.","ref":"AWS.CloudFront.html#create_monitoring_subscription/4","title":"AWS.CloudFront.create_monitoring_subscription/4","type":"function"},{"doc":"Creates a new origin access control in CloudFront.\n\nAfter you create an origin access control, you can add it to an origin in a\nCloudFront distribution so that CloudFront sends authenticated (signed) requests\nto the origin.\n\nThis makes it possible to block public access to the origin, allowing viewers\n(users) to access the origin's content only through CloudFront.\n\nFor more information about using a CloudFront origin access control, see\n[Restricting access to an Amazon Web Services origin](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/private-content-restricting-access-to-origin.html)\nin the *Amazon CloudFront Developer Guide*.","ref":"AWS.CloudFront.html#create_origin_access_control/3","title":"AWS.CloudFront.create_origin_access_control/3","type":"function"},{"doc":"Creates an origin request policy.\n\nAfter you create an origin request policy, you can attach it to one or more\ncache behaviors. When it's attached to a cache behavior, the origin request\npolicy determines the values that CloudFront includes in requests that it sends\nto the origin. Each request that CloudFront sends to the origin includes the\nfollowing:\n\n  * The request body and the URL path (without the domain name) from\nthe viewer request.\n\n  * The headers that CloudFront automatically includes in every origin\nrequest, including `Host`, `User-Agent`, and `X-Amz-Cf-Id`.\n\n  * All HTTP headers, cookies, and URL query strings that are\nspecified in the cache policy or the origin request policy. These can include\nitems from the viewer request and, in the case of headers, additional ones that\nare added by CloudFront.\n\nCloudFront sends a request when it can't find a valid object in its cache that\nmatches the request. If you want to send values to the origin and also include\nthem in the cache key, use `CachePolicy`.\n\nFor more information about origin request policies, see [Controlling origin requests](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/controlling-origin-requests.html)\nin the *Amazon CloudFront Developer Guide*.","ref":"AWS.CloudFront.html#create_origin_request_policy/3","title":"AWS.CloudFront.create_origin_request_policy/3","type":"function"},{"doc":"Uploads a public key to CloudFront that you can use with [signed URLs and signed cookies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/PrivateContent.html),\nor with [field-level encryption](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/field-level-encryption.html).","ref":"AWS.CloudFront.html#create_public_key/3","title":"AWS.CloudFront.create_public_key/3","type":"function"},{"doc":"Creates a real-time log configuration.\n\nAfter you create a real-time log configuration, you can attach it to one or more\ncache behaviors to send real-time log data to the specified Amazon Kinesis data\nstream.\n\nFor more information about real-time log configurations, see [Real-time logs](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/real-time-logs.html)\nin the *Amazon CloudFront Developer Guide*.","ref":"AWS.CloudFront.html#create_realtime_log_config/3","title":"AWS.CloudFront.create_realtime_log_config/3","type":"function"},{"doc":"Creates a response headers policy.\n\nA response headers policy contains information about a set of HTTP headers. To\ncreate a response headers policy, you provide some metadata about the policy and\na set of configurations that specify the headers.\n\nAfter you create a response headers policy, you can use its ID to attach it to\none or more cache behaviors in a CloudFront distribution. When it's attached to\na cache behavior, the response headers policy affects the HTTP headers that\nCloudFront includes in HTTP responses to requests that match the cache behavior.\nCloudFront adds or removes response headers according to the configuration of\nthe response headers policy.\n\nFor more information, see [Adding or removing HTTP headers in CloudFront responses](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/modifying-response-headers.html)\nin the *Amazon CloudFront Developer Guide*.","ref":"AWS.CloudFront.html#create_response_headers_policy/3","title":"AWS.CloudFront.create_response_headers_policy/3","type":"function"},{"doc":"This API is deprecated.\n\nAmazon CloudFront is deprecating real-time messaging protocol (RTMP)\ndistributions on December 31, 2020. For more information, [read the announcement](http://forums.aws.amazon.com/ann.jspa?annID=7356) on the Amazon\nCloudFront discussion forum.","ref":"AWS.CloudFront.html#create_streaming_distribution/3","title":"AWS.CloudFront.create_streaming_distribution/3","type":"function"},{"doc":"This API is deprecated.\n\nAmazon CloudFront is deprecating real-time messaging protocol (RTMP)\ndistributions on December 31, 2020. For more information, [read the announcement](http://forums.aws.amazon.com/ann.jspa?annID=7356) on the Amazon\nCloudFront discussion forum.","ref":"AWS.CloudFront.html#create_streaming_distribution_with_tags/3","title":"AWS.CloudFront.create_streaming_distribution_with_tags/3","type":"function"},{"doc":"Deletes a cache policy.\n\nYou cannot delete a cache policy if it's attached to a cache behavior. First\nupdate your distributions to remove the cache policy from all cache behaviors,\nthen delete the cache policy.\n\nTo delete a cache policy, you must provide the policy's identifier and version.\nTo get these values, you can use `ListCachePolicies` or `GetCachePolicy`.","ref":"AWS.CloudFront.html#delete_cache_policy/4","title":"AWS.CloudFront.delete_cache_policy/4","type":"function"},{"doc":"Delete an origin access identity.","ref":"AWS.CloudFront.html#delete_cloud_front_origin_access_identity/4","title":"AWS.CloudFront.delete_cloud_front_origin_access_identity/4","type":"function"},{"doc":"Deletes a continuous deployment policy.\n\nYou cannot delete a continuous deployment policy that's attached to a primary\ndistribution. First update your distribution to remove the continuous deployment\npolicy, then you can delete the policy.","ref":"AWS.CloudFront.html#delete_continuous_deployment_policy/4","title":"AWS.CloudFront.delete_continuous_deployment_policy/4","type":"function"},{"doc":"Delete a distribution.","ref":"AWS.CloudFront.html#delete_distribution/4","title":"AWS.CloudFront.delete_distribution/4","type":"function"},{"doc":"Remove a field-level encryption configuration.","ref":"AWS.CloudFront.html#delete_field_level_encryption_config/4","title":"AWS.CloudFront.delete_field_level_encryption_config/4","type":"function"},{"doc":"Remove a field-level encryption profile.","ref":"AWS.CloudFront.html#delete_field_level_encryption_profile/4","title":"AWS.CloudFront.delete_field_level_encryption_profile/4","type":"function"},{"doc":"Deletes a CloudFront function.\n\nYou cannot delete a function if it's associated with a cache behavior. First,\nupdate your distributions to remove the function association from all cache\nbehaviors, then delete the function.\n\nTo delete a function, you must provide the function's name and version (`ETag`\nvalue). To get these values, you can use `ListFunctions` and `DescribeFunction`.","ref":"AWS.CloudFront.html#delete_function/4","title":"AWS.CloudFront.delete_function/4","type":"function"},{"doc":"Deletes a key group.\n\nYou cannot delete a key group that is referenced in a cache behavior. First\nupdate your distributions to remove the key group from all cache behaviors, then\ndelete the key group.\n\nTo delete a key group, you must provide the key group's identifier and version.\nTo get these values, use `ListKeyGroups` followed by `GetKeyGroup` or\n`GetKeyGroupConfig`.","ref":"AWS.CloudFront.html#delete_key_group/4","title":"AWS.CloudFront.delete_key_group/4","type":"function"},{"doc":"Specifies the Key Value Store to delete.","ref":"AWS.CloudFront.html#delete_key_value_store/4","title":"AWS.CloudFront.delete_key_value_store/4","type":"function"},{"doc":"Disables additional CloudWatch metrics for the specified CloudFront\ndistribution.","ref":"AWS.CloudFront.html#delete_monitoring_subscription/4","title":"AWS.CloudFront.delete_monitoring_subscription/4","type":"function"},{"doc":"Deletes a CloudFront origin access control.\n\nYou cannot delete an origin access control if it's in use. First, update all\ndistributions to remove the origin access control from all origins, then delete\nthe origin access control.","ref":"AWS.CloudFront.html#delete_origin_access_control/4","title":"AWS.CloudFront.delete_origin_access_control/4","type":"function"},{"doc":"Deletes an origin request policy.\n\nYou cannot delete an origin request policy if it's attached to any cache\nbehaviors. First update your distributions to remove the origin request policy\nfrom all cache behaviors, then delete the origin request policy.\n\nTo delete an origin request policy, you must provide the policy's identifier and\nversion. To get the identifier, you can use `ListOriginRequestPolicies` or\n`GetOriginRequestPolicy`.","ref":"AWS.CloudFront.html#delete_origin_request_policy/4","title":"AWS.CloudFront.delete_origin_request_policy/4","type":"function"},{"doc":"Remove a public key you previously added to CloudFront.","ref":"AWS.CloudFront.html#delete_public_key/4","title":"AWS.CloudFront.delete_public_key/4","type":"function"},{"doc":"Deletes a real-time log configuration.\n\nYou cannot delete a real-time log configuration if it's attached to a cache\nbehavior. First update your distributions to remove the real-time log\nconfiguration from all cache behaviors, then delete the real-time log\nconfiguration.\n\nTo delete a real-time log configuration, you can provide the configuration's\nname or its Amazon Resource Name (ARN). You must provide at least one. If you\nprovide both, CloudFront uses the name to identify the real-time log\nconfiguration to delete.","ref":"AWS.CloudFront.html#delete_realtime_log_config/3","title":"AWS.CloudFront.delete_realtime_log_config/3","type":"function"},{"doc":"Deletes a response headers policy.\n\nYou cannot delete a response headers policy if it's attached to a cache\nbehavior. First update your distributions to remove the response headers policy\nfrom all cache behaviors, then delete the response headers policy.\n\nTo delete a response headers policy, you must provide the policy's identifier\nand version. To get these values, you can use `ListResponseHeadersPolicies` or\n`GetResponseHeadersPolicy`.","ref":"AWS.CloudFront.html#delete_response_headers_policy/4","title":"AWS.CloudFront.delete_response_headers_policy/4","type":"function"},{"doc":"Delete a streaming distribution.\n\nTo delete an RTMP distribution using the CloudFront API, perform the following\nsteps.\n\n**To delete an RTMP distribution using the CloudFront API**:\n\n  1. Disable the RTMP distribution.\n\n  2. Submit a `GET Streaming Distribution Config` request to get the\ncurrent configuration and the `Etag` header for the distribution.\n\n  3. Update the XML document that was returned in the response to your\n`GET Streaming Distribution Config` request to change the value of `Enabled` to\n`false`.\n\n  4. Submit a `PUT Streaming Distribution Config` request to update\nthe configuration for your distribution. In the request body, include the XML\ndocument that you updated in Step 3. Then set the value of the HTTP `If-Match`\nheader to the value of the `ETag` header that CloudFront returned when you\nsubmitted the `GET Streaming Distribution Config` request in Step 2.\n\n  5. Review the response to the `PUT Streaming Distribution Config`\nrequest to confirm that the distribution was successfully disabled.\n\n  6. Submit a `GET Streaming Distribution Config` request to confirm\nthat your changes have propagated. When propagation is complete, the value of\n`Status` is `Deployed`.\n\n  7. Submit a `DELETE Streaming Distribution` request. Set the value\nof the HTTP `If-Match` header to the value of the `ETag` header that CloudFront\nreturned when you submitted the `GET Streaming Distribution Config` request in\nStep 2.\n\n  8. Review the response to your `DELETE Streaming Distribution`\nrequest to confirm that the distribution was successfully deleted.\n\nFor information about deleting a distribution using the CloudFront console, see\n[Deleting a Distribution](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/HowToDeleteDistribution.html)\nin the *Amazon CloudFront Developer Guide*.","ref":"AWS.CloudFront.html#delete_streaming_distribution/4","title":"AWS.CloudFront.delete_streaming_distribution/4","type":"function"},{"doc":"Gets configuration information and metadata about a CloudFront function, but not\nthe function's code.\n\nTo get a function's code, use `GetFunction`.\n\nTo get configuration information and metadata about a function, you must provide\nthe function's name and stage. To get these values, you can use `ListFunctions`.","ref":"AWS.CloudFront.html#describe_function/4","title":"AWS.CloudFront.describe_function/4","type":"function"},{"doc":"Specifies the Key Value Store and its configuration.","ref":"AWS.CloudFront.html#describe_key_value_store/3","title":"AWS.CloudFront.describe_key_value_store/3","type":"function"},{"doc":"Gets a cache policy, including the following metadata:\n\n  * The policy's identifier.\n\n  * The date and time when the policy was last modified.\n\nTo get a cache policy, you must provide the policy's identifier. If the cache\npolicy is attached to a distribution's cache behavior, you can get the policy's\nidentifier using `ListDistributions` or `GetDistribution`. If the cache policy\nis not attached to a cache behavior, you can get the identifier using\n`ListCachePolicies`.","ref":"AWS.CloudFront.html#get_cache_policy/3","title":"AWS.CloudFront.get_cache_policy/3","type":"function"},{"doc":"Gets a cache policy configuration.\n\nTo get a cache policy configuration, you must provide the policy's identifier.\nIf the cache policy is attached to a distribution's cache behavior, you can get\nthe policy's identifier using `ListDistributions` or `GetDistribution`. If the\ncache policy is not attached to a cache behavior, you can get the identifier\nusing `ListCachePolicies`.","ref":"AWS.CloudFront.html#get_cache_policy_config/3","title":"AWS.CloudFront.get_cache_policy_config/3","type":"function"},{"doc":"Get the information about an origin access identity.","ref":"AWS.CloudFront.html#get_cloud_front_origin_access_identity/3","title":"AWS.CloudFront.get_cloud_front_origin_access_identity/3","type":"function"},{"doc":"Get the configuration information about an origin access identity.","ref":"AWS.CloudFront.html#get_cloud_front_origin_access_identity_config/3","title":"AWS.CloudFront.get_cloud_front_origin_access_identity_config/3","type":"function"},{"doc":"Gets a continuous deployment policy, including metadata (the policy's identifier\nand the date and time when the policy was last modified).","ref":"AWS.CloudFront.html#get_continuous_deployment_policy/3","title":"AWS.CloudFront.get_continuous_deployment_policy/3","type":"function"},{"doc":"Gets configuration information about a continuous deployment policy.","ref":"AWS.CloudFront.html#get_continuous_deployment_policy_config/3","title":"AWS.CloudFront.get_continuous_deployment_policy_config/3","type":"function"},{"doc":"Get the information about a distribution.","ref":"AWS.CloudFront.html#get_distribution/3","title":"AWS.CloudFront.get_distribution/3","type":"function"},{"doc":"Get the configuration information about a distribution.","ref":"AWS.CloudFront.html#get_distribution_config/3","title":"AWS.CloudFront.get_distribution_config/3","type":"function"},{"doc":"Get the field-level encryption configuration information.","ref":"AWS.CloudFront.html#get_field_level_encryption/3","title":"AWS.CloudFront.get_field_level_encryption/3","type":"function"},{"doc":"Get the field-level encryption configuration information.","ref":"AWS.CloudFront.html#get_field_level_encryption_config/3","title":"AWS.CloudFront.get_field_level_encryption_config/3","type":"function"},{"doc":"Get the field-level encryption profile information.","ref":"AWS.CloudFront.html#get_field_level_encryption_profile/3","title":"AWS.CloudFront.get_field_level_encryption_profile/3","type":"function"},{"doc":"Get the field-level encryption profile configuration information.","ref":"AWS.CloudFront.html#get_field_level_encryption_profile_config/3","title":"AWS.CloudFront.get_field_level_encryption_profile_config/3","type":"function"},{"doc":"Gets the code of a CloudFront function.\n\nTo get configuration information and metadata about a function, use\n`DescribeFunction`.\n\nTo get a function's code, you must provide the function's name and stage. To get\nthese values, you can use `ListFunctions`.","ref":"AWS.CloudFront.html#get_function/4","title":"AWS.CloudFront.get_function/4","type":"function"},{"doc":"Get the information about an invalidation.","ref":"AWS.CloudFront.html#get_invalidation/4","title":"AWS.CloudFront.get_invalidation/4","type":"function"},{"doc":"Gets a key group, including the date and time when the key group was last\nmodified.\n\nTo get a key group, you must provide the key group's identifier. If the key\ngroup is referenced in a distribution's cache behavior, you can get the key\ngroup's identifier using `ListDistributions` or `GetDistribution`. If the key\ngroup is not referenced in a cache behavior, you can get the identifier using\n`ListKeyGroups`.","ref":"AWS.CloudFront.html#get_key_group/3","title":"AWS.CloudFront.get_key_group/3","type":"function"},{"doc":"Gets a key group configuration.\n\nTo get a key group configuration, you must provide the key group's identifier.\nIf the key group is referenced in a distribution's cache behavior, you can get\nthe key group's identifier using `ListDistributions` or `GetDistribution`. If\nthe key group is not referenced in a cache behavior, you can get the identifier\nusing `ListKeyGroups`.","ref":"AWS.CloudFront.html#get_key_group_config/3","title":"AWS.CloudFront.get_key_group_config/3","type":"function"},{"doc":"Gets information about whether additional CloudWatch metrics are enabled for the\nspecified CloudFront distribution.","ref":"AWS.CloudFront.html#get_monitoring_subscription/3","title":"AWS.CloudFront.get_monitoring_subscription/3","type":"function"},{"doc":"Gets a CloudFront origin access control, including its unique identifier.","ref":"AWS.CloudFront.html#get_origin_access_control/3","title":"AWS.CloudFront.get_origin_access_control/3","type":"function"},{"doc":"Gets a CloudFront origin access control configuration.","ref":"AWS.CloudFront.html#get_origin_access_control_config/3","title":"AWS.CloudFront.get_origin_access_control_config/3","type":"function"},{"doc":"Gets an origin request policy, including the following metadata:\n\n  * The policy's identifier.\n\n  * The date and time when the policy was last modified.\n\nTo get an origin request policy, you must provide the policy's identifier. If\nthe origin request policy is attached to a distribution's cache behavior, you\ncan get the policy's identifier using `ListDistributions` or `GetDistribution`.\nIf the origin request policy is not attached to a cache behavior, you can get\nthe identifier using `ListOriginRequestPolicies`.","ref":"AWS.CloudFront.html#get_origin_request_policy/3","title":"AWS.CloudFront.get_origin_request_policy/3","type":"function"},{"doc":"Gets an origin request policy configuration.\n\nTo get an origin request policy configuration, you must provide the policy's\nidentifier. If the origin request policy is attached to a distribution's cache\nbehavior, you can get the policy's identifier using `ListDistributions` or\n`GetDistribution`. If the origin request policy is not attached to a cache\nbehavior, you can get the identifier using `ListOriginRequestPolicies`.","ref":"AWS.CloudFront.html#get_origin_request_policy_config/3","title":"AWS.CloudFront.get_origin_request_policy_config/3","type":"function"},{"doc":"Gets a public key.","ref":"AWS.CloudFront.html#get_public_key/3","title":"AWS.CloudFront.get_public_key/3","type":"function"},{"doc":"Gets a public key configuration.","ref":"AWS.CloudFront.html#get_public_key_config/3","title":"AWS.CloudFront.get_public_key_config/3","type":"function"},{"doc":"Gets a real-time log configuration.\n\nTo get a real-time log configuration, you can provide the configuration's name\nor its Amazon Resource Name (ARN). You must provide at least one. If you provide\nboth, CloudFront uses the name to identify the real-time log configuration to\nget.","ref":"AWS.CloudFront.html#get_realtime_log_config/3","title":"AWS.CloudFront.get_realtime_log_config/3","type":"function"},{"doc":"Gets a response headers policy, including metadata (the policy's identifier and\nthe date and time when the policy was last modified).\n\nTo get a response headers policy, you must provide the policy's identifier. If\nthe response headers policy is attached to a distribution's cache behavior, you\ncan get the policy's identifier using `ListDistributions` or `GetDistribution`.\nIf the response headers policy is not attached to a cache behavior, you can get\nthe identifier using `ListResponseHeadersPolicies`.","ref":"AWS.CloudFront.html#get_response_headers_policy/3","title":"AWS.CloudFront.get_response_headers_policy/3","type":"function"},{"doc":"Gets a response headers policy configuration.\n\nTo get a response headers policy configuration, you must provide the policy's\nidentifier. If the response headers policy is attached to a distribution's cache\nbehavior, you can get the policy's identifier using `ListDistributions` or\n`GetDistribution`. If the response headers policy is not attached to a cache\nbehavior, you can get the identifier using `ListResponseHeadersPolicies`.","ref":"AWS.CloudFront.html#get_response_headers_policy_config/3","title":"AWS.CloudFront.get_response_headers_policy_config/3","type":"function"},{"doc":"Gets information about a specified RTMP distribution, including the distribution\nconfiguration.","ref":"AWS.CloudFront.html#get_streaming_distribution/3","title":"AWS.CloudFront.get_streaming_distribution/3","type":"function"},{"doc":"Get the configuration information about a streaming distribution.","ref":"AWS.CloudFront.html#get_streaming_distribution_config/3","title":"AWS.CloudFront.get_streaming_distribution_config/3","type":"function"},{"doc":"Gets a list of cache policies.\n\nYou can optionally apply a filter to return only the managed policies created by\nAmazon Web Services, or only the custom policies created in your Amazon Web\nServices account.\n\nYou can optionally specify the maximum number of items to receive in the\nresponse. If the total number of items in the list exceeds the maximum that you\nspecify, or the default maximum, the response is paginated. To get the next page\nof items, send a subsequent request that specifies the `NextMarker` value from\nthe current response as the `Marker` value in the subsequent request.","ref":"AWS.CloudFront.html#list_cache_policies/5","title":"AWS.CloudFront.list_cache_policies/5","type":"function"},{"doc":"Lists origin access identities.","ref":"AWS.CloudFront.html#list_cloud_front_origin_access_identities/4","title":"AWS.CloudFront.list_cloud_front_origin_access_identities/4","type":"function"},{"doc":"Gets a list of aliases (also called CNAMEs or alternate domain names) that\nconflict or overlap with the provided alias, and the associated CloudFront\ndistributions and Amazon Web Services accounts for each conflicting alias.\n\nIn the returned list, the distribution and account IDs are partially hidden,\nwhich allows you to identify the distributions and accounts that you own, but\nhelps to protect the information of ones that you don't own.\n\nUse this operation to find aliases that are in use in CloudFront that conflict\nor overlap with the provided alias. For example, if you provide\n`www.example.com` as input, the returned list can include `www.example.com` and\nthe overlapping wildcard alternate domain name (`*.example.com`), if they exist.\nIf you provide `*.example.com` as input, the returned list can include\n`*.example.com` and any alternate domain names covered by that wildcard (for\nexample, `www.example.com`, `test.example.com`, `dev.example.com`, and so on),\nif they exist.\n\nTo list conflicting aliases, you provide the alias to search and the ID of a\ndistribution in your account that has an attached SSL/TLS certificate that\nincludes the provided alias. For more information, including how to set up the\ndistribution and certificate, see [Moving an alternate domain name to a different\ndistribution](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/CNAMEs.html#alternate-domain-names-move)\nin the *Amazon CloudFront Developer Guide*.\n\nYou can optionally specify the maximum number of items to receive in the\nresponse. If the total number of items in the list exceeds the maximum that you\nspecify, or the default maximum, the response is paginated. To get the next page\nof items, send a subsequent request that specifies the `NextMarker` value from\nthe current response as the `Marker` value in the subsequent request.","ref":"AWS.CloudFront.html#list_conflicting_aliases/6","title":"AWS.CloudFront.list_conflicting_aliases/6","type":"function"},{"doc":"Gets a list of the continuous deployment policies in your Amazon Web Services\naccount.\n\nYou can optionally specify the maximum number of items to receive in the\nresponse. If the total number of items in the list exceeds the maximum that you\nspecify, or the default maximum, the response is paginated. To get the next page\nof items, send a subsequent request that specifies the `NextMarker` value from\nthe current response as the `Marker` value in the subsequent request.","ref":"AWS.CloudFront.html#list_continuous_deployment_policies/4","title":"AWS.CloudFront.list_continuous_deployment_policies/4","type":"function"},{"doc":"List CloudFront distributions.","ref":"AWS.CloudFront.html#list_distributions/4","title":"AWS.CloudFront.list_distributions/4","type":"function"},{"doc":"Gets a list of distribution IDs for distributions that have a cache behavior\nthat's associated with the specified cache policy.\n\nYou can optionally specify the maximum number of items to receive in the\nresponse. If the total number of items in the list exceeds the maximum that you\nspecify, or the default maximum, the response is paginated. To get the next page\nof items, send a subsequent request that specifies the `NextMarker` value from\nthe current response as the `Marker` value in the subsequent request.","ref":"AWS.CloudFront.html#list_distributions_by_cache_policy_id/5","title":"AWS.CloudFront.list_distributions_by_cache_policy_id/5","type":"function"},{"doc":"Gets a list of distribution IDs for distributions that have a cache behavior\nthat references the specified key group.\n\nYou can optionally specify the maximum number of items to receive in the\nresponse. If the total number of items in the list exceeds the maximum that you\nspecify, or the default maximum, the response is paginated. To get the next page\nof items, send a subsequent request that specifies the `NextMarker` value from\nthe current response as the `Marker` value in the subsequent request.","ref":"AWS.CloudFront.html#list_distributions_by_key_group/5","title":"AWS.CloudFront.list_distributions_by_key_group/5","type":"function"},{"doc":"Gets a list of distribution IDs for distributions that have a cache behavior\nthat's associated with the specified origin request policy.\n\nYou can optionally specify the maximum number of items to receive in the\nresponse. If the total number of items in the list exceeds the maximum that you\nspecify, or the default maximum, the response is paginated. To get the next page\nof items, send a subsequent request that specifies the `NextMarker` value from\nthe current response as the `Marker` value in the subsequent request.","ref":"AWS.CloudFront.html#list_distributions_by_origin_request_policy_id/5","title":"AWS.CloudFront.list_distributions_by_origin_request_policy_id/5","type":"function"},{"doc":"Gets a list of distributions that have a cache behavior that's associated with\nthe specified real-time log configuration.\n\nYou can specify the real-time log configuration by its name or its Amazon\nResource Name (ARN). You must provide at least one. If you provide both,\nCloudFront uses the name to identify the real-time log configuration to list\ndistributions for.\n\nYou can optionally specify the maximum number of items to receive in the\nresponse. If the total number of items in the list exceeds the maximum that you\nspecify, or the default maximum, the response is paginated. To get the next page\nof items, send a subsequent request that specifies the `NextMarker` value from\nthe current response as the `Marker` value in the subsequent request.","ref":"AWS.CloudFront.html#list_distributions_by_realtime_log_config/3","title":"AWS.CloudFront.list_distributions_by_realtime_log_config/3","type":"function"},{"doc":"Gets a list of distribution IDs for distributions that have a cache behavior\nthat's associated with the specified response headers policy.\n\nYou can optionally specify the maximum number of items to receive in the\nresponse. If the total number of items in the list exceeds the maximum that you\nspecify, or the default maximum, the response is paginated. To get the next page\nof items, send a subsequent request that specifies the `NextMarker` value from\nthe current response as the `Marker` value in the subsequent request.","ref":"AWS.CloudFront.html#list_distributions_by_response_headers_policy_id/5","title":"AWS.CloudFront.list_distributions_by_response_headers_policy_id/5","type":"function"},{"doc":"List the distributions that are associated with a specified WAF web ACL.","ref":"AWS.CloudFront.html#list_distributions_by_web_acl_id/5","title":"AWS.CloudFront.list_distributions_by_web_acl_id/5","type":"function"},{"doc":"List all field-level encryption configurations that have been created in\nCloudFront for this account.","ref":"AWS.CloudFront.html#list_field_level_encryption_configs/4","title":"AWS.CloudFront.list_field_level_encryption_configs/4","type":"function"},{"doc":"Request a list of field-level encryption profiles that have been created in\nCloudFront for this account.","ref":"AWS.CloudFront.html#list_field_level_encryption_profiles/4","title":"AWS.CloudFront.list_field_level_encryption_profiles/4","type":"function"},{"doc":"Gets a list of all CloudFront functions in your Amazon Web Services account.\n\nYou can optionally apply a filter to return only the functions that are in the\nspecified stage, either `DEVELOPMENT` or `LIVE`.\n\nYou can optionally specify the maximum number of items to receive in the\nresponse. If the total number of items in the list exceeds the maximum that you\nspecify, or the default maximum, the response is paginated. To get the next page\nof items, send a subsequent request that specifies the `NextMarker` value from\nthe current response as the `Marker` value in the subsequent request.","ref":"AWS.CloudFront.html#list_functions/5","title":"AWS.CloudFront.list_functions/5","type":"function"},{"doc":"Lists invalidation batches.","ref":"AWS.CloudFront.html#list_invalidations/5","title":"AWS.CloudFront.list_invalidations/5","type":"function"},{"doc":"Gets a list of key groups.\n\nYou can optionally specify the maximum number of items to receive in the\nresponse. If the total number of items in the list exceeds the maximum that you\nspecify, or the default maximum, the response is paginated. To get the next page\nof items, send a subsequent request that specifies the `NextMarker` value from\nthe current response as the `Marker` value in the subsequent request.","ref":"AWS.CloudFront.html#list_key_groups/4","title":"AWS.CloudFront.list_key_groups/4","type":"function"},{"doc":"Specifies the Key Value Stores to list.","ref":"AWS.CloudFront.html#list_key_value_stores/5","title":"AWS.CloudFront.list_key_value_stores/5","type":"function"},{"doc":"Gets the list of CloudFront origin access controls in this Amazon Web Services\naccount.\n\nYou can optionally specify the maximum number of items to receive in the\nresponse. If the total number of items in the list exceeds the maximum that you\nspecify, or the default maximum, the response is paginated. To get the next page\nof items, send another request that specifies the `NextMarker` value from the\ncurrent response as the `Marker` value in the next request.","ref":"AWS.CloudFront.html#list_origin_access_controls/4","title":"AWS.CloudFront.list_origin_access_controls/4","type":"function"},{"doc":"Gets a list of origin request policies.\n\nYou can optionally apply a filter to return only the managed policies created by\nAmazon Web Services, or only the custom policies created in your Amazon Web\nServices account.\n\nYou can optionally specify the maximum number of items to receive in the\nresponse. If the total number of items in the list exceeds the maximum that you\nspecify, or the default maximum, the response is paginated. To get the next page\nof items, send a subsequent request that specifies the `NextMarker` value from\nthe current response as the `Marker` value in the subsequent request.","ref":"AWS.CloudFront.html#list_origin_request_policies/5","title":"AWS.CloudFront.list_origin_request_policies/5","type":"function"},{"doc":"List all public keys that have been added to CloudFront for this account.","ref":"AWS.CloudFront.html#list_public_keys/4","title":"AWS.CloudFront.list_public_keys/4","type":"function"},{"doc":"Gets a list of real-time log configurations.\n\nYou can optionally specify the maximum number of items to receive in the\nresponse. If the total number of items in the list exceeds the maximum that you\nspecify, or the default maximum, the response is paginated. To get the next page\nof items, send a subsequent request that specifies the `NextMarker` value from\nthe current response as the `Marker` value in the subsequent request.","ref":"AWS.CloudFront.html#list_realtime_log_configs/4","title":"AWS.CloudFront.list_realtime_log_configs/4","type":"function"},{"doc":"Gets a list of response headers policies.\n\nYou can optionally apply a filter to get only the managed policies created by\nAmazon Web Services, or only the custom policies created in your Amazon Web\nServices account.\n\nYou can optionally specify the maximum number of items to receive in the\nresponse. If the total number of items in the list exceeds the maximum that you\nspecify, or the default maximum, the response is paginated. To get the next page\nof items, send a subsequent request that specifies the `NextMarker` value from\nthe current response as the `Marker` value in the subsequent request.","ref":"AWS.CloudFront.html#list_response_headers_policies/5","title":"AWS.CloudFront.list_response_headers_policies/5","type":"function"},{"doc":"List streaming distributions.","ref":"AWS.CloudFront.html#list_streaming_distributions/4","title":"AWS.CloudFront.list_streaming_distributions/4","type":"function"},{"doc":"List tags for a CloudFront resource.","ref":"AWS.CloudFront.html#list_tags_for_resource/3","title":"AWS.CloudFront.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.CloudFront.html#metadata/0","title":"AWS.CloudFront.metadata/0","type":"function"},{"doc":"Publishes a CloudFront function by copying the function code from the\n`DEVELOPMENT` stage to `LIVE`.\n\nThis automatically updates all cache behaviors that are using this function to\nuse the newly published copy in the `LIVE` stage.\n\nWhen a function is published to the `LIVE` stage, you can attach the function to\na distribution's cache behavior, using the function's Amazon Resource Name\n(ARN).\n\nTo publish a function, you must provide the function's name and version (`ETag`\nvalue). To get these values, you can use `ListFunctions` and `DescribeFunction`.","ref":"AWS.CloudFront.html#publish_function/4","title":"AWS.CloudFront.publish_function/4","type":"function"},{"doc":"Add tags to a CloudFront resource.","ref":"AWS.CloudFront.html#tag_resource/3","title":"AWS.CloudFront.tag_resource/3","type":"function"},{"doc":"Tests a CloudFront function.\n\nTo test a function, you provide an *event object* that represents an HTTP\nrequest or response that your CloudFront distribution could receive in\nproduction. CloudFront runs the function, passing it the event object that you\nprovided, and returns the function's result (the modified event object) in the\nresponse. The response also contains function logs and error messages, if any\nexist. For more information about testing functions, see [Testing functions](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/managing-functions.html#test-function)\nin the *Amazon CloudFront Developer Guide*.\n\nTo test a function, you provide the function's name and version (`ETag` value)\nalong with the event object. To get the function's name and version, you can use\n`ListFunctions` and `DescribeFunction`.","ref":"AWS.CloudFront.html#test_function/4","title":"AWS.CloudFront.test_function/4","type":"function"},{"doc":"Remove tags from a CloudFront resource.","ref":"AWS.CloudFront.html#untag_resource/3","title":"AWS.CloudFront.untag_resource/3","type":"function"},{"doc":"Updates a cache policy configuration.\n\nWhen you update a cache policy configuration, all the fields are updated with\nthe values provided in the request. You cannot update some fields independent of\nothers. To update a cache policy configuration:\n\n  1. Use `GetCachePolicyConfig` to get the current configuration.\n\n  2. Locally modify the fields in the cache policy configuration that\nyou want to update.\n\n  3. Call `UpdateCachePolicy` by providing the entire cache policy\nconfiguration, including the fields that you modified and those that you didn't.","ref":"AWS.CloudFront.html#update_cache_policy/4","title":"AWS.CloudFront.update_cache_policy/4","type":"function"},{"doc":"Update an origin access identity.","ref":"AWS.CloudFront.html#update_cloud_front_origin_access_identity/4","title":"AWS.CloudFront.update_cloud_front_origin_access_identity/4","type":"function"},{"doc":"Updates a continuous deployment policy.\n\nYou can update a continuous deployment policy to enable or disable it, to change\nthe percentage of traffic that it sends to the staging distribution, or to\nchange the staging distribution that it sends traffic to.\n\nWhen you update a continuous deployment policy configuration, all the fields are\nupdated with the values that are provided in the request. You cannot update some\nfields independent of others. To update a continuous deployment policy\nconfiguration:\n\n  1. Use `GetContinuousDeploymentPolicyConfig` to get the current\nconfiguration.\n\n  2. Locally modify the fields in the continuous deployment policy\nconfiguration that you want to update.\n\n  3. Use `UpdateContinuousDeploymentPolicy`, providing the entire\ncontinuous deployment policy configuration, including the fields that you\nmodified and those that you didn't.","ref":"AWS.CloudFront.html#update_continuous_deployment_policy/4","title":"AWS.CloudFront.update_continuous_deployment_policy/4","type":"function"},{"doc":"Updates the configuration for a CloudFront distribution.\n\nThe update process includes getting the current distribution configuration,\nupdating it to make your changes, and then submitting an `UpdateDistribution`\nrequest to make the updates.","ref":"AWS.CloudFront.html#update_distribution/4","title":"AWS.CloudFront.update_distribution/4","type":"function"},{"doc":"1. Use `GetDistributionConfig` to get the current configuration,\nincluding the version identifier (`ETag`).\n\n  2. Update the distribution configuration that was returned in the\nresponse. Note the following important requirements and restrictions:\n\n    * You must rename the `ETag` field to `IfMatch`, leaving\nthe value unchanged. (Set the value of `IfMatch` to the value of `ETag`, then\nremove the `ETag` field.)\n\n    * You can't change the value of `CallerReference`.\n\n  3. Submit an `UpdateDistribution` request, providing the\ndistribution configuration. The new configuration replaces the existing\nconfiguration. The values that you specify in an `UpdateDistribution` request\nare not merged into your existing configuration. Make sure to include all\nfields: the ones that you modified and also the ones that you didn't.","ref":"AWS.CloudFront.html#update_distribution/4-to-update-a-web-distribution-using-the-cloudfront-api","title":"To update a web distribution using the CloudFront API - AWS.CloudFront.update_distribution/4","type":"function"},{"doc":"Copies the staging distribution's configuration to its corresponding primary\ndistribution.\n\nThe primary distribution retains its `Aliases` (also known as alternate domain\nnames or CNAMEs) and `ContinuousDeploymentPolicyId` value, but otherwise its\nconfiguration is overwritten to match the staging distribution.\n\nYou can use this operation in a continuous deployment workflow after you have\ntested configuration changes on the staging distribution. After using a\ncontinuous deployment policy to move a portion of your domain name's traffic to\nthe staging distribution and verifying that it works as intended, you can use\nthis operation to copy the staging distribution's configuration to the primary\ndistribution. This action will disable the continuous deployment policy and move\nyour domain's traffic back to the primary distribution.\n\nThis API operation requires the following IAM permissions:\n\n  *\n[GetDistribution](https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_GetDistribution.html)     *\n[UpdateDistribution](https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_UpdateDistribution.html)","ref":"AWS.CloudFront.html#update_distribution_with_staging_config/4","title":"AWS.CloudFront.update_distribution_with_staging_config/4","type":"function"},{"doc":"Update a field-level encryption configuration.","ref":"AWS.CloudFront.html#update_field_level_encryption_config/4","title":"AWS.CloudFront.update_field_level_encryption_config/4","type":"function"},{"doc":"Update a field-level encryption profile.","ref":"AWS.CloudFront.html#update_field_level_encryption_profile/4","title":"AWS.CloudFront.update_field_level_encryption_profile/4","type":"function"},{"doc":"Updates a CloudFront function.\n\nYou can update a function's code or the comment that describes the function. You\ncannot update a function's name.\n\nTo update a function, you provide the function's name and version (`ETag` value)\nalong with the updated function code. To get the name and version, you can use\n`ListFunctions` and `DescribeFunction`.","ref":"AWS.CloudFront.html#update_function/4","title":"AWS.CloudFront.update_function/4","type":"function"},{"doc":"Updates a key group.\n\nWhen you update a key group, all the fields are updated with the values provided\nin the request. You cannot update some fields independent of others. To update a\nkey group:\n\n  1. Get the current key group with `GetKeyGroup` or\n`GetKeyGroupConfig`.\n\n  2. Locally modify the fields in the key group that you want to\nupdate. For example, add or remove public key IDs.\n\n  3. Call `UpdateKeyGroup` with the entire key group object, including\nthe fields that you modified and those that you didn't.","ref":"AWS.CloudFront.html#update_key_group/4","title":"AWS.CloudFront.update_key_group/4","type":"function"},{"doc":"Specifies the Key Value Store to update.","ref":"AWS.CloudFront.html#update_key_value_store/4","title":"AWS.CloudFront.update_key_value_store/4","type":"function"},{"doc":"Updates a CloudFront origin access control.","ref":"AWS.CloudFront.html#update_origin_access_control/4","title":"AWS.CloudFront.update_origin_access_control/4","type":"function"},{"doc":"Updates an origin request policy configuration.\n\nWhen you update an origin request policy configuration, all the fields are\nupdated with the values provided in the request. You cannot update some fields\nindependent of others. To update an origin request policy configuration:\n\n  1. Use `GetOriginRequestPolicyConfig` to get the current\nconfiguration.\n\n  2. Locally modify the fields in the origin request policy\nconfiguration that you want to update.\n\n  3. Call `UpdateOriginRequestPolicy` by providing the entire origin\nrequest policy configuration, including the fields that you modified and those\nthat you didn't.","ref":"AWS.CloudFront.html#update_origin_request_policy/4","title":"AWS.CloudFront.update_origin_request_policy/4","type":"function"},{"doc":"Update public key information.\n\nNote that the only value you can change is the comment.","ref":"AWS.CloudFront.html#update_public_key/4","title":"AWS.CloudFront.update_public_key/4","type":"function"},{"doc":"Updates a real-time log configuration.\n\nWhen you update a real-time log configuration, all the parameters are updated\nwith the values provided in the request. You cannot update some parameters\nindependent of others. To update a real-time log configuration:\n\n  1. Call `GetRealtimeLogConfig` to get the current real-time log\nconfiguration.\n\n  2. Locally modify the parameters in the real-time log configuration\nthat you want to update.\n\n  3. Call this API (`UpdateRealtimeLogConfig`) by providing the entire\nreal-time log configuration, including the parameters that you modified and\nthose that you didn't.\n\nYou cannot update a real-time log configuration's `Name` or `ARN`.","ref":"AWS.CloudFront.html#update_realtime_log_config/3","title":"AWS.CloudFront.update_realtime_log_config/3","type":"function"},{"doc":"Updates a response headers policy.\n\nWhen you update a response headers policy, the entire policy is replaced. You\ncannot update some policy fields independent of others. To update a response\nheaders policy configuration:\n\n  1. Use `GetResponseHeadersPolicyConfig` to get the current policy's\nconfiguration.\n\n  2. Modify the fields in the response headers policy configuration\nthat you want to update.\n\n  3. Call `UpdateResponseHeadersPolicy`, providing the entire response\nheaders policy configuration, including the fields that you modified and those\nthat you didn't.","ref":"AWS.CloudFront.html#update_response_headers_policy/4","title":"AWS.CloudFront.update_response_headers_policy/4","type":"function"},{"doc":"Update a streaming distribution.","ref":"AWS.CloudFront.html#update_streaming_distribution/4","title":"AWS.CloudFront.update_streaming_distribution/4","type":"function"},{"doc":"AWS CloudHSM Service\n\nThis is documentation for **AWS CloudHSM Classic**.\n\nFor more information, see [AWS CloudHSM Classic FAQs](http://aws.amazon.com/cloudhsm/faqs-classic/), the [AWS CloudHSM Classic User Guide](https://docs.aws.amazon.com/cloudhsm/classic/userguide/), and the\n[AWS CloudHSM Classic API Reference](https://docs.aws.amazon.com/cloudhsm/classic/APIReference/).\n\n**For information about the current version of AWS CloudHSM**, see [AWS CloudHSM](http://aws.amazon.com/cloudhsm/), the [AWS CloudHSM User Guide](https://docs.aws.amazon.com/cloudhsm/latest/userguide/), and the [AWS CloudHSM API\nReference](https://docs.aws.amazon.com/cloudhsm/latest/APIReference/).","ref":"AWS.CloudHSM.html","title":"AWS.CloudHSM","type":"module"},{"doc":"This is documentation for **AWS CloudHSM Classic**.\n\nFor more information, see [AWS CloudHSM Classic FAQs](http://aws.amazon.com/cloudhsm/faqs-classic/), the [AWS CloudHSM Classic User Guide](https://docs.aws.amazon.com/cloudhsm/classic/userguide/), and the\n[AWS CloudHSM Classic API Reference](https://docs.aws.amazon.com/cloudhsm/classic/APIReference/).\n\n**For information about the current version of AWS CloudHSM**, see [AWS CloudHSM](http://aws.amazon.com/cloudhsm/), the [AWS CloudHSM User Guide](https://docs.aws.amazon.com/cloudhsm/latest/userguide/), and the [AWS CloudHSM API\nReference](https://docs.aws.amazon.com/cloudhsm/latest/APIReference/).\n\nAdds or overwrites one or more tags for the specified AWS CloudHSM resource.\n\nEach tag consists of a key and a value. Tag keys must be unique to each\nresource.","ref":"AWS.CloudHSM.html#add_tags_to_resource/3","title":"AWS.CloudHSM.add_tags_to_resource/3","type":"function"},{"doc":"This is documentation for **AWS CloudHSM Classic**.\n\nFor more information, see [AWS CloudHSM Classic FAQs](http://aws.amazon.com/cloudhsm/faqs-classic/), the [AWS CloudHSM Classic User Guide](https://docs.aws.amazon.com/cloudhsm/classic/userguide/), and the\n[AWS CloudHSM Classic API Reference](https://docs.aws.amazon.com/cloudhsm/classic/APIReference/).\n\n**For information about the current version of AWS CloudHSM**, see [AWS CloudHSM](http://aws.amazon.com/cloudhsm/), the [AWS CloudHSM User Guide](https://docs.aws.amazon.com/cloudhsm/latest/userguide/), and the [AWS CloudHSM API\nReference](https://docs.aws.amazon.com/cloudhsm/latest/APIReference/).\n\nCreates a high-availability partition group. A high-availability partition group\nis a group of partitions that spans multiple physical HSMs.","ref":"AWS.CloudHSM.html#create_hapg/3","title":"AWS.CloudHSM.create_hapg/3","type":"function"},{"doc":"This is documentation for **AWS CloudHSM Classic**.\n\nFor more information, see [AWS CloudHSM Classic FAQs](http://aws.amazon.com/cloudhsm/faqs-classic/), the [AWS CloudHSM Classic User Guide](https://docs.aws.amazon.com/cloudhsm/classic/userguide/), and the\n[AWS CloudHSM Classic API Reference](https://docs.aws.amazon.com/cloudhsm/classic/APIReference/).\n\n**For information about the current version of AWS CloudHSM**, see [AWS CloudHSM](http://aws.amazon.com/cloudhsm/), the [AWS CloudHSM User Guide](https://docs.aws.amazon.com/cloudhsm/latest/userguide/), and the [AWS CloudHSM API\nReference](https://docs.aws.amazon.com/cloudhsm/latest/APIReference/).\n\nCreates an uninitialized HSM instance.\n\nThere is an upfront fee charged for each HSM instance that you create with the\n`CreateHsm` operation. If you accidentally provision an HSM and want to request\na refund, delete the instance using the `DeleteHsm` operation, go to the [AWS Support Center](https://console.aws.amazon.com/support/home), create a new case,\nand select **Account and Billing Support**.\n\nIt can take up to 20 minutes to create and provision an HSM. You can monitor the\nstatus of the HSM with the `DescribeHsm` operation. The HSM is ready to be\ninitialized when the status changes to `RUNNING`.","ref":"AWS.CloudHSM.html#create_hsm/3","title":"AWS.CloudHSM.create_hsm/3","type":"function"},{"doc":"This is documentation for **AWS CloudHSM Classic**.\n\nFor more information, see [AWS CloudHSM Classic FAQs](http://aws.amazon.com/cloudhsm/faqs-classic/), the [AWS CloudHSM Classic User Guide](https://docs.aws.amazon.com/cloudhsm/classic/userguide/), and the\n[AWS CloudHSM Classic API Reference](https://docs.aws.amazon.com/cloudhsm/classic/APIReference/).\n\n**For information about the current version of AWS CloudHSM**, see [AWS CloudHSM](http://aws.amazon.com/cloudhsm/), the [AWS CloudHSM User Guide](https://docs.aws.amazon.com/cloudhsm/latest/userguide/), and the [AWS CloudHSM API\nReference](https://docs.aws.amazon.com/cloudhsm/latest/APIReference/).\n\nCreates an HSM client.","ref":"AWS.CloudHSM.html#create_luna_client/3","title":"AWS.CloudHSM.create_luna_client/3","type":"function"},{"doc":"This is documentation for **AWS CloudHSM Classic**.\n\nFor more information, see [AWS CloudHSM Classic FAQs](http://aws.amazon.com/cloudhsm/faqs-classic/), the [AWS CloudHSM Classic User Guide](https://docs.aws.amazon.com/cloudhsm/classic/userguide/), and the\n[AWS CloudHSM Classic API Reference](https://docs.aws.amazon.com/cloudhsm/classic/APIReference/).\n\n**For information about the current version of AWS CloudHSM**, see [AWS CloudHSM](http://aws.amazon.com/cloudhsm/), the [AWS CloudHSM User Guide](https://docs.aws.amazon.com/cloudhsm/latest/userguide/), and the [AWS CloudHSM API\nReference](https://docs.aws.amazon.com/cloudhsm/latest/APIReference/).\n\nDeletes a high-availability partition group.","ref":"AWS.CloudHSM.html#delete_hapg/3","title":"AWS.CloudHSM.delete_hapg/3","type":"function"},{"doc":"This is documentation for **AWS CloudHSM Classic**.\n\nFor more information, see [AWS CloudHSM Classic FAQs](http://aws.amazon.com/cloudhsm/faqs-classic/), the [AWS CloudHSM Classic User Guide](https://docs.aws.amazon.com/cloudhsm/classic/userguide/), and the\n[AWS CloudHSM Classic API Reference](https://docs.aws.amazon.com/cloudhsm/classic/APIReference/).\n\n**For information about the current version of AWS CloudHSM**, see [AWS CloudHSM](http://aws.amazon.com/cloudhsm/), the [AWS CloudHSM User Guide](https://docs.aws.amazon.com/cloudhsm/latest/userguide/), and the [AWS CloudHSM API\nReference](https://docs.aws.amazon.com/cloudhsm/latest/APIReference/).\n\nDeletes an HSM. After completion, this operation cannot be undone and your key\nmaterial cannot be recovered.","ref":"AWS.CloudHSM.html#delete_hsm/3","title":"AWS.CloudHSM.delete_hsm/3","type":"function"},{"doc":"This is documentation for **AWS CloudHSM Classic**.\n\nFor more information, see [AWS CloudHSM Classic FAQs](http://aws.amazon.com/cloudhsm/faqs-classic/), the [AWS CloudHSM Classic User Guide](https://docs.aws.amazon.com/cloudhsm/classic/userguide/), and the\n[AWS CloudHSM Classic API Reference](https://docs.aws.amazon.com/cloudhsm/classic/APIReference/).\n\n**For information about the current version of AWS CloudHSM**, see [AWS CloudHSM](http://aws.amazon.com/cloudhsm/), the [AWS CloudHSM User Guide](https://docs.aws.amazon.com/cloudhsm/latest/userguide/), and the [AWS CloudHSM API\nReference](https://docs.aws.amazon.com/cloudhsm/latest/APIReference/).\n\nDeletes a client.","ref":"AWS.CloudHSM.html#delete_luna_client/3","title":"AWS.CloudHSM.delete_luna_client/3","type":"function"},{"doc":"This is documentation for **AWS CloudHSM Classic**.\n\nFor more information, see [AWS CloudHSM Classic FAQs](http://aws.amazon.com/cloudhsm/faqs-classic/), the [AWS CloudHSM Classic User Guide](https://docs.aws.amazon.com/cloudhsm/classic/userguide/), and the\n[AWS CloudHSM Classic API Reference](https://docs.aws.amazon.com/cloudhsm/classic/APIReference/).\n\n**For information about the current version of AWS CloudHSM**, see [AWS CloudHSM](http://aws.amazon.com/cloudhsm/), the [AWS CloudHSM User Guide](https://docs.aws.amazon.com/cloudhsm/latest/userguide/), and the [AWS CloudHSM API\nReference](https://docs.aws.amazon.com/cloudhsm/latest/APIReference/).\n\nRetrieves information about a high-availability partition group.","ref":"AWS.CloudHSM.html#describe_hapg/3","title":"AWS.CloudHSM.describe_hapg/3","type":"function"},{"doc":"This is documentation for **AWS CloudHSM Classic**.\n\nFor more information, see [AWS CloudHSM Classic FAQs](http://aws.amazon.com/cloudhsm/faqs-classic/), the [AWS CloudHSM Classic User Guide](https://docs.aws.amazon.com/cloudhsm/classic/userguide/), and the\n[AWS CloudHSM Classic API Reference](https://docs.aws.amazon.com/cloudhsm/classic/APIReference/).\n\n**For information about the current version of AWS CloudHSM**, see [AWS CloudHSM](http://aws.amazon.com/cloudhsm/), the [AWS CloudHSM User Guide](https://docs.aws.amazon.com/cloudhsm/latest/userguide/), and the [AWS CloudHSM API\nReference](https://docs.aws.amazon.com/cloudhsm/latest/APIReference/).\n\nRetrieves information about an HSM. You can identify the HSM by its ARN or its\nserial number.","ref":"AWS.CloudHSM.html#describe_hsm/3","title":"AWS.CloudHSM.describe_hsm/3","type":"function"},{"doc":"This is documentation for **AWS CloudHSM Classic**.\n\nFor more information, see [AWS CloudHSM Classic FAQs](http://aws.amazon.com/cloudhsm/faqs-classic/), the [AWS CloudHSM Classic User Guide](https://docs.aws.amazon.com/cloudhsm/classic/userguide/), and the\n[AWS CloudHSM Classic API Reference](https://docs.aws.amazon.com/cloudhsm/classic/APIReference/).\n\n**For information about the current version of AWS CloudHSM**, see [AWS CloudHSM](http://aws.amazon.com/cloudhsm/), the [AWS CloudHSM User Guide](https://docs.aws.amazon.com/cloudhsm/latest/userguide/), and the [AWS CloudHSM API\nReference](https://docs.aws.amazon.com/cloudhsm/latest/APIReference/).\n\nRetrieves information about an HSM client.","ref":"AWS.CloudHSM.html#describe_luna_client/3","title":"AWS.CloudHSM.describe_luna_client/3","type":"function"},{"doc":"This is documentation for **AWS CloudHSM Classic**.\n\nFor more information, see [AWS CloudHSM Classic FAQs](http://aws.amazon.com/cloudhsm/faqs-classic/), the [AWS CloudHSM Classic User Guide](https://docs.aws.amazon.com/cloudhsm/classic/userguide/), and the\n[AWS CloudHSM Classic API Reference](https://docs.aws.amazon.com/cloudhsm/classic/APIReference/).\n\n**For information about the current version of AWS CloudHSM**, see [AWS CloudHSM](http://aws.amazon.com/cloudhsm/), the [AWS CloudHSM User Guide](https://docs.aws.amazon.com/cloudhsm/latest/userguide/), and the [AWS CloudHSM API\nReference](https://docs.aws.amazon.com/cloudhsm/latest/APIReference/).\n\nGets the configuration files necessary to connect to all high availability\npartition groups the client is associated with.","ref":"AWS.CloudHSM.html#get_config/3","title":"AWS.CloudHSM.get_config/3","type":"function"},{"doc":"This is documentation for **AWS CloudHSM Classic**.\n\nFor more information, see [AWS CloudHSM Classic FAQs](http://aws.amazon.com/cloudhsm/faqs-classic/), the [AWS CloudHSM Classic User Guide](https://docs.aws.amazon.com/cloudhsm/classic/userguide/), and the\n[AWS CloudHSM Classic API Reference](https://docs.aws.amazon.com/cloudhsm/classic/APIReference/).\n\n**For information about the current version of AWS CloudHSM**, see [AWS CloudHSM](http://aws.amazon.com/cloudhsm/), the [AWS CloudHSM User Guide](https://docs.aws.amazon.com/cloudhsm/latest/userguide/), and the [AWS CloudHSM API\nReference](https://docs.aws.amazon.com/cloudhsm/latest/APIReference/).\n\nLists the Availability Zones that have available AWS CloudHSM capacity.","ref":"AWS.CloudHSM.html#list_available_zones/3","title":"AWS.CloudHSM.list_available_zones/3","type":"function"},{"doc":"This is documentation for **AWS CloudHSM Classic**.\n\nFor more information, see [AWS CloudHSM Classic FAQs](http://aws.amazon.com/cloudhsm/faqs-classic/), the [AWS CloudHSM Classic User Guide](https://docs.aws.amazon.com/cloudhsm/classic/userguide/), and the\n[AWS CloudHSM Classic API Reference](https://docs.aws.amazon.com/cloudhsm/classic/APIReference/).\n\n**For information about the current version of AWS CloudHSM**, see [AWS CloudHSM](http://aws.amazon.com/cloudhsm/), the [AWS CloudHSM User Guide](https://docs.aws.amazon.com/cloudhsm/latest/userguide/), and the [AWS CloudHSM API\nReference](https://docs.aws.amazon.com/cloudhsm/latest/APIReference/).\n\nLists the high-availability partition groups for the account.\n\nThis operation supports pagination with the use of the `NextToken` member. If\nmore results are available, the `NextToken` member of the response contains a\ntoken that you pass in the next call to `ListHapgs` to retrieve the next set of\nitems.","ref":"AWS.CloudHSM.html#list_hapgs/3","title":"AWS.CloudHSM.list_hapgs/3","type":"function"},{"doc":"This is documentation for **AWS CloudHSM Classic**.\n\nFor more information, see [AWS CloudHSM Classic FAQs](http://aws.amazon.com/cloudhsm/faqs-classic/), the [AWS CloudHSM Classic User Guide](https://docs.aws.amazon.com/cloudhsm/classic/userguide/), and the\n[AWS CloudHSM Classic API Reference](https://docs.aws.amazon.com/cloudhsm/classic/APIReference/).\n\n**For information about the current version of AWS CloudHSM**, see [AWS CloudHSM](http://aws.amazon.com/cloudhsm/), the [AWS CloudHSM User Guide](https://docs.aws.amazon.com/cloudhsm/latest/userguide/), and the [AWS CloudHSM API\nReference](https://docs.aws.amazon.com/cloudhsm/latest/APIReference/).\n\nRetrieves the identifiers of all of the HSMs provisioned for the current\ncustomer.\n\nThis operation supports pagination with the use of the `NextToken` member. If\nmore results are available, the `NextToken` member of the response contains a\ntoken that you pass in the next call to `ListHsms` to retrieve the next set of\nitems.","ref":"AWS.CloudHSM.html#list_hsms/3","title":"AWS.CloudHSM.list_hsms/3","type":"function"},{"doc":"This is documentation for **AWS CloudHSM Classic**.\n\nFor more information, see [AWS CloudHSM Classic FAQs](http://aws.amazon.com/cloudhsm/faqs-classic/), the [AWS CloudHSM Classic User Guide](https://docs.aws.amazon.com/cloudhsm/classic/userguide/), and the\n[AWS CloudHSM Classic API Reference](https://docs.aws.amazon.com/cloudhsm/classic/APIReference/).\n\n**For information about the current version of AWS CloudHSM**, see [AWS CloudHSM](http://aws.amazon.com/cloudhsm/), the [AWS CloudHSM User Guide](https://docs.aws.amazon.com/cloudhsm/latest/userguide/), and the [AWS CloudHSM API\nReference](https://docs.aws.amazon.com/cloudhsm/latest/APIReference/).\n\nLists all of the clients.\n\nThis operation supports pagination with the use of the `NextToken` member. If\nmore results are available, the `NextToken` member of the response contains a\ntoken that you pass in the next call to `ListLunaClients` to retrieve the next\nset of items.","ref":"AWS.CloudHSM.html#list_luna_clients/3","title":"AWS.CloudHSM.list_luna_clients/3","type":"function"},{"doc":"This is documentation for **AWS CloudHSM Classic**.\n\nFor more information, see [AWS CloudHSM Classic FAQs](http://aws.amazon.com/cloudhsm/faqs-classic/), the [AWS CloudHSM Classic User Guide](https://docs.aws.amazon.com/cloudhsm/classic/userguide/), and the\n[AWS CloudHSM Classic API Reference](https://docs.aws.amazon.com/cloudhsm/classic/APIReference/).\n\n**For information about the current version of AWS CloudHSM**, see [AWS CloudHSM](http://aws.amazon.com/cloudhsm/), the [AWS CloudHSM User Guide](https://docs.aws.amazon.com/cloudhsm/latest/userguide/), and the [AWS CloudHSM API\nReference](https://docs.aws.amazon.com/cloudhsm/latest/APIReference/).\n\nReturns a list of all tags for the specified AWS CloudHSM resource.","ref":"AWS.CloudHSM.html#list_tags_for_resource/3","title":"AWS.CloudHSM.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.CloudHSM.html#metadata/0","title":"AWS.CloudHSM.metadata/0","type":"function"},{"doc":"This is documentation for **AWS CloudHSM Classic**.\n\nFor more information, see [AWS CloudHSM Classic FAQs](http://aws.amazon.com/cloudhsm/faqs-classic/), the [AWS CloudHSM Classic User Guide](https://docs.aws.amazon.com/cloudhsm/classic/userguide/), and the\n[AWS CloudHSM Classic API Reference](https://docs.aws.amazon.com/cloudhsm/classic/APIReference/).\n\n**For information about the current version of AWS CloudHSM**, see [AWS CloudHSM](http://aws.amazon.com/cloudhsm/), the [AWS CloudHSM User Guide](https://docs.aws.amazon.com/cloudhsm/latest/userguide/), and the [AWS CloudHSM API\nReference](https://docs.aws.amazon.com/cloudhsm/latest/APIReference/).\n\nModifies an existing high-availability partition group.","ref":"AWS.CloudHSM.html#modify_hapg/3","title":"AWS.CloudHSM.modify_hapg/3","type":"function"},{"doc":"This is documentation for **AWS CloudHSM Classic**.\n\nFor more information, see [AWS CloudHSM Classic FAQs](http://aws.amazon.com/cloudhsm/faqs-classic/), the [AWS CloudHSM Classic User Guide](https://docs.aws.amazon.com/cloudhsm/classic/userguide/), and the\n[AWS CloudHSM Classic API Reference](https://docs.aws.amazon.com/cloudhsm/classic/APIReference/).\n\n**For information about the current version of AWS CloudHSM**, see [AWS CloudHSM](http://aws.amazon.com/cloudhsm/), the [AWS CloudHSM User Guide](https://docs.aws.amazon.com/cloudhsm/latest/userguide/), and the [AWS CloudHSM API\nReference](https://docs.aws.amazon.com/cloudhsm/latest/APIReference/).\n\nModifies an HSM.\n\nThis operation can result in the HSM being offline for up to 15 minutes while\nthe AWS CloudHSM service is reconfigured. If you are modifying a production HSM,\nyou should ensure that your AWS CloudHSM service is configured for high\navailability, and consider executing this operation during a maintenance window.","ref":"AWS.CloudHSM.html#modify_hsm/3","title":"AWS.CloudHSM.modify_hsm/3","type":"function"},{"doc":"This is documentation for **AWS CloudHSM Classic**.\n\nFor more information, see [AWS CloudHSM Classic FAQs](http://aws.amazon.com/cloudhsm/faqs-classic/), the [AWS CloudHSM Classic User Guide](https://docs.aws.amazon.com/cloudhsm/classic/userguide/), and the\n[AWS CloudHSM Classic API Reference](https://docs.aws.amazon.com/cloudhsm/classic/APIReference/).\n\n**For information about the current version of AWS CloudHSM**, see [AWS CloudHSM](http://aws.amazon.com/cloudhsm/), the [AWS CloudHSM User Guide](https://docs.aws.amazon.com/cloudhsm/latest/userguide/), and the [AWS CloudHSM API\nReference](https://docs.aws.amazon.com/cloudhsm/latest/APIReference/).\n\nModifies the certificate used by the client.\n\nThis action can potentially start a workflow to install the new certificate on\nthe client's HSMs.","ref":"AWS.CloudHSM.html#modify_luna_client/3","title":"AWS.CloudHSM.modify_luna_client/3","type":"function"},{"doc":"This is documentation for **AWS CloudHSM Classic**.\n\nFor more information, see [AWS CloudHSM Classic FAQs](http://aws.amazon.com/cloudhsm/faqs-classic/), the [AWS CloudHSM Classic User Guide](https://docs.aws.amazon.com/cloudhsm/classic/userguide/), and the\n[AWS CloudHSM Classic API Reference](https://docs.aws.amazon.com/cloudhsm/classic/APIReference/).\n\n**For information about the current version of AWS CloudHSM**, see [AWS CloudHSM](http://aws.amazon.com/cloudhsm/), the [AWS CloudHSM User Guide](https://docs.aws.amazon.com/cloudhsm/latest/userguide/), and the [AWS CloudHSM API\nReference](https://docs.aws.amazon.com/cloudhsm/latest/APIReference/).\n\nRemoves one or more tags from the specified AWS CloudHSM resource.\n\nTo remove a tag, specify only the tag key to remove (not the value). To\noverwrite the value for an existing tag, use `AddTagsToResource`.","ref":"AWS.CloudHSM.html#remove_tags_from_resource/3","title":"AWS.CloudHSM.remove_tags_from_resource/3","type":"function"},{"doc":"For more information about AWS CloudHSM, see [AWS CloudHSM](http://aws.amazon.com/cloudhsm/) and the [AWS CloudHSM User Guide](https://docs.aws.amazon.com/cloudhsm/latest/userguide/).","ref":"AWS.CloudHSMV2.html","title":"AWS.CloudHSMV2","type":"module"},{"doc":"Copy an AWS CloudHSM cluster backup to a different region.","ref":"AWS.CloudHSMV2.html#copy_backup_to_region/3","title":"AWS.CloudHSMV2.copy_backup_to_region/3","type":"function"},{"doc":"Creates a new AWS CloudHSM cluster.","ref":"AWS.CloudHSMV2.html#create_cluster/3","title":"AWS.CloudHSMV2.create_cluster/3","type":"function"},{"doc":"Creates a new hardware security module (HSM) in the specified AWS CloudHSM\ncluster.","ref":"AWS.CloudHSMV2.html#create_hsm/3","title":"AWS.CloudHSMV2.create_hsm/3","type":"function"},{"doc":"Deletes a specified AWS CloudHSM backup.\n\nA backup can be restored up to 7 days after the DeleteBackup request is made.\nFor more information on restoring a backup, see `RestoreBackup`.","ref":"AWS.CloudHSMV2.html#delete_backup/3","title":"AWS.CloudHSMV2.delete_backup/3","type":"function"},{"doc":"Deletes the specified AWS CloudHSM cluster.\n\nBefore you can delete a cluster, you must delete all HSMs in the cluster. To see\nif the cluster contains any HSMs, use `DescribeClusters`. To delete an HSM, use\n`DeleteHsm`.","ref":"AWS.CloudHSMV2.html#delete_cluster/3","title":"AWS.CloudHSMV2.delete_cluster/3","type":"function"},{"doc":"Deletes the specified HSM.\n\nTo specify an HSM, you can use its identifier (ID), the IP address of the HSM's\nelastic network interface (ENI), or the ID of the HSM's ENI. You need to specify\nonly one of these values. To find these values, use `DescribeClusters`.","ref":"AWS.CloudHSMV2.html#delete_hsm/3","title":"AWS.CloudHSMV2.delete_hsm/3","type":"function"},{"doc":"Gets information about backups of AWS CloudHSM clusters.\n\nThis is a paginated operation, which means that each response might contain only\na subset of all the backups. When the response contains only a subset of\nbackups, it includes a `NextToken` value. Use this value in a subsequent\n`DescribeBackups` request to get more backups. When you receive a response with\nno `NextToken` (or an empty or null value), that means there are no more backups\nto get.","ref":"AWS.CloudHSMV2.html#describe_backups/3","title":"AWS.CloudHSMV2.describe_backups/3","type":"function"},{"doc":"Gets information about AWS CloudHSM clusters.\n\nThis is a paginated operation, which means that each response might contain only\na subset of all the clusters. When the response contains only a subset of\nclusters, it includes a `NextToken` value. Use this value in a subsequent\n`DescribeClusters` request to get more clusters. When you receive a response\nwith no `NextToken` (or an empty or null value), that means there are no more\nclusters to get.","ref":"AWS.CloudHSMV2.html#describe_clusters/3","title":"AWS.CloudHSMV2.describe_clusters/3","type":"function"},{"doc":"Claims an AWS CloudHSM cluster by submitting the cluster certificate issued by\nyour issuing certificate authority (CA) and the CA's root certificate.\n\nBefore you can claim a cluster, you must sign the cluster's certificate signing\nrequest (CSR) with your issuing CA. To get the cluster's CSR, use\n`DescribeClusters`.","ref":"AWS.CloudHSMV2.html#initialize_cluster/3","title":"AWS.CloudHSMV2.initialize_cluster/3","type":"function"},{"doc":"Gets a list of tags for the specified AWS CloudHSM cluster.\n\nThis is a paginated operation, which means that each response might contain only\na subset of all the tags. When the response contains only a subset of tags, it\nincludes a `NextToken` value. Use this value in a subsequent `ListTags` request\nto get more tags. When you receive a response with no `NextToken` (or an empty\nor null value), that means there are no more tags to get.","ref":"AWS.CloudHSMV2.html#list_tags/3","title":"AWS.CloudHSMV2.list_tags/3","type":"function"},{"doc":"","ref":"AWS.CloudHSMV2.html#metadata/0","title":"AWS.CloudHSMV2.metadata/0","type":"function"},{"doc":"Modifies attributes for AWS CloudHSM backup.","ref":"AWS.CloudHSMV2.html#modify_backup_attributes/3","title":"AWS.CloudHSMV2.modify_backup_attributes/3","type":"function"},{"doc":"Modifies AWS CloudHSM cluster.","ref":"AWS.CloudHSMV2.html#modify_cluster/3","title":"AWS.CloudHSMV2.modify_cluster/3","type":"function"},{"doc":"Restores a specified AWS CloudHSM backup that is in the `PENDING_DELETION`\nstate.\n\nFor mor information on deleting a backup, see `DeleteBackup`.","ref":"AWS.CloudHSMV2.html#restore_backup/3","title":"AWS.CloudHSMV2.restore_backup/3","type":"function"},{"doc":"Adds or overwrites one or more tags for the specified AWS CloudHSM cluster.","ref":"AWS.CloudHSMV2.html#tag_resource/3","title":"AWS.CloudHSMV2.tag_resource/3","type":"function"},{"doc":"Removes the specified tag or tags from the specified AWS CloudHSM cluster.","ref":"AWS.CloudHSMV2.html#untag_resource/3","title":"AWS.CloudHSMV2.untag_resource/3","type":"function"},{"doc":"Amazon CloudSearch Configuration Service\n\nYou use the Amazon CloudSearch configuration service to create, configure, and\nmanage search domains.\n\nConfiguration service requests are submitted using the AWS Query protocol. AWS\nQuery requests are HTTP or HTTPS requests submitted via HTTP GET or POST with a\nquery parameter named Action.\n\nThe endpoint for configuration service requests is region-specific:\ncloudsearch.*region*.amazonaws.com. For example,\ncloudsearch.us-east-1.amazonaws.com. For a current list of supported regions and\nendpoints, see [Regions and Endpoints](http://docs.aws.amazon.com/general/latest/gr/rande.html#cloudsearch_region).","ref":"AWS.CloudSearch.html","title":"AWS.CloudSearch","type":"module"},{"doc":"Indexes the search suggestions.\n\nFor more information, see [Configuring Suggesters](http://docs.aws.amazon.com/cloudsearch/latest/developerguide/getting-suggestions.html#configuring-suggesters)\nin the *Amazon CloudSearch Developer Guide*.","ref":"AWS.CloudSearch.html#build_suggesters/3","title":"AWS.CloudSearch.build_suggesters/3","type":"function"},{"doc":"Creates a new search domain.\n\nFor more information, see [Creating a Search Domain](http://docs.aws.amazon.com/cloudsearch/latest/developerguide/creating-domains.html)\nin the *Amazon CloudSearch Developer Guide*.","ref":"AWS.CloudSearch.html#create_domain/3","title":"AWS.CloudSearch.create_domain/3","type":"function"},{"doc":"Configures an analysis scheme that can be applied to a `text` or `text-array`\nfield to define language-specific text processing options.\n\nFor more information, see [Configuring Analysis Schemes](http://docs.aws.amazon.com/cloudsearch/latest/developerguide/configuring-analysis-schemes.html)\nin the *Amazon CloudSearch Developer Guide*.","ref":"AWS.CloudSearch.html#define_analysis_scheme/3","title":"AWS.CloudSearch.define_analysis_scheme/3","type":"function"},{"doc":"Configures an ``Expression`` for the search domain.\n\nUsed to create new expressions and modify existing ones. If the expression\nexists, the new configuration replaces the old one. For more information, see\n[Configuring Expressions](http://docs.aws.amazon.com/cloudsearch/latest/developerguide/configuring-expressions.html)\nin the *Amazon CloudSearch Developer Guide*.","ref":"AWS.CloudSearch.html#define_expression/3","title":"AWS.CloudSearch.define_expression/3","type":"function"},{"doc":"Configures an ``IndexField`` for the search domain.\n\nUsed to create new fields and modify existing ones. You must specify the name of\nthe domain you are configuring and an index field configuration. The index field\nconfiguration specifies a unique name, the index field type, and the options you\nwant to configure for the field. The options you can specify depend on the\n``IndexFieldType``. If the field exists, the new configuration replaces the old\none. For more information, see [Configuring Index Fields](http://docs.aws.amazon.com/cloudsearch/latest/developerguide/configuring-index-fields.html)\nin the *Amazon CloudSearch Developer Guide*.","ref":"AWS.CloudSearch.html#define_index_field/3","title":"AWS.CloudSearch.define_index_field/3","type":"function"},{"doc":"Configures a suggester for a domain.\n\nA suggester enables you to display possible matches before users finish typing\ntheir queries. When you configure a suggester, you must specify the name of the\ntext field you want to search for possible matches and a unique name for the\nsuggester. For more information, see [Getting Search Suggestions](http://docs.aws.amazon.com/cloudsearch/latest/developerguide/getting-suggestions.html)\nin the *Amazon CloudSearch Developer Guide*.","ref":"AWS.CloudSearch.html#define_suggester/3","title":"AWS.CloudSearch.define_suggester/3","type":"function"},{"doc":"Deletes an analysis scheme.\n\nFor more information, see [Configuring Analysis Schemes](http://docs.aws.amazon.com/cloudsearch/latest/developerguide/configuring-analysis-schemes.html)\nin the *Amazon CloudSearch Developer Guide*.","ref":"AWS.CloudSearch.html#delete_analysis_scheme/3","title":"AWS.CloudSearch.delete_analysis_scheme/3","type":"function"},{"doc":"Permanently deletes a search domain and all of its data.\n\nOnce a domain has been deleted, it cannot be recovered. For more information,\nsee [Deleting a Search Domain](http://docs.aws.amazon.com/cloudsearch/latest/developerguide/deleting-domains.html)\nin the *Amazon CloudSearch Developer Guide*.","ref":"AWS.CloudSearch.html#delete_domain/3","title":"AWS.CloudSearch.delete_domain/3","type":"function"},{"doc":"Removes an ``Expression`` from the search domain.\n\nFor more information, see [Configuring Expressions](http://docs.aws.amazon.com/cloudsearch/latest/developerguide/configuring-expressions.html)\nin the *Amazon CloudSearch Developer Guide*.","ref":"AWS.CloudSearch.html#delete_expression/3","title":"AWS.CloudSearch.delete_expression/3","type":"function"},{"doc":"Removes an ``IndexField`` from the search domain.\n\nFor more information, see [Configuring Index Fields](http://docs.aws.amazon.com/cloudsearch/latest/developerguide/configuring-index-fields.html)\nin the *Amazon CloudSearch Developer Guide*.","ref":"AWS.CloudSearch.html#delete_index_field/3","title":"AWS.CloudSearch.delete_index_field/3","type":"function"},{"doc":"Deletes a suggester.\n\nFor more information, see [Getting Search Suggestions](http://docs.aws.amazon.com/cloudsearch/latest/developerguide/getting-suggestions.html)\nin the *Amazon CloudSearch Developer Guide*.","ref":"AWS.CloudSearch.html#delete_suggester/3","title":"AWS.CloudSearch.delete_suggester/3","type":"function"},{"doc":"Gets the analysis schemes configured for a domain.\n\nAn analysis scheme defines language-specific text processing options for a\n`text` field. Can be limited to specific analysis schemes by name. By default,\nshows all analysis schemes and includes any pending changes to the\nconfiguration. Set the `Deployed` option to `true` to show the active\nconfiguration and exclude pending changes. For more information, see\n[Configuring Analysis Schemes](http://docs.aws.amazon.com/cloudsearch/latest/developerguide/configuring-analysis-schemes.html)\nin the *Amazon CloudSearch Developer Guide*.","ref":"AWS.CloudSearch.html#describe_analysis_schemes/3","title":"AWS.CloudSearch.describe_analysis_schemes/3","type":"function"},{"doc":"Gets the availability options configured for a domain.\n\nBy default, shows the configuration with any pending changes. Set the `Deployed`\noption to `true` to show the active configuration and exclude pending changes.\nFor more information, see [Configuring Availability Options](http://docs.aws.amazon.com/cloudsearch/latest/developerguide/configuring-availability-options.html)\nin the *Amazon CloudSearch Developer Guide*.","ref":"AWS.CloudSearch.html#describe_availability_options/3","title":"AWS.CloudSearch.describe_availability_options/3","type":"function"},{"doc":"Returns the domain's endpoint options, specifically whether all requests to the\ndomain must arrive over HTTPS.\n\nFor more information, see [Configuring Domain Endpoint Options](http://docs.aws.amazon.com/cloudsearch/latest/developerguide/configuring-domain-endpoint-options.html)\nin the *Amazon CloudSearch Developer Guide*.","ref":"AWS.CloudSearch.html#describe_domain_endpoint_options/3","title":"AWS.CloudSearch.describe_domain_endpoint_options/3","type":"function"},{"doc":"Gets information about the search domains owned by this account.\n\nCan be limited to specific domains. Shows all domains by default. To get the\nnumber of searchable documents in a domain, use the console or submit a\n`matchall` request to your domain's search endpoint:\n`q=matchall&amp;q.parser=structured&amp;size=0`. For more information, see\n[Getting Information about a Search Domain](http://docs.aws.amazon.com/cloudsearch/latest/developerguide/getting-domain-info.html)\nin the *Amazon CloudSearch Developer Guide*.","ref":"AWS.CloudSearch.html#describe_domains/3","title":"AWS.CloudSearch.describe_domains/3","type":"function"},{"doc":"Gets the expressions configured for the search domain.\n\nCan be limited to specific expressions by name. By default, shows all\nexpressions and includes any pending changes to the configuration. Set the\n`Deployed` option to `true` to show the active configuration and exclude pending\nchanges. For more information, see [Configuring Expressions](http://docs.aws.amazon.com/cloudsearch/latest/developerguide/configuring-expressions.html)\nin the *Amazon CloudSearch Developer Guide*.","ref":"AWS.CloudSearch.html#describe_expressions/3","title":"AWS.CloudSearch.describe_expressions/3","type":"function"},{"doc":"Gets information about the index fields configured for the search domain.\n\nCan be limited to specific fields by name. By default, shows all fields and\nincludes any pending changes to the configuration. Set the `Deployed` option to\n`true` to show the active configuration and exclude pending changes. For more\ninformation, see [Getting Domain Information](http://docs.aws.amazon.com/cloudsearch/latest/developerguide/getting-domain-info.html)\nin the *Amazon CloudSearch Developer Guide*.","ref":"AWS.CloudSearch.html#describe_index_fields/3","title":"AWS.CloudSearch.describe_index_fields/3","type":"function"},{"doc":"Gets the scaling parameters configured for a domain.\n\nA domain's scaling parameters specify the desired search instance type and\nreplication count. For more information, see [Configuring Scaling Options](http://docs.aws.amazon.com/cloudsearch/latest/developerguide/configuring-scaling-options.html)\nin the *Amazon CloudSearch Developer Guide*.","ref":"AWS.CloudSearch.html#describe_scaling_parameters/3","title":"AWS.CloudSearch.describe_scaling_parameters/3","type":"function"},{"doc":"Gets information about the access policies that control access to the domain's\ndocument and search endpoints.\n\nBy default, shows the configuration with any pending changes. Set the `Deployed`\noption to `true` to show the active configuration and exclude pending changes.\nFor more information, see [Configuring Access for a Search Domain](http://docs.aws.amazon.com/cloudsearch/latest/developerguide/configuring-access.html)\nin the *Amazon CloudSearch Developer Guide*.","ref":"AWS.CloudSearch.html#describe_service_access_policies/3","title":"AWS.CloudSearch.describe_service_access_policies/3","type":"function"},{"doc":"Gets the suggesters configured for a domain.\n\nA suggester enables you to display possible matches before users finish typing\ntheir queries. Can be limited to specific suggesters by name. By default, shows\nall suggesters and includes any pending changes to the configuration. Set the\n`Deployed` option to `true` to show the active configuration and exclude pending\nchanges. For more information, see [Getting Search Suggestions](http://docs.aws.amazon.com/cloudsearch/latest/developerguide/getting-suggestions.html)\nin the *Amazon CloudSearch Developer Guide*.","ref":"AWS.CloudSearch.html#describe_suggesters/3","title":"AWS.CloudSearch.describe_suggesters/3","type":"function"},{"doc":"Tells the search domain to start indexing its documents using the latest\nindexing options.\n\nThis operation must be invoked to activate options whose `OptionStatus` is\n`RequiresIndexDocuments`.","ref":"AWS.CloudSearch.html#index_documents/3","title":"AWS.CloudSearch.index_documents/3","type":"function"},{"doc":"Lists all search domains owned by an account.","ref":"AWS.CloudSearch.html#list_domain_names/3","title":"AWS.CloudSearch.list_domain_names/3","type":"function"},{"doc":"","ref":"AWS.CloudSearch.html#metadata/0","title":"AWS.CloudSearch.metadata/0","type":"function"},{"doc":"Configures the availability options for a domain.\n\nEnabling the Multi-AZ option expands an Amazon CloudSearch domain to an\nadditional Availability Zone in the same Region to increase fault tolerance in\nthe event of a service disruption. Changes to the Multi-AZ option can take about\nhalf an hour to become active. For more information, see [Configuring Availability\nOptions](http://docs.aws.amazon.com/cloudsearch/latest/developerguide/configuring-availability-options.html)\nin the *Amazon CloudSearch Developer Guide*.","ref":"AWS.CloudSearch.html#update_availability_options/3","title":"AWS.CloudSearch.update_availability_options/3","type":"function"},{"doc":"Updates the domain's endpoint options, specifically whether all requests to the\ndomain must arrive over HTTPS.\n\nFor more information, see [Configuring Domain Endpoint Options](http://docs.aws.amazon.com/cloudsearch/latest/developerguide/configuring-domain-endpoint-options.html)\nin the *Amazon CloudSearch Developer Guide*.","ref":"AWS.CloudSearch.html#update_domain_endpoint_options/3","title":"AWS.CloudSearch.update_domain_endpoint_options/3","type":"function"},{"doc":"Configures scaling parameters for a domain.\n\nA domain's scaling parameters specify the desired search instance type and\nreplication count. Amazon CloudSearch will still automatically scale your domain\nbased on the volume of data and traffic, but not below the desired instance type\nand replication count. If the Multi-AZ option is enabled, these values control\nthe resources used per Availability Zone. For more information, see [Configuring Scaling\nOptions](http://docs.aws.amazon.com/cloudsearch/latest/developerguide/configuring-scaling-options.html)\nin the *Amazon CloudSearch Developer Guide*.","ref":"AWS.CloudSearch.html#update_scaling_parameters/3","title":"AWS.CloudSearch.update_scaling_parameters/3","type":"function"},{"doc":"Configures the access rules that control access to the domain's document and\nsearch endpoints.\n\nFor more information, see [ Configuring Access for an Amazon CloudSearch Domain](http://docs.aws.amazon.com/cloudsearch/latest/developerguide/configuring-access.html).","ref":"AWS.CloudSearch.html#update_service_access_policies/3","title":"AWS.CloudSearch.update_service_access_policies/3","type":"function"},{"doc":"You use the AmazonCloudSearch2013 API to upload documents to a search domain and\nsearch those documents.\n\nThe endpoints for submitting `UploadDocuments`, `Search`, and `Suggest` requests\nare domain-specific. To get the endpoints for your domain, use the Amazon\nCloudSearch configuration service `DescribeDomains` action. The domain endpoints\nare also displayed on the domain dashboard in the Amazon CloudSearch console.\nYou submit suggest requests to the search endpoint.\n\nFor more information, see the [Amazon CloudSearch Developer Guide](http://docs.aws.amazon.com/cloudsearch/latest/developerguide).","ref":"AWS.CloudSearchDomain.html","title":"AWS.CloudSearchDomain","type":"module"},{"doc":"","ref":"AWS.CloudSearchDomain.html#metadata/0","title":"AWS.CloudSearchDomain.metadata/0","type":"function"},{"doc":"Retrieves a list of documents that match the specified search criteria.\n\nHow you specify the search criteria depends on which query parser you use.\nAmazon CloudSearch supports four query parsers:\n\n  * `simple`: search all `text` and `text-array` fields for the\nspecified string. Search for phrases, individual terms, and prefixes.\n  * `structured`: search specific fields, construct compound queries\nusing Boolean operators, and use advanced features such as term boosting and\nproximity searching.\n  * `lucene`: specify search criteria using the Apache Lucene query\nparser syntax.\n  * `dismax`: specify search criteria using the simplified subset of\nthe Apache Lucene query parser syntax defined by the DisMax query parser.\n\nFor more information, see [Searching Your Data](http://docs.aws.amazon.com/cloudsearch/latest/developerguide/searching.html)\nin the *Amazon CloudSearch Developer Guide*.\n\nThe endpoint for submitting `Search` requests is domain-specific. You submit\nsearch requests to a domain's search endpoint. To get the search endpoint for\nyour domain, use the Amazon CloudSearch configuration service `DescribeDomains`\naction. A domain's endpoints are also displayed on the domain dashboard in the\nAmazon CloudSearch console.","ref":"AWS.CloudSearchDomain.html#search/16","title":"AWS.CloudSearchDomain.search/16","type":"function"},{"doc":"Retrieves autocomplete suggestions for a partial query string.\n\nYou can use suggestions enable you to display likely matches before users finish\ntyping. In Amazon CloudSearch, suggestions are based on the contents of a\nparticular text field. When you request suggestions, Amazon CloudSearch finds\nall of the documents whose values in the suggester field start with the\nspecified query string. The beginning of the field must match the query string\nto be considered a match.\n\nFor more information about configuring suggesters and retrieving suggestions,\nsee [Getting Suggestions](http://docs.aws.amazon.com/cloudsearch/latest/developerguide/getting-suggestions.html)\nin the *Amazon CloudSearch Developer Guide*.\n\nThe endpoint for submitting `Suggest` requests is domain-specific. You submit\nsuggest requests to a domain's search endpoint. To get the search endpoint for\nyour domain, use the Amazon CloudSearch configuration service `DescribeDomains`\naction. A domain's endpoints are also displayed on the domain dashboard in the\nAmazon CloudSearch console.","ref":"AWS.CloudSearchDomain.html#suggest/5","title":"AWS.CloudSearchDomain.suggest/5","type":"function"},{"doc":"Posts a batch of documents to a search domain for indexing.\n\nA document batch is a collection of add and delete operations that represent the\ndocuments you want to add, update, or delete from your domain. Batches can be\ndescribed in either JSON or XML. Each item that you want Amazon CloudSearch to\nreturn as a search result (such as a product) is represented as a document.\nEvery document has a unique ID and one or more fields that contain the data that\nyou want to search and return in results. Individual documents cannot contain\nmore than 1 MB of data. The entire batch cannot exceed 5 MB. To get the best\npossible upload performance, group add and delete operations in batches that are\nclose the 5 MB limit. Submitting a large volume of single-document batches can\noverload a domain's document service.\n\nThe endpoint for submitting `UploadDocuments` requests is domain-specific. To\nget the document endpoint for your domain, use the Amazon CloudSearch\nconfiguration service `DescribeDomains` action. A domain's endpoints are also\ndisplayed on the domain dashboard in the Amazon CloudSearch console.\n\nFor more information about formatting your data for Amazon CloudSearch, see\n[Preparing Your Data](http://docs.aws.amazon.com/cloudsearch/latest/developerguide/preparing-data.html)\nin the *Amazon CloudSearch Developer Guide*. For more information about\nuploading data for indexing, see [Uploading Data](http://docs.aws.amazon.com/cloudsearch/latest/developerguide/uploading-data.html)\nin the *Amazon CloudSearch Developer Guide*.","ref":"AWS.CloudSearchDomain.html#upload_documents/3","title":"AWS.CloudSearchDomain.upload_documents/3","type":"function"},{"doc":"CloudTrail\n\nThis is the CloudTrail API Reference.\n\nIt provides descriptions of actions, data types, common parameters, and common\nerrors for CloudTrail.\n\nCloudTrail is a web service that records Amazon Web Services API calls for your\nAmazon Web Services account and delivers log files to an Amazon S3 bucket. The\nrecorded information includes the identity of the user, the start time of the\nAmazon Web Services API call, the source IP address, the request parameters, and\nthe response elements returned by the service.\n\nAs an alternative to the API, you can use one of the Amazon Web Services SDKs,\nwhich consist of libraries and sample code for various programming languages and\nplatforms (Java, Ruby, .NET, iOS, Android, etc.). The SDKs provide programmatic\naccess to CloudTrail. For example, the SDKs handle cryptographically signing\nrequests, managing errors, and retrying requests automatically. For more\ninformation about the Amazon Web Services SDKs, including how to download and\ninstall them, see [Tools to Build on Amazon Web Services](http://aws.amazon.com/tools/).\n\nSee the [CloudTrail User Guide](https://docs.aws.amazon.com/awscloudtrail/latest/userguide/cloudtrail-user-guide.html)\nfor information about the data that is included with each Amazon Web Services\nAPI call listed in the log files.","ref":"AWS.CloudTrail.html","title":"AWS.CloudTrail","type":"module"},{"doc":"Adds one or more tags to a trail, event data store, or channel, up to a limit of\n50.\n\nOverwrites an existing tag's value when a new value is specified for an existing\ntag key. Tag key names must be unique; you cannot have two keys with the same\nname but different values. If you specify a key without a value, the tag will be\ncreated with the specified key and a value of null. You can tag a trail or event\ndata store that applies to all Amazon Web Services Regions only from the Region\nin which the trail or event data store was created (also known as its home\nRegion).","ref":"AWS.CloudTrail.html#add_tags/3","title":"AWS.CloudTrail.add_tags/3","type":"function"},{"doc":"Cancels a query if the query is not in a terminated state, such as `CANCELLED`,\n`FAILED`, `TIMED_OUT`, or `FINISHED`.\n\nYou must specify an ARN value for `EventDataStore`. The ID of the query that you\nwant to cancel is also required. When you run `CancelQuery`, the query status\nmight show as `CANCELLED` even if the operation is not yet finished.","ref":"AWS.CloudTrail.html#cancel_query/3","title":"AWS.CloudTrail.cancel_query/3","type":"function"},{"doc":"Creates a channel for CloudTrail to ingest events from a partner or external\nsource.\n\nAfter you create a channel, a CloudTrail Lake event data store can log events\nfrom the partner or source that you specify.","ref":"AWS.CloudTrail.html#create_channel/3","title":"AWS.CloudTrail.create_channel/3","type":"function"},{"doc":"Creates a new event data store.","ref":"AWS.CloudTrail.html#create_event_data_store/3","title":"AWS.CloudTrail.create_event_data_store/3","type":"function"},{"doc":"Creates a trail that specifies the settings for delivery of log data to an\nAmazon S3 bucket.","ref":"AWS.CloudTrail.html#create_trail/3","title":"AWS.CloudTrail.create_trail/3","type":"function"},{"doc":"Deletes a channel.","ref":"AWS.CloudTrail.html#delete_channel/3","title":"AWS.CloudTrail.delete_channel/3","type":"function"},{"doc":"Disables the event data store specified by `EventDataStore`, which accepts an\nevent data store ARN.\n\nAfter you run `DeleteEventDataStore`, the event data store enters a\n`PENDING_DELETION` state, and is automatically deleted after a wait period of\nseven days. `TerminationProtectionEnabled` must be set to `False` on the event\ndata store and the `FederationStatus` must be `DISABLED`. You cannot delete an\nevent data store if `TerminationProtectionEnabled` is `True` or the\n`FederationStatus` is `ENABLED`.\n\nAfter you run `DeleteEventDataStore` on an event data store, you cannot run\n`ListQueries`, `DescribeQuery`, or `GetQueryResults` on queries that are using\nan event data store in a `PENDING_DELETION` state. An event data store in the\n`PENDING_DELETION` state does not incur costs.","ref":"AWS.CloudTrail.html#delete_event_data_store/3","title":"AWS.CloudTrail.delete_event_data_store/3","type":"function"},{"doc":"Deletes the resource-based policy attached to the CloudTrail channel.","ref":"AWS.CloudTrail.html#delete_resource_policy/3","title":"AWS.CloudTrail.delete_resource_policy/3","type":"function"},{"doc":"Deletes a trail.\n\nThis operation must be called from the Region in which the trail was created.\n`DeleteTrail` cannot be called on the shadow trails (replicated trails in other\nRegions) of a trail that is enabled in all Regions.","ref":"AWS.CloudTrail.html#delete_trail/3","title":"AWS.CloudTrail.delete_trail/3","type":"function"},{"doc":"Removes CloudTrail delegated administrator permissions from a member account in\nan organization.","ref":"AWS.CloudTrail.html#deregister_organization_delegated_admin/3","title":"AWS.CloudTrail.deregister_organization_delegated_admin/3","type":"function"},{"doc":"Returns metadata about a query, including query run time in milliseconds, number\nof events scanned and matched, and query status.\n\nIf the query results were delivered to an S3 bucket, the response also provides\nthe S3 URI and the delivery status.\n\nYou must specify either a `QueryID` or a `QueryAlias`. Specifying the\n`QueryAlias` parameter returns information about the last query run for the\nalias.","ref":"AWS.CloudTrail.html#describe_query/3","title":"AWS.CloudTrail.describe_query/3","type":"function"},{"doc":"Retrieves settings for one or more trails associated with the current Region for\nyour account.","ref":"AWS.CloudTrail.html#describe_trails/3","title":"AWS.CloudTrail.describe_trails/3","type":"function"},{"doc":"Disables Lake query federation on the specified event data store.\n\nWhen you disable federation, CloudTrail disables the integration with Glue, Lake\nFormation, and Amazon Athena. After disabling Lake query federation, you can no\nlonger query your event data in Amazon Athena.\n\nNo CloudTrail Lake data is deleted when you disable federation and you can\ncontinue to run queries in CloudTrail Lake.","ref":"AWS.CloudTrail.html#disable_federation/3","title":"AWS.CloudTrail.disable_federation/3","type":"function"},{"doc":"Enables Lake query federation on the specified event data store.\n\nFederating an event data store lets you view the metadata associated with the\nevent data store in the Glue [Data Catalog](https://docs.aws.amazon.com/glue/latest/dg/components-overview.html#data-catalog-intro)\nand run SQL queries against your event data using Amazon Athena. The table\nmetadata stored in the Glue Data Catalog lets the Athena query engine know how\nto find, read, and process the data that you want to query.\n\nWhen you enable Lake query federation, CloudTrail creates a managed database\nnamed `aws:cloudtrail` (if the database doesn't already exist) and a managed\nfederated table in the Glue Data Catalog. The event data store ID is used for\nthe table name. CloudTrail registers the role ARN and event data store in [Lake Formation](https://docs.aws.amazon.com/awscloudtrail/latest/userguide/query-federation-lake-formation.html),\nthe service responsible for allowing fine-grained access control of the\nfederated resources in the Glue Data Catalog.\n\nFor more information about Lake query federation, see [Federate an event data store](https://docs.aws.amazon.com/awscloudtrail/latest/userguide/query-federation.html).","ref":"AWS.CloudTrail.html#enable_federation/3","title":"AWS.CloudTrail.enable_federation/3","type":"function"},{"doc":"Returns information about a specific channel.","ref":"AWS.CloudTrail.html#get_channel/3","title":"AWS.CloudTrail.get_channel/3","type":"function"},{"doc":"Returns information about an event data store specified as either an ARN or the\nID portion of the ARN.","ref":"AWS.CloudTrail.html#get_event_data_store/3","title":"AWS.CloudTrail.get_event_data_store/3","type":"function"},{"doc":"Describes the settings for the event selectors that you configured for your\ntrail.\n\nThe information returned for your event selectors includes the following:\n\n  * If your event selector includes read-only events, write-only\nevents, or all events. This applies to both management events and data events.\n\n  * If your event selector includes management events.\n\n  * If your event selector includes data events, the resources on\nwhich you are logging data events.\n\nFor more information about logging management and data events, see the following\ntopics in the *CloudTrail User Guide*:\n\n  * [Logging management events](https://docs.aws.amazon.com/awscloudtrail/latest/userguide/logging-management-events-with-cloudtrail.html)\n\n  * [Logging data events](https://docs.aws.amazon.com/awscloudtrail/latest/userguide/logging-data-events-with-cloudtrail.html)","ref":"AWS.CloudTrail.html#get_event_selectors/3","title":"AWS.CloudTrail.get_event_selectors/3","type":"function"},{"doc":"Returns information about a specific import.","ref":"AWS.CloudTrail.html#get_import/3","title":"AWS.CloudTrail.get_import/3","type":"function"},{"doc":"Describes the settings for the Insights event selectors that you configured for\nyour trail or event data store.\n\n`GetInsightSelectors` shows if CloudTrail Insights event logging is enabled on\nthe trail or event data store, and if it is, which Insights types are enabled.\nIf you run `GetInsightSelectors` on a trail or event data store that does not\nhave Insights events enabled, the operation throws the exception\n`InsightNotEnabledException`\n\nSpecify either the `EventDataStore` parameter to get Insights event selectors\nfor an event data store, or the `TrailName` parameter to the get Insights event\nselectors for a trail. You cannot specify these parameters together.\n\nFor more information, see [Logging CloudTrail Insights events](https://docs.aws.amazon.com/awscloudtrail/latest/userguide/logging-insights-events-with-cloudtrail.html)\nin the *CloudTrail User Guide*.","ref":"AWS.CloudTrail.html#get_insight_selectors/3","title":"AWS.CloudTrail.get_insight_selectors/3","type":"function"},{"doc":"Gets event data results of a query.\n\nYou must specify the `QueryID` value returned by the `StartQuery` operation.","ref":"AWS.CloudTrail.html#get_query_results/3","title":"AWS.CloudTrail.get_query_results/3","type":"function"},{"doc":"Retrieves the JSON text of the resource-based policy document attached to the\nCloudTrail channel.","ref":"AWS.CloudTrail.html#get_resource_policy/3","title":"AWS.CloudTrail.get_resource_policy/3","type":"function"},{"doc":"Returns settings information for a specified trail.","ref":"AWS.CloudTrail.html#get_trail/3","title":"AWS.CloudTrail.get_trail/3","type":"function"},{"doc":"Returns a JSON-formatted list of information about the specified trail.\n\nFields include information on delivery errors, Amazon SNS and Amazon S3 errors,\nand start and stop logging times for each trail. This operation returns trail\nstatus from a single Region. To return trail status from all Regions, you must\ncall the operation on each Region.","ref":"AWS.CloudTrail.html#get_trail_status/3","title":"AWS.CloudTrail.get_trail_status/3","type":"function"},{"doc":"Lists the channels in the current account, and their source names.","ref":"AWS.CloudTrail.html#list_channels/3","title":"AWS.CloudTrail.list_channels/3","type":"function"},{"doc":"Returns information about all event data stores in the account, in the current\nRegion.","ref":"AWS.CloudTrail.html#list_event_data_stores/3","title":"AWS.CloudTrail.list_event_data_stores/3","type":"function"},{"doc":"Returns a list of failures for the specified import.","ref":"AWS.CloudTrail.html#list_import_failures/3","title":"AWS.CloudTrail.list_import_failures/3","type":"function"},{"doc":"Returns information on all imports, or a select set of imports by `ImportStatus`\nor `Destination`.","ref":"AWS.CloudTrail.html#list_imports/3","title":"AWS.CloudTrail.list_imports/3","type":"function"},{"doc":"Returns Insights metrics data for trails that have enabled Insights.\n\nThe request must include the `EventSource`, `EventName`, and `InsightType`\nparameters.\n\nIf the `InsightType` is set to `ApiErrorRateInsight`, the request must also\ninclude the `ErrorCode` parameter.\n\nThe following are the available time periods for `ListInsightsMetricData`. Each\ncutoff is inclusive.\n\n  * Data points with a period of 60 seconds (1-minute) are available\nfor 15 days.\n\n  * Data points with a period of 300 seconds (5-minute) are available\nfor 63 days.\n\n  * Data points with a period of 3600 seconds (1 hour) are available\nfor 90 days.\n\nAccess to the `ListInsightsMetricData` API operation is linked to the\n`cloudtrail:LookupEvents` action. To use this operation, you must have\npermissions to perform the `cloudtrail:LookupEvents` action.","ref":"AWS.CloudTrail.html#list_insights_metric_data/3","title":"AWS.CloudTrail.list_insights_metric_data/3","type":"function"},{"doc":"Returns all public keys whose private keys were used to sign the digest files\nwithin the specified time range.\n\nThe public key is needed to validate digest files that were signed with its\ncorresponding private key.\n\nCloudTrail uses different private and public key pairs per Region. Each digest\nfile is signed with a private key unique to its Region. When you validate a\ndigest file from a specific Region, you must look in the same Region for its\ncorresponding public key.","ref":"AWS.CloudTrail.html#list_public_keys/3","title":"AWS.CloudTrail.list_public_keys/3","type":"function"},{"doc":"Returns a list of queries and query statuses for the past seven days.\n\nYou must specify an ARN value for `EventDataStore`. Optionally, to shorten the\nlist of results, you can specify a time range, formatted as timestamps, by\nadding `StartTime` and `EndTime` parameters, and a `QueryStatus` value. Valid\nvalues for `QueryStatus` include `QUEUED`, `RUNNING`, `FINISHED`, `FAILED`,\n`TIMED_OUT`, or `CANCELLED`.","ref":"AWS.CloudTrail.html#list_queries/3","title":"AWS.CloudTrail.list_queries/3","type":"function"},{"doc":"Lists the tags for the specified trails, event data stores, or channels in the\ncurrent Region.","ref":"AWS.CloudTrail.html#list_tags/3","title":"AWS.CloudTrail.list_tags/3","type":"function"},{"doc":"Lists trails that are in the current account.","ref":"AWS.CloudTrail.html#list_trails/3","title":"AWS.CloudTrail.list_trails/3","type":"function"},{"doc":"Looks up [management events](https://docs.aws.amazon.com/awscloudtrail/latest/userguide/cloudtrail-concepts.html#cloudtrail-concepts-management-events)\nor [CloudTrail Insights events](https://docs.aws.amazon.com/awscloudtrail/latest/userguide/cloudtrail-concepts.html#cloudtrail-concepts-insights-events)\nthat are captured by CloudTrail.\n\nYou can look up events that occurred in a Region within the last 90 days.\n\n`LookupEvents` returns recent Insights events for trails that enable Insights.\nTo view Insights events for an event data store, you can run queries on your\nInsights event data store, and you can also view the Lake dashboard for\nInsights.\n\nLookup supports the following attributes for management events:\n\n  * Amazon Web Services access key\n\n  * Event ID\n\n  * Event name\n\n  * Event source\n\n  * Read only\n\n  * Resource name\n\n  * Resource type\n\n  * User name\n\nLookup supports the following attributes for Insights events:\n\n  * Event ID\n\n  * Event name\n\n  * Event source\n\nAll attributes are optional. The default number of results returned is 50, with\na maximum of 50 possible. The response includes a token that you can use to get\nthe next page of results.\n\nThe rate of lookup requests is limited to two per second, per account, per\nRegion. If this limit is exceeded, a throttling error occurs.","ref":"AWS.CloudTrail.html#lookup_events/3","title":"AWS.CloudTrail.lookup_events/3","type":"function"},{"doc":"","ref":"AWS.CloudTrail.html#metadata/0","title":"AWS.CloudTrail.metadata/0","type":"function"},{"doc":"Configures an event selector or advanced event selectors for your trail.\n\nUse event selectors or advanced event selectors to specify management and data\nevent settings for your trail. If you want your trail to log Insights events, be\nsure the event selector enables logging of the Insights event types you want\nconfigured for your trail. For more information about logging Insights events,\nsee [Logging Insights events for trails](https://docs.aws.amazon.com/awscloudtrail/latest/userguide/logging-insights-events-with-cloudtrail.html)\nin the *CloudTrail User Guide*. By default, trails created without specific\nevent selectors are configured to log all read and write management events, and\nno data events.\n\nWhen an event occurs in your account, CloudTrail evaluates the event selectors\nor advanced event selectors in all trails. For each trail, if the event matches\nany event selector, the trail processes and logs the event. If the event doesn't\nmatch any event selector, the trail doesn't log the event.\n\nExample\n\n  1. You create an event selector for a trail and specify that you\nwant write-only events.\n\n  2. The EC2 `GetConsoleOutput` and `RunInstances` API operations\noccur in your account.\n\n  3. CloudTrail evaluates whether the events match your event\nselectors.\n\n  4. The `RunInstances` is a write-only event and it matches your\nevent selector. The trail logs the event.\n\n  5. The `GetConsoleOutput` is a read-only event that doesn't match\nyour event selector. The trail doesn't log the event.\n\nThe `PutEventSelectors` operation must be called from the Region in which the\ntrail was created; otherwise, an `InvalidHomeRegionException` exception is\nthrown.\n\nYou can configure up to five event selectors for each trail. For more\ninformation, see [Logging management events](https://docs.aws.amazon.com/awscloudtrail/latest/userguide/logging-management-events-with-cloudtrail.html),\n[Logging data events](https://docs.aws.amazon.com/awscloudtrail/latest/userguide/logging-data-events-with-cloudtrail.html),\nand [Quotas in CloudTrail](https://docs.aws.amazon.com/awscloudtrail/latest/userguide/WhatIsCloudTrail-Limits.html)\nin the *CloudTrail User Guide*.\n\nYou can add advanced event selectors, and conditions for your advanced event\nselectors, up to a maximum of 500 values for all conditions and selectors on a\ntrail. You can use either `AdvancedEventSelectors` or `EventSelectors`, but not\nboth. If you apply `AdvancedEventSelectors` to a trail, any existing\n`EventSelectors` are overwritten. For more information about advanced event\nselectors, see [Logging data events](https://docs.aws.amazon.com/awscloudtrail/latest/userguide/logging-data-events-with-cloudtrail.html)\nin the *CloudTrail User Guide*.","ref":"AWS.CloudTrail.html#put_event_selectors/3","title":"AWS.CloudTrail.put_event_selectors/3","type":"function"},{"doc":"Lets you enable Insights event logging by specifying the Insights selectors that\nyou want to enable on an existing trail or event data store.\n\nYou also use `PutInsightSelectors` to turn off Insights event logging, by\npassing an empty list of Insights types. The valid Insights event types are\n`ApiErrorRateInsight` and `ApiCallRateInsight`.\n\nTo enable Insights on an event data store, you must specify the ARNs (or ID\nsuffix of the ARNs) for the source event data store (`EventDataStore`) and the\ndestination event data store (`InsightsDestination`). The source event data\nstore logs management events and enables Insights. The destination event data\nstore logs Insights events based upon the management event activity of the\nsource event data store. The source and destination event data stores must\nbelong to the same Amazon Web Services account.\n\nTo log Insights events for a trail, you must specify the name (`TrailName`) of\nthe CloudTrail trail for which you want to change or add Insights selectors.\n\nTo log CloudTrail Insights events on API call volume, the trail or event data\nstore must log `write` management events. To log CloudTrail Insights events on\nAPI error rate, the trail or event data store must log `read` or `write`\nmanagement events. You can call `GetEventSelectors` on a trail to check whether\nthe trail logs management events. You can call `GetEventDataStore` on an event\ndata store to check whether the event data store logs management events.\n\nFor more information, see [Logging CloudTrail Insights events](https://docs.aws.amazon.com/awscloudtrail/latest/userguide/logging-insights-events-with-cloudtrail.html)\nin the *CloudTrail User Guide*.","ref":"AWS.CloudTrail.html#put_insight_selectors/3","title":"AWS.CloudTrail.put_insight_selectors/3","type":"function"},{"doc":"Attaches a resource-based permission policy to a CloudTrail channel that is used\nfor an integration with an event source outside of Amazon Web Services.\n\nFor more information about resource-based policies, see [CloudTrail resource-based policy\nexamples](https://docs.aws.amazon.com/awscloudtrail/latest/userguide/security_iam_resource-based-policy-examples.html)\nin the *CloudTrail User Guide*.","ref":"AWS.CloudTrail.html#put_resource_policy/3","title":"AWS.CloudTrail.put_resource_policy/3","type":"function"},{"doc":"Registers an organization’s member account as the CloudTrail [delegated administrator](https://docs.aws.amazon.com/awscloudtrail/latest/userguide/cloudtrail-delegated-administrator.html).","ref":"AWS.CloudTrail.html#register_organization_delegated_admin/3","title":"AWS.CloudTrail.register_organization_delegated_admin/3","type":"function"},{"doc":"Removes the specified tags from a trail, event data store, or channel.","ref":"AWS.CloudTrail.html#remove_tags/3","title":"AWS.CloudTrail.remove_tags/3","type":"function"},{"doc":"Restores a deleted event data store specified by `EventDataStore`, which accepts\nan event data store ARN.\n\nYou can only restore a deleted event data store within the seven-day wait period\nafter deletion. Restoring an event data store can take several minutes,\ndepending on the size of the event data store.","ref":"AWS.CloudTrail.html#restore_event_data_store/3","title":"AWS.CloudTrail.restore_event_data_store/3","type":"function"},{"doc":"Starts the ingestion of live events on an event data store specified as either\nan ARN or the ID portion of the ARN.\n\nTo start ingestion, the event data store `Status` must be `STOPPED_INGESTION`\nand the `eventCategory` must be `Management`, `Data`, or `ConfigurationItem`.","ref":"AWS.CloudTrail.html#start_event_data_store_ingestion/3","title":"AWS.CloudTrail.start_event_data_store_ingestion/3","type":"function"},{"doc":"Starts an import of logged trail events from a source S3 bucket to a destination\nevent data store.\n\nBy default, CloudTrail only imports events contained in the S3 bucket's\n`CloudTrail` prefix and the prefixes inside the `CloudTrail` prefix, and does\nnot check prefixes for other Amazon Web Services services. If you want to import\nCloudTrail events contained in another prefix, you must include the prefix in\nthe `S3LocationUri`. For more considerations about importing trail events, see\n[Considerations](https://docs.aws.amazon.com/awscloudtrail/latest/userguide/cloudtrail-copy-trail-to-lake.html#cloudtrail-trail-copy-considerations).  When you start a new import, the `Destinations` and `ImportSource` parameters\nare required. Before starting a new import, disable any access control lists\n(ACLs) attached to the source S3 bucket. For more information about disabling\nACLs, see [Controlling ownership of objects and disabling ACLs for your\nbucket](https://docs.aws.amazon.com/AmazonS3/latest/userguide/about-object-ownership.html).\n\nWhen you retry an import, the `ImportID` parameter is required.\n\nIf the destination event data store is for an organization, you must use the\nmanagement account to import trail events. You cannot use the delegated\nadministrator account for the organization.","ref":"AWS.CloudTrail.html#start_import/3","title":"AWS.CloudTrail.start_import/3","type":"function"},{"doc":"Starts the recording of Amazon Web Services API calls and log file delivery for\na trail.\n\nFor a trail that is enabled in all Regions, this operation must be called from\nthe Region in which the trail was created. This operation cannot be called on\nthe shadow trails (replicated trails in other Regions) of a trail that is\nenabled in all Regions.","ref":"AWS.CloudTrail.html#start_logging/3","title":"AWS.CloudTrail.start_logging/3","type":"function"},{"doc":"Starts a CloudTrail Lake query.\n\nUse the `QueryStatement` parameter to provide your SQL query, enclosed in single\nquotation marks. Use the optional `DeliveryS3Uri` parameter to deliver the query\nresults to an S3 bucket.\n\n`StartQuery` requires you specify either the `QueryStatement` parameter, or a\n`QueryAlias` and any `QueryParameters`. In the current release, the `QueryAlias`\nand `QueryParameters` parameters are used only for the queries that populate the\nCloudTrail Lake dashboards.","ref":"AWS.CloudTrail.html#start_query/3","title":"AWS.CloudTrail.start_query/3","type":"function"},{"doc":"Stops the ingestion of live events on an event data store specified as either an\nARN or the ID portion of the ARN.\n\nTo stop ingestion, the event data store `Status` must be `ENABLED` and the\n`eventCategory` must be `Management`, `Data`, or `ConfigurationItem`.","ref":"AWS.CloudTrail.html#stop_event_data_store_ingestion/3","title":"AWS.CloudTrail.stop_event_data_store_ingestion/3","type":"function"},{"doc":"Stops a specified import.","ref":"AWS.CloudTrail.html#stop_import/3","title":"AWS.CloudTrail.stop_import/3","type":"function"},{"doc":"Suspends the recording of Amazon Web Services API calls and log file delivery\nfor the specified trail.\n\nUnder most circumstances, there is no need to use this action. You can update a\ntrail without stopping it first. This action is the only way to stop recording.\nFor a trail enabled in all Regions, this operation must be called from the\nRegion in which the trail was created, or an `InvalidHomeRegionException` will\noccur. This operation cannot be called on the shadow trails (replicated trails\nin other Regions) of a trail enabled in all Regions.","ref":"AWS.CloudTrail.html#stop_logging/3","title":"AWS.CloudTrail.stop_logging/3","type":"function"},{"doc":"Updates a channel specified by a required channel ARN or UUID.","ref":"AWS.CloudTrail.html#update_channel/3","title":"AWS.CloudTrail.update_channel/3","type":"function"},{"doc":"Updates an event data store.\n\nThe required `EventDataStore` value is an ARN or the ID portion of the ARN.\nOther parameters are optional, but at least one optional parameter must be\nspecified, or CloudTrail throws an error. `RetentionPeriod` is in days, and\nvalid values are integers between 7 and 3653 if the `BillingMode` is set to\n`EXTENDABLE_RETENTION_PRICING`, or between 7 and 2557 if `BillingMode` is set to\n`FIXED_RETENTION_PRICING`. By default, `TerminationProtection` is enabled.\n\nFor event data stores for CloudTrail events, `AdvancedEventSelectors` includes\nor excludes management or data events in your event data store. For more\ninformation about `AdvancedEventSelectors`, see\n[AdvancedEventSelectors](https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_AdvancedEventSelector.html).\n\nFor event data stores for CloudTrail Insights events, Config configuration\nitems, Audit Manager evidence, or non-Amazon Web Services events,\n`AdvancedEventSelectors` includes events of that type in your event data store.","ref":"AWS.CloudTrail.html#update_event_data_store/3","title":"AWS.CloudTrail.update_event_data_store/3","type":"function"},{"doc":"Updates trail settings that control what events you are logging, and how to\nhandle log files.\n\nChanges to a trail do not require stopping the CloudTrail service. Use this\naction to designate an existing bucket for log delivery. If the existing bucket\nhas previously been a target for CloudTrail log files, an IAM policy exists for\nthe bucket. `UpdateTrail` must be called from the Region in which the trail was\ncreated; otherwise, an `InvalidHomeRegionException` is thrown.","ref":"AWS.CloudTrail.html#update_trail/3","title":"AWS.CloudTrail.update_trail/3","type":"function"},{"doc":"The CloudTrail Data Service lets you ingest events into CloudTrail from any\nsource in your hybrid environments, such as in-house or SaaS applications hosted\non-premises or in the cloud, virtual machines, or containers.\n\nYou can store, access, analyze, troubleshoot and take action on this data\nwithout maintaining multiple log aggregators and reporting tools. After you run\n`PutAuditEvents` to ingest your application activity into CloudTrail, you can\nuse CloudTrail Lake to search, query, and analyze the data that is logged from\nyour applications.","ref":"AWS.CloudTrailData.html","title":"AWS.CloudTrailData","type":"module"},{"doc":"","ref":"AWS.CloudTrailData.html#metadata/0","title":"AWS.CloudTrailData.metadata/0","type":"function"},{"doc":"Ingests your application events into CloudTrail Lake.\n\nA required parameter, `auditEvents`, accepts the JSON records (also called\n*payload*) of events that you want CloudTrail to ingest. You can add up to 100\nof these events (or up to 1 MB) per `PutAuditEvents` request.","ref":"AWS.CloudTrailData.html#put_audit_events/3","title":"AWS.CloudTrailData.put_audit_events/3","type":"function"},{"doc":"Amazon CloudWatch monitors your Amazon Web Services (Amazon Web Services)\nresources and the applications you run on Amazon Web Services in real time.\n\nYou can use CloudWatch to collect and track metrics, which are the variables you\nwant to measure for your resources and applications.\n\nCloudWatch alarms send notifications or automatically change the resources you\nare monitoring based on rules that you define. For example, you can monitor the\nCPU usage and disk reads and writes of your Amazon EC2 instances. Then, use this\ndata to determine whether you should launch additional instances to handle\nincreased load. You can also use this data to stop under-used instances to save\nmoney.\n\nIn addition to monitoring the built-in metrics that come with Amazon Web\nServices, you can monitor your own custom metrics. With CloudWatch, you gain\nsystem-wide visibility into resource utilization, application performance, and\noperational health.","ref":"AWS.CloudWatch.html","title":"AWS.CloudWatch","type":"module"},{"doc":"Deletes the specified alarms.\n\nYou can delete up to 100 alarms in one operation. However, this total can\ninclude no more than one composite alarm. For example, you could delete 99\nmetric alarms and one composite alarms with one operation, but you can't delete\ntwo composite alarms with one operation.\n\nIf you specify an incorrect alarm name or make any other error in the operation,\nno alarms are deleted. To confirm that alarms were deleted successfully, you can\nuse the\n[DescribeAlarms](https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_DescribeAlarms.html)\noperation after using `DeleteAlarms`.\n\nIt is possible to create a loop or cycle of composite alarms, where composite\nalarm A depends on composite alarm B, and composite alarm B also depends on\ncomposite alarm A. In this scenario, you can't delete any composite alarm that\nis part of the cycle because there is always still a composite alarm that\ndepends on that alarm that you want to delete.\n\nTo get out of such a situation, you must break the cycle by changing the rule of\none of the composite alarms in the cycle to remove a dependency that creates the\ncycle. The simplest change to make to break a cycle is to change the `AlarmRule`\nof one of the alarms to `false`.\n\nAdditionally, the evaluation of composite alarms stops if CloudWatch detects a\ncycle in the evaluation path.","ref":"AWS.CloudWatch.html#delete_alarms/3","title":"AWS.CloudWatch.delete_alarms/3","type":"function"},{"doc":"Deletes the specified anomaly detection model from your account.\n\nFor more information about how to delete an anomaly detection model, see\n[Deleting an anomaly detection model](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/Create_Anomaly_Detection_Alarm.html#Delete_Anomaly_Detection_Model)\nin the *CloudWatch User Guide*.","ref":"AWS.CloudWatch.html#delete_anomaly_detector/3","title":"AWS.CloudWatch.delete_anomaly_detector/3","type":"function"},{"doc":"Deletes all dashboards that you specify.\n\nYou can specify up to 100 dashboards to delete. If there is an error during this\ncall, no dashboards are deleted.","ref":"AWS.CloudWatch.html#delete_dashboards/3","title":"AWS.CloudWatch.delete_dashboards/3","type":"function"},{"doc":"Permanently deletes the specified Contributor Insights rules.\n\nIf you create a rule, delete it, and then re-create it with the same name,\nhistorical data from the first time the rule was created might not be available.","ref":"AWS.CloudWatch.html#delete_insight_rules/3","title":"AWS.CloudWatch.delete_insight_rules/3","type":"function"},{"doc":"Permanently deletes the metric stream that you specify.","ref":"AWS.CloudWatch.html#delete_metric_stream/3","title":"AWS.CloudWatch.delete_metric_stream/3","type":"function"},{"doc":"Retrieves the history for the specified alarm.\n\nYou can filter the results by date range or item type. If an alarm name is not\nspecified, the histories for either all metric alarms or all composite alarms\nare returned.\n\nCloudWatch retains the history of an alarm even if you delete the alarm.\n\nTo use this operation and return information about a composite alarm, you must\nbe signed on with the `cloudwatch:DescribeAlarmHistory` permission that is\nscoped to `*`. You can't return information about composite alarms if your\n`cloudwatch:DescribeAlarmHistory` permission has a narrower scope.","ref":"AWS.CloudWatch.html#describe_alarm_history/3","title":"AWS.CloudWatch.describe_alarm_history/3","type":"function"},{"doc":"Retrieves the specified alarms.\n\nYou can filter the results by specifying a prefix for the alarm name, the alarm\nstate, or a prefix for any action.\n\nTo use this operation and return information about composite alarms, you must be\nsigned on with the `cloudwatch:DescribeAlarms` permission that is scoped to `*`.\nYou can't return information about composite alarms if your\n`cloudwatch:DescribeAlarms` permission has a narrower scope.","ref":"AWS.CloudWatch.html#describe_alarms/3","title":"AWS.CloudWatch.describe_alarms/3","type":"function"},{"doc":"Retrieves the alarms for the specified metric.\n\nTo filter the results, specify a statistic, period, or unit.\n\nThis operation retrieves only standard alarms that are based on the specified\nmetric. It does not return alarms based on math expressions that use the\nspecified metric, or composite alarms that use the specified metric.","ref":"AWS.CloudWatch.html#describe_alarms_for_metric/3","title":"AWS.CloudWatch.describe_alarms_for_metric/3","type":"function"},{"doc":"Lists the anomaly detection models that you have created in your account.\n\nFor single metric anomaly detectors, you can list all of the models in your\naccount or filter the results to only the models that are related to a certain\nnamespace, metric name, or metric dimension. For metric math anomaly detectors,\nyou can list them by adding `METRIC_MATH` to the `AnomalyDetectorTypes` array.\nThis will return all metric math anomaly detectors in your account.","ref":"AWS.CloudWatch.html#describe_anomaly_detectors/3","title":"AWS.CloudWatch.describe_anomaly_detectors/3","type":"function"},{"doc":"Returns a list of all the Contributor Insights rules in your account.\n\nFor more information about Contributor Insights, see [Using Contributor Insights to Analyze High-Cardinality\nData](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/ContributorInsights.html).","ref":"AWS.CloudWatch.html#describe_insight_rules/3","title":"AWS.CloudWatch.describe_insight_rules/3","type":"function"},{"doc":"Disables the actions for the specified alarms.\n\nWhen an alarm's actions are disabled, the alarm actions do not execute when the\nalarm state changes.","ref":"AWS.CloudWatch.html#disable_alarm_actions/3","title":"AWS.CloudWatch.disable_alarm_actions/3","type":"function"},{"doc":"Disables the specified Contributor Insights rules.\n\nWhen rules are disabled, they do not analyze log groups and do not incur costs.","ref":"AWS.CloudWatch.html#disable_insight_rules/3","title":"AWS.CloudWatch.disable_insight_rules/3","type":"function"},{"doc":"Enables the actions for the specified alarms.","ref":"AWS.CloudWatch.html#enable_alarm_actions/3","title":"AWS.CloudWatch.enable_alarm_actions/3","type":"function"},{"doc":"Enables the specified Contributor Insights rules.\n\nWhen rules are enabled, they immediately begin analyzing log data.","ref":"AWS.CloudWatch.html#enable_insight_rules/3","title":"AWS.CloudWatch.enable_insight_rules/3","type":"function"},{"doc":"Displays the details of the dashboard that you specify.\n\nTo copy an existing dashboard, use `GetDashboard`, and then use the data\nreturned within `DashboardBody` as the template for the new dashboard when you\ncall `PutDashboard` to create the copy.","ref":"AWS.CloudWatch.html#get_dashboard/3","title":"AWS.CloudWatch.get_dashboard/3","type":"function"},{"doc":"This operation returns the time series data collected by a Contributor Insights\nrule.\n\nThe data includes the identity and number of contributors to the log group.\n\nYou can also optionally return one or more statistics about each data point in\nthe time series. These statistics can include the following:\n\n  * `UniqueContributors` -- the number of unique contributors for each\ndata point.\n\n  * `MaxContributorValue` -- the value of the top contributor for each\ndata point. The identity of the contributor might change for each data point in\nthe graph.\n\nIf this rule aggregates by COUNT, the top contributor for each data point is the\ncontributor with the most occurrences in that period. If the rule aggregates by\nSUM, the top contributor is the contributor with the highest sum in the log\nfield specified by the rule's `Value`, during that period.\n\n  * `SampleCount` -- the number of data points matched by the rule.\n\n  * `Sum` -- the sum of the values from all contributors during the\ntime period represented by that data point.\n\n  * `Minimum` -- the minimum value from a single observation during\nthe time period represented by that data point.\n\n  * `Maximum` -- the maximum value from a single observation during\nthe time period represented by that data point.\n\n  * `Average` -- the average value from all contributors during the\ntime period represented by that data point.","ref":"AWS.CloudWatch.html#get_insight_rule_report/3","title":"AWS.CloudWatch.get_insight_rule_report/3","type":"function"},{"doc":"You can use the `GetMetricData` API to retrieve CloudWatch metric values.\n\nThe operation can also include a CloudWatch Metrics Insights query, and one or\nmore metric math functions.\n\nA `GetMetricData` operation that does not include a query can retrieve as many\nas 500 different metrics in a single request, with a total of as many as 100,800\ndata points. You can also optionally perform metric math expressions on the\nvalues of the returned statistics, to create new time series that represent new\ninsights into your data. For example, using Lambda metrics, you could divide the\nErrors metric by the Invocations metric to get an error rate time series. For\nmore information about metric math expressions, see [Metric Math Syntax and Functions](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/using-metric-math.html#metric-math-syntax)\nin the *Amazon CloudWatch User Guide*.\n\nIf you include a Metrics Insights query, each `GetMetricData` operation can\ninclude only one query. But the same `GetMetricData` operation can also retrieve\nother metrics. Metrics Insights queries can query only the most recent three\nhours of metric data. For more information about Metrics Insights, see [Query your metrics with CloudWatch Metrics\nInsights](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/query_with_cloudwatch-metrics-insights.html).\n\nCalls to the `GetMetricData` API have a different pricing structure than calls\nto `GetMetricStatistics`. For more information about pricing, see [Amazon CloudWatch Pricing](https://aws.amazon.com/cloudwatch/pricing/).\n\nAmazon CloudWatch retains metric data as follows:\n\n  * Data points with a period of less than 60 seconds are available\nfor 3 hours. These data points are high-resolution metrics and are available\nonly for custom metrics that have been defined with a `StorageResolution` of 1.\n\n  * Data points with a period of 60 seconds (1-minute) are available\nfor 15 days.\n\n  * Data points with a period of 300 seconds (5-minute) are available\nfor 63 days.\n\n  * Data points with a period of 3600 seconds (1 hour) are available\nfor 455 days (15 months).\n\nData points that are initially published with a shorter period are aggregated\ntogether for long-term storage. For example, if you collect data using a period\nof 1 minute, the data remains available for 15 days with 1-minute resolution.\nAfter 15 days, this data is still available, but is aggregated and retrievable\nonly with a resolution of 5 minutes. After 63 days, the data is further\naggregated and is available with a resolution of 1 hour.\n\nIf you omit `Unit` in your request, all data that was collected with any unit is\nreturned, along with the corresponding units that were specified when the data\nwas reported to CloudWatch. If you specify a unit, the operation returns only\ndata that was collected with that unit specified. If you specify a unit that\ndoes not match the data collected, the results of the operation are null.\nCloudWatch does not perform unit conversions.","ref":"AWS.CloudWatch.html#get_metric_data/3","title":"AWS.CloudWatch.get_metric_data/3","type":"function"},{"doc":"You can't mix a Metric Insights query and metric math syntax in the same\nexpression, but you can reference results from a Metrics Insights query within\nother Metric math expressions. A Metrics Insights query without a","ref":"AWS.CloudWatch.html#get_metric_data/3-using-metrics-insights-queries-with-metric-math","title":"Using Metrics Insights queries with metric math - AWS.CloudWatch.get_metric_data/3","type":"function"},{"doc":"clause returns a single time-series (TS), and can be used as input for a metric\nmath expression that expects a single time series. A Metrics Insights query with\na **GROUP BY** clause returns an array of time-series (TS[]), and can be used as\ninput for a metric math expression that expects an array of time series.","ref":"AWS.CloudWatch.html#get_metric_data/3-group-by","title":"GROUP BY - AWS.CloudWatch.get_metric_data/3","type":"function"},{"doc":"Gets statistics for the specified metric.\n\nThe maximum number of data points returned from a single call is 1,440. If you\nrequest more than 1,440 data points, CloudWatch returns an error. To reduce the\nnumber of data points, you can narrow the specified time range and make multiple\nrequests across adjacent time ranges, or you can increase the specified period.\nData points are not returned in chronological order.\n\nCloudWatch aggregates data points based on the length of the period that you\nspecify. For example, if you request statistics with a one-hour period,\nCloudWatch aggregates all data points with time stamps that fall within each\none-hour period. Therefore, the number of values aggregated by CloudWatch is\nlarger than the number of data points returned.\n\nCloudWatch needs raw data points to calculate percentile statistics. If you\npublish data using a statistic set instead, you can only retrieve percentile\nstatistics for this data if one of the following conditions is true:\n\n  * The SampleCount value of the statistic set is 1.\n\n  * The Min and the Max values of the statistic set are equal.\n\nPercentile statistics are not available for metrics when any of the metric\nvalues are negative numbers.\n\nAmazon CloudWatch retains metric data as follows:\n\n  * Data points with a period of less than 60 seconds are available\nfor 3 hours. These data points are high-resolution metrics and are available\nonly for custom metrics that have been defined with a `StorageResolution` of 1.\n\n  * Data points with a period of 60 seconds (1-minute) are available\nfor 15 days.\n\n  * Data points with a period of 300 seconds (5-minute) are available\nfor 63 days.\n\n  * Data points with a period of 3600 seconds (1 hour) are available\nfor 455 days (15 months).\n\nData points that are initially published with a shorter period are aggregated\ntogether for long-term storage. For example, if you collect data using a period\nof 1 minute, the data remains available for 15 days with 1-minute resolution.\nAfter 15 days, this data is still available, but is aggregated and retrievable\nonly with a resolution of 5 minutes. After 63 days, the data is further\naggregated and is available with a resolution of 1 hour.\n\nCloudWatch started retaining 5-minute and 1-hour metric data as of July 9, 2016.\n\nFor information about metrics and dimensions supported by Amazon Web Services\nservices, see the [Amazon CloudWatch Metrics and Dimensions Reference](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CW_Support_For_AWS.html)\nin the *Amazon CloudWatch User Guide*.","ref":"AWS.CloudWatch.html#get_metric_statistics/3","title":"AWS.CloudWatch.get_metric_statistics/3","type":"function"},{"doc":"Returns information about the metric stream that you specify.","ref":"AWS.CloudWatch.html#get_metric_stream/3","title":"AWS.CloudWatch.get_metric_stream/3","type":"function"},{"doc":"You can use the `GetMetricWidgetImage` API to retrieve a snapshot graph of one\nor more Amazon CloudWatch metrics as a bitmap image.\n\nYou can then embed this image into your services and products, such as wiki\npages, reports, and documents. You could also retrieve images regularly, such as\nevery minute, and create your own custom live dashboard.\n\nThe graph you retrieve can include all CloudWatch metric graph features,\nincluding metric math and horizontal and vertical annotations.\n\nThere is a limit of 20 transactions per second for this API. Each\n`GetMetricWidgetImage` action has the following limits:\n\n  * As many as 100 metrics in the graph.\n\n  * Up to 100 KB uncompressed payload.","ref":"AWS.CloudWatch.html#get_metric_widget_image/3","title":"AWS.CloudWatch.get_metric_widget_image/3","type":"function"},{"doc":"Returns a list of the dashboards for your account.\n\nIf you include `DashboardNamePrefix`, only those dashboards with names starting\nwith the prefix are listed. Otherwise, all dashboards in your account are\nlisted.\n\n`ListDashboards` returns up to 1000 results on one page. If there are more than\n1000 dashboards, you can call `ListDashboards` again and include the value you\nreceived for `NextToken` in the first call, to receive the next 1000 results.","ref":"AWS.CloudWatch.html#list_dashboards/3","title":"AWS.CloudWatch.list_dashboards/3","type":"function"},{"doc":"Returns a list that contains the number of managed Contributor Insights rules in\nyour account.","ref":"AWS.CloudWatch.html#list_managed_insight_rules/3","title":"AWS.CloudWatch.list_managed_insight_rules/3","type":"function"},{"doc":"Returns a list of metric streams in this account.","ref":"AWS.CloudWatch.html#list_metric_streams/3","title":"AWS.CloudWatch.list_metric_streams/3","type":"function"},{"doc":"List the specified metrics.\n\nYou can use the returned metrics with\n[GetMetricData](https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_GetMetricData.html) or\n[GetMetricStatistics](https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_GetMetricStatistics.html)\nto get statistical data.\n\nUp to 500 results are returned for any one call. To retrieve additional results,\nuse the returned token with subsequent calls.\n\nAfter you create a metric, allow up to 15 minutes for the metric to appear. To\nsee metric statistics sooner, use\n[GetMetricData](https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_GetMetricData.html) or\n[GetMetricStatistics](https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_GetMetricStatistics.html).\n\nIf you are using CloudWatch cross-account observability, you can use this\noperation in a monitoring account and view metrics from the linked source\naccounts. For more information, see [CloudWatch cross-account observability](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch-Unified-Cross-Account.html).\n\n`ListMetrics` doesn't return information about metrics if those metrics haven't\nreported data in the past two weeks. To retrieve those metrics, use\n[GetMetricData](https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_GetMetricData.html) or\n[GetMetricStatistics](https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_GetMetricStatistics.html).","ref":"AWS.CloudWatch.html#list_metrics/3","title":"AWS.CloudWatch.list_metrics/3","type":"function"},{"doc":"Displays the tags associated with a CloudWatch resource.\n\nCurrently, alarms and Contributor Insights rules support tagging.","ref":"AWS.CloudWatch.html#list_tags_for_resource/3","title":"AWS.CloudWatch.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.CloudWatch.html#metadata/0","title":"AWS.CloudWatch.metadata/0","type":"function"},{"doc":"Creates an anomaly detection model for a CloudWatch metric.\n\nYou can use the model to display a band of expected normal values when the\nmetric is graphed.\n\nFor more information, see [CloudWatch Anomaly Detection](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch_Anomaly_Detection.html).","ref":"AWS.CloudWatch.html#put_anomaly_detector/3","title":"AWS.CloudWatch.put_anomaly_detector/3","type":"function"},{"doc":"Creates or updates a *composite alarm*.\n\nWhen you create a composite alarm, you specify a rule expression for the alarm\nthat takes into account the alarm states of other alarms that you have created.\nThe composite alarm goes into ALARM state only if all conditions of the rule are\nmet.\n\nThe alarms specified in a composite alarm's rule expression can include metric\nalarms and other composite alarms. The rule expression of a composite alarm can\ninclude as many as 100 underlying alarms. Any single alarm can be included in\nthe rule expressions of as many as 150 composite alarms.\n\nUsing composite alarms can reduce alarm noise. You can create multiple metric\nalarms, and also create a composite alarm and set up alerts only for the\ncomposite alarm. For example, you could create a composite alarm that goes into\nALARM state only when more than one of the underlying metric alarms are in ALARM\nstate.\n\nCurrently, the only alarm actions that can be taken by composite alarms are\nnotifying SNS topics.\n\nIt is possible to create a loop or cycle of composite alarms, where composite\nalarm A depends on composite alarm B, and composite alarm B also depends on\ncomposite alarm A. In this scenario, you can't delete any composite alarm that\nis part of the cycle because there is always still a composite alarm that\ndepends on that alarm that you want to delete.\n\nTo get out of such a situation, you must break the cycle by changing the rule of\none of the composite alarms in the cycle to remove a dependency that creates the\ncycle. The simplest change to make to break a cycle is to change the `AlarmRule`\nof one of the alarms to `false`.\n\nAdditionally, the evaluation of composite alarms stops if CloudWatch detects a\ncycle in the evaluation path.\n\nWhen this operation creates an alarm, the alarm state is immediately set to\n`INSUFFICIENT_DATA`. The alarm is then evaluated and its state is set\nappropriately. Any actions associated with the new state are then executed. For\na composite alarm, this initial time after creation is the only time that the\nalarm can be in `INSUFFICIENT_DATA` state.\n\nWhen you update an existing alarm, its state is left unchanged, but the update\ncompletely overwrites the previous configuration of the alarm.\n\nTo use this operation, you must be signed on with the\n`cloudwatch:PutCompositeAlarm` permission that is scoped to `*`. You can't\ncreate a composite alarms if your `cloudwatch:PutCompositeAlarm` permission has\na narrower scope.\n\nIf you are an IAM user, you must have `iam:CreateServiceLinkedRole` to create a\ncomposite alarm that has Systems Manager OpsItem actions.","ref":"AWS.CloudWatch.html#put_composite_alarm/3","title":"AWS.CloudWatch.put_composite_alarm/3","type":"function"},{"doc":"Creates a dashboard if it does not already exist, or updates an existing\ndashboard.\n\nIf you update a dashboard, the entire contents are replaced with what you\nspecify here.\n\nAll dashboards in your account are global, not region-specific.\n\nA simple way to create a dashboard using `PutDashboard` is to copy an existing\ndashboard. To copy an existing dashboard using the console, you can load the\ndashboard and then use the View/edit source command in the Actions menu to\ndisplay the JSON block for that dashboard. Another way to copy a dashboard is to\nuse `GetDashboard`, and then use the data returned within `DashboardBody` as the\ntemplate for the new dashboard when you call `PutDashboard`.\n\nWhen you create a dashboard with `PutDashboard`, a good practice is to add a\ntext widget at the top of the dashboard with a message that the dashboard was\ncreated by script and should not be changed in the console. This message could\nalso point console users to the location of the `DashboardBody` script or the\nCloudFormation template used to create the dashboard.","ref":"AWS.CloudWatch.html#put_dashboard/3","title":"AWS.CloudWatch.put_dashboard/3","type":"function"},{"doc":"Creates a Contributor Insights rule.\n\nRules evaluate log events in a CloudWatch Logs log group, enabling you to find\ncontributor data for the log events in that log group. For more information, see\n[Using Contributor Insights to Analyze High-Cardinality Data](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/ContributorInsights.html).\n\nIf you create a rule, delete it, and then re-create it with the same name,\nhistorical data from the first time the rule was created might not be available.","ref":"AWS.CloudWatch.html#put_insight_rule/3","title":"AWS.CloudWatch.put_insight_rule/3","type":"function"},{"doc":"Creates a managed Contributor Insights rule for a specified Amazon Web Services\nresource.\n\nWhen you enable a managed rule, you create a Contributor Insights rule that\ncollects data from Amazon Web Services services. You cannot edit these rules\nwith `PutInsightRule`. The rules can be enabled, disabled, and deleted using\n`EnableInsightRules`, `DisableInsightRules`, and `DeleteInsightRules`. If a\npreviously created managed rule is currently disabled, a subsequent call to this\nAPI will re-enable it. Use `ListManagedInsightRules` to describe all available\nrules.","ref":"AWS.CloudWatch.html#put_managed_insight_rules/3","title":"AWS.CloudWatch.put_managed_insight_rules/3","type":"function"},{"doc":"Creates or updates an alarm and associates it with the specified metric, metric\nmath expression, anomaly detection model, or Metrics Insights query.\n\nFor more information about using a Metrics Insights query for an alarm, see\n[Create alarms on Metrics Insights queries](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/Create_Metrics_Insights_Alarm.html).\n\nAlarms based on anomaly detection models cannot have Auto Scaling actions.\n\nWhen this operation creates an alarm, the alarm state is immediately set to\n`INSUFFICIENT_DATA`. The alarm is then evaluated and its state is set\nappropriately. Any actions associated with the new state are then executed.\n\nWhen you update an existing alarm, its state is left unchanged, but the update\ncompletely overwrites the previous configuration of the alarm.\n\nIf you are an IAM user, you must have Amazon EC2 permissions for some alarm\noperations:\n\n  * The `iam:CreateServiceLinkedRole` permission for all alarms with\nEC2 actions\n\n  * The `iam:CreateServiceLinkedRole` permissions to create an alarm\nwith Systems Manager OpsItem or response plan actions.\n\nThe first time you create an alarm in the Amazon Web Services Management\nConsole, the CLI, or by using the PutMetricAlarm API, CloudWatch creates the\nnecessary service-linked role for you. The service-linked roles are called\n`AWSServiceRoleForCloudWatchEvents` and\n`AWSServiceRoleForCloudWatchAlarms_ActionSSM`. For more information, see [Amazon Web Services service-linked\nrole](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_terms-and-concepts.html#iam-term-service-linked-role).\n\nEach `PutMetricAlarm` action has a maximum uncompressed payload of 120 KB.","ref":"AWS.CloudWatch.html#put_metric_alarm/3","title":"AWS.CloudWatch.put_metric_alarm/3","type":"function"},{"doc":"You can set an alarm on metrics in the current account, or in another account.\nTo create a cross-account alarm that watches a metric in a different account,\nyou must have completed the following pre-requisites:\n\n  * The account where the metrics are located (the *sharing account*)\nmust already have a sharing role named **CloudWatch-CrossAccountSharingRole**.\nIf it does not already have this role, you must create it using the instructions\nin **Set up a sharing account** in [ Cross-account cross-Region CloudWatch console](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/Cross-Account-Cross-Region.html#enable-cross-account-cross-Region).\nThe policy for that role must grant access to the ID of the account where you\nare creating the alarm.\n\n  * The account where you are creating the alarm (the *monitoring\naccount*) must already have a service-linked role named\n**AWSServiceRoleForCloudWatchCrossAccount** to allow CloudWatch to assume the\nsharing role in the sharing account. If it does not, you must create it\nfollowing the directions in **Set up a monitoring account** in [ Cross-account cross-Region CloudWatch\nconsole](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/Cross-Account-Cross-Region.html#enable-cross-account-cross-Region).","ref":"AWS.CloudWatch.html#put_metric_alarm/3-cross-account-alarms","title":"Cross-account alarms - AWS.CloudWatch.put_metric_alarm/3","type":"function"},{"doc":"Publishes metric data points to Amazon CloudWatch.\n\nCloudWatch associates the data points with the specified metric. If the\nspecified metric does not exist, CloudWatch creates the metric. When CloudWatch\ncreates a metric, it can take up to fifteen minutes for the metric to appear in\ncalls to\n[ListMetrics](https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_ListMetrics.html).  You can publish either individual data points in the `Value` field, or arrays of\nvalues and the number of times each value occurred during the period by using\nthe `Values` and `Counts` fields in the `MetricDatum` structure. Using the\n`Values` and `Counts` method enables you to publish up to 150 values per metric\nwith one `PutMetricData` request, and supports retrieving percentile statistics\non this data.\n\nEach `PutMetricData` request is limited to 1 MB in size for HTTP POST requests.\nYou can send a payload compressed by gzip. Each request is also limited to no\nmore than 1000 different metrics.\n\nAlthough the `Value` parameter accepts numbers of type `Double`, CloudWatch\nrejects values that are either too small or too large. Values must be in the\nrange of -2^360 to 2^360. In addition, special values (for example, NaN,\n+Infinity, -Infinity) are not supported.\n\nYou can use up to 30 dimensions per metric to further clarify what data the\nmetric collects. Each dimension consists of a Name and Value pair. For more\ninformation about specifying dimensions, see [Publishing\nMetrics](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/publishingMetrics.html)\nin the *Amazon CloudWatch User Guide*.\n\nYou specify the time stamp to be associated with each data point. You can\nspecify time stamps that are as much as two weeks before the current date, and\nas much as 2 hours after the current day and time.\n\nData points with time stamps from 24 hours ago or longer can take at least 48\nhours to become available for\n[GetMetricData](https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_GetMetricData.html) or\n[GetMetricStatistics](https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_GetMetricStatistics.html)\nfrom the time they are submitted. Data points with time stamps between 3 and 24\nhours ago can take as much as 2 hours to become available for for\n[GetMetricData](https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_GetMetricData.html) or\n[GetMetricStatistics](https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_GetMetricStatistics.html).\n\nCloudWatch needs raw data points to calculate percentile statistics. If you\npublish data using a statistic set instead, you can only retrieve percentile\nstatistics for this data if one of the following conditions is true:\n\n  * The `SampleCount` value of the statistic set is 1 and `Min`,\n`Max`, and `Sum` are all equal.\n\n  * The `Min` and `Max` are equal, and `Sum` is equal to `Min`\nmultiplied by `SampleCount`.","ref":"AWS.CloudWatch.html#put_metric_data/3","title":"AWS.CloudWatch.put_metric_data/3","type":"function"},{"doc":"Creates or updates a metric stream.\n\nMetric streams can automatically stream CloudWatch metrics to Amazon Web\nServices destinations, including Amazon S3, and to many third-party solutions.\n\nFor more information, see [ Using Metric Streams](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch-Metric-Streams.html).\n\nTo create a metric stream, you must be signed in to an account that has the\n`iam:PassRole` permission and either the `CloudWatchFullAccess` policy or the\n`cloudwatch:PutMetricStream` permission.\n\nWhen you create or update a metric stream, you choose one of the following:\n\n  * Stream metrics from all metric namespaces in the account.\n\n  * Stream metrics from all metric namespaces in the account, except\nfor the namespaces that you list in `ExcludeFilters`.\n\n  * Stream metrics from only the metric namespaces that you list in\n`IncludeFilters`.\n\nBy default, a metric stream always sends the `MAX`, `MIN`, `SUM`, and\n`SAMPLECOUNT` statistics for each metric that is streamed. You can use the\n`StatisticsConfigurations` parameter to have the metric stream send additional\nstatistics in the stream. Streaming additional statistics incurs additional\ncosts. For more information, see [Amazon CloudWatch Pricing](https://aws.amazon.com/cloudwatch/pricing/).\n\nWhen you use `PutMetricStream` to create a new metric stream, the stream is\ncreated in the `running` state. If you use it to update an existing stream, the\nstate of the stream is not changed.\n\nIf you are using CloudWatch cross-account observability and you create a metric\nstream in a monitoring account, you can choose whether to include metrics from\nsource accounts in the stream. For more information, see [CloudWatch cross-account\nobservability](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch-Unified-Cross-Account.html).","ref":"AWS.CloudWatch.html#put_metric_stream/3","title":"AWS.CloudWatch.put_metric_stream/3","type":"function"},{"doc":"Temporarily sets the state of an alarm for testing purposes.\n\nWhen the updated state differs from the previous value, the action configured\nfor the appropriate state is invoked. For example, if your alarm is configured\nto send an Amazon SNS message when an alarm is triggered, temporarily changing\nthe alarm state to `ALARM` sends an SNS message.\n\nMetric alarms returns to their actual state quickly, often within seconds.\nBecause the metric alarm state change happens quickly, it is typically only\nvisible in the alarm's **History** tab in the Amazon CloudWatch console or\nthrough\n[DescribeAlarmHistory](https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_DescribeAlarmHistory.html).\n\nIf you use `SetAlarmState` on a composite alarm, the composite alarm is not\nguaranteed to return to its actual state. It returns to its actual state only\nonce any of its children alarms change state. It is also reevaluated if you\nupdate its configuration.\n\nIf an alarm triggers EC2 Auto Scaling policies or application Auto Scaling\npolicies, you must include information in the `StateReasonData` parameter to\nenable the policy to take the correct action.","ref":"AWS.CloudWatch.html#set_alarm_state/3","title":"AWS.CloudWatch.set_alarm_state/3","type":"function"},{"doc":"Starts the streaming of metrics for one or more of your metric streams.","ref":"AWS.CloudWatch.html#start_metric_streams/3","title":"AWS.CloudWatch.start_metric_streams/3","type":"function"},{"doc":"Stops the streaming of metrics for one or more of your metric streams.","ref":"AWS.CloudWatch.html#stop_metric_streams/3","title":"AWS.CloudWatch.stop_metric_streams/3","type":"function"},{"doc":"Assigns one or more tags (key-value pairs) to the specified CloudWatch resource.\n\nCurrently, the only CloudWatch resources that can be tagged are alarms and\nContributor Insights rules.\n\nTags can help you organize and categorize your resources. You can also use them\nto scope user permissions by granting a user permission to access or change only\nresources with certain tag values.\n\nTags don't have any semantic meaning to Amazon Web Services and are interpreted\nstrictly as strings of characters.\n\nYou can use the `TagResource` action with an alarm that already has tags. If you\nspecify a new tag key for the alarm, this tag is appended to the list of tags\nassociated with the alarm. If you specify a tag key that is already associated\nwith the alarm, the new tag value that you specify replaces the previous value\nfor that tag.\n\nYou can associate as many as 50 tags with a CloudWatch resource.","ref":"AWS.CloudWatch.html#tag_resource/3","title":"AWS.CloudWatch.tag_resource/3","type":"function"},{"doc":"Removes one or more tags from the specified resource.","ref":"AWS.CloudWatch.html#untag_resource/3","title":"AWS.CloudWatch.untag_resource/3","type":"function"},{"doc":"Amazon EventBridge helps you to respond to state changes in your Amazon Web\nServices resources.\n\nWhen your resources change state, they automatically send events to an event\nstream. You can create rules that match selected events in the stream and route\nthem to targets to take action. You can also use rules to take action on a\npredetermined schedule. For example, you can configure rules to:\n\n  * Automatically invoke an Lambda function to update DNS entries when\nan event notifies you that Amazon EC2 instance enters the running state.\n\n  * Direct specific API records from CloudTrail to an Amazon Kinesis\ndata stream for detailed analysis of potential security or availability risks.\n\n  * Periodically invoke a built-in target to create a snapshot of an\nAmazon EBS volume.\n\nFor more information about the features of Amazon EventBridge, see the [Amazon EventBridge User\nGuide](https://docs.aws.amazon.com/eventbridge/latest/userguide).","ref":"AWS.CloudWatchEvents.html","title":"AWS.CloudWatchEvents","type":"module"},{"doc":"Activates a partner event source that has been deactivated.\n\nOnce activated, your matching event bus will start receiving events from the\nevent source.","ref":"AWS.CloudWatchEvents.html#activate_event_source/3","title":"AWS.CloudWatchEvents.activate_event_source/3","type":"function"},{"doc":"Cancels the specified replay.","ref":"AWS.CloudWatchEvents.html#cancel_replay/3","title":"AWS.CloudWatchEvents.cancel_replay/3","type":"function"},{"doc":"Creates an API destination, which is an HTTP invocation endpoint configured as a\ntarget for events.","ref":"AWS.CloudWatchEvents.html#create_api_destination/3","title":"AWS.CloudWatchEvents.create_api_destination/3","type":"function"},{"doc":"Creates an archive of events with the specified settings.\n\nWhen you create an archive, incoming events might not immediately start being\nsent to the archive. Allow a short period of time for changes to take effect. If\nyou do not specify a pattern to filter events sent to the archive, all events\nare sent to the archive except replayed events. Replayed events are not sent to\nan archive.","ref":"AWS.CloudWatchEvents.html#create_archive/3","title":"AWS.CloudWatchEvents.create_archive/3","type":"function"},{"doc":"Creates a connection.\n\nA connection defines the authorization type and credentials to use for\nauthorization with an API destination HTTP endpoint.","ref":"AWS.CloudWatchEvents.html#create_connection/3","title":"AWS.CloudWatchEvents.create_connection/3","type":"function"},{"doc":"Creates a new event bus within your account.\n\nThis can be a custom event bus which you can use to receive events from your\ncustom applications and services, or it can be a partner event bus which can be\nmatched to a partner event source.","ref":"AWS.CloudWatchEvents.html#create_event_bus/3","title":"AWS.CloudWatchEvents.create_event_bus/3","type":"function"},{"doc":"Called by an SaaS partner to create a partner event source.\n\nThis operation is not used by Amazon Web Services customers.\n\nEach partner event source can be used by one Amazon Web Services account to\ncreate a matching partner event bus in that Amazon Web Services account. A SaaS\npartner must create one partner event source for each Amazon Web Services\naccount that wants to receive those event types.\n\nA partner event source creates events based on resources within the SaaS\npartner's service or application.\n\nAn Amazon Web Services account that creates a partner event bus that matches the\npartner event source can use that event bus to receive events from the partner,\nand then process them using Amazon Web Services Events rules and targets.\n\nPartner event source names follow this format:\n\n` *partner_name*/*event_namespace*/*event_name* `\n\n*partner_name* is determined during partner registration and identifies the\npartner to Amazon Web Services customers. *event_namespace* is determined by the\npartner and is a way for the partner to categorize their events. *event_name* is\ndetermined by the partner, and should uniquely identify an event-generating\nresource within the partner system. The combination of *event_namespace* and\n*event_name* should help Amazon Web Services customers decide whether to create\nan event bus to receive these events.","ref":"AWS.CloudWatchEvents.html#create_partner_event_source/3","title":"AWS.CloudWatchEvents.create_partner_event_source/3","type":"function"},{"doc":"You can use this operation to temporarily stop receiving events from the\nspecified partner event source.\n\nThe matching event bus is not deleted.\n\nWhen you deactivate a partner event source, the source goes into PENDING state.\nIf it remains in PENDING state for more than two weeks, it is deleted.\n\nTo activate a deactivated partner event source, use\n[ActivateEventSource](https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_ActivateEventSource.html).","ref":"AWS.CloudWatchEvents.html#deactivate_event_source/3","title":"AWS.CloudWatchEvents.deactivate_event_source/3","type":"function"},{"doc":"Removes all authorization parameters from the connection.\n\nThis lets you remove the secret from the connection so you can reuse it without\nhaving to create a new connection.","ref":"AWS.CloudWatchEvents.html#deauthorize_connection/3","title":"AWS.CloudWatchEvents.deauthorize_connection/3","type":"function"},{"doc":"Deletes the specified API destination.","ref":"AWS.CloudWatchEvents.html#delete_api_destination/3","title":"AWS.CloudWatchEvents.delete_api_destination/3","type":"function"},{"doc":"Deletes the specified archive.","ref":"AWS.CloudWatchEvents.html#delete_archive/3","title":"AWS.CloudWatchEvents.delete_archive/3","type":"function"},{"doc":"Deletes a connection.","ref":"AWS.CloudWatchEvents.html#delete_connection/3","title":"AWS.CloudWatchEvents.delete_connection/3","type":"function"},{"doc":"Deletes the specified custom event bus or partner event bus.\n\nAll rules associated with this event bus need to be deleted. You can't delete\nyour account's default event bus.","ref":"AWS.CloudWatchEvents.html#delete_event_bus/3","title":"AWS.CloudWatchEvents.delete_event_bus/3","type":"function"},{"doc":"This operation is used by SaaS partners to delete a partner event source.\n\nThis operation is not used by Amazon Web Services customers.\n\nWhen you delete an event source, the status of the corresponding partner event\nbus in the Amazon Web Services customer account becomes DELETED.","ref":"AWS.CloudWatchEvents.html#delete_partner_event_source/3","title":"AWS.CloudWatchEvents.delete_partner_event_source/3","type":"function"},{"doc":"Deletes the specified rule.\n\nBefore you can delete the rule, you must remove all targets, using\n[RemoveTargets](https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_RemoveTargets.html).\n\nWhen you delete a rule, incoming events might continue to match to the deleted\nrule. Allow a short period of time for changes to take effect.\n\nIf you call delete rule multiple times for the same rule, all calls will\nsucceed. When you call delete rule for a non-existent custom eventbus,\n`ResourceNotFoundException` is returned.\n\nManaged rules are rules created and managed by another Amazon Web Services\nservice on your behalf. These rules are created by those other Amazon Web\nServices services to support functionality in those services. You can delete\nthese rules using the `Force` option, but you should do so only if you are sure\nthe other service is not still using that rule.","ref":"AWS.CloudWatchEvents.html#delete_rule/3","title":"AWS.CloudWatchEvents.delete_rule/3","type":"function"},{"doc":"Retrieves details about an API destination.","ref":"AWS.CloudWatchEvents.html#describe_api_destination/3","title":"AWS.CloudWatchEvents.describe_api_destination/3","type":"function"},{"doc":"Retrieves details about an archive.","ref":"AWS.CloudWatchEvents.html#describe_archive/3","title":"AWS.CloudWatchEvents.describe_archive/3","type":"function"},{"doc":"Retrieves details about a connection.","ref":"AWS.CloudWatchEvents.html#describe_connection/3","title":"AWS.CloudWatchEvents.describe_connection/3","type":"function"},{"doc":"Displays details about an event bus in your account.\n\nThis can include the external Amazon Web Services accounts that are permitted to\nwrite events to your default event bus, and the associated policy. For custom\nevent buses and partner event buses, it displays the name, ARN, policy, state,\nand creation time.\n\nTo enable your account to receive events from other accounts on its default\nevent bus, use\n[PutPermission](https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_PutPermission.html).  For more information about partner event buses, see\n[CreateEventBus](https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_CreateEventBus.html).","ref":"AWS.CloudWatchEvents.html#describe_event_bus/3","title":"AWS.CloudWatchEvents.describe_event_bus/3","type":"function"},{"doc":"This operation lists details about a partner event source that is shared with\nyour account.","ref":"AWS.CloudWatchEvents.html#describe_event_source/3","title":"AWS.CloudWatchEvents.describe_event_source/3","type":"function"},{"doc":"An SaaS partner can use this operation to list details about a partner event\nsource that they have created.\n\nAmazon Web Services customers do not use this operation. Instead, Amazon Web\nServices customers can use\n[DescribeEventSource](https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_DescribeEventSource.html)\nto see details about a partner event source that is shared with them.","ref":"AWS.CloudWatchEvents.html#describe_partner_event_source/3","title":"AWS.CloudWatchEvents.describe_partner_event_source/3","type":"function"},{"doc":"Retrieves details about a replay.\n\nUse `DescribeReplay` to determine the progress of a running replay. A replay\nprocesses events to replay based on the time in the event, and replays them\nusing 1 minute intervals. If you use `StartReplay` and specify an\n`EventStartTime` and an `EventEndTime` that covers a 20 minute time range, the\nevents are replayed from the first minute of that 20 minute range first. Then\nthe events from the second minute are replayed. You can use `DescribeReplay` to\ndetermine the progress of a replay. The value returned for\n`EventLastReplayedTime` indicates the time within the specified time range\nassociated with the last event replayed.","ref":"AWS.CloudWatchEvents.html#describe_replay/3","title":"AWS.CloudWatchEvents.describe_replay/3","type":"function"},{"doc":"Describes the specified rule.\n\nDescribeRule does not list the targets of a rule. To see the targets associated\nwith a rule, use\n[ListTargetsByRule](https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_ListTargetsByRule.html).","ref":"AWS.CloudWatchEvents.html#describe_rule/3","title":"AWS.CloudWatchEvents.describe_rule/3","type":"function"},{"doc":"Disables the specified rule.\n\nA disabled rule won't match any events, and won't self-trigger if it has a\nschedule expression.\n\nWhen you disable a rule, incoming events might continue to match to the disabled\nrule. Allow a short period of time for changes to take effect.","ref":"AWS.CloudWatchEvents.html#disable_rule/3","title":"AWS.CloudWatchEvents.disable_rule/3","type":"function"},{"doc":"Enables the specified rule.\n\nIf the rule does not exist, the operation fails.\n\nWhen you enable a rule, incoming events might not immediately start matching to\na newly enabled rule. Allow a short period of time for changes to take effect.","ref":"AWS.CloudWatchEvents.html#enable_rule/3","title":"AWS.CloudWatchEvents.enable_rule/3","type":"function"},{"doc":"Retrieves a list of API destination in the account in the current Region.","ref":"AWS.CloudWatchEvents.html#list_api_destinations/3","title":"AWS.CloudWatchEvents.list_api_destinations/3","type":"function"},{"doc":"Lists your archives.\n\nYou can either list all the archives or you can provide a prefix to match to the\narchive names. Filter parameters are exclusive.","ref":"AWS.CloudWatchEvents.html#list_archives/3","title":"AWS.CloudWatchEvents.list_archives/3","type":"function"},{"doc":"Retrieves a list of connections from the account.","ref":"AWS.CloudWatchEvents.html#list_connections/3","title":"AWS.CloudWatchEvents.list_connections/3","type":"function"},{"doc":"Lists all the event buses in your account, including the default event bus,\ncustom event buses, and partner event buses.","ref":"AWS.CloudWatchEvents.html#list_event_buses/3","title":"AWS.CloudWatchEvents.list_event_buses/3","type":"function"},{"doc":"You can use this to see all the partner event sources that have been shared with\nyour Amazon Web Services account.\n\nFor more information about partner event sources, see\n[CreateEventBus](https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_CreateEventBus.html).","ref":"AWS.CloudWatchEvents.html#list_event_sources/3","title":"AWS.CloudWatchEvents.list_event_sources/3","type":"function"},{"doc":"An SaaS partner can use this operation to display the Amazon Web Services\naccount ID that a particular partner event source name is associated with.\n\nThis operation is not used by Amazon Web Services customers.","ref":"AWS.CloudWatchEvents.html#list_partner_event_source_accounts/3","title":"AWS.CloudWatchEvents.list_partner_event_source_accounts/3","type":"function"},{"doc":"An SaaS partner can use this operation to list all the partner event source\nnames that they have created.\n\nThis operation is not used by Amazon Web Services customers.","ref":"AWS.CloudWatchEvents.html#list_partner_event_sources/3","title":"AWS.CloudWatchEvents.list_partner_event_sources/3","type":"function"},{"doc":"Lists your replays.\n\nYou can either list all the replays or you can provide a prefix to match to the\nreplay names. Filter parameters are exclusive.","ref":"AWS.CloudWatchEvents.html#list_replays/3","title":"AWS.CloudWatchEvents.list_replays/3","type":"function"},{"doc":"Lists the rules for the specified target.\n\nYou can see which of the rules in Amazon EventBridge can invoke a specific\ntarget in your account.","ref":"AWS.CloudWatchEvents.html#list_rule_names_by_target/3","title":"AWS.CloudWatchEvents.list_rule_names_by_target/3","type":"function"},{"doc":"Lists your Amazon EventBridge rules.\n\nYou can either list all the rules or you can provide a prefix to match to the\nrule names.\n\nListRules does not list the targets of a rule. To see the targets associated\nwith a rule, use\n[ListTargetsByRule](https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_ListTargetsByRule.html).","ref":"AWS.CloudWatchEvents.html#list_rules/3","title":"AWS.CloudWatchEvents.list_rules/3","type":"function"},{"doc":"Displays the tags associated with an EventBridge resource.\n\nIn EventBridge, rules and event buses can be tagged.","ref":"AWS.CloudWatchEvents.html#list_tags_for_resource/3","title":"AWS.CloudWatchEvents.list_tags_for_resource/3","type":"function"},{"doc":"Lists the targets assigned to the specified rule.","ref":"AWS.CloudWatchEvents.html#list_targets_by_rule/3","title":"AWS.CloudWatchEvents.list_targets_by_rule/3","type":"function"},{"doc":"","ref":"AWS.CloudWatchEvents.html#metadata/0","title":"AWS.CloudWatchEvents.metadata/0","type":"function"},{"doc":"Sends custom events to Amazon EventBridge so that they can be matched to rules.","ref":"AWS.CloudWatchEvents.html#put_events/3","title":"AWS.CloudWatchEvents.put_events/3","type":"function"},{"doc":"This is used by SaaS partners to write events to a customer's partner event bus.\n\nAmazon Web Services customers do not use this operation.","ref":"AWS.CloudWatchEvents.html#put_partner_events/3","title":"AWS.CloudWatchEvents.put_partner_events/3","type":"function"},{"doc":"Running `PutPermission` permits the specified Amazon Web Services account or\nAmazon Web Services organization to put events to the specified *event bus*.\n\nAmazon EventBridge (CloudWatch Events) rules in your account are triggered by\nthese events arriving to an event bus in your account.\n\nFor another account to send events to your account, that external account must\nhave an EventBridge rule with your account's event bus as a target.\n\nTo enable multiple Amazon Web Services accounts to put events to your event bus,\nrun `PutPermission` once for each of these accounts. Or, if all the accounts are\nmembers of the same Amazon Web Services organization, you can run\n`PutPermission` once specifying `Principal` as \"*\" and specifying the Amazon Web\nServices organization ID in `Condition`, to grant permissions to all accounts in\nthat organization.\n\nIf you grant permissions using an organization, then accounts in that\norganization must specify a `RoleArn` with proper permissions when they use\n`PutTarget` to add your account's event bus as a target. For more information,\nsee [Sending and Receiving Events Between Amazon Web Services Accounts](https://docs.aws.amazon.com/eventbridge/latest/userguide/eventbridge-cross-account-event-delivery.html)\nin the *Amazon EventBridge User Guide*.\n\nThe permission policy on the event bus cannot exceed 10 KB in size.","ref":"AWS.CloudWatchEvents.html#put_permission/3","title":"AWS.CloudWatchEvents.put_permission/3","type":"function"},{"doc":"Creates or updates the specified rule.\n\nRules are enabled by default, or based on value of the state. You can disable a\nrule using\n[DisableRule](https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_DisableRule.html).  A single rule watches for events from a single event bus. Events generated by\nAmazon Web Services services go to your account's default event bus. Events\ngenerated by SaaS partner services or applications go to the matching partner\nevent bus. If you have custom applications or services, you can specify whether\ntheir events go to your default event bus or a custom event bus that you have\ncreated. For more information, see\n[CreateEventBus](https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_CreateEventBus.html).\n\nIf you are updating an existing rule, the rule is replaced with what you specify\nin this `PutRule` command. If you omit arguments in `PutRule`, the old values\nfor those arguments are not kept. Instead, they are replaced with null values.\n\nWhen you create or update a rule, incoming events might not immediately start\nmatching to new or updated rules. Allow a short period of time for changes to\ntake effect.\n\nA rule must contain at least an EventPattern or ScheduleExpression. Rules with\nEventPatterns are triggered when a matching event is observed. Rules with\nScheduleExpressions self-trigger based on the given schedule. A rule can have\nboth an EventPattern and a ScheduleExpression, in which case the rule triggers\non matching events as well as on a schedule.\n\nWhen you initially create a rule, you can optionally assign one or more tags to\nthe rule. Tags can help you organize and categorize your resources. You can also\nuse them to scope user permissions, by granting a user permission to access or\nchange only rules with certain tag values. To use the `PutRule` operation and\nassign tags, you must have both the `events:PutRule` and `events:TagResource`\npermissions.\n\nIf you are updating an existing rule, any tags you specify in the `PutRule`\noperation are ignored. To update the tags of an existing rule, use\n[TagResource](https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_TagResource.html) and\n[UntagResource](https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_UntagResource.html).\n\nMost services in Amazon Web Services treat : or / as the same character in\nAmazon Resource Names (ARNs). However, EventBridge uses an exact match in event\npatterns and rules. Be sure to use the correct ARN characters when creating\nevent patterns so that they match the ARN syntax in the event you want to match.\n\nIn EventBridge, it is possible to create rules that lead to infinite loops,\nwhere a rule is fired repeatedly. For example, a rule might detect that ACLs\nhave changed on an S3 bucket, and trigger software to change them to the desired\nstate. If the rule is not written carefully, the subsequent change to the ACLs\nfires the rule again, creating an infinite loop.\n\nTo prevent this, write the rules so that the triggered actions do not re-fire\nthe same rule. For example, your rule could fire only if ACLs are found to be in\na bad state, instead of after any change.\n\nAn infinite loop can quickly cause higher than expected charges. We recommend\nthat you use budgeting, which alerts you when charges exceed your specified\nlimit. For more information, see [Managing Your Costs with Budgets](https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/budgets-managing-costs.html).","ref":"AWS.CloudWatchEvents.html#put_rule/3","title":"AWS.CloudWatchEvents.put_rule/3","type":"function"},{"doc":"Adds the specified targets to the specified rule, or updates the targets if they\nare already associated with the rule.\n\nTargets are the resources that are invoked when a rule is triggered.\n\nYou can configure the following as targets for Events:\n\n  * [API destination](https://docs.aws.amazon.com/eventbridge/latest/userguide/eb-api-destinations.html)\n\n  * Amazon API Gateway REST API endpoints\n\n  * API Gateway\n\n  * Batch job queue\n\n  * CloudWatch Logs group\n\n  * CodeBuild project\n\n  * CodePipeline\n\n  * Amazon EC2 `CreateSnapshot` API call\n\n  * Amazon EC2 `RebootInstances` API call\n\n  * Amazon EC2 `StopInstances` API call\n\n  * Amazon EC2 `TerminateInstances` API call\n\n  * Amazon ECS tasks\n\n  * Event bus in a different Amazon Web Services account or Region.\n\nYou can use an event bus in the US East (N. Virginia) us-east-1, US West\n(Oregon) us-west-2, or Europe (Ireland) eu-west-1 Regions as a target for a\nrule.\n\n  * Firehose delivery stream (Kinesis Data Firehose)\n\n  * Inspector assessment template (Amazon Inspector)\n\n  * Kinesis stream (Kinesis Data Stream)\n\n  * Lambda function\n\n  * Redshift clusters (Data API statement execution)\n\n  * Amazon SNS topic\n\n  * Amazon SQS queues (includes FIFO queues\n\n  * SSM Automation\n\n  * SSM OpsItem\n\n  * SSM Run Command\n\n  * Step Functions state machines\n\nCreating rules with built-in targets is supported only in the Amazon Web\nServices Management Console. The built-in targets are `EC2 CreateSnapshot API\ncall`, `EC2 RebootInstances API call`, `EC2 StopInstances API call`, and `EC2\nTerminateInstances API call`.\n\nFor some target types, `PutTargets` provides target-specific parameters. If the\ntarget is a Kinesis data stream, you can optionally specify which shard the\nevent goes to by using the `KinesisParameters` argument. To invoke a command on\nmultiple EC2 instances with one rule, you can use the `RunCommandParameters`\nfield.\n\nTo be able to make API calls against the resources that you own, Amazon\nEventBridge needs the appropriate permissions. For Lambda and Amazon SNS\nresources, EventBridge relies on resource-based policies. For EC2 instances,\nKinesis Data Streams, Step Functions state machines and API Gateway REST APIs,\nEventBridge relies on IAM roles that you specify in the `RoleARN` argument in\n`PutTargets`. For more information, see [Authentication and Access Control](https://docs.aws.amazon.com/eventbridge/latest/userguide/auth-and-access-control-eventbridge.html)\nin the *Amazon EventBridge User Guide*.\n\nIf another Amazon Web Services account is in the same region and has granted you\npermission (using `PutPermission`), you can send events to that account. Set\nthat account's event bus as a target of the rules in your account. To send the\nmatched events to the other account, specify that account's event bus as the\n`Arn` value when you run `PutTargets`. If your account sends events to another\naccount, your account is charged for each sent event. Each event sent to another\naccount is charged as a custom event. The account receiving the event is not\ncharged. For more information, see [Amazon EventBridge Pricing](http://aws.amazon.com/eventbridge/pricing/).\n\n`Input`, `InputPath`, and `InputTransformer` are not available with `PutTarget`\nif the target is an event bus of a different Amazon Web Services account.\n\nIf you are setting the event bus of another account as the target, and that\naccount granted permission to your account through an organization instead of\ndirectly by the account ID, then you must specify a `RoleArn` with proper\npermissions in the `Target` structure. For more information, see [Sending and Receiving Events Between Amazon Web Services\nAccounts](https://docs.aws.amazon.com/eventbridge/latest/userguide/eventbridge-cross-account-event-delivery.html)\nin the *Amazon EventBridge User Guide*.\n\nFor more information about enabling cross-account events, see\n[PutPermission](https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_PutPermission.html).\n\n**Input**, **InputPath**, and **InputTransformer** are mutually exclusive and\noptional parameters of a target. When a rule is triggered due to a matched\nevent:\n\n  * If none of the following arguments are specified for a target,\nthen the entire event is passed to the target in JSON format (unless the target\nis Amazon EC2 Run Command or Amazon ECS task, in which case nothing from the\nevent is passed to the target).\n\n  * If **Input** is specified in the form of valid JSON, then the\nmatched event is overridden with this constant.\n\n  * If **InputPath** is specified in the form of JSONPath (for\nexample, `$.detail`), then only the part of the event specified in the path is\npassed to the target (for example, only the detail part of the event is passed).\n\n  * If **InputTransformer** is specified, then one or more specified\nJSONPaths are extracted from the event and used as values in a template that you\nspecify as the input to the target.\n\nWhen you specify `InputPath` or `InputTransformer`, you must use JSON dot\nnotation, not bracket notation.\n\nWhen you add targets to a rule and the associated rule triggers soon after, new\nor updated targets might not be immediately invoked. Allow a short period of\ntime for changes to take effect.\n\nThis action can partially fail if too many requests are made at the same time.\nIf that happens, `FailedEntryCount` is non-zero in the response and each entry\nin `FailedEntries` provides the ID of the failed target and the error code.","ref":"AWS.CloudWatchEvents.html#put_targets/3","title":"AWS.CloudWatchEvents.put_targets/3","type":"function"},{"doc":"Revokes the permission of another Amazon Web Services account to be able to put\nevents to the specified event bus.\n\nSpecify the account to revoke by the `StatementId` value that you associated\nwith the account when you granted it permission with `PutPermission`. You can\nfind the `StatementId` by using\n[DescribeEventBus](https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_DescribeEventBus.html).","ref":"AWS.CloudWatchEvents.html#remove_permission/3","title":"AWS.CloudWatchEvents.remove_permission/3","type":"function"},{"doc":"Removes the specified targets from the specified rule.\n\nWhen the rule is triggered, those targets are no longer be invoked.\n\nWhen you remove a target, when the associated rule triggers, removed targets\nmight continue to be invoked. Allow a short period of time for changes to take\neffect.\n\nThis action can partially fail if too many requests are made at the same time.\nIf that happens, `FailedEntryCount` is non-zero in the response and each entry\nin `FailedEntries` provides the ID of the failed target and the error code.","ref":"AWS.CloudWatchEvents.html#remove_targets/3","title":"AWS.CloudWatchEvents.remove_targets/3","type":"function"},{"doc":"Starts the specified replay.\n\nEvents are not necessarily replayed in the exact same order that they were added\nto the archive. A replay processes events to replay based on the time in the\nevent, and replays them using 1 minute intervals. If you specify an\n`EventStartTime` and an `EventEndTime` that covers a 20 minute time range, the\nevents are replayed from the first minute of that 20 minute range first. Then\nthe events from the second minute are replayed. You can use `DescribeReplay` to\ndetermine the progress of a replay. The value returned for\n`EventLastReplayedTime` indicates the time within the specified time range\nassociated with the last event replayed.","ref":"AWS.CloudWatchEvents.html#start_replay/3","title":"AWS.CloudWatchEvents.start_replay/3","type":"function"},{"doc":"Assigns one or more tags (key-value pairs) to the specified EventBridge\nresource.\n\nTags can help you organize and categorize your resources. You can also use them\nto scope user permissions by granting a user permission to access or change only\nresources with certain tag values. In EventBridge, rules and event buses can be\ntagged.\n\nTags don't have any semantic meaning to Amazon Web Services and are interpreted\nstrictly as strings of characters.\n\nYou can use the `TagResource` action with a resource that already has tags. If\nyou specify a new tag key, this tag is appended to the list of tags associated\nwith the resource. If you specify a tag key that is already associated with the\nresource, the new tag value that you specify replaces the previous value for\nthat tag.\n\nYou can associate as many as 50 tags with a resource.","ref":"AWS.CloudWatchEvents.html#tag_resource/3","title":"AWS.CloudWatchEvents.tag_resource/3","type":"function"},{"doc":"Tests whether the specified event pattern matches the provided event.\n\nMost services in Amazon Web Services treat : or / as the same character in\nAmazon Resource Names (ARNs). However, EventBridge uses an exact match in event\npatterns and rules. Be sure to use the correct ARN characters when creating\nevent patterns so that they match the ARN syntax in the event you want to match.","ref":"AWS.CloudWatchEvents.html#test_event_pattern/3","title":"AWS.CloudWatchEvents.test_event_pattern/3","type":"function"},{"doc":"Removes one or more tags from the specified EventBridge resource.\n\nIn Amazon EventBridge (CloudWatch Events), rules and event buses can be tagged.","ref":"AWS.CloudWatchEvents.html#untag_resource/3","title":"AWS.CloudWatchEvents.untag_resource/3","type":"function"},{"doc":"Updates an API destination.","ref":"AWS.CloudWatchEvents.html#update_api_destination/3","title":"AWS.CloudWatchEvents.update_api_destination/3","type":"function"},{"doc":"Updates the specified archive.","ref":"AWS.CloudWatchEvents.html#update_archive/3","title":"AWS.CloudWatchEvents.update_archive/3","type":"function"},{"doc":"Updates settings for a connection.","ref":"AWS.CloudWatchEvents.html#update_connection/3","title":"AWS.CloudWatchEvents.update_connection/3","type":"function"},{"doc":"You can use Amazon CloudWatch Logs to monitor, store, and access your log files\nfrom EC2 instances, CloudTrail, and other sources.\n\nYou can then retrieve the associated log data from CloudWatch Logs using the\nCloudWatch console. Alternatively, you can use CloudWatch Logs commands in the\nAmazon Web Services CLI, CloudWatch Logs API, or CloudWatch Logs SDK.\n\nYou can use CloudWatch Logs to:\n\n  * **Monitor logs from EC2 instances in real time**: You can use\nCloudWatch Logs to monitor applications and systems using log data. For example,\nCloudWatch Logs can track the number of errors that occur in your application\nlogs. Then, it can send you a notification whenever the rate of errors exceeds a\nthreshold that you specify. CloudWatch Logs uses your log data for monitoring so\nno code changes are required. For example, you can monitor application logs for\nspecific literal terms (such as \"NullReferenceException\"). You can also count\nthe number of occurrences of a literal term at a particular position in log data\n(such as \"404\" status codes in an Apache access log). When the term you are\nsearching for is found, CloudWatch Logs reports the data to a CloudWatch metric\nthat you specify.\n\n  * **Monitor CloudTrail logged events**: You can create alarms in\nCloudWatch and receive notifications of particular API activity as captured by\nCloudTrail. You can use the notification to perform troubleshooting.\n\n  * **Archive log data**: You can use CloudWatch Logs to store your\nlog data in highly durable storage. You can change the log retention setting so\nthat any log events earlier than this setting are automatically deleted. The\nCloudWatch Logs agent helps to quickly send both rotated and non-rotated log\ndata off of a host and into the log service. You can then access the raw log\ndata when you need it.","ref":"AWS.CloudWatchLogs.html","title":"AWS.CloudWatchLogs","type":"module"},{"doc":"Associates the specified KMS key with either one log group in the account, or\nwith all stored CloudWatch Logs query insights results in the account.\n\nWhen you use `AssociateKmsKey`, you specify either the `logGroupName` parameter\nor the `resourceIdentifier` parameter. You can't specify both of those\nparameters in the same operation.\n\n  * Specify the `logGroupName` parameter to cause all log events\nstored in the log group to be encrypted with that key. Only the log events\ningested after the key is associated are encrypted with that key.\n\nAssociating a KMS key with a log group overrides any existing associations\nbetween the log group and a KMS key. After a KMS key is associated with a log\ngroup, all newly ingested data for the log group is encrypted using the KMS key.\nThis association is stored as long as the data encrypted with the KMS key is\nstill within CloudWatch Logs. This enables CloudWatch Logs to decrypt this data\nwhenever it is requested.\n\nAssociating a key with a log group does not cause the results of queries of that\nlog group to be encrypted with that key. To have query results encrypted with a\nKMS key, you must use an `AssociateKmsKey` operation with the\n`resourceIdentifier` parameter that specifies a `query-result` resource.\n\n  * Specify the `resourceIdentifier` parameter with a `query-result`\nresource, to use that key to encrypt the stored results of all future\n[StartQuery](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_StartQuery.html) operations in the account. The response from a\n[GetQueryResults](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_GetQueryResults.html)\noperation will still return the query results in plain text.\n\nEven if you have not associated a key with your query results, the query results\nare encrypted when stored, using the default CloudWatch Logs method.\n\nIf you run a query from a monitoring account that queries logs in a source\naccount, the query results key from the monitoring account, if any, is used.\n\nIf you delete the key that is used to encrypt log events or log group query\nresults, then all the associated stored log events or query results that were\nencrypted with that key will be unencryptable and unusable.\n\nCloudWatch Logs supports only symmetric KMS keys. Do not use an associate an\nasymmetric KMS key with your log group or query results. For more information,\nsee [Using Symmetric and Asymmetric Keys](https://docs.aws.amazon.com/kms/latest/developerguide/symmetric-asymmetric.html).\n\nIt can take up to 5 minutes for this operation to take effect.\n\nIf you attempt to associate a KMS key with a log group but the KMS key does not\nexist or the KMS key is disabled, you receive an `InvalidParameterException`\nerror.","ref":"AWS.CloudWatchLogs.html#associate_kms_key/3","title":"AWS.CloudWatchLogs.associate_kms_key/3","type":"function"},{"doc":"Cancels the specified export task.\n\nThe task must be in the `PENDING` or `RUNNING` state.","ref":"AWS.CloudWatchLogs.html#cancel_export_task/3","title":"AWS.CloudWatchLogs.cancel_export_task/3","type":"function"},{"doc":"Creates a *delivery*.\n\nA delivery is a connection between a logical *delivery source* and a logical\n*delivery destination* that you have already created.\n\nOnly some Amazon Web Services services support being configured as a delivery\nsource using this operation. These services are listed as **Supported [V2 Permissions]** in the table at [Enabling logging from Amazon Web Services services.](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/AWS-logs-and-resource-policy.html)\n\nA delivery destination can represent a log group in CloudWatch Logs, an Amazon\nS3 bucket, or a delivery stream in Kinesis Data Firehose.\n\nTo configure logs delivery between a supported Amazon Web Services service and a\ndestination, you must do the following:\n\n  * Create a delivery source, which is a logical object that\nrepresents the resource that is actually sending the logs. For more information,\nsee\n[PutDeliverySource](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutDeliverySource.html).     * Create a *delivery destination*, which is a logical object that\nrepresents the actual delivery destination. For more information, see\n[PutDeliveryDestination](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutDeliveryDestination.html).\n\n  * If you are delivering logs cross-account, you must use\n[PutDeliveryDestinationPolicy](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutDeliveryDestinationPolicy.html)\nin the destination account to assign an IAM policy to the destination. This\npolicy allows delivery to that destination.\n\n  * Use `CreateDelivery` to create a *delivery* by pairing exactly one\ndelivery source and one delivery destination.\n\nYou can configure a single delivery source to send logs to multiple destinations\nby creating multiple deliveries. You can also create multiple deliveries to\nconfigure multiple delivery sources to send logs to the same delivery\ndestination.\n\nYou can't update an existing delivery. You can only create and delete\ndeliveries.","ref":"AWS.CloudWatchLogs.html#create_delivery/3","title":"AWS.CloudWatchLogs.create_delivery/3","type":"function"},{"doc":"Creates an export task so that you can efficiently export data from a log group\nto an Amazon S3 bucket.\n\nWhen you perform a `CreateExportTask` operation, you must use credentials that\nhave permission to write to the S3 bucket that you specify as the destination.\n\nExporting log data to S3 buckets that are encrypted by KMS is supported.\nExporting log data to Amazon S3 buckets that have S3 Object Lock enabled with a\nretention period is also supported.\n\nExporting to S3 buckets that are encrypted with AES-256 is supported.\n\nThis is an asynchronous call. If all the required information is provided, this\noperation initiates an export task and responds with the ID of the task. After\nthe task has started, you can use\n[DescribeExportTasks](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DescribeExportTasks.html) to get the status of the export task. Each account can only have one active\n(`RUNNING` or `PENDING`) export task at a time. To cancel an export task, use\n[CancelExportTask](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_CancelExportTask.html).\n\nYou can export logs from multiple log groups or multiple time ranges to the same\nS3 bucket. To separate log data for each export task, specify a prefix to be\nused as the Amazon S3 key prefix for all exported objects.\n\nTime-based sorting on chunks of log data inside an exported file is not\nguaranteed. You can sort the exported log field data by using Linux utilities.","ref":"AWS.CloudWatchLogs.html#create_export_task/3","title":"AWS.CloudWatchLogs.create_export_task/3","type":"function"},{"doc":"Creates an *anomaly detector* that regularly scans one or more log groups and\nlook for patterns and anomalies in the logs.\n\nAn anomaly detector can help surface issues by automatically discovering\nanomalies in your log event traffic. An anomaly detector uses machine learning\nalgorithms to scan log events and find *patterns*. A pattern is a shared text\nstructure that recurs among your log fields. Patterns provide a useful tool for\nanalyzing large sets of logs because a large number of log events can often be\ncompressed into a few patterns.\n\nThe anomaly detector uses pattern recognition to find `anomalies`, which are\nunusual log events. It uses the `evaluationFrequency` to compare current log\nevents and patterns with trained baselines.\n\nFields within a pattern are called *tokens*. Fields that vary within a pattern,\nsuch as a request ID or timestamp, are referred to as *dynamic tokens* and\nrepresented by `<*>`.\n\nThe following is an example of a pattern:\n\n`[INFO] Request time: <*> ms`  This pattern represents log events like `[INFO] Request time: 327 ms` and other\nsimilar log events that differ only by the number, in this csse 327. When the\npattern is displayed, the different numbers are replaced by `<*>`\n\nAny parts of log events that are masked as sensitive data are not scanned for\nanomalies. For more information about masking sensitive data, see [Help protect sensitive log data with\nmasking](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/mask-sensitive-log-data.html).","ref":"AWS.CloudWatchLogs.html#create_log_anomaly_detector/3","title":"AWS.CloudWatchLogs.create_log_anomaly_detector/3","type":"function"},{"doc":"Creates a log group with the specified name.\n\nYou can create up to 1,000,000 log groups per Region per account.\n\nYou must use the following guidelines when naming a log group:\n\n  * Log group names must be unique within a Region for an Amazon Web\nServices account.\n\n  * Log group names can be between 1 and 512 characters long.\n\n  * Log group names consist of the following characters: a-z, A-Z,\n0-9, '_' (underscore), '-' (hyphen), '/' (forward slash), '.' (period), and '#'\n(number sign)\n\n  * Log group names can't start with the string `aws/`\n\nWhen you create a log group, by default the log events in the log group do not\nexpire. To set a retention policy so that events expire and are deleted after a\nspecified time, use\n[PutRetentionPolicy](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutRetentionPolicy.html).  If you associate an KMS key with the log group, ingested data is encrypted using\nthe KMS key. This association is stored as long as the data encrypted with the\nKMS key is still within CloudWatch Logs. This enables CloudWatch Logs to decrypt\nthis data whenever it is requested.\n\nIf you attempt to associate a KMS key with the log group but the KMS key does\nnot exist or the KMS key is disabled, you receive an `InvalidParameterException`\nerror.\n\nCloudWatch Logs supports only symmetric KMS keys. Do not associate an asymmetric\nKMS key with your log group. For more information, see [Using Symmetric and\nAsymmetric\nKeys](https://docs.aws.amazon.com/kms/latest/developerguide/symmetric-asymmetric.html).","ref":"AWS.CloudWatchLogs.html#create_log_group/3","title":"AWS.CloudWatchLogs.create_log_group/3","type":"function"},{"doc":"Creates a log stream for the specified log group.\n\nA log stream is a sequence of log events that originate from a single source,\nsuch as an application instance or a resource that is being monitored.\n\nThere is no limit on the number of log streams that you can create for a log\ngroup. There is a limit of 50 TPS on `CreateLogStream` operations, after which\ntransactions are throttled.\n\nYou must use the following guidelines when naming a log stream:\n\n  * Log stream names must be unique within the log group.\n\n  * Log stream names can be between 1 and 512 characters long.\n\n  * Don't use ':' (colon) or '*' (asterisk) characters.","ref":"AWS.CloudWatchLogs.html#create_log_stream/3","title":"AWS.CloudWatchLogs.create_log_stream/3","type":"function"},{"doc":"Deletes a CloudWatch Logs account policy.\n\nThis stops the policy from applying to all log groups or a subset of log groups\nin the account. Log-group level policies will still be in effect.\n\nTo use this operation, you must be signed on with the correct permissions\ndepending on the type of policy that you are deleting.\n\n  * To delete a data protection policy, you must have the\n`logs:DeleteDataProtectionPolicy` and `logs:DeleteAccountPolicy` permissions.\n\n  * To delete a subscription filter policy, you must have the\n`logs:DeleteSubscriptionFilter` and `logs:DeleteAccountPolicy` permissions.","ref":"AWS.CloudWatchLogs.html#delete_account_policy/3","title":"AWS.CloudWatchLogs.delete_account_policy/3","type":"function"},{"doc":"Deletes the data protection policy from the specified log group.\n\nFor more information about data protection policies, see\n[PutDataProtectionPolicy](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutDataProtectionPolicy.html).","ref":"AWS.CloudWatchLogs.html#delete_data_protection_policy/3","title":"AWS.CloudWatchLogs.delete_data_protection_policy/3","type":"function"},{"doc":"Deletes s *delivery*.\n\nA delivery is a connection between a logical *delivery source* and a logical\n*delivery destination*. Deleting a delivery only deletes the connection between\nthe delivery source and delivery destination. It does not delete the delivery\ndestination or the delivery source.","ref":"AWS.CloudWatchLogs.html#delete_delivery/3","title":"AWS.CloudWatchLogs.delete_delivery/3","type":"function"},{"doc":"Deletes a *delivery destination*.\n\nA delivery is a connection between a logical *delivery source* and a logical\n*delivery destination*.\n\nYou can't delete a delivery destination if any current deliveries are associated\nwith it. To find whether any deliveries are associated with this delivery\ndestination, use the\n[DescribeDeliveries](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DescribeDeliveries.html)\noperation and check the `deliveryDestinationArn` field in the results.","ref":"AWS.CloudWatchLogs.html#delete_delivery_destination/3","title":"AWS.CloudWatchLogs.delete_delivery_destination/3","type":"function"},{"doc":"Deletes a delivery destination policy.\n\nFor more information about these policies, see\n[PutDeliveryDestinationPolicy](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutDeliveryDestinationPolicy.html).","ref":"AWS.CloudWatchLogs.html#delete_delivery_destination_policy/3","title":"AWS.CloudWatchLogs.delete_delivery_destination_policy/3","type":"function"},{"doc":"Deletes a *delivery source*.\n\nA delivery is a connection between a logical *delivery source* and a logical\n*delivery destination*.\n\nYou can't delete a delivery source if any current deliveries are associated with\nit. To find whether any deliveries are associated with this delivery source, use\nthe\n[DescribeDeliveries](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DescribeDeliveries.html)\noperation and check the `deliverySourceName` field in the results.","ref":"AWS.CloudWatchLogs.html#delete_delivery_source/3","title":"AWS.CloudWatchLogs.delete_delivery_source/3","type":"function"},{"doc":"Deletes the specified destination, and eventually disables all the subscription\nfilters that publish to it.\n\nThis operation does not delete the physical resource encapsulated by the\ndestination.","ref":"AWS.CloudWatchLogs.html#delete_destination/3","title":"AWS.CloudWatchLogs.delete_destination/3","type":"function"},{"doc":"Deletes the specified CloudWatch Logs anomaly detector.","ref":"AWS.CloudWatchLogs.html#delete_log_anomaly_detector/3","title":"AWS.CloudWatchLogs.delete_log_anomaly_detector/3","type":"function"},{"doc":"Deletes the specified log group and permanently deletes all the archived log\nevents associated with the log group.","ref":"AWS.CloudWatchLogs.html#delete_log_group/3","title":"AWS.CloudWatchLogs.delete_log_group/3","type":"function"},{"doc":"Deletes the specified log stream and permanently deletes all the archived log\nevents associated with the log stream.","ref":"AWS.CloudWatchLogs.html#delete_log_stream/3","title":"AWS.CloudWatchLogs.delete_log_stream/3","type":"function"},{"doc":"Deletes the specified metric filter.","ref":"AWS.CloudWatchLogs.html#delete_metric_filter/3","title":"AWS.CloudWatchLogs.delete_metric_filter/3","type":"function"},{"doc":"Deletes a saved CloudWatch Logs Insights query definition.\n\nA query definition contains details about a saved CloudWatch Logs Insights\nquery.\n\nEach `DeleteQueryDefinition` operation can delete one query definition.\n\nYou must have the `logs:DeleteQueryDefinition` permission to be able to perform\nthis operation.","ref":"AWS.CloudWatchLogs.html#delete_query_definition/3","title":"AWS.CloudWatchLogs.delete_query_definition/3","type":"function"},{"doc":"Deletes a resource policy from this account.\n\nThis revokes the access of the identities in that policy to put log events to\nthis account.","ref":"AWS.CloudWatchLogs.html#delete_resource_policy/3","title":"AWS.CloudWatchLogs.delete_resource_policy/3","type":"function"},{"doc":"Deletes the specified retention policy.\n\nLog events do not expire if they belong to log groups without a retention\npolicy.","ref":"AWS.CloudWatchLogs.html#delete_retention_policy/3","title":"AWS.CloudWatchLogs.delete_retention_policy/3","type":"function"},{"doc":"Deletes the specified subscription filter.","ref":"AWS.CloudWatchLogs.html#delete_subscription_filter/3","title":"AWS.CloudWatchLogs.delete_subscription_filter/3","type":"function"},{"doc":"Returns a list of all CloudWatch Logs account policies in the account.","ref":"AWS.CloudWatchLogs.html#describe_account_policies/3","title":"AWS.CloudWatchLogs.describe_account_policies/3","type":"function"},{"doc":"Retrieves a list of the deliveries that have been created in the account.\n\nA *delivery* is a connection between a [ *delivery source*\n](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutDeliverySource.html)\nand a [ *delivery destination*\n](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutDeliveryDestination.html).\n\nA delivery source represents an Amazon Web Services resource that sends logs to\nan logs delivery destination. The destination can be CloudWatch Logs, Amazon S3,\nor Kinesis Data Firehose. Only some Amazon Web Services services support being\nconfigured as a delivery source. These services are listed in [Enable logging from Amazon Web Services\nservices.](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/AWS-logs-and-resource-policy.html)","ref":"AWS.CloudWatchLogs.html#describe_deliveries/3","title":"AWS.CloudWatchLogs.describe_deliveries/3","type":"function"},{"doc":"Retrieves a list of the delivery destinations that have been created in the\naccount.","ref":"AWS.CloudWatchLogs.html#describe_delivery_destinations/3","title":"AWS.CloudWatchLogs.describe_delivery_destinations/3","type":"function"},{"doc":"Retrieves a list of the delivery sources that have been created in the account.","ref":"AWS.CloudWatchLogs.html#describe_delivery_sources/3","title":"AWS.CloudWatchLogs.describe_delivery_sources/3","type":"function"},{"doc":"Lists all your destinations.\n\nThe results are ASCII-sorted by destination name.","ref":"AWS.CloudWatchLogs.html#describe_destinations/3","title":"AWS.CloudWatchLogs.describe_destinations/3","type":"function"},{"doc":"Lists the specified export tasks.\n\nYou can list all your export tasks or filter the results based on task ID or\ntask status.","ref":"AWS.CloudWatchLogs.html#describe_export_tasks/3","title":"AWS.CloudWatchLogs.describe_export_tasks/3","type":"function"},{"doc":"Lists the specified log groups.\n\nYou can list all your log groups or filter the results by prefix. The results\nare ASCII-sorted by log group name.\n\nCloudWatch Logs doesn’t support IAM policies that control access to the\n`DescribeLogGroups` action by using the `aws:ResourceTag/*key-name* ` condition\nkey. Other CloudWatch Logs actions do support the use of the\n`aws:ResourceTag/*key-name* ` condition key to control access. For more\ninformation about using tags to control access, see [Controlling access to Amazon Web Services resources using\ntags](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_tags.html).\n\nIf you are using CloudWatch cross-account observability, you can use this\noperation in a monitoring account and view data from the linked source accounts.\nFor more information, see [CloudWatch cross-account observability](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch-Unified-Cross-Account.html).","ref":"AWS.CloudWatchLogs.html#describe_log_groups/3","title":"AWS.CloudWatchLogs.describe_log_groups/3","type":"function"},{"doc":"Lists the log streams for the specified log group.\n\nYou can list all the log streams or filter the results by prefix. You can also\ncontrol how the results are ordered.\n\nYou can specify the log group to search by using either `logGroupIdentifier` or\n`logGroupName`. You must include one of these two parameters, but you can't\ninclude both.\n\nThis operation has a limit of five transactions per second, after which\ntransactions are throttled.\n\nIf you are using CloudWatch cross-account observability, you can use this\noperation in a monitoring account and view data from the linked source accounts.\nFor more information, see [CloudWatch cross-account observability](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch-Unified-Cross-Account.html).","ref":"AWS.CloudWatchLogs.html#describe_log_streams/3","title":"AWS.CloudWatchLogs.describe_log_streams/3","type":"function"},{"doc":"Lists the specified metric filters.\n\nYou can list all of the metric filters or filter the results by log name,\nprefix, metric name, or metric namespace. The results are ASCII-sorted by filter\nname.","ref":"AWS.CloudWatchLogs.html#describe_metric_filters/3","title":"AWS.CloudWatchLogs.describe_metric_filters/3","type":"function"},{"doc":"Returns a list of CloudWatch Logs Insights queries that are scheduled, running,\nor have been run recently in this account.\n\nYou can request all queries or limit it to queries of a specific log group or\nqueries with a certain status.","ref":"AWS.CloudWatchLogs.html#describe_queries/3","title":"AWS.CloudWatchLogs.describe_queries/3","type":"function"},{"doc":"This operation returns a paginated list of your saved CloudWatch Logs Insights\nquery definitions.\n\nYou can retrieve query definitions from the current account or from a source\naccount that is linked to the current account.\n\nYou can use the `queryDefinitionNamePrefix` parameter to limit the results to\nonly the query definitions that have names that start with a certain string.","ref":"AWS.CloudWatchLogs.html#describe_query_definitions/3","title":"AWS.CloudWatchLogs.describe_query_definitions/3","type":"function"},{"doc":"Lists the resource policies in this account.","ref":"AWS.CloudWatchLogs.html#describe_resource_policies/3","title":"AWS.CloudWatchLogs.describe_resource_policies/3","type":"function"},{"doc":"Lists the subscription filters for the specified log group.\n\nYou can list all the subscription filters or filter the results by prefix. The\nresults are ASCII-sorted by filter name.","ref":"AWS.CloudWatchLogs.html#describe_subscription_filters/3","title":"AWS.CloudWatchLogs.describe_subscription_filters/3","type":"function"},{"doc":"Disassociates the specified KMS key from the specified log group or from all\nCloudWatch Logs Insights query results in the account.\n\nWhen you use `DisassociateKmsKey`, you specify either the `logGroupName`\nparameter or the `resourceIdentifier` parameter. You can't specify both of those\nparameters in the same operation.\n\n  * Specify the `logGroupName` parameter to stop using the KMS key to\nencrypt future log events ingested and stored in the log group. Instead, they\nwill be encrypted with the default CloudWatch Logs method. The log events that\nwere ingested while the key was associated with the log group are still\nencrypted with that key. Therefore, CloudWatch Logs will need permissions for\nthe key whenever that data is accessed.\n\n  * Specify the `resourceIdentifier` parameter with the `query-result`\nresource to stop using the KMS key to encrypt the results of all future\n[StartQuery](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_StartQuery.html)\noperations in the account. They will instead be encrypted with the default\nCloudWatch Logs method. The results from queries that ran while the key was\nassociated with the account are still encrypted with that key. Therefore,\nCloudWatch Logs will need permissions for the key whenever that data is\naccessed.\n\nIt can take up to 5 minutes for this operation to take effect.","ref":"AWS.CloudWatchLogs.html#disassociate_kms_key/3","title":"AWS.CloudWatchLogs.disassociate_kms_key/3","type":"function"},{"doc":"Lists log events from the specified log group.\n\nYou can list all the log events or filter the results using a filter pattern, a\ntime range, and the name of the log stream.\n\nYou must have the `logs:FilterLogEvents` permission to perform this operation.\n\nYou can specify the log group to search by using either `logGroupIdentifier` or\n`logGroupName`. You must include one of these two parameters, but you can't\ninclude both.\n\nBy default, this operation returns as many log events as can fit in 1 MB (up to\n10,000 log events) or all the events found within the specified time range. If\nthe results include a token, that means there are more log events available. You\ncan get additional results by specifying the token in a subsequent call. This\noperation can return empty results while there are more log events available\nthrough the token.\n\nThe returned log events are sorted by event timestamp, the timestamp when the\nevent was ingested by CloudWatch Logs, and the ID of the `PutLogEvents` request.\n\nIf you are using CloudWatch cross-account observability, you can use this\noperation in a monitoring account and view data from the linked source accounts.\nFor more information, see [CloudWatch cross-account observability](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch-Unified-Cross-Account.html).","ref":"AWS.CloudWatchLogs.html#filter_log_events/3","title":"AWS.CloudWatchLogs.filter_log_events/3","type":"function"},{"doc":"Returns information about a log group data protection policy.","ref":"AWS.CloudWatchLogs.html#get_data_protection_policy/3","title":"AWS.CloudWatchLogs.get_data_protection_policy/3","type":"function"},{"doc":"Returns complete information about one logical *delivery*.\n\nA delivery is a connection between a [ *delivery source*\n](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutDeliverySource.html)\nand a [ *delivery destination*\n](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutDeliveryDestination.html).\n\nA delivery source represents an Amazon Web Services resource that sends logs to\nan logs delivery destination. The destination can be CloudWatch Logs, Amazon S3,\nor Kinesis Data Firehose. Only some Amazon Web Services services support being\nconfigured as a delivery source. These services are listed in [Enable logging from Amazon Web Services\nservices.](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/AWS-logs-and-resource-policy.html)\n\nYou need to specify the delivery `id` in this operation. You can find the IDs of\nthe deliveries in your account with the\n[DescribeDeliveries](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DescribeDeliveries.html)\noperation.","ref":"AWS.CloudWatchLogs.html#get_delivery/3","title":"AWS.CloudWatchLogs.get_delivery/3","type":"function"},{"doc":"Retrieves complete information about one delivery destination.","ref":"AWS.CloudWatchLogs.html#get_delivery_destination/3","title":"AWS.CloudWatchLogs.get_delivery_destination/3","type":"function"},{"doc":"Retrieves the delivery destination policy assigned to the delivery destination\nthat you specify.\n\nFor more information about delivery destinations and their policies, see\n[PutDeliveryDestinationPolicy](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutDeliveryDestinationPolicy.html).","ref":"AWS.CloudWatchLogs.html#get_delivery_destination_policy/3","title":"AWS.CloudWatchLogs.get_delivery_destination_policy/3","type":"function"},{"doc":"Retrieves complete information about one delivery source.","ref":"AWS.CloudWatchLogs.html#get_delivery_source/3","title":"AWS.CloudWatchLogs.get_delivery_source/3","type":"function"},{"doc":"Retrieves information about the log anomaly detector that you specify.","ref":"AWS.CloudWatchLogs.html#get_log_anomaly_detector/3","title":"AWS.CloudWatchLogs.get_log_anomaly_detector/3","type":"function"},{"doc":"Lists log events from the specified log stream.\n\nYou can list all of the log events or filter using a time range.\n\nBy default, this operation returns as many log events as can fit in a response\nsize of 1MB (up to 10,000 log events). You can get additional log events by\nspecifying one of the tokens in a subsequent call. This operation can return\nempty results while there are more log events available through the token.\n\nIf you are using CloudWatch cross-account observability, you can use this\noperation in a monitoring account and view data from the linked source accounts.\nFor more information, see [CloudWatch cross-account observability](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch-Unified-Cross-Account.html).\n\nYou can specify the log group to search by using either `logGroupIdentifier` or\n`logGroupName`. You must include one of these two parameters, but you can't\ninclude both.","ref":"AWS.CloudWatchLogs.html#get_log_events/3","title":"AWS.CloudWatchLogs.get_log_events/3","type":"function"},{"doc":"Returns a list of the fields that are included in log events in the specified\nlog group.\n\nIncludes the percentage of log events that contain each field. The search is\nlimited to a time period that you specify.\n\nYou can specify the log group to search by using either `logGroupIdentifier` or\n`logGroupName`. You must specify one of these parameters, but you can't specify\nboth.\n\nIn the results, fields that start with `@` are fields generated by CloudWatch\nLogs. For example, `@timestamp` is the timestamp of each log event. For more\ninformation about the fields that are generated by CloudWatch logs, see\n[Supported Logs and Discovered Fields](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CWL_AnalyzeLogData-discoverable-fields.html).\n\nThe response results are sorted by the frequency percentage, starting with the\nhighest percentage.\n\nIf you are using CloudWatch cross-account observability, you can use this\noperation in a monitoring account and view data from the linked source accounts.\nFor more information, see [CloudWatch cross-account observability](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch-Unified-Cross-Account.html).","ref":"AWS.CloudWatchLogs.html#get_log_group_fields/3","title":"AWS.CloudWatchLogs.get_log_group_fields/3","type":"function"},{"doc":"Retrieves all of the fields and values of a single log event.\n\nAll fields are retrieved, even if the original query that produced the\n`logRecordPointer` retrieved only a subset of fields. Fields are returned as\nfield name/field value pairs.\n\nThe full unparsed log event is returned within `@message`.","ref":"AWS.CloudWatchLogs.html#get_log_record/3","title":"AWS.CloudWatchLogs.get_log_record/3","type":"function"},{"doc":"Returns the results from the specified query.\n\nOnly the fields requested in the query are returned, along with a `@ptr` field,\nwhich is the identifier for the log record. You can use the value of `@ptr` in a\n[GetLogRecord](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_GetLogRecord.html) operation to get the full log record.\n\n`GetQueryResults` does not start running a query. To run a query, use\n[StartQuery](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_StartQuery.html).\nFor more information about how long results of previous queries are available,\nsee [CloudWatch Logs quotas](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/cloudwatch_limits_cwl.html).\n\nIf the value of the `Status` field in the output is `Running`, this operation\nreturns only partial results. If you see a value of `Scheduled` or `Running` for\nthe status, you can retry the operation later to see the final results.\n\nIf you are using CloudWatch cross-account observability, you can use this\noperation in a monitoring account to start queries in linked source accounts.\nFor more information, see [CloudWatch cross-account observability](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch-Unified-Cross-Account.html).","ref":"AWS.CloudWatchLogs.html#get_query_results/3","title":"AWS.CloudWatchLogs.get_query_results/3","type":"function"},{"doc":"Returns a list of anomalies that log anomaly detectors have found.\n\nFor details about the structure format of each anomaly object that is returned,\nsee the example in this section.","ref":"AWS.CloudWatchLogs.html#list_anomalies/3","title":"AWS.CloudWatchLogs.list_anomalies/3","type":"function"},{"doc":"Retrieves a list of the log anomaly detectors in the account.","ref":"AWS.CloudWatchLogs.html#list_log_anomaly_detectors/3","title":"AWS.CloudWatchLogs.list_log_anomaly_detectors/3","type":"function"},{"doc":"Displays the tags associated with a CloudWatch Logs resource.\n\nCurrently, log groups and destinations support tagging.","ref":"AWS.CloudWatchLogs.html#list_tags_for_resource/3","title":"AWS.CloudWatchLogs.list_tags_for_resource/3","type":"function"},{"doc":"The ListTagsLogGroup operation is on the path to deprecation.\n\nWe recommend that you use\n[ListTagsForResource](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_ListTagsForResource.html)\ninstead.\n\nLists the tags for the specified log group.","ref":"AWS.CloudWatchLogs.html#list_tags_log_group/3","title":"AWS.CloudWatchLogs.list_tags_log_group/3","type":"function"},{"doc":"","ref":"AWS.CloudWatchLogs.html#metadata/0","title":"AWS.CloudWatchLogs.metadata/0","type":"function"},{"doc":"Creates an account-level data protection policy or subscription filter policy\nthat applies to all log groups or a subset of log groups in the account.","ref":"AWS.CloudWatchLogs.html#put_account_policy/3","title":"AWS.CloudWatchLogs.put_account_policy/3","type":"function"},{"doc":"A data protection policy can help safeguard sensitive data that's ingested by\nyour log groups by auditing and masking the sensitive log data. Each account can\nhave only one account-level data protection policy.\n\nSensitive data is detected and masked when it is ingested into a log group. When\nyou set a data protection policy, log events ingested into the log groups before\nthat time are not masked.\n\nIf you use `PutAccountPolicy` to create a data protection policy for your whole\naccount, it applies to both existing log groups and all log groups that are\ncreated later in this account. The account-level policy is applied to existing\nlog groups with eventual consistency. It might take up to 5 minutes before\nsensitive data in existing log groups begins to be masked.\n\nBy default, when a user views a log event that includes masked data, the\nsensitive data is replaced by asterisks. A user who has the `logs:Unmask`\npermission can use a\n[GetLogEvents](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_GetLogEvents.html) or\n[FilterLogEvents](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_FilterLogEvents.html)\noperation with the `unmask` parameter set to `true` to view the unmasked log\nevents. Users with the `logs:Unmask` can also view unmasked data in the\nCloudWatch Logs console by running a CloudWatch Logs Insights query with the\n`unmask` query command.\n\nFor more information, including a list of types of data that can be audited and\nmasked, see [Protect sensitive log data with masking](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/mask-sensitive-log-data.html).\n\nTo use the `PutAccountPolicy` operation for a data protection policy, you must\nbe signed on with the `logs:PutDataProtectionPolicy` and `logs:PutAccountPolicy`\npermissions.\n\nThe `PutAccountPolicy` operation applies to all log groups in the account. You\ncan use\n[PutDataProtectionPolicy](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutDataProtectionPolicy.html) to create a data protection policy that applies to just one log group. If a log\ngroup has its own data protection policy and the account also has an\naccount-level data protection policy, then the two policies are cumulative. Any\nsensitive term specified in either policy is masked.","ref":"AWS.CloudWatchLogs.html#put_account_policy/3-data-protection-policy","title":"Data protection policy - AWS.CloudWatchLogs.put_account_policy/3","type":"function"},{"doc":"A subscription filter policy sets up a real-time feed of log events from\nCloudWatch Logs to other Amazon Web Services services. Account-level\nsubscription filter policies apply to both existing log groups and log groups\nthat are created later in this account. Supported destinations are Kinesis Data\nStreams, Kinesis Data Firehose, and Lambda. When log events are sent to the\nreceiving service, they are Base64 encoded and compressed with the GZIP format.\n\nThe following destinations are supported for subscription filters:\n\n  * An Kinesis Data Streams data stream in the same account as the\nsubscription policy, for same-account delivery.\n\n  * An Kinesis Data Firehose data stream in the same account as the\nsubscription policy, for same-account delivery.\n\n  * A Lambda function in the same account as the subscription policy,\nfor same-account delivery.\n\n  * A logical destination in a different account created with\n[PutDestination](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutDestination.html),\nfor cross-account delivery. Kinesis Data Streams and Kinesis Data Firehose are\nsupported as logical destinations.\n\nEach account can have one account-level subscription filter policy. If you are\nupdating an existing filter, you must specify the correct name in `PolicyName`.\nTo perform a `PutAccountPolicy` subscription filter operation for any\ndestination except a Lambda function, you must also have the `iam:PassRole`\npermission.","ref":"AWS.CloudWatchLogs.html#put_account_policy/3-subscription-filter-policy","title":"Subscription filter policy - AWS.CloudWatchLogs.put_account_policy/3","type":"function"},{"doc":"Creates a data protection policy for the specified log group.\n\nA data protection policy can help safeguard sensitive data that's ingested by\nthe log group by auditing and masking the sensitive log data.\n\nSensitive data is detected and masked when it is ingested into the log group.\nWhen you set a data protection policy, log events ingested into the log group\nbefore that time are not masked.\n\nBy default, when a user views a log event that includes masked data, the\nsensitive data is replaced by asterisks. A user who has the `logs:Unmask`\npermission can use a\n[GetLogEvents](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_GetLogEvents.html) or\n[FilterLogEvents](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_FilterLogEvents.html)\noperation with the `unmask` parameter set to `true` to view the unmasked log\nevents. Users with the `logs:Unmask` can also view unmasked data in the\nCloudWatch Logs console by running a CloudWatch Logs Insights query with the\n`unmask` query command.\n\nFor more information, including a list of types of data that can be audited and\nmasked, see [Protect sensitive log data with masking](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/mask-sensitive-log-data.html).\n\nThe `PutDataProtectionPolicy` operation applies to only the specified log group.\nYou can also use\n[PutAccountPolicy](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutAccountPolicy.html)\nto create an account-level data protection policy that applies to all log groups\nin the account, including both existing log groups and log groups that are\ncreated level. If a log group has its own data protection policy and the account\nalso has an account-level data protection policy, then the two policies are\ncumulative. Any sensitive term specified in either policy is masked.","ref":"AWS.CloudWatchLogs.html#put_data_protection_policy/3","title":"AWS.CloudWatchLogs.put_data_protection_policy/3","type":"function"},{"doc":"Creates or updates a logical *delivery destination*.\n\nA delivery destination is an Amazon Web Services resource that represents an\nAmazon Web Services service that logs can be sent to. CloudWatch Logs, Amazon\nS3, and Kinesis Data Firehose are supported as logs delivery destinations.\n\nTo configure logs delivery between a supported Amazon Web Services service and a\ndestination, you must do the following:\n\n  * Create a delivery source, which is a logical object that\nrepresents the resource that is actually sending the logs. For more information,\nsee\n[PutDeliverySource](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutDeliverySource.html).     * Use `PutDeliveryDestination` to create a *delivery destination*,\nwhich is a logical object that represents the actual delivery destination.\n\n  * If you are delivering logs cross-account, you must use\n[PutDeliveryDestinationPolicy](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutDeliveryDestinationPolicy.html)\nin the destination account to assign an IAM policy to the destination. This\npolicy allows delivery to that destination.\n\n  * Use `CreateDelivery` to create a *delivery* by pairing exactly one\ndelivery source and one delivery destination. For more information, see\n[CreateDelivery](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_CreateDelivery.html). \n\nYou can configure a single delivery source to send logs to multiple destinations\nby creating multiple deliveries. You can also create multiple deliveries to\nconfigure multiple delivery sources to send logs to the same delivery\ndestination.\n\nOnly some Amazon Web Services services support being configured as a delivery\nsource. These services are listed as **Supported [V2 Permissions]** in the table\nat [Enabling logging from Amazon Web Services services.](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/AWS-logs-and-resource-policy.html)\n\nIf you use this operation to update an existing delivery destination, all the\ncurrent delivery destination parameters are overwritten with the new parameter\nvalues that you specify.","ref":"AWS.CloudWatchLogs.html#put_delivery_destination/3","title":"AWS.CloudWatchLogs.put_delivery_destination/3","type":"function"},{"doc":"Creates and assigns an IAM policy that grants permissions to CloudWatch Logs to\ndeliver logs cross-account to a specified destination in this account.\n\nTo configure the delivery of logs from an Amazon Web Services service in another\naccount to a logs delivery destination in the current account, you must do the\nfollowing:\n\n  * Create a delivery source, which is a logical object that\nrepresents the resource that is actually sending the logs. For more information,\nsee\n[PutDeliverySource](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutDeliverySource.html).     * Create a *delivery destination*, which is a logical object that\nrepresents the actual delivery destination. For more information, see\n[PutDeliveryDestination](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutDeliveryDestination.html).\n\n  * Use this operation in the destination account to assign an IAM\npolicy to the destination. This policy allows delivery to that destination.\n\n  * Create a *delivery* by pairing exactly one delivery source and one\ndelivery destination. For more information, see\n[CreateDelivery](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_CreateDelivery.html). \n\nOnly some Amazon Web Services services support being configured as a delivery\nsource. These services are listed as **Supported [V2 Permissions]** in the table\nat [Enabling logging from Amazon Web Services services.](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/AWS-logs-and-resource-policy.html)\n\nThe contents of the policy must include two statements. One statement enables\ngeneral logs delivery, and the other allows delivery to the chosen destination.\nSee the examples for the needed policies.","ref":"AWS.CloudWatchLogs.html#put_delivery_destination_policy/3","title":"AWS.CloudWatchLogs.put_delivery_destination_policy/3","type":"function"},{"doc":"Creates or updates a logical *delivery source*.\n\nA delivery source represents an Amazon Web Services resource that sends logs to\nan logs delivery destination. The destination can be CloudWatch Logs, Amazon S3,\nor Kinesis Data Firehose.\n\nTo configure logs delivery between a delivery destination and an Amazon Web\nServices service that is supported as a delivery source, you must do the\nfollowing:\n\n  * Use `PutDeliverySource` to create a delivery source, which is a\nlogical object that represents the resource that is actually sending the logs.\n\n  * Use `PutDeliveryDestination` to create a *delivery destination*,\nwhich is a logical object that represents the actual delivery destination. For\nmore information, see\n[PutDeliveryDestination](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutDeliveryDestination.html).     * If you are delivering logs cross-account, you must use\n[PutDeliveryDestinationPolicy](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutDeliveryDestinationPolicy.html)\nin the destination account to assign an IAM policy to the destination. This\npolicy allows delivery to that destination.\n\n  * Use `CreateDelivery` to create a *delivery* by pairing exactly one\ndelivery source and one delivery destination. For more information, see\n[CreateDelivery](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_CreateDelivery.html). \n\nYou can configure a single delivery source to send logs to multiple destinations\nby creating multiple deliveries. You can also create multiple deliveries to\nconfigure multiple delivery sources to send logs to the same delivery\ndestination.\n\nOnly some Amazon Web Services services support being configured as a delivery\nsource. These services are listed as **Supported [V2 Permissions]** in the table\nat [Enabling logging from Amazon Web Services services.](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/AWS-logs-and-resource-policy.html)\n\nIf you use this operation to update an existing delivery source, all the current\ndelivery source parameters are overwritten with the new parameter values that\nyou specify.","ref":"AWS.CloudWatchLogs.html#put_delivery_source/3","title":"AWS.CloudWatchLogs.put_delivery_source/3","type":"function"},{"doc":"Creates or updates a destination.\n\nThis operation is used only to create destinations for cross-account\nsubscriptions.\n\nA destination encapsulates a physical resource (such as an Amazon Kinesis\nstream). With a destination, you can subscribe to a real-time stream of log\nevents for a different account, ingested using\n[PutLogEvents](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutLogEvents.html).  Through an access policy, a destination controls what is written to it. By\ndefault, `PutDestination` does not set any access policy with the destination,\nwhich means a cross-account user cannot call\n[PutSubscriptionFilter](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutSubscriptionFilter.html)\nagainst this destination. To enable this, the destination owner must call\n[PutDestinationPolicy](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutDestinationPolicy.html)\nafter `PutDestination`.\n\nTo perform a `PutDestination` operation, you must also have the `iam:PassRole`\npermission.","ref":"AWS.CloudWatchLogs.html#put_destination/3","title":"AWS.CloudWatchLogs.put_destination/3","type":"function"},{"doc":"Creates or updates an access policy associated with an existing destination.\n\nAn access policy is an [IAM policy document](https://docs.aws.amazon.com/IAM/latest/UserGuide/policies_overview.html)\nthat is used to authorize claims to register a subscription filter against a\ngiven destination.","ref":"AWS.CloudWatchLogs.html#put_destination_policy/3","title":"AWS.CloudWatchLogs.put_destination_policy/3","type":"function"},{"doc":"Uploads a batch of log events to the specified log stream.\n\nThe sequence token is now ignored in `PutLogEvents` actions. `PutLogEvents`\nactions are always accepted and never return `InvalidSequenceTokenException` or\n`DataAlreadyAcceptedException` even if the sequence token is not valid. You can\nuse parallel `PutLogEvents` actions on the same log stream.\n\nThe batch of events must satisfy the following constraints:\n\n  * The maximum batch size is 1,048,576 bytes. This size is calculated\nas the sum of all event messages in UTF-8, plus 26 bytes for each log event.\n\n  * None of the log events in the batch can be more than 2 hours in\nthe future.\n\n  * None of the log events in the batch can be more than 14 days in\nthe past. Also, none of the log events can be from earlier than the retention\nperiod of the log group.\n\n  * The log events in the batch must be in chronological order by\ntheir timestamp. The timestamp is the time that the event occurred, expressed as\nthe number of milliseconds after `Jan 1, 1970 00:00:00 UTC`. (In Amazon Web\nServices Tools for PowerShell and the Amazon Web Services SDK for .NET, the\ntimestamp is specified in .NET format: `yyyy-mm-ddThh:mm:ss`. For example,\n`2017-09-15T13:45:30`.)\n\n  * A batch of log events in a single request cannot span more than 24\nhours. Otherwise, the operation fails.\n\n  * Each log event can be no larger than 256 KB.\n\n  * The maximum number of log events in a batch is 10,000.\n\n  * The quota of five requests per second per log stream has been\nremoved. Instead, `PutLogEvents` actions are throttled based on a per-second\nper-account quota. You can request an increase to the per-second throttling\nquota by using the Service Quotas service.\n\nIf a call to `PutLogEvents` returns \"UnrecognizedClientException\" the most\nlikely cause is a non-valid Amazon Web Services access key ID or secret key.","ref":"AWS.CloudWatchLogs.html#put_log_events/3","title":"AWS.CloudWatchLogs.put_log_events/3","type":"function"},{"doc":"Creates or updates a metric filter and associates it with the specified log\ngroup.\n\nWith metric filters, you can configure rules to extract metric data from log\nevents ingested through\n[PutLogEvents](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutLogEvents.html).  The maximum number of metric filters that can be associated with a log group is\n100.\n\nWhen you create a metric filter, you can also optionally assign a unit and\ndimensions to the metric that is created.\n\nMetrics extracted from log events are charged as custom metrics. To prevent\nunexpected high charges, do not specify high-cardinality fields such as\n`IPAddress` or `requestID` as dimensions. Each different value found for a\ndimension is treated as a separate metric and accrues charges as a separate\ncustom metric.\n\nCloudWatch Logs might disable a metric filter if it generates 1,000 different\nname/value pairs for your specified dimensions within one hour.\n\nYou can also set up a billing alarm to alert you if your charges are higher than\nexpected. For more information, see [ Creating a Billing Alarm to Monitor Your\nEstimated Amazon Web Services\nCharges](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/monitor_estimated_charges_with_cloudwatch.html).","ref":"AWS.CloudWatchLogs.html#put_metric_filter/3","title":"AWS.CloudWatchLogs.put_metric_filter/3","type":"function"},{"doc":"Creates or updates a query definition for CloudWatch Logs Insights.\n\nFor more information, see [Analyzing Log Data with CloudWatch Logs Insights](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/AnalyzingLogData.html).\n\nTo update a query definition, specify its `queryDefinitionId` in your request.\nThe values of `name`, `queryString`, and `logGroupNames` are changed to the\nvalues that you specify in your update operation. No current values are retained\nfrom the current query definition. For example, imagine updating a current query\ndefinition that includes log groups. If you don't specify the `logGroupNames`\nparameter in your update operation, the query definition changes to contain no\nlog groups.\n\nYou must have the `logs:PutQueryDefinition` permission to be able to perform\nthis operation.","ref":"AWS.CloudWatchLogs.html#put_query_definition/3","title":"AWS.CloudWatchLogs.put_query_definition/3","type":"function"},{"doc":"Creates or updates a resource policy allowing other Amazon Web Services services\nto put log events to this account, such as Amazon Route 53.\n\nAn account can have up to 10 resource policies per Amazon Web Services Region.","ref":"AWS.CloudWatchLogs.html#put_resource_policy/3","title":"AWS.CloudWatchLogs.put_resource_policy/3","type":"function"},{"doc":"Sets the retention of the specified log group.\n\nWith a retention policy, you can configure the number of days for which to\nretain log events in the specified log group.\n\nCloudWatch Logs doesn’t immediately delete log events when they reach their\nretention setting. It typically takes up to 72 hours after that before log\nevents are deleted, but in rare situations might take longer.\n\nTo illustrate, imagine that you change a log group to have a longer retention\nsetting when it contains log events that are past the expiration date, but\nhaven’t been deleted. Those log events will take up to 72 hours to be deleted\nafter the new retention date is reached. To make sure that log data is deleted\npermanently, keep a log group at its lower retention setting until 72 hours\nafter the previous retention period ends. Alternatively, wait to change the\nretention setting until you confirm that the earlier log events are deleted.\n\nWhen log events reach their retention setting they are marked for deletion.\nAfter they are marked for deletion, they do not add to your archival storage\ncosts anymore, even if they are not actually deleted until later. These log\nevents marked for deletion are also not included when you use an API to retrieve\nthe `storedBytes` value to see how many bytes a log group is storing.","ref":"AWS.CloudWatchLogs.html#put_retention_policy/3","title":"AWS.CloudWatchLogs.put_retention_policy/3","type":"function"},{"doc":"Creates or updates a subscription filter and associates it with the specified\nlog group.\n\nWith subscription filters, you can subscribe to a real-time stream of log events\ningested through\n[PutLogEvents](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutLogEvents.html) and have them delivered to a specific destination. When log events are sent to\nthe receiving service, they are Base64 encoded and compressed with the GZIP\nformat.\n\nThe following destinations are supported for subscription filters:\n\n  * An Amazon Kinesis data stream belonging to the same account as the\nsubscription filter, for same-account delivery.\n\n  * A logical destination created with\n[PutDestination](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutDestination.html)\nthat belongs to a different account, for cross-account delivery. We currently\nsupport Kinesis Data Streams and Kinesis Data Firehose as logical destinations.\n\n  * An Amazon Kinesis Data Firehose delivery stream that belongs to\nthe same account as the subscription filter, for same-account delivery.\n\n  * An Lambda function that belongs to the same account as the\nsubscription filter, for same-account delivery.\n\nEach log group can have up to two subscription filters associated with it. If\nyou are updating an existing filter, you must specify the correct name in\n`filterName`.\n\nTo perform a `PutSubscriptionFilter` operation for any destination except a\nLambda function, you must also have the `iam:PassRole` permission.","ref":"AWS.CloudWatchLogs.html#put_subscription_filter/3","title":"AWS.CloudWatchLogs.put_subscription_filter/3","type":"function"},{"doc":"Starts a Live Tail streaming session for one or more log groups.\n\nA Live Tail session returns a stream of log events that have been recently\ningested in the log groups. For more information, see [Use Live Tail to view logs in near real\ntime](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CloudWatchLogs_LiveTail.html).\n\nThe response to this operation is a response stream, over which the server sends\nlive log events and the client receives them.\n\nThe following objects are sent over the stream:\n\n  * A single\n[LiveTailSessionStart](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_LiveTailSessionStart.html) object is sent at the start of the session.\n\n  * Every second, a\n[LiveTailSessionUpdate](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_LiveTailSessionUpdate.html)\nobject is sent. Each of these objects contains an array of the actual log\nevents.\n\nIf no new log events were ingested in the past second, the\n`LiveTailSessionUpdate` object will contain an empty array.\n\nThe array of log events contained in a `LiveTailSessionUpdate` can include as\nmany as 500 log events. If the number of log events matching the request exceeds\n500 per second, the log events are sampled down to 500 log events to be included\nin each `LiveTailSessionUpdate` object.\n\nIf your client consumes the log events slower than the server produces them,\nCloudWatch Logs buffers up to 10 `LiveTailSessionUpdate` events or 5000 log\nevents, after which it starts dropping the oldest events.\n\n  * A\n[SessionStreamingException](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_SessionStreamingException.html) object is returned if an unknown error occurs on the server side.\n\n  * A\n[SessionTimeoutException](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_SessionTimeoutException.html)\nobject is returned when the session times out, after it has been kept open for\nthree hours.\n\nYou can end a session before it times out by closing the session stream or by\nclosing the client that is receiving the stream. The session also ends if the\nestablished connection between the client and the server breaks.\n\nFor examples of using an SDK to start a Live Tail session, see [ Start a Live Tail session using an Amazon Web Services\nSDK](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/example_cloudwatch-logs_StartLiveTail_section.html).","ref":"AWS.CloudWatchLogs.html#start_live_tail/3","title":"AWS.CloudWatchLogs.start_live_tail/3","type":"function"},{"doc":"Schedules a query of a log group using CloudWatch Logs Insights.\n\nYou specify the log group and time range to query and the query string to use.\n\nFor more information, see [CloudWatch Logs Insights Query Syntax](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CWL_QuerySyntax.html).\n\nAfter you run a query using `StartQuery`, the query results are stored by\nCloudWatch Logs. You can use\n[GetQueryResults](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_GetQueryResults.html) to retrieve the results of a query, using the `queryId` that `StartQuery`\nreturns.\n\nIf you have associated a KMS key with the query results in this account, then\n[StartQuery](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_StartQuery.html)\nuses that key to encrypt the results when it stores them. If no key is\nassociated with query results, the query results are encrypted with the default\nCloudWatch Logs encryption method.\n\nQueries time out after 60 minutes of runtime. If your queries are timing out,\nreduce the time range being searched or partition your query into a number of\nqueries.\n\nIf you are using CloudWatch cross-account observability, you can use this\noperation in a monitoring account to start a query in a linked source account.\nFor more information, see [CloudWatch cross-account observability](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch-Unified-Cross-Account.html).\nFor a cross-account `StartQuery` operation, the query definition must be defined\nin the monitoring account.\n\nYou can have up to 30 concurrent CloudWatch Logs insights queries, including\nqueries that have been added to dashboards.","ref":"AWS.CloudWatchLogs.html#start_query/3","title":"AWS.CloudWatchLogs.start_query/3","type":"function"},{"doc":"Stops a CloudWatch Logs Insights query that is in progress.\n\nIf the query has already ended, the operation returns an error indicating that\nthe specified query is not running.","ref":"AWS.CloudWatchLogs.html#stop_query/3","title":"AWS.CloudWatchLogs.stop_query/3","type":"function"},{"doc":"The TagLogGroup operation is on the path to deprecation.\n\nWe recommend that you use\n[TagResource](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_TagResource.html) instead.\n\nAdds or updates the specified tags for the specified log group.\n\nTo list the tags for a log group, use\n[ListTagsForResource](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_ListTagsForResource.html).\nTo remove tags, use\n[UntagResource](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_UntagResource.html).  For more information about tags, see [Tag Log Groups in Amazon CloudWatch\nLogs](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/Working-with-log-groups-and-streams.html#log-group-tagging)\nin the *Amazon CloudWatch Logs User Guide*.\n\nCloudWatch Logs doesn’t support IAM policies that prevent users from assigning\nspecified tags to log groups using the `aws:Resource/*key-name* ` or\n`aws:TagKeys` condition keys. For more information about using tags to control\naccess, see [Controlling access to Amazon Web Services resources using tags](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_tags.html).","ref":"AWS.CloudWatchLogs.html#tag_log_group/3","title":"AWS.CloudWatchLogs.tag_log_group/3","type":"function"},{"doc":"Assigns one or more tags (key-value pairs) to the specified CloudWatch Logs\nresource.\n\nCurrently, the only CloudWatch Logs resources that can be tagged are log groups\nand destinations.\n\nTags can help you organize and categorize your resources. You can also use them\nto scope user permissions by granting a user permission to access or change only\nresources with certain tag values.\n\nTags don't have any semantic meaning to Amazon Web Services and are interpreted\nstrictly as strings of characters.\n\nYou can use the `TagResource` action with a resource that already has tags. If\nyou specify a new tag key for the alarm, this tag is appended to the list of\ntags associated with the alarm. If you specify a tag key that is already\nassociated with the alarm, the new tag value that you specify replaces the\nprevious value for that tag.\n\nYou can associate as many as 50 tags with a CloudWatch Logs resource.","ref":"AWS.CloudWatchLogs.html#tag_resource/3","title":"AWS.CloudWatchLogs.tag_resource/3","type":"function"},{"doc":"Tests the filter pattern of a metric filter against a sample of log event\nmessages.\n\nYou can use this operation to validate the correctness of a metric filter\npattern.","ref":"AWS.CloudWatchLogs.html#test_metric_filter/3","title":"AWS.CloudWatchLogs.test_metric_filter/3","type":"function"},{"doc":"The UntagLogGroup operation is on the path to deprecation.\n\nWe recommend that you use\n[UntagResource](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_UntagResource.html) instead.\n\nRemoves the specified tags from the specified log group.\n\nTo list the tags for a log group, use\n[ListTagsForResource](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_ListTagsForResource.html).\nTo add tags, use\n[TagResource](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_TagResource.html).\n\nCloudWatch Logs doesn’t support IAM policies that prevent users from assigning\nspecified tags to log groups using the `aws:Resource/*key-name* ` or\n`aws:TagKeys` condition keys.","ref":"AWS.CloudWatchLogs.html#untag_log_group/3","title":"AWS.CloudWatchLogs.untag_log_group/3","type":"function"},{"doc":"Removes one or more tags from the specified resource.","ref":"AWS.CloudWatchLogs.html#untag_resource/3","title":"AWS.CloudWatchLogs.untag_resource/3","type":"function"},{"doc":"Use this operation to *suppress* anomaly detection for a specified anomaly or\npattern.\n\nIf you suppress an anomaly, CloudWatch Logs won’t report new occurrences of that\nanomaly and won't update that anomaly with new data. If you suppress a pattern,\nCloudWatch Logs won’t report any anomalies related to that pattern.\n\nYou must specify either `anomalyId` or `patternId`, but you can't specify both\nparameters in the same operation.\n\nIf you have previously used this operation to suppress detection of a pattern or\nanomaly, you can use it again to cause CloudWatch Logs to end the suppression.\nTo do this, use this operation and specify the anomaly or pattern to stop\nsuppressing, and omit the `suppressionType` and `suppressionPeriod` parameters.","ref":"AWS.CloudWatchLogs.html#update_anomaly/3","title":"AWS.CloudWatchLogs.update_anomaly/3","type":"function"},{"doc":"Updates an existing log anomaly detector.","ref":"AWS.CloudWatchLogs.html#update_log_anomaly_detector/3","title":"AWS.CloudWatchLogs.update_log_anomaly_detector/3","type":"function"},{"doc":"CodeBuild\n\nCodeBuild is a fully managed build service in the cloud.\n\nCodeBuild compiles your source code, runs unit tests, and produces artifacts\nthat are ready to deploy. CodeBuild eliminates the need to provision, manage,\nand scale your own build servers. It provides prepackaged build environments for\nthe most popular programming languages and build tools, such as Apache Maven,\nGradle, and more. You can also fully customize build environments in CodeBuild\nto use your own build tools. CodeBuild scales automatically to meet peak build\nrequests. You pay only for the build time you consume. For more information\nabout CodeBuild, see the * [CodeBuild User Guide](https://docs.aws.amazon.com/codebuild/latest/userguide/welcome.html).*","ref":"AWS.CodeBuild.html","title":"AWS.CodeBuild","type":"module"},{"doc":"Deletes one or more builds.","ref":"AWS.CodeBuild.html#batch_delete_builds/3","title":"AWS.CodeBuild.batch_delete_builds/3","type":"function"},{"doc":"Retrieves information about one or more batch builds.","ref":"AWS.CodeBuild.html#batch_get_build_batches/3","title":"AWS.CodeBuild.batch_get_build_batches/3","type":"function"},{"doc":"Gets information about one or more builds.","ref":"AWS.CodeBuild.html#batch_get_builds/3","title":"AWS.CodeBuild.batch_get_builds/3","type":"function"},{"doc":"Gets information about one or more compute fleets.","ref":"AWS.CodeBuild.html#batch_get_fleets/3","title":"AWS.CodeBuild.batch_get_fleets/3","type":"function"},{"doc":"Gets information about one or more build projects.","ref":"AWS.CodeBuild.html#batch_get_projects/3","title":"AWS.CodeBuild.batch_get_projects/3","type":"function"},{"doc":"Returns an array of report groups.","ref":"AWS.CodeBuild.html#batch_get_report_groups/3","title":"AWS.CodeBuild.batch_get_report_groups/3","type":"function"},{"doc":"Returns an array of reports.","ref":"AWS.CodeBuild.html#batch_get_reports/3","title":"AWS.CodeBuild.batch_get_reports/3","type":"function"},{"doc":"Creates a compute fleet.","ref":"AWS.CodeBuild.html#create_fleet/3","title":"AWS.CodeBuild.create_fleet/3","type":"function"},{"doc":"Creates a build project.","ref":"AWS.CodeBuild.html#create_project/3","title":"AWS.CodeBuild.create_project/3","type":"function"},{"doc":"Creates a report group.\n\nA report group contains a collection of reports.","ref":"AWS.CodeBuild.html#create_report_group/3","title":"AWS.CodeBuild.create_report_group/3","type":"function"},{"doc":"For an existing CodeBuild build project that has its source code stored in a\nGitHub or Bitbucket repository, enables CodeBuild to start rebuilding the source\ncode every time a code change is pushed to the repository.\n\nIf you enable webhooks for an CodeBuild project, and the project is used as a\nbuild step in CodePipeline, then two identical builds are created for each\ncommit. One build is triggered through webhooks, and one through CodePipeline.\nBecause billing is on a per-build basis, you are billed for both builds.\nTherefore, if you are using CodePipeline, we recommend that you disable webhooks\nin CodeBuild. In the CodeBuild console, clear the Webhook box. For more\ninformation, see step 5 in [Change a Build Project's Settings](https://docs.aws.amazon.com/codebuild/latest/userguide/change-project.html#change-project-console).","ref":"AWS.CodeBuild.html#create_webhook/3","title":"AWS.CodeBuild.create_webhook/3","type":"function"},{"doc":"Deletes a batch build.","ref":"AWS.CodeBuild.html#delete_build_batch/3","title":"AWS.CodeBuild.delete_build_batch/3","type":"function"},{"doc":"Deletes a compute fleet.\n\nWhen you delete a compute fleet, its builds are not deleted.","ref":"AWS.CodeBuild.html#delete_fleet/3","title":"AWS.CodeBuild.delete_fleet/3","type":"function"},{"doc":"Deletes a build project.\n\nWhen you delete a project, its builds are not deleted.","ref":"AWS.CodeBuild.html#delete_project/3","title":"AWS.CodeBuild.delete_project/3","type":"function"},{"doc":"Deletes a report.","ref":"AWS.CodeBuild.html#delete_report/3","title":"AWS.CodeBuild.delete_report/3","type":"function"},{"doc":"Deletes a report group.\n\nBefore you delete a report group, you must delete its reports.","ref":"AWS.CodeBuild.html#delete_report_group/3","title":"AWS.CodeBuild.delete_report_group/3","type":"function"},{"doc":"Deletes a resource policy that is identified by its resource ARN.","ref":"AWS.CodeBuild.html#delete_resource_policy/3","title":"AWS.CodeBuild.delete_resource_policy/3","type":"function"},{"doc":"Deletes a set of GitHub, GitHub Enterprise, or Bitbucket source credentials.","ref":"AWS.CodeBuild.html#delete_source_credentials/3","title":"AWS.CodeBuild.delete_source_credentials/3","type":"function"},{"doc":"For an existing CodeBuild build project that has its source code stored in a\nGitHub or Bitbucket repository, stops CodeBuild from rebuilding the source code\nevery time a code change is pushed to the repository.","ref":"AWS.CodeBuild.html#delete_webhook/3","title":"AWS.CodeBuild.delete_webhook/3","type":"function"},{"doc":"Retrieves one or more code coverage reports.","ref":"AWS.CodeBuild.html#describe_code_coverages/3","title":"AWS.CodeBuild.describe_code_coverages/3","type":"function"},{"doc":"Returns a list of details about test cases for a report.","ref":"AWS.CodeBuild.html#describe_test_cases/3","title":"AWS.CodeBuild.describe_test_cases/3","type":"function"},{"doc":"Analyzes and accumulates test report values for the specified test reports.","ref":"AWS.CodeBuild.html#get_report_group_trend/3","title":"AWS.CodeBuild.get_report_group_trend/3","type":"function"},{"doc":"Gets a resource policy that is identified by its resource ARN.","ref":"AWS.CodeBuild.html#get_resource_policy/3","title":"AWS.CodeBuild.get_resource_policy/3","type":"function"},{"doc":"Imports the source repository credentials for an CodeBuild project that has its\nsource code stored in a GitHub, GitHub Enterprise, or Bitbucket repository.","ref":"AWS.CodeBuild.html#import_source_credentials/3","title":"AWS.CodeBuild.import_source_credentials/3","type":"function"},{"doc":"Resets the cache for a project.","ref":"AWS.CodeBuild.html#invalidate_project_cache/3","title":"AWS.CodeBuild.invalidate_project_cache/3","type":"function"},{"doc":"Retrieves the identifiers of your build batches in the current region.","ref":"AWS.CodeBuild.html#list_build_batches/3","title":"AWS.CodeBuild.list_build_batches/3","type":"function"},{"doc":"Retrieves the identifiers of the build batches for a specific project.","ref":"AWS.CodeBuild.html#list_build_batches_for_project/3","title":"AWS.CodeBuild.list_build_batches_for_project/3","type":"function"},{"doc":"Gets a list of build IDs, with each build ID representing a single build.","ref":"AWS.CodeBuild.html#list_builds/3","title":"AWS.CodeBuild.list_builds/3","type":"function"},{"doc":"Gets a list of build identifiers for the specified build project, with each\nbuild identifier representing a single build.","ref":"AWS.CodeBuild.html#list_builds_for_project/3","title":"AWS.CodeBuild.list_builds_for_project/3","type":"function"},{"doc":"Gets information about Docker images that are managed by CodeBuild.","ref":"AWS.CodeBuild.html#list_curated_environment_images/3","title":"AWS.CodeBuild.list_curated_environment_images/3","type":"function"},{"doc":"Gets a list of compute fleet names with each compute fleet name representing a\nsingle compute fleet.","ref":"AWS.CodeBuild.html#list_fleets/3","title":"AWS.CodeBuild.list_fleets/3","type":"function"},{"doc":"Gets a list of build project names, with each build project name representing a\nsingle build project.","ref":"AWS.CodeBuild.html#list_projects/3","title":"AWS.CodeBuild.list_projects/3","type":"function"},{"doc":"Gets a list ARNs for the report groups in the current Amazon Web Services\naccount.","ref":"AWS.CodeBuild.html#list_report_groups/3","title":"AWS.CodeBuild.list_report_groups/3","type":"function"},{"doc":"Returns a list of ARNs for the reports in the current Amazon Web Services\naccount.","ref":"AWS.CodeBuild.html#list_reports/3","title":"AWS.CodeBuild.list_reports/3","type":"function"},{"doc":"Returns a list of ARNs for the reports that belong to a `ReportGroup`.","ref":"AWS.CodeBuild.html#list_reports_for_report_group/3","title":"AWS.CodeBuild.list_reports_for_report_group/3","type":"function"},{"doc":"Gets a list of projects that are shared with other Amazon Web Services accounts\nor users.","ref":"AWS.CodeBuild.html#list_shared_projects/3","title":"AWS.CodeBuild.list_shared_projects/3","type":"function"},{"doc":"Gets a list of report groups that are shared with other Amazon Web Services\naccounts or users.","ref":"AWS.CodeBuild.html#list_shared_report_groups/3","title":"AWS.CodeBuild.list_shared_report_groups/3","type":"function"},{"doc":"Returns a list of `SourceCredentialsInfo` objects.","ref":"AWS.CodeBuild.html#list_source_credentials/3","title":"AWS.CodeBuild.list_source_credentials/3","type":"function"},{"doc":"","ref":"AWS.CodeBuild.html#metadata/0","title":"AWS.CodeBuild.metadata/0","type":"function"},{"doc":"Stores a resource policy for the ARN of a `Project` or `ReportGroup` object.","ref":"AWS.CodeBuild.html#put_resource_policy/3","title":"AWS.CodeBuild.put_resource_policy/3","type":"function"},{"doc":"Restarts a build.","ref":"AWS.CodeBuild.html#retry_build/3","title":"AWS.CodeBuild.retry_build/3","type":"function"},{"doc":"Restarts a failed batch build.\n\nOnly batch builds that have failed can be retried.","ref":"AWS.CodeBuild.html#retry_build_batch/3","title":"AWS.CodeBuild.retry_build_batch/3","type":"function"},{"doc":"Starts running a build.","ref":"AWS.CodeBuild.html#start_build/3","title":"AWS.CodeBuild.start_build/3","type":"function"},{"doc":"Starts a batch build for a project.","ref":"AWS.CodeBuild.html#start_build_batch/3","title":"AWS.CodeBuild.start_build_batch/3","type":"function"},{"doc":"Attempts to stop running a build.","ref":"AWS.CodeBuild.html#stop_build/3","title":"AWS.CodeBuild.stop_build/3","type":"function"},{"doc":"Stops a running batch build.","ref":"AWS.CodeBuild.html#stop_build_batch/3","title":"AWS.CodeBuild.stop_build_batch/3","type":"function"},{"doc":"Updates a compute fleet.","ref":"AWS.CodeBuild.html#update_fleet/3","title":"AWS.CodeBuild.update_fleet/3","type":"function"},{"doc":"Changes the settings of a build project.","ref":"AWS.CodeBuild.html#update_project/3","title":"AWS.CodeBuild.update_project/3","type":"function"},{"doc":"Changes the public visibility for a project.\n\nThe project's build results, logs, and artifacts are available to the general\npublic. For more information, see [Public build projects](https://docs.aws.amazon.com/codebuild/latest/userguide/public-builds.html)\nin the *CodeBuild User Guide*.\n\nThe following should be kept in mind when making your projects public:\n\n   All of a project's build results, logs, and artifacts, including\nbuilds that were run when the project was private, are available to the general\npublic.\n\n   All build logs and artifacts are available to the public.\nEnvironment variables, source code, and other sensitive information may have\nbeen output to the build logs and artifacts. You must be careful about what\ninformation is output to the build logs. Some best practice are:\n\n     Do not store sensitive values in environment variables.\nWe recommend that you use an Amazon EC2 Systems Manager Parameter Store or\nSecrets Manager to store sensitive values.\n\n     Follow [Best practices for using webhooks](https://docs.aws.amazon.com/codebuild/latest/userguide/webhooks.html#webhook-best-practices)\nin the *CodeBuild User Guide* to limit which entities can trigger a build, and\ndo not store the buildspec in the project itself, to ensure that your webhooks\nare as secure as possible.\n\n   A malicious user can use public builds to distribute malicious\nartifacts. We recommend that you review all pull requests to verify that the\npull request is a legitimate change. We also recommend that you validate any\nartifacts with their checksums to make sure that the correct artifacts are being\ndownloaded.","ref":"AWS.CodeBuild.html#update_project_visibility/3","title":"AWS.CodeBuild.update_project_visibility/3","type":"function"},{"doc":"Updates a report group.","ref":"AWS.CodeBuild.html#update_report_group/3","title":"AWS.CodeBuild.update_report_group/3","type":"function"},{"doc":"Updates the webhook associated with an CodeBuild build project.\n\nIf you use Bitbucket for your repository, `rotateSecret` is ignored.","ref":"AWS.CodeBuild.html#update_webhook/3","title":"AWS.CodeBuild.update_webhook/3","type":"function"},{"doc":"CodeCommit\n\nThis is the *CodeCommit API Reference*.\n\nThis reference provides descriptions of the operations and data types for\nCodeCommit API along with usage examples.\n\nYou can use the CodeCommit API to work with the following objects:\n\nRepositories, by calling the following:\n\n  * `BatchGetRepositories`, which returns information about one or\nmore repositories associated with your Amazon Web Services account.\n\n  * `CreateRepository`, which creates an CodeCommit repository.\n\n  * `DeleteRepository`, which deletes an CodeCommit repository.\n\n  * `GetRepository`, which returns information about a specified\nrepository.\n\n  * `ListRepositories`, which lists all CodeCommit repositories\nassociated with your Amazon Web Services account.\n\n  * `UpdateRepositoryDescription`, which sets or updates the\ndescription of the repository.\n\n  * `UpdateRepositoryEncryptionKey`, which updates the Key Management\nService encryption key used to encrypt and decrypt a repository.\n\n  * `UpdateRepositoryName`, which changes the name of the repository.\nIf you change the name of a repository, no other users of that repository can\naccess it until you send them the new HTTPS or SSH URL to use.\n\nBranches, by calling the following:\n\n  * `CreateBranch`, which creates a branch in a specified repository.\n\n  * `DeleteBranch`, which deletes the specified branch in a repository\nunless it is the default branch.\n\n  * `GetBranch`, which returns information about a specified branch.\n\n  * `ListBranches`, which lists all branches for a specified\nrepository.\n\n  * `UpdateDefaultBranch`, which changes the default branch for a\nrepository.\n\nFiles, by calling the following:\n\n  * `DeleteFile`, which deletes the content of a specified file from a\nspecified branch.\n\n  * `GetBlob`, which returns the base-64 encoded content of an\nindividual Git blob object in a repository.\n\n  * `GetFile`, which returns the base-64 encoded content of a\nspecified file.\n\n  * `GetFolder`, which returns the contents of a specified folder or\ndirectory.\n\n  * `ListFileCommitHistory`, which retrieves a list of commits and\nchanges to a specified file.\n\n  * `PutFile`, which adds or modifies a single file in a specified\nrepository and branch.\n\nCommits, by calling the following:\n\n  * `BatchGetCommits`, which returns information about one or more\ncommits in a repository.\n\n  * `CreateCommit`, which creates a commit for changes to a\nrepository.\n\n  * `GetCommit`, which returns information about a commit, including\ncommit messages and author and committer information.\n\n  * `GetDifferences`, which returns information about the differences\nin a valid commit specifier (such as a branch, tag, HEAD, commit ID, or other\nfully qualified reference).\n\nMerges, by calling the following:\n\n  * `BatchDescribeMergeConflicts`, which returns information about\nconflicts in a merge between commits in a repository.\n\n  * `CreateUnreferencedMergeCommit`, which creates an unreferenced\ncommit between two branches or commits for the purpose of comparing them and\nidentifying any potential conflicts.\n\n  * `DescribeMergeConflicts`, which returns information about merge\nconflicts between the base, source, and destination versions of a file in a\npotential merge.\n\n  * `GetMergeCommit`, which returns information about the merge\nbetween a source and destination commit.\n\n  * `GetMergeConflicts`, which returns information about merge\nconflicts between the source and destination branch in a pull request.\n\n  * `GetMergeOptions`, which returns information about the available\nmerge options between two branches or commit specifiers.\n\n  * `MergeBranchesByFastForward`, which merges two branches using the\nfast-forward merge option.\n\n  * `MergeBranchesBySquash`, which merges two branches using the\nsquash merge option.\n\n  * `MergeBranchesByThreeWay`, which merges two branches using the\nthree-way merge option.\n\nPull requests, by calling the following:\n\n  * `CreatePullRequest`, which creates a pull request in a specified\nrepository.\n\n  * `CreatePullRequestApprovalRule`, which creates an approval rule\nfor a specified pull request.\n\n  * `DeletePullRequestApprovalRule`, which deletes an approval rule\nfor a specified pull request.\n\n  * `DescribePullRequestEvents`, which returns information about one\nor more pull request events.\n\n  * `EvaluatePullRequestApprovalRules`, which evaluates whether a pull\nrequest has met all the conditions specified in its associated approval rules.\n\n  * `GetCommentsForPullRequest`, which returns information about\ncomments on a specified pull request.\n\n  * `GetPullRequest`, which returns information about a specified pull\nrequest.\n\n  * `GetPullRequestApprovalStates`, which returns information about\nthe approval states for a specified pull request.\n\n  * `GetPullRequestOverrideState`, which returns information about\nwhether approval rules have been set aside (overriden) for a pull request, and\nif so, the Amazon Resource Name (ARN) of the user or identity that overrode the\nrules and their requirements for the pull request.\n\n  * `ListPullRequests`, which lists all pull requests for a\nrepository.\n\n  * `MergePullRequestByFastForward`, which merges the source\ndestination branch of a pull request into the specified destination branch for\nthat pull request using the fast-forward merge option.\n\n  * `MergePullRequestBySquash`, which merges the source destination\nbranch of a pull request into the specified destination branch for that pull\nrequest using the squash merge option.\n\n  * `MergePullRequestByThreeWay`, which merges the source destination\nbranch of a pull request into the specified destination branch for that pull\nrequest using the three-way merge option.\n\n  * `OverridePullRequestApprovalRules`, which sets aside all approval\nrule requirements for a pull request.\n\n  * `PostCommentForPullRequest`, which posts a comment to a pull\nrequest at the specified line, file, or request.\n\n  * `UpdatePullRequestApprovalRuleContent`, which updates the\nstructure of an approval rule for a pull request.\n\n  * `UpdatePullRequestApprovalState`, which updates the state of an\napproval on a pull request.\n\n  * `UpdatePullRequestDescription`, which updates the description of a\npull request.\n\n  * `UpdatePullRequestStatus`, which updates the status of a pull\nrequest.\n\n  * `UpdatePullRequestTitle`, which updates the title of a pull\nrequest.\n\nApproval rule templates, by calling the following:\n\n  * `AssociateApprovalRuleTemplateWithRepository`, which associates a\ntemplate with a specified repository. After the template is associated with a\nrepository, CodeCommit creates approval rules that match the template conditions\non every pull request created in the specified repository.\n\n  * `BatchAssociateApprovalRuleTemplateWithRepositories`, which\nassociates a template with one or more specified repositories. After the\ntemplate is associated with a repository, CodeCommit creates approval rules that\nmatch the template conditions on every pull request created in the specified\nrepositories.\n\n  * `BatchDisassociateApprovalRuleTemplateFromRepositories`, which\nremoves the association between a template and specified repositories so that\napproval rules based on the template are not automatically created when pull\nrequests are created in those repositories.\n\n  * `CreateApprovalRuleTemplate`, which creates a template for\napproval rules that can then be associated with one or more repositories in your\nAmazon Web Services account.\n\n  * `DeleteApprovalRuleTemplate`, which deletes the specified\ntemplate. It does not remove approval rules on pull requests already created\nwith the template.\n\n  * `DisassociateApprovalRuleTemplateFromRepository`, which removes\nthe association between a template and a repository so that approval rules based\non the template are not automatically created when pull requests are created in\nthe specified repository.\n\n  * `GetApprovalRuleTemplate`, which returns information about an\napproval rule template.\n\n  * `ListApprovalRuleTemplates`, which lists all approval rule\ntemplates in the Amazon Web Services Region in your Amazon Web Services account.\n\n  * `ListAssociatedApprovalRuleTemplatesForRepository`, which lists\nall approval rule templates that are associated with a specified repository.\n\n  * `ListRepositoriesForApprovalRuleTemplate`, which lists all\nrepositories associated with the specified approval rule template.\n\n  * `UpdateApprovalRuleTemplateDescription`, which updates the\ndescription of an approval rule template.\n\n  * `UpdateApprovalRuleTemplateName`, which updates the name of an\napproval rule template.\n\n  * `UpdateApprovalRuleTemplateContent`, which updates the content of\nan approval rule template.\n\nComments in a repository, by calling the following:\n\n  * `DeleteCommentContent`, which deletes the content of a comment on\na commit in a repository.\n\n  * `GetComment`, which returns information about a comment on a\ncommit.\n\n  * `GetCommentReactions`, which returns information about emoji\nreactions to comments.\n\n  * `GetCommentsForComparedCommit`, which returns information about\ncomments on the comparison between two commit specifiers in a repository.\n\n  * `PostCommentForComparedCommit`, which creates a comment on the\ncomparison between two commit specifiers in a repository.\n\n  * `PostCommentReply`, which creates a reply to a comment.\n\n  * `PutCommentReaction`, which creates or updates an emoji reaction\nto a comment.\n\n  * `UpdateComment`, which updates the content of a comment on a\ncommit in a repository.\n\nTags used to tag resources in CodeCommit (not Git tags), by calling the\nfollowing:\n\n  * `ListTagsForResource`, which gets information about Amazon Web\nServicestags for a specified Amazon Resource Name (ARN) in CodeCommit.\n\n  * `TagResource`, which adds or updates tags for a resource in\nCodeCommit.\n\n  * `UntagResource`, which removes tags for a resource in CodeCommit.\n\nTriggers, by calling the following:\n\n  * `GetRepositoryTriggers`, which returns information about triggers\nconfigured for a repository.\n\n  * `PutRepositoryTriggers`, which replaces all triggers for a\nrepository and can be used to create or delete triggers.\n\n  * `TestRepositoryTriggers`, which tests the functionality of a\nrepository trigger by sending data to the trigger target.\n\nFor information about how to use CodeCommit, see the [CodeCommit User Guide](https://docs.aws.amazon.com/codecommit/latest/userguide/welcome.html).","ref":"AWS.CodeCommit.html","title":"AWS.CodeCommit","type":"module"},{"doc":"Creates an association between an approval rule template and a specified\nrepository.\n\nThen, the next time a pull request is created in the repository where the\ndestination reference (if specified) matches the destination reference (branch)\nfor the pull request, an approval rule that matches the template conditions is\nautomatically created for that pull request. If no destination references are\nspecified in the template, an approval rule that matches the template contents\nis created for all pull requests in that repository.","ref":"AWS.CodeCommit.html#associate_approval_rule_template_with_repository/3","title":"AWS.CodeCommit.associate_approval_rule_template_with_repository/3","type":"function"},{"doc":"Creates an association between an approval rule template and one or more\nspecified repositories.","ref":"AWS.CodeCommit.html#batch_associate_approval_rule_template_with_repositories/3","title":"AWS.CodeCommit.batch_associate_approval_rule_template_with_repositories/3","type":"function"},{"doc":"Returns information about one or more merge conflicts in the attempted merge of\ntwo commit specifiers using the squash or three-way merge strategy.","ref":"AWS.CodeCommit.html#batch_describe_merge_conflicts/3","title":"AWS.CodeCommit.batch_describe_merge_conflicts/3","type":"function"},{"doc":"Removes the association between an approval rule template and one or more\nspecified repositories.","ref":"AWS.CodeCommit.html#batch_disassociate_approval_rule_template_from_repositories/3","title":"AWS.CodeCommit.batch_disassociate_approval_rule_template_from_repositories/3","type":"function"},{"doc":"Returns information about the contents of one or more commits in a repository.","ref":"AWS.CodeCommit.html#batch_get_commits/3","title":"AWS.CodeCommit.batch_get_commits/3","type":"function"},{"doc":"Returns information about one or more repositories.\n\nThe description field for a repository accepts all HTML characters and all valid\nUnicode characters. Applications that do not HTML-encode the description and\ndisplay it in a webpage can expose users to potentially malicious code. Make\nsure that you HTML-encode the description field in any application that uses\nthis API to display the repository description on a webpage.","ref":"AWS.CodeCommit.html#batch_get_repositories/3","title":"AWS.CodeCommit.batch_get_repositories/3","type":"function"},{"doc":"Creates a template for approval rules that can then be associated with one or\nmore repositories in your Amazon Web Services account.\n\nWhen you associate a template with a repository, CodeCommit creates an approval\nrule that matches the conditions of the template for all pull requests that meet\nthe conditions of the template. For more information, see\n`AssociateApprovalRuleTemplateWithRepository`.","ref":"AWS.CodeCommit.html#create_approval_rule_template/3","title":"AWS.CodeCommit.create_approval_rule_template/3","type":"function"},{"doc":"Creates a branch in a repository and points the branch to a commit.\n\nCalling the create branch operation does not set a repository's default branch.\nTo do this, call the update default branch operation.","ref":"AWS.CodeCommit.html#create_branch/3","title":"AWS.CodeCommit.create_branch/3","type":"function"},{"doc":"Creates a commit for a repository on the tip of a specified branch.","ref":"AWS.CodeCommit.html#create_commit/3","title":"AWS.CodeCommit.create_commit/3","type":"function"},{"doc":"Creates a pull request in the specified repository.","ref":"AWS.CodeCommit.html#create_pull_request/3","title":"AWS.CodeCommit.create_pull_request/3","type":"function"},{"doc":"Creates an approval rule for a pull request.","ref":"AWS.CodeCommit.html#create_pull_request_approval_rule/3","title":"AWS.CodeCommit.create_pull_request_approval_rule/3","type":"function"},{"doc":"Creates a new, empty repository.","ref":"AWS.CodeCommit.html#create_repository/3","title":"AWS.CodeCommit.create_repository/3","type":"function"},{"doc":"Creates an unreferenced commit that represents the result of merging two\nbranches using a specified merge strategy.\n\nThis can help you determine the outcome of a potential merge. This API cannot be\nused with the fast-forward merge strategy because that strategy does not create\na merge commit.\n\nThis unreferenced merge commit can only be accessed using the GetCommit API or\nthrough git commands such as git fetch. To retrieve this commit, you must\nspecify its commit ID or otherwise reference it.","ref":"AWS.CodeCommit.html#create_unreferenced_merge_commit/3","title":"AWS.CodeCommit.create_unreferenced_merge_commit/3","type":"function"},{"doc":"Deletes a specified approval rule template.\n\nDeleting a template does not remove approval rules on pull requests already\ncreated with the template.","ref":"AWS.CodeCommit.html#delete_approval_rule_template/3","title":"AWS.CodeCommit.delete_approval_rule_template/3","type":"function"},{"doc":"Deletes a branch from a repository, unless that branch is the default branch for\nthe repository.","ref":"AWS.CodeCommit.html#delete_branch/3","title":"AWS.CodeCommit.delete_branch/3","type":"function"},{"doc":"Deletes the content of a comment made on a change, file, or commit in a\nrepository.","ref":"AWS.CodeCommit.html#delete_comment_content/3","title":"AWS.CodeCommit.delete_comment_content/3","type":"function"},{"doc":"Deletes a specified file from a specified branch.\n\nA commit is created on the branch that contains the revision. The file still\nexists in the commits earlier to the commit that contains the deletion.","ref":"AWS.CodeCommit.html#delete_file/3","title":"AWS.CodeCommit.delete_file/3","type":"function"},{"doc":"Deletes an approval rule from a specified pull request.\n\nApproval rules can be deleted from a pull request only if the pull request is\nopen, and if the approval rule was created specifically for a pull request and\nnot generated from an approval rule template associated with the repository\nwhere the pull request was created. You cannot delete an approval rule from a\nmerged or closed pull request.","ref":"AWS.CodeCommit.html#delete_pull_request_approval_rule/3","title":"AWS.CodeCommit.delete_pull_request_approval_rule/3","type":"function"},{"doc":"Deletes a repository.\n\nIf a specified repository was already deleted, a null repository ID is returned.\n\nDeleting a repository also deletes all associated objects and metadata. After a\nrepository is deleted, all future push calls to the deleted repository fail.","ref":"AWS.CodeCommit.html#delete_repository/3","title":"AWS.CodeCommit.delete_repository/3","type":"function"},{"doc":"Returns information about one or more merge conflicts in the attempted merge of\ntwo commit specifiers using the squash or three-way merge strategy.\n\nIf the merge option for the attempted merge is specified as FAST_FORWARD_MERGE,\nan exception is thrown.","ref":"AWS.CodeCommit.html#describe_merge_conflicts/3","title":"AWS.CodeCommit.describe_merge_conflicts/3","type":"function"},{"doc":"Returns information about one or more pull request events.","ref":"AWS.CodeCommit.html#describe_pull_request_events/3","title":"AWS.CodeCommit.describe_pull_request_events/3","type":"function"},{"doc":"Removes the association between a template and a repository so that approval\nrules based on the template are not automatically created when pull requests are\ncreated in the specified repository.\n\nThis does not delete any approval rules previously created for pull requests\nthrough the template association.","ref":"AWS.CodeCommit.html#disassociate_approval_rule_template_from_repository/3","title":"AWS.CodeCommit.disassociate_approval_rule_template_from_repository/3","type":"function"},{"doc":"Evaluates whether a pull request has met all the conditions specified in its\nassociated approval rules.","ref":"AWS.CodeCommit.html#evaluate_pull_request_approval_rules/3","title":"AWS.CodeCommit.evaluate_pull_request_approval_rules/3","type":"function"},{"doc":"Returns information about a specified approval rule template.","ref":"AWS.CodeCommit.html#get_approval_rule_template/3","title":"AWS.CodeCommit.get_approval_rule_template/3","type":"function"},{"doc":"Returns the base-64 encoded content of an individual blob in a repository.","ref":"AWS.CodeCommit.html#get_blob/3","title":"AWS.CodeCommit.get_blob/3","type":"function"},{"doc":"Returns information about a repository branch, including its name and the last\ncommit ID.","ref":"AWS.CodeCommit.html#get_branch/3","title":"AWS.CodeCommit.get_branch/3","type":"function"},{"doc":"Returns the content of a comment made on a change, file, or commit in a\nrepository.\n\nReaction counts might include numbers from user identities who were deleted\nafter the reaction was made. For a count of reactions from active identities,\nuse GetCommentReactions.","ref":"AWS.CodeCommit.html#get_comment/3","title":"AWS.CodeCommit.get_comment/3","type":"function"},{"doc":"Returns information about reactions to a specified comment ID.\n\nReactions from users who have been deleted will not be included in the count.","ref":"AWS.CodeCommit.html#get_comment_reactions/3","title":"AWS.CodeCommit.get_comment_reactions/3","type":"function"},{"doc":"Returns information about comments made on the comparison between two commits.\n\nReaction counts might include numbers from user identities who were deleted\nafter the reaction was made. For a count of reactions from active identities,\nuse GetCommentReactions.","ref":"AWS.CodeCommit.html#get_comments_for_compared_commit/3","title":"AWS.CodeCommit.get_comments_for_compared_commit/3","type":"function"},{"doc":"Returns comments made on a pull request.\n\nReaction counts might include numbers from user identities who were deleted\nafter the reaction was made. For a count of reactions from active identities,\nuse GetCommentReactions.","ref":"AWS.CodeCommit.html#get_comments_for_pull_request/3","title":"AWS.CodeCommit.get_comments_for_pull_request/3","type":"function"},{"doc":"Returns information about a commit, including commit message and committer\ninformation.","ref":"AWS.CodeCommit.html#get_commit/3","title":"AWS.CodeCommit.get_commit/3","type":"function"},{"doc":"Returns information about the differences in a valid commit specifier (such as a\nbranch, tag, HEAD, commit ID, or other fully qualified reference).\n\nResults can be limited to a specified path.","ref":"AWS.CodeCommit.html#get_differences/3","title":"AWS.CodeCommit.get_differences/3","type":"function"},{"doc":"Returns the base-64 encoded contents of a specified file and its metadata.","ref":"AWS.CodeCommit.html#get_file/3","title":"AWS.CodeCommit.get_file/3","type":"function"},{"doc":"Returns the contents of a specified folder in a repository.","ref":"AWS.CodeCommit.html#get_folder/3","title":"AWS.CodeCommit.get_folder/3","type":"function"},{"doc":"Returns information about a specified merge commit.","ref":"AWS.CodeCommit.html#get_merge_commit/3","title":"AWS.CodeCommit.get_merge_commit/3","type":"function"},{"doc":"Returns information about merge conflicts between the before and after commit\nIDs for a pull request in a repository.","ref":"AWS.CodeCommit.html#get_merge_conflicts/3","title":"AWS.CodeCommit.get_merge_conflicts/3","type":"function"},{"doc":"Returns information about the merge options available for merging two specified\nbranches.\n\nFor details about why a merge option is not available, use GetMergeConflicts or\nDescribeMergeConflicts.","ref":"AWS.CodeCommit.html#get_merge_options/3","title":"AWS.CodeCommit.get_merge_options/3","type":"function"},{"doc":"Gets information about a pull request in a specified repository.","ref":"AWS.CodeCommit.html#get_pull_request/3","title":"AWS.CodeCommit.get_pull_request/3","type":"function"},{"doc":"Gets information about the approval states for a specified pull request.\n\nApproval states only apply to pull requests that have one or more approval rules\napplied to them.","ref":"AWS.CodeCommit.html#get_pull_request_approval_states/3","title":"AWS.CodeCommit.get_pull_request_approval_states/3","type":"function"},{"doc":"Returns information about whether approval rules have been set aside\n(overridden) for a pull request, and if so, the Amazon Resource Name (ARN) of\nthe user or identity that overrode the rules and their requirements for the pull\nrequest.","ref":"AWS.CodeCommit.html#get_pull_request_override_state/3","title":"AWS.CodeCommit.get_pull_request_override_state/3","type":"function"},{"doc":"Returns information about a repository.\n\nThe description field for a repository accepts all HTML characters and all valid\nUnicode characters. Applications that do not HTML-encode the description and\ndisplay it in a webpage can expose users to potentially malicious code. Make\nsure that you HTML-encode the description field in any application that uses\nthis API to display the repository description on a webpage.","ref":"AWS.CodeCommit.html#get_repository/3","title":"AWS.CodeCommit.get_repository/3","type":"function"},{"doc":"Gets information about triggers configured for a repository.","ref":"AWS.CodeCommit.html#get_repository_triggers/3","title":"AWS.CodeCommit.get_repository_triggers/3","type":"function"},{"doc":"Lists all approval rule templates in the specified Amazon Web Services Region in\nyour Amazon Web Services account.\n\nIf an Amazon Web Services Region is not specified, the Amazon Web Services\nRegion where you are signed in is used.","ref":"AWS.CodeCommit.html#list_approval_rule_templates/3","title":"AWS.CodeCommit.list_approval_rule_templates/3","type":"function"},{"doc":"Lists all approval rule templates that are associated with a specified\nrepository.","ref":"AWS.CodeCommit.html#list_associated_approval_rule_templates_for_repository/3","title":"AWS.CodeCommit.list_associated_approval_rule_templates_for_repository/3","type":"function"},{"doc":"Gets information about one or more branches in a repository.","ref":"AWS.CodeCommit.html#list_branches/3","title":"AWS.CodeCommit.list_branches/3","type":"function"},{"doc":"Retrieves a list of commits and changes to a specified file.","ref":"AWS.CodeCommit.html#list_file_commit_history/3","title":"AWS.CodeCommit.list_file_commit_history/3","type":"function"},{"doc":"Returns a list of pull requests for a specified repository.\n\nThe return list can be refined by pull request status or pull request author\nARN.","ref":"AWS.CodeCommit.html#list_pull_requests/3","title":"AWS.CodeCommit.list_pull_requests/3","type":"function"},{"doc":"Gets information about one or more repositories.","ref":"AWS.CodeCommit.html#list_repositories/3","title":"AWS.CodeCommit.list_repositories/3","type":"function"},{"doc":"Lists all repositories associated with the specified approval rule template.","ref":"AWS.CodeCommit.html#list_repositories_for_approval_rule_template/3","title":"AWS.CodeCommit.list_repositories_for_approval_rule_template/3","type":"function"},{"doc":"Gets information about Amazon Web Servicestags for a specified Amazon Resource\nName (ARN) in CodeCommit.\n\nFor a list of valid resources in CodeCommit, see [CodeCommit Resources and Operations](https://docs.aws.amazon.com/codecommit/latest/userguide/auth-and-access-control-iam-access-control-identity-based.html#arn-formats)\nin the* CodeCommit User Guide*.","ref":"AWS.CodeCommit.html#list_tags_for_resource/3","title":"AWS.CodeCommit.list_tags_for_resource/3","type":"function"},{"doc":"Merges two branches using the fast-forward merge strategy.","ref":"AWS.CodeCommit.html#merge_branches_by_fast_forward/3","title":"AWS.CodeCommit.merge_branches_by_fast_forward/3","type":"function"},{"doc":"Merges two branches using the squash merge strategy.","ref":"AWS.CodeCommit.html#merge_branches_by_squash/3","title":"AWS.CodeCommit.merge_branches_by_squash/3","type":"function"},{"doc":"Merges two specified branches using the three-way merge strategy.","ref":"AWS.CodeCommit.html#merge_branches_by_three_way/3","title":"AWS.CodeCommit.merge_branches_by_three_way/3","type":"function"},{"doc":"Attempts to merge the source commit of a pull request into the specified\ndestination branch for that pull request at the specified commit using the\nfast-forward merge strategy.\n\nIf the merge is successful, it closes the pull request.","ref":"AWS.CodeCommit.html#merge_pull_request_by_fast_forward/3","title":"AWS.CodeCommit.merge_pull_request_by_fast_forward/3","type":"function"},{"doc":"Attempts to merge the source commit of a pull request into the specified\ndestination branch for that pull request at the specified commit using the\nsquash merge strategy.\n\nIf the merge is successful, it closes the pull request.","ref":"AWS.CodeCommit.html#merge_pull_request_by_squash/3","title":"AWS.CodeCommit.merge_pull_request_by_squash/3","type":"function"},{"doc":"Attempts to merge the source commit of a pull request into the specified\ndestination branch for that pull request at the specified commit using the\nthree-way merge strategy.\n\nIf the merge is successful, it closes the pull request.","ref":"AWS.CodeCommit.html#merge_pull_request_by_three_way/3","title":"AWS.CodeCommit.merge_pull_request_by_three_way/3","type":"function"},{"doc":"","ref":"AWS.CodeCommit.html#metadata/0","title":"AWS.CodeCommit.metadata/0","type":"function"},{"doc":"Sets aside (overrides) all approval rule requirements for a specified pull\nrequest.","ref":"AWS.CodeCommit.html#override_pull_request_approval_rules/3","title":"AWS.CodeCommit.override_pull_request_approval_rules/3","type":"function"},{"doc":"Posts a comment on the comparison between two commits.","ref":"AWS.CodeCommit.html#post_comment_for_compared_commit/3","title":"AWS.CodeCommit.post_comment_for_compared_commit/3","type":"function"},{"doc":"Posts a comment on a pull request.","ref":"AWS.CodeCommit.html#post_comment_for_pull_request/3","title":"AWS.CodeCommit.post_comment_for_pull_request/3","type":"function"},{"doc":"Posts a comment in reply to an existing comment on a comparison between commits\nor a pull request.","ref":"AWS.CodeCommit.html#post_comment_reply/3","title":"AWS.CodeCommit.post_comment_reply/3","type":"function"},{"doc":"Adds or updates a reaction to a specified comment for the user whose identity is\nused to make the request.\n\nYou can only add or update a reaction for yourself. You cannot add, modify, or\ndelete a reaction for another user.","ref":"AWS.CodeCommit.html#put_comment_reaction/3","title":"AWS.CodeCommit.put_comment_reaction/3","type":"function"},{"doc":"Adds or updates a file in a branch in an CodeCommit repository, and generates a\ncommit for the addition in the specified branch.","ref":"AWS.CodeCommit.html#put_file/3","title":"AWS.CodeCommit.put_file/3","type":"function"},{"doc":"Replaces all triggers for a repository.\n\nUsed to create or delete triggers.","ref":"AWS.CodeCommit.html#put_repository_triggers/3","title":"AWS.CodeCommit.put_repository_triggers/3","type":"function"},{"doc":"Adds or updates tags for a resource in CodeCommit.\n\nFor a list of valid resources in CodeCommit, see [CodeCommit Resources and Operations](https://docs.aws.amazon.com/codecommit/latest/userguide/auth-and-access-control-iam-access-control-identity-based.html#arn-formats)\nin the *CodeCommit User Guide*.","ref":"AWS.CodeCommit.html#tag_resource/3","title":"AWS.CodeCommit.tag_resource/3","type":"function"},{"doc":"Tests the functionality of repository triggers by sending information to the\ntrigger target.\n\nIf real data is available in the repository, the test sends data from the last\ncommit. If no data is available, sample data is generated.","ref":"AWS.CodeCommit.html#test_repository_triggers/3","title":"AWS.CodeCommit.test_repository_triggers/3","type":"function"},{"doc":"Removes tags for a resource in CodeCommit.\n\nFor a list of valid resources in CodeCommit, see [CodeCommit Resources and Operations](https://docs.aws.amazon.com/codecommit/latest/userguide/auth-and-access-control-iam-access-control-identity-based.html#arn-formats)\nin the *CodeCommit User Guide*.","ref":"AWS.CodeCommit.html#untag_resource/3","title":"AWS.CodeCommit.untag_resource/3","type":"function"},{"doc":"Updates the content of an approval rule template.\n\nYou can change the number of required approvals, the membership of the approval\nrule, and whether an approval pool is defined.","ref":"AWS.CodeCommit.html#update_approval_rule_template_content/3","title":"AWS.CodeCommit.update_approval_rule_template_content/3","type":"function"},{"doc":"Updates the description for a specified approval rule template.","ref":"AWS.CodeCommit.html#update_approval_rule_template_description/3","title":"AWS.CodeCommit.update_approval_rule_template_description/3","type":"function"},{"doc":"Updates the name of a specified approval rule template.","ref":"AWS.CodeCommit.html#update_approval_rule_template_name/3","title":"AWS.CodeCommit.update_approval_rule_template_name/3","type":"function"},{"doc":"Replaces the contents of a comment.","ref":"AWS.CodeCommit.html#update_comment/3","title":"AWS.CodeCommit.update_comment/3","type":"function"},{"doc":"Sets or changes the default branch name for the specified repository.\n\nIf you use this operation to change the default branch name to the current\ndefault branch name, a success message is returned even though the default\nbranch did not change.","ref":"AWS.CodeCommit.html#update_default_branch/3","title":"AWS.CodeCommit.update_default_branch/3","type":"function"},{"doc":"Updates the structure of an approval rule created specifically for a pull\nrequest.\n\nFor example, you can change the number of required approvers and the approval\npool for approvers.","ref":"AWS.CodeCommit.html#update_pull_request_approval_rule_content/3","title":"AWS.CodeCommit.update_pull_request_approval_rule_content/3","type":"function"},{"doc":"Updates the state of a user's approval on a pull request.\n\nThe user is derived from the signed-in account when the request is made.","ref":"AWS.CodeCommit.html#update_pull_request_approval_state/3","title":"AWS.CodeCommit.update_pull_request_approval_state/3","type":"function"},{"doc":"Replaces the contents of the description of a pull request.","ref":"AWS.CodeCommit.html#update_pull_request_description/3","title":"AWS.CodeCommit.update_pull_request_description/3","type":"function"},{"doc":"Updates the status of a pull request.","ref":"AWS.CodeCommit.html#update_pull_request_status/3","title":"AWS.CodeCommit.update_pull_request_status/3","type":"function"},{"doc":"Replaces the title of a pull request.","ref":"AWS.CodeCommit.html#update_pull_request_title/3","title":"AWS.CodeCommit.update_pull_request_title/3","type":"function"},{"doc":"Sets or changes the comment or description for a repository.\n\nThe description field for a repository accepts all HTML characters and all valid\nUnicode characters. Applications that do not HTML-encode the description and\ndisplay it in a webpage can expose users to potentially malicious code. Make\nsure that you HTML-encode the description field in any application that uses\nthis API to display the repository description on a webpage.","ref":"AWS.CodeCommit.html#update_repository_description/3","title":"AWS.CodeCommit.update_repository_description/3","type":"function"},{"doc":"Updates the Key Management Service encryption key used to encrypt and decrypt a\nCodeCommit repository.","ref":"AWS.CodeCommit.html#update_repository_encryption_key/3","title":"AWS.CodeCommit.update_repository_encryption_key/3","type":"function"},{"doc":"Renames a repository.\n\nThe repository name must be unique across the calling Amazon Web Services\naccount. Repository names are limited to 100 alphanumeric, dash, and underscore\ncharacters, and cannot include certain characters. The suffix .git is\nprohibited. For more information about the limits on repository names, see\n[Quotas](https://docs.aws.amazon.com/codecommit/latest/userguide/limits.html) in\nthe CodeCommit User Guide.","ref":"AWS.CodeCommit.html#update_repository_name/3","title":"AWS.CodeCommit.update_repository_name/3","type":"function"},{"doc":"CodeDeploy is a deployment service that automates application deployments to\nAmazon EC2 instances, on-premises instances running in your own facility,\nserverless Lambda functions, or applications in an Amazon ECS service.\n\nYou can deploy a nearly unlimited variety of application content, such as an\nupdated Lambda function, updated applications in an Amazon ECS service, code,\nweb and configuration files, executables, packages, scripts, multimedia files,\nand so on. CodeDeploy can deploy application content stored in Amazon S3\nbuckets, GitHub repositories, or Bitbucket repositories. You do not need to make\nchanges to your existing code before you can use CodeDeploy.\n\nCodeDeploy makes it easier for you to rapidly release new features, helps you\navoid downtime during application deployment, and handles the complexity of\nupdating your applications, without many of the risks associated with\nerror-prone manual deployments.","ref":"AWS.CodeDeploy.html","title":"AWS.CodeDeploy","type":"module"},{"doc":"Use the information in this guide to help you work with the following CodeDeploy\ncomponents:\n\n  * **Application**: A name that uniquely identifies the application\nyou want to deploy. CodeDeploy uses this name, which functions as a container,\nto ensure the correct combination of revision, deployment configuration, and\ndeployment group are referenced during a deployment.\n\n  * **Deployment group**: A set of individual instances, CodeDeploy\nLambda deployment configuration settings, or an Amazon ECS service and network\ndetails. A Lambda deployment group specifies how to route traffic to a new\nversion of a Lambda function. An Amazon ECS deployment group specifies the\nservice created in Amazon ECS to deploy, a load balancer, and a listener to\nreroute production traffic to an updated containerized application. An Amazon\nEC2/On-premises deployment group contains individually tagged instances, Amazon\nEC2 instances in Amazon EC2 Auto Scaling groups, or both. All deployment groups\ncan specify optional trigger, alarm, and rollback settings.\n\n  * **Deployment configuration**: A set of deployment rules and\ndeployment success and failure conditions used by CodeDeploy during a\ndeployment.\n\n  * **Deployment**: The process and the components used when updating\na Lambda function, a containerized application in an Amazon ECS service, or of\ninstalling content on one or more instances.\n\n  * **Application revisions**: For an Lambda deployment, this is an\nAppSpec file that specifies the Lambda function to be updated and one or more\nfunctions to validate deployment lifecycle events. For an Amazon ECS deployment,\nthis is an AppSpec file that specifies the Amazon ECS task definition,\ncontainer, and port where production traffic is rerouted. For an EC2/On-premises\ndeployment, this is an archive file that contains source content—source code,\nwebpages, executable files, and deployment scripts—along with an AppSpec file.\nRevisions are stored in Amazon S3 buckets or GitHub repositories. For Amazon S3,\na revision is uniquely identified by its Amazon S3 object key and its ETag,\nversion, or both. For GitHub, a revision is uniquely identified by its commit\nID.\n\nThis guide also contains information to help you get details about the instances\nin your deployments, to make on-premises instances available for CodeDeploy\ndeployments, to get details about a Lambda function deployment, and to get\ndetails about Amazon ECS service deployments.","ref":"AWS.CodeDeploy.html#module-codedeploy-components","title":"CodeDeploy Components - AWS.CodeDeploy","type":"module"},{"doc":"* [CodeDeploy User Guide](https://docs.aws.amazon.com/codedeploy/latest/userguide)\n\n  * [CodeDeploy API Reference Guide](https://docs.aws.amazon.com/codedeploy/latest/APIReference/)\n\n  * [CLI Reference for CodeDeploy](https://docs.aws.amazon.com/cli/latest/reference/deploy/index.html)\n\n  * [CodeDeploy Developer Forum](https://forums.aws.amazon.com/forum.jspa?forumID=179)","ref":"AWS.CodeDeploy.html#module-codedeploy-information-resources","title":"CodeDeploy Information Resources - AWS.CodeDeploy","type":"module"},{"doc":"Adds tags to on-premises instances.","ref":"AWS.CodeDeploy.html#add_tags_to_on_premises_instances/3","title":"AWS.CodeDeploy.add_tags_to_on_premises_instances/3","type":"function"},{"doc":"Gets information about one or more application revisions.\n\nThe maximum number of application revisions that can be returned is 25.","ref":"AWS.CodeDeploy.html#batch_get_application_revisions/3","title":"AWS.CodeDeploy.batch_get_application_revisions/3","type":"function"},{"doc":"Gets information about one or more applications.\n\nThe maximum number of applications that can be returned is 100.","ref":"AWS.CodeDeploy.html#batch_get_applications/3","title":"AWS.CodeDeploy.batch_get_applications/3","type":"function"},{"doc":"Gets information about one or more deployment groups.","ref":"AWS.CodeDeploy.html#batch_get_deployment_groups/3","title":"AWS.CodeDeploy.batch_get_deployment_groups/3","type":"function"},{"doc":"This method works, but is deprecated.\n\nUse `BatchGetDeploymentTargets` instead.\n\nReturns an array of one or more instances associated with a deployment. This\nmethod works with EC2/On-premises and Lambda compute platforms. The newer\n`BatchGetDeploymentTargets` works with all compute platforms. The maximum number\nof instances that can be returned is 25.","ref":"AWS.CodeDeploy.html#batch_get_deployment_instances/3","title":"AWS.CodeDeploy.batch_get_deployment_instances/3","type":"function"},{"doc":"Returns an array of one or more targets associated with a deployment.\n\nThis method works with all compute types and should be used instead of the\ndeprecated `BatchGetDeploymentInstances`. The maximum number of targets that can\nbe returned is 25.\n\nThe type of targets returned depends on the deployment's compute platform or\ndeployment method:\n\n  * **EC2/On-premises**: Information about Amazon EC2 instance\ntargets.\n\n  * **Lambda**: Information about Lambda functions targets.\n\n  * **Amazon ECS**: Information about Amazon ECS service targets.\n\n  * **CloudFormation**: Information about targets of blue/green\ndeployments initiated by a CloudFormation stack update.","ref":"AWS.CodeDeploy.html#batch_get_deployment_targets/3","title":"AWS.CodeDeploy.batch_get_deployment_targets/3","type":"function"},{"doc":"Gets information about one or more deployments.\n\nThe maximum number of deployments that can be returned is 25.","ref":"AWS.CodeDeploy.html#batch_get_deployments/3","title":"AWS.CodeDeploy.batch_get_deployments/3","type":"function"},{"doc":"Gets information about one or more on-premises instances.\n\nThe maximum number of on-premises instances that can be returned is 25.","ref":"AWS.CodeDeploy.html#batch_get_on_premises_instances/3","title":"AWS.CodeDeploy.batch_get_on_premises_instances/3","type":"function"},{"doc":"For a blue/green deployment, starts the process of rerouting traffic from\ninstances in the original environment to instances in the replacement\nenvironment without waiting for a specified wait time to elapse.\n\n(Traffic rerouting, which is achieved by registering instances in the\nreplacement environment with the load balancer, can start as soon as all\ninstances have a status of Ready.)","ref":"AWS.CodeDeploy.html#continue_deployment/3","title":"AWS.CodeDeploy.continue_deployment/3","type":"function"},{"doc":"Creates an application.","ref":"AWS.CodeDeploy.html#create_application/3","title":"AWS.CodeDeploy.create_application/3","type":"function"},{"doc":"Deploys an application revision through the specified deployment group.","ref":"AWS.CodeDeploy.html#create_deployment/3","title":"AWS.CodeDeploy.create_deployment/3","type":"function"},{"doc":"Creates a deployment configuration.","ref":"AWS.CodeDeploy.html#create_deployment_config/3","title":"AWS.CodeDeploy.create_deployment_config/3","type":"function"},{"doc":"Creates a deployment group to which application revisions are deployed.","ref":"AWS.CodeDeploy.html#create_deployment_group/3","title":"AWS.CodeDeploy.create_deployment_group/3","type":"function"},{"doc":"Deletes an application.","ref":"AWS.CodeDeploy.html#delete_application/3","title":"AWS.CodeDeploy.delete_application/3","type":"function"},{"doc":"Deletes a deployment configuration.\n\nA deployment configuration cannot be deleted if it is currently in use.\nPredefined configurations cannot be deleted.","ref":"AWS.CodeDeploy.html#delete_deployment_config/3","title":"AWS.CodeDeploy.delete_deployment_config/3","type":"function"},{"doc":"Deletes a deployment group.","ref":"AWS.CodeDeploy.html#delete_deployment_group/3","title":"AWS.CodeDeploy.delete_deployment_group/3","type":"function"},{"doc":"Deletes a GitHub account connection.","ref":"AWS.CodeDeploy.html#delete_git_hub_account_token/3","title":"AWS.CodeDeploy.delete_git_hub_account_token/3","type":"function"},{"doc":"Deletes resources linked to an external ID.\n\nThis action only applies if you have configured blue/green deployments through\nCloudFormation.\n\nIt is not necessary to call this action directly. CloudFormation calls it on\nyour behalf when it needs to delete stack resources. This action is offered\npublicly in case you need to delete resources to comply with General Data\nProtection Regulation (GDPR) requirements.","ref":"AWS.CodeDeploy.html#delete_resources_by_external_id/3","title":"AWS.CodeDeploy.delete_resources_by_external_id/3","type":"function"},{"doc":"Deregisters an on-premises instance.","ref":"AWS.CodeDeploy.html#deregister_on_premises_instance/3","title":"AWS.CodeDeploy.deregister_on_premises_instance/3","type":"function"},{"doc":"Gets information about an application.","ref":"AWS.CodeDeploy.html#get_application/3","title":"AWS.CodeDeploy.get_application/3","type":"function"},{"doc":"Gets information about an application revision.","ref":"AWS.CodeDeploy.html#get_application_revision/3","title":"AWS.CodeDeploy.get_application_revision/3","type":"function"},{"doc":"Gets information about a deployment.\n\nThe `content` property of the `appSpecContent` object in the returned revision\nis always null. Use `GetApplicationRevision` and the `sha256` property of the\nreturned `appSpecContent` object to get the content of the deployment’s AppSpec\nfile.","ref":"AWS.CodeDeploy.html#get_deployment/3","title":"AWS.CodeDeploy.get_deployment/3","type":"function"},{"doc":"Gets information about a deployment configuration.","ref":"AWS.CodeDeploy.html#get_deployment_config/3","title":"AWS.CodeDeploy.get_deployment_config/3","type":"function"},{"doc":"Gets information about a deployment group.","ref":"AWS.CodeDeploy.html#get_deployment_group/3","title":"AWS.CodeDeploy.get_deployment_group/3","type":"function"},{"doc":"Gets information about an instance as part of a deployment.","ref":"AWS.CodeDeploy.html#get_deployment_instance/3","title":"AWS.CodeDeploy.get_deployment_instance/3","type":"function"},{"doc":"Returns information about a deployment target.","ref":"AWS.CodeDeploy.html#get_deployment_target/3","title":"AWS.CodeDeploy.get_deployment_target/3","type":"function"},{"doc":"Gets information about an on-premises instance.","ref":"AWS.CodeDeploy.html#get_on_premises_instance/3","title":"AWS.CodeDeploy.get_on_premises_instance/3","type":"function"},{"doc":"Lists information about revisions for an application.","ref":"AWS.CodeDeploy.html#list_application_revisions/3","title":"AWS.CodeDeploy.list_application_revisions/3","type":"function"},{"doc":"Lists the applications registered with the user or Amazon Web Services account.","ref":"AWS.CodeDeploy.html#list_applications/3","title":"AWS.CodeDeploy.list_applications/3","type":"function"},{"doc":"Lists the deployment configurations with the user or Amazon Web Services\naccount.","ref":"AWS.CodeDeploy.html#list_deployment_configs/3","title":"AWS.CodeDeploy.list_deployment_configs/3","type":"function"},{"doc":"Lists the deployment groups for an application registered with the Amazon Web\nServices user or Amazon Web Services account.","ref":"AWS.CodeDeploy.html#list_deployment_groups/3","title":"AWS.CodeDeploy.list_deployment_groups/3","type":"function"},{"doc":"The newer `BatchGetDeploymentTargets` should be used instead because it works\nwith all compute types.\n\n`ListDeploymentInstances` throws an exception if it is used with a compute\nplatform other than EC2/On-premises or Lambda.\n\nLists the instance for a deployment associated with the user or Amazon Web\nServices account.","ref":"AWS.CodeDeploy.html#list_deployment_instances/3","title":"AWS.CodeDeploy.list_deployment_instances/3","type":"function"},{"doc":"Returns an array of target IDs that are associated a deployment.","ref":"AWS.CodeDeploy.html#list_deployment_targets/3","title":"AWS.CodeDeploy.list_deployment_targets/3","type":"function"},{"doc":"Lists the deployments in a deployment group for an application registered with\nthe user or Amazon Web Services account.","ref":"AWS.CodeDeploy.html#list_deployments/3","title":"AWS.CodeDeploy.list_deployments/3","type":"function"},{"doc":"Lists the names of stored connections to GitHub accounts.","ref":"AWS.CodeDeploy.html#list_git_hub_account_token_names/3","title":"AWS.CodeDeploy.list_git_hub_account_token_names/3","type":"function"},{"doc":"Gets a list of names for one or more on-premises instances.\n\nUnless otherwise specified, both registered and deregistered on-premises\ninstance names are listed. To list only registered or deregistered on-premises\ninstance names, use the registration status parameter.","ref":"AWS.CodeDeploy.html#list_on_premises_instances/3","title":"AWS.CodeDeploy.list_on_premises_instances/3","type":"function"},{"doc":"Returns a list of tags for the resource identified by a specified Amazon\nResource Name (ARN).\n\nTags are used to organize and categorize your CodeDeploy resources.","ref":"AWS.CodeDeploy.html#list_tags_for_resource/3","title":"AWS.CodeDeploy.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.CodeDeploy.html#metadata/0","title":"AWS.CodeDeploy.metadata/0","type":"function"},{"doc":"Sets the result of a Lambda validation function.\n\nThe function validates lifecycle hooks during a deployment that uses the Lambda\nor Amazon ECS compute platform. For Lambda deployments, the available lifecycle\nhooks are `BeforeAllowTraffic` and `AfterAllowTraffic`. For Amazon ECS\ndeployments, the available lifecycle hooks are `BeforeInstall`, `AfterInstall`,\n`AfterAllowTestTraffic`, `BeforeAllowTraffic`, and `AfterAllowTraffic`. Lambda\nvalidation functions return `Succeeded` or `Failed`. For more information, see\n[AppSpec 'hooks' Section for an Lambda Deployment\n](https://docs.aws.amazon.com/codedeploy/latest/userguide/reference-appspec-file-structure-hooks.html#appspec-hooks-lambda)\nand [AppSpec 'hooks' Section for an Amazon ECS Deployment](https://docs.aws.amazon.com/codedeploy/latest/userguide/reference-appspec-file-structure-hooks.html#appspec-hooks-ecs).","ref":"AWS.CodeDeploy.html#put_lifecycle_event_hook_execution_status/3","title":"AWS.CodeDeploy.put_lifecycle_event_hook_execution_status/3","type":"function"},{"doc":"Registers with CodeDeploy a revision for the specified application.","ref":"AWS.CodeDeploy.html#register_application_revision/3","title":"AWS.CodeDeploy.register_application_revision/3","type":"function"},{"doc":"Registers an on-premises instance.\n\nOnly one IAM ARN (an IAM session ARN or IAM user ARN) is supported in the\nrequest. You cannot use both.","ref":"AWS.CodeDeploy.html#register_on_premises_instance/3","title":"AWS.CodeDeploy.register_on_premises_instance/3","type":"function"},{"doc":"Removes one or more tags from one or more on-premises instances.","ref":"AWS.CodeDeploy.html#remove_tags_from_on_premises_instances/3","title":"AWS.CodeDeploy.remove_tags_from_on_premises_instances/3","type":"function"},{"doc":"In a blue/green deployment, overrides any specified wait time and starts\nterminating instances immediately after the traffic routing is complete.","ref":"AWS.CodeDeploy.html#skip_wait_time_for_instance_termination/3","title":"AWS.CodeDeploy.skip_wait_time_for_instance_termination/3","type":"function"},{"doc":"Attempts to stop an ongoing deployment.","ref":"AWS.CodeDeploy.html#stop_deployment/3","title":"AWS.CodeDeploy.stop_deployment/3","type":"function"},{"doc":"Associates the list of tags in the input `Tags` parameter with the resource\nidentified by the `ResourceArn` input parameter.","ref":"AWS.CodeDeploy.html#tag_resource/3","title":"AWS.CodeDeploy.tag_resource/3","type":"function"},{"doc":"Disassociates a resource from a list of tags.\n\nThe resource is identified by the `ResourceArn` input parameter. The tags are\nidentified by the list of keys in the `TagKeys` input parameter.","ref":"AWS.CodeDeploy.html#untag_resource/3","title":"AWS.CodeDeploy.untag_resource/3","type":"function"},{"doc":"Changes the name of an application.","ref":"AWS.CodeDeploy.html#update_application/3","title":"AWS.CodeDeploy.update_application/3","type":"function"},{"doc":"Changes information about a deployment group.","ref":"AWS.CodeDeploy.html#update_deployment_group/3","title":"AWS.CodeDeploy.update_deployment_group/3","type":"function"},{"doc":"This section provides documentation for the Amazon CodeGuru Profiler API\noperations.\n\nAmazon CodeGuru Profiler collects runtime performance data from your live\napplications, and provides recommendations that can help you fine-tune your\napplication performance. Using machine learning algorithms, CodeGuru Profiler\ncan help you find your most expensive lines of code and suggest ways you can\nimprove efficiency and remove CPU bottlenecks.\n\nAmazon CodeGuru Profiler provides different visualizations of profiling data to\nhelp you identify what code is running on the CPU, see how much time is\nconsumed, and suggest ways to reduce CPU utilization.\n\nAmazon CodeGuru Profiler currently supports applications written in all Java\nvirtual machine (JVM) languages and Python. While CodeGuru Profiler supports\nboth visualizations and recommendations for applications written in Java, it can\nalso generate visualizations and a subset of recommendations for applications\nwritten in other JVM languages and Python.\n\nFor more information, see [What is Amazon CodeGuru Profiler](https://docs.aws.amazon.com/codeguru/latest/profiler-ug/what-is-codeguru-profiler.html)\nin the *Amazon CodeGuru Profiler User Guide*.","ref":"AWS.CodeGuruProfiler.html","title":"AWS.CodeGuruProfiler","type":"module"},{"doc":"Add up to 2 anomaly notifications channels for a profiling group.","ref":"AWS.CodeGuruProfiler.html#add_notification_channels/4","title":"AWS.CodeGuruProfiler.add_notification_channels/4","type":"function"},{"doc":"Returns the time series of values for a requested list of frame metrics from a\ntime period.","ref":"AWS.CodeGuruProfiler.html#batch_get_frame_metric_data/4","title":"AWS.CodeGuruProfiler.batch_get_frame_metric_data/4","type":"function"},{"doc":"Used by profiler agents to report their current state and to receive remote\nconfiguration updates.\n\nFor example, `ConfigureAgent` can be used to tell an agent whether to profile or\nnot and for how long to return profiling data.","ref":"AWS.CodeGuruProfiler.html#configure_agent/4","title":"AWS.CodeGuruProfiler.configure_agent/4","type":"function"},{"doc":"Creates a profiling group.","ref":"AWS.CodeGuruProfiler.html#create_profiling_group/3","title":"AWS.CodeGuruProfiler.create_profiling_group/3","type":"function"},{"doc":"Deletes a profiling group.","ref":"AWS.CodeGuruProfiler.html#delete_profiling_group/4","title":"AWS.CodeGuruProfiler.delete_profiling_group/4","type":"function"},{"doc":"Returns a [ `ProfilingGroupDescription`\n](https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_ProfilingGroupDescription.html)\nobject that contains information about the requested profiling group.","ref":"AWS.CodeGuruProfiler.html#describe_profiling_group/3","title":"AWS.CodeGuruProfiler.describe_profiling_group/3","type":"function"},{"doc":"Returns a list of [ `FindingsReportSummary`\n](https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_FindingsReportSummary.html)\nobjects that contain analysis results for all profiling groups in your AWS\naccount.","ref":"AWS.CodeGuruProfiler.html#get_findings_report_account_summary/5","title":"AWS.CodeGuruProfiler.get_findings_report_account_summary/5","type":"function"},{"doc":"Get the current configuration for anomaly notifications for a profiling group.","ref":"AWS.CodeGuruProfiler.html#get_notification_configuration/3","title":"AWS.CodeGuruProfiler.get_notification_configuration/3","type":"function"},{"doc":"Returns the JSON-formatted resource-based policy on a profiling group.","ref":"AWS.CodeGuruProfiler.html#get_policy/3","title":"AWS.CodeGuruProfiler.get_policy/3","type":"function"},{"doc":"Gets the aggregated profile of a profiling group for a specified time range.\n\nAmazon CodeGuru Profiler collects posted agent profiles for a profiling group\ninto aggregated profiles.\n\n` Because aggregated profiles expire over time `GetProfile` is not idempotent.\n\nSpecify the time range for the requested aggregated profile using 1 or 2 of the\nfollowing parameters: `startTime`, `endTime`, `period`. The maximum time range\nallowed is 7 days. If you specify all 3 parameters, an exception is thrown. If\nyou specify only `period`, the latest aggregated profile is returned.\n\nAggregated profiles are available with aggregation periods of 5 minutes, 1 hour,\nand 1 day, aligned to UTC. The aggregation period of an aggregated profile\ndetermines how long it is retained. For more information, see [\n`AggregatedProfileTime`\n](https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_AggregatedProfileTime.html).\nThe aggregated profile's aggregation period determines how long it is retained\nby CodeGuru Profiler.\n\n  * If the aggregation period is 5 minutes, the aggregated profile is\nretained for 15 days.\n\n  * If the aggregation period is 1 hour, the aggregated profile is\nretained for 60 days.\n\n  * If the aggregation period is 1 day, the aggregated profile is\nretained for 3 years.\n\nThere are two use cases for calling `GetProfile`.\n\n  1. If you want to return an aggregated profile that already exists,\nuse [ `ListProfileTimes`\n](https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_ListProfileTimes.html)\nto view the time ranges of existing aggregated profiles. Use them in a\n`GetProfile` request to return a specific, existing aggregated profile.\n\n  2. If you want to return an aggregated profile for a time range that\ndoesn't align with an existing aggregated profile, then CodeGuru Profiler makes\na best effort to combine existing aggregated profiles from the requested time\nrange and return them as one aggregated profile.\n\nIf aggregated profiles do not exist for the full time range requested, then\naggregated profiles for a smaller time range are returned. For example, if the\nrequested time range is from 00:00 to 00:20, and the existing aggregated\nprofiles are from 00:15 and 00:25, then the aggregated profiles from 00:15 to\n00:20 are returned.\n\n`","ref":"AWS.CodeGuruProfiler.html#get_profile/8","title":"AWS.CodeGuruProfiler.get_profile/8","type":"function"},{"doc":"Returns a list of [ `Recommendation`\n](https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_Recommendation.html)\nobjects that contain recommendations for a profiling group for a given time\nperiod.\n\nA list of [ `Anomaly`\n](https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_Anomaly.html)\nobjects that contains details about anomalies detected in the profiling group\nfor the same time period is also returned.","ref":"AWS.CodeGuruProfiler.html#get_recommendations/6","title":"AWS.CodeGuruProfiler.get_recommendations/6","type":"function"},{"doc":"List the available reports for a given profiling group and time range.","ref":"AWS.CodeGuruProfiler.html#list_findings_reports/8","title":"AWS.CodeGuruProfiler.list_findings_reports/8","type":"function"},{"doc":"Lists the start times of the available aggregated profiles of a profiling group\nfor an aggregation period within the specified time range.","ref":"AWS.CodeGuruProfiler.html#list_profile_times/9","title":"AWS.CodeGuruProfiler.list_profile_times/9","type":"function"},{"doc":"Returns a list of profiling groups.\n\nThe profiling groups are returned as [ `ProfilingGroupDescription`\n](https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_ProfilingGroupDescription.html)\nobjects.","ref":"AWS.CodeGuruProfiler.html#list_profiling_groups/5","title":"AWS.CodeGuruProfiler.list_profiling_groups/5","type":"function"},{"doc":"Returns a list of the tags that are assigned to a specified resource.","ref":"AWS.CodeGuruProfiler.html#list_tags_for_resource/3","title":"AWS.CodeGuruProfiler.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.CodeGuruProfiler.html#metadata/0","title":"AWS.CodeGuruProfiler.metadata/0","type":"function"},{"doc":"Submits profiling data to an aggregated profile of a profiling group.\n\nTo get an aggregated profile that is created with this profiling data, use [\n`GetProfile`\n](https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_GetProfile.html).","ref":"AWS.CodeGuruProfiler.html#post_agent_profile/4","title":"AWS.CodeGuruProfiler.post_agent_profile/4","type":"function"},{"doc":"Adds permissions to a profiling group's resource-based policy that are provided\nusing an action group.\n\nIf a profiling group doesn't have a resource-based policy, one is created for it\nusing the permissions in the action group and the roles and users in the\n`principals` parameter.\n\n` The one supported action group that can be added is `agentPermission` which\ngrants `ConfigureAgent` and `PostAgent` permissions. For more information, see\n[Resource-based policies in CodeGuru Profiler](https://docs.aws.amazon.com/codeguru/latest/profiler-ug/resource-based-policies.html)\nin the *Amazon CodeGuru Profiler User Guide*, [ `ConfigureAgent`\n](https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_ConfigureAgent.html),\nand [ `PostAgentProfile`\n](https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_PostAgentProfile.html).\n\nThe first time you call `PutPermission` on a profiling group, do not specify a\n`revisionId` because it doesn't have a resource-based policy. Subsequent calls\nmust provide a `revisionId` to specify which revision of the resource-based\npolicy to add the permissions to.\n\nThe response contains the profiling group's JSON-formatted resource policy.\n\n`","ref":"AWS.CodeGuruProfiler.html#put_permission/5","title":"AWS.CodeGuruProfiler.put_permission/5","type":"function"},{"doc":"Remove one anomaly notifications channel for a profiling group.","ref":"AWS.CodeGuruProfiler.html#remove_notification_channel/5","title":"AWS.CodeGuruProfiler.remove_notification_channel/5","type":"function"},{"doc":"Removes permissions from a profiling group's resource-based policy that are\nprovided using an action group.\n\nThe one supported action group that can be removed is `agentPermission` which\ngrants `ConfigureAgent` and `PostAgent` permissions. For more information, see\n[Resource-based policies in CodeGuru Profiler](https://docs.aws.amazon.com/codeguru/latest/profiler-ug/resource-based-policies.html)\nin the *Amazon CodeGuru Profiler User Guide*, [ `ConfigureAgent`\n](https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_ConfigureAgent.html),\nand [ `PostAgentProfile`\n](https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_PostAgentProfile.html).","ref":"AWS.CodeGuruProfiler.html#remove_permission/5","title":"AWS.CodeGuruProfiler.remove_permission/5","type":"function"},{"doc":"Sends feedback to CodeGuru Profiler about whether the anomaly detected by the\nanalysis is useful or not.","ref":"AWS.CodeGuruProfiler.html#submit_feedback/5","title":"AWS.CodeGuruProfiler.submit_feedback/5","type":"function"},{"doc":"Use to assign one or more tags to a resource.","ref":"AWS.CodeGuruProfiler.html#tag_resource/4","title":"AWS.CodeGuruProfiler.tag_resource/4","type":"function"},{"doc":"Use to remove one or more tags from a resource.","ref":"AWS.CodeGuruProfiler.html#untag_resource/4","title":"AWS.CodeGuruProfiler.untag_resource/4","type":"function"},{"doc":"Updates a profiling group.","ref":"AWS.CodeGuruProfiler.html#update_profiling_group/4","title":"AWS.CodeGuruProfiler.update_profiling_group/4","type":"function"},{"doc":"This section provides documentation for the Amazon CodeGuru Reviewer API\noperations.\n\nCodeGuru Reviewer is a service that uses program analysis and machine learning\nto detect potential defects that are difficult for developers to find and\nrecommends fixes in your Java and Python code.\n\nBy proactively detecting and providing recommendations for addressing code\ndefects and implementing best practices, CodeGuru Reviewer improves the overall\nquality and maintainability of your code base during the code review stage. For\nmore information about CodeGuru Reviewer, see the * [Amazon CodeGuru Reviewer User\nGuide](https://docs.aws.amazon.com/codeguru/latest/reviewer-ug/welcome.html).*\n\nTo improve the security of your CodeGuru Reviewer API calls, you can establish a\nprivate connection between your VPC and CodeGuru Reviewer by creating an\n*interface VPC endpoint*. For more information, see [CodeGuru Reviewer and interface VPC endpoints (Amazon Web Services\nPrivateLink)](https://docs.aws.amazon.com/codeguru/latest/reviewer-ug/vpc-interface-endpoints.html)\nin the *Amazon CodeGuru Reviewer User Guide*.","ref":"AWS.CodeGuruReviewer.html","title":"AWS.CodeGuruReviewer","type":"module"},{"doc":"Use to associate an Amazon Web Services CodeCommit repository or a repository\nmanaged by Amazon Web Services CodeStar Connections with Amazon CodeGuru\nReviewer.\n\nWhen you associate a repository, CodeGuru Reviewer reviews source code changes\nin the repository's pull requests and provides automatic recommendations. You\ncan view recommendations using the CodeGuru Reviewer console. For more\ninformation, see [Recommendations in Amazon CodeGuru Reviewer](https://docs.aws.amazon.com/codeguru/latest/reviewer-ug/recommendations.html)\nin the *Amazon CodeGuru Reviewer User Guide.*\n\nIf you associate a CodeCommit or S3 repository, it must be in the same Amazon\nWeb Services Region and Amazon Web Services account where its CodeGuru Reviewer\ncode reviews are configured.\n\nBitbucket and GitHub Enterprise Server repositories are managed by Amazon Web\nServices CodeStar Connections to connect to CodeGuru Reviewer. For more\ninformation, see [Associate a repository](https://docs.aws.amazon.com/codeguru/latest/reviewer-ug/getting-started-associate-repository.html)\nin the *Amazon CodeGuru Reviewer User Guide.*\n\nYou cannot use the CodeGuru Reviewer SDK or the Amazon Web Services CLI to\nassociate a GitHub repository with Amazon CodeGuru Reviewer. To associate a\nGitHub repository, use the console. For more information, see [Getting started with CodeGuru\nReviewer](https://docs.aws.amazon.com/codeguru/latest/reviewer-ug/getting-started-with-guru.html)\nin the *CodeGuru Reviewer User Guide.*","ref":"AWS.CodeGuruReviewer.html#associate_repository/3","title":"AWS.CodeGuruReviewer.associate_repository/3","type":"function"},{"doc":"Use to create a code review with a\n[CodeReviewType](https://docs.aws.amazon.com/codeguru/latest/reviewer-api/API_CodeReviewType.html)\nof `RepositoryAnalysis`.\n\nThis type of code review analyzes all code under a specified branch in an\nassociated repository. `PullRequest` code reviews are automatically triggered by\na pull request.","ref":"AWS.CodeGuruReviewer.html#create_code_review/3","title":"AWS.CodeGuruReviewer.create_code_review/3","type":"function"},{"doc":"Returns the metadata associated with the code review along with its status.","ref":"AWS.CodeGuruReviewer.html#describe_code_review/3","title":"AWS.CodeGuruReviewer.describe_code_review/3","type":"function"},{"doc":"Describes the customer feedback for a CodeGuru Reviewer recommendation.","ref":"AWS.CodeGuruReviewer.html#describe_recommendation_feedback/5","title":"AWS.CodeGuruReviewer.describe_recommendation_feedback/5","type":"function"},{"doc":"Returns a\n[RepositoryAssociation](https://docs.aws.amazon.com/codeguru/latest/reviewer-api/API_RepositoryAssociation.html)\nobject that contains information about the requested repository association.","ref":"AWS.CodeGuruReviewer.html#describe_repository_association/3","title":"AWS.CodeGuruReviewer.describe_repository_association/3","type":"function"},{"doc":"Removes the association between Amazon CodeGuru Reviewer and a repository.","ref":"AWS.CodeGuruReviewer.html#disassociate_repository/4","title":"AWS.CodeGuruReviewer.disassociate_repository/4","type":"function"},{"doc":"Lists all the code reviews that the customer has created in the past 90 days.","ref":"AWS.CodeGuruReviewer.html#list_code_reviews/8","title":"AWS.CodeGuruReviewer.list_code_reviews/8","type":"function"},{"doc":"Returns a list of\n[RecommendationFeedbackSummary](https://docs.aws.amazon.com/codeguru/latest/reviewer-api/API_RecommendationFeedbackSummary.html)\nobjects that contain customer recommendation feedback for all CodeGuru Reviewer\nusers.","ref":"AWS.CodeGuruReviewer.html#list_recommendation_feedback/7","title":"AWS.CodeGuruReviewer.list_recommendation_feedback/7","type":"function"},{"doc":"Returns the list of all recommendations for a completed code review.","ref":"AWS.CodeGuruReviewer.html#list_recommendations/5","title":"AWS.CodeGuruReviewer.list_recommendations/5","type":"function"},{"doc":"Returns a list of\n[RepositoryAssociationSummary](https://docs.aws.amazon.com/codeguru/latest/reviewer-api/API_RepositoryAssociationSummary.html) objects that contain summary information about a repository association.\n\nYou can filter the returned list by\n[ProviderType](https://docs.aws.amazon.com/codeguru/latest/reviewer-api/API_RepositoryAssociationSummary.html#reviewer-Type-RepositoryAssociationSummary-ProviderType),\n[Name](https://docs.aws.amazon.com/codeguru/latest/reviewer-api/API_RepositoryAssociationSummary.html#reviewer-Type-RepositoryAssociationSummary-Name), [State](https://docs.aws.amazon.com/codeguru/latest/reviewer-api/API_RepositoryAssociationSummary.html#reviewer-Type-RepositoryAssociationSummary-State),\nand\n[Owner](https://docs.aws.amazon.com/codeguru/latest/reviewer-api/API_RepositoryAssociationSummary.html#reviewer-Type-RepositoryAssociationSummary-Owner).","ref":"AWS.CodeGuruReviewer.html#list_repository_associations/8","title":"AWS.CodeGuruReviewer.list_repository_associations/8","type":"function"},{"doc":"Returns the list of tags associated with an associated repository resource.","ref":"AWS.CodeGuruReviewer.html#list_tags_for_resource/3","title":"AWS.CodeGuruReviewer.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.CodeGuruReviewer.html#metadata/0","title":"AWS.CodeGuruReviewer.metadata/0","type":"function"},{"doc":"Stores customer feedback for a CodeGuru Reviewer recommendation.\n\nWhen this API is called again with different reactions the previous feedback is\noverwritten.","ref":"AWS.CodeGuruReviewer.html#put_recommendation_feedback/3","title":"AWS.CodeGuruReviewer.put_recommendation_feedback/3","type":"function"},{"doc":"Adds one or more tags to an associated repository.","ref":"AWS.CodeGuruReviewer.html#tag_resource/4","title":"AWS.CodeGuruReviewer.tag_resource/4","type":"function"},{"doc":"Removes a tag from an associated repository.","ref":"AWS.CodeGuruReviewer.html#untag_resource/4","title":"AWS.CodeGuruReviewer.untag_resource/4","type":"function"},{"doc":"Amazon CodeGuru Security is in preview release and is subject to change.\n\nThis section provides documentation for the Amazon CodeGuru Security API\noperations. CodeGuru Security is a service that uses program analysis and\nmachine learning to detect security policy violations and vulnerabilities, and\nrecommends ways to address these security risks.\n\nBy proactively detecting and providing recommendations for addressing security\nrisks, CodeGuru Security improves the overall security of your application code.\nFor more information about CodeGuru Security, see the [Amazon CodeGuru Security User\nGuide](https://docs.aws.amazon.com/codeguru/latest/security-ug/what-is-codeguru-security.html).","ref":"AWS.CodeGuruSecurity.html","title":"AWS.CodeGuruSecurity","type":"module"},{"doc":"Returns a list of all requested findings.","ref":"AWS.CodeGuruSecurity.html#batch_get_findings/3","title":"AWS.CodeGuruSecurity.batch_get_findings/3","type":"function"},{"doc":"Use to create a scan using code uploaded to an S3 bucket.","ref":"AWS.CodeGuruSecurity.html#create_scan/3","title":"AWS.CodeGuruSecurity.create_scan/3","type":"function"},{"doc":"Generates a pre-signed URL and request headers used to upload a code resource.\n\nYou can upload your code resource to the URL and add the request headers using\nany HTTP client.","ref":"AWS.CodeGuruSecurity.html#create_upload_url/3","title":"AWS.CodeGuruSecurity.create_upload_url/3","type":"function"},{"doc":"Use to get account level configuration.","ref":"AWS.CodeGuruSecurity.html#get_account_configuration/2","title":"AWS.CodeGuruSecurity.get_account_configuration/2","type":"function"},{"doc":"Returns a list of all findings generated by a particular scan.","ref":"AWS.CodeGuruSecurity.html#get_findings/6","title":"AWS.CodeGuruSecurity.get_findings/6","type":"function"},{"doc":"Returns top level metrics about an account from a specified date, including\nnumber of open findings, the categories with most findings, the scans with most\nopen findings, and scans with most open critical findings.","ref":"AWS.CodeGuruSecurity.html#get_metrics_summary/3","title":"AWS.CodeGuruSecurity.get_metrics_summary/3","type":"function"},{"doc":"Returns details about a scan, including whether or not a scan has completed.","ref":"AWS.CodeGuruSecurity.html#get_scan/4","title":"AWS.CodeGuruSecurity.get_scan/4","type":"function"},{"doc":"Returns metrics about all findings in an account within a specified time range.","ref":"AWS.CodeGuruSecurity.html#list_findings_metrics/6","title":"AWS.CodeGuruSecurity.list_findings_metrics/6","type":"function"},{"doc":"Returns a list of all the standard scans in an account.\n\nDoes not return express scans.","ref":"AWS.CodeGuruSecurity.html#list_scans/4","title":"AWS.CodeGuruSecurity.list_scans/4","type":"function"},{"doc":"Returns a list of all tags associated with a scan.","ref":"AWS.CodeGuruSecurity.html#list_tags_for_resource/3","title":"AWS.CodeGuruSecurity.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.CodeGuruSecurity.html#metadata/0","title":"AWS.CodeGuruSecurity.metadata/0","type":"function"},{"doc":"Use to add one or more tags to an existing scan.","ref":"AWS.CodeGuruSecurity.html#tag_resource/4","title":"AWS.CodeGuruSecurity.tag_resource/4","type":"function"},{"doc":"Use to remove one or more tags from an existing scan.","ref":"AWS.CodeGuruSecurity.html#untag_resource/4","title":"AWS.CodeGuruSecurity.untag_resource/4","type":"function"},{"doc":"Use to update account-level configuration with an encryption key.","ref":"AWS.CodeGuruSecurity.html#update_account_configuration/3","title":"AWS.CodeGuruSecurity.update_account_configuration/3","type":"function"},{"doc":"CodePipeline","ref":"AWS.CodePipeline.html","title":"AWS.CodePipeline","type":"module"},{"doc":"This is the CodePipeline API Reference.\n\nThis guide provides descriptions of the actions and data types for CodePipeline.\nSome functionality for your pipeline can only be configured through the API. For\nmore information, see the [CodePipeline User Guide](https://docs.aws.amazon.com/codepipeline/latest/userguide/welcome.html).\n\nYou can use the CodePipeline API to work with pipelines, stages, actions, and\ntransitions.\n\n*Pipelines* are models of automated release processes. Each pipeline is uniquely\nnamed, and consists of stages, actions, and transitions.\n\nYou can work with pipelines by calling:\n\n  * `CreatePipeline`, which creates a uniquely named pipeline.\n\n  * `DeletePipeline`, which deletes the specified pipeline.\n\n  * `GetPipeline`, which returns information about the pipeline\nstructure and pipeline metadata, including the pipeline Amazon Resource Name\n(ARN).\n\n  * `GetPipelineExecution`, which returns information about a specific\nexecution of a pipeline.\n\n  * `GetPipelineState`, which returns information about the current\nstate of the stages and actions of a pipeline.\n\n  * `ListActionExecutions`, which returns action-level details for\npast executions. The details include full stage and action-level details,\nincluding individual action duration, status, any errors that occurred during\nthe execution, and input and output artifact location details.\n\n  * `ListPipelines`, which gets a summary of all of the pipelines\nassociated with your account.\n\n  * `ListPipelineExecutions`, which gets a summary of the most recent\nexecutions for a pipeline.\n\n  * `StartPipelineExecution`, which runs the most recent revision of\nan artifact through the pipeline.\n\n  * `StopPipelineExecution`, which stops the specified pipeline\nexecution from continuing through the pipeline.\n\n  * `UpdatePipeline`, which updates a pipeline with edits or changes\nto the structure of the pipeline.\n\nPipelines include *stages*. Each stage contains one or more actions that must\ncomplete before the next stage begins. A stage results in success or failure. If\na stage fails, the pipeline stops at that stage and remains stopped until either\na new version of an artifact appears in the source location, or a user takes\naction to rerun the most recent artifact through the pipeline. You can call\n`GetPipelineState`, which displays the status of a pipeline, including the\nstatus of stages in the pipeline, or `GetPipeline`, which returns the entire\nstructure of the pipeline, including the stages of that pipeline. For more\ninformation about the structure of stages and actions, see [CodePipeline Pipeline Structure\nReference](https://docs.aws.amazon.com/codepipeline/latest/userguide/pipeline-structure.html).\n\nPipeline stages include *actions* that are categorized into categories such as\nsource or build actions performed in a stage of a pipeline. For example, you can\nuse a source action to import artifacts into a pipeline from a source such as\nAmazon S3. Like stages, you do not work with actions directly in most cases, but\nyou do define and interact with actions when working with pipeline operations\nsuch as `CreatePipeline` and `GetPipelineState`. Valid action categories are:\n\n  * Source\n\n  * Build\n\n  * Test\n\n  * Deploy\n\n  * Approval\n\n  * Invoke\n\nPipelines also include *transitions*, which allow the transition of artifacts\nfrom one stage to the next in a pipeline after the actions in one stage\ncomplete.\n\nYou can work with transitions by calling:\n\n  * `DisableStageTransition`, which prevents artifacts from\ntransitioning to the next stage in a pipeline.\n\n  * `EnableStageTransition`, which enables transition of artifacts\nbetween stages in a pipeline.","ref":"AWS.CodePipeline.html#module-overview","title":"Overview - AWS.CodePipeline","type":"module"},{"doc":"For third-party integrators or developers who want to create their own\nintegrations with CodePipeline, the expected sequence varies from the standard\nAPI user. To integrate with CodePipeline, developers need to work with the\nfollowing items:\n\n**Jobs**, which are instances of an action. For example, a job for a source\naction might import a revision of an artifact from a source.\n\nYou can work with jobs by calling:\n\n  * `AcknowledgeJob`, which confirms whether a job worker has received\nthe specified job.\n\n  * `GetJobDetails`, which returns the details of a job.\n\n  * `PollForJobs`, which determines whether there are any jobs to act\non.\n\n  * `PutJobFailureResult`, which provides details of a job failure.\n\n  * `PutJobSuccessResult`, which provides details of a job success.\n\n**Third party jobs**, which are instances of an action created by a partner\naction and integrated into CodePipeline. Partner actions are created by members\nof the Amazon Web Services Partner Network.\n\nYou can work with third party jobs by calling:\n\n  * `AcknowledgeThirdPartyJob`, which confirms whether a job worker\nhas received the specified job.\n\n  * `GetThirdPartyJobDetails`, which requests the details of a job for\na partner action.\n\n  * `PollForThirdPartyJobs`, which determines whether there are any\njobs to act on.\n\n  * `PutThirdPartyJobFailureResult`, which provides details of a job\nfailure.\n\n  * `PutThirdPartyJobSuccessResult`, which provides details of a job\nsuccess.","ref":"AWS.CodePipeline.html#module-using-the-api-to-integrate-with-codepipeline","title":"Using the API to integrate with CodePipeline - AWS.CodePipeline","type":"module"},{"doc":"Returns information about a specified job and whether that job has been received\nby the job worker.\n\nUsed for custom actions only.","ref":"AWS.CodePipeline.html#acknowledge_job/3","title":"AWS.CodePipeline.acknowledge_job/3","type":"function"},{"doc":"Confirms a job worker has received the specified job.\n\nUsed for partner actions only.","ref":"AWS.CodePipeline.html#acknowledge_third_party_job/3","title":"AWS.CodePipeline.acknowledge_third_party_job/3","type":"function"},{"doc":"Creates a new custom action that can be used in all pipelines associated with\nthe Amazon Web Services account.\n\nOnly used for custom actions.","ref":"AWS.CodePipeline.html#create_custom_action_type/3","title":"AWS.CodePipeline.create_custom_action_type/3","type":"function"},{"doc":"Creates a pipeline.\n\nIn the pipeline structure, you must include either `artifactStore` or\n`artifactStores` in your pipeline, but you cannot use both. If you create a\ncross-region action in your pipeline, you must use `artifactStores`.","ref":"AWS.CodePipeline.html#create_pipeline/3","title":"AWS.CodePipeline.create_pipeline/3","type":"function"},{"doc":"Marks a custom action as deleted.\n\n`PollForJobs` for the custom action fails after the action is marked for\ndeletion. Used for custom actions only.\n\nTo re-create a custom action after it has been deleted you must use a string in\nthe version field that has never been used before. This string can be an\nincremented version number, for example. To restore a deleted custom action, use\na JSON file that is identical to the deleted action, including the original\nstring in the version field.","ref":"AWS.CodePipeline.html#delete_custom_action_type/3","title":"AWS.CodePipeline.delete_custom_action_type/3","type":"function"},{"doc":"Deletes the specified pipeline.","ref":"AWS.CodePipeline.html#delete_pipeline/3","title":"AWS.CodePipeline.delete_pipeline/3","type":"function"},{"doc":"Deletes a previously created webhook by name.\n\nDeleting the webhook stops CodePipeline from starting a pipeline every time an\nexternal event occurs. The API returns successfully when trying to delete a\nwebhook that is already deleted. If a deleted webhook is re-created by calling\nPutWebhook with the same name, it will have a different URL.","ref":"AWS.CodePipeline.html#delete_webhook/3","title":"AWS.CodePipeline.delete_webhook/3","type":"function"},{"doc":"Removes the connection between the webhook that was created by CodePipeline and\nthe external tool with events to be detected.\n\nCurrently supported only for webhooks that target an action type of GitHub.","ref":"AWS.CodePipeline.html#deregister_webhook_with_third_party/3","title":"AWS.CodePipeline.deregister_webhook_with_third_party/3","type":"function"},{"doc":"Prevents artifacts in a pipeline from transitioning to the next stage in the\npipeline.","ref":"AWS.CodePipeline.html#disable_stage_transition/3","title":"AWS.CodePipeline.disable_stage_transition/3","type":"function"},{"doc":"Enables artifacts in a pipeline to transition to a stage in a pipeline.","ref":"AWS.CodePipeline.html#enable_stage_transition/3","title":"AWS.CodePipeline.enable_stage_transition/3","type":"function"},{"doc":"Returns information about an action type created for an external provider, where\nthe action is to be used by customers of the external provider.\n\nThe action can be created with any supported integration model.","ref":"AWS.CodePipeline.html#get_action_type/3","title":"AWS.CodePipeline.get_action_type/3","type":"function"},{"doc":"Returns information about a job.\n\nUsed for custom actions only.\n\nWhen this API is called, CodePipeline returns temporary credentials for the S3\nbucket used to store artifacts for the pipeline, if the action requires access\nto that S3 bucket for input or output artifacts. This API also returns any\nsecret values defined for the action.","ref":"AWS.CodePipeline.html#get_job_details/3","title":"AWS.CodePipeline.get_job_details/3","type":"function"},{"doc":"Returns the metadata, structure, stages, and actions of a pipeline.\n\nCan be used to return the entire structure of a pipeline in JSON format, which\ncan then be modified and used to update the pipeline structure with\n`UpdatePipeline`.","ref":"AWS.CodePipeline.html#get_pipeline/3","title":"AWS.CodePipeline.get_pipeline/3","type":"function"},{"doc":"Returns information about an execution of a pipeline, including details about\nartifacts, the pipeline execution ID, and the name, version, and status of the\npipeline.","ref":"AWS.CodePipeline.html#get_pipeline_execution/3","title":"AWS.CodePipeline.get_pipeline_execution/3","type":"function"},{"doc":"Returns information about the state of a pipeline, including the stages and\nactions.\n\nValues returned in the `revisionId` and `revisionUrl` fields indicate the source\nrevision information, such as the commit ID, for the current state.","ref":"AWS.CodePipeline.html#get_pipeline_state/3","title":"AWS.CodePipeline.get_pipeline_state/3","type":"function"},{"doc":"Requests the details of a job for a third party action.\n\nUsed for partner actions only.\n\nWhen this API is called, CodePipeline returns temporary credentials for the S3\nbucket used to store artifacts for the pipeline, if the action requires access\nto that S3 bucket for input or output artifacts. This API also returns any\nsecret values defined for the action.","ref":"AWS.CodePipeline.html#get_third_party_job_details/3","title":"AWS.CodePipeline.get_third_party_job_details/3","type":"function"},{"doc":"Lists the action executions that have occurred in a pipeline.","ref":"AWS.CodePipeline.html#list_action_executions/3","title":"AWS.CodePipeline.list_action_executions/3","type":"function"},{"doc":"Gets a summary of all CodePipeline action types associated with your account.","ref":"AWS.CodePipeline.html#list_action_types/3","title":"AWS.CodePipeline.list_action_types/3","type":"function"},{"doc":"Gets a summary of the most recent executions for a pipeline.","ref":"AWS.CodePipeline.html#list_pipeline_executions/3","title":"AWS.CodePipeline.list_pipeline_executions/3","type":"function"},{"doc":"Gets a summary of all of the pipelines associated with your account.","ref":"AWS.CodePipeline.html#list_pipelines/3","title":"AWS.CodePipeline.list_pipelines/3","type":"function"},{"doc":"Gets the set of key-value pairs (metadata) that are used to manage the resource.","ref":"AWS.CodePipeline.html#list_tags_for_resource/3","title":"AWS.CodePipeline.list_tags_for_resource/3","type":"function"},{"doc":"Gets a listing of all the webhooks in this Amazon Web Services Region for this\naccount.\n\nThe output lists all webhooks and includes the webhook URL and ARN and the\nconfiguration for each webhook.","ref":"AWS.CodePipeline.html#list_webhooks/3","title":"AWS.CodePipeline.list_webhooks/3","type":"function"},{"doc":"","ref":"AWS.CodePipeline.html#metadata/0","title":"AWS.CodePipeline.metadata/0","type":"function"},{"doc":"Returns information about any jobs for CodePipeline to act on.\n\n`PollForJobs` is valid only for action types with \"Custom\" in the owner field.\nIf the action type contains `AWS` or `ThirdParty` in the owner field, the\n`PollForJobs` action returns an error.\n\nWhen this API is called, CodePipeline returns temporary credentials for the S3\nbucket used to store artifacts for the pipeline, if the action requires access\nto that S3 bucket for input or output artifacts. This API also returns any\nsecret values defined for the action.","ref":"AWS.CodePipeline.html#poll_for_jobs/3","title":"AWS.CodePipeline.poll_for_jobs/3","type":"function"},{"doc":"Determines whether there are any third party jobs for a job worker to act on.\n\nUsed for partner actions only.\n\nWhen this API is called, CodePipeline returns temporary credentials for the S3\nbucket used to store artifacts for the pipeline, if the action requires access\nto that S3 bucket for input or output artifacts.","ref":"AWS.CodePipeline.html#poll_for_third_party_jobs/3","title":"AWS.CodePipeline.poll_for_third_party_jobs/3","type":"function"},{"doc":"Provides information to CodePipeline about new revisions to a source.","ref":"AWS.CodePipeline.html#put_action_revision/3","title":"AWS.CodePipeline.put_action_revision/3","type":"function"},{"doc":"Provides the response to a manual approval request to CodePipeline.\n\nValid responses include Approved and Rejected.","ref":"AWS.CodePipeline.html#put_approval_result/3","title":"AWS.CodePipeline.put_approval_result/3","type":"function"},{"doc":"Represents the failure of a job as returned to the pipeline by a job worker.\n\nUsed for custom actions only.","ref":"AWS.CodePipeline.html#put_job_failure_result/3","title":"AWS.CodePipeline.put_job_failure_result/3","type":"function"},{"doc":"Represents the success of a job as returned to the pipeline by a job worker.\n\nUsed for custom actions only.","ref":"AWS.CodePipeline.html#put_job_success_result/3","title":"AWS.CodePipeline.put_job_success_result/3","type":"function"},{"doc":"Represents the failure of a third party job as returned to the pipeline by a job\nworker.\n\nUsed for partner actions only.","ref":"AWS.CodePipeline.html#put_third_party_job_failure_result/3","title":"AWS.CodePipeline.put_third_party_job_failure_result/3","type":"function"},{"doc":"Represents the success of a third party job as returned to the pipeline by a job\nworker.\n\nUsed for partner actions only.","ref":"AWS.CodePipeline.html#put_third_party_job_success_result/3","title":"AWS.CodePipeline.put_third_party_job_success_result/3","type":"function"},{"doc":"Defines a webhook and returns a unique webhook URL generated by CodePipeline.\n\nThis URL can be supplied to third party source hosting providers to call every\ntime there's a code change. When CodePipeline receives a POST request on this\nURL, the pipeline defined in the webhook is started as long as the POST request\nsatisfied the authentication and filtering requirements supplied when defining\nthe webhook. RegisterWebhookWithThirdParty and DeregisterWebhookWithThirdParty\nAPIs can be used to automatically configure supported third parties to call the\ngenerated webhook URL.","ref":"AWS.CodePipeline.html#put_webhook/3","title":"AWS.CodePipeline.put_webhook/3","type":"function"},{"doc":"Configures a connection between the webhook that was created and the external\ntool with events to be detected.","ref":"AWS.CodePipeline.html#register_webhook_with_third_party/3","title":"AWS.CodePipeline.register_webhook_with_third_party/3","type":"function"},{"doc":"You can retry a stage that has failed without having to run a pipeline again\nfrom the beginning.\n\nYou do this by either retrying the failed actions in a stage or by retrying all\nactions in the stage starting from the first action in the stage. When you retry\nthe failed actions in a stage, all actions that are still in progress continue\nworking, and failed actions are triggered again. When you retry a failed stage\nfrom the first action in the stage, the stage cannot have any actions in\nprogress. Before a stage can be retried, it must either have all actions failed\nor some actions failed and some succeeded.","ref":"AWS.CodePipeline.html#retry_stage_execution/3","title":"AWS.CodePipeline.retry_stage_execution/3","type":"function"},{"doc":"Starts the specified pipeline.\n\nSpecifically, it begins processing the latest commit to the source location\nspecified as part of the pipeline.","ref":"AWS.CodePipeline.html#start_pipeline_execution/3","title":"AWS.CodePipeline.start_pipeline_execution/3","type":"function"},{"doc":"Stops the specified pipeline execution.\n\nYou choose to either stop the pipeline execution by completing in-progress\nactions without starting subsequent actions, or by abandoning in-progress\nactions. While completing or abandoning in-progress actions, the pipeline\nexecution is in a `Stopping` state. After all in-progress actions are completed\nor abandoned, the pipeline execution is in a `Stopped` state.","ref":"AWS.CodePipeline.html#stop_pipeline_execution/3","title":"AWS.CodePipeline.stop_pipeline_execution/3","type":"function"},{"doc":"Adds to or modifies the tags of the given resource.\n\nTags are metadata that can be used to manage a resource.","ref":"AWS.CodePipeline.html#tag_resource/3","title":"AWS.CodePipeline.tag_resource/3","type":"function"},{"doc":"Removes tags from an Amazon Web Services resource.","ref":"AWS.CodePipeline.html#untag_resource/3","title":"AWS.CodePipeline.untag_resource/3","type":"function"},{"doc":"Updates an action type that was created with any supported integration model,\nwhere the action type is to be used by customers of the action type provider.\n\nUse a JSON file with the action definition and `UpdateActionType` to provide the\nfull structure.","ref":"AWS.CodePipeline.html#update_action_type/3","title":"AWS.CodePipeline.update_action_type/3","type":"function"},{"doc":"Updates a specified pipeline with edits or changes to its structure.\n\nUse a JSON file with the pipeline structure and `UpdatePipeline` to provide the\nfull structure of the pipeline. Updating the pipeline increases the version\nnumber of the pipeline by 1.","ref":"AWS.CodePipeline.html#update_pipeline/3","title":"AWS.CodePipeline.update_pipeline/3","type":"function"},{"doc":"AWS CodeStar\n\nThis is the API reference for AWS CodeStar.\n\nThis reference provides descriptions of the operations and data types for the\nAWS CodeStar API along with usage examples.\n\nYou can use the AWS CodeStar API to work with:\n\nProjects and their resources, by calling the following:\n\n  * `DeleteProject`, which deletes a project.\n\n  * `DescribeProject`, which lists the attributes of a project.\n\n  * `ListProjects`, which lists all projects associated with your AWS\naccount.\n\n  * `ListResources`, which lists the resources associated with a\nproject.\n\n  * `ListTagsForProject`, which lists the tags associated with a\nproject.\n\n  * `TagProject`, which adds tags to a project.\n\n  * `UntagProject`, which removes tags from a project.\n\n  * `UpdateProject`, which updates the attributes of a project.\n\nTeams and team members, by calling the following:\n\n  * `AssociateTeamMember`, which adds an IAM user to the team for a\nproject.\n\n  * `DisassociateTeamMember`, which removes an IAM user from the team\nfor a project.\n\n  * `ListTeamMembers`, which lists all the IAM users in the team for a\nproject, including their roles and attributes.\n\n  * `UpdateTeamMember`, which updates a team member's attributes in a\nproject.\n\nUsers, by calling the following:\n\n  * `CreateUserProfile`, which creates a user profile that contains\ndata associated with the user across all projects.\n\n  * `DeleteUserProfile`, which deletes all user profile information\nacross all projects.\n\n  * `DescribeUserProfile`, which describes the profile of a user.\n\n  * `ListUserProfiles`, which lists all user profiles.\n\n  * `UpdateUserProfile`, which updates the profile for a user.","ref":"AWS.CodeStar.html","title":"AWS.CodeStar","type":"module"},{"doc":"Adds an IAM user to the team for an AWS CodeStar project.","ref":"AWS.CodeStar.html#associate_team_member/3","title":"AWS.CodeStar.associate_team_member/3","type":"function"},{"doc":"Creates a project, including project resources.\n\nThis action creates a project based on a submitted project request. A set of\nsource code files and a toolchain template file can be included with the project\nrequest. If these are not provided, an empty project is created.","ref":"AWS.CodeStar.html#create_project/3","title":"AWS.CodeStar.create_project/3","type":"function"},{"doc":"Creates a profile for a user that includes user preferences, such as the display\nname and email address assocciated with the user, in AWS CodeStar.\n\nThe user profile is not project-specific. Information in the user profile is\ndisplayed wherever the user's information appears to other users in AWS\nCodeStar.","ref":"AWS.CodeStar.html#create_user_profile/3","title":"AWS.CodeStar.create_user_profile/3","type":"function"},{"doc":"Deletes a project, including project resources.\n\nDoes not delete users associated with the project, but does delete the IAM roles\nthat allowed access to the project.","ref":"AWS.CodeStar.html#delete_project/3","title":"AWS.CodeStar.delete_project/3","type":"function"},{"doc":"Deletes a user profile in AWS CodeStar, including all personal preference data\nassociated with that profile, such as display name and email address.\n\nIt does not delete the history of that user, for example the history of commits\nmade by that user.","ref":"AWS.CodeStar.html#delete_user_profile/3","title":"AWS.CodeStar.delete_user_profile/3","type":"function"},{"doc":"Describes a project and its resources.","ref":"AWS.CodeStar.html#describe_project/3","title":"AWS.CodeStar.describe_project/3","type":"function"},{"doc":"Describes a user in AWS CodeStar and the user attributes across all projects.","ref":"AWS.CodeStar.html#describe_user_profile/3","title":"AWS.CodeStar.describe_user_profile/3","type":"function"},{"doc":"Removes a user from a project.\n\nRemoving a user from a project also removes the IAM policies from that user that\nallowed access to the project and its resources. Disassociating a team member\ndoes not remove that user's profile from AWS CodeStar. It does not remove the\nuser from IAM.","ref":"AWS.CodeStar.html#disassociate_team_member/3","title":"AWS.CodeStar.disassociate_team_member/3","type":"function"},{"doc":"Lists all projects in AWS CodeStar associated with your AWS account.","ref":"AWS.CodeStar.html#list_projects/3","title":"AWS.CodeStar.list_projects/3","type":"function"},{"doc":"Lists resources associated with a project in AWS CodeStar.","ref":"AWS.CodeStar.html#list_resources/3","title":"AWS.CodeStar.list_resources/3","type":"function"},{"doc":"Gets the tags for a project.","ref":"AWS.CodeStar.html#list_tags_for_project/3","title":"AWS.CodeStar.list_tags_for_project/3","type":"function"},{"doc":"Lists all team members associated with a project.","ref":"AWS.CodeStar.html#list_team_members/3","title":"AWS.CodeStar.list_team_members/3","type":"function"},{"doc":"Lists all the user profiles configured for your AWS account in AWS CodeStar.","ref":"AWS.CodeStar.html#list_user_profiles/3","title":"AWS.CodeStar.list_user_profiles/3","type":"function"},{"doc":"","ref":"AWS.CodeStar.html#metadata/0","title":"AWS.CodeStar.metadata/0","type":"function"},{"doc":"Adds tags to a project.","ref":"AWS.CodeStar.html#tag_project/3","title":"AWS.CodeStar.tag_project/3","type":"function"},{"doc":"Removes tags from a project.","ref":"AWS.CodeStar.html#untag_project/3","title":"AWS.CodeStar.untag_project/3","type":"function"},{"doc":"Updates a project in AWS CodeStar.","ref":"AWS.CodeStar.html#update_project/3","title":"AWS.CodeStar.update_project/3","type":"function"},{"doc":"Updates a team member's attributes in an AWS CodeStar project.\n\nFor example, you can change a team member's role in the project, or change\nwhether they have remote access to project resources.","ref":"AWS.CodeStar.html#update_team_member/3","title":"AWS.CodeStar.update_team_member/3","type":"function"},{"doc":"Updates a user's profile in AWS CodeStar.\n\nThe user profile is not project-specific. Information in the user profile is\ndisplayed wherever the user's information appears to other users in AWS\nCodeStar.","ref":"AWS.CodeStar.html#update_user_profile/3","title":"AWS.CodeStar.update_user_profile/3","type":"function"},{"doc":"AWS CodeStar Connections\n\nThis Amazon Web Services CodeStar Connections API Reference provides\ndescriptions and usage examples of the operations and data types for the Amazon\nWeb Services CodeStar Connections API.\n\nYou can use the connections API to work with connections and installations.\n\n*Connections* are configurations that you use to connect Amazon Web Services\nresources to external code repositories. Each connection is a resource that can\nbe given to services such as CodePipeline to connect to a third-party repository\nsuch as Bitbucket. For example, you can add the connection in CodePipeline so\nthat it triggers your pipeline when a code change is made to your third-party\ncode repository. Each connection is named and associated with a unique ARN that\nis used to reference the connection.\n\nWhen you create a connection, the console initiates a third-party connection\nhandshake. *Installations* are the apps that are used to conduct this handshake.\nFor example, the installation for the Bitbucket provider type is the Bitbucket\napp. When you create a connection, you can choose an existing installation or\ncreate one.\n\nWhen you want to create a connection to an installed provider type such as\nGitHub Enterprise Server, you create a *host* for your connections.\n\nYou can work with connections by calling:\n\n  * `CreateConnection`, which creates a uniquely named connection that\ncan be referenced by services such as CodePipeline.\n\n  * `DeleteConnection`, which deletes the specified connection.\n\n  * `GetConnection`, which returns information about the connection,\nincluding the connection status.\n\n  * `ListConnections`, which lists the connections associated with\nyour account.\n\nYou can work with hosts by calling:\n\n  * `CreateHost`, which creates a host that represents the\ninfrastructure where your provider is installed.\n\n  * `DeleteHost`, which deletes the specified host.\n\n  * `GetHost`, which returns information about the host, including the\nsetup status.\n\n  * `ListHosts`, which lists the hosts associated with your account.\n\nYou can work with tags in Amazon Web Services CodeStar Connections by calling\nthe following:\n\n  * `ListTagsForResource`, which gets information about Amazon Web\nServices tags for a specified Amazon Resource Name (ARN) in Amazon Web Services\nCodeStar Connections.\n\n  * `TagResource`, which adds or updates tags for a resource in Amazon\nWeb Services CodeStar Connections.\n\n  * `UntagResource`, which removes tags for a resource in Amazon Web\nServices CodeStar Connections.\n\nFor information about how to use Amazon Web Services CodeStar Connections, see\nthe [Developer Tools User Guide](https://docs.aws.amazon.com/dtconsole/latest/userguide/welcome-connections.html).","ref":"AWS.CodeStarConnections.html","title":"AWS.CodeStarConnections","type":"module"},{"doc":"Creates a connection that can then be given to other Amazon Web Services\nservices like CodePipeline so that it can access third-party code repositories.\n\nThe connection is in pending status until the third-party connection handshake\nis completed from the console.","ref":"AWS.CodeStarConnections.html#create_connection/3","title":"AWS.CodeStarConnections.create_connection/3","type":"function"},{"doc":"Creates a resource that represents the infrastructure where a third-party\nprovider is installed.\n\nThe host is used when you create connections to an installed third-party\nprovider type, such as GitHub Enterprise Server. You create one host for all\nconnections to that provider.\n\nA host created through the CLI or the SDK is in `PENDING` status by default. You\ncan make its status `AVAILABLE` by setting up the host in the console.","ref":"AWS.CodeStarConnections.html#create_host/3","title":"AWS.CodeStarConnections.create_host/3","type":"function"},{"doc":"Creates a link to a specified external Git repository.\n\nA repository link allows Git sync to monitor and sync changes to files in a\nspecified Git repository.","ref":"AWS.CodeStarConnections.html#create_repository_link/3","title":"AWS.CodeStarConnections.create_repository_link/3","type":"function"},{"doc":"Creates a sync configuration which allows Amazon Web Services to sync content\nfrom a Git repository to update a specified Amazon Web Services resource.\n\nParameters for the sync configuration are determined by the sync type.","ref":"AWS.CodeStarConnections.html#create_sync_configuration/3","title":"AWS.CodeStarConnections.create_sync_configuration/3","type":"function"},{"doc":"The connection to be deleted.","ref":"AWS.CodeStarConnections.html#delete_connection/3","title":"AWS.CodeStarConnections.delete_connection/3","type":"function"},{"doc":"The host to be deleted.\n\nBefore you delete a host, all connections associated to the host must be\ndeleted.\n\nA host cannot be deleted if it is in the VPC_CONFIG_INITIALIZING or\nVPC_CONFIG_DELETING state.","ref":"AWS.CodeStarConnections.html#delete_host/3","title":"AWS.CodeStarConnections.delete_host/3","type":"function"},{"doc":"Deletes the association between your connection and a specified external Git\nrepository.","ref":"AWS.CodeStarConnections.html#delete_repository_link/3","title":"AWS.CodeStarConnections.delete_repository_link/3","type":"function"},{"doc":"Deletes the sync configuration for a specified repository and connection.","ref":"AWS.CodeStarConnections.html#delete_sync_configuration/3","title":"AWS.CodeStarConnections.delete_sync_configuration/3","type":"function"},{"doc":"Returns the connection ARN and details such as status, owner, and provider type.","ref":"AWS.CodeStarConnections.html#get_connection/3","title":"AWS.CodeStarConnections.get_connection/3","type":"function"},{"doc":"Returns the host ARN and details such as status, provider type, endpoint, and,\nif applicable, the VPC configuration.","ref":"AWS.CodeStarConnections.html#get_host/3","title":"AWS.CodeStarConnections.get_host/3","type":"function"},{"doc":"Returns details about a repository link.\n\nA repository link allows Git sync to monitor and sync changes from files in a\nspecified Git repository.","ref":"AWS.CodeStarConnections.html#get_repository_link/3","title":"AWS.CodeStarConnections.get_repository_link/3","type":"function"},{"doc":"Returns details about the sync status for a repository.\n\nA repository sync uses Git sync to push and pull changes from your remote\nrepository.","ref":"AWS.CodeStarConnections.html#get_repository_sync_status/3","title":"AWS.CodeStarConnections.get_repository_sync_status/3","type":"function"},{"doc":"Returns the status of the sync with the Git repository for a specific Amazon Web\nServices resource.","ref":"AWS.CodeStarConnections.html#get_resource_sync_status/3","title":"AWS.CodeStarConnections.get_resource_sync_status/3","type":"function"},{"doc":"Returns a list of the most recent sync blockers.","ref":"AWS.CodeStarConnections.html#get_sync_blocker_summary/3","title":"AWS.CodeStarConnections.get_sync_blocker_summary/3","type":"function"},{"doc":"Returns details about a sync configuration, including the sync type and resource\nname.\n\nA sync configuration allows the configuration to sync (push and pull) changes\nfrom the remote repository for a specified branch in a Git repository.","ref":"AWS.CodeStarConnections.html#get_sync_configuration/3","title":"AWS.CodeStarConnections.get_sync_configuration/3","type":"function"},{"doc":"Lists the connections associated with your account.","ref":"AWS.CodeStarConnections.html#list_connections/3","title":"AWS.CodeStarConnections.list_connections/3","type":"function"},{"doc":"Lists the hosts associated with your account.","ref":"AWS.CodeStarConnections.html#list_hosts/3","title":"AWS.CodeStarConnections.list_hosts/3","type":"function"},{"doc":"Lists the repository links created for connections in your account.","ref":"AWS.CodeStarConnections.html#list_repository_links/3","title":"AWS.CodeStarConnections.list_repository_links/3","type":"function"},{"doc":"Lists the repository sync definitions for repository links in your account.","ref":"AWS.CodeStarConnections.html#list_repository_sync_definitions/3","title":"AWS.CodeStarConnections.list_repository_sync_definitions/3","type":"function"},{"doc":"Returns a list of sync configurations for a specified repository.","ref":"AWS.CodeStarConnections.html#list_sync_configurations/3","title":"AWS.CodeStarConnections.list_sync_configurations/3","type":"function"},{"doc":"Gets the set of key-value pairs (metadata) that are used to manage the resource.","ref":"AWS.CodeStarConnections.html#list_tags_for_resource/3","title":"AWS.CodeStarConnections.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.CodeStarConnections.html#metadata/0","title":"AWS.CodeStarConnections.metadata/0","type":"function"},{"doc":"Adds to or modifies the tags of the given resource.\n\nTags are metadata that can be used to manage a resource.","ref":"AWS.CodeStarConnections.html#tag_resource/3","title":"AWS.CodeStarConnections.tag_resource/3","type":"function"},{"doc":"Removes tags from an Amazon Web Services resource.","ref":"AWS.CodeStarConnections.html#untag_resource/3","title":"AWS.CodeStarConnections.untag_resource/3","type":"function"},{"doc":"Updates a specified host with the provided configurations.","ref":"AWS.CodeStarConnections.html#update_host/3","title":"AWS.CodeStarConnections.update_host/3","type":"function"},{"doc":"Updates the association between your connection and a specified external Git\nrepository.\n\nA repository link allows Git sync to monitor and sync changes to files in a\nspecified Git repository.","ref":"AWS.CodeStarConnections.html#update_repository_link/3","title":"AWS.CodeStarConnections.update_repository_link/3","type":"function"},{"doc":"Allows you to update the status of a sync blocker, resolving the blocker and\nallowing syncing to continue.","ref":"AWS.CodeStarConnections.html#update_sync_blocker/3","title":"AWS.CodeStarConnections.update_sync_blocker/3","type":"function"},{"doc":"Updates the sync configuration for your connection and a specified external Git\nrepository.","ref":"AWS.CodeStarConnections.html#update_sync_configuration/3","title":"AWS.CodeStarConnections.update_sync_configuration/3","type":"function"},{"doc":"CodeArtifact is a fully managed artifact repository compatible with\nlanguage-native package managers and build tools such as npm, Apache Maven, pip,\nand dotnet.\n\nYou can use CodeArtifact to share packages with development teams and pull\npackages. Packages can be pulled from both public and CodeArtifact repositories.\nYou can also create an upstream relationship between a CodeArtifact repository\nand another repository, which effectively merges their contents from the point\nof view of a package manager client.","ref":"AWS.Codeartifact.html","title":"AWS.Codeartifact","type":"module"},{"doc":"Use the information in this guide to help you work with the following\nCodeArtifact components:\n\n  * **Repository## : A CodeArtifact repository contains a set of\n[package versions](https://docs.aws.amazon.com/codeartifact/latest/ug/welcome.html#welcome-concepts-package-version),\neach of which maps to a set of assets, or files. Repositories are polyglot, so a\nsingle repository can contain packages of any supported type. Each repository\nexposes endpoints for fetching and publishing packages using tools like the \n`npm` ** CLI, the Maven CLI (** `mvn` **), Python CLIs (** `pip` ** and\n`twine`), and NuGet CLIs (`nuget` and `dotnet`).\n\n  * **Domain**: Repositories are aggregated into a higher-level entity\nknown as a *domain*. All package assets and metadata are stored in the domain,\nbut are consumed through repositories. A given package asset, such as a Maven\nJAR file, is stored once per domain, no matter how many repositories it's\npresent in. All of the assets and metadata in a domain are encrypted with the\nsame customer master key (CMK) stored in Key Management Service (KMS).\n\nEach repository is a member of a single domain and can't be moved to a different\ndomain.\n\nThe domain allows organizational policy to be applied across multiple\nrepositories, such as which accounts can access repositories in the domain, and\nwhich public repositories can be used as sources of packages.\n\nAlthough an organization can have multiple domains, we recommend a single\nproduction domain that contains all published artifacts so that teams can find\nand share packages across their organization.\n\n  * **Package**: A *package* is a bundle of software and the metadata\nrequired to resolve dependencies and install the software. CodeArtifact supports\n[npm](https://docs.aws.amazon.com/codeartifact/latest/ug/using-npm.html), [PyPI](https://docs.aws.amazon.com/codeartifact/latest/ug/using-python.html),\n[Maven](https://docs.aws.amazon.com/codeartifact/latest/ug/using-maven), and [NuGet](https://docs.aws.amazon.com/codeartifact/latest/ug/using-nuget) package\nformats.\n\nIn CodeArtifact, a package consists of:\n\n    * A *name* (for example, `webpack` is the name of a\npopular npm package)\n\n    * An optional namespace (for example, `@types` in\n`@types/node`)\n\n    * A set of versions (for example, `1.0.0`, `1.0.1`,\n`1.0.2`, etc.)\n\n    * Package-level metadata (for example, npm tags)\n\n  * **Package version**: A version of a package, such as `@types/node\n12.6.9`. The version number format and semantics vary for different package\nformats. For example, npm package versions must conform to the [Semantic Versioning specification](https://semver.org/). In CodeArtifact, a package\nversion consists of the version identifier, metadata at the package version\nlevel, and a set of assets.\n\n  * **Upstream repository**: One repository is *upstream* of another\nwhen the package versions in it can be accessed from the repository endpoint of\nthe downstream repository, effectively merging the contents of the two\nrepositories from the point of view of a client. CodeArtifact allows creating an\nupstream relationship between two repositories.\n\n  * **Asset**: An individual file stored in CodeArtifact associated\nwith a package version, such as an npm `.tgz` file or Maven POM and JAR files.\n\nCodeArtifact supports these operations:\n\n  * `AssociateExternalConnection`: Adds an existing external\nconnection to a repository.\n\n  * `CopyPackageVersions`: Copies package versions from one repository\nto another repository in the same domain.\n\n  * `CreateDomain`: Creates a domain\n\n  * `CreateRepository`: Creates a CodeArtifact repository in a domain.\n\n  * `DeleteDomain`: Deletes a domain. You cannot delete a domain that\ncontains repositories.\n\n  * `DeleteDomainPermissionsPolicy`: Deletes the resource policy that\nis set on a domain.\n\n  * `DeletePackage`: Deletes a package and all associated package\nversions.\n\n  * `DeletePackageVersions`: Deletes versions of a package. After a\npackage has been deleted, it can be republished, but its assets and metadata\ncannot be restored because they have been permanently removed from storage.\n\n  * `DeleteRepository`: Deletes a repository.\n\n  * `DeleteRepositoryPermissionsPolicy`: Deletes the resource policy\nthat is set on a repository.\n\n  * `DescribeDomain`: Returns a `DomainDescription` object that\ncontains information about the requested domain.\n\n  * `DescribePackage`: Returns a\n[PackageDescription](https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_PackageDescription.html) object that contains details about a package.\n\n  * `DescribePackageVersion`: Returns a\n[PackageVersionDescription](https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_PackageVersionDescription.html)\nobject that contains details about a package version.\n\n  * `DescribeRepository`: Returns a `RepositoryDescription` object\nthat contains detailed information about the requested repository.\n\n  * `DisposePackageVersions`: Disposes versions of a package. A\npackage version with the status `Disposed` cannot be restored because they have\nbeen permanently removed from storage.\n\n  * `DisassociateExternalConnection`: Removes an existing external\nconnection from a repository.\n\n  * `GetAuthorizationToken`: Generates a temporary authorization token\nfor accessing repositories in the domain. The token expires the authorization\nperiod has passed. The default authorization period is 12 hours and can be\ncustomized to any length with a maximum of 12 hours.\n\n  * `GetDomainPermissionsPolicy`: Returns the policy of a resource\nthat is attached to the specified domain.\n\n  * `GetPackageVersionAsset`: Returns the contents of an asset that is\nin a package version.\n\n  * `GetPackageVersionReadme`: Gets the readme file or descriptive\ntext for a package version.\n\n  * `GetRepositoryEndpoint`: Returns the endpoint of a repository for\na specific package format. A repository has one endpoint for each package\nformat:\n\n    * `maven`\n\n    * `npm`\n\n    * `nuget`\n\n    * `pypi`\n\n  * `GetRepositoryPermissionsPolicy`: Returns the resource policy that\nis set on a repository.\n\n  * `ListDomains`: Returns a list of `DomainSummary` objects. Each\nreturned `DomainSummary` object contains information about a domain.\n\n  * `ListPackages`: Lists the packages in a repository.\n\n  * `ListPackageVersionAssets`: Lists the assets for a given package\nversion.\n\n  * `ListPackageVersionDependencies`: Returns a list of the direct\ndependencies for a package version.\n\n  * `ListPackageVersions`: Returns a list of package versions for a\nspecified package in a repository.\n\n  * `ListRepositories`: Returns a list of repositories owned by the\nAmazon Web Services account that called this method.\n\n  * `ListRepositoriesInDomain`: Returns a list of the repositories in\na domain.\n\n  * `PublishPackageVersion`: Creates a new package version containing\none or more assets.\n\n  * `PutDomainPermissionsPolicy`: Attaches a resource policy to a\ndomain.\n\n  * `PutPackageOriginConfiguration`: Sets the package origin\nconfiguration for a package, which determine how new versions of the package can\nbe added to a specific repository.\n\n  * `PutRepositoryPermissionsPolicy`: Sets the resource policy on a\nrepository that specifies permissions to access it.\n\n  * `UpdatePackageVersionsStatus`: Updates the status of one or more\nversions of a package.\n\n  * `UpdateRepository`: Updates the properties of a repository.","ref":"AWS.Codeartifact.html#module-codeartifact-components","title":"CodeArtifact Components - AWS.Codeartifact","type":"module"},{"doc":"Adds an existing external connection to a repository.\n\nOne external connection is allowed per repository.\n\nA repository can have one or more upstream repositories, or an external\nconnection.","ref":"AWS.Codeartifact.html#associate_external_connection/3","title":"AWS.Codeartifact.associate_external_connection/3","type":"function"},{"doc":"Copies package versions from one repository to another repository in the same\ndomain.\n\nYou must specify `versions` or `versionRevisions`. You cannot specify both.","ref":"AWS.Codeartifact.html#copy_package_versions/3","title":"AWS.Codeartifact.copy_package_versions/3","type":"function"},{"doc":"Creates a domain.\n\nCodeArtifact *domains* make it easier to manage multiple repositories across an\norganization. You can use a domain to apply permissions across many repositories\nowned by different Amazon Web Services accounts. An asset is stored only once in\na domain, even if it's in multiple repositories.\n\nAlthough you can have multiple domains, we recommend a single production domain\nthat contains all published artifacts so that your development teams can find\nand share packages. You can use a second pre-production domain to test changes\nto the production domain configuration.","ref":"AWS.Codeartifact.html#create_domain/3","title":"AWS.Codeartifact.create_domain/3","type":"function"},{"doc":"Creates a repository.","ref":"AWS.Codeartifact.html#create_repository/3","title":"AWS.Codeartifact.create_repository/3","type":"function"},{"doc":"Deletes a domain.\n\nYou cannot delete a domain that contains repositories. If you want to delete a\ndomain with repositories, first delete its repositories.","ref":"AWS.Codeartifact.html#delete_domain/3","title":"AWS.Codeartifact.delete_domain/3","type":"function"},{"doc":"Deletes the resource policy set on a domain.","ref":"AWS.Codeartifact.html#delete_domain_permissions_policy/3","title":"AWS.Codeartifact.delete_domain_permissions_policy/3","type":"function"},{"doc":"Deletes a package and all associated package versions.\n\nA deleted package cannot be restored. To delete one or more package versions,\nuse the\n[DeletePackageVersions](https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_DeletePackageVersions.html)\nAPI.","ref":"AWS.Codeartifact.html#delete_package/3","title":"AWS.Codeartifact.delete_package/3","type":"function"},{"doc":"Deletes one or more versions of a package.\n\nA deleted package version cannot be restored in your repository. If you want to\nremove a package version from your repository and be able to restore it later,\nset its status to `Archived`. Archived packages cannot be downloaded from a\nrepository and don't show up with list package APIs (for example,\n[ListPackageVersions](https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_ListPackageVersions.html)), but you can restore them using\n[UpdatePackageVersionsStatus](https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_UpdatePackageVersionsStatus.html).","ref":"AWS.Codeartifact.html#delete_package_versions/3","title":"AWS.Codeartifact.delete_package_versions/3","type":"function"},{"doc":"Deletes a repository.","ref":"AWS.Codeartifact.html#delete_repository/3","title":"AWS.Codeartifact.delete_repository/3","type":"function"},{"doc":"Deletes the resource policy that is set on a repository.\n\nAfter a resource policy is deleted, the permissions allowed and denied by the\ndeleted policy are removed. The effect of deleting a resource policy might not\nbe immediate.\n\nUse `DeleteRepositoryPermissionsPolicy` with caution. After a policy is deleted,\nAmazon Web Services users, roles, and accounts lose permissions to perform the\nrepository actions granted by the deleted policy.","ref":"AWS.Codeartifact.html#delete_repository_permissions_policy/3","title":"AWS.Codeartifact.delete_repository_permissions_policy/3","type":"function"},{"doc":"Returns a\n[DomainDescription](https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_DomainDescription.html)\nobject that contains information about the requested domain.","ref":"AWS.Codeartifact.html#describe_domain/4","title":"AWS.Codeartifact.describe_domain/4","type":"function"},{"doc":"Returns a\n[PackageDescription](https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_PackageDescription.html)\nobject that contains information about the requested package.","ref":"AWS.Codeartifact.html#describe_package/8","title":"AWS.Codeartifact.describe_package/8","type":"function"},{"doc":"Returns a\n[PackageVersionDescription](https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_PackageVersionDescription.html)\nobject that contains information about the requested package version.","ref":"AWS.Codeartifact.html#describe_package_version/9","title":"AWS.Codeartifact.describe_package_version/9","type":"function"},{"doc":"Returns a `RepositoryDescription` object that contains detailed information\nabout the requested repository.","ref":"AWS.Codeartifact.html#describe_repository/5","title":"AWS.Codeartifact.describe_repository/5","type":"function"},{"doc":"Removes an existing external connection from a repository.","ref":"AWS.Codeartifact.html#disassociate_external_connection/3","title":"AWS.Codeartifact.disassociate_external_connection/3","type":"function"},{"doc":"Deletes the assets in package versions and sets the package versions' status to\n`Disposed`.\n\nA disposed package version cannot be restored in your repository because its\nassets are deleted.\n\nTo view all disposed package versions in a repository, use\n[ListPackageVersions](https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_ListPackageVersions.html) and set the\n[status](https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_ListPackageVersions.html#API_ListPackageVersions_RequestSyntax)\nparameter to `Disposed`.\n\nTo view information about a disposed package version, use\n[DescribePackageVersion](https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_DescribePackageVersion.html).","ref":"AWS.Codeartifact.html#dispose_package_versions/3","title":"AWS.Codeartifact.dispose_package_versions/3","type":"function"},{"doc":"Generates a temporary authorization token for accessing repositories in the\ndomain.\n\nThis API requires the `codeartifact:GetAuthorizationToken` and\n`sts:GetServiceBearerToken` permissions. For more information about\nauthorization tokens, see [CodeArtifact authentication and tokens](https://docs.aws.amazon.com/codeartifact/latest/ug/tokens-authentication.html).\n\nCodeArtifact authorization tokens are valid for a period of 12 hours when\ncreated with the `login` command. You can call `login` periodically to refresh\nthe token. When you create an authorization token with the\n`GetAuthorizationToken` API, you can set a custom authorization period, up to a\nmaximum of 12 hours, with the `durationSeconds` parameter.\n\nThe authorization period begins after `login` or `GetAuthorizationToken` is\ncalled. If `login` or `GetAuthorizationToken` is called while assuming a role,\nthe token lifetime is independent of the maximum session duration of the role.\nFor example, if you call `sts assume-role` and specify a session duration of 15\nminutes, then generate a CodeArtifact authorization token, the token will be\nvalid for the full authorization period even though this is longer than the\n15-minute session duration.\n\nSee [Using IAM Roles](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_use.html) for\nmore information on controlling session duration.","ref":"AWS.Codeartifact.html#get_authorization_token/3","title":"AWS.Codeartifact.get_authorization_token/3","type":"function"},{"doc":"Returns the resource policy attached to the specified domain.\n\nThe policy is a resource-based policy, not an identity-based policy. For more\ninformation, see [Identity-based policies and resource-based policies\n](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_identity-vs-resource.html)\nin the *IAM User Guide*.","ref":"AWS.Codeartifact.html#get_domain_permissions_policy/4","title":"AWS.Codeartifact.get_domain_permissions_policy/4","type":"function"},{"doc":"Returns an asset (or file) that is in a package.\n\nFor example, for a Maven package version, use `GetPackageVersionAsset` to\ndownload a `JAR` file, a `POM` file, or any other assets in the package version.","ref":"AWS.Codeartifact.html#get_package_version_asset/11","title":"AWS.Codeartifact.get_package_version_asset/11","type":"function"},{"doc":"Gets the readme file or descriptive text for a package version.\n\nThe returned text might contain formatting. For example, it might contain\nformatting for Markdown or reStructuredText.","ref":"AWS.Codeartifact.html#get_package_version_readme/9","title":"AWS.Codeartifact.get_package_version_readme/9","type":"function"},{"doc":"Returns the endpoint of a repository for a specific package format.\n\nA repository has one endpoint for each package format:\n\n  * `maven`\n\n  * `npm`\n\n  * `nuget`\n\n  * `pypi`","ref":"AWS.Codeartifact.html#get_repository_endpoint/6","title":"AWS.Codeartifact.get_repository_endpoint/6","type":"function"},{"doc":"Returns the resource policy that is set on a repository.","ref":"AWS.Codeartifact.html#get_repository_permissions_policy/5","title":"AWS.Codeartifact.get_repository_permissions_policy/5","type":"function"},{"doc":"Returns a list of\n[DomainSummary](https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_PackageVersionDescription.html)\nobjects for all domains owned by the Amazon Web Services account that makes this\ncall.\n\nEach returned `DomainSummary` object contains information about a domain.","ref":"AWS.Codeartifact.html#list_domains/3","title":"AWS.Codeartifact.list_domains/3","type":"function"},{"doc":"Returns a list of\n[AssetSummary](https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_AssetSummary.html)\nobjects for assets in a package version.","ref":"AWS.Codeartifact.html#list_package_version_assets/3","title":"AWS.Codeartifact.list_package_version_assets/3","type":"function"},{"doc":"Returns the direct dependencies for a package version.\n\nThe dependencies are returned as\n[PackageDependency](https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_PackageDependency.html)\nobjects. CodeArtifact extracts the dependencies for a package version from the\nmetadata file for the package format (for example, the `package.json` file for\nnpm packages and the `pom.xml` file for Maven). Any package version dependencies\nthat are not listed in the configuration file are not returned.","ref":"AWS.Codeartifact.html#list_package_version_dependencies/3","title":"AWS.Codeartifact.list_package_version_dependencies/3","type":"function"},{"doc":"Returns a list of\n[PackageVersionSummary](https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_PackageVersionSummary.html)\nobjects for package versions in a repository that match the request parameters.\n\nPackage versions of all statuses will be returned by default when calling\n`list-package-versions` with no `--status` parameter.","ref":"AWS.Codeartifact.html#list_package_versions/3","title":"AWS.Codeartifact.list_package_versions/3","type":"function"},{"doc":"Returns a list of\n[PackageSummary](https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_PackageSummary.html)\nobjects for packages in a repository that match the request parameters.","ref":"AWS.Codeartifact.html#list_packages/3","title":"AWS.Codeartifact.list_packages/3","type":"function"},{"doc":"Returns a list of\n[RepositorySummary](https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_RepositorySummary.html)\nobjects.\n\nEach `RepositorySummary` contains information about a repository in the\nspecified Amazon Web Services account and that matches the input parameters.","ref":"AWS.Codeartifact.html#list_repositories/3","title":"AWS.Codeartifact.list_repositories/3","type":"function"},{"doc":"Returns a list of\n[RepositorySummary](https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_RepositorySummary.html)\nobjects.\n\nEach `RepositorySummary` contains information about a repository in the\nspecified domain and that matches the input parameters.","ref":"AWS.Codeartifact.html#list_repositories_in_domain/3","title":"AWS.Codeartifact.list_repositories_in_domain/3","type":"function"},{"doc":"Gets information about Amazon Web Services tags for a specified Amazon Resource\nName (ARN) in CodeArtifact.","ref":"AWS.Codeartifact.html#list_tags_for_resource/3","title":"AWS.Codeartifact.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.Codeartifact.html#metadata/0","title":"AWS.Codeartifact.metadata/0","type":"function"},{"doc":"Creates a new package version containing one or more assets (or files).\n\nThe `unfinished` flag can be used to keep the package version in the\n`Unfinished` state until all of its assets have been uploaded (see [Package version\nstatus](https://docs.aws.amazon.com/codeartifact/latest/ug/packages-overview.html#package-version-status.html#package-version-status)\nin the *CodeArtifact user guide*). To set the package version’s status to\n`Published`, omit the `unfinished` flag when uploading the final asset, or set\nthe status using\n[UpdatePackageVersionStatus](https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_UpdatePackageVersionsStatus.html). Once a package version’s status is set to `Published`, it cannot change back to\n`Unfinished`.\n\nOnly generic packages can be published using this API. For more information, see\n[Using generic\npackages](https://docs.aws.amazon.com/codeartifact/latest/ug/using-generic.html)\nin the *CodeArtifact User Guide*.","ref":"AWS.Codeartifact.html#publish_package_version/3","title":"AWS.Codeartifact.publish_package_version/3","type":"function"},{"doc":"Sets a resource policy on a domain that specifies permissions to access it.\n\nWhen you call `PutDomainPermissionsPolicy`, the resource policy on the domain is\nignored when evaluting permissions. This ensures that the owner of a domain\ncannot lock themselves out of the domain, which would prevent them from being\nable to update the resource policy.","ref":"AWS.Codeartifact.html#put_domain_permissions_policy/3","title":"AWS.Codeartifact.put_domain_permissions_policy/3","type":"function"},{"doc":"Sets the package origin configuration for a package.\n\nThe package origin configuration determines how new versions of a package can be\nadded to a repository. You can allow or block direct publishing of new package\nversions, or ingestion and retaining of new package versions from an external\nconnection or upstream source. For more information about package origin\ncontrols and configuration, see [Editing package origin controls](https://docs.aws.amazon.com/codeartifact/latest/ug/package-origin-controls.html)\nin the *CodeArtifact User Guide*.\n\n`PutPackageOriginConfiguration` can be called on a package that doesn't yet\nexist in the repository. When called on a package that does not exist, a package\nis created in the repository with no versions and the requested restrictions are\nset on the package. This can be used to preemptively block ingesting or\nretaining any versions from external connections or upstream repositories, or to\nblock publishing any versions of the package into the repository before\nconnecting any package managers or publishers to the repository.","ref":"AWS.Codeartifact.html#put_package_origin_configuration/3","title":"AWS.Codeartifact.put_package_origin_configuration/3","type":"function"},{"doc":"Sets the resource policy on a repository that specifies permissions to access\nit.\n\nWhen you call `PutRepositoryPermissionsPolicy`, the resource policy on the\nrepository is ignored when evaluting permissions. This ensures that the owner of\na repository cannot lock themselves out of the repository, which would prevent\nthem from being able to update the resource policy.","ref":"AWS.Codeartifact.html#put_repository_permissions_policy/3","title":"AWS.Codeartifact.put_repository_permissions_policy/3","type":"function"},{"doc":"Adds or updates tags for a resource in CodeArtifact.","ref":"AWS.Codeartifact.html#tag_resource/3","title":"AWS.Codeartifact.tag_resource/3","type":"function"},{"doc":"Removes tags from a resource in CodeArtifact.","ref":"AWS.Codeartifact.html#untag_resource/3","title":"AWS.Codeartifact.untag_resource/3","type":"function"},{"doc":"Updates the status of one or more versions of a package.\n\nUsing `UpdatePackageVersionsStatus`, you can update the status of package\nversions to `Archived`, `Published`, or `Unlisted`. To set the status of a\npackage version to `Disposed`, use\n[DisposePackageVersions](https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_DisposePackageVersions.html).","ref":"AWS.Codeartifact.html#update_package_versions_status/3","title":"AWS.Codeartifact.update_package_versions_status/3","type":"function"},{"doc":"Update the properties of a repository.","ref":"AWS.Codeartifact.html#update_repository/3","title":"AWS.Codeartifact.update_repository/3","type":"function"},{"doc":"This AWS CodeStar Notifications API Reference provides descriptions and usage\nexamples of the operations and data types for the AWS CodeStar Notifications\nAPI.\n\nYou can use the AWS CodeStar Notifications API to work with the following\nobjects:\n\nNotification rules, by calling the following:\n\n  * `CreateNotificationRule`, which creates a notification rule for a\nresource in your account.\n\n  * `DeleteNotificationRule`, which deletes a notification rule.\n\n  * `DescribeNotificationRule`, which provides information about a\nnotification rule.\n\n  * `ListNotificationRules`, which lists the notification rules\nassociated with your account.\n\n  * `UpdateNotificationRule`, which changes the name, events, or\ntargets associated with a notification rule.\n\n  * `Subscribe`, which subscribes a target to a notification rule.\n\n  * `Unsubscribe`, which removes a target from a notification rule.\n\nTargets, by calling the following:\n\n  * `DeleteTarget`, which removes a notification rule target from a\nnotification rule.\n\n  * `ListTargets`, which lists the targets associated with a\nnotification rule.\n\nEvents, by calling the following:\n\n  * `ListEventTypes`, which lists the event types you can include in a\nnotification rule.\n\nTags, by calling the following:\n\n  * `ListTagsForResource`, which lists the tags already associated\nwith a notification rule in your account.\n\n  * `TagResource`, which associates a tag you provide with a\nnotification rule in your account.\n\n  * `UntagResource`, which removes a tag from a notification rule in\nyour account.\n\nFor information about how to use AWS CodeStar Notifications, see the [Amazon Web Services Developer Tools Console User\nGuide](https://docs.aws.amazon.com/dtconsole/latest/userguide/what-is-dtconsole.html).","ref":"AWS.Codestarnotifications.html","title":"AWS.Codestarnotifications","type":"module"},{"doc":"Creates a notification rule for a resource.\n\nThe rule specifies the events you want notifications about and the targets (such\nas Chatbot topics or Chatbot clients configured for Slack) where you want to\nreceive them.","ref":"AWS.Codestarnotifications.html#create_notification_rule/3","title":"AWS.Codestarnotifications.create_notification_rule/3","type":"function"},{"doc":"Deletes a notification rule for a resource.","ref":"AWS.Codestarnotifications.html#delete_notification_rule/3","title":"AWS.Codestarnotifications.delete_notification_rule/3","type":"function"},{"doc":"Deletes a specified target for notifications.","ref":"AWS.Codestarnotifications.html#delete_target/3","title":"AWS.Codestarnotifications.delete_target/3","type":"function"},{"doc":"Returns information about a specified notification rule.","ref":"AWS.Codestarnotifications.html#describe_notification_rule/3","title":"AWS.Codestarnotifications.describe_notification_rule/3","type":"function"},{"doc":"Returns information about the event types available for configuring\nnotifications.","ref":"AWS.Codestarnotifications.html#list_event_types/3","title":"AWS.Codestarnotifications.list_event_types/3","type":"function"},{"doc":"Returns a list of the notification rules for an Amazon Web Services account.","ref":"AWS.Codestarnotifications.html#list_notification_rules/3","title":"AWS.Codestarnotifications.list_notification_rules/3","type":"function"},{"doc":"Returns a list of the tags associated with a notification rule.","ref":"AWS.Codestarnotifications.html#list_tags_for_resource/3","title":"AWS.Codestarnotifications.list_tags_for_resource/3","type":"function"},{"doc":"Returns a list of the notification rule targets for an Amazon Web Services\naccount.","ref":"AWS.Codestarnotifications.html#list_targets/3","title":"AWS.Codestarnotifications.list_targets/3","type":"function"},{"doc":"","ref":"AWS.Codestarnotifications.html#metadata/0","title":"AWS.Codestarnotifications.metadata/0","type":"function"},{"doc":"Creates an association between a notification rule and an Chatbot topic or\nChatbot client so that the associated target can receive notifications when the\nevents described in the rule are triggered.","ref":"AWS.Codestarnotifications.html#subscribe/3","title":"AWS.Codestarnotifications.subscribe/3","type":"function"},{"doc":"Associates a set of provided tags with a notification rule.","ref":"AWS.Codestarnotifications.html#tag_resource/3","title":"AWS.Codestarnotifications.tag_resource/3","type":"function"},{"doc":"Removes an association between a notification rule and an Chatbot topic so that\nsubscribers to that topic stop receiving notifications when the events described\nin the rule are triggered.","ref":"AWS.Codestarnotifications.html#unsubscribe/3","title":"AWS.Codestarnotifications.unsubscribe/3","type":"function"},{"doc":"Removes the association between one or more provided tags and a notification\nrule.","ref":"AWS.Codestarnotifications.html#untag_resource/4","title":"AWS.Codestarnotifications.untag_resource/4","type":"function"},{"doc":"Updates a notification rule for a resource.\n\nYou can change the events that trigger the notification rule, the status of the\nrule, and the targets that receive the notifications.\n\nTo add or remove tags for a notification rule, you must use `TagResource` and\n`UntagResource`.","ref":"AWS.Codestarnotifications.html#update_notification_rule/3","title":"AWS.Codestarnotifications.update_notification_rule/3","type":"function"},{"doc":"Amazon Cognito Federated Identities\n\nAmazon Cognito Federated Identities is a web service that delivers scoped\ntemporary credentials to mobile devices and other untrusted environments.\n\nIt uniquely identifies a device and supplies the user with a consistent identity\nover the lifetime of an application.\n\nUsing Amazon Cognito Federated Identities, you can enable authentication with\none or more third-party identity providers (Facebook, Google, or Login with\nAmazon) or an Amazon Cognito user pool, and you can also choose to support\nunauthenticated access from your app. Cognito delivers a unique identifier for\neach user and acts as an OpenID token provider trusted by AWS Security Token\nService (STS) to access temporary, limited-privilege AWS credentials.\n\nFor a description of the authentication flow from the Amazon Cognito Developer\nGuide see [Authentication Flow](https://docs.aws.amazon.com/cognito/latest/developerguide/authentication-flow.html).\n\nFor more information see [Amazon Cognito Federated Identities](https://docs.aws.amazon.com/cognito/latest/developerguide/cognito-identity.html).","ref":"AWS.CognitoIdentity.html","title":"AWS.CognitoIdentity","type":"module"},{"doc":"Creates a new identity pool.\n\nThe identity pool is a store of user identity information that is specific to\nyour AWS account. The keys for `SupportedLoginProviders` are as follows:\n\n  * Facebook: `graph.facebook.com`\n\n  * Google: `accounts.google.com`\n\n  * Amazon: `www.amazon.com`\n\n  * Twitter: `api.twitter.com`\n\n  * Digits: `www.digits.com`\n\nYou must use AWS Developer credentials to call this API.","ref":"AWS.CognitoIdentity.html#create_identity_pool/3","title":"AWS.CognitoIdentity.create_identity_pool/3","type":"function"},{"doc":"Deletes identities from an identity pool.\n\nYou can specify a list of 1-60 identities that you want to delete.\n\nYou must use AWS Developer credentials to call this API.","ref":"AWS.CognitoIdentity.html#delete_identities/3","title":"AWS.CognitoIdentity.delete_identities/3","type":"function"},{"doc":"Deletes an identity pool.\n\nOnce a pool is deleted, users will not be able to authenticate with the pool.\n\nYou must use AWS Developer credentials to call this API.","ref":"AWS.CognitoIdentity.html#delete_identity_pool/3","title":"AWS.CognitoIdentity.delete_identity_pool/3","type":"function"},{"doc":"Returns metadata related to the given identity, including when the identity was\ncreated and any associated linked logins.\n\nYou must use AWS Developer credentials to call this API.","ref":"AWS.CognitoIdentity.html#describe_identity/3","title":"AWS.CognitoIdentity.describe_identity/3","type":"function"},{"doc":"Gets details about a particular identity pool, including the pool name, ID\ndescription, creation date, and current number of users.\n\nYou must use AWS Developer credentials to call this API.","ref":"AWS.CognitoIdentity.html#describe_identity_pool/3","title":"AWS.CognitoIdentity.describe_identity_pool/3","type":"function"},{"doc":"Returns credentials for the provided identity ID.\n\nAny provided logins will be validated against supported login providers. If the\ntoken is for cognito-identity.amazonaws.com, it will be passed through to AWS\nSecurity Token Service with the appropriate role for the token.\n\nThis is a public API. You do not need any credentials to call this API.","ref":"AWS.CognitoIdentity.html#get_credentials_for_identity/3","title":"AWS.CognitoIdentity.get_credentials_for_identity/3","type":"function"},{"doc":"Generates (or retrieves) a Cognito ID.\n\nSupplying multiple logins will create an implicit linked account.\n\nThis is a public API. You do not need any credentials to call this API.","ref":"AWS.CognitoIdentity.html#get_id/3","title":"AWS.CognitoIdentity.get_id/3","type":"function"},{"doc":"Gets the roles for an identity pool.\n\nYou must use AWS Developer credentials to call this API.","ref":"AWS.CognitoIdentity.html#get_identity_pool_roles/3","title":"AWS.CognitoIdentity.get_identity_pool_roles/3","type":"function"},{"doc":"Gets an OpenID token, using a known Cognito ID.\n\nThis known Cognito ID is returned by `GetId`. You can optionally add additional\nlogins for the identity. Supplying multiple logins creates an implicit link.\n\nThe OpenID token is valid for 10 minutes.\n\nThis is a public API. You do not need any credentials to call this API.","ref":"AWS.CognitoIdentity.html#get_open_id_token/3","title":"AWS.CognitoIdentity.get_open_id_token/3","type":"function"},{"doc":"Registers (or retrieves) a Cognito `IdentityId` and an OpenID Connect token for\na user authenticated by your backend authentication process.\n\nSupplying multiple logins will create an implicit linked account. You can only\nspecify one developer provider as part of the `Logins` map, which is linked to\nthe identity pool. The developer provider is the \"domain\" by which Cognito will\nrefer to your users.\n\nYou can use `GetOpenIdTokenForDeveloperIdentity` to create a new identity and to\nlink new logins (that is, user credentials issued by a public provider or\ndeveloper provider) to an existing identity. When you want to create a new\nidentity, the `IdentityId` should be null. When you want to associate a new\nlogin with an existing authenticated/unauthenticated identity, you can do so by\nproviding the existing `IdentityId`. This API will create the identity in the\nspecified `IdentityPoolId`.\n\nYou must use AWS Developer credentials to call this API.","ref":"AWS.CognitoIdentity.html#get_open_id_token_for_developer_identity/3","title":"AWS.CognitoIdentity.get_open_id_token_for_developer_identity/3","type":"function"},{"doc":"Use `GetPrincipalTagAttributeMap` to list all mappings between `PrincipalTags`\nand user attributes.","ref":"AWS.CognitoIdentity.html#get_principal_tag_attribute_map/3","title":"AWS.CognitoIdentity.get_principal_tag_attribute_map/3","type":"function"},{"doc":"Lists the identities in an identity pool.\n\nYou must use AWS Developer credentials to call this API.","ref":"AWS.CognitoIdentity.html#list_identities/3","title":"AWS.CognitoIdentity.list_identities/3","type":"function"},{"doc":"Lists all of the Cognito identity pools registered for your account.\n\nYou must use AWS Developer credentials to call this API.","ref":"AWS.CognitoIdentity.html#list_identity_pools/3","title":"AWS.CognitoIdentity.list_identity_pools/3","type":"function"},{"doc":"Lists the tags that are assigned to an Amazon Cognito identity pool.\n\nA tag is a label that you can apply to identity pools to categorize and manage\nthem in different ways, such as by purpose, owner, environment, or other\ncriteria.\n\nYou can use this action up to 10 times per second, per account.","ref":"AWS.CognitoIdentity.html#list_tags_for_resource/3","title":"AWS.CognitoIdentity.list_tags_for_resource/3","type":"function"},{"doc":"Retrieves the `IdentityID` associated with a `DeveloperUserIdentifier` or the\nlist of `DeveloperUserIdentifier` values associated with an `IdentityId` for an\nexisting identity.\n\nEither `IdentityID` or `DeveloperUserIdentifier` must not be null. If you supply\nonly one of these values, the other value will be searched in the database and\nreturned as a part of the response. If you supply both,\n`DeveloperUserIdentifier` will be matched against `IdentityID`. If the values\nare verified against the database, the response returns both values and is the\nsame as the request. Otherwise a `ResourceConflictException` is thrown.\n\n`LookupDeveloperIdentity` is intended for low-throughput control plane\noperations: for example, to enable customer service to locate an identity ID by\nusername. If you are using it for higher-volume operations such as user\nauthentication, your requests are likely to be throttled.\n`GetOpenIdTokenForDeveloperIdentity` is a better option for higher-volume\noperations for user authentication.\n\nYou must use AWS Developer credentials to call this API.","ref":"AWS.CognitoIdentity.html#lookup_developer_identity/3","title":"AWS.CognitoIdentity.lookup_developer_identity/3","type":"function"},{"doc":"Merges two users having different `IdentityId`s, existing in the same identity\npool, and identified by the same developer provider.\n\nYou can use this action to request that discrete users be merged and identified\nas a single user in the Cognito environment. Cognito associates the given source\nuser (`SourceUserIdentifier`) with the `IdentityId` of the\n`DestinationUserIdentifier`. Only developer-authenticated users can be merged.\nIf the users to be merged are associated with the same public provider, but as\ntwo different users, an exception will be thrown.\n\nThe number of linked logins is limited to 20. So, the number of linked logins\nfor the source user, `SourceUserIdentifier`, and the destination user,\n`DestinationUserIdentifier`, together should not be larger than 20. Otherwise,\nan exception will be thrown.\n\nYou must use AWS Developer credentials to call this API.","ref":"AWS.CognitoIdentity.html#merge_developer_identities/3","title":"AWS.CognitoIdentity.merge_developer_identities/3","type":"function"},{"doc":"","ref":"AWS.CognitoIdentity.html#metadata/0","title":"AWS.CognitoIdentity.metadata/0","type":"function"},{"doc":"Sets the roles for an identity pool.\n\nThese roles are used when making calls to `GetCredentialsForIdentity` action.\n\nYou must use AWS Developer credentials to call this API.","ref":"AWS.CognitoIdentity.html#set_identity_pool_roles/3","title":"AWS.CognitoIdentity.set_identity_pool_roles/3","type":"function"},{"doc":"You can use this operation to use default (username and clientID) attribute or\ncustom attribute mappings.","ref":"AWS.CognitoIdentity.html#set_principal_tag_attribute_map/3","title":"AWS.CognitoIdentity.set_principal_tag_attribute_map/3","type":"function"},{"doc":"Assigns a set of tags to the specified Amazon Cognito identity pool.\n\nA tag is a label that you can use to categorize and manage identity pools in\ndifferent ways, such as by purpose, owner, environment, or other criteria.\n\nEach tag consists of a key and value, both of which you define. A key is a\ngeneral category for more specific values. For example, if you have two versions\nof an identity pool, one for testing and another for production, you might\nassign an `Environment` tag key to both identity pools. The value of this key\nmight be `Test` for one identity pool and `Production` for the other.\n\nTags are useful for cost tracking and access control. You can activate your tags\nso that they appear on the Billing and Cost Management console, where you can\ntrack the costs associated with your identity pools. In an IAM policy, you can\nconstrain permissions for identity pools based on specific tags or tag values.\n\nYou can use this action up to 5 times per second, per account. An identity pool\ncan have as many as 50 tags.","ref":"AWS.CognitoIdentity.html#tag_resource/3","title":"AWS.CognitoIdentity.tag_resource/3","type":"function"},{"doc":"Unlinks a `DeveloperUserIdentifier` from an existing identity.\n\nUnlinked developer users will be considered new identities next time they are\nseen. If, for a given Cognito identity, you remove all federated identities as\nwell as the developer user identifier, the Cognito identity becomes\ninaccessible.\n\nYou must use AWS Developer credentials to call this API.","ref":"AWS.CognitoIdentity.html#unlink_developer_identity/3","title":"AWS.CognitoIdentity.unlink_developer_identity/3","type":"function"},{"doc":"Unlinks a federated identity from an existing account.\n\nUnlinked logins will be considered new identities next time they are seen.\nRemoving the last linked login will make this identity inaccessible.\n\nThis is a public API. You do not need any credentials to call this API.","ref":"AWS.CognitoIdentity.html#unlink_identity/3","title":"AWS.CognitoIdentity.unlink_identity/3","type":"function"},{"doc":"Removes the specified tags from the specified Amazon Cognito identity pool.\n\nYou can use this action up to 5 times per second, per account","ref":"AWS.CognitoIdentity.html#untag_resource/3","title":"AWS.CognitoIdentity.untag_resource/3","type":"function"},{"doc":"Updates an identity pool.\n\nYou must use AWS Developer credentials to call this API.","ref":"AWS.CognitoIdentity.html#update_identity_pool/3","title":"AWS.CognitoIdentity.update_identity_pool/3","type":"function"},{"doc":"With the Amazon Cognito user pools API, you can configure user pools and\nauthenticate users.\n\nTo authenticate users from third-party identity providers (IdPs) in this API,\nyou can [link IdP users to native user profiles](https://docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-pools-identity-federation-consolidate-users.html).\nLearn more about the authentication and authorization of federated users at\n[Adding user pool sign-in through a third party](https://docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-pools-identity-federation.html)\nand in the [User pool federation endpoints and hosted UI reference](https://docs.aws.amazon.com/cognito/latest/developerguide/cognito-userpools-server-contract-reference.html).\n\nThis API reference provides detailed information about API operations and object\ntypes in Amazon Cognito.\n\nAlong with resource management operations, the Amazon Cognito user pools API\nincludes classes of operations and authorization models for client-side and\nserver-side authentication of users. You can interact with operations in the\nAmazon Cognito user pools API as any of the following subjects.\n\n  1. An administrator who wants to configure user pools, app clients,\nusers, groups, or other user pool functions.\n\n  2. A server-side app, like a web application, that wants to use its\nAmazon Web Services privileges to manage, authenticate, or authorize a user.\n\n  3. A client-side app, like a mobile app, that wants to make\nunauthenticated requests to manage, authenticate, or authorize a user.\n\nFor more information, see [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)\nin the *Amazon Cognito Developer Guide*.\n\nWith your Amazon Web Services SDK, you can build the logic to support\noperational flows in every use case for this API. You can also make direct REST\nAPI requests to [Amazon Cognito user pools service endpoints](https://docs.aws.amazon.com/general/latest/gr/cognito_identity.html#cognito_identity_your_user_pools_region).\nThe following links can get you started with the `CognitoIdentityProvider`\nclient in other supported Amazon Web Services SDKs.\n\n  * [Amazon Web Services Command Line Interface](https://docs.aws.amazon.com/cli/latest/reference/cognito-idp/index.html#cli-aws-cognito-idp)\n\n  * [Amazon Web Services SDK for .NET](https://docs.aws.amazon.com/sdkfornet/v3/apidocs/items/CognitoIdentityProvider/TCognitoIdentityProviderClient.html)\n\n  * [Amazon Web Services SDK for C++](https://sdk.amazonaws.com/cpp/api/LATEST/aws-cpp-sdk-cognito-idp/html/class_aws_1_1_cognito_identity_provider_1_1_cognito_identity_provider_client.html)\n\n  * [Amazon Web Services SDK for Go](https://docs.aws.amazon.com/sdk-for-go/api/service/cognitoidentityprovider/#CognitoIdentityProvider)\n\n  * [Amazon Web Services SDK for Java V2](https://sdk.amazonaws.com/java/api/latest/software/amazon/awssdk/services/cognitoidentityprovider/CognitoIdentityProviderClient.html)\n\n  * [Amazon Web Services SDK for JavaScript](https://docs.aws.amazon.com/AWSJavaScriptSDK/latest/AWS/CognitoIdentityServiceProvider.html)\n\n  * [Amazon Web Services SDK for PHP V3](https://docs.aws.amazon.com/aws-sdk-php/v3/api/api-cognito-idp-2016-04-18.html)\n\n  * [Amazon Web Services SDK for Python](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cognito-idp.html)\n\n  * [Amazon Web Services SDK for Ruby V3](https://docs.aws.amazon.com/sdk-for-ruby/v3/api/Aws/CognitoIdentityProvider/Client.html)\n\nTo get started with an Amazon Web Services SDK, see [Tools to Build on Amazon Web Services](http://aws.amazon.com/developer/tools/). For example actions and\nscenarios, see [Code examples for Amazon Cognito Identity Provider using Amazon Web Services\nSDKs](https://docs.aws.amazon.com/cognito/latest/developerguide/service_code_examples_cognito-identity-provider.html).","ref":"AWS.CognitoIdentityProvider.html","title":"AWS.CognitoIdentityProvider","type":"module"},{"doc":"Adds additional user attributes to the user pool schema.\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#add_custom_attributes/3","title":"AWS.CognitoIdentityProvider.add_custom_attributes/3","type":"function"},{"doc":"[Signing Amazon Web Services API Requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#add_custom_attributes/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.add_custom_attributes/3","type":"function"},{"doc":"Adds a user to a group.\n\nA user who is in a group can present a preferred-role claim to an identity pool,\nand populates a `cognito:groups` claim to their access and identity tokens.\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#admin_add_user_to_group/3","title":"AWS.CognitoIdentityProvider.admin_add_user_to_group/3","type":"function"},{"doc":"[Signing Amazon Web Services API Requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#admin_add_user_to_group/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.admin_add_user_to_group/3","type":"function"},{"doc":"This IAM-authenticated API operation provides a code that Amazon Cognito sent to\nyour user when they signed up in your user pool.\n\nAfter your user enters their code, they confirm ownership of the email address\nor phone number that they provided, and their user account becomes active.\nDepending on your user pool configuration, your users will receive their\nconfirmation code in an email or SMS message.\n\nLocal users who signed up in your user pool are the only type of user who can\nconfirm sign-up with a code. Users who federate through an external identity\nprovider (IdP) have already been confirmed by their IdP. Administrator-created\nusers confirm their accounts when they respond to their invitation email message\nand choose a password.\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#admin_confirm_sign_up/3","title":"AWS.CognitoIdentityProvider.admin_confirm_sign_up/3","type":"function"},{"doc":"[Signing Amazon Web Services API Requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#admin_confirm_sign_up/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.admin_confirm_sign_up/3","type":"function"},{"doc":"Creates a new user in the specified user pool.\n\nIf `MessageAction` isn't set, the default is to send a welcome message via email\nor phone (SMS).\n\nThis action might generate an SMS text message. Starting June 1, 2021, US\ntelecom carriers require you to register an origination phone number before you\ncan send SMS messages to US phone numbers. If you use SMS text messages in\nAmazon Cognito, you must register a phone number with [Amazon Pinpoint](https://console.aws.amazon.com/pinpoint/home/). Amazon Cognito uses\nthe registered number automatically. Otherwise, Amazon Cognito users who must\nreceive SMS messages might not be able to sign up, activate their accounts, or\nsign in.\n\nIf you have never used SMS text messages with Amazon Cognito or any other Amazon\nWeb Service, Amazon Simple Notification Service might place your account in the\nSMS sandbox. In * [sandbox mode](https://docs.aws.amazon.com/sns/latest/dg/sns-sms-sandbox.html) *, you can\nsend messages only to verified phone numbers. After you test your app while in\nthe sandbox environment, you can move out of the sandbox and into production.\nFor more information, see [ SMS message settings for Amazon Cognito user pools](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-sms-settings.html)\nin the *Amazon Cognito Developer Guide*.\n\nThis message is based on a template that you configured in your call to create\nor update a user pool. This template includes your custom sign-up instructions\nand placeholders for user name and temporary password.\n\nAlternatively, you can call `AdminCreateUser` with `SUPPRESS` for the\n`MessageAction` parameter, and Amazon Cognito won't send any email.\n\nIn either case, the user will be in the `FORCE_CHANGE_PASSWORD` state until they\nsign in and change their password.\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#admin_create_user/3","title":"AWS.CognitoIdentityProvider.admin_create_user/3","type":"function"},{"doc":"[Signing Amazon Web Services API Requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#admin_create_user/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.admin_create_user/3","type":"function"},{"doc":"Deletes a user as an administrator.\n\nWorks on any user.\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#admin_delete_user/3","title":"AWS.CognitoIdentityProvider.admin_delete_user/3","type":"function"},{"doc":"[Signing Amazon Web Services API Requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#admin_delete_user/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.admin_delete_user/3","type":"function"},{"doc":"Deletes the user attributes in a user pool as an administrator.\n\nWorks on any user.\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#admin_delete_user_attributes/3","title":"AWS.CognitoIdentityProvider.admin_delete_user_attributes/3","type":"function"},{"doc":"[Signing Amazon Web Services API Requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#admin_delete_user_attributes/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.admin_delete_user_attributes/3","type":"function"},{"doc":"Prevents the user from signing in with the specified external (SAML or social)\nidentity provider (IdP).\n\nIf the user that you want to deactivate is a Amazon Cognito user pools native\nusername + password user, they can't use their password to sign in. If the user\nto deactivate is a linked external IdP user, any link between that user and an\nexisting user is removed. When the external user signs in again, and the user is\nno longer attached to the previously linked `DestinationUser`, the user must\ncreate a new user account. See\n[AdminLinkProviderForUser](https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminLinkProviderForUser.html).  The `ProviderName` must match the value specified when creating an IdP for the\npool.\n\nTo deactivate a native username + password user, the `ProviderName` value must\nbe `Cognito` and the `ProviderAttributeName` must be `Cognito_Subject`. The\n`ProviderAttributeValue` must be the name that is used in the user pool for the\nuser.\n\nThe `ProviderAttributeName` must always be `Cognito_Subject` for social IdPs.\nThe `ProviderAttributeValue` must always be the exact subject that was used when\nthe user was originally linked as a source user.\n\nFor de-linking a SAML identity, there are two scenarios. If the linked identity\nhas not yet been used to sign in, the `ProviderAttributeName` and\n`ProviderAttributeValue` must be the same values that were used for the\n`SourceUser` when the identities were originally linked using `\nAdminLinkProviderForUser` call. (If the linking was done with\n`ProviderAttributeName` set to `Cognito_Subject`, the same applies here).\nHowever, if the user has already signed in, the `ProviderAttributeName` must be\n`Cognito_Subject` and `ProviderAttributeValue` must be the subject of the SAML\nassertion.\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#admin_disable_provider_for_user/3","title":"AWS.CognitoIdentityProvider.admin_disable_provider_for_user/3","type":"function"},{"doc":"[Signing Amazon Web Services API\nRequests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#admin_disable_provider_for_user/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.admin_disable_provider_for_user/3","type":"function"},{"doc":"Deactivates a user and revokes all access tokens for the user.\n\nA deactivated user can't sign in, but still appears in the responses to\n`GetUser` and `ListUsers` API requests.\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#admin_disable_user/3","title":"AWS.CognitoIdentityProvider.admin_disable_user/3","type":"function"},{"doc":"[Signing Amazon Web Services API Requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#admin_disable_user/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.admin_disable_user/3","type":"function"},{"doc":"Enables the specified user as an administrator.\n\nWorks on any user.\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#admin_enable_user/3","title":"AWS.CognitoIdentityProvider.admin_enable_user/3","type":"function"},{"doc":"[Signing Amazon Web Services API Requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#admin_enable_user/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.admin_enable_user/3","type":"function"},{"doc":"Forgets the device, as an administrator.\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#admin_forget_device/3","title":"AWS.CognitoIdentityProvider.admin_forget_device/3","type":"function"},{"doc":"[Signing Amazon Web Services API Requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#admin_forget_device/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.admin_forget_device/3","type":"function"},{"doc":"Gets the device, as an administrator.\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#admin_get_device/3","title":"AWS.CognitoIdentityProvider.admin_get_device/3","type":"function"},{"doc":"[Signing Amazon Web Services API Requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#admin_get_device/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.admin_get_device/3","type":"function"},{"doc":"Gets the specified user by user name in a user pool as an administrator.\n\nWorks on any user.\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#admin_get_user/3","title":"AWS.CognitoIdentityProvider.admin_get_user/3","type":"function"},{"doc":"[Signing Amazon Web Services API Requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#admin_get_user/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.admin_get_user/3","type":"function"},{"doc":"Initiates the authentication flow, as an administrator.\n\nThis action might generate an SMS text message. Starting June 1, 2021, US\ntelecom carriers require you to register an origination phone number before you\ncan send SMS messages to US phone numbers. If you use SMS text messages in\nAmazon Cognito, you must register a phone number with [Amazon Pinpoint](https://console.aws.amazon.com/pinpoint/home/). Amazon Cognito uses\nthe registered number automatically. Otherwise, Amazon Cognito users who must\nreceive SMS messages might not be able to sign up, activate their accounts, or\nsign in.\n\nIf you have never used SMS text messages with Amazon Cognito or any other Amazon\nWeb Service, Amazon Simple Notification Service might place your account in the\nSMS sandbox. In * [sandbox mode](https://docs.aws.amazon.com/sns/latest/dg/sns-sms-sandbox.html) *, you can\nsend messages only to verified phone numbers. After you test your app while in\nthe sandbox environment, you can move out of the sandbox and into production.\nFor more information, see [ SMS message settings for Amazon Cognito user pools](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-sms-settings.html)\nin the *Amazon Cognito Developer Guide*.\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#admin_initiate_auth/3","title":"AWS.CognitoIdentityProvider.admin_initiate_auth/3","type":"function"},{"doc":"[Signing Amazon Web Services API Requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#admin_initiate_auth/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.admin_initiate_auth/3","type":"function"},{"doc":"Links an existing user account in a user pool (`DestinationUser`) to an identity\nfrom an external IdP (`SourceUser`) based on a specified attribute name and\nvalue from the external IdP.\n\nThis allows you to create a link from the existing user account to an external\nfederated user identity that has not yet been used to sign in. You can then use\nthe federated user identity to sign in as the existing user account.\n\nFor example, if there is an existing user with a username and password, this API\nlinks that user to a federated user identity. When the user signs in with a\nfederated user identity, they sign in as the existing user account.\n\nThe maximum number of federated identities linked to a user is five.\n\nBecause this API allows a user with an external federated identity to sign in as\nan existing user in the user pool, it is critical that it only be used with\nexternal IdPs and provider attributes that have been trusted by the application\nowner.\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#admin_link_provider_for_user/3","title":"AWS.CognitoIdentityProvider.admin_link_provider_for_user/3","type":"function"},{"doc":"[Signing Amazon Web Services API Requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#admin_link_provider_for_user/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.admin_link_provider_for_user/3","type":"function"},{"doc":"Lists devices, as an administrator.\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#admin_list_devices/3","title":"AWS.CognitoIdentityProvider.admin_list_devices/3","type":"function"},{"doc":"[Signing Amazon Web Services API Requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#admin_list_devices/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.admin_list_devices/3","type":"function"},{"doc":"Lists the groups that a user belongs to.\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#admin_list_groups_for_user/3","title":"AWS.CognitoIdentityProvider.admin_list_groups_for_user/3","type":"function"},{"doc":"[Signing Amazon Web Services API Requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#admin_list_groups_for_user/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.admin_list_groups_for_user/3","type":"function"},{"doc":"A history of user activity and any risks detected as part of Amazon Cognito\nadvanced security.\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#admin_list_user_auth_events/3","title":"AWS.CognitoIdentityProvider.admin_list_user_auth_events/3","type":"function"},{"doc":"[Signing Amazon Web Services API Requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#admin_list_user_auth_events/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.admin_list_user_auth_events/3","type":"function"},{"doc":"Removes the specified user from the specified group.\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#admin_remove_user_from_group/3","title":"AWS.CognitoIdentityProvider.admin_remove_user_from_group/3","type":"function"},{"doc":"[Signing Amazon Web Services API Requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#admin_remove_user_from_group/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.admin_remove_user_from_group/3","type":"function"},{"doc":"Resets the specified user's password in a user pool as an administrator.\n\nWorks on any user.\n\nThis action might generate an SMS text message. Starting June 1, 2021, US\ntelecom carriers require you to register an origination phone number before you\ncan send SMS messages to US phone numbers. If you use SMS text messages in\nAmazon Cognito, you must register a phone number with [Amazon Pinpoint](https://console.aws.amazon.com/pinpoint/home/). Amazon Cognito uses\nthe registered number automatically. Otherwise, Amazon Cognito users who must\nreceive SMS messages might not be able to sign up, activate their accounts, or\nsign in.\n\nIf you have never used SMS text messages with Amazon Cognito or any other Amazon\nWeb Service, Amazon Simple Notification Service might place your account in the\nSMS sandbox. In * [sandbox mode](https://docs.aws.amazon.com/sns/latest/dg/sns-sms-sandbox.html) *, you can\nsend messages only to verified phone numbers. After you test your app while in\nthe sandbox environment, you can move out of the sandbox and into production.\nFor more information, see [ SMS message settings for Amazon Cognito user pools](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-sms-settings.html)\nin the *Amazon Cognito Developer Guide*.\n\nDeactivates a user's password, requiring them to change it. If a user tries to\nsign in after the API is called, Amazon Cognito responds with a\n`PasswordResetRequiredException` error. Your app must then perform the actions\nthat reset your user's password: the forgot-password flow. In addition, if the\nuser pool has phone verification selected and a verified phone number exists for\nthe user, or if email verification is selected and a verified email exists for\nthe user, calling this API will also result in sending a message to the end user\nwith the code to change their password.\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#admin_reset_user_password/3","title":"AWS.CognitoIdentityProvider.admin_reset_user_password/3","type":"function"},{"doc":"[Signing Amazon Web Services API Requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#admin_reset_user_password/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.admin_reset_user_password/3","type":"function"},{"doc":"Some API operations in a user pool generate a challenge, like a prompt for an\nMFA code, for device authentication that bypasses MFA, or for a custom\nauthentication challenge.\n\nAn `AdminRespondToAuthChallenge` API request provides the answer to that\nchallenge, like a code or a secure remote password (SRP). The parameters of a\nresponse to an authentication challenge vary with the type of challenge.\n\nFor more information about custom authentication challenges, see [Custom authentication challenge Lambda\ntriggers](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-lambda-challenge.html).\n\nThis action might generate an SMS text message. Starting June 1, 2021, US\ntelecom carriers require you to register an origination phone number before you\ncan send SMS messages to US phone numbers. If you use SMS text messages in\nAmazon Cognito, you must register a phone number with [Amazon Pinpoint](https://console.aws.amazon.com/pinpoint/home/). Amazon Cognito uses\nthe registered number automatically. Otherwise, Amazon Cognito users who must\nreceive SMS messages might not be able to sign up, activate their accounts, or\nsign in.\n\nIf you have never used SMS text messages with Amazon Cognito or any other Amazon\nWeb Service, Amazon Simple Notification Service might place your account in the\nSMS sandbox. In * [sandbox mode](https://docs.aws.amazon.com/sns/latest/dg/sns-sms-sandbox.html) *, you can\nsend messages only to verified phone numbers. After you test your app while in\nthe sandbox environment, you can move out of the sandbox and into production.\nFor more information, see [ SMS message settings for Amazon Cognito user pools](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-sms-settings.html)\nin the *Amazon Cognito Developer Guide*.\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#admin_respond_to_auth_challenge/3","title":"AWS.CognitoIdentityProvider.admin_respond_to_auth_challenge/3","type":"function"},{"doc":"[Signing Amazon Web Services API Requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#admin_respond_to_auth_challenge/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.admin_respond_to_auth_challenge/3","type":"function"},{"doc":"The user's multi-factor authentication (MFA) preference, including which MFA\noptions are activated, and if any are preferred.\n\nOnly one factor can be set as preferred. The preferred MFA factor will be used\nto authenticate a user if multiple factors are activated. If multiple options\nare activated and no preference is set, a challenge to choose an MFA option will\nbe returned during sign-in.\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#admin_set_user_mfa_preference/3","title":"AWS.CognitoIdentityProvider.admin_set_user_mfa_preference/3","type":"function"},{"doc":"[Signing Amazon Web Services API Requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#admin_set_user_mfa_preference/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.admin_set_user_mfa_preference/3","type":"function"},{"doc":"Sets the specified user's password in a user pool as an administrator.\n\nWorks on any user.\n\nThe password can be temporary or permanent. If it is temporary, the user status\nenters the `FORCE_CHANGE_PASSWORD` state. When the user next tries to sign in,\nthe InitiateAuth/AdminInitiateAuth response will contain the\n`NEW_PASSWORD_REQUIRED` challenge. If the user doesn't sign in before it\nexpires, the user won't be able to sign in, and an administrator must reset\ntheir password.\n\nOnce the user has set a new password, or the password is permanent, the user\nstatus is set to `Confirmed`.\n\n`AdminSetUserPassword` can set a password for the user profile that Amazon\nCognito creates for third-party federated users. When you set a password, the\nfederated user's status changes from `EXTERNAL_PROVIDER` to `CONFIRMED`. A user\nin this state can sign in as a federated user, and initiate authentication flows\nin the API like a linked native user. They can also modify their password and\nattributes in token-authenticated API requests like `ChangePassword` and\n`UpdateUserAttributes`. As a best security practice and to keep users in sync\nwith your external IdP, don't set passwords on federated user profiles. To set\nup a federated user for native sign-in with a linked native user, refer to\n[Linking federated users to an existing user profile](https://docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-pools-identity-federation-consolidate-users.html).\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#admin_set_user_password/3","title":"AWS.CognitoIdentityProvider.admin_set_user_password/3","type":"function"},{"doc":"[Signing Amazon Web Services API Requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#admin_set_user_password/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.admin_set_user_password/3","type":"function"},{"doc":"*This action is no longer supported.* You can use it to configure only SMS MFA.\n\nYou can't use it to configure time-based one-time password (TOTP) software token\nMFA. To configure either type of MFA, use\n[AdminSetUserMFAPreference](https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminSetUserMFAPreference.html) instead.\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#admin_set_user_settings/3","title":"AWS.CognitoIdentityProvider.admin_set_user_settings/3","type":"function"},{"doc":"[Signing Amazon Web Services API\nRequests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#admin_set_user_settings/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.admin_set_user_settings/3","type":"function"},{"doc":"Provides feedback for an authentication event indicating if it was from a valid\nuser.\n\nThis feedback is used for improving the risk evaluation decision for the user\npool as part of Amazon Cognito advanced security.\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#admin_update_auth_event_feedback/3","title":"AWS.CognitoIdentityProvider.admin_update_auth_event_feedback/3","type":"function"},{"doc":"[Signing Amazon Web Services API Requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#admin_update_auth_event_feedback/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.admin_update_auth_event_feedback/3","type":"function"},{"doc":"Updates the device status as an administrator.\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#admin_update_device_status/3","title":"AWS.CognitoIdentityProvider.admin_update_device_status/3","type":"function"},{"doc":"[Signing Amazon Web Services API Requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#admin_update_device_status/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.admin_update_device_status/3","type":"function"},{"doc":"This action might generate an SMS text message.\n\nStarting June 1, 2021, US telecom carriers require you to register an\norigination phone number before you can send SMS messages to US phone numbers.\nIf you use SMS text messages in Amazon Cognito, you must register a phone number\nwith [Amazon Pinpoint](https://console.aws.amazon.com/pinpoint/home/). Amazon Cognito uses the registered number automatically. Otherwise, Amazon Cognito\nusers who must receive SMS messages might not be able to sign up, activate their\naccounts, or sign in.\n\nIf you have never used SMS text messages with Amazon Cognito or any other Amazon\nWeb Service, Amazon Simple Notification Service might place your account in the\nSMS sandbox. In * [sandbox\nmode](https://docs.aws.amazon.com/sns/latest/dg/sns-sms-sandbox.html) *, you can\nsend messages only to verified phone numbers. After you test your app while in\nthe sandbox environment, you can move out of the sandbox and into production.\nFor more information, see [ SMS message settings for Amazon Cognito user pools](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-sms-settings.html)\nin the *Amazon Cognito Developer Guide*.\n\nUpdates the specified user's attributes, including developer attributes, as an\nadministrator. Works on any user. To delete an attribute from your user, submit\nthe attribute in your API request with a blank value.\n\nFor custom attributes, you must prepend the `custom:` prefix to the attribute\nname.\n\nIn addition to updating user attributes, this API can also be used to mark phone\nand email as verified.\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#admin_update_user_attributes/3","title":"AWS.CognitoIdentityProvider.admin_update_user_attributes/3","type":"function"},{"doc":"[Signing Amazon Web Services API Requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#admin_update_user_attributes/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.admin_update_user_attributes/3","type":"function"},{"doc":"Invalidates the identity, access, and refresh tokens that Amazon Cognito issued\nto a user.\n\nCall this operation with your administrative credentials when your user signs\nout of your app. This results in the following behavior.\n\n  * Amazon Cognito no longer accepts *token-authorized* user\noperations that you authorize with a signed-out user's access tokens. For more\ninformation, see [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html).\n\nAmazon Cognito returns an `Access Token has been revoked` error when your app\nattempts to authorize a user pools API request with a revoked access token that\ncontains the scope `aws.cognito.signin.user.admin`.\n\n  * Amazon Cognito no longer accepts a signed-out user's ID token in a\n[GetId\n](https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_GetId.html)\nrequest to an identity pool with `ServerSideTokenCheck` enabled for its user\npool IdP configuration in\n[CognitoIdentityProvider](https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_CognitoIdentityProvider.html).     * Amazon Cognito no longer accepts a signed-out user's refresh\ntokens in refresh requests.\n\nOther requests might be valid until your user's token expires.\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#admin_user_global_sign_out/3","title":"AWS.CognitoIdentityProvider.admin_user_global_sign_out/3","type":"function"},{"doc":"[Signing Amazon Web Services API\nRequests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#admin_user_global_sign_out/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.admin_user_global_sign_out/3","type":"function"},{"doc":"Begins setup of time-based one-time password (TOTP) multi-factor authentication\n(MFA) for a user, with a unique private key that Amazon Cognito generates and\nreturns in the API response.\n\nYou can authorize an `AssociateSoftwareToken` request with either the user's\naccess token, or a session string from a challenge response that you received\nfrom Amazon Cognito.\n\nAmazon Cognito disassociates an existing software token when you verify the new\ntoken in a [\nVerifySoftwareToken](https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_VerifySoftwareToken.html)\nAPI request. If you don't verify the software token and your user pool doesn't\nrequire MFA, the user can then authenticate with user name and password\ncredentials alone. If your user pool requires TOTP MFA, Amazon Cognito generates\nan `MFA_SETUP` or `SOFTWARE_TOKEN_SETUP` challenge each time your user signs.\nComplete setup with `AssociateSoftwareToken` and `VerifySoftwareToken`.\n\nAfter you set up software token MFA for your user, Amazon Cognito generates a\n`SOFTWARE_TOKEN_MFA` challenge when they authenticate. Respond to this challenge\nwith your user's TOTP.\n\nAmazon Cognito doesn't evaluate Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you can't use IAM\ncredentials to authorize requests, and you can't grant IAM permissions in\npolicies. For more information about authorization models in Amazon Cognito, see\n[Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html).","ref":"AWS.CognitoIdentityProvider.html#associate_software_token/3","title":"AWS.CognitoIdentityProvider.associate_software_token/3","type":"function"},{"doc":"Changes the password for a specified user in a user pool.\n\nAuthorize this action with a signed-in user's access token. It must include the\nscope `aws.cognito.signin.user.admin`.\n\nAmazon Cognito doesn't evaluate Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you can't use IAM\ncredentials to authorize requests, and you can't grant IAM permissions in\npolicies. For more information about authorization models in Amazon Cognito, see\n[Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html).","ref":"AWS.CognitoIdentityProvider.html#change_password/3","title":"AWS.CognitoIdentityProvider.change_password/3","type":"function"},{"doc":"Confirms tracking of the device.\n\nThis API call is the call that begins device tracking. For more information\nabout device authentication, see [Working with user devices in your user pool](https://docs.aws.amazon.com/cognito/latest/developerguide/amazon-cognito-user-pools-device-tracking.html).\n\nAuthorize this action with a signed-in user's access token. It must include the\nscope `aws.cognito.signin.user.admin`.\n\nAmazon Cognito doesn't evaluate Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you can't use IAM\ncredentials to authorize requests, and you can't grant IAM permissions in\npolicies. For more information about authorization models in Amazon Cognito, see\n[Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html).","ref":"AWS.CognitoIdentityProvider.html#confirm_device/3","title":"AWS.CognitoIdentityProvider.confirm_device/3","type":"function"},{"doc":"Allows a user to enter a confirmation code to reset a forgotten password.\n\nAmazon Cognito doesn't evaluate Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you can't use IAM\ncredentials to authorize requests, and you can't grant IAM permissions in\npolicies. For more information about authorization models in Amazon Cognito, see\n[Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html).","ref":"AWS.CognitoIdentityProvider.html#confirm_forgot_password/3","title":"AWS.CognitoIdentityProvider.confirm_forgot_password/3","type":"function"},{"doc":"This public API operation provides a code that Amazon Cognito sent to your user\nwhen they signed up in your user pool via the\n[SignUp](https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_SignUp.html) API operation.\n\nAfter your user enters their code, they confirm ownership of the email address\nor phone number that they provided, and their user account becomes active.\nDepending on your user pool configuration, your users will receive their\nconfirmation code in an email or SMS message.\n\nLocal users who signed up in your user pool are the only type of user who can\nconfirm sign-up with a code. Users who federate through an external identity\nprovider (IdP) have already been confirmed by their IdP. Administrator-created\nusers, users created with the\n[AdminCreateUser](https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminCreateUser.html)\nAPI operation, confirm their accounts when they respond to their invitation\nemail message and choose a password. They do not receive a confirmation code.\nInstead, they receive a temporary password.\n\nAmazon Cognito doesn't evaluate Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you can't use IAM\ncredentials to authorize requests, and you can't grant IAM permissions in\npolicies. For more information about authorization models in Amazon Cognito, see\n[Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html).","ref":"AWS.CognitoIdentityProvider.html#confirm_sign_up/3","title":"AWS.CognitoIdentityProvider.confirm_sign_up/3","type":"function"},{"doc":"Creates a new group in the specified user pool.\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#create_group/3","title":"AWS.CognitoIdentityProvider.create_group/3","type":"function"},{"doc":"[Signing Amazon Web Services API Requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#create_group/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.create_group/3","type":"function"},{"doc":"Adds a configuration and trust relationship between a third-party identity\nprovider (IdP) and a user pool.\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#create_identity_provider/3","title":"AWS.CognitoIdentityProvider.create_identity_provider/3","type":"function"},{"doc":"[Signing Amazon Web Services API Requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#create_identity_provider/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.create_identity_provider/3","type":"function"},{"doc":"Creates a new OAuth2.0 resource server and defines custom scopes within it.\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#create_resource_server/3","title":"AWS.CognitoIdentityProvider.create_resource_server/3","type":"function"},{"doc":"[Signing Amazon Web Services API Requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#create_resource_server/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.create_resource_server/3","type":"function"},{"doc":"Creates a user import job.\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#create_user_import_job/3","title":"AWS.CognitoIdentityProvider.create_user_import_job/3","type":"function"},{"doc":"[Signing Amazon Web Services API Requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#create_user_import_job/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.create_user_import_job/3","type":"function"},{"doc":"This action might generate an SMS text message.\n\nStarting June 1, 2021, US telecom carriers require you to register an\norigination phone number before you can send SMS messages to US phone numbers.\nIf you use SMS text messages in Amazon Cognito, you must register a phone number\nwith [Amazon Pinpoint](https://console.aws.amazon.com/pinpoint/home/). Amazon Cognito uses the registered number automatically. Otherwise, Amazon Cognito\nusers who must receive SMS messages might not be able to sign up, activate their\naccounts, or sign in.\n\nIf you have never used SMS text messages with Amazon Cognito or any other Amazon\nWeb Service, Amazon Simple Notification Service might place your account in the\nSMS sandbox. In * [sandbox\nmode](https://docs.aws.amazon.com/sns/latest/dg/sns-sms-sandbox.html) *, you can\nsend messages only to verified phone numbers. After you test your app while in\nthe sandbox environment, you can move out of the sandbox and into production.\nFor more information, see [ SMS message settings for Amazon Cognito user pools](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-sms-settings.html)\nin the *Amazon Cognito Developer Guide*.\n\nCreates a new Amazon Cognito user pool and sets the password policy for the\npool.\n\nIf you don't provide a value for an attribute, Amazon Cognito sets it to its\ndefault value.\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#create_user_pool/3","title":"AWS.CognitoIdentityProvider.create_user_pool/3","type":"function"},{"doc":"[Signing Amazon Web Services API Requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#create_user_pool/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.create_user_pool/3","type":"function"},{"doc":"Creates the user pool client.\n\nWhen you create a new user pool client, token revocation is automatically\nactivated. For more information about revoking tokens, see\n[RevokeToken](https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_RevokeToken.html).  If you don't provide a value for an attribute, Amazon Cognito sets it to its\ndefault value.\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#create_user_pool_client/3","title":"AWS.CognitoIdentityProvider.create_user_pool_client/3","type":"function"},{"doc":"[Signing Amazon Web Services API\nRequests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#create_user_pool_client/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.create_user_pool_client/3","type":"function"},{"doc":"Creates a new domain for a user pool.\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#create_user_pool_domain/3","title":"AWS.CognitoIdentityProvider.create_user_pool_domain/3","type":"function"},{"doc":"[Signing Amazon Web Services API Requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#create_user_pool_domain/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.create_user_pool_domain/3","type":"function"},{"doc":"Deletes a group.\n\nCalling this action requires developer credentials.","ref":"AWS.CognitoIdentityProvider.html#delete_group/3","title":"AWS.CognitoIdentityProvider.delete_group/3","type":"function"},{"doc":"Deletes an IdP for a user pool.","ref":"AWS.CognitoIdentityProvider.html#delete_identity_provider/3","title":"AWS.CognitoIdentityProvider.delete_identity_provider/3","type":"function"},{"doc":"Deletes a resource server.","ref":"AWS.CognitoIdentityProvider.html#delete_resource_server/3","title":"AWS.CognitoIdentityProvider.delete_resource_server/3","type":"function"},{"doc":"Allows a user to delete their own user profile.\n\nAuthorize this action with a signed-in user's access token. It must include the\nscope `aws.cognito.signin.user.admin`.\n\nAmazon Cognito doesn't evaluate Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you can't use IAM\ncredentials to authorize requests, and you can't grant IAM permissions in\npolicies. For more information about authorization models in Amazon Cognito, see\n[Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html).","ref":"AWS.CognitoIdentityProvider.html#delete_user/3","title":"AWS.CognitoIdentityProvider.delete_user/3","type":"function"},{"doc":"Deletes the attributes for a user.\n\nAuthorize this action with a signed-in user's access token. It must include the\nscope `aws.cognito.signin.user.admin`.\n\nAmazon Cognito doesn't evaluate Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you can't use IAM\ncredentials to authorize requests, and you can't grant IAM permissions in\npolicies. For more information about authorization models in Amazon Cognito, see\n[Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html).","ref":"AWS.CognitoIdentityProvider.html#delete_user_attributes/3","title":"AWS.CognitoIdentityProvider.delete_user_attributes/3","type":"function"},{"doc":"Deletes the specified Amazon Cognito user pool.","ref":"AWS.CognitoIdentityProvider.html#delete_user_pool/3","title":"AWS.CognitoIdentityProvider.delete_user_pool/3","type":"function"},{"doc":"Allows the developer to delete the user pool client.","ref":"AWS.CognitoIdentityProvider.html#delete_user_pool_client/3","title":"AWS.CognitoIdentityProvider.delete_user_pool_client/3","type":"function"},{"doc":"Deletes a domain for a user pool.","ref":"AWS.CognitoIdentityProvider.html#delete_user_pool_domain/3","title":"AWS.CognitoIdentityProvider.delete_user_pool_domain/3","type":"function"},{"doc":"Gets information about a specific IdP.","ref":"AWS.CognitoIdentityProvider.html#describe_identity_provider/3","title":"AWS.CognitoIdentityProvider.describe_identity_provider/3","type":"function"},{"doc":"Describes a resource server.","ref":"AWS.CognitoIdentityProvider.html#describe_resource_server/3","title":"AWS.CognitoIdentityProvider.describe_resource_server/3","type":"function"},{"doc":"Describes the risk configuration.","ref":"AWS.CognitoIdentityProvider.html#describe_risk_configuration/3","title":"AWS.CognitoIdentityProvider.describe_risk_configuration/3","type":"function"},{"doc":"Describes the user import job.","ref":"AWS.CognitoIdentityProvider.html#describe_user_import_job/3","title":"AWS.CognitoIdentityProvider.describe_user_import_job/3","type":"function"},{"doc":"Returns the configuration information and metadata of the specified user pool.\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#describe_user_pool/3","title":"AWS.CognitoIdentityProvider.describe_user_pool/3","type":"function"},{"doc":"[Signing Amazon Web Services API Requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#describe_user_pool/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.describe_user_pool/3","type":"function"},{"doc":"Client method for returning the configuration information and metadata of the\nspecified user pool app client.\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#describe_user_pool_client/3","title":"AWS.CognitoIdentityProvider.describe_user_pool_client/3","type":"function"},{"doc":"[Signing Amazon Web Services API Requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#describe_user_pool_client/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.describe_user_pool_client/3","type":"function"},{"doc":"Gets information about a domain.","ref":"AWS.CognitoIdentityProvider.html#describe_user_pool_domain/3","title":"AWS.CognitoIdentityProvider.describe_user_pool_domain/3","type":"function"},{"doc":"Forgets the specified device.\n\nFor more information about device authentication, see [Working with user devices in your user\npool](https://docs.aws.amazon.com/cognito/latest/developerguide/amazon-cognito-user-pools-device-tracking.html).\n\nAuthorize this action with a signed-in user's access token. It must include the\nscope `aws.cognito.signin.user.admin`.\n\nAmazon Cognito doesn't evaluate Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you can't use IAM\ncredentials to authorize requests, and you can't grant IAM permissions in\npolicies. For more information about authorization models in Amazon Cognito, see\n[Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html).","ref":"AWS.CognitoIdentityProvider.html#forget_device/3","title":"AWS.CognitoIdentityProvider.forget_device/3","type":"function"},{"doc":"Calling this API causes a message to be sent to the end user with a confirmation\ncode that is required to change the user's password.\n\nFor the `Username` parameter, you can use the username or user alias. The method\nused to send the confirmation code is sent according to the specified\nAccountRecoverySetting. For more information, see [Recovering User Accounts](https://docs.aws.amazon.com/cognito/latest/developerguide/how-to-recover-a-user-account.html)\nin the *Amazon Cognito Developer Guide*. To use the confirmation code for\nresetting the password, call\n[ConfirmForgotPassword](https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_ConfirmForgotPassword.html).  If neither a verified phone number nor a verified email exists, this API returns\n`InvalidParameterException`. If your app client has a client secret and you\ndon't provide a `SECRET_HASH` parameter, this API returns\n`NotAuthorizedException`.\n\nAmazon Cognito doesn't evaluate Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you can't use IAM\ncredentials to authorize requests, and you can't grant IAM permissions in\npolicies. For more information about authorization models in Amazon Cognito, see\n[Using the Amazon Cognito user pools API and user pool\nendpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html).\n\nThis action might generate an SMS text message. Starting June 1, 2021, US\ntelecom carriers require you to register an origination phone number before you\ncan send SMS messages to US phone numbers. If you use SMS text messages in\nAmazon Cognito, you must register a phone number with [Amazon Pinpoint](https://console.aws.amazon.com/pinpoint/home/). Amazon Cognito uses\nthe registered number automatically. Otherwise, Amazon Cognito users who must\nreceive SMS messages might not be able to sign up, activate their accounts, or\nsign in.\n\nIf you have never used SMS text messages with Amazon Cognito or any other Amazon\nWeb Service, Amazon Simple Notification Service might place your account in the\nSMS sandbox. In * [sandbox mode](https://docs.aws.amazon.com/sns/latest/dg/sns-sms-sandbox.html) *, you can\nsend messages only to verified phone numbers. After you test your app while in\nthe sandbox environment, you can move out of the sandbox and into production.\nFor more information, see [ SMS message settings for Amazon Cognito user pools](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-sms-settings.html)\nin the *Amazon Cognito Developer Guide*.","ref":"AWS.CognitoIdentityProvider.html#forgot_password/3","title":"AWS.CognitoIdentityProvider.forgot_password/3","type":"function"},{"doc":"Gets the header information for the comma-separated value (CSV) file to be used\nas input for the user import job.","ref":"AWS.CognitoIdentityProvider.html#get_csv_header/3","title":"AWS.CognitoIdentityProvider.get_csv_header/3","type":"function"},{"doc":"Gets the device.\n\nFor more information about device authentication, see [Working with user devices in your user\npool](https://docs.aws.amazon.com/cognito/latest/developerguide/amazon-cognito-user-pools-device-tracking.html).\n\nAuthorize this action with a signed-in user's access token. It must include the\nscope `aws.cognito.signin.user.admin`.\n\nAmazon Cognito doesn't evaluate Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you can't use IAM\ncredentials to authorize requests, and you can't grant IAM permissions in\npolicies. For more information about authorization models in Amazon Cognito, see\n[Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html).","ref":"AWS.CognitoIdentityProvider.html#get_device/3","title":"AWS.CognitoIdentityProvider.get_device/3","type":"function"},{"doc":"Gets a group.\n\nCalling this action requires developer credentials.","ref":"AWS.CognitoIdentityProvider.html#get_group/3","title":"AWS.CognitoIdentityProvider.get_group/3","type":"function"},{"doc":"Gets the specified IdP.","ref":"AWS.CognitoIdentityProvider.html#get_identity_provider_by_identifier/3","title":"AWS.CognitoIdentityProvider.get_identity_provider_by_identifier/3","type":"function"},{"doc":"Gets the detailed activity logging configuration for a user pool.","ref":"AWS.CognitoIdentityProvider.html#get_log_delivery_configuration/3","title":"AWS.CognitoIdentityProvider.get_log_delivery_configuration/3","type":"function"},{"doc":"This method takes a user pool ID, and returns the signing certificate.\n\nThe issued certificate is valid for 10 years from the date of issue.\n\nAmazon Cognito issues and assigns a new signing certificate annually. This\nprocess returns a new value in the response to `GetSigningCertificate`, but\ndoesn't invalidate the original certificate.","ref":"AWS.CognitoIdentityProvider.html#get_signing_certificate/3","title":"AWS.CognitoIdentityProvider.get_signing_certificate/3","type":"function"},{"doc":"Gets the user interface (UI) Customization information for a particular app\nclient's app UI, if any such information exists for the client.\n\nIf nothing is set for the particular client, but there is an existing pool level\ncustomization (the app `clientId` is `ALL`), then that information is returned.\nIf nothing is present, then an empty shape is returned.","ref":"AWS.CognitoIdentityProvider.html#get_ui_customization/3","title":"AWS.CognitoIdentityProvider.get_ui_customization/3","type":"function"},{"doc":"Gets the user attributes and metadata for a user.\n\nAuthorize this action with a signed-in user's access token. It must include the\nscope `aws.cognito.signin.user.admin`.\n\nAmazon Cognito doesn't evaluate Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you can't use IAM\ncredentials to authorize requests, and you can't grant IAM permissions in\npolicies. For more information about authorization models in Amazon Cognito, see\n[Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html).","ref":"AWS.CognitoIdentityProvider.html#get_user/3","title":"AWS.CognitoIdentityProvider.get_user/3","type":"function"},{"doc":"Generates a user attribute verification code for the specified attribute name.\n\nSends a message to a user with a code that they must return in a\nVerifyUserAttribute request.\n\nAuthorize this action with a signed-in user's access token. It must include the\nscope `aws.cognito.signin.user.admin`.\n\nAmazon Cognito doesn't evaluate Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you can't use IAM\ncredentials to authorize requests, and you can't grant IAM permissions in\npolicies. For more information about authorization models in Amazon Cognito, see\n[Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html).\n\nThis action might generate an SMS text message. Starting June 1, 2021, US\ntelecom carriers require you to register an origination phone number before you\ncan send SMS messages to US phone numbers. If you use SMS text messages in\nAmazon Cognito, you must register a phone number with [Amazon Pinpoint](https://console.aws.amazon.com/pinpoint/home/). Amazon Cognito uses\nthe registered number automatically. Otherwise, Amazon Cognito users who must\nreceive SMS messages might not be able to sign up, activate their accounts, or\nsign in.\n\nIf you have never used SMS text messages with Amazon Cognito or any other Amazon\nWeb Service, Amazon Simple Notification Service might place your account in the\nSMS sandbox. In * [sandbox mode](https://docs.aws.amazon.com/sns/latest/dg/sns-sms-sandbox.html) *, you can\nsend messages only to verified phone numbers. After you test your app while in\nthe sandbox environment, you can move out of the sandbox and into production.\nFor more information, see [ SMS message settings for Amazon Cognito user pools](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-sms-settings.html)\nin the *Amazon Cognito Developer Guide*.","ref":"AWS.CognitoIdentityProvider.html#get_user_attribute_verification_code/3","title":"AWS.CognitoIdentityProvider.get_user_attribute_verification_code/3","type":"function"},{"doc":"Gets the user pool multi-factor authentication (MFA) configuration.","ref":"AWS.CognitoIdentityProvider.html#get_user_pool_mfa_config/3","title":"AWS.CognitoIdentityProvider.get_user_pool_mfa_config/3","type":"function"},{"doc":"Invalidates the identity, access, and refresh tokens that Amazon Cognito issued\nto a user.\n\nCall this operation when your user signs out of your app. This results in the\nfollowing behavior.\n\n  * Amazon Cognito no longer accepts *token-authorized* user\noperations that you authorize with a signed-out user's access tokens. For more\ninformation, see [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html).\n\nAmazon Cognito returns an `Access Token has been revoked` error when your app\nattempts to authorize a user pools API request with a revoked access token that\ncontains the scope `aws.cognito.signin.user.admin`.\n\n  * Amazon Cognito no longer accepts a signed-out user's ID token in a\n[GetId\n](https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_GetId.html)\nrequest to an identity pool with `ServerSideTokenCheck` enabled for its user\npool IdP configuration in\n[CognitoIdentityProvider](https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_CognitoIdentityProvider.html).     * Amazon Cognito no longer accepts a signed-out user's refresh\ntokens in refresh requests.\n\nOther requests might be valid until your user's token expires.\n\nAuthorize this action with a signed-in user's access token. It must include the\nscope `aws.cognito.signin.user.admin`.\n\nAmazon Cognito doesn't evaluate Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you can't use IAM\ncredentials to authorize requests, and you can't grant IAM permissions in\npolicies. For more information about authorization models in Amazon Cognito, see\n[Using the Amazon Cognito user pools API and user pool\nendpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html).","ref":"AWS.CognitoIdentityProvider.html#global_sign_out/3","title":"AWS.CognitoIdentityProvider.global_sign_out/3","type":"function"},{"doc":"Initiates sign-in for a user in the Amazon Cognito user directory.\n\nYou can't sign in a user with a federated IdP with `InitiateAuth`. For more\ninformation, see [ Adding user pool sign-in through a third party](https://docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-pools-identity-federation.html).\n\nAmazon Cognito doesn't evaluate Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you can't use IAM\ncredentials to authorize requests, and you can't grant IAM permissions in\npolicies. For more information about authorization models in Amazon Cognito, see\n[Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html).\n\nThis action might generate an SMS text message. Starting June 1, 2021, US\ntelecom carriers require you to register an origination phone number before you\ncan send SMS messages to US phone numbers. If you use SMS text messages in\nAmazon Cognito, you must register a phone number with [Amazon Pinpoint](https://console.aws.amazon.com/pinpoint/home/). Amazon Cognito uses\nthe registered number automatically. Otherwise, Amazon Cognito users who must\nreceive SMS messages might not be able to sign up, activate their accounts, or\nsign in.\n\nIf you have never used SMS text messages with Amazon Cognito or any other Amazon\nWeb Service, Amazon Simple Notification Service might place your account in the\nSMS sandbox. In * [sandbox mode](https://docs.aws.amazon.com/sns/latest/dg/sns-sms-sandbox.html) *, you can\nsend messages only to verified phone numbers. After you test your app while in\nthe sandbox environment, you can move out of the sandbox and into production.\nFor more information, see [ SMS message settings for Amazon Cognito user pools](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-sms-settings.html)\nin the *Amazon Cognito Developer Guide*.","ref":"AWS.CognitoIdentityProvider.html#initiate_auth/3","title":"AWS.CognitoIdentityProvider.initiate_auth/3","type":"function"},{"doc":"Lists the sign-in devices that Amazon Cognito has registered to the current\nuser.\n\nFor more information about device authentication, see [Working with user devices in your user\npool](https://docs.aws.amazon.com/cognito/latest/developerguide/amazon-cognito-user-pools-device-tracking.html).\n\nAuthorize this action with a signed-in user's access token. It must include the\nscope `aws.cognito.signin.user.admin`.\n\nAmazon Cognito doesn't evaluate Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you can't use IAM\ncredentials to authorize requests, and you can't grant IAM permissions in\npolicies. For more information about authorization models in Amazon Cognito, see\n[Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html).","ref":"AWS.CognitoIdentityProvider.html#list_devices/3","title":"AWS.CognitoIdentityProvider.list_devices/3","type":"function"},{"doc":"Lists the groups associated with a user pool.\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#list_groups/3","title":"AWS.CognitoIdentityProvider.list_groups/3","type":"function"},{"doc":"[Signing Amazon Web Services API Requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#list_groups/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.list_groups/3","type":"function"},{"doc":"Lists information about all IdPs for a user pool.\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#list_identity_providers/3","title":"AWS.CognitoIdentityProvider.list_identity_providers/3","type":"function"},{"doc":"[Signing Amazon Web Services API Requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#list_identity_providers/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.list_identity_providers/3","type":"function"},{"doc":"Lists the resource servers for a user pool.\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#list_resource_servers/3","title":"AWS.CognitoIdentityProvider.list_resource_servers/3","type":"function"},{"doc":"[Signing Amazon Web Services API Requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#list_resource_servers/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.list_resource_servers/3","type":"function"},{"doc":"Lists the tags that are assigned to an Amazon Cognito user pool.\n\nA tag is a label that you can apply to user pools to categorize and manage them\nin different ways, such as by purpose, owner, environment, or other criteria.\n\nYou can use this action up to 10 times per second, per account.","ref":"AWS.CognitoIdentityProvider.html#list_tags_for_resource/3","title":"AWS.CognitoIdentityProvider.list_tags_for_resource/3","type":"function"},{"doc":"Lists user import jobs for a user pool.\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#list_user_import_jobs/3","title":"AWS.CognitoIdentityProvider.list_user_import_jobs/3","type":"function"},{"doc":"[Signing Amazon Web Services API Requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#list_user_import_jobs/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.list_user_import_jobs/3","type":"function"},{"doc":"Lists the clients that have been created for the specified user pool.\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#list_user_pool_clients/3","title":"AWS.CognitoIdentityProvider.list_user_pool_clients/3","type":"function"},{"doc":"[Signing Amazon Web Services API Requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#list_user_pool_clients/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.list_user_pool_clients/3","type":"function"},{"doc":"Lists the user pools associated with an Amazon Web Services account.\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#list_user_pools/3","title":"AWS.CognitoIdentityProvider.list_user_pools/3","type":"function"},{"doc":"[Signing Amazon Web Services API Requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#list_user_pools/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.list_user_pools/3","type":"function"},{"doc":"Lists users and their basic details in a user pool.\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#list_users/3","title":"AWS.CognitoIdentityProvider.list_users/3","type":"function"},{"doc":"[Signing Amazon Web Services API Requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#list_users/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.list_users/3","type":"function"},{"doc":"Lists the users in the specified group.\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#list_users_in_group/3","title":"AWS.CognitoIdentityProvider.list_users_in_group/3","type":"function"},{"doc":"[Signing Amazon Web Services API Requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#list_users_in_group/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.list_users_in_group/3","type":"function"},{"doc":"","ref":"AWS.CognitoIdentityProvider.html#metadata/0","title":"AWS.CognitoIdentityProvider.metadata/0","type":"function"},{"doc":"Resends the confirmation (for confirmation of registration) to a specific user\nin the user pool.\n\nAmazon Cognito doesn't evaluate Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you can't use IAM\ncredentials to authorize requests, and you can't grant IAM permissions in\npolicies. For more information about authorization models in Amazon Cognito, see\n[Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html).\n\nThis action might generate an SMS text message. Starting June 1, 2021, US\ntelecom carriers require you to register an origination phone number before you\ncan send SMS messages to US phone numbers. If you use SMS text messages in\nAmazon Cognito, you must register a phone number with [Amazon Pinpoint](https://console.aws.amazon.com/pinpoint/home/). Amazon Cognito uses\nthe registered number automatically. Otherwise, Amazon Cognito users who must\nreceive SMS messages might not be able to sign up, activate their accounts, or\nsign in.\n\nIf you have never used SMS text messages with Amazon Cognito or any other Amazon\nWeb Service, Amazon Simple Notification Service might place your account in the\nSMS sandbox. In * [sandbox mode](https://docs.aws.amazon.com/sns/latest/dg/sns-sms-sandbox.html) *, you can\nsend messages only to verified phone numbers. After you test your app while in\nthe sandbox environment, you can move out of the sandbox and into production.\nFor more information, see [ SMS message settings for Amazon Cognito user pools](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-sms-settings.html)\nin the *Amazon Cognito Developer Guide*.","ref":"AWS.CognitoIdentityProvider.html#resend_confirmation_code/3","title":"AWS.CognitoIdentityProvider.resend_confirmation_code/3","type":"function"},{"doc":"Some API operations in a user pool generate a challenge, like a prompt for an\nMFA code, for device authentication that bypasses MFA, or for a custom\nauthentication challenge.\n\nA `RespondToAuthChallenge` API request provides the answer to that challenge,\nlike a code or a secure remote password (SRP). The parameters of a response to\nan authentication challenge vary with the type of challenge.\n\nFor more information about custom authentication challenges, see [Custom authentication challenge Lambda\ntriggers](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-lambda-challenge.html).\n\nAmazon Cognito doesn't evaluate Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you can't use IAM\ncredentials to authorize requests, and you can't grant IAM permissions in\npolicies. For more information about authorization models in Amazon Cognito, see\n[Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html).\n\nThis action might generate an SMS text message. Starting June 1, 2021, US\ntelecom carriers require you to register an origination phone number before you\ncan send SMS messages to US phone numbers. If you use SMS text messages in\nAmazon Cognito, you must register a phone number with [Amazon Pinpoint](https://console.aws.amazon.com/pinpoint/home/). Amazon Cognito uses\nthe registered number automatically. Otherwise, Amazon Cognito users who must\nreceive SMS messages might not be able to sign up, activate their accounts, or\nsign in.\n\nIf you have never used SMS text messages with Amazon Cognito or any other Amazon\nWeb Service, Amazon Simple Notification Service might place your account in the\nSMS sandbox. In * [sandbox mode](https://docs.aws.amazon.com/sns/latest/dg/sns-sms-sandbox.html) *, you can\nsend messages only to verified phone numbers. After you test your app while in\nthe sandbox environment, you can move out of the sandbox and into production.\nFor more information, see [ SMS message settings for Amazon Cognito user pools](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-sms-settings.html)\nin the *Amazon Cognito Developer Guide*.","ref":"AWS.CognitoIdentityProvider.html#respond_to_auth_challenge/3","title":"AWS.CognitoIdentityProvider.respond_to_auth_challenge/3","type":"function"},{"doc":"Revokes all of the access tokens generated by, and at the same time as, the\nspecified refresh token.\n\nAfter a token is revoked, you can't use the revoked token to access Amazon\nCognito user APIs, or to authorize access to your resource server.\n\nAmazon Cognito doesn't evaluate Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you can't use IAM\ncredentials to authorize requests, and you can't grant IAM permissions in\npolicies. For more information about authorization models in Amazon Cognito, see\n[Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html).","ref":"AWS.CognitoIdentityProvider.html#revoke_token/3","title":"AWS.CognitoIdentityProvider.revoke_token/3","type":"function"},{"doc":"Sets up or modifies the detailed activity logging configuration of a user pool.","ref":"AWS.CognitoIdentityProvider.html#set_log_delivery_configuration/3","title":"AWS.CognitoIdentityProvider.set_log_delivery_configuration/3","type":"function"},{"doc":"Configures actions on detected risks.\n\nTo delete the risk configuration for `UserPoolId` or `ClientId`, pass null\nvalues for all four configuration types.\n\nTo activate Amazon Cognito advanced security features, update the user pool to\ninclude the `UserPoolAddOns` key`AdvancedSecurityMode`.","ref":"AWS.CognitoIdentityProvider.html#set_risk_configuration/3","title":"AWS.CognitoIdentityProvider.set_risk_configuration/3","type":"function"},{"doc":"Sets the user interface (UI) customization information for a user pool's\nbuilt-in app UI.\n\nYou can specify app UI customization settings for a single client (with a\nspecific `clientId`) or for all clients (by setting the `clientId` to `ALL`). If\nyou specify `ALL`, the default configuration is used for every client that has\nno previously set UI customization. If you specify UI customization settings for\na particular client, it will no longer return to the `ALL` configuration.\n\nTo use this API, your user pool must have a domain associated with it.\nOtherwise, there is no place to host the app's pages, and the service will throw\nan error.","ref":"AWS.CognitoIdentityProvider.html#set_ui_customization/3","title":"AWS.CognitoIdentityProvider.set_ui_customization/3","type":"function"},{"doc":"Set the user's multi-factor authentication (MFA) method preference, including\nwhich MFA factors are activated and if any are preferred.\n\nOnly one factor can be set as preferred. The preferred MFA factor will be used\nto authenticate a user if multiple factors are activated. If multiple options\nare activated and no preference is set, a challenge to choose an MFA option will\nbe returned during sign-in. If an MFA type is activated for a user, the user\nwill be prompted for MFA during all sign-in attempts unless device tracking is\nturned on and the device has been trusted. If you want MFA to be applied\nselectively based on the assessed risk level of sign-in attempts, deactivate MFA\nfor users and turn on Adaptive Authentication for the user pool.\n\nAuthorize this action with a signed-in user's access token. It must include the\nscope `aws.cognito.signin.user.admin`.\n\nAmazon Cognito doesn't evaluate Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you can't use IAM\ncredentials to authorize requests, and you can't grant IAM permissions in\npolicies. For more information about authorization models in Amazon Cognito, see\n[Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html).","ref":"AWS.CognitoIdentityProvider.html#set_user_mfa_preference/3","title":"AWS.CognitoIdentityProvider.set_user_mfa_preference/3","type":"function"},{"doc":"Sets the user pool multi-factor authentication (MFA) configuration.\n\nThis action might generate an SMS text message. Starting June 1, 2021, US\ntelecom carriers require you to register an origination phone number before you\ncan send SMS messages to US phone numbers. If you use SMS text messages in\nAmazon Cognito, you must register a phone number with [Amazon Pinpoint](https://console.aws.amazon.com/pinpoint/home/). Amazon Cognito uses\nthe registered number automatically. Otherwise, Amazon Cognito users who must\nreceive SMS messages might not be able to sign up, activate their accounts, or\nsign in.\n\nIf you have never used SMS text messages with Amazon Cognito or any other Amazon\nWeb Service, Amazon Simple Notification Service might place your account in the\nSMS sandbox. In * [sandbox mode](https://docs.aws.amazon.com/sns/latest/dg/sns-sms-sandbox.html) *, you can\nsend messages only to verified phone numbers. After you test your app while in\nthe sandbox environment, you can move out of the sandbox and into production.\nFor more information, see [ SMS message settings for Amazon Cognito user pools](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-sms-settings.html)\nin the *Amazon Cognito Developer Guide*.","ref":"AWS.CognitoIdentityProvider.html#set_user_pool_mfa_config/3","title":"AWS.CognitoIdentityProvider.set_user_pool_mfa_config/3","type":"function"},{"doc":"*This action is no longer supported.* You can use it to configure only SMS MFA.\n\nYou can't use it to configure time-based one-time password (TOTP) software token\nMFA. To configure either type of MFA, use\n[SetUserMFAPreference](https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_SetUserMFAPreference.html) instead.\n\nAuthorize this action with a signed-in user's access token. It must include the\nscope `aws.cognito.signin.user.admin`.\n\nAmazon Cognito doesn't evaluate Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you can't use IAM\ncredentials to authorize requests, and you can't grant IAM permissions in\npolicies. For more information about authorization models in Amazon Cognito, see\n[Using the Amazon Cognito user pools API and user pool\nendpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html).","ref":"AWS.CognitoIdentityProvider.html#set_user_settings/3","title":"AWS.CognitoIdentityProvider.set_user_settings/3","type":"function"},{"doc":"Registers the user in the specified user pool and creates a user name, password,\nand user attributes.\n\nAmazon Cognito doesn't evaluate Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you can't use IAM\ncredentials to authorize requests, and you can't grant IAM permissions in\npolicies. For more information about authorization models in Amazon Cognito, see\n[Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html).\n\nThis action might generate an SMS text message. Starting June 1, 2021, US\ntelecom carriers require you to register an origination phone number before you\ncan send SMS messages to US phone numbers. If you use SMS text messages in\nAmazon Cognito, you must register a phone number with [Amazon Pinpoint](https://console.aws.amazon.com/pinpoint/home/). Amazon Cognito uses\nthe registered number automatically. Otherwise, Amazon Cognito users who must\nreceive SMS messages might not be able to sign up, activate their accounts, or\nsign in.\n\nIf you have never used SMS text messages with Amazon Cognito or any other Amazon\nWeb Service, Amazon Simple Notification Service might place your account in the\nSMS sandbox. In * [sandbox mode](https://docs.aws.amazon.com/sns/latest/dg/sns-sms-sandbox.html) *, you can\nsend messages only to verified phone numbers. After you test your app while in\nthe sandbox environment, you can move out of the sandbox and into production.\nFor more information, see [ SMS message settings for Amazon Cognito user pools](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-sms-settings.html)\nin the *Amazon Cognito Developer Guide*.","ref":"AWS.CognitoIdentityProvider.html#sign_up/3","title":"AWS.CognitoIdentityProvider.sign_up/3","type":"function"},{"doc":"Starts the user import.","ref":"AWS.CognitoIdentityProvider.html#start_user_import_job/3","title":"AWS.CognitoIdentityProvider.start_user_import_job/3","type":"function"},{"doc":"Stops the user import job.","ref":"AWS.CognitoIdentityProvider.html#stop_user_import_job/3","title":"AWS.CognitoIdentityProvider.stop_user_import_job/3","type":"function"},{"doc":"Assigns a set of tags to an Amazon Cognito user pool.\n\nA tag is a label that you can use to categorize and manage user pools in\ndifferent ways, such as by purpose, owner, environment, or other criteria.\n\nEach tag consists of a key and value, both of which you define. A key is a\ngeneral category for more specific values. For example, if you have two versions\nof a user pool, one for testing and another for production, you might assign an\n`Environment` tag key to both user pools. The value of this key might be `Test`\nfor one user pool, and `Production` for the other.\n\nTags are useful for cost tracking and access control. You can activate your tags\nso that they appear on the Billing and Cost Management console, where you can\ntrack the costs associated with your user pools. In an Identity and Access\nManagement policy, you can constrain permissions for user pools based on\nspecific tags or tag values.\n\nYou can use this action up to 5 times per second, per account. A user pool can\nhave as many as 50 tags.","ref":"AWS.CognitoIdentityProvider.html#tag_resource/3","title":"AWS.CognitoIdentityProvider.tag_resource/3","type":"function"},{"doc":"Removes the specified tags from an Amazon Cognito user pool.\n\nYou can use this action up to 5 times per second, per account.","ref":"AWS.CognitoIdentityProvider.html#untag_resource/3","title":"AWS.CognitoIdentityProvider.untag_resource/3","type":"function"},{"doc":"Provides the feedback for an authentication event, whether it was from a valid\nuser or not.\n\nThis feedback is used for improving the risk evaluation decision for the user\npool as part of Amazon Cognito advanced security.\n\nAmazon Cognito doesn't evaluate Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you can't use IAM\ncredentials to authorize requests, and you can't grant IAM permissions in\npolicies. For more information about authorization models in Amazon Cognito, see\n[Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html).","ref":"AWS.CognitoIdentityProvider.html#update_auth_event_feedback/3","title":"AWS.CognitoIdentityProvider.update_auth_event_feedback/3","type":"function"},{"doc":"Updates the device status.\n\nFor more information about device authentication, see [Working with user devices in your user\npool](https://docs.aws.amazon.com/cognito/latest/developerguide/amazon-cognito-user-pools-device-tracking.html).\n\nAuthorize this action with a signed-in user's access token. It must include the\nscope `aws.cognito.signin.user.admin`.\n\nAmazon Cognito doesn't evaluate Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you can't use IAM\ncredentials to authorize requests, and you can't grant IAM permissions in\npolicies. For more information about authorization models in Amazon Cognito, see\n[Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html).","ref":"AWS.CognitoIdentityProvider.html#update_device_status/3","title":"AWS.CognitoIdentityProvider.update_device_status/3","type":"function"},{"doc":"Updates the specified group with the specified attributes.\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#update_group/3","title":"AWS.CognitoIdentityProvider.update_group/3","type":"function"},{"doc":"[Signing Amazon Web Services API Requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#update_group/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.update_group/3","type":"function"},{"doc":"Updates IdP information for a user pool.\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#update_identity_provider/3","title":"AWS.CognitoIdentityProvider.update_identity_provider/3","type":"function"},{"doc":"[Signing Amazon Web Services API Requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#update_identity_provider/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.update_identity_provider/3","type":"function"},{"doc":"Updates the name and scopes of resource server.\n\nAll other fields are read-only.\n\nIf you don't provide a value for an attribute, it is set to the default value.\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#update_resource_server/3","title":"AWS.CognitoIdentityProvider.update_resource_server/3","type":"function"},{"doc":"[Signing Amazon Web Services API Requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#update_resource_server/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.update_resource_server/3","type":"function"},{"doc":"With this operation, your users can update one or more of their attributes with\ntheir own credentials.\n\nYou authorize this API request with the user's access token. To delete an\nattribute from your user, submit the attribute in your API request with a blank\nvalue. Custom attribute values in this request must include the `custom:`\nprefix.\n\nAuthorize this action with a signed-in user's access token. It must include the\nscope `aws.cognito.signin.user.admin`.\n\nAmazon Cognito doesn't evaluate Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you can't use IAM\ncredentials to authorize requests, and you can't grant IAM permissions in\npolicies. For more information about authorization models in Amazon Cognito, see\n[Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html).\n\nThis action might generate an SMS text message. Starting June 1, 2021, US\ntelecom carriers require you to register an origination phone number before you\ncan send SMS messages to US phone numbers. If you use SMS text messages in\nAmazon Cognito, you must register a phone number with [Amazon Pinpoint](https://console.aws.amazon.com/pinpoint/home/). Amazon Cognito uses\nthe registered number automatically. Otherwise, Amazon Cognito users who must\nreceive SMS messages might not be able to sign up, activate their accounts, or\nsign in.\n\nIf you have never used SMS text messages with Amazon Cognito or any other Amazon\nWeb Service, Amazon Simple Notification Service might place your account in the\nSMS sandbox. In * [sandbox mode](https://docs.aws.amazon.com/sns/latest/dg/sns-sms-sandbox.html) *, you can\nsend messages only to verified phone numbers. After you test your app while in\nthe sandbox environment, you can move out of the sandbox and into production.\nFor more information, see [ SMS message settings for Amazon Cognito user pools](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-sms-settings.html)\nin the *Amazon Cognito Developer Guide*.","ref":"AWS.CognitoIdentityProvider.html#update_user_attributes/3","title":"AWS.CognitoIdentityProvider.update_user_attributes/3","type":"function"},{"doc":"This action might generate an SMS text message.\n\nStarting June 1, 2021, US telecom carriers require you to register an\norigination phone number before you can send SMS messages to US phone numbers.\nIf you use SMS text messages in Amazon Cognito, you must register a phone number\nwith [Amazon Pinpoint](https://console.aws.amazon.com/pinpoint/home/). Amazon Cognito uses the registered number automatically. Otherwise, Amazon Cognito\nusers who must receive SMS messages might not be able to sign up, activate their\naccounts, or sign in.\n\nIf you have never used SMS text messages with Amazon Cognito or any other Amazon\nWeb Service, Amazon Simple Notification Service might place your account in the\nSMS sandbox. In * [sandbox\nmode](https://docs.aws.amazon.com/sns/latest/dg/sns-sms-sandbox.html) *, you can\nsend messages only to verified phone numbers. After you test your app while in\nthe sandbox environment, you can move out of the sandbox and into production.\nFor more information, see [ SMS message settings for Amazon Cognito user pools](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-sms-settings.html)\nin the *Amazon Cognito Developer Guide*.\n\nUpdates the specified user pool with the specified attributes. You can get a\nlist of the current user pool settings using\n[DescribeUserPool](https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_DescribeUserPool.html).  If you don't provide a value for an attribute, Amazon Cognito sets it to its\ndefault value.\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#update_user_pool/3","title":"AWS.CognitoIdentityProvider.update_user_pool/3","type":"function"},{"doc":"[Signing Amazon Web Services API\nRequests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#update_user_pool/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.update_user_pool/3","type":"function"},{"doc":"Updates the specified user pool app client with the specified attributes.\n\nYou can get a list of the current user pool app client settings using\n[DescribeUserPoolClient](https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_DescribeUserPoolClient.html).  If you don't provide a value for an attribute, Amazon Cognito sets it to its\ndefault value.\n\nYou can also use this operation to enable token revocation for user pool\nclients. For more information about revoking tokens, see\n[RevokeToken](https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_RevokeToken.html).\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#update_user_pool_client/3","title":"AWS.CognitoIdentityProvider.update_user_pool_client/3","type":"function"},{"doc":"[Signing Amazon Web Services API Requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#update_user_pool_client/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.update_user_pool_client/3","type":"function"},{"doc":"Updates the Secure Sockets Layer (SSL) certificate for the custom domain for\nyour user pool.\n\nYou can use this operation to provide the Amazon Resource Name (ARN) of a new\ncertificate to Amazon Cognito. You can't use it to change the domain for a user\npool.\n\nA custom domain is used to host the Amazon Cognito hosted UI, which provides\nsign-up and sign-in pages for your application. When you set up a custom domain,\nyou provide a certificate that you manage with Certificate Manager (ACM). When\nnecessary, you can use this operation to change the certificate that you applied\nto your custom domain.\n\nUsually, this is unnecessary following routine certificate renewal with ACM.\nWhen you renew your existing certificate in ACM, the ARN for your certificate\nremains the same, and your custom domain uses the new certificate automatically.\n\nHowever, if you replace your existing certificate with a new one, ACM gives the\nnew certificate a new ARN. To apply the new certificate to your custom domain,\nyou must provide this ARN to Amazon Cognito.\n\nWhen you add your new certificate in ACM, you must choose US East (N. Virginia)\nas the Amazon Web Services Region.\n\nAfter you submit your request, Amazon Cognito requires up to 1 hour to\ndistribute your new certificate to your custom domain.\n\nFor more information about adding a custom domain to your user pool, see [Using Your Own Domain for the Hosted\nUI](https://docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-pools-add-custom-domain.html).\n\nAmazon Cognito evaluates Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you must use IAM\ncredentials to authorize requests, and you must grant yourself the corresponding\nIAM permission in a policy.","ref":"AWS.CognitoIdentityProvider.html#update_user_pool_domain/3","title":"AWS.CognitoIdentityProvider.update_user_pool_domain/3","type":"function"},{"doc":"[Signing Amazon Web Services API Requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-signing.html)\n\n   [Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html)","ref":"AWS.CognitoIdentityProvider.html#update_user_pool_domain/3-learn-more","title":"Learn more - AWS.CognitoIdentityProvider.update_user_pool_domain/3","type":"function"},{"doc":"Use this API to register a user's entered time-based one-time password (TOTP)\ncode and mark the user's software token MFA status as \"verified\" if successful.\n\nThe request takes an access token or a session string, but not both.\n\nAmazon Cognito doesn't evaluate Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you can't use IAM\ncredentials to authorize requests, and you can't grant IAM permissions in\npolicies. For more information about authorization models in Amazon Cognito, see\n[Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html).","ref":"AWS.CognitoIdentityProvider.html#verify_software_token/3","title":"AWS.CognitoIdentityProvider.verify_software_token/3","type":"function"},{"doc":"Verifies the specified user attributes in the user pool.\n\nIf your user pool requires verification before Amazon Cognito updates the\nattribute value, VerifyUserAttribute updates the affected attribute to its\npending value. For more information, see [\nUserAttributeUpdateSettingsType](https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_UserAttributeUpdateSettingsType.html).\n\nAuthorize this action with a signed-in user's access token. It must include the\nscope `aws.cognito.signin.user.admin`.\n\nAmazon Cognito doesn't evaluate Identity and Access Management (IAM) policies in\nrequests for this API operation. For this operation, you can't use IAM\ncredentials to authorize requests, and you can't grant IAM permissions in\npolicies. For more information about authorization models in Amazon Cognito, see\n[Using the Amazon Cognito user pools API and user pool endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pools-API-operations.html).","ref":"AWS.CognitoIdentityProvider.html#verify_user_attribute/3","title":"AWS.CognitoIdentityProvider.verify_user_attribute/3","type":"function"},{"doc":"Amazon Cognito Sync\n\nAmazon Cognito Sync provides an AWS service and client library that enable\ncross-device syncing of application-related user data.\n\nHigh-level client libraries are available for both iOS and Android. You can use\nthese libraries to persist data locally so that it's available even if the\ndevice is offline. Developer credentials don't need to be stored on the mobile\ndevice to access the service. You can use Amazon Cognito to obtain a normalized\nuser ID and credentials. User data is persisted in a dataset that can store up\nto 1 MB of key-value pairs, and you can have up to 20 datasets per user\nidentity.\n\nWith Amazon Cognito Sync, the data stored for each identity is accessible only\nto credentials assigned to that identity. In order to use the Cognito Sync\nservice, you need to make API calls using credentials retrieved with [Amazon Cognito Identity\nservice](http://docs.aws.amazon.com/cognitoidentity/latest/APIReference/Welcome.html).\n\nIf you want to use Cognito Sync in an Android or iOS application, you will\nprobably want to make API calls via the AWS Mobile SDK. To learn more, see the\n[Developer Guide for Android](http://docs.aws.amazon.com/mobile/sdkforandroid/developerguide/cognito-sync.html)\nand the [Developer Guide for iOS](http://docs.aws.amazon.com/mobile/sdkforios/developerguide/cognito-sync.html).","ref":"AWS.CognitoSync.html","title":"AWS.CognitoSync","type":"module"},{"doc":"Initiates a bulk publish of all existing datasets for an Identity Pool to the\nconfigured stream.\n\nCustomers are limited to one successful bulk publish per 24 hours. Bulk publish\nis an asynchronous request, customers can see the status of the request via the\nGetBulkPublishDetails operation.\n\nThis API can only be called with developer credentials. You cannot call this API\nwith the temporary user credentials provided by Cognito Identity.","ref":"AWS.CognitoSync.html#bulk_publish/4","title":"AWS.CognitoSync.bulk_publish/4","type":"function"},{"doc":"Deletes the specific dataset.\n\nThe dataset will be deleted permanently, and the action can't be undone.\nDatasets that this dataset was merged with will no longer report the merge. Any\nsubsequent operation on this dataset will result in a ResourceNotFoundException.\n\nThis API can be called with temporary user credentials provided by Cognito\nIdentity or with developer credentials.","ref":"AWS.CognitoSync.html#delete_dataset/6","title":"AWS.CognitoSync.delete_dataset/6","type":"function"},{"doc":"Gets meta data about a dataset by identity and dataset name.\n\nWith Amazon Cognito Sync, each identity has access only to its own data. Thus,\nthe credentials used to make this API call need to have access to the identity\ndata.\n\nThis API can be called with temporary user credentials provided by Cognito\nIdentity or with developer credentials. You should use Cognito Identity\ncredentials to make this API call.","ref":"AWS.CognitoSync.html#describe_dataset/5","title":"AWS.CognitoSync.describe_dataset/5","type":"function"},{"doc":"Gets usage details (for example, data storage) about a particular identity pool.\n\nThis API can only be called with developer credentials. You cannot call this API\nwith the temporary user credentials provided by Cognito Identity.","ref":"AWS.CognitoSync.html#describe_identity_pool_usage/3","title":"AWS.CognitoSync.describe_identity_pool_usage/3","type":"function"},{"doc":"Gets usage information for an identity, including number of datasets and data\nusage.\n\nThis API can be called with temporary user credentials provided by Cognito\nIdentity or with developer credentials.","ref":"AWS.CognitoSync.html#describe_identity_usage/4","title":"AWS.CognitoSync.describe_identity_usage/4","type":"function"},{"doc":"Get the status of the last BulkPublish operation for an identity pool.\n\nThis API can only be called with developer credentials. You cannot call this API\nwith the temporary user credentials provided by Cognito Identity.","ref":"AWS.CognitoSync.html#get_bulk_publish_details/4","title":"AWS.CognitoSync.get_bulk_publish_details/4","type":"function"},{"doc":"Gets the events and the corresponding Lambda functions associated with an\nidentity pool.\n\nThis API can only be called with developer credentials. You cannot call this API\nwith the temporary user credentials provided by Cognito Identity.","ref":"AWS.CognitoSync.html#get_cognito_events/3","title":"AWS.CognitoSync.get_cognito_events/3","type":"function"},{"doc":"Gets the configuration settings of an identity pool.\n\nThis API can only be called with developer credentials. You cannot call this API\nwith the temporary user credentials provided by Cognito Identity.","ref":"AWS.CognitoSync.html#get_identity_pool_configuration/3","title":"AWS.CognitoSync.get_identity_pool_configuration/3","type":"function"},{"doc":"Lists datasets for an identity.\n\nWith Amazon Cognito Sync, each identity has access only to its own data. Thus,\nthe credentials used to make this API call need to have access to the identity\ndata.\n\nListDatasets can be called with temporary user credentials provided by Cognito\nIdentity or with developer credentials. You should use the Cognito Identity\ncredentials to make this API call.","ref":"AWS.CognitoSync.html#list_datasets/6","title":"AWS.CognitoSync.list_datasets/6","type":"function"},{"doc":"Gets a list of identity pools registered with Cognito.\n\nListIdentityPoolUsage can only be called with developer credentials. You cannot\nmake this API call with the temporary user credentials provided by Cognito\nIdentity.","ref":"AWS.CognitoSync.html#list_identity_pool_usage/4","title":"AWS.CognitoSync.list_identity_pool_usage/4","type":"function"},{"doc":"Gets paginated records, optionally changed after a particular sync count for a\ndataset and identity.\n\nWith Amazon Cognito Sync, each identity has access only to its own data. Thus,\nthe credentials used to make this API call need to have access to the identity\ndata.\n\nListRecords can be called with temporary user credentials provided by Cognito\nIdentity or with developer credentials. You should use Cognito Identity\ncredentials to make this API call.","ref":"AWS.CognitoSync.html#list_records/9","title":"AWS.CognitoSync.list_records/9","type":"function"},{"doc":"","ref":"AWS.CognitoSync.html#metadata/0","title":"AWS.CognitoSync.metadata/0","type":"function"},{"doc":"Registers a device to receive push sync notifications.\n\nThis API can only be called with temporary credentials provided by Cognito\nIdentity. You cannot call this API with developer credentials.","ref":"AWS.CognitoSync.html#register_device/5","title":"AWS.CognitoSync.register_device/5","type":"function"},{"doc":"Sets the AWS Lambda function for a given event type for an identity pool.\n\nThis request only updates the key/value pair specified. Other key/values pairs\nare not updated. To remove a key value pair, pass a empty value for the\nparticular key.\n\nThis API can only be called with developer credentials. You cannot call this API\nwith the temporary user credentials provided by Cognito Identity.","ref":"AWS.CognitoSync.html#set_cognito_events/4","title":"AWS.CognitoSync.set_cognito_events/4","type":"function"},{"doc":"Sets the necessary configuration for push sync.\n\nThis API can only be called with developer credentials. You cannot call this API\nwith the temporary user credentials provided by Cognito Identity.","ref":"AWS.CognitoSync.html#set_identity_pool_configuration/4","title":"AWS.CognitoSync.set_identity_pool_configuration/4","type":"function"},{"doc":"Subscribes to receive notifications when a dataset is modified by another\ndevice.\n\nThis API can only be called with temporary credentials provided by Cognito\nIdentity. You cannot call this API with developer credentials.","ref":"AWS.CognitoSync.html#subscribe_to_dataset/7","title":"AWS.CognitoSync.subscribe_to_dataset/7","type":"function"},{"doc":"Unsubscribes from receiving notifications when a dataset is modified by another\ndevice.\n\nThis API can only be called with temporary credentials provided by Cognito\nIdentity. You cannot call this API with developer credentials.","ref":"AWS.CognitoSync.html#unsubscribe_from_dataset/7","title":"AWS.CognitoSync.unsubscribe_from_dataset/7","type":"function"},{"doc":"Posts updates to records and adds and deletes records for a dataset and user.\n\nThe sync count in the record patch is your last known sync count for that\nrecord. The server will reject an UpdateRecords request with a\nResourceConflictException if you try to patch a record with a new value but a\nstale sync count.\n\nFor example, if the sync count on the server is 5 for a key called highScore and\nyou try and submit a new highScore with sync count of 4, the request will be\nrejected. To obtain the current sync count for a record, call ListRecords. On a\nsuccessful update of the record, the response returns the new sync count for\nthat record. You should present that sync count the next time you try to update\nthat same record. When the record does not exist, specify the sync count as 0.\n\nThis API can be called with temporary user credentials provided by Cognito\nIdentity or with developer credentials.","ref":"AWS.CognitoSync.html#update_records/6","title":"AWS.CognitoSync.update_records/6","type":"function"},{"doc":"Amazon Comprehend is an Amazon Web Services service for gaining insight into the\ncontent of documents.\n\nUse these actions to determine the topics contained in your documents, the\ntopics they discuss, the predominant sentiment expressed in them, the\npredominant language used, and more.","ref":"AWS.Comprehend.html","title":"AWS.Comprehend","type":"module"},{"doc":"Determines the dominant language of the input text for a batch of documents.\n\nFor a list of languages that Amazon Comprehend can detect, see [Amazon Comprehend Supported\nLanguages](https://docs.aws.amazon.com/comprehend/latest/dg/how-languages.html).","ref":"AWS.Comprehend.html#batch_detect_dominant_language/3","title":"AWS.Comprehend.batch_detect_dominant_language/3","type":"function"},{"doc":"Inspects the text of a batch of documents for named entities and returns\ninformation about them.\n\nFor more information about named entities, see\n[Entities](https://docs.aws.amazon.com/comprehend/latest/dg/how-entities.html)\nin the Comprehend Developer Guide.","ref":"AWS.Comprehend.html#batch_detect_entities/3","title":"AWS.Comprehend.batch_detect_entities/3","type":"function"},{"doc":"Detects the key noun phrases found in a batch of documents.","ref":"AWS.Comprehend.html#batch_detect_key_phrases/3","title":"AWS.Comprehend.batch_detect_key_phrases/3","type":"function"},{"doc":"Inspects a batch of documents and returns an inference of the prevailing\nsentiment, `POSITIVE`, `NEUTRAL`, `MIXED`, or `NEGATIVE`, in each one.","ref":"AWS.Comprehend.html#batch_detect_sentiment/3","title":"AWS.Comprehend.batch_detect_sentiment/3","type":"function"},{"doc":"Inspects the text of a batch of documents for the syntax and part of speech of\nthe words in the document and returns information about them.\n\nFor more information, see\n[Syntax](https://docs.aws.amazon.com/comprehend/latest/dg/how-syntax.html) in\nthe Comprehend Developer Guide.","ref":"AWS.Comprehend.html#batch_detect_syntax/3","title":"AWS.Comprehend.batch_detect_syntax/3","type":"function"},{"doc":"Inspects a batch of documents and returns a sentiment analysis for each entity\nidentified in the documents.\n\nFor more information about targeted sentiment, see [Targeted sentiment](https://docs.aws.amazon.com/comprehend/latest/dg/how-targeted-sentiment.html)\nin the *Amazon Comprehend Developer Guide*.","ref":"AWS.Comprehend.html#batch_detect_targeted_sentiment/3","title":"AWS.Comprehend.batch_detect_targeted_sentiment/3","type":"function"},{"doc":"Creates a classification request to analyze a single document in real-time.\n\n`ClassifyDocument` supports the following model types:\n\n  * Custom classifier - a custom model that you have created and\ntrained. For input, you can provide plain text, a single-page document (PDF,\nWord, or image), or Amazon Textract API output. For more information, see\n[Custom classification](https://docs.aws.amazon.com/comprehend/latest/dg/how-document-classification.html)\nin the *Amazon Comprehend Developer Guide*.\n\n  * Prompt safety classifier - Amazon Comprehend provides a\npre-trained model for classifying input prompts for generative AI applications.\nFor input, you provide English plain text input. For prompt safety\nclassification, the response includes only the `Classes` field. For more\ninformation about prompt safety classifiers, see [Prompt safety classification](https://docs.aws.amazon.com/comprehend/latest/dg/trust-safety.html#prompt-classification)\nin the *Amazon Comprehend Developer Guide*.\n\nIf the system detects errors while processing a page in the input document, the\nAPI response includes an `Errors` field that describes the errors.\n\nIf the system detects a document-level error in your input document, the API\nreturns an `InvalidRequestException` error response. For details about this\nexception, see [ Errors in semi-structured documents](https://docs.aws.amazon.com/comprehend/latest/dg/idp-inputs-sync-err.html)\nin the Comprehend Developer Guide.","ref":"AWS.Comprehend.html#classify_document/3","title":"AWS.Comprehend.classify_document/3","type":"function"},{"doc":"Analyzes input text for the presence of personally identifiable information\n(PII) and returns the labels of identified PII entity types such as name,\naddress, bank account number, or phone number.","ref":"AWS.Comprehend.html#contains_pii_entities/3","title":"AWS.Comprehend.contains_pii_entities/3","type":"function"},{"doc":"Creates a dataset to upload training or test data for a model associated with a\nflywheel.\n\nFor more information about datasets, see [ Flywheel overview](https://docs.aws.amazon.com/comprehend/latest/dg/flywheels-about.html)\nin the *Amazon Comprehend Developer Guide*.","ref":"AWS.Comprehend.html#create_dataset/3","title":"AWS.Comprehend.create_dataset/3","type":"function"},{"doc":"Creates a new document classifier that you can use to categorize documents.\n\nTo create a classifier, you provide a set of training documents that are labeled\nwith the categories that you want to use. For more information, see [Training classifier\nmodels](https://docs.aws.amazon.com/comprehend/latest/dg/training-classifier-model.html)\nin the Comprehend Developer Guide.","ref":"AWS.Comprehend.html#create_document_classifier/3","title":"AWS.Comprehend.create_document_classifier/3","type":"function"},{"doc":"Creates a model-specific endpoint for synchronous inference for a previously\ntrained custom model For information about endpoints, see [Managing endpoints](https://docs.aws.amazon.com/comprehend/latest/dg/manage-endpoints.html).","ref":"AWS.Comprehend.html#create_endpoint/3","title":"AWS.Comprehend.create_endpoint/3","type":"function"},{"doc":"Creates an entity recognizer using submitted files.\n\nAfter your `CreateEntityRecognizer` request is submitted, you can check job\nstatus using the `DescribeEntityRecognizer` API.","ref":"AWS.Comprehend.html#create_entity_recognizer/3","title":"AWS.Comprehend.create_entity_recognizer/3","type":"function"},{"doc":"A flywheel is an Amazon Web Services resource that orchestrates the ongoing\ntraining of a model for custom classification or custom entity recognition.\n\nYou can create a flywheel to start with an existing trained model, or Comprehend\ncan create and train a new model.\n\nWhen you create the flywheel, Comprehend creates a data lake in your account.\nThe data lake holds the training data and test data for all versions of the\nmodel.\n\nTo use a flywheel with an existing trained model, you specify the active model\nversion. Comprehend copies the model's training data and test data into the\nflywheel's data lake.\n\nTo use the flywheel with a new model, you need to provide a dataset for training\ndata (and optional test data) when you create the flywheel.\n\nFor more information about flywheels, see [ Flywheel overview](https://docs.aws.amazon.com/comprehend/latest/dg/flywheels-about.html)\nin the *Amazon Comprehend Developer Guide*.","ref":"AWS.Comprehend.html#create_flywheel/3","title":"AWS.Comprehend.create_flywheel/3","type":"function"},{"doc":"Deletes a previously created document classifier\n\nOnly those classifiers that are in terminated states (IN_ERROR, TRAINED) will be\ndeleted.\n\nIf an active inference job is using the model, a `ResourceInUseException` will\nbe returned.\n\nThis is an asynchronous action that puts the classifier into a DELETING state,\nand it is then removed by a background job. Once removed, the classifier\ndisappears from your account and is no longer available for use.","ref":"AWS.Comprehend.html#delete_document_classifier/3","title":"AWS.Comprehend.delete_document_classifier/3","type":"function"},{"doc":"Deletes a model-specific endpoint for a previously-trained custom model.\n\nAll endpoints must be deleted in order for the model to be deleted. For\ninformation about endpoints, see [Managing endpoints](https://docs.aws.amazon.com/comprehend/latest/dg/manage-endpoints.html).","ref":"AWS.Comprehend.html#delete_endpoint/3","title":"AWS.Comprehend.delete_endpoint/3","type":"function"},{"doc":"Deletes an entity recognizer.\n\nOnly those recognizers that are in terminated states (IN_ERROR, TRAINED) will be\ndeleted. If an active inference job is using the model, a\n`ResourceInUseException` will be returned.\n\nThis is an asynchronous action that puts the recognizer into a DELETING state,\nand it is then removed by a background job. Once removed, the recognizer\ndisappears from your account and is no longer available for use.","ref":"AWS.Comprehend.html#delete_entity_recognizer/3","title":"AWS.Comprehend.delete_entity_recognizer/3","type":"function"},{"doc":"Deletes a flywheel.\n\nWhen you delete the flywheel, Amazon Comprehend does not delete the data lake or\nthe model associated with the flywheel.\n\nFor more information about flywheels, see [ Flywheel overview](https://docs.aws.amazon.com/comprehend/latest/dg/flywheels-about.html)\nin the *Amazon Comprehend Developer Guide*.","ref":"AWS.Comprehend.html#delete_flywheel/3","title":"AWS.Comprehend.delete_flywheel/3","type":"function"},{"doc":"Deletes a resource-based policy that is attached to a custom model.","ref":"AWS.Comprehend.html#delete_resource_policy/3","title":"AWS.Comprehend.delete_resource_policy/3","type":"function"},{"doc":"Returns information about the dataset that you specify.\n\nFor more information about datasets, see [ Flywheel overview](https://docs.aws.amazon.com/comprehend/latest/dg/flywheels-about.html)\nin the *Amazon Comprehend Developer Guide*.","ref":"AWS.Comprehend.html#describe_dataset/3","title":"AWS.Comprehend.describe_dataset/3","type":"function"},{"doc":"Gets the properties associated with a document classification job.\n\nUse this operation to get the status of a classification job.","ref":"AWS.Comprehend.html#describe_document_classification_job/3","title":"AWS.Comprehend.describe_document_classification_job/3","type":"function"},{"doc":"Gets the properties associated with a document classifier.","ref":"AWS.Comprehend.html#describe_document_classifier/3","title":"AWS.Comprehend.describe_document_classifier/3","type":"function"},{"doc":"Gets the properties associated with a dominant language detection job.\n\nUse this operation to get the status of a detection job.","ref":"AWS.Comprehend.html#describe_dominant_language_detection_job/3","title":"AWS.Comprehend.describe_dominant_language_detection_job/3","type":"function"},{"doc":"Gets the properties associated with a specific endpoint.\n\nUse this operation to get the status of an endpoint. For information about\nendpoints, see [Managing endpoints](https://docs.aws.amazon.com/comprehend/latest/dg/manage-endpoints.html).","ref":"AWS.Comprehend.html#describe_endpoint/3","title":"AWS.Comprehend.describe_endpoint/3","type":"function"},{"doc":"Gets the properties associated with an entities detection job.\n\nUse this operation to get the status of a detection job.","ref":"AWS.Comprehend.html#describe_entities_detection_job/3","title":"AWS.Comprehend.describe_entities_detection_job/3","type":"function"},{"doc":"Provides details about an entity recognizer including status, S3 buckets\ncontaining training data, recognizer metadata, metrics, and so on.","ref":"AWS.Comprehend.html#describe_entity_recognizer/3","title":"AWS.Comprehend.describe_entity_recognizer/3","type":"function"},{"doc":"Gets the status and details of an events detection job.","ref":"AWS.Comprehend.html#describe_events_detection_job/3","title":"AWS.Comprehend.describe_events_detection_job/3","type":"function"},{"doc":"Provides configuration information about the flywheel.\n\nFor more information about flywheels, see [ Flywheel overview](https://docs.aws.amazon.com/comprehend/latest/dg/flywheels-about.html)\nin the *Amazon Comprehend Developer Guide*.","ref":"AWS.Comprehend.html#describe_flywheel/3","title":"AWS.Comprehend.describe_flywheel/3","type":"function"},{"doc":"Retrieve the configuration properties of a flywheel iteration.\n\nFor more information about flywheels, see [ Flywheel overview](https://docs.aws.amazon.com/comprehend/latest/dg/flywheels-about.html)\nin the *Amazon Comprehend Developer Guide*.","ref":"AWS.Comprehend.html#describe_flywheel_iteration/3","title":"AWS.Comprehend.describe_flywheel_iteration/3","type":"function"},{"doc":"Gets the properties associated with a key phrases detection job.\n\nUse this operation to get the status of a detection job.","ref":"AWS.Comprehend.html#describe_key_phrases_detection_job/3","title":"AWS.Comprehend.describe_key_phrases_detection_job/3","type":"function"},{"doc":"Gets the properties associated with a PII entities detection job.\n\nFor example, you can use this operation to get the job status.","ref":"AWS.Comprehend.html#describe_pii_entities_detection_job/3","title":"AWS.Comprehend.describe_pii_entities_detection_job/3","type":"function"},{"doc":"Gets the details of a resource-based policy that is attached to a custom model,\nincluding the JSON body of the policy.","ref":"AWS.Comprehend.html#describe_resource_policy/3","title":"AWS.Comprehend.describe_resource_policy/3","type":"function"},{"doc":"Gets the properties associated with a sentiment detection job.\n\nUse this operation to get the status of a detection job.","ref":"AWS.Comprehend.html#describe_sentiment_detection_job/3","title":"AWS.Comprehend.describe_sentiment_detection_job/3","type":"function"},{"doc":"Gets the properties associated with a targeted sentiment detection job.\n\nUse this operation to get the status of the job.","ref":"AWS.Comprehend.html#describe_targeted_sentiment_detection_job/3","title":"AWS.Comprehend.describe_targeted_sentiment_detection_job/3","type":"function"},{"doc":"Gets the properties associated with a topic detection job.\n\nUse this operation to get the status of a detection job.","ref":"AWS.Comprehend.html#describe_topics_detection_job/3","title":"AWS.Comprehend.describe_topics_detection_job/3","type":"function"},{"doc":"Determines the dominant language of the input text.\n\nFor a list of languages that Amazon Comprehend can detect, see [Amazon Comprehend Supported\nLanguages](https://docs.aws.amazon.com/comprehend/latest/dg/how-languages.html).","ref":"AWS.Comprehend.html#detect_dominant_language/3","title":"AWS.Comprehend.detect_dominant_language/3","type":"function"},{"doc":"Detects named entities in input text when you use the pre-trained model.\n\nDetects custom entities if you have a custom entity recognition model.\n\nWhen detecting named entities using the pre-trained model, use plain text as the\ninput. For more information about named entities, see\n[Entities](https://docs.aws.amazon.com/comprehend/latest/dg/how-entities.html) in the Comprehend Developer Guide.\n\nWhen you use a custom entity recognition model, you can input plain text or you\ncan upload a single-page input document (text, PDF, Word, or image).\n\nIf the system detects errors while processing a page in the input document, the\nAPI response includes an entry in `Errors` for each error.\n\nIf the system detects a document-level error in your input document, the API\nreturns an `InvalidRequestException` error response. For details about this\nexception, see [ Errors in semi-structured\ndocuments](https://docs.aws.amazon.com/comprehend/latest/dg/idp-inputs-sync-err.html)\nin the Comprehend Developer Guide.","ref":"AWS.Comprehend.html#detect_entities/3","title":"AWS.Comprehend.detect_entities/3","type":"function"},{"doc":"Detects the key noun phrases found in the text.","ref":"AWS.Comprehend.html#detect_key_phrases/3","title":"AWS.Comprehend.detect_key_phrases/3","type":"function"},{"doc":"Inspects the input text for entities that contain personally identifiable\ninformation (PII) and returns information about them.","ref":"AWS.Comprehend.html#detect_pii_entities/3","title":"AWS.Comprehend.detect_pii_entities/3","type":"function"},{"doc":"Inspects text and returns an inference of the prevailing sentiment (`POSITIVE`,\n`NEUTRAL`, `MIXED`, or `NEGATIVE`).","ref":"AWS.Comprehend.html#detect_sentiment/3","title":"AWS.Comprehend.detect_sentiment/3","type":"function"},{"doc":"Inspects text for syntax and the part of speech of words in the document.\n\nFor more information, see\n[Syntax](https://docs.aws.amazon.com/comprehend/latest/dg/how-syntax.html) in\nthe Comprehend Developer Guide.","ref":"AWS.Comprehend.html#detect_syntax/3","title":"AWS.Comprehend.detect_syntax/3","type":"function"},{"doc":"Inspects the input text and returns a sentiment analysis for each entity\nidentified in the text.\n\nFor more information about targeted sentiment, see [Targeted sentiment](https://docs.aws.amazon.com/comprehend/latest/dg/how-targeted-sentiment.html)\nin the *Amazon Comprehend Developer Guide*.","ref":"AWS.Comprehend.html#detect_targeted_sentiment/3","title":"AWS.Comprehend.detect_targeted_sentiment/3","type":"function"},{"doc":"Performs toxicity analysis on the list of text strings that you provide as\ninput.\n\nThe API response contains a results list that matches the size of the input\nlist. For more information about toxicity detection, see [Toxicity detection](https://docs.aws.amazon.com/comprehend/latest/dg/toxicity-detection.html)\nin the *Amazon Comprehend Developer Guide*.","ref":"AWS.Comprehend.html#detect_toxic_content/3","title":"AWS.Comprehend.detect_toxic_content/3","type":"function"},{"doc":"Creates a new custom model that replicates a source custom model that you\nimport.\n\nThe source model can be in your Amazon Web Services account or another one.\n\nIf the source model is in another Amazon Web Services account, then it must have\na resource-based policy that authorizes you to import it.\n\nThe source model must be in the same Amazon Web Services Region that you're\nusing when you import. You can't import a model that's in a different Region.","ref":"AWS.Comprehend.html#import_model/3","title":"AWS.Comprehend.import_model/3","type":"function"},{"doc":"List the datasets that you have configured in this Region.\n\nFor more information about datasets, see [ Flywheel overview](https://docs.aws.amazon.com/comprehend/latest/dg/flywheels-about.html)\nin the *Amazon Comprehend Developer Guide*.","ref":"AWS.Comprehend.html#list_datasets/3","title":"AWS.Comprehend.list_datasets/3","type":"function"},{"doc":"Gets a list of the documentation classification jobs that you have submitted.","ref":"AWS.Comprehend.html#list_document_classification_jobs/3","title":"AWS.Comprehend.list_document_classification_jobs/3","type":"function"},{"doc":"Gets a list of summaries of the document classifiers that you have created","ref":"AWS.Comprehend.html#list_document_classifier_summaries/3","title":"AWS.Comprehend.list_document_classifier_summaries/3","type":"function"},{"doc":"Gets a list of the document classifiers that you have created.","ref":"AWS.Comprehend.html#list_document_classifiers/3","title":"AWS.Comprehend.list_document_classifiers/3","type":"function"},{"doc":"Gets a list of the dominant language detection jobs that you have submitted.","ref":"AWS.Comprehend.html#list_dominant_language_detection_jobs/3","title":"AWS.Comprehend.list_dominant_language_detection_jobs/3","type":"function"},{"doc":"Gets a list of all existing endpoints that you've created.\n\nFor information about endpoints, see [Managing endpoints](https://docs.aws.amazon.com/comprehend/latest/dg/manage-endpoints.html).","ref":"AWS.Comprehend.html#list_endpoints/3","title":"AWS.Comprehend.list_endpoints/3","type":"function"},{"doc":"Gets a list of the entity detection jobs that you have submitted.","ref":"AWS.Comprehend.html#list_entities_detection_jobs/3","title":"AWS.Comprehend.list_entities_detection_jobs/3","type":"function"},{"doc":"Gets a list of summaries for the entity recognizers that you have created.","ref":"AWS.Comprehend.html#list_entity_recognizer_summaries/3","title":"AWS.Comprehend.list_entity_recognizer_summaries/3","type":"function"},{"doc":"Gets a list of the properties of all entity recognizers that you created,\nincluding recognizers currently in training.\n\nAllows you to filter the list of recognizers based on criteria such as status\nand submission time. This call returns up to 500 entity recognizers in the list,\nwith a default number of 100 recognizers in the list.\n\nThe results of this list are not in any particular order. Please get the list\nand sort locally if needed.","ref":"AWS.Comprehend.html#list_entity_recognizers/3","title":"AWS.Comprehend.list_entity_recognizers/3","type":"function"},{"doc":"Gets a list of the events detection jobs that you have submitted.","ref":"AWS.Comprehend.html#list_events_detection_jobs/3","title":"AWS.Comprehend.list_events_detection_jobs/3","type":"function"},{"doc":"Information about the history of a flywheel iteration.\n\nFor more information about flywheels, see [ Flywheel overview](https://docs.aws.amazon.com/comprehend/latest/dg/flywheels-about.html)\nin the *Amazon Comprehend Developer Guide*.","ref":"AWS.Comprehend.html#list_flywheel_iteration_history/3","title":"AWS.Comprehend.list_flywheel_iteration_history/3","type":"function"},{"doc":"Gets a list of the flywheels that you have created.","ref":"AWS.Comprehend.html#list_flywheels/3","title":"AWS.Comprehend.list_flywheels/3","type":"function"},{"doc":"Get a list of key phrase detection jobs that you have submitted.","ref":"AWS.Comprehend.html#list_key_phrases_detection_jobs/3","title":"AWS.Comprehend.list_key_phrases_detection_jobs/3","type":"function"},{"doc":"Gets a list of the PII entity detection jobs that you have submitted.","ref":"AWS.Comprehend.html#list_pii_entities_detection_jobs/3","title":"AWS.Comprehend.list_pii_entities_detection_jobs/3","type":"function"},{"doc":"Gets a list of sentiment detection jobs that you have submitted.","ref":"AWS.Comprehend.html#list_sentiment_detection_jobs/3","title":"AWS.Comprehend.list_sentiment_detection_jobs/3","type":"function"},{"doc":"Lists all tags associated with a given Amazon Comprehend resource.","ref":"AWS.Comprehend.html#list_tags_for_resource/3","title":"AWS.Comprehend.list_tags_for_resource/3","type":"function"},{"doc":"Gets a list of targeted sentiment detection jobs that you have submitted.","ref":"AWS.Comprehend.html#list_targeted_sentiment_detection_jobs/3","title":"AWS.Comprehend.list_targeted_sentiment_detection_jobs/3","type":"function"},{"doc":"Gets a list of the topic detection jobs that you have submitted.","ref":"AWS.Comprehend.html#list_topics_detection_jobs/3","title":"AWS.Comprehend.list_topics_detection_jobs/3","type":"function"},{"doc":"","ref":"AWS.Comprehend.html#metadata/0","title":"AWS.Comprehend.metadata/0","type":"function"},{"doc":"Attaches a resource-based policy to a custom model.\n\nYou can use this policy to authorize an entity in another Amazon Web Services\naccount to import the custom model, which replicates it in Amazon Comprehend in\ntheir account.","ref":"AWS.Comprehend.html#put_resource_policy/3","title":"AWS.Comprehend.put_resource_policy/3","type":"function"},{"doc":"Starts an asynchronous document classification job using a custom classification\nmodel.\n\nUse the `DescribeDocumentClassificationJob` operation to track the progress of\nthe job.","ref":"AWS.Comprehend.html#start_document_classification_job/3","title":"AWS.Comprehend.start_document_classification_job/3","type":"function"},{"doc":"Starts an asynchronous dominant language detection job for a collection of\ndocuments.\n\nUse the operation to track the status of a job.","ref":"AWS.Comprehend.html#start_dominant_language_detection_job/3","title":"AWS.Comprehend.start_dominant_language_detection_job/3","type":"function"},{"doc":"Starts an asynchronous entity detection job for a collection of documents.\n\nUse the operation to track the status of a job.\n\nThis API can be used for either standard entity detection or custom entity\nrecognition. In order to be used for custom entity recognition, the optional\n`EntityRecognizerArn` must be used in order to provide access to the recognizer\nbeing used to detect the custom entity.","ref":"AWS.Comprehend.html#start_entities_detection_job/3","title":"AWS.Comprehend.start_entities_detection_job/3","type":"function"},{"doc":"Starts an asynchronous event detection job for a collection of documents.","ref":"AWS.Comprehend.html#start_events_detection_job/3","title":"AWS.Comprehend.start_events_detection_job/3","type":"function"},{"doc":"Start the flywheel iteration.This operation uses any new datasets to train a new\nmodel version.\n\nFor more information about flywheels, see [ Flywheel overview](https://docs.aws.amazon.com/comprehend/latest/dg/flywheels-about.html)\nin the *Amazon Comprehend Developer Guide*.","ref":"AWS.Comprehend.html#start_flywheel_iteration/3","title":"AWS.Comprehend.start_flywheel_iteration/3","type":"function"},{"doc":"Starts an asynchronous key phrase detection job for a collection of documents.\n\nUse the operation to track the status of a job.","ref":"AWS.Comprehend.html#start_key_phrases_detection_job/3","title":"AWS.Comprehend.start_key_phrases_detection_job/3","type":"function"},{"doc":"Starts an asynchronous PII entity detection job for a collection of documents.","ref":"AWS.Comprehend.html#start_pii_entities_detection_job/3","title":"AWS.Comprehend.start_pii_entities_detection_job/3","type":"function"},{"doc":"Starts an asynchronous sentiment detection job for a collection of documents.\n\nUse the operation to track the status of a job.","ref":"AWS.Comprehend.html#start_sentiment_detection_job/3","title":"AWS.Comprehend.start_sentiment_detection_job/3","type":"function"},{"doc":"Starts an asynchronous targeted sentiment detection job for a collection of\ndocuments.\n\nUse the `DescribeTargetedSentimentDetectionJob` operation to track the status of\na job.","ref":"AWS.Comprehend.html#start_targeted_sentiment_detection_job/3","title":"AWS.Comprehend.start_targeted_sentiment_detection_job/3","type":"function"},{"doc":"Starts an asynchronous topic detection job.\n\nUse the `DescribeTopicDetectionJob` operation to track the status of a job.","ref":"AWS.Comprehend.html#start_topics_detection_job/3","title":"AWS.Comprehend.start_topics_detection_job/3","type":"function"},{"doc":"Stops a dominant language detection job in progress.\n\nIf the job state is `IN_PROGRESS` the job is marked for termination and put into\nthe `STOP_REQUESTED` state. If the job completes before it can be stopped, it is\nput into the `COMPLETED` state; otherwise the job is stopped and put into the\n`STOPPED` state.\n\nIf the job is in the `COMPLETED` or `FAILED` state when you call the\n`StopDominantLanguageDetectionJob` operation, the operation returns a 400\nInternal Request Exception.\n\nWhen a job is stopped, any documents already processed are written to the output\nlocation.","ref":"AWS.Comprehend.html#stop_dominant_language_detection_job/3","title":"AWS.Comprehend.stop_dominant_language_detection_job/3","type":"function"},{"doc":"Stops an entities detection job in progress.\n\nIf the job state is `IN_PROGRESS` the job is marked for termination and put into\nthe `STOP_REQUESTED` state. If the job completes before it can be stopped, it is\nput into the `COMPLETED` state; otherwise the job is stopped and put into the\n`STOPPED` state.\n\nIf the job is in the `COMPLETED` or `FAILED` state when you call the\n`StopDominantLanguageDetectionJob` operation, the operation returns a 400\nInternal Request Exception.\n\nWhen a job is stopped, any documents already processed are written to the output\nlocation.","ref":"AWS.Comprehend.html#stop_entities_detection_job/3","title":"AWS.Comprehend.stop_entities_detection_job/3","type":"function"},{"doc":"Stops an events detection job in progress.","ref":"AWS.Comprehend.html#stop_events_detection_job/3","title":"AWS.Comprehend.stop_events_detection_job/3","type":"function"},{"doc":"Stops a key phrases detection job in progress.\n\nIf the job state is `IN_PROGRESS` the job is marked for termination and put into\nthe `STOP_REQUESTED` state. If the job completes before it can be stopped, it is\nput into the `COMPLETED` state; otherwise the job is stopped and put into the\n`STOPPED` state.\n\nIf the job is in the `COMPLETED` or `FAILED` state when you call the\n`StopDominantLanguageDetectionJob` operation, the operation returns a 400\nInternal Request Exception.\n\nWhen a job is stopped, any documents already processed are written to the output\nlocation.","ref":"AWS.Comprehend.html#stop_key_phrases_detection_job/3","title":"AWS.Comprehend.stop_key_phrases_detection_job/3","type":"function"},{"doc":"Stops a PII entities detection job in progress.","ref":"AWS.Comprehend.html#stop_pii_entities_detection_job/3","title":"AWS.Comprehend.stop_pii_entities_detection_job/3","type":"function"},{"doc":"Stops a sentiment detection job in progress.\n\nIf the job state is `IN_PROGRESS`, the job is marked for termination and put\ninto the `STOP_REQUESTED` state. If the job completes before it can be stopped,\nit is put into the `COMPLETED` state; otherwise the job is be stopped and put\ninto the `STOPPED` state.\n\nIf the job is in the `COMPLETED` or `FAILED` state when you call the\n`StopDominantLanguageDetectionJob` operation, the operation returns a 400\nInternal Request Exception.\n\nWhen a job is stopped, any documents already processed are written to the output\nlocation.","ref":"AWS.Comprehend.html#stop_sentiment_detection_job/3","title":"AWS.Comprehend.stop_sentiment_detection_job/3","type":"function"},{"doc":"Stops a targeted sentiment detection job in progress.\n\nIf the job state is `IN_PROGRESS`, the job is marked for termination and put\ninto the `STOP_REQUESTED` state. If the job completes before it can be stopped,\nit is put into the `COMPLETED` state; otherwise the job is be stopped and put\ninto the `STOPPED` state.\n\nIf the job is in the `COMPLETED` or `FAILED` state when you call the\n`StopDominantLanguageDetectionJob` operation, the operation returns a 400\nInternal Request Exception.\n\nWhen a job is stopped, any documents already processed are written to the output\nlocation.","ref":"AWS.Comprehend.html#stop_targeted_sentiment_detection_job/3","title":"AWS.Comprehend.stop_targeted_sentiment_detection_job/3","type":"function"},{"doc":"Stops a document classifier training job while in progress.\n\nIf the training job state is `TRAINING`, the job is marked for termination and\nput into the `STOP_REQUESTED` state. If the training job completes before it can\nbe stopped, it is put into the `TRAINED`; otherwise the training job is stopped\nand put into the `STOPPED` state and the service sends back an HTTP 200 response\nwith an empty HTTP body.","ref":"AWS.Comprehend.html#stop_training_document_classifier/3","title":"AWS.Comprehend.stop_training_document_classifier/3","type":"function"},{"doc":"Stops an entity recognizer training job while in progress.\n\nIf the training job state is `TRAINING`, the job is marked for termination and\nput into the `STOP_REQUESTED` state. If the training job completes before it can\nbe stopped, it is put into the `TRAINED`; otherwise the training job is stopped\nand putted into the `STOPPED` state and the service sends back an HTTP 200\nresponse with an empty HTTP body.","ref":"AWS.Comprehend.html#stop_training_entity_recognizer/3","title":"AWS.Comprehend.stop_training_entity_recognizer/3","type":"function"},{"doc":"Associates a specific tag with an Amazon Comprehend resource.\n\nA tag is a key-value pair that adds as a metadata to a resource used by Amazon\nComprehend. For example, a tag with \"Sales\" as the key might be added to a\nresource to indicate its use by the sales department.","ref":"AWS.Comprehend.html#tag_resource/3","title":"AWS.Comprehend.tag_resource/3","type":"function"},{"doc":"Removes a specific tag associated with an Amazon Comprehend resource.","ref":"AWS.Comprehend.html#untag_resource/3","title":"AWS.Comprehend.untag_resource/3","type":"function"},{"doc":"Updates information about the specified endpoint.\n\nFor information about endpoints, see [Managing endpoints](https://docs.aws.amazon.com/comprehend/latest/dg/manage-endpoints.html).","ref":"AWS.Comprehend.html#update_endpoint/3","title":"AWS.Comprehend.update_endpoint/3","type":"function"},{"doc":"Update the configuration information for an existing flywheel.","ref":"AWS.Comprehend.html#update_flywheel/3","title":"AWS.Comprehend.update_flywheel/3","type":"function"},{"doc":"Amazon Comprehend Medical extracts structured information from unstructured\nclinical text.\n\nUse these actions to gain insight in your documents. Amazon Comprehend Medical\nonly detects entities in English language texts. Amazon Comprehend Medical\nplaces limits on the sizes of files allowed for different API operations. To\nlearn more, see [Guidelines and quotas](https://docs.aws.amazon.com/comprehend-medical/latest/dev/comprehendmedical-quotas.html)\nin the *Amazon Comprehend Medical Developer Guide*.","ref":"AWS.ComprehendMedical.html","title":"AWS.ComprehendMedical","type":"module"},{"doc":"Gets the properties associated with a medical entities detection job.\n\nUse this operation to get the status of a detection job.","ref":"AWS.ComprehendMedical.html#describe_entities_detection_v2_job/3","title":"AWS.ComprehendMedical.describe_entities_detection_v2_job/3","type":"function"},{"doc":"Gets the properties associated with an InferICD10CM job.\n\nUse this operation to get the status of an inference job.","ref":"AWS.ComprehendMedical.html#describe_icd10_cm_inference_job/3","title":"AWS.ComprehendMedical.describe_icd10_cm_inference_job/3","type":"function"},{"doc":"Gets the properties associated with a protected health information (PHI)\ndetection job.\n\nUse this operation to get the status of a detection job.","ref":"AWS.ComprehendMedical.html#describe_phi_detection_job/3","title":"AWS.ComprehendMedical.describe_phi_detection_job/3","type":"function"},{"doc":"Gets the properties associated with an InferRxNorm job.\n\nUse this operation to get the status of an inference job.","ref":"AWS.ComprehendMedical.html#describe_rx_norm_inference_job/3","title":"AWS.ComprehendMedical.describe_rx_norm_inference_job/3","type":"function"},{"doc":"Gets the properties associated with an InferSNOMEDCT job.\n\nUse this operation to get the status of an inference job.","ref":"AWS.ComprehendMedical.html#describe_s_n_o_m_e_d_c_t_inference_job/3","title":"AWS.ComprehendMedical.describe_s_n_o_m_e_d_c_t_inference_job/3","type":"function"},{"doc":"The `DetectEntities` operation is deprecated.\n\nYou should use the `DetectEntitiesV2` operation instead.\n\nInspects the clinical text for a variety of medical entities and returns\nspecific information about them such as entity category, location, and\nconfidence score on that information.","ref":"AWS.ComprehendMedical.html#detect_entities/3","title":"AWS.ComprehendMedical.detect_entities/3","type":"function"},{"doc":"Inspects the clinical text for a variety of medical entities and returns\nspecific information about them such as entity category, location, and\nconfidence score on that information.\n\nAmazon Comprehend Medical only detects medical entities in English language\ntexts.\n\nThe `DetectEntitiesV2` operation replaces the `DetectEntities` operation. This\nnew action uses a different model for determining the entities in your medical\ntext and changes the way that some entities are returned in the output. You\nshould use the `DetectEntitiesV2` operation in all new applications.\n\nThe `DetectEntitiesV2` operation returns the `Acuity` and `Direction` entities\nas attributes instead of types.","ref":"AWS.ComprehendMedical.html#detect_entities_v2/3","title":"AWS.ComprehendMedical.detect_entities_v2/3","type":"function"},{"doc":"Inspects the clinical text for protected health information (PHI) entities and\nreturns the entity category, location, and confidence score for each entity.\n\nAmazon Comprehend Medical only detects entities in English language texts.","ref":"AWS.ComprehendMedical.html#detect_phi/3","title":"AWS.ComprehendMedical.detect_phi/3","type":"function"},{"doc":"InferICD10CM detects medical conditions as entities listed in a patient record\nand links those entities to normalized concept identifiers in the ICD-10-CM\nknowledge base from the Centers for Disease Control.\n\nAmazon Comprehend Medical only detects medical entities in English language\ntexts.","ref":"AWS.ComprehendMedical.html#infer_icd10_cm/3","title":"AWS.ComprehendMedical.infer_icd10_cm/3","type":"function"},{"doc":"InferRxNorm detects medications as entities listed in a patient record and links\nto the normalized concept identifiers in the RxNorm database from the National\nLibrary of Medicine.\n\nAmazon Comprehend Medical only detects medical entities in English language\ntexts.","ref":"AWS.ComprehendMedical.html#infer_rx_norm/3","title":"AWS.ComprehendMedical.infer_rx_norm/3","type":"function"},{"doc":"InferSNOMEDCT detects possible medical concepts as entities and links them to\ncodes from the Systematized Nomenclature of Medicine, Clinical Terms (SNOMED-CT)\nontology","ref":"AWS.ComprehendMedical.html#infer_s_n_o_m_e_d_c_t/3","title":"AWS.ComprehendMedical.infer_s_n_o_m_e_d_c_t/3","type":"function"},{"doc":"Gets a list of medical entity detection jobs that you have submitted.","ref":"AWS.ComprehendMedical.html#list_entities_detection_v2_jobs/3","title":"AWS.ComprehendMedical.list_entities_detection_v2_jobs/3","type":"function"},{"doc":"Gets a list of InferICD10CM jobs that you have submitted.","ref":"AWS.ComprehendMedical.html#list_icd10_cm_inference_jobs/3","title":"AWS.ComprehendMedical.list_icd10_cm_inference_jobs/3","type":"function"},{"doc":"Gets a list of protected health information (PHI) detection jobs you have\nsubmitted.","ref":"AWS.ComprehendMedical.html#list_phi_detection_jobs/3","title":"AWS.ComprehendMedical.list_phi_detection_jobs/3","type":"function"},{"doc":"Gets a list of InferRxNorm jobs that you have submitted.","ref":"AWS.ComprehendMedical.html#list_rx_norm_inference_jobs/3","title":"AWS.ComprehendMedical.list_rx_norm_inference_jobs/3","type":"function"},{"doc":"Gets a list of InferSNOMEDCT jobs a user has submitted.","ref":"AWS.ComprehendMedical.html#list_s_n_o_m_e_d_c_t_inference_jobs/3","title":"AWS.ComprehendMedical.list_s_n_o_m_e_d_c_t_inference_jobs/3","type":"function"},{"doc":"","ref":"AWS.ComprehendMedical.html#metadata/0","title":"AWS.ComprehendMedical.metadata/0","type":"function"},{"doc":"Starts an asynchronous medical entity detection job for a collection of\ndocuments.\n\nUse the `DescribeEntitiesDetectionV2Job` operation to track the status of a job.","ref":"AWS.ComprehendMedical.html#start_entities_detection_v2_job/3","title":"AWS.ComprehendMedical.start_entities_detection_v2_job/3","type":"function"},{"doc":"Starts an asynchronous job to detect medical conditions and link them to the\nICD-10-CM ontology.\n\nUse the `DescribeICD10CMInferenceJob` operation to track the status of a job.","ref":"AWS.ComprehendMedical.html#start_icd10_cm_inference_job/3","title":"AWS.ComprehendMedical.start_icd10_cm_inference_job/3","type":"function"},{"doc":"Starts an asynchronous job to detect protected health information (PHI).\n\nUse the `DescribePHIDetectionJob` operation to track the status of a job.","ref":"AWS.ComprehendMedical.html#start_phi_detection_job/3","title":"AWS.ComprehendMedical.start_phi_detection_job/3","type":"function"},{"doc":"Starts an asynchronous job to detect medication entities and link them to the\nRxNorm ontology.\n\nUse the `DescribeRxNormInferenceJob` operation to track the status of a job.","ref":"AWS.ComprehendMedical.html#start_rx_norm_inference_job/3","title":"AWS.ComprehendMedical.start_rx_norm_inference_job/3","type":"function"},{"doc":"Starts an asynchronous job to detect medical concepts and link them to the\nSNOMED-CT ontology.\n\nUse the DescribeSNOMEDCTInferenceJob operation to track the status of a job.","ref":"AWS.ComprehendMedical.html#start_s_n_o_m_e_d_c_t_inference_job/3","title":"AWS.ComprehendMedical.start_s_n_o_m_e_d_c_t_inference_job/3","type":"function"},{"doc":"Stops a medical entities detection job in progress.","ref":"AWS.ComprehendMedical.html#stop_entities_detection_v2_job/3","title":"AWS.ComprehendMedical.stop_entities_detection_v2_job/3","type":"function"},{"doc":"Stops an InferICD10CM inference job in progress.","ref":"AWS.ComprehendMedical.html#stop_icd10_cm_inference_job/3","title":"AWS.ComprehendMedical.stop_icd10_cm_inference_job/3","type":"function"},{"doc":"Stops a protected health information (PHI) detection job in progress.","ref":"AWS.ComprehendMedical.html#stop_phi_detection_job/3","title":"AWS.ComprehendMedical.stop_phi_detection_job/3","type":"function"},{"doc":"Stops an InferRxNorm inference job in progress.","ref":"AWS.ComprehendMedical.html#stop_rx_norm_inference_job/3","title":"AWS.ComprehendMedical.stop_rx_norm_inference_job/3","type":"function"},{"doc":"Stops an InferSNOMEDCT inference job in progress.","ref":"AWS.ComprehendMedical.html#stop_s_n_o_m_e_d_c_t_inference_job/3","title":"AWS.ComprehendMedical.stop_s_n_o_m_e_d_c_t_inference_job/3","type":"function"},{"doc":"Compute Optimizer is a service that analyzes the configuration and utilization\nmetrics of your Amazon Web Services compute resources, such as Amazon EC2\ninstances, Amazon EC2 Auto Scaling groups, Lambda functions, Amazon EBS volumes,\nand Amazon ECS services on Fargate.\n\nIt reports whether your resources are optimal, and generates optimization\nrecommendations to reduce the cost and improve the performance of your\nworkloads. Compute Optimizer also provides recent utilization metric data, in\naddition to projected utilization metric data for the recommendations, which you\ncan use to evaluate which recommendation provides the best price-performance\ntrade-off. The analysis of your usage patterns can help you decide when to move\nor resize your running resources, and still meet your performance and capacity\nrequirements. For more information about Compute Optimizer, including the\nrequired permissions to use the service, see the [Compute Optimizer User Guide](https://docs.aws.amazon.com/compute-optimizer/latest/ug/).","ref":"AWS.ComputeOptimizer.html","title":"AWS.ComputeOptimizer","type":"module"},{"doc":"Deletes a recommendation preference, such as enhanced infrastructure metrics.\n\nFor more information, see [Activating enhanced infrastructure metrics](https://docs.aws.amazon.com/compute-optimizer/latest/ug/enhanced-infrastructure-metrics.html)\nin the *Compute Optimizer User Guide*.","ref":"AWS.ComputeOptimizer.html#delete_recommendation_preferences/3","title":"AWS.ComputeOptimizer.delete_recommendation_preferences/3","type":"function"},{"doc":"Describes recommendation export jobs created in the last seven days.\n\nUse the `ExportAutoScalingGroupRecommendations` or\n`ExportEC2InstanceRecommendations` actions to request an export of your\nrecommendations. Then use the `DescribeRecommendationExportJobs` action to view\nyour export jobs.","ref":"AWS.ComputeOptimizer.html#describe_recommendation_export_jobs/3","title":"AWS.ComputeOptimizer.describe_recommendation_export_jobs/3","type":"function"},{"doc":"Exports optimization recommendations for Auto Scaling groups.\n\nRecommendations are exported in a comma-separated values (.csv) file, and its\nmetadata in a JavaScript Object Notation (JSON) (.json) file, to an existing\nAmazon Simple Storage Service (Amazon S3) bucket that you specify. For more\ninformation, see [Exporting Recommendations](https://docs.aws.amazon.com/compute-optimizer/latest/ug/exporting-recommendations.html)\nin the *Compute Optimizer User Guide*.\n\nYou can have only one Auto Scaling group export job in progress per Amazon Web\nServices Region.","ref":"AWS.ComputeOptimizer.html#export_auto_scaling_group_recommendations/3","title":"AWS.ComputeOptimizer.export_auto_scaling_group_recommendations/3","type":"function"},{"doc":"Exports optimization recommendations for Amazon ECS services on Fargate.\n\nRecommendations are exported in a CSV file, and its metadata in a JSON file, to\nan existing Amazon Simple Storage Service (Amazon S3) bucket that you specify.\nFor more information, see [Exporting Recommendations](https://docs.aws.amazon.com/compute-optimizer/latest/ug/exporting-recommendations.html)\nin the *Compute Optimizer User Guide*.\n\nYou can only have one Amazon ECS service export job in progress per Amazon Web\nServices Region.","ref":"AWS.ComputeOptimizer.html#export_e_c_s_service_recommendations/3","title":"AWS.ComputeOptimizer.export_e_c_s_service_recommendations/3","type":"function"},{"doc":"Exports optimization recommendations for Amazon EBS volumes.\n\nRecommendations are exported in a comma-separated values (.csv) file, and its\nmetadata in a JavaScript Object Notation (JSON) (.json) file, to an existing\nAmazon Simple Storage Service (Amazon S3) bucket that you specify. For more\ninformation, see [Exporting Recommendations](https://docs.aws.amazon.com/compute-optimizer/latest/ug/exporting-recommendations.html)\nin the *Compute Optimizer User Guide*.\n\nYou can have only one Amazon EBS volume export job in progress per Amazon Web\nServices Region.","ref":"AWS.ComputeOptimizer.html#export_ebs_volume_recommendations/3","title":"AWS.ComputeOptimizer.export_ebs_volume_recommendations/3","type":"function"},{"doc":"Exports optimization recommendations for Amazon EC2 instances.\n\nRecommendations are exported in a comma-separated values (.csv) file, and its\nmetadata in a JavaScript Object Notation (JSON) (.json) file, to an existing\nAmazon Simple Storage Service (Amazon S3) bucket that you specify. For more\ninformation, see [Exporting Recommendations](https://docs.aws.amazon.com/compute-optimizer/latest/ug/exporting-recommendations.html)\nin the *Compute Optimizer User Guide*.\n\nYou can have only one Amazon EC2 instance export job in progress per Amazon Web\nServices Region.","ref":"AWS.ComputeOptimizer.html#export_ec2_instance_recommendations/3","title":"AWS.ComputeOptimizer.export_ec2_instance_recommendations/3","type":"function"},{"doc":"Exports optimization recommendations for Lambda functions.\n\nRecommendations are exported in a comma-separated values (.csv) file, and its\nmetadata in a JavaScript Object Notation (JSON) (.json) file, to an existing\nAmazon Simple Storage Service (Amazon S3) bucket that you specify. For more\ninformation, see [Exporting Recommendations](https://docs.aws.amazon.com/compute-optimizer/latest/ug/exporting-recommendations.html)\nin the *Compute Optimizer User Guide*.\n\nYou can have only one Lambda function export job in progress per Amazon Web\nServices Region.","ref":"AWS.ComputeOptimizer.html#export_lambda_function_recommendations/3","title":"AWS.ComputeOptimizer.export_lambda_function_recommendations/3","type":"function"},{"doc":"Export optimization recommendations for your licenses.\n\nRecommendations are exported in a comma-separated values (CSV) file, and its\nmetadata in a JavaScript Object Notation (JSON) file, to an existing Amazon\nSimple Storage Service (Amazon S3) bucket that you specify. For more\ninformation, see [Exporting Recommendations](https://docs.aws.amazon.com/compute-optimizer/latest/ug/exporting-recommendations.html)\nin the *Compute Optimizer User Guide*.\n\nYou can have only one license export job in progress per Amazon Web Services\nRegion.","ref":"AWS.ComputeOptimizer.html#export_license_recommendations/3","title":"AWS.ComputeOptimizer.export_license_recommendations/3","type":"function"},{"doc":"Returns Auto Scaling group recommendations.\n\nCompute Optimizer generates recommendations for Amazon EC2 Auto Scaling groups\nthat meet a specific set of requirements. For more information, see the\n[Supported resources and requirements](https://docs.aws.amazon.com/compute-optimizer/latest/ug/requirements.html)\nin the *Compute Optimizer User Guide*.","ref":"AWS.ComputeOptimizer.html#get_auto_scaling_group_recommendations/3","title":"AWS.ComputeOptimizer.get_auto_scaling_group_recommendations/3","type":"function"},{"doc":"Returns the projected metrics of Amazon ECS service recommendations.","ref":"AWS.ComputeOptimizer.html#get_e_c_s_service_recommendation_projected_metrics/3","title":"AWS.ComputeOptimizer.get_e_c_s_service_recommendation_projected_metrics/3","type":"function"},{"doc":"Returns Amazon ECS service recommendations.\n\nCompute Optimizer generates recommendations for Amazon ECS services on Fargate\nthat meet a specific set of requirements. For more information, see the\n[Supported resources and requirements](https://docs.aws.amazon.com/compute-optimizer/latest/ug/requirements.html)\nin the *Compute Optimizer User Guide*.","ref":"AWS.ComputeOptimizer.html#get_e_c_s_service_recommendations/3","title":"AWS.ComputeOptimizer.get_e_c_s_service_recommendations/3","type":"function"},{"doc":"Returns Amazon Elastic Block Store (Amazon EBS) volume recommendations.\n\nCompute Optimizer generates recommendations for Amazon EBS volumes that meet a\nspecific set of requirements. For more information, see the [Supported resources and\nrequirements](https://docs.aws.amazon.com/compute-optimizer/latest/ug/requirements.html)\nin the *Compute Optimizer User Guide*.","ref":"AWS.ComputeOptimizer.html#get_ebs_volume_recommendations/3","title":"AWS.ComputeOptimizer.get_ebs_volume_recommendations/3","type":"function"},{"doc":"Returns Amazon EC2 instance recommendations.\n\nCompute Optimizer generates recommendations for Amazon Elastic Compute Cloud\n(Amazon EC2) instances that meet a specific set of requirements. For more\ninformation, see the [Supported resources and requirements](https://docs.aws.amazon.com/compute-optimizer/latest/ug/requirements.html)\nin the *Compute Optimizer User Guide*.","ref":"AWS.ComputeOptimizer.html#get_ec2_instance_recommendations/3","title":"AWS.ComputeOptimizer.get_ec2_instance_recommendations/3","type":"function"},{"doc":"Returns the projected utilization metrics of Amazon EC2 instance\nrecommendations.\n\nThe `Cpu` and `Memory` metrics are the only projected utilization metrics\nreturned when you run this action. Additionally, the `Memory` metric is returned\nonly for resources that have the unified CloudWatch agent installed on them. For\nmore information, see [Enabling Memory Utilization with the CloudWatch Agent](https://docs.aws.amazon.com/compute-optimizer/latest/ug/metrics.html#cw-agent).","ref":"AWS.ComputeOptimizer.html#get_ec2_recommendation_projected_metrics/3","title":"AWS.ComputeOptimizer.get_ec2_recommendation_projected_metrics/3","type":"function"},{"doc":"Returns the recommendation preferences that are in effect for a given resource,\nsuch as enhanced infrastructure metrics.\n\nConsiders all applicable preferences that you might have set at the resource,\naccount, and organization level.\n\nWhen you create a recommendation preference, you can set its status to `Active`\nor `Inactive`. Use this action to view the recommendation preferences that are\nin effect, or `Active`.","ref":"AWS.ComputeOptimizer.html#get_effective_recommendation_preferences/3","title":"AWS.ComputeOptimizer.get_effective_recommendation_preferences/3","type":"function"},{"doc":"Returns the enrollment (opt in) status of an account to the Compute Optimizer\nservice.\n\nIf the account is the management account of an organization, this action also\nconfirms the enrollment status of member accounts of the organization. Use the\n`GetEnrollmentStatusesForOrganization` action to get detailed information about\nthe enrollment status of member accounts of an organization.","ref":"AWS.ComputeOptimizer.html#get_enrollment_status/3","title":"AWS.ComputeOptimizer.get_enrollment_status/3","type":"function"},{"doc":"Returns the Compute Optimizer enrollment (opt-in) status of organization member\naccounts, if your account is an organization management account.\n\nTo get the enrollment status of standalone accounts, use the\n`GetEnrollmentStatus` action.","ref":"AWS.ComputeOptimizer.html#get_enrollment_statuses_for_organization/3","title":"AWS.ComputeOptimizer.get_enrollment_statuses_for_organization/3","type":"function"},{"doc":"Returns Lambda function recommendations.\n\nCompute Optimizer generates recommendations for functions that meet a specific\nset of requirements. For more information, see the [Supported resources and requirements](https://docs.aws.amazon.com/compute-optimizer/latest/ug/requirements.html)\nin the *Compute Optimizer User Guide*.","ref":"AWS.ComputeOptimizer.html#get_lambda_function_recommendations/3","title":"AWS.ComputeOptimizer.get_lambda_function_recommendations/3","type":"function"},{"doc":"Returns license recommendations for Amazon EC2 instances that run on a specific\nlicense.\n\nCompute Optimizer generates recommendations for licenses that meet a specific\nset of requirements. For more information, see the [Supported resources and requirements](https://docs.aws.amazon.com/compute-optimizer/latest/ug/requirements.html)\nin the *Compute Optimizer User Guide*.","ref":"AWS.ComputeOptimizer.html#get_license_recommendations/3","title":"AWS.ComputeOptimizer.get_license_recommendations/3","type":"function"},{"doc":"Returns existing recommendation preferences, such as enhanced infrastructure\nmetrics.\n\nUse the `scope` parameter to specify which preferences to return. You can\nspecify to return preferences for an organization, a specific account ID, or a\nspecific EC2 instance or Auto Scaling group Amazon Resource Name (ARN).\n\nFor more information, see [Activating enhanced infrastructure metrics](https://docs.aws.amazon.com/compute-optimizer/latest/ug/enhanced-infrastructure-metrics.html)\nin the *Compute Optimizer User Guide*.","ref":"AWS.ComputeOptimizer.html#get_recommendation_preferences/3","title":"AWS.ComputeOptimizer.get_recommendation_preferences/3","type":"function"},{"doc":"Returns the optimization findings for an account.\n\nIt returns the number of:\n\n  * Amazon EC2 instances in an account that are `Underprovisioned`,\n`Overprovisioned`, or `Optimized`.\n\n  * Auto Scaling groups in an account that are `NotOptimized`, or\n`Optimized`.\n\n  * Amazon EBS volumes in an account that are `NotOptimized`, or\n`Optimized`.\n\n  * Lambda functions in an account that are `NotOptimized`, or\n`Optimized`.\n\n  * Amazon ECS services in an account that are `Underprovisioned`,\n`Overprovisioned`, or `Optimized`.","ref":"AWS.ComputeOptimizer.html#get_recommendation_summaries/3","title":"AWS.ComputeOptimizer.get_recommendation_summaries/3","type":"function"},{"doc":"","ref":"AWS.ComputeOptimizer.html#metadata/0","title":"AWS.ComputeOptimizer.metadata/0","type":"function"},{"doc":"Creates a new recommendation preference or updates an existing recommendation\npreference, such as enhanced infrastructure metrics.\n\nFor more information, see [Activating enhanced infrastructure metrics](https://docs.aws.amazon.com/compute-optimizer/latest/ug/enhanced-infrastructure-metrics.html)\nin the *Compute Optimizer User Guide*.","ref":"AWS.ComputeOptimizer.html#put_recommendation_preferences/3","title":"AWS.ComputeOptimizer.put_recommendation_preferences/3","type":"function"},{"doc":"Updates the enrollment (opt in and opt out) status of an account to the Compute\nOptimizer service.\n\nIf the account is a management account of an organization, this action can also\nbe used to enroll member accounts of the organization.\n\nYou must have the appropriate permissions to opt in to Compute Optimizer, to\nview its recommendations, and to opt out. For more information, see [Controlling access with Amazon Web Services Identity and Access\nManagement](https://docs.aws.amazon.com/compute-optimizer/latest/ug/security-iam.html)\nin the *Compute Optimizer User Guide*.\n\nWhen you opt in, Compute Optimizer automatically creates a service-linked role\nin your account to access its data. For more information, see [Using Service-Linked Roles for Compute\nOptimizer](https://docs.aws.amazon.com/compute-optimizer/latest/ug/using-service-linked-roles.html)\nin the *Compute Optimizer User Guide*.","ref":"AWS.ComputeOptimizer.html#update_enrollment_status/3","title":"AWS.ComputeOptimizer.update_enrollment_status/3","type":"function"},{"doc":"Config\n\nConfig provides a way to keep track of the configurations of all the Amazon Web\nServices resources associated with your Amazon Web Services account.\n\nYou can use Config to get the current and historical configurations of each\nAmazon Web Services resource and also to get information about the relationship\nbetween the resources. An Amazon Web Services resource can be an Amazon Compute\nCloud (Amazon EC2) instance, an Elastic Block Store (EBS) volume, an elastic\nnetwork Interface (ENI), or a security group. For a complete list of resources\ncurrently supported by Config, see [Supported Amazon Web Services resources](https://docs.aws.amazon.com/config/latest/developerguide/resource-config-reference.html#supported-resources).\n\nYou can access and manage Config through the Amazon Web Services Management\nConsole, the Amazon Web Services Command Line Interface (Amazon Web Services\nCLI), the Config API, or the Amazon Web Services SDKs for Config. This reference\nguide contains documentation for the Config API and the Amazon Web Services CLI\ncommands that you can use to manage Config. The Config API uses the Signature\nVersion 4 protocol for signing requests. For more information about how to sign\na request with this protocol, see [Signature Version 4 Signing Process](https://docs.aws.amazon.com/general/latest/gr/signature-version-4.html).\nFor detailed information about Config features and their associated actions or\ncommands, as well as how to work with Amazon Web Services Management Console,\nsee [What Is Config](https://docs.aws.amazon.com/config/latest/developerguide/WhatIsConfig.html)\nin the *Config Developer Guide*.","ref":"AWS.Config.html","title":"AWS.Config","type":"module"},{"doc":"Returns the current configuration items for resources that are present in your\nConfig aggregator.\n\nThe operation also returns a list of resources that are not processed in the\ncurrent request. If there are no unprocessed resources, the operation returns an\nempty `unprocessedResourceIdentifiers` list.\n\n   The API does not return results for deleted resources.\n\n   The API does not return tags and relationships.","ref":"AWS.Config.html#batch_get_aggregate_resource_config/3","title":"AWS.Config.batch_get_aggregate_resource_config/3","type":"function"},{"doc":"Returns the `BaseConfigurationItem` for one or more requested resources.\n\nThe operation also returns a list of resources that are not processed in the\ncurrent request. If there are no unprocessed resources, the operation returns an\nempty unprocessedResourceKeys list.\n\n   The API does not return results for deleted resources.\n\n   The API does not return any tags for the requested resources. This\ninformation is filtered out of the supplementaryConfiguration section of the API\nresponse.","ref":"AWS.Config.html#batch_get_resource_config/3","title":"AWS.Config.batch_get_resource_config/3","type":"function"},{"doc":"Deletes the authorization granted to the specified configuration aggregator\naccount in a specified region.","ref":"AWS.Config.html#delete_aggregation_authorization/3","title":"AWS.Config.delete_aggregation_authorization/3","type":"function"},{"doc":"Deletes the specified Config rule and all of its evaluation results.\n\nConfig sets the state of a rule to `DELETING` until the deletion is complete.\nYou cannot update a rule while it is in this state. If you make a\n`PutConfigRule` or `DeleteConfigRule` request for the rule, you will receive a\n`ResourceInUseException`.\n\nYou can check the state of a rule by using the `DescribeConfigRules` request.","ref":"AWS.Config.html#delete_config_rule/3","title":"AWS.Config.delete_config_rule/3","type":"function"},{"doc":"Deletes the specified configuration aggregator and the aggregated data\nassociated with the aggregator.","ref":"AWS.Config.html#delete_configuration_aggregator/3","title":"AWS.Config.delete_configuration_aggregator/3","type":"function"},{"doc":"Deletes the configuration recorder.\n\nAfter the configuration recorder is deleted, Config will not record resource\nconfiguration changes until you create a new configuration recorder.\n\nThis action does not delete the configuration information that was previously\nrecorded. You will be able to access the previously recorded information by\nusing the `GetResourceConfigHistory` action, but you will not be able to access\nthis information in the Config console until you create a new configuration\nrecorder.","ref":"AWS.Config.html#delete_configuration_recorder/3","title":"AWS.Config.delete_configuration_recorder/3","type":"function"},{"doc":"Deletes the specified conformance pack and all the Config rules, remediation\nactions, and all evaluation results within that conformance pack.\n\nConfig sets the conformance pack to `DELETE_IN_PROGRESS` until the deletion is\ncomplete. You cannot update a conformance pack while it is in this state.","ref":"AWS.Config.html#delete_conformance_pack/3","title":"AWS.Config.delete_conformance_pack/3","type":"function"},{"doc":"Deletes the delivery channel.\n\nBefore you can delete the delivery channel, you must stop the configuration\nrecorder by using the `StopConfigurationRecorder` action.","ref":"AWS.Config.html#delete_delivery_channel/3","title":"AWS.Config.delete_delivery_channel/3","type":"function"},{"doc":"Deletes the evaluation results for the specified Config rule.\n\nYou can specify one Config rule per request. After you delete the evaluation\nresults, you can call the `StartConfigRulesEvaluation` API to start evaluating\nyour Amazon Web Services resources against the rule.","ref":"AWS.Config.html#delete_evaluation_results/3","title":"AWS.Config.delete_evaluation_results/3","type":"function"},{"doc":"Deletes the specified organization Config rule and all of its evaluation results\nfrom all member accounts in that organization.\n\nOnly a management account and a delegated administrator account can delete an\norganization Config rule. When calling this API with a delegated administrator,\nyou must ensure Organizations `ListDelegatedAdministrator` permissions are\nadded.\n\nConfig sets the state of a rule to DELETE_IN_PROGRESS until the deletion is\ncomplete. You cannot update a rule while it is in this state.","ref":"AWS.Config.html#delete_organization_config_rule/3","title":"AWS.Config.delete_organization_config_rule/3","type":"function"},{"doc":"Deletes the specified organization conformance pack and all of the Config rules\nand remediation actions from all member accounts in that organization.\n\nOnly a management account or a delegated administrator account can delete an\norganization conformance pack. When calling this API with a delegated\nadministrator, you must ensure Organizations `ListDelegatedAdministrator`\npermissions are added.\n\nConfig sets the state of a conformance pack to DELETE_IN_PROGRESS until the\ndeletion is complete. You cannot update a conformance pack while it is in this\nstate.","ref":"AWS.Config.html#delete_organization_conformance_pack/3","title":"AWS.Config.delete_organization_conformance_pack/3","type":"function"},{"doc":"Deletes pending authorization requests for a specified aggregator account in a\nspecified region.","ref":"AWS.Config.html#delete_pending_aggregation_request/3","title":"AWS.Config.delete_pending_aggregation_request/3","type":"function"},{"doc":"Deletes the remediation configuration.","ref":"AWS.Config.html#delete_remediation_configuration/3","title":"AWS.Config.delete_remediation_configuration/3","type":"function"},{"doc":"Deletes one or more remediation exceptions mentioned in the resource keys.\n\nConfig generates a remediation exception when a problem occurs executing a\nremediation action to a specific resource. Remediation exceptions blocks\nauto-remediation until the exception is cleared.","ref":"AWS.Config.html#delete_remediation_exceptions/3","title":"AWS.Config.delete_remediation_exceptions/3","type":"function"},{"doc":"Records the configuration state for a custom resource that has been deleted.\n\nThis API records a new ConfigurationItem with a ResourceDeleted status. You can\nretrieve the ConfigurationItems recorded for this resource in your Config\nHistory.","ref":"AWS.Config.html#delete_resource_config/3","title":"AWS.Config.delete_resource_config/3","type":"function"},{"doc":"Deletes the retention configuration.","ref":"AWS.Config.html#delete_retention_configuration/3","title":"AWS.Config.delete_retention_configuration/3","type":"function"},{"doc":"Deletes the stored query for a single Amazon Web Services account and a single\nAmazon Web Services Region.","ref":"AWS.Config.html#delete_stored_query/3","title":"AWS.Config.delete_stored_query/3","type":"function"},{"doc":"Schedules delivery of a configuration snapshot to the Amazon S3 bucket in the\nspecified delivery channel.\n\nAfter the delivery has started, Config sends the following notifications using\nan Amazon SNS topic that you have specified.\n\n  * Notification of the start of the delivery.\n\n  * Notification of the completion of the delivery, if the delivery\nwas successfully completed.\n\n  * Notification of delivery failure, if the delivery failed.","ref":"AWS.Config.html#deliver_config_snapshot/3","title":"AWS.Config.deliver_config_snapshot/3","type":"function"},{"doc":"Returns a list of compliant and noncompliant rules with the number of resources\nfor compliant and noncompliant rules.\n\nDoes not display rules that do not have compliance results.\n\nThe results can return an empty result page, but if you have a `nextToken`, the\nresults are displayed on the next page.","ref":"AWS.Config.html#describe_aggregate_compliance_by_config_rules/3","title":"AWS.Config.describe_aggregate_compliance_by_config_rules/3","type":"function"},{"doc":"Returns a list of the conformance packs and their associated compliance status\nwith the count of compliant and noncompliant Config rules within each\nconformance pack.\n\nAlso returns the total rule count which includes compliant rules, noncompliant\nrules, and rules that cannot be evaluated due to insufficient data.\n\nThe results can return an empty result page, but if you have a `nextToken`, the\nresults are displayed on the next page.","ref":"AWS.Config.html#describe_aggregate_compliance_by_conformance_packs/3","title":"AWS.Config.describe_aggregate_compliance_by_conformance_packs/3","type":"function"},{"doc":"Returns a list of authorizations granted to various aggregator accounts and\nregions.","ref":"AWS.Config.html#describe_aggregation_authorizations/3","title":"AWS.Config.describe_aggregation_authorizations/3","type":"function"},{"doc":"Indicates whether the specified Config rules are compliant.\n\nIf a rule is noncompliant, this action returns the number of Amazon Web Services\nresources that do not comply with the rule.\n\nA rule is compliant if all of the evaluated resources comply with it. It is\nnoncompliant if any of these resources do not comply.\n\nIf Config has no current evaluation results for the rule, it returns\n`INSUFFICIENT_DATA`. This result might indicate one of the following conditions:\n\n  * Config has never invoked an evaluation for the rule. To check\nwhether it has, use the `DescribeConfigRuleEvaluationStatus` action to get the\n`LastSuccessfulInvocationTime` and `LastFailedInvocationTime`.\n\n  * The rule's Lambda function is failing to send evaluation results\nto Config. Verify that the role you assigned to your configuration recorder\nincludes the `config:PutEvaluations` permission. If the rule is a custom rule,\nverify that the Lambda execution role includes the `config:PutEvaluations`\npermission.\n\n  * The rule's Lambda function has returned `NOT_APPLICABLE` for all\nevaluation results. This can occur if the resources were deleted or removed from\nthe rule's scope.","ref":"AWS.Config.html#describe_compliance_by_config_rule/3","title":"AWS.Config.describe_compliance_by_config_rule/3","type":"function"},{"doc":"Indicates whether the specified Amazon Web Services resources are compliant.\n\nIf a resource is noncompliant, this action returns the number of Config rules\nthat the resource does not comply with.\n\nA resource is compliant if it complies with all the Config rules that evaluate\nit. It is noncompliant if it does not comply with one or more of these rules.\n\nIf Config has no current evaluation results for the resource, it returns\n`INSUFFICIENT_DATA`. This result might indicate one of the following conditions\nabout the rules that evaluate the resource:\n\n  * Config has never invoked an evaluation for the rule. To check\nwhether it has, use the `DescribeConfigRuleEvaluationStatus` action to get the\n`LastSuccessfulInvocationTime` and `LastFailedInvocationTime`.\n\n  * The rule's Lambda function is failing to send evaluation results\nto Config. Verify that the role that you assigned to your configuration recorder\nincludes the `config:PutEvaluations` permission. If the rule is a custom rule,\nverify that the Lambda execution role includes the `config:PutEvaluations`\npermission.\n\n  * The rule's Lambda function has returned `NOT_APPLICABLE` for all\nevaluation results. This can occur if the resources were deleted or removed from\nthe rule's scope.","ref":"AWS.Config.html#describe_compliance_by_resource/3","title":"AWS.Config.describe_compliance_by_resource/3","type":"function"},{"doc":"Returns status information for each of your Config managed rules.\n\nThe status includes information such as the last time Config invoked the rule,\nthe last time Config failed to invoke the rule, and the related error for the\nlast failure.","ref":"AWS.Config.html#describe_config_rule_evaluation_status/3","title":"AWS.Config.describe_config_rule_evaluation_status/3","type":"function"},{"doc":"Returns details about your Config rules.","ref":"AWS.Config.html#describe_config_rules/3","title":"AWS.Config.describe_config_rules/3","type":"function"},{"doc":"Returns status information for sources within an aggregator.\n\nThe status includes information about the last time Config verified\nauthorization between the source account and an aggregator account. In case of a\nfailure, the status contains the related error code or message.","ref":"AWS.Config.html#describe_configuration_aggregator_sources_status/3","title":"AWS.Config.describe_configuration_aggregator_sources_status/3","type":"function"},{"doc":"Returns the details of one or more configuration aggregators.\n\nIf the configuration aggregator is not specified, this action returns the\ndetails for all the configuration aggregators associated with the account.","ref":"AWS.Config.html#describe_configuration_aggregators/3","title":"AWS.Config.describe_configuration_aggregators/3","type":"function"},{"doc":"Returns the current status of the specified configuration recorder as well as\nthe status of the last recording event for the recorder.\n\nIf a configuration recorder is not specified, this action returns the status of\nall configuration recorders associated with the account.\n\n>You can specify only one configuration recorder for each Amazon Web Services\nRegion for each account. For a detailed status of recording events over time,\nadd your Config events to Amazon CloudWatch metrics and use CloudWatch metrics.","ref":"AWS.Config.html#describe_configuration_recorder_status/3","title":"AWS.Config.describe_configuration_recorder_status/3","type":"function"},{"doc":"Returns the details for the specified configuration recorders.\n\nIf the configuration recorder is not specified, this action returns the details\nfor all configuration recorders associated with the account.\n\nYou can specify only one configuration recorder for each Amazon Web Services\nRegion for each account.","ref":"AWS.Config.html#describe_configuration_recorders/3","title":"AWS.Config.describe_configuration_recorders/3","type":"function"},{"doc":"Returns compliance details for each rule in that conformance pack.\n\nYou must provide exact rule names.","ref":"AWS.Config.html#describe_conformance_pack_compliance/3","title":"AWS.Config.describe_conformance_pack_compliance/3","type":"function"},{"doc":"Provides one or more conformance packs deployment status.\n\nIf there are no conformance packs then you will see an empty result.","ref":"AWS.Config.html#describe_conformance_pack_status/3","title":"AWS.Config.describe_conformance_pack_status/3","type":"function"},{"doc":"Returns a list of one or more conformance packs.","ref":"AWS.Config.html#describe_conformance_packs/3","title":"AWS.Config.describe_conformance_packs/3","type":"function"},{"doc":"Returns the current status of the specified delivery channel.\n\nIf a delivery channel is not specified, this action returns the current status\nof all delivery channels associated with the account.\n\nCurrently, you can specify only one delivery channel per region in your account.","ref":"AWS.Config.html#describe_delivery_channel_status/3","title":"AWS.Config.describe_delivery_channel_status/3","type":"function"},{"doc":"Returns details about the specified delivery channel.\n\nIf a delivery channel is not specified, this action returns the details of all\ndelivery channels associated with the account.\n\nCurrently, you can specify only one delivery channel per region in your account.","ref":"AWS.Config.html#describe_delivery_channels/3","title":"AWS.Config.describe_delivery_channels/3","type":"function"},{"doc":"Provides organization Config rule deployment status for an organization.\n\nThe status is not considered successful until organization Config rule is\nsuccessfully deployed in all the member accounts with an exception of excluded\naccounts.\n\nWhen you specify the limit and the next token, you receive a paginated response.\nLimit and next token are not applicable if you specify organization Config rule\nnames. It is only applicable, when you request all the organization Config\nrules.","ref":"AWS.Config.html#describe_organization_config_rule_statuses/3","title":"AWS.Config.describe_organization_config_rule_statuses/3","type":"function"},{"doc":"Returns a list of organization Config rules.\n\nWhen you specify the limit and the next token, you receive a paginated response.\n\nLimit and next token are not applicable if you specify organization Config rule\nnames. It is only applicable, when you request all the organization Config\nrules.\n\n*For accounts within an organzation*\n\nIf you deploy an organizational rule or conformance pack in an organization\nadministrator account, and then establish a delegated administrator and deploy\nan organizational rule or conformance pack in the delegated administrator\naccount, you won't be able to see the organizational rule or conformance pack in\nthe organization administrator account from the delegated administrator account\nor see the organizational rule or conformance pack in the delegated\nadministrator account from organization administrator account. The\n`DescribeOrganizationConfigRules` and `DescribeOrganizationConformancePacks`\nAPIs can only see and interact with the organization-related resource that were\ndeployed from within the account calling those APIs.","ref":"AWS.Config.html#describe_organization_config_rules/3","title":"AWS.Config.describe_organization_config_rules/3","type":"function"},{"doc":"Provides organization conformance pack deployment status for an organization.\n\nThe status is not considered successful until organization conformance pack is\nsuccessfully deployed in all the member accounts with an exception of excluded\naccounts.\n\nWhen you specify the limit and the next token, you receive a paginated response.\nLimit and next token are not applicable if you specify organization conformance\npack names. They are only applicable, when you request all the organization\nconformance packs.","ref":"AWS.Config.html#describe_organization_conformance_pack_statuses/3","title":"AWS.Config.describe_organization_conformance_pack_statuses/3","type":"function"},{"doc":"Returns a list of organization conformance packs.\n\nWhen you specify the limit and the next token, you receive a paginated response.\n\nLimit and next token are not applicable if you specify organization conformance\npacks names. They are only applicable, when you request all the organization\nconformance packs.\n\n*For accounts within an organzation*\n\nIf you deploy an organizational rule or conformance pack in an organization\nadministrator account, and then establish a delegated administrator and deploy\nan organizational rule or conformance pack in the delegated administrator\naccount, you won't be able to see the organizational rule or conformance pack in\nthe organization administrator account from the delegated administrator account\nor see the organizational rule or conformance pack in the delegated\nadministrator account from organization administrator account. The\n`DescribeOrganizationConfigRules` and `DescribeOrganizationConformancePacks`\nAPIs can only see and interact with the organization-related resource that were\ndeployed from within the account calling those APIs.","ref":"AWS.Config.html#describe_organization_conformance_packs/3","title":"AWS.Config.describe_organization_conformance_packs/3","type":"function"},{"doc":"Returns a list of all pending aggregation requests.","ref":"AWS.Config.html#describe_pending_aggregation_requests/3","title":"AWS.Config.describe_pending_aggregation_requests/3","type":"function"},{"doc":"Returns the details of one or more remediation configurations.","ref":"AWS.Config.html#describe_remediation_configurations/3","title":"AWS.Config.describe_remediation_configurations/3","type":"function"},{"doc":"Returns the details of one or more remediation exceptions.\n\nA detailed view of a remediation exception for a set of resources that includes\nan explanation of an exception and the time when the exception will be deleted.\nWhen you specify the limit and the next token, you receive a paginated response.\n\nConfig generates a remediation exception when a problem occurs executing a\nremediation action to a specific resource. Remediation exceptions blocks\nauto-remediation until the exception is cleared.\n\nWhen you specify the limit and the next token, you receive a paginated response.\n\nLimit and next token are not applicable if you request resources in batch. It is\nonly applicable, when you request all resources.","ref":"AWS.Config.html#describe_remediation_exceptions/3","title":"AWS.Config.describe_remediation_exceptions/3","type":"function"},{"doc":"Provides a detailed view of a Remediation Execution for a set of resources\nincluding state, timestamps for when steps for the remediation execution occur,\nand any error messages for steps that have failed.\n\nWhen you specify the limit and the next token, you receive a paginated response.","ref":"AWS.Config.html#describe_remediation_execution_status/3","title":"AWS.Config.describe_remediation_execution_status/3","type":"function"},{"doc":"Returns the details of one or more retention configurations.\n\nIf the retention configuration name is not specified, this action returns the\ndetails for all the retention configurations for that account.\n\nCurrently, Config supports only one retention configuration per region in your\naccount.","ref":"AWS.Config.html#describe_retention_configurations/3","title":"AWS.Config.describe_retention_configurations/3","type":"function"},{"doc":"Returns the evaluation results for the specified Config rule for a specific\nresource in a rule.\n\nThe results indicate which Amazon Web Services resources were evaluated by the\nrule, when each resource was last evaluated, and whether each resource complies\nwith the rule.\n\nThe results can return an empty result page. But if you have a `nextToken`, the\nresults are displayed on the next page.","ref":"AWS.Config.html#get_aggregate_compliance_details_by_config_rule/3","title":"AWS.Config.get_aggregate_compliance_details_by_config_rule/3","type":"function"},{"doc":"Returns the number of compliant and noncompliant rules for one or more accounts\nand regions in an aggregator.\n\nThe results can return an empty result page, but if you have a nextToken, the\nresults are displayed on the next page.","ref":"AWS.Config.html#get_aggregate_config_rule_compliance_summary/3","title":"AWS.Config.get_aggregate_config_rule_compliance_summary/3","type":"function"},{"doc":"Returns the count of compliant and noncompliant conformance packs across all\nAmazon Web Services accounts and Amazon Web Services Regions in an aggregator.\n\nYou can filter based on Amazon Web Services account ID or Amazon Web Services\nRegion.\n\nThe results can return an empty result page, but if you have a nextToken, the\nresults are displayed on the next page.","ref":"AWS.Config.html#get_aggregate_conformance_pack_compliance_summary/3","title":"AWS.Config.get_aggregate_conformance_pack_compliance_summary/3","type":"function"},{"doc":"Returns the resource counts across accounts and regions that are present in your\nConfig aggregator.\n\nYou can request the resource counts by providing filters and GroupByKey.\n\nFor example, if the input contains accountID 12345678910 and region us-east-1 in\nfilters, the API returns the count of resources in account ID 12345678910 and\nregion us-east-1. If the input contains ACCOUNT_ID as a GroupByKey, the API\nreturns resource counts for all source accounts that are present in your\naggregator.","ref":"AWS.Config.html#get_aggregate_discovered_resource_counts/3","title":"AWS.Config.get_aggregate_discovered_resource_counts/3","type":"function"},{"doc":"Returns configuration item that is aggregated for your specific resource in a\nspecific source account and region.","ref":"AWS.Config.html#get_aggregate_resource_config/3","title":"AWS.Config.get_aggregate_resource_config/3","type":"function"},{"doc":"Returns the evaluation results for the specified Config rule.\n\nThe results indicate which Amazon Web Services resources were evaluated by the\nrule, when each resource was last evaluated, and whether each resource complies\nwith the rule.","ref":"AWS.Config.html#get_compliance_details_by_config_rule/3","title":"AWS.Config.get_compliance_details_by_config_rule/3","type":"function"},{"doc":"Returns the evaluation results for the specified Amazon Web Services resource.\n\nThe results indicate which Config rules were used to evaluate the resource, when\neach rule was last invoked, and whether the resource complies with each rule.","ref":"AWS.Config.html#get_compliance_details_by_resource/3","title":"AWS.Config.get_compliance_details_by_resource/3","type":"function"},{"doc":"Returns the number of Config rules that are compliant and noncompliant, up to a\nmaximum of 25 for each.","ref":"AWS.Config.html#get_compliance_summary_by_config_rule/3","title":"AWS.Config.get_compliance_summary_by_config_rule/3","type":"function"},{"doc":"Returns the number of resources that are compliant and the number that are\nnoncompliant.\n\nYou can specify one or more resource types to get these numbers for each\nresource type. The maximum number returned is 100.","ref":"AWS.Config.html#get_compliance_summary_by_resource_type/3","title":"AWS.Config.get_compliance_summary_by_resource_type/3","type":"function"},{"doc":"Returns compliance details of a conformance pack for all Amazon Web Services\nresources that are monitered by conformance pack.","ref":"AWS.Config.html#get_conformance_pack_compliance_details/3","title":"AWS.Config.get_conformance_pack_compliance_details/3","type":"function"},{"doc":"Returns compliance details for the conformance pack based on the cumulative\ncompliance results of all the rules in that conformance pack.","ref":"AWS.Config.html#get_conformance_pack_compliance_summary/3","title":"AWS.Config.get_conformance_pack_compliance_summary/3","type":"function"},{"doc":"Returns the policy definition containing the logic for your Config Custom Policy\nrule.","ref":"AWS.Config.html#get_custom_rule_policy/3","title":"AWS.Config.get_custom_rule_policy/3","type":"function"},{"doc":"Returns the resource types, the number of each resource type, and the total\nnumber of resources that Config is recording in this region for your Amazon Web\nServices account.","ref":"AWS.Config.html#get_discovered_resource_counts/3","title":"AWS.Config.get_discovered_resource_counts/3","type":"function"},{"doc":"1. Config is recording three resource types in the US East (Ohio)\nRegion for your account: 25 EC2 instances, 20 IAM users, and 15 S3 buckets.\n\n  2. You make a call to the `GetDiscoveredResourceCounts` action and\nspecify that you want all resource types.\n\n  3. Config returns the following:\n\n    * The resource types (EC2 instances, IAM users, and S3\nbuckets).\n\n    * The number of each resource type (25, 20, and 15).\n\n    * The total number of all resources (60).\n\nThe response is paginated. By default, Config lists 100 `ResourceCount` objects\non each page. You can customize this number with the `limit` parameter. The\nresponse includes a `nextToken` string. To get the next page of results, run the\nrequest again and specify the string for the `nextToken` parameter.\n\nIf you make a call to the `GetDiscoveredResourceCounts` action, you might not\nimmediately receive resource counts in the following situations:\n\n   You are a new Config customer.\n\n   You just enabled resource recording.\n\nIt might take a few minutes for Config to record and count your resources. Wait\na few minutes and then retry the `GetDiscoveredResourceCounts` action.","ref":"AWS.Config.html#get_discovered_resource_counts/3-example","title":"Example - AWS.Config.get_discovered_resource_counts/3","type":"function"},{"doc":"Returns detailed status for each member account within an organization for a\ngiven organization Config rule.","ref":"AWS.Config.html#get_organization_config_rule_detailed_status/3","title":"AWS.Config.get_organization_config_rule_detailed_status/3","type":"function"},{"doc":"Returns detailed status for each member account within an organization for a\ngiven organization conformance pack.","ref":"AWS.Config.html#get_organization_conformance_pack_detailed_status/3","title":"AWS.Config.get_organization_conformance_pack_detailed_status/3","type":"function"},{"doc":"Returns the policy definition containing the logic for your organization Config\nCustom Policy rule.","ref":"AWS.Config.html#get_organization_custom_rule_policy/3","title":"AWS.Config.get_organization_custom_rule_policy/3","type":"function"},{"doc":"For accurate reporting on the compliance status, you must record the\n`AWS::Config::ResourceCompliance` resource type.\n\nFor more information, see [Selecting Which Resources Config Records](https://docs.aws.amazon.com/config/latest/developerguide/select-resources.html).\n\nReturns a list of `ConfigurationItems` for the specified resource. The list\ncontains details about each state of the resource during the specified time\ninterval. If you specified a retention period to retain your\n`ConfigurationItems` between a minimum of 30 days and a maximum of 7 years (2557\ndays), Config returns the `ConfigurationItems` for the specified retention\nperiod.\n\nThe response is paginated. By default, Config returns a limit of 10\nconfiguration items per page. You can customize this number with the `limit`\nparameter. The response includes a `nextToken` string. To get the next page of\nresults, run the request again and specify the string for the `nextToken`\nparameter.\n\nEach call to the API is limited to span a duration of seven days. It is likely\nthat the number of records returned is smaller than the specified `limit`. In\nsuch cases, you can make another call, using the `nextToken`.","ref":"AWS.Config.html#get_resource_config_history/3","title":"AWS.Config.get_resource_config_history/3","type":"function"},{"doc":"Returns a summary of resource evaluation for the specified resource evaluation\nID from the proactive rules that were run.\n\nThe results indicate which evaluation context was used to evaluate the rules,\nwhich resource details were evaluated, the evaluation mode that was run, and\nwhether the resource details comply with the configuration of the proactive\nrules.\n\nTo see additional information about the evaluation result, such as which rule\nflagged a resource as NON_COMPLIANT, use the\n[GetComplianceDetailsByResource](https://docs.aws.amazon.com/config/latest/APIReference/API_GetComplianceDetailsByResource.html) API. For more information, see the\n[Examples](https://docs.aws.amazon.com/config/latest/APIReference/API_GetResourceEvaluationSummary.html#API_GetResourceEvaluationSummary_Examples)\nsection.","ref":"AWS.Config.html#get_resource_evaluation_summary/3","title":"AWS.Config.get_resource_evaluation_summary/3","type":"function"},{"doc":"Returns the details of a specific stored query.","ref":"AWS.Config.html#get_stored_query/3","title":"AWS.Config.get_stored_query/3","type":"function"},{"doc":"Accepts a resource type and returns a list of resource identifiers that are\naggregated for a specific resource type across accounts and regions.\n\nA resource identifier includes the resource type, ID, (if available) the custom\nresource name, source account, and source region. You can narrow the results to\ninclude only resources that have specific resource IDs, or a resource name, or\nsource account ID, or source region.\n\nFor example, if the input consists of accountID 12345678910 and the region is\nus-east-1 for resource type `AWS::EC2::Instance` then the API returns all the\nEC2 instance identifiers of accountID 12345678910 and region us-east-1.","ref":"AWS.Config.html#list_aggregate_discovered_resources/3","title":"AWS.Config.list_aggregate_discovered_resources/3","type":"function"},{"doc":"Returns a list of conformance pack compliance scores.\n\nA compliance score is the percentage of the number of compliant rule-resource\ncombinations in a conformance pack compared to the number of total possible\nrule-resource combinations in the conformance pack. This metric provides you\nwith a high-level view of the compliance state of your conformance packs. You\ncan use it to identify, investigate, and understand the level of compliance in\nyour conformance packs.\n\nConformance packs with no evaluation results will have a compliance score of\n`INSUFFICIENT_DATA`.","ref":"AWS.Config.html#list_conformance_pack_compliance_scores/3","title":"AWS.Config.list_conformance_pack_compliance_scores/3","type":"function"},{"doc":"Accepts a resource type and returns a list of resource identifiers for the\nresources of that type.\n\nA resource identifier includes the resource type, ID, and (if available) the\ncustom resource name. The results consist of resources that Config has\ndiscovered, including those that Config is not currently recording. You can\nnarrow the results to include only resources that have specific resource IDs or\na resource name.\n\nYou can specify either resource IDs or a resource name, but not both, in the\nsame request.\n\nThe response is paginated. By default, Config lists 100 resource identifiers on\neach page. You can customize this number with the `limit` parameter. The\nresponse includes a `nextToken` string. To get the next page of results, run the\nrequest again and specify the string for the `nextToken` parameter.","ref":"AWS.Config.html#list_discovered_resources/3","title":"AWS.Config.list_discovered_resources/3","type":"function"},{"doc":"Returns a list of proactive resource evaluations.","ref":"AWS.Config.html#list_resource_evaluations/3","title":"AWS.Config.list_resource_evaluations/3","type":"function"},{"doc":"Lists the stored queries for a single Amazon Web Services account and a single\nAmazon Web Services Region.\n\nThe default is 100.","ref":"AWS.Config.html#list_stored_queries/3","title":"AWS.Config.list_stored_queries/3","type":"function"},{"doc":"List the tags for Config resource.","ref":"AWS.Config.html#list_tags_for_resource/3","title":"AWS.Config.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.Config.html#metadata/0","title":"AWS.Config.metadata/0","type":"function"},{"doc":"Authorizes the aggregator account and region to collect data from the source\naccount and region.\n\n`PutAggregationAuthorization` is an idempotent API. Subsequent requests won’t\ncreate a duplicate resource if one was already created. If a following request\nhas different `tags` values, Config will ignore these differences and treat it\nas an idempotent request of the previous. In this case, `tags` will not be\nupdated, even if they are different.","ref":"AWS.Config.html#put_aggregation_authorization/3","title":"AWS.Config.put_aggregation_authorization/3","type":"function"},{"doc":"Adds or updates an Config rule to evaluate if your Amazon Web Services resources\ncomply with your desired configurations.\n\nFor information on how many Config rules you can have per account, see [","ref":"AWS.Config.html#put_config_rule/3","title":"AWS.Config.put_config_rule/3","type":"function"},{"doc":"](https://docs.aws.amazon.com/config/latest/developerguide/configlimits.html) in\nthe *Config Developer Guide*.\n\nThere are two types of rules: *Config Managed Rules* and *Config Custom Rules*.\nYou can use `PutConfigRule` to create both Config Managed Rules and Config\nCustom Rules.\n\nConfig Managed Rules are predefined, customizable rules created by Config. For a\nlist of managed rules, see [List of Config Managed Rules](https://docs.aws.amazon.com/config/latest/developerguide/managed-rules-by-aws-config.html).\nIf you are adding an Config managed rule, you must specify the rule's identifier\nfor the `SourceIdentifier` key.\n\nConfig Custom Rules are rules that you create from scratch. There are two ways\nto create Config custom rules: with Lambda functions ([ Lambda Developer Guide](https://docs.aws.amazon.com/config/latest/developerguide/gettingstarted-concepts.html#gettingstarted-concepts-function))\nand with Guard ([Guard GitHub Repository](https://github.com/aws-cloudformation/cloudformation-guard)), a\npolicy-as-code language. Config custom rules created with Lambda are called\n*Config Custom Lambda Rules* and Config custom rules created with Guard are\ncalled *Config Custom Policy Rules*.\n\nIf you are adding a new Config Custom Lambda rule, you first need to create an\nLambda function that the rule invokes to evaluate your resources. When you use\n`PutConfigRule` to add a Custom Lambda rule to Config, you must specify the\nAmazon Resource Name (ARN) that Lambda assigns to the function. You specify the\nARN in the `SourceIdentifier` key. This key is part of the `Source` object,\nwhich is part of the `ConfigRule` object.\n\nFor any new Config rule that you add, specify the `ConfigRuleName` in the\n`ConfigRule` object. Do not specify the `ConfigRuleArn` or the `ConfigRuleId`.\nThese values are generated by Config for new rules.\n\nIf you are updating a rule that you added previously, you can specify the rule\nby `ConfigRuleName`, `ConfigRuleId`, or `ConfigRuleArn` in the `ConfigRule` data\ntype that you use in this request.\n\nFor more information about developing and using Config rules, see [Evaluating Resources with Config\nRules](https://docs.aws.amazon.com/config/latest/developerguide/evaluate-config.html)\nin the *Config Developer Guide*.\n\n`PutConfigRule` is an idempotent API. Subsequent requests won’t create a\nduplicate resource if one was already created. If a following request has\ndifferent `tags` values, Config will ignore these differences and treat it as an\nidempotent request of the previous. In this case, `tags` will not be updated,\neven if they are different.","ref":"AWS.Config.html#put_config_rule/3-service-limits","title":"Service Limits - AWS.Config.put_config_rule/3","type":"function"},{"doc":"Creates and updates the configuration aggregator with the selected source\naccounts and regions.\n\nThe source account can be individual account(s) or an organization.\n\n`accountIds` that are passed will be replaced with existing accounts. If you\nwant to add additional accounts into the aggregator, call\n`DescribeConfigurationAggregators` to get the previous accounts and then append\nnew ones.\n\nConfig should be enabled in source accounts and regions you want to aggregate.\n\nIf your source type is an organization, you must be signed in to the management\naccount or a registered delegated administrator and all the features must be\nenabled in your organization. If the caller is a management account, Config\ncalls `EnableAwsServiceAccess` API to enable integration between Config and\nOrganizations. If the caller is a registered delegated administrator, Config\ncalls `ListDelegatedAdministrators` API to verify whether the caller is a valid\ndelegated administrator.\n\nTo register a delegated administrator, see [Register a Delegated Administrator](https://docs.aws.amazon.com/config/latest/developerguide/set-up-aggregator-cli.html#register-a-delegated-administrator-cli)\nin the *Config developer guide*.\n\n`PutConfigurationAggregator` is an idempotent API. Subsequent requests won’t\ncreate a duplicate resource if one was already created. If a following request\nhas different `tags` values, Config will ignore these differences and treat it\nas an idempotent request of the previous. In this case, `tags` will not be\nupdated, even if they are different.","ref":"AWS.Config.html#put_configuration_aggregator/3","title":"AWS.Config.put_configuration_aggregator/3","type":"function"},{"doc":"Creates a new configuration recorder to record configuration changes for\nspecified resource types.\n\nYou can also use this action to change the `roleARN` or the `recordingGroup` of\nan existing recorder. For more information, see [","ref":"AWS.Config.html#put_configuration_recorder/3","title":"AWS.Config.put_configuration_recorder/3","type":"function"},{"doc":"](https://docs.aws.amazon.com/config/latest/developerguide/stop-start-recorder.html)\nin the *Config Developer Guide*.\n\nYou can specify only one configuration recorder for each Amazon Web Services\nRegion for each account.\n\nIf the configuration recorder does not have the `recordingGroup` field\nspecified, the default is to record all supported resource types.","ref":"AWS.Config.html#put_configuration_recorder/3-managing-the-configuration-recorder","title":"Managing the Configuration Recorder - AWS.Config.put_configuration_recorder/3","type":"function"},{"doc":"Creates or updates a conformance pack.\n\nA conformance pack is a collection of Config rules that can be easily deployed\nin an account and a region and across an organization. For information on how\nmany conformance packs you can have per account, see [","ref":"AWS.Config.html#put_conformance_pack/3","title":"AWS.Config.put_conformance_pack/3","type":"function"},{"doc":"](https://docs.aws.amazon.com/config/latest/developerguide/configlimits.html) in\nthe *Config Developer Guide*.\n\nThis API creates a service-linked role `AWSServiceRoleForConfigConforms` in your\naccount. The service-linked role is created only when the role does not exist in\nyour account.\n\nYou must specify only one of the follow parameters: `TemplateS3Uri`,\n`TemplateBody` or `TemplateSSMDocumentDetails`.","ref":"AWS.Config.html#put_conformance_pack/3-service-limits","title":"Service Limits - AWS.Config.put_conformance_pack/3","type":"function"},{"doc":"Creates a delivery channel object to deliver configuration information and other\ncompliance information to an Amazon S3 bucket and Amazon SNS topic.\n\nFor more information, see [Notifications that Config Sends to an Amazon SNS topic](https://docs.aws.amazon.com/config/latest/developerguide/notifications-for-AWS-Config.html).\n\nBefore you can create a delivery channel, you must create a configuration\nrecorder.\n\nYou can use this action to change the Amazon S3 bucket or an Amazon SNS topic of\nthe existing delivery channel. To change the Amazon S3 bucket or an Amazon SNS\ntopic, call this action and specify the changed values for the S3 bucket and the\nSNS topic. If you specify a different value for either the S3 bucket or the SNS\ntopic, this action will keep the existing value for the parameter that is not\nchanged.\n\nYou can have only one delivery channel per region in your account.","ref":"AWS.Config.html#put_delivery_channel/3","title":"AWS.Config.put_delivery_channel/3","type":"function"},{"doc":"Used by an Lambda function to deliver evaluation results to Config.\n\nThis action is required in every Lambda function that is invoked by an Config\nrule.","ref":"AWS.Config.html#put_evaluations/3","title":"AWS.Config.put_evaluations/3","type":"function"},{"doc":"Add or updates the evaluations for process checks.\n\nThis API checks if the rule is a process check when the name of the Config rule\nis provided.","ref":"AWS.Config.html#put_external_evaluation/3","title":"AWS.Config.put_external_evaluation/3","type":"function"},{"doc":"Adds or updates an Config rule for your entire organization to evaluate if your\nAmazon Web Services resources comply with your desired configurations.\n\nFor information on how many organization Config rules you can have per account,\nsee [","ref":"AWS.Config.html#put_organization_config_rule/3","title":"AWS.Config.put_organization_config_rule/3","type":"function"},{"doc":"](https://docs.aws.amazon.com/config/latest/developerguide/configlimits.html) in\nthe *Config Developer Guide*.\n\nOnly a management account and a delegated administrator can create or update an\norganization Config rule. When calling this API with a delegated administrator,\nyou must ensure Organizations `ListDelegatedAdministrator` permissions are\nadded. An organization can have up to 3 delegated administrators.\n\nThis API enables organization service access through the\n`EnableAWSServiceAccess` action and creates a service-linked role\n`AWSServiceRoleForConfigMultiAccountSetup` in the management or delegated\nadministrator account of your organization. The service-linked role is created\nonly when the role does not exist in the caller account. Config verifies the\nexistence of role with `GetRole` action.\n\nTo use this API with delegated administrator, register a delegated administrator\nby calling Amazon Web Services Organization `register-delegated-administrator`\nfor `config-multiaccountsetup.amazonaws.com`.\n\nThere are two types of rules: *Config Managed Rules* and *Config Custom Rules*.\nYou can use `PutOrganizationConfigRule` to create both Config Managed Rules and\nConfig Custom Rules.\n\nConfig Managed Rules are predefined, customizable rules created by Config. For a\nlist of managed rules, see [List of Config Managed Rules](https://docs.aws.amazon.com/config/latest/developerguide/managed-rules-by-aws-config.html).\nIf you are adding an Config managed rule, you must specify the rule's identifier\nfor the `RuleIdentifier` key.\n\nConfig Custom Rules are rules that you create from scratch. There are two ways\nto create Config custom rules: with Lambda functions ([ Lambda Developer Guide](https://docs.aws.amazon.com/config/latest/developerguide/gettingstarted-concepts.html#gettingstarted-concepts-function))\nand with Guard ([Guard GitHub Repository](https://github.com/aws-cloudformation/cloudformation-guard)), a\npolicy-as-code language. Config custom rules created with Lambda are called\n*Config Custom Lambda Rules* and Config custom rules created with Guard are\ncalled *Config Custom Policy Rules*.\n\nIf you are adding a new Config Custom Lambda rule, you first need to create an\nLambda function in the management account or a delegated administrator that the\nrule invokes to evaluate your resources. You also need to create an IAM role in\nthe managed account that can be assumed by the Lambda function. When you use\n`PutOrganizationConfigRule` to add a Custom Lambda rule to Config, you must\nspecify the Amazon Resource Name (ARN) that Lambda assigns to the function.\n\nPrerequisite: Ensure you call `EnableAllFeatures` API to enable all features in\nan organization.\n\nMake sure to specify one of either `OrganizationCustomPolicyRuleMetadata` for\nCustom Policy rules, `OrganizationCustomRuleMetadata` for Custom Lambda rules,\nor `OrganizationManagedRuleMetadata` for managed rules.","ref":"AWS.Config.html#put_organization_config_rule/3-service-limits","title":"Service Limits - AWS.Config.put_organization_config_rule/3","type":"function"},{"doc":"Deploys conformance packs across member accounts in an Amazon Web Services\nOrganization.\n\nFor information on how many organization conformance packs and how many Config\nrules you can have per account, see [","ref":"AWS.Config.html#put_organization_conformance_pack/3","title":"AWS.Config.put_organization_conformance_pack/3","type":"function"},{"doc":"](https://docs.aws.amazon.com/config/latest/developerguide/configlimits.html) in\nthe *Config Developer Guide*.\n\nOnly a management account and a delegated administrator can call this API. When\ncalling this API with a delegated administrator, you must ensure Organizations\n`ListDelegatedAdministrator` permissions are added. An organization can have up\nto 3 delegated administrators.\n\nThis API enables organization service access for\n`config-multiaccountsetup.amazonaws.com` through the `EnableAWSServiceAccess`\naction and creates a service-linked role\n`AWSServiceRoleForConfigMultiAccountSetup` in the management or delegated\nadministrator account of your organization. The service-linked role is created\nonly when the role does not exist in the caller account. To use this API with\ndelegated administrator, register a delegated administrator by calling Amazon\nWeb Services Organization `register-delegate-admin` for\n`config-multiaccountsetup.amazonaws.com`.\n\nPrerequisite: Ensure you call `EnableAllFeatures` API to enable all features in\nan organization.\n\nYou must specify either the `TemplateS3Uri` or the `TemplateBody` parameter, but\nnot both. If you provide both Config uses the `TemplateS3Uri` parameter and\nignores the `TemplateBody` parameter.\n\nConfig sets the state of a conformance pack to CREATE_IN_PROGRESS and\nUPDATE_IN_PROGRESS until the conformance pack is created or updated. You cannot\nupdate a conformance pack while it is in this state.","ref":"AWS.Config.html#put_organization_conformance_pack/3-service-limits","title":"Service Limits - AWS.Config.put_organization_conformance_pack/3","type":"function"},{"doc":"Adds or updates the remediation configuration with a specific Config rule with\nthe selected target or action.\n\nThe API creates the `RemediationConfiguration` object for the Config rule. The\nConfig rule must already exist for you to add a remediation configuration. The\ntarget (SSM document) must exist and have permissions to use the target.\n\nIf you make backward incompatible changes to the SSM document, you must call\nthis again to ensure the remediations can run.\n\nThis API does not support adding remediation configurations for service-linked\nConfig Rules such as Organization Config rules, the rules deployed by\nconformance packs, and rules deployed by Amazon Web Services Security Hub.\n\nFor manual remediation configuration, you need to provide a value for\n`automationAssumeRole` or use a value in the `assumeRole`field to remediate your\nresources. The SSM automation document can use either as long as it maps to a\nvalid parameter.\n\nHowever, for automatic remediation configuration, the only valid `assumeRole`\nfield value is `AutomationAssumeRole` and you need to provide a value for\n`AutomationAssumeRole` to remediate your resources.","ref":"AWS.Config.html#put_remediation_configurations/3","title":"AWS.Config.put_remediation_configurations/3","type":"function"},{"doc":"A remediation exception is when a specified resource is no longer considered for\nauto-remediation.\n\nThis API adds a new exception or updates an existing exception for a specified\nresource with a specified Config rule.\n\nConfig generates a remediation exception when a problem occurs running a\nremediation action for a specified resource. Remediation exceptions blocks\nauto-remediation until the exception is cleared.\n\nWhen placing an exception on an Amazon Web Services resource, it is recommended\nthat remediation is set as manual remediation until the given Config rule for\nthe specified resource evaluates the resource as `NON_COMPLIANT`. Once the\nresource has been evaluated as `NON_COMPLIANT`, you can add remediation\nexceptions and change the remediation type back from Manual to Auto if you want\nto use auto-remediation. Otherwise, using auto-remediation before a\n`NON_COMPLIANT` evaluation result can delete resources before the exception is\napplied.\n\nPlacing an exception can only be performed on resources that are\n`NON_COMPLIANT`. If you use this API for `COMPLIANT` resources or resources that\nare `NOT_APPLICABLE`, a remediation exception will not be generated. For more\ninformation on the conditions that initiate the possible Config evaluation\nresults, see [Concepts | Config Rules](https://docs.aws.amazon.com/config/latest/developerguide/config-concepts.html#aws-config-rules)\nin the *Config Developer Guide*.","ref":"AWS.Config.html#put_remediation_exceptions/3","title":"AWS.Config.put_remediation_exceptions/3","type":"function"},{"doc":"Records the configuration state for the resource provided in the request.\n\nThe configuration state of a resource is represented in Config as Configuration\nItems. Once this API records the configuration item, you can retrieve the list\nof configuration items for the custom resource type using existing Config APIs.\n\nThe custom resource type must be registered with CloudFormation. This API\naccepts the configuration item registered with CloudFormation.\n\nWhen you call this API, Config only stores configuration state of the resource\nprovided in the request. This API does not change or remediate the configuration\nof the resource.\n\nWrite-only schema properites are not recorded as part of the published\nconfiguration item.","ref":"AWS.Config.html#put_resource_config/3","title":"AWS.Config.put_resource_config/3","type":"function"},{"doc":"Creates and updates the retention configuration with details about retention\nperiod (number of days) that Config stores your historical information.\n\nThe API creates the `RetentionConfiguration` object and names the object as\n**default**. When you have a `RetentionConfiguration` object named **default**,\ncalling the API modifies the default object.\n\nCurrently, Config supports only one retention configuration per region in your\naccount.","ref":"AWS.Config.html#put_retention_configuration/3","title":"AWS.Config.put_retention_configuration/3","type":"function"},{"doc":"Saves a new query or updates an existing saved query.\n\nThe `QueryName` must be unique for a single Amazon Web Services account and a\nsingle Amazon Web Services Region. You can create upto 300 queries in a single\nAmazon Web Services account and a single Amazon Web Services Region.\n\n`PutStoredQuery` is an idempotent API. Subsequent requests won’t create a\nduplicate resource if one was already created. If a following request has\ndifferent `tags` values, Config will ignore these differences and treat it as an\nidempotent request of the previous. In this case, `tags` will not be updated,\neven if they are different.","ref":"AWS.Config.html#put_stored_query/3","title":"AWS.Config.put_stored_query/3","type":"function"},{"doc":"Accepts a structured query language (SQL) SELECT command and an aggregator to\nquery configuration state of Amazon Web Services resources across multiple\naccounts and regions, performs the corresponding search, and returns resource\nconfigurations matching the properties.\n\nFor more information about query components, see the [","ref":"AWS.Config.html#select_aggregate_resource_config/3","title":"AWS.Config.select_aggregate_resource_config/3","type":"function"},{"doc":"](https://docs.aws.amazon.com/config/latest/developerguide/query-components.html)\nsection in the *Config Developer Guide*.\n\nIf you run an aggregation query (i.e., using `GROUP BY` or using aggregate\nfunctions such as `COUNT`; e.g., `SELECT resourceId, COUNT(*) WHERE resourceType\n= 'AWS::IAM::Role' GROUP BY resourceId`) and do not specify the `MaxResults` or\nthe `Limit` query parameters, the default page size is set to 500.\n\nIf you run a non-aggregation query (i.e., not using `GROUP BY` or aggregate\nfunction; e.g., `SELECT * WHERE resourceType = 'AWS::IAM::Role'`) and do not\nspecify the `MaxResults` or the `Limit` query parameters, the default page size\nis set to 25.","ref":"AWS.Config.html#select_aggregate_resource_config/3-query-components","title":"Query Components - AWS.Config.select_aggregate_resource_config/3","type":"function"},{"doc":"Accepts a structured query language (SQL) `SELECT` command, performs the\ncorresponding search, and returns resource configurations matching the\nproperties.\n\nFor more information about query components, see the [","ref":"AWS.Config.html#select_resource_config/3","title":"AWS.Config.select_resource_config/3","type":"function"},{"doc":"](https://docs.aws.amazon.com/config/latest/developerguide/query-components.html)\nsection in the *Config Developer Guide*.","ref":"AWS.Config.html#select_resource_config/3-query-components","title":"Query Components - AWS.Config.select_resource_config/3","type":"function"},{"doc":"Runs an on-demand evaluation for the specified Config rules against the last\nknown configuration state of the resources.\n\nUse `StartConfigRulesEvaluation` when you want to test that a rule you updated\nis working as expected. `StartConfigRulesEvaluation` does not re-record the\nlatest configuration state for your resources. It re-runs an evaluation against\nthe last known state of your resources.\n\nYou can specify up to 25 Config rules per request.\n\nAn existing `StartConfigRulesEvaluation` call for the specified rules must\ncomplete before you can call the API again. If you chose to have Config stream\nto an Amazon SNS topic, you will receive a `ConfigRuleEvaluationStarted`\nnotification when the evaluation starts.\n\nYou don't need to call the `StartConfigRulesEvaluation` API to run an evaluation\nfor a new rule. When you create a rule, Config evaluates your resources against\nthe rule automatically.\n\nThe `StartConfigRulesEvaluation` API is useful if you want to run on-demand\nevaluations, such as the following example:\n\n  1. You have a custom rule that evaluates your IAM resources every 24\nhours.\n\n  2. You update your Lambda function to add additional conditions to\nyour rule.\n\n  3. Instead of waiting for the next periodic evaluation, you call the\n`StartConfigRulesEvaluation` API.\n\n  4. Config invokes your Lambda function and evaluates your IAM\nresources.\n\n  5. Your custom rule will still run periodic evaluations every 24\nhours.","ref":"AWS.Config.html#start_config_rules_evaluation/3","title":"AWS.Config.start_config_rules_evaluation/3","type":"function"},{"doc":"Starts recording configurations of the Amazon Web Services resources you have\nselected to record in your Amazon Web Services account.\n\nYou must have created at least one delivery channel to successfully start the\nconfiguration recorder.","ref":"AWS.Config.html#start_configuration_recorder/3","title":"AWS.Config.start_configuration_recorder/3","type":"function"},{"doc":"Runs an on-demand remediation for the specified Config rules against the last\nknown remediation configuration.\n\nIt runs an execution against the current state of your resources. Remediation\nexecution is asynchronous.\n\nYou can specify up to 100 resource keys per request. An existing\nStartRemediationExecution call for the specified resource keys must complete\nbefore you can call the API again.","ref":"AWS.Config.html#start_remediation_execution/3","title":"AWS.Config.start_remediation_execution/3","type":"function"},{"doc":"Runs an on-demand evaluation for the specified resource to determine whether the\nresource details will comply with configured Config rules.\n\nYou can also use it for evaluation purposes. Config recommends using an\nevaluation context. It runs an execution against the resource details with all\nof the Config rules in your account that match with the specified proactive mode\nand resource type.\n\nEnsure you have the `cloudformation:DescribeType` role setup to validate the\nresource type schema.\n\nYou can find the [Resource type schema](https://docs.aws.amazon.com/cloudformation-cli/latest/userguide/resource-type-schema.html)\nin \"*Amazon Web Services public extensions*\" within the CloudFormation registry\nor with the following CLI commmand: `aws cloudformation describe-type\n--type-name \"AWS::S3::Bucket\" --type RESOURCE`.\n\nFor more information, see [Managing extensions through the CloudFormation registry](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/registry.html#registry-view)\nand [Amazon Web Services resource and property types reference](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-template-resource-type-ref.html)\nin the CloudFormation User Guide.","ref":"AWS.Config.html#start_resource_evaluation/3","title":"AWS.Config.start_resource_evaluation/3","type":"function"},{"doc":"Stops recording configurations of the Amazon Web Services resources you have\nselected to record in your Amazon Web Services account.","ref":"AWS.Config.html#stop_configuration_recorder/3","title":"AWS.Config.stop_configuration_recorder/3","type":"function"},{"doc":"Associates the specified tags to a resource with the specified resourceArn.\n\nIf existing tags on a resource are not specified in the request parameters, they\nare not changed. If existing tags are specified, however, then their values will\nbe updated. When a resource is deleted, the tags associated with that resource\nare deleted as well.","ref":"AWS.Config.html#tag_resource/3","title":"AWS.Config.tag_resource/3","type":"function"},{"doc":"Deletes specified tags from a resource.","ref":"AWS.Config.html#untag_resource/3","title":"AWS.Config.untag_resource/3","type":"function"},{"doc":"Amazon Connect is a cloud-based contact center solution that you use to set up\nand manage a customer contact center and provide reliable customer engagement at\nany scale.\n\nAmazon Connect provides metrics and real-time reporting that enable you to\noptimize contact routing. You can also resolve customer issues more efficiently\nby getting customers in touch with the appropriate agents.\n\nThere are limits to the number of Amazon Connect resources that you can create.\nThere are also limits to the number of requests that you can make per second.\nFor more information, see [Amazon Connect Service Quotas](https://docs.aws.amazon.com/connect/latest/adminguide/amazon-connect-service-limits.html)\nin the *Amazon Connect Administrator Guide*.\n\nYou can connect programmatically to an Amazon Web Services service by using an\nendpoint. For a list of Amazon Connect endpoints, see [Amazon Connect Endpoints](https://docs.aws.amazon.com/general/latest/gr/connect_region.html).","ref":"AWS.Connect.html","title":"AWS.Connect","type":"module"},{"doc":"Activates an evaluation form in the specified Amazon Connect instance.\n\nAfter the evaluation form is activated, it is available to start new evaluations\nbased on the form.","ref":"AWS.Connect.html#activate_evaluation_form/5","title":"AWS.Connect.activate_evaluation_form/5","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nAssociates the specified dataset for a Amazon Connect instance with the target\naccount. You can associate only one dataset in a single call.","ref":"AWS.Connect.html#associate_analytics_data_set/4","title":"AWS.Connect.associate_analytics_data_set/4","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nAssociates an approved origin to an Amazon Connect instance.","ref":"AWS.Connect.html#associate_approved_origin/4","title":"AWS.Connect.associate_approved_origin/4","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nAllows the specified Amazon Connect instance to access the specified Amazon Lex\nor Amazon Lex V2 bot.","ref":"AWS.Connect.html#associate_bot/4","title":"AWS.Connect.associate_bot/4","type":"function"},{"doc":"Associates an existing vocabulary as the default.\n\nContact Lens for Amazon Connect uses the vocabulary in post-call and real-time\nanalysis sessions for the given language.","ref":"AWS.Connect.html#associate_default_vocabulary/5","title":"AWS.Connect.associate_default_vocabulary/5","type":"function"},{"doc":"Associates a connect resource to a flow.","ref":"AWS.Connect.html#associate_flow/4","title":"AWS.Connect.associate_flow/4","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nAssociates a storage resource type for the first time. You can only associate\none type of storage configuration in a single call. This means, for example,\nthat you can't define an instance with multiple S3 buckets for storing chat\ntranscripts.\n\nThis API does not create a resource that doesn't exist. It only associates it to\nthe instance. Ensure that the resource being specified in the storage\nconfiguration, like an S3 bucket, exists when being used for association.","ref":"AWS.Connect.html#associate_instance_storage_config/4","title":"AWS.Connect.associate_instance_storage_config/4","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nAllows the specified Amazon Connect instance to access the specified Lambda\nfunction.","ref":"AWS.Connect.html#associate_lambda_function/4","title":"AWS.Connect.associate_lambda_function/4","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nAllows the specified Amazon Connect instance to access the specified Amazon Lex\nV1 bot. This API only supports the association of Amazon Lex V1 bots.","ref":"AWS.Connect.html#associate_lex_bot/4","title":"AWS.Connect.associate_lex_bot/4","type":"function"},{"doc":"Associates a flow with a phone number claimed to your Amazon Connect instance.\n\nIf the number is claimed to a traffic distribution group, and you are calling\nthis API using an instance in the Amazon Web Services Region where the traffic\ndistribution group was created, you can use either a full phone number ARN or\nUUID value for the `PhoneNumberId` URI request parameter. However, if the number\nis claimed to a traffic distribution group and you are calling this API using an\ninstance in the alternate Amazon Web Services Region associated with the traffic\ndistribution group, you must provide a full phone number ARN. If a UUID is\nprovided in this scenario, you will receive a `ResourceNotFoundException`.","ref":"AWS.Connect.html#associate_phone_number_contact_flow/4","title":"AWS.Connect.associate_phone_number_contact_flow/4","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nAssociates a set of quick connects with a queue.","ref":"AWS.Connect.html#associate_queue_quick_connects/5","title":"AWS.Connect.associate_queue_quick_connects/5","type":"function"},{"doc":"Associates a set of queues with a routing profile.","ref":"AWS.Connect.html#associate_routing_profile_queues/5","title":"AWS.Connect.associate_routing_profile_queues/5","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nAssociates a security key to the instance.","ref":"AWS.Connect.html#associate_security_key/4","title":"AWS.Connect.associate_security_key/4","type":"function"},{"doc":"Associates an agent with a traffic distribution group.","ref":"AWS.Connect.html#associate_traffic_distribution_group_user/4","title":"AWS.Connect.associate_traffic_distribution_group_user/4","type":"function"},{"doc":">Associates a set of proficiencies with a user.","ref":"AWS.Connect.html#associate_user_proficiencies/5","title":"AWS.Connect.associate_user_proficiencies/5","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nAssociates a list of analytics datasets for a given Amazon Connect instance to a\ntarget account. You can associate multiple datasets in a single call.","ref":"AWS.Connect.html#batch_associate_analytics_data_set/4","title":"AWS.Connect.batch_associate_analytics_data_set/4","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nRemoves a list of analytics datasets associated with a given Amazon Connect\ninstance. You can disassociate multiple datasets in a single call.","ref":"AWS.Connect.html#batch_disassociate_analytics_data_set/4","title":"AWS.Connect.batch_disassociate_analytics_data_set/4","type":"function"},{"doc":"Retrieve the flow associations for the given resources.","ref":"AWS.Connect.html#batch_get_flow_association/4","title":"AWS.Connect.batch_get_flow_association/4","type":"function"},{"doc":"Only the Amazon Connect outbound campaigns service principal is allowed to\nassume a role in your account and call this API.\n\nAllows you to create a batch of contacts in Amazon Connect. The outbound\ncampaigns capability ingests dial requests via the\n[PutDialRequestBatch](https://docs.aws.amazon.com/connect-outbound/latest/APIReference/API_PutDialRequestBatch.html)\nAPI. It then uses BatchPutContact to create contacts corresponding to those dial\nrequests. If agents are available, the dial requests are dialed out, which\nresults in a voice call. The resulting voice call uses the same contactId that\nwas created by BatchPutContact.","ref":"AWS.Connect.html#batch_put_contact/4","title":"AWS.Connect.batch_put_contact/4","type":"function"},{"doc":"Claims an available phone number to your Amazon Connect instance or traffic\ndistribution group.\n\nYou can call this API only in the same Amazon Web Services Region where the\nAmazon Connect instance or traffic distribution group was created.\n\nFor more information about how to use this operation, see [Claim a phone number in your\ncountry](https://docs.aws.amazon.com/connect/latest/adminguide/claim-phone-number.html)\nand [Claim phone numbers to traffic distribution groups](https://docs.aws.amazon.com/connect/latest/adminguide/claim-phone-numbers-traffic-distribution-groups.html)\nin the *Amazon Connect Administrator Guide*.\n\nYou can call the\n[SearchAvailablePhoneNumbers](https://docs.aws.amazon.com/connect/latest/APIReference/API_SearchAvailablePhoneNumbers.html) API for available phone numbers that you can claim. Call the\n[DescribePhoneNumber](https://docs.aws.amazon.com/connect/latest/APIReference/API_DescribePhoneNumber.html)\nAPI to verify the status of a previous\n[ClaimPhoneNumber](https://docs.aws.amazon.com/connect/latest/APIReference/API_ClaimPhoneNumber.html)\noperation.\n\nIf you plan to claim and release numbers frequently during a 30 day period,\ncontact us for a service quota exception. Otherwise, it is possible you will be\nblocked from claiming and releasing any more numbers until 30 days past the\noldest number released has expired.\n\nBy default you can claim and release up to 200% of your maximum number of active\nphone numbers during any 30 day period. If you claim and release phone numbers\nusing the UI or API during a rolling 30 day cycle that exceeds 200% of your\nphone number service level quota, you will be blocked from claiming any more\nnumbers until 30 days past the oldest number released has expired.\n\nFor example, if you already have 99 claimed numbers and a service level quota of\n99 phone numbers, and in any 30 day period you release 99, claim 99, and then\nrelease 99, you will have exceeded the 200% limit. At that point you are blocked\nfrom claiming any more numbers until you open an Amazon Web Services support\nticket.","ref":"AWS.Connect.html#claim_phone_number/3","title":"AWS.Connect.claim_phone_number/3","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nCreates an agent status for the specified Amazon Connect instance.","ref":"AWS.Connect.html#create_agent_status/4","title":"AWS.Connect.create_agent_status/4","type":"function"},{"doc":"Creates a flow for the specified Amazon Connect instance.\n\nYou can also create and update flows using the [Amazon Connect Flow language](https://docs.aws.amazon.com/connect/latest/APIReference/flow-language.html).","ref":"AWS.Connect.html#create_contact_flow/4","title":"AWS.Connect.create_contact_flow/4","type":"function"},{"doc":"Creates a flow module for the specified Amazon Connect instance.","ref":"AWS.Connect.html#create_contact_flow_module/4","title":"AWS.Connect.create_contact_flow_module/4","type":"function"},{"doc":"Creates an evaluation form in the specified Amazon Connect instance.\n\nThe form can be used to define questions related to agent performance, and\ncreate sections to organize such questions. Question and section identifiers\ncannot be duplicated within the same evaluation form.","ref":"AWS.Connect.html#create_evaluation_form/4","title":"AWS.Connect.create_evaluation_form/4","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nCreates hours of operation.","ref":"AWS.Connect.html#create_hours_of_operation/4","title":"AWS.Connect.create_hours_of_operation/4","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nInitiates an Amazon Connect instance with all the supported channels enabled. It\ndoes not attach any storage, such as Amazon Simple Storage Service (Amazon S3)\nor Amazon Kinesis. It also does not allow for any configurations on features,\nsuch as Contact Lens for Amazon Connect.\n\nAmazon Connect enforces a limit on the total number of instances that you can\ncreate or delete in 30 days. If you exceed this limit, you will get an error\nmessage indicating there has been an excessive number of attempts at creating or\ndeleting instances. You must wait 30 days before you can restart creating and\ndeleting instances in your account.","ref":"AWS.Connect.html#create_instance/3","title":"AWS.Connect.create_instance/3","type":"function"},{"doc":"Creates an Amazon Web Services resource association with an Amazon Connect\ninstance.","ref":"AWS.Connect.html#create_integration_association/4","title":"AWS.Connect.create_integration_association/4","type":"function"},{"doc":"Adds a new participant into an on-going chat contact.\n\nFor more information, see [Customize chat flow experiences by integrating custom participants](https://docs.aws.amazon.com/connect/latest/adminguide/chat-customize-flow.html).","ref":"AWS.Connect.html#create_participant/3","title":"AWS.Connect.create_participant/3","type":"function"},{"doc":"Enables rehydration of chats for the lifespan of a contact.\n\nFor more information about chat rehydration, see [Enable persistent chat](https://docs.aws.amazon.com/connect/latest/adminguide/chat-persistence.html)\nin the *Amazon Connect Administrator Guide*.","ref":"AWS.Connect.html#create_persistent_contact_association/5","title":"AWS.Connect.create_persistent_contact_association/5","type":"function"},{"doc":"Creates a new predefined attribute for the specified Amazon Connect instance.","ref":"AWS.Connect.html#create_predefined_attribute/4","title":"AWS.Connect.create_predefined_attribute/4","type":"function"},{"doc":"Creates a prompt.\n\nFor more information about prompts, such as supported file types and maximum\nlength, see [Create prompts](https://docs.aws.amazon.com/connect/latest/adminguide/prompts.html) in\nthe *Amazon Connect Administrator's Guide*.","ref":"AWS.Connect.html#create_prompt/4","title":"AWS.Connect.create_prompt/4","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nCreates a new queue for the specified Amazon Connect instance.\n\n   If the phone number is claimed to a traffic distribution group that\nwas created in the same Region as the Amazon Connect instance where you are\ncalling this API, then you can use a full phone number ARN or a UUID for\n`OutboundCallerIdNumberId`. However, if the phone number is claimed to a traffic\ndistribution group that is in one Region, and you are calling this API from an\ninstance in another Amazon Web Services Region that is associated with the\ntraffic distribution group, you must provide a full phone number ARN. If a UUID\nis provided in this scenario, you will receive a `ResourceNotFoundException`.\n\n   Only use the phone number ARN format that doesn't contain\n`instance` in the path, for example,\n`arn:aws:connect:us-east-1:1234567890:phone-number/uuid`. This is the same ARN\nformat that is returned when you call the\n[ListPhoneNumbersV2](https://docs.aws.amazon.com/connect/latest/APIReference/API_ListPhoneNumbersV2.html) API.\n\n   If you plan to use IAM policies to allow/deny access to this API\nfor phone number resources claimed to a traffic distribution group, see [Allow\nor Deny queue API actions for phone numbers in a replica\nRegion](https://docs.aws.amazon.com/connect/latest/adminguide/security_iam_resource-level-policy-examples.html#allow-deny-queue-actions-replica-region).","ref":"AWS.Connect.html#create_queue/4","title":"AWS.Connect.create_queue/4","type":"function"},{"doc":"Creates a quick connect for the specified Amazon Connect instance.","ref":"AWS.Connect.html#create_quick_connect/4","title":"AWS.Connect.create_quick_connect/4","type":"function"},{"doc":"Creates a new routing profile.","ref":"AWS.Connect.html#create_routing_profile/4","title":"AWS.Connect.create_routing_profile/4","type":"function"},{"doc":"Creates a rule for the specified Amazon Connect instance.\n\nUse the [Rules Function language](https://docs.aws.amazon.com/connect/latest/APIReference/connect-rules-language.html)\nto code conditions for the rule.","ref":"AWS.Connect.html#create_rule/4","title":"AWS.Connect.create_rule/4","type":"function"},{"doc":"Creates a security profile.","ref":"AWS.Connect.html#create_security_profile/4","title":"AWS.Connect.create_security_profile/4","type":"function"},{"doc":"Creates a new task template in the specified Amazon Connect instance.","ref":"AWS.Connect.html#create_task_template/4","title":"AWS.Connect.create_task_template/4","type":"function"},{"doc":"Creates a traffic distribution group given an Amazon Connect instance that has\nbeen replicated.\n\nThe `SignInConfig` distribution is available only on a default\n`TrafficDistributionGroup` (see the `IsDefault` parameter in the\n[TrafficDistributionGroup](https://docs.aws.amazon.com/connect/latest/APIReference/API_TrafficDistributionGroup.html) data type). If you call `UpdateTrafficDistribution` with a modified\n`SignInConfig` and a non-default `TrafficDistributionGroup`, an\n`InvalidRequestException` is returned.\n\nFor more information about creating traffic distribution groups, see [Set up\ntraffic distribution\ngroups](https://docs.aws.amazon.com/connect/latest/adminguide/setup-traffic-distribution-groups.html)\nin the *Amazon Connect Administrator Guide*.","ref":"AWS.Connect.html#create_traffic_distribution_group/3","title":"AWS.Connect.create_traffic_distribution_group/3","type":"function"},{"doc":"Creates a use case for an integration association.","ref":"AWS.Connect.html#create_use_case/5","title":"AWS.Connect.create_use_case/5","type":"function"},{"doc":"Creates a user account for the specified Amazon Connect instance.\n\nCertain\n[UserIdentityInfo](https://docs.aws.amazon.com/connect/latest/APIReference/API_UserIdentityInfo.html) parameters are required in some situations. For example, `Email` is required if\nyou are using SAML for identity management. `FirstName` and `LastName` are\nrequired if you are using Amazon Connect or SAML for identity management.\n\nFor information about how to create users using the Amazon Connect admin\nwebsite, see [Add\nUsers](https://docs.aws.amazon.com/connect/latest/adminguide/user-management.html)\nin the *Amazon Connect Administrator Guide*.","ref":"AWS.Connect.html#create_user/4","title":"AWS.Connect.create_user/4","type":"function"},{"doc":"Creates a new user hierarchy group.","ref":"AWS.Connect.html#create_user_hierarchy_group/4","title":"AWS.Connect.create_user_hierarchy_group/4","type":"function"},{"doc":"Creates a new view with the possible status of `SAVED` or `PUBLISHED`.\n\nThe views will have a unique name for each connect instance.\n\nIt performs basic content validation if the status is `SAVED` or full content\nvalidation if the status is set to `PUBLISHED`. An error is returned if\nvalidation fails. It associates either the `$SAVED` qualifier or both of the\n`$SAVED` and `$LATEST` qualifiers with the provided view content based on the\nstatus. The view is idempotent if ClientToken is provided.","ref":"AWS.Connect.html#create_view/4","title":"AWS.Connect.create_view/4","type":"function"},{"doc":"Publishes a new version of the view identifier.\n\nVersions are immutable and monotonically increasing.\n\nIt returns the highest version if there is no change in content compared to that\nversion. An error is displayed if the supplied ViewContentSha256 is different\nfrom the ViewContentSha256 of the `$LATEST` alias.","ref":"AWS.Connect.html#create_view_version/5","title":"AWS.Connect.create_view_version/5","type":"function"},{"doc":"Creates a custom vocabulary associated with your Amazon Connect instance.\n\nYou can set a custom vocabulary to be your default vocabulary for a given\nlanguage. Contact Lens for Amazon Connect uses the default vocabulary in\npost-call and real-time contact analysis sessions for that language.","ref":"AWS.Connect.html#create_vocabulary/4","title":"AWS.Connect.create_vocabulary/4","type":"function"},{"doc":"Deactivates an evaluation form in the specified Amazon Connect instance.\n\nAfter a form is deactivated, it is no longer available for users to start new\nevaluations based on the form.","ref":"AWS.Connect.html#deactivate_evaluation_form/5","title":"AWS.Connect.deactivate_evaluation_form/5","type":"function"},{"doc":"Deletes a contact evaluation in the specified Amazon Connect instance.","ref":"AWS.Connect.html#delete_contact_evaluation/5","title":"AWS.Connect.delete_contact_evaluation/5","type":"function"},{"doc":"Deletes a flow for the specified Amazon Connect instance.","ref":"AWS.Connect.html#delete_contact_flow/5","title":"AWS.Connect.delete_contact_flow/5","type":"function"},{"doc":"Deletes the specified flow module.","ref":"AWS.Connect.html#delete_contact_flow_module/5","title":"AWS.Connect.delete_contact_flow_module/5","type":"function"},{"doc":"Deletes an evaluation form in the specified Amazon Connect instance.\n\n  * If the version property is provided, only the specified version of\nthe evaluation form is deleted.\n\n  * If no version is provided, then the full form (all versions) is\ndeleted.","ref":"AWS.Connect.html#delete_evaluation_form/5","title":"AWS.Connect.delete_evaluation_form/5","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nDeletes an hours of operation.","ref":"AWS.Connect.html#delete_hours_of_operation/5","title":"AWS.Connect.delete_hours_of_operation/5","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nDeletes the Amazon Connect instance.\n\nAmazon Connect enforces a limit on the total number of instances that you can\ncreate or delete in 30 days. If you exceed this limit, you will get an error\nmessage indicating there has been an excessive number of attempts at creating or\ndeleting instances. You must wait 30 days before you can restart creating and\ndeleting instances in your account.","ref":"AWS.Connect.html#delete_instance/4","title":"AWS.Connect.delete_instance/4","type":"function"},{"doc":"Deletes an Amazon Web Services resource association from an Amazon Connect\ninstance.\n\nThe association must not have any use cases associated with it.","ref":"AWS.Connect.html#delete_integration_association/5","title":"AWS.Connect.delete_integration_association/5","type":"function"},{"doc":"Deletes a predefined attribute from the specified Amazon Connect instance.","ref":"AWS.Connect.html#delete_predefined_attribute/5","title":"AWS.Connect.delete_predefined_attribute/5","type":"function"},{"doc":"Deletes a prompt.","ref":"AWS.Connect.html#delete_prompt/5","title":"AWS.Connect.delete_prompt/5","type":"function"},{"doc":"Deletes a queue.","ref":"AWS.Connect.html#delete_queue/5","title":"AWS.Connect.delete_queue/5","type":"function"},{"doc":"Deletes a quick connect.","ref":"AWS.Connect.html#delete_quick_connect/5","title":"AWS.Connect.delete_quick_connect/5","type":"function"},{"doc":"Deletes a routing profile.","ref":"AWS.Connect.html#delete_routing_profile/5","title":"AWS.Connect.delete_routing_profile/5","type":"function"},{"doc":"Deletes a rule for the specified Amazon Connect instance.","ref":"AWS.Connect.html#delete_rule/5","title":"AWS.Connect.delete_rule/5","type":"function"},{"doc":"Deletes a security profile.","ref":"AWS.Connect.html#delete_security_profile/5","title":"AWS.Connect.delete_security_profile/5","type":"function"},{"doc":"Deletes the task template.","ref":"AWS.Connect.html#delete_task_template/5","title":"AWS.Connect.delete_task_template/5","type":"function"},{"doc":"Deletes a traffic distribution group.\n\nThis API can be called only in the Region where the traffic distribution group\nis created.\n\nFor more information about deleting traffic distribution groups, see [Delete traffic distribution\ngroups](https://docs.aws.amazon.com/connect/latest/adminguide/delete-traffic-distribution-groups.html)\nin the *Amazon Connect Administrator Guide*.","ref":"AWS.Connect.html#delete_traffic_distribution_group/4","title":"AWS.Connect.delete_traffic_distribution_group/4","type":"function"},{"doc":"Deletes a use case from an integration association.","ref":"AWS.Connect.html#delete_use_case/6","title":"AWS.Connect.delete_use_case/6","type":"function"},{"doc":"Deletes a user account from the specified Amazon Connect instance.\n\nFor information about what happens to a user's data when their account is\ndeleted, see [Delete Users from Your Amazon Connect Instance](https://docs.aws.amazon.com/connect/latest/adminguide/delete-users.html)\nin the *Amazon Connect Administrator Guide*.","ref":"AWS.Connect.html#delete_user/5","title":"AWS.Connect.delete_user/5","type":"function"},{"doc":"Deletes an existing user hierarchy group.\n\nIt must not be associated with any agents or have any active child groups.","ref":"AWS.Connect.html#delete_user_hierarchy_group/5","title":"AWS.Connect.delete_user_hierarchy_group/5","type":"function"},{"doc":"Deletes the view entirely.\n\nIt deletes the view and all associated qualifiers (versions and aliases).","ref":"AWS.Connect.html#delete_view/5","title":"AWS.Connect.delete_view/5","type":"function"},{"doc":"Deletes the particular version specified in `ViewVersion` identifier.","ref":"AWS.Connect.html#delete_view_version/6","title":"AWS.Connect.delete_view_version/6","type":"function"},{"doc":"Deletes the vocabulary that has the given identifier.","ref":"AWS.Connect.html#delete_vocabulary/5","title":"AWS.Connect.delete_vocabulary/5","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nDescribes an agent status.","ref":"AWS.Connect.html#describe_agent_status/4","title":"AWS.Connect.describe_agent_status/4","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nDescribes the specified contact.\n\nContact information remains available in Amazon Connect for 24 months, and then\nit is deleted.\n\nOnly data from November 12, 2021, and later is returned by this API.","ref":"AWS.Connect.html#describe_contact/4","title":"AWS.Connect.describe_contact/4","type":"function"},{"doc":"Describes a contact evaluation in the specified Amazon Connect instance.","ref":"AWS.Connect.html#describe_contact_evaluation/4","title":"AWS.Connect.describe_contact_evaluation/4","type":"function"},{"doc":"Describes the specified flow.\n\nYou can also create and update flows using the [Amazon Connect Flow language](https://docs.aws.amazon.com/connect/latest/APIReference/flow-language.html).","ref":"AWS.Connect.html#describe_contact_flow/4","title":"AWS.Connect.describe_contact_flow/4","type":"function"},{"doc":"Describes the specified flow module.","ref":"AWS.Connect.html#describe_contact_flow_module/4","title":"AWS.Connect.describe_contact_flow_module/4","type":"function"},{"doc":"Describes an evaluation form in the specified Amazon Connect instance.\n\nIf the version property is not provided, the latest version of the evaluation\nform is described.","ref":"AWS.Connect.html#describe_evaluation_form/5","title":"AWS.Connect.describe_evaluation_form/5","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nDescribes the hours of operation.","ref":"AWS.Connect.html#describe_hours_of_operation/4","title":"AWS.Connect.describe_hours_of_operation/4","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nReturns the current state of the specified instance identifier. It tracks the\ninstance while it is being created and returns an error status, if applicable.\n\nIf an instance is not created successfully, the instance status reason field\nreturns details relevant to the reason. The instance in a failed state is\nreturned only for 24 hours after the CreateInstance API was invoked.","ref":"AWS.Connect.html#describe_instance/3","title":"AWS.Connect.describe_instance/3","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nDescribes the specified instance attribute.","ref":"AWS.Connect.html#describe_instance_attribute/4","title":"AWS.Connect.describe_instance_attribute/4","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nRetrieves the current storage configurations for the specified resource type,\nassociation ID, and instance ID.","ref":"AWS.Connect.html#describe_instance_storage_config/5","title":"AWS.Connect.describe_instance_storage_config/5","type":"function"},{"doc":"Gets details and status of a phone number that’s claimed to your Amazon Connect\ninstance or traffic distribution group.\n\nIf the number is claimed to a traffic distribution group, and you are calling in\nthe Amazon Web Services Region where the traffic distribution group was created,\nyou can use either a phone number ARN or UUID value for the `PhoneNumberId` URI\nrequest parameter. However, if the number is claimed to a traffic distribution\ngroup and you are calling this API in the alternate Amazon Web Services Region\nassociated with the traffic distribution group, you must provide a full phone\nnumber ARN. If a UUID is provided in this scenario, you will receive a\n`ResourceNotFoundException`.","ref":"AWS.Connect.html#describe_phone_number/3","title":"AWS.Connect.describe_phone_number/3","type":"function"},{"doc":"Describes a predefined attribute for the specified Amazon Connect instance.","ref":"AWS.Connect.html#describe_predefined_attribute/4","title":"AWS.Connect.describe_predefined_attribute/4","type":"function"},{"doc":"Describes the prompt.","ref":"AWS.Connect.html#describe_prompt/4","title":"AWS.Connect.describe_prompt/4","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nDescribes the specified queue.","ref":"AWS.Connect.html#describe_queue/4","title":"AWS.Connect.describe_queue/4","type":"function"},{"doc":"Describes the quick connect.","ref":"AWS.Connect.html#describe_quick_connect/4","title":"AWS.Connect.describe_quick_connect/4","type":"function"},{"doc":"Describes the specified routing profile.","ref":"AWS.Connect.html#describe_routing_profile/4","title":"AWS.Connect.describe_routing_profile/4","type":"function"},{"doc":"Describes a rule for the specified Amazon Connect instance.","ref":"AWS.Connect.html#describe_rule/4","title":"AWS.Connect.describe_rule/4","type":"function"},{"doc":"Gets basic information about the security profle.","ref":"AWS.Connect.html#describe_security_profile/4","title":"AWS.Connect.describe_security_profile/4","type":"function"},{"doc":"Gets details and status of a traffic distribution group.","ref":"AWS.Connect.html#describe_traffic_distribution_group/3","title":"AWS.Connect.describe_traffic_distribution_group/3","type":"function"},{"doc":"Describes the specified user.\n\nYou can [find the instance ID in the Amazon Connect console](https://docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html)\n(it’s the final part of the ARN). The console does not display the user IDs.\nInstead, list the users and note the IDs provided in the output.","ref":"AWS.Connect.html#describe_user/4","title":"AWS.Connect.describe_user/4","type":"function"},{"doc":"Describes the specified hierarchy group.","ref":"AWS.Connect.html#describe_user_hierarchy_group/4","title":"AWS.Connect.describe_user_hierarchy_group/4","type":"function"},{"doc":"Describes the hierarchy structure of the specified Amazon Connect instance.","ref":"AWS.Connect.html#describe_user_hierarchy_structure/3","title":"AWS.Connect.describe_user_hierarchy_structure/3","type":"function"},{"doc":"Retrieves the view for the specified Amazon Connect instance and view\nidentifier.\n\nThe view identifier can be supplied as a ViewId or ARN.\n\n`$SAVED` needs to be supplied if a view is unpublished.\n\nThe view identifier can contain an optional qualifier, for example,\n` :$SAVED`, which is either an actual version number or an Amazon\nConnect managed qualifier `$SAVED | $LATEST`. If it is not supplied, then\n`$LATEST` is assumed for customer managed views and an error is returned if\nthere is no published content available. Version 1 is assumed for Amazon Web\nServices managed views.","ref":"AWS.Connect.html#describe_view/4","title":"AWS.Connect.describe_view/4","type":"function"},{"doc":"Describes the specified vocabulary.","ref":"AWS.Connect.html#describe_vocabulary/4","title":"AWS.Connect.describe_vocabulary/4","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nRemoves the dataset ID associated with a given Amazon Connect instance.","ref":"AWS.Connect.html#disassociate_analytics_data_set/4","title":"AWS.Connect.disassociate_analytics_data_set/4","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nRevokes access to integrated applications from Amazon Connect.","ref":"AWS.Connect.html#disassociate_approved_origin/4","title":"AWS.Connect.disassociate_approved_origin/4","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nRevokes authorization from the specified instance to access the specified Amazon\nLex or Amazon Lex V2 bot.","ref":"AWS.Connect.html#disassociate_bot/4","title":"AWS.Connect.disassociate_bot/4","type":"function"},{"doc":"Disassociates a connect resource from a flow.","ref":"AWS.Connect.html#disassociate_flow/6","title":"AWS.Connect.disassociate_flow/6","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nRemoves the storage type configurations for the specified resource type and\nassociation ID.","ref":"AWS.Connect.html#disassociate_instance_storage_config/5","title":"AWS.Connect.disassociate_instance_storage_config/5","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nRemove the Lambda function from the dropdown options available in the relevant\nflow blocks.","ref":"AWS.Connect.html#disassociate_lambda_function/4","title":"AWS.Connect.disassociate_lambda_function/4","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nRevokes authorization from the specified instance to access the specified Amazon\nLex bot.","ref":"AWS.Connect.html#disassociate_lex_bot/4","title":"AWS.Connect.disassociate_lex_bot/4","type":"function"},{"doc":"Removes the flow association from a phone number claimed to your Amazon Connect\ninstance.\n\nIf the number is claimed to a traffic distribution group, and you are calling\nthis API using an instance in the Amazon Web Services Region where the traffic\ndistribution group was created, you can use either a full phone number ARN or\nUUID value for the `PhoneNumberId` URI request parameter. However, if the number\nis claimed to a traffic distribution group and you are calling this API using an\ninstance in the alternate Amazon Web Services Region associated with the traffic\ndistribution group, you must provide a full phone number ARN. If a UUID is\nprovided in this scenario, you will receive a `ResourceNotFoundException`.","ref":"AWS.Connect.html#disassociate_phone_number_contact_flow/4","title":"AWS.Connect.disassociate_phone_number_contact_flow/4","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nDisassociates a set of quick connects from a queue.","ref":"AWS.Connect.html#disassociate_queue_quick_connects/5","title":"AWS.Connect.disassociate_queue_quick_connects/5","type":"function"},{"doc":"Disassociates a set of queues from a routing profile.","ref":"AWS.Connect.html#disassociate_routing_profile_queues/5","title":"AWS.Connect.disassociate_routing_profile_queues/5","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nDeletes the specified security key.","ref":"AWS.Connect.html#disassociate_security_key/5","title":"AWS.Connect.disassociate_security_key/5","type":"function"},{"doc":"Disassociates an agent from a traffic distribution group.","ref":"AWS.Connect.html#disassociate_traffic_distribution_group_user/4","title":"AWS.Connect.disassociate_traffic_distribution_group_user/4","type":"function"},{"doc":"Disassociates a set of proficiencies from a user.","ref":"AWS.Connect.html#disassociate_user_proficiencies/5","title":"AWS.Connect.disassociate_user_proficiencies/5","type":"function"},{"doc":"Dismisses contacts from an agent’s CCP and returns the agent to an available\nstate, which allows the agent to receive a new routed contact.\n\nContacts can only be dismissed if they are in a `MISSED`, `ERROR`, `ENDED`, or\n`REJECTED` state in the [Agent Event Stream](https://docs.aws.amazon.com/connect/latest/adminguide/about-contact-states.html).","ref":"AWS.Connect.html#dismiss_user_contact/5","title":"AWS.Connect.dismiss_user_contact/5","type":"function"},{"doc":"Retrieves the contact attributes for the specified contact.","ref":"AWS.Connect.html#get_contact_attributes/4","title":"AWS.Connect.get_contact_attributes/4","type":"function"},{"doc":"Gets the real-time metric data from the specified Amazon Connect instance.\n\nFor a description of each metric, see [Real-time Metrics Definitions](https://docs.aws.amazon.com/connect/latest/adminguide/real-time-metrics-definitions.html)\nin the *Amazon Connect Administrator Guide*.","ref":"AWS.Connect.html#get_current_metric_data/4","title":"AWS.Connect.get_current_metric_data/4","type":"function"},{"doc":"Gets the real-time active user data from the specified Amazon Connect instance.","ref":"AWS.Connect.html#get_current_user_data/4","title":"AWS.Connect.get_current_user_data/4","type":"function"},{"doc":"Supports SAML sign-in for Amazon Connect.\n\nRetrieves a token for federation. The token is for the Amazon Connect user which\ncorresponds to the IAM credentials that were used to invoke this action.\n\nFor more information about how SAML sign-in works in Amazon Connect, see\n[Configure SAML with IAM for Amazon Connect in the *Amazon Connect Administrator Guide*.](https://docs.aws.amazon.com/connect/latest/adminguide/configure-saml.html\n)\n\nThis API doesn't support root users. If you try to invoke GetFederationToken\nwith root credentials, an error message similar to the following one appears:\n\n`Provided identity: Principal: .... User: .... cannot be used for federation\nwith Amazon Connect`","ref":"AWS.Connect.html#get_federation_token/3","title":"AWS.Connect.get_federation_token/3","type":"function"},{"doc":"Retrieves the flow associated for a given resource.","ref":"AWS.Connect.html#get_flow_association/5","title":"AWS.Connect.get_flow_association/5","type":"function"},{"doc":"Gets historical metric data from the specified Amazon Connect instance.\n\nFor a description of each historical metric, see [Historical Metrics Definitions](https://docs.aws.amazon.com/connect/latest/adminguide/historical-metrics-definitions.html)\nin the *Amazon Connect Administrator Guide*.\n\nWe recommend using the\n[GetMetricDataV2](https://docs.aws.amazon.com/connect/latest/APIReference/API_GetMetricDataV2.html)\nAPI. It provides more flexibility, features, and the ability to query longer\ntime ranges than `GetMetricData`. Use it to retrieve historical agent and\ncontact metrics for the last 3 months, at varying intervals. You can also use it\nto build custom dashboards to measure historical queue and agent performance.\nFor example, you can track the number of incoming contacts for the last 7 days,\nwith data split by day, to see how contact volume changed per day of the week.","ref":"AWS.Connect.html#get_metric_data/4","title":"AWS.Connect.get_metric_data/4","type":"function"},{"doc":"Gets metric data from the specified Amazon Connect instance.\n\n`GetMetricDataV2` offers more features than\n[GetMetricData](https://docs.aws.amazon.com/connect/latest/APIReference/API_GetMetricData.html), the previous version of this API. It has new metrics, offers filtering at a\nmetric level, and offers the ability to filter and group data by channels,\nqueues, routing profiles, agents, and agent hierarchy levels. It can retrieve\nhistorical data for the last 3 months, at varying intervals.\n\nFor a description of the historical metrics that are supported by\n`GetMetricDataV2` and `GetMetricData`, see [Historical metrics\ndefinitions](https://docs.aws.amazon.com/connect/latest/adminguide/historical-metrics-definitions.html)\nin the *Amazon Connect Administrator's Guide*.","ref":"AWS.Connect.html#get_metric_data_v2/3","title":"AWS.Connect.get_metric_data_v2/3","type":"function"},{"doc":"Gets the prompt file.","ref":"AWS.Connect.html#get_prompt_file/4","title":"AWS.Connect.get_prompt_file/4","type":"function"},{"doc":"Gets details about a specific task template in the specified Amazon Connect\ninstance.","ref":"AWS.Connect.html#get_task_template/5","title":"AWS.Connect.get_task_template/5","type":"function"},{"doc":"Retrieves the current traffic distribution for a given traffic distribution\ngroup.","ref":"AWS.Connect.html#get_traffic_distribution/3","title":"AWS.Connect.get_traffic_distribution/3","type":"function"},{"doc":"Imports a claimed phone number from an external service, such as Amazon\nPinpoint, into an Amazon Connect instance.\n\nYou can call this API only in the same Amazon Web Services Region where the\nAmazon Connect instance was created.","ref":"AWS.Connect.html#import_phone_number/3","title":"AWS.Connect.import_phone_number/3","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nLists agent statuses.","ref":"AWS.Connect.html#list_agent_statuses/6","title":"AWS.Connect.list_agent_statuses/6","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nLists the association status of requested dataset ID for a given Amazon Connect\ninstance.","ref":"AWS.Connect.html#list_analytics_data_associations/6","title":"AWS.Connect.list_analytics_data_associations/6","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nReturns a paginated list of all approved origins associated with the instance.","ref":"AWS.Connect.html#list_approved_origins/5","title":"AWS.Connect.list_approved_origins/5","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nFor the specified version of Amazon Lex, returns a paginated list of all the\nAmazon Lex bots currently associated with the instance. Use this API to returns\nboth Amazon Lex V1 and V2 bots.","ref":"AWS.Connect.html#list_bots/6","title":"AWS.Connect.list_bots/6","type":"function"},{"doc":"Lists contact evaluations in the specified Amazon Connect instance.","ref":"AWS.Connect.html#list_contact_evaluations/5","title":"AWS.Connect.list_contact_evaluations/5","type":"function"},{"doc":"Provides information about the flow modules for the specified Amazon Connect\ninstance.","ref":"AWS.Connect.html#list_contact_flow_modules/6","title":"AWS.Connect.list_contact_flow_modules/6","type":"function"},{"doc":"Provides information about the flows for the specified Amazon Connect instance.\n\nYou can also create and update flows using the [Amazon Connect Flow language](https://docs.aws.amazon.com/connect/latest/APIReference/flow-language.html).\n\nFor more information about flows, see\n[Flows](https://docs.aws.amazon.com/connect/latest/adminguide/concepts-contact-flows.html)\nin the *Amazon Connect Administrator Guide*.","ref":"AWS.Connect.html#list_contact_flows/6","title":"AWS.Connect.list_contact_flows/6","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nFor the specified `referenceTypes`, returns a list of references associated with\nthe contact.","ref":"AWS.Connect.html#list_contact_references/6","title":"AWS.Connect.list_contact_references/6","type":"function"},{"doc":"Lists the default vocabularies for the specified Amazon Connect instance.","ref":"AWS.Connect.html#list_default_vocabularies/4","title":"AWS.Connect.list_default_vocabularies/4","type":"function"},{"doc":"Lists versions of an evaluation form in the specified Amazon Connect instance.","ref":"AWS.Connect.html#list_evaluation_form_versions/6","title":"AWS.Connect.list_evaluation_form_versions/6","type":"function"},{"doc":"Lists evaluation forms in the specified Amazon Connect instance.","ref":"AWS.Connect.html#list_evaluation_forms/5","title":"AWS.Connect.list_evaluation_forms/5","type":"function"},{"doc":"List the flow association based on the filters.","ref":"AWS.Connect.html#list_flow_associations/6","title":"AWS.Connect.list_flow_associations/6","type":"function"},{"doc":"Provides information about the hours of operation for the specified Amazon\nConnect instance.\n\nFor more information about hours of operation, see [Set the Hours of Operation for a\nQueue](https://docs.aws.amazon.com/connect/latest/adminguide/set-hours-operation.html)\nin the *Amazon Connect Administrator Guide*.","ref":"AWS.Connect.html#list_hours_of_operations/5","title":"AWS.Connect.list_hours_of_operations/5","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nReturns a paginated list of all attribute types for the given instance.","ref":"AWS.Connect.html#list_instance_attributes/5","title":"AWS.Connect.list_instance_attributes/5","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nReturns a paginated list of storage configs for the identified instance and\nresource type.","ref":"AWS.Connect.html#list_instance_storage_configs/6","title":"AWS.Connect.list_instance_storage_configs/6","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nReturn a list of instances which are in active state, creation-in-progress\nstate, and failed state. Instances that aren't successfully created (they are in\na failed state) are returned only for 24 hours after the CreateInstance API was\ninvoked.","ref":"AWS.Connect.html#list_instances/4","title":"AWS.Connect.list_instances/4","type":"function"},{"doc":"Provides summary information about the Amazon Web Services resource associations\nfor the specified Amazon Connect instance.","ref":"AWS.Connect.html#list_integration_associations/7","title":"AWS.Connect.list_integration_associations/7","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nReturns a paginated list of all Lambda functions that display in the dropdown\noptions in the relevant flow blocks.","ref":"AWS.Connect.html#list_lambda_functions/5","title":"AWS.Connect.list_lambda_functions/5","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nReturns a paginated list of all the Amazon Lex V1 bots currently associated with\nthe instance. To return both Amazon Lex V1 and V2 bots, use the\n[ListBots](https://docs.aws.amazon.com/connect/latest/APIReference/API_ListBots.html)\nAPI.","ref":"AWS.Connect.html#list_lex_bots/5","title":"AWS.Connect.list_lex_bots/5","type":"function"},{"doc":"Provides information about the phone numbers for the specified Amazon Connect\ninstance.\n\nFor more information about phone numbers, see [Set Up Phone Numbers for Your Contact\nCenter](https://docs.aws.amazon.com/connect/latest/adminguide/contact-center-phone-number.html)\nin the *Amazon Connect Administrator Guide*.\n\n   We recommend using\n[ListPhoneNumbersV2](https://docs.aws.amazon.com/connect/latest/APIReference/API_ListPhoneNumbersV2.html) to return phone number types. ListPhoneNumbers doesn't support number types\n`UIFN`, `SHARED`, `THIRD_PARTY_TF`, and `THIRD_PARTY_DID`. While it returns\nnumbers of those types, it incorrectly lists them as `TOLL_FREE` or `DID`.\n\n   The phone number `Arn` value that is returned from each of the\nitems in the\n[PhoneNumberSummaryList](https://docs.aws.amazon.com/connect/latest/APIReference/API_ListPhoneNumbers.html#connect-ListPhoneNumbers-response-PhoneNumberSummaryList)\ncannot be used to tag phone number resources. It will fail with a\n`ResourceNotFoundException`. Instead, use the\n[ListPhoneNumbersV2](https://docs.aws.amazon.com/connect/latest/APIReference/API_ListPhoneNumbersV2.html)\nAPI. It returns the new phone number ARN that can be used to tag phone number\nresources.","ref":"AWS.Connect.html#list_phone_numbers/7","title":"AWS.Connect.list_phone_numbers/7","type":"function"},{"doc":"Lists phone numbers claimed to your Amazon Connect instance or traffic\ndistribution group.\n\nIf the provided `TargetArn` is a traffic distribution group, you can call this\nAPI in both Amazon Web Services Regions associated with traffic distribution\ngroup.\n\nFor more information about phone numbers, see [Set Up Phone Numbers for Your Contact\nCenter](https://docs.aws.amazon.com/connect/latest/adminguide/contact-center-phone-number.html)\nin the *Amazon Connect Administrator Guide*.\n\n   When given an instance ARN, `ListPhoneNumbersV2` returns only the\nphone numbers claimed to the instance.\n\n   When given a traffic distribution group ARN `ListPhoneNumbersV2`\nreturns only the phone numbers claimed to the traffic distribution group.","ref":"AWS.Connect.html#list_phone_numbers_v2/3","title":"AWS.Connect.list_phone_numbers_v2/3","type":"function"},{"doc":"Lists predefined attributes for the specified Amazon Connect instance.","ref":"AWS.Connect.html#list_predefined_attributes/5","title":"AWS.Connect.list_predefined_attributes/5","type":"function"},{"doc":"Provides information about the prompts for the specified Amazon Connect\ninstance.","ref":"AWS.Connect.html#list_prompts/5","title":"AWS.Connect.list_prompts/5","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nLists the quick connects associated with a queue.","ref":"AWS.Connect.html#list_queue_quick_connects/6","title":"AWS.Connect.list_queue_quick_connects/6","type":"function"},{"doc":"Provides information about the queues for the specified Amazon Connect instance.\n\nIf you do not specify a `QueueTypes` parameter, both standard and agent queues\nare returned. This might cause an unexpected truncation of results if you have\nmore than 1000 agents and you limit the number of results of the API call in\ncode.\n\nFor more information about queues, see [Queues: Standard and Agent](https://docs.aws.amazon.com/connect/latest/adminguide/concepts-queues-standard-and-agent.html)\nin the *Amazon Connect Administrator Guide*.","ref":"AWS.Connect.html#list_queues/6","title":"AWS.Connect.list_queues/6","type":"function"},{"doc":"Provides information about the quick connects for the specified Amazon Connect\ninstance.","ref":"AWS.Connect.html#list_quick_connects/6","title":"AWS.Connect.list_quick_connects/6","type":"function"},{"doc":"Provides a list of analysis segments for a real-time analysis session.","ref":"AWS.Connect.html#list_realtime_contact_analysis_segments_v2/5","title":"AWS.Connect.list_realtime_contact_analysis_segments_v2/5","type":"function"},{"doc":"Lists the queues associated with a routing profile.","ref":"AWS.Connect.html#list_routing_profile_queues/6","title":"AWS.Connect.list_routing_profile_queues/6","type":"function"},{"doc":"Provides summary information about the routing profiles for the specified Amazon\nConnect instance.\n\nFor more information about routing profiles, see [Routing Profiles](https://docs.aws.amazon.com/connect/latest/adminguide/concepts-routing.html)\nand [Create a Routing Profile](https://docs.aws.amazon.com/connect/latest/adminguide/routing-profiles.html)\nin the *Amazon Connect Administrator Guide*.","ref":"AWS.Connect.html#list_routing_profiles/5","title":"AWS.Connect.list_routing_profiles/5","type":"function"},{"doc":"List all rules for the specified Amazon Connect instance.","ref":"AWS.Connect.html#list_rules/7","title":"AWS.Connect.list_rules/7","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nReturns a paginated list of all security keys associated with the instance.","ref":"AWS.Connect.html#list_security_keys/5","title":"AWS.Connect.list_security_keys/5","type":"function"},{"doc":"Returns a list of third-party applications in a specific security profile.","ref":"AWS.Connect.html#list_security_profile_applications/6","title":"AWS.Connect.list_security_profile_applications/6","type":"function"},{"doc":"Lists the permissions granted to a security profile.","ref":"AWS.Connect.html#list_security_profile_permissions/6","title":"AWS.Connect.list_security_profile_permissions/6","type":"function"},{"doc":"Provides summary information about the security profiles for the specified\nAmazon Connect instance.\n\nFor more information about security profiles, see [Security Profiles](https://docs.aws.amazon.com/connect/latest/adminguide/connect-security-profiles.html)\nin the *Amazon Connect Administrator Guide*.","ref":"AWS.Connect.html#list_security_profiles/5","title":"AWS.Connect.list_security_profiles/5","type":"function"},{"doc":"Lists the tags for the specified resource.\n\nFor sample policies that use tags, see [Amazon Connect Identity-Based Policy Examples](https://docs.aws.amazon.com/connect/latest/adminguide/security_iam_id-based-policy-examples.html)\nin the *Amazon Connect Administrator Guide*.","ref":"AWS.Connect.html#list_tags_for_resource/3","title":"AWS.Connect.list_tags_for_resource/3","type":"function"},{"doc":"Lists task templates for the specified Amazon Connect instance.","ref":"AWS.Connect.html#list_task_templates/7","title":"AWS.Connect.list_task_templates/7","type":"function"},{"doc":"Lists traffic distribution group users.","ref":"AWS.Connect.html#list_traffic_distribution_group_users/5","title":"AWS.Connect.list_traffic_distribution_group_users/5","type":"function"},{"doc":"Lists traffic distribution groups.","ref":"AWS.Connect.html#list_traffic_distribution_groups/5","title":"AWS.Connect.list_traffic_distribution_groups/5","type":"function"},{"doc":"Lists the use cases for the integration association.","ref":"AWS.Connect.html#list_use_cases/6","title":"AWS.Connect.list_use_cases/6","type":"function"},{"doc":"Provides summary information about the hierarchy groups for the specified Amazon\nConnect instance.\n\nFor more information about agent hierarchies, see [Set Up Agent Hierarchies](https://docs.aws.amazon.com/connect/latest/adminguide/agent-hierarchy.html)\nin the *Amazon Connect Administrator Guide*.","ref":"AWS.Connect.html#list_user_hierarchy_groups/5","title":"AWS.Connect.list_user_hierarchy_groups/5","type":"function"},{"doc":"Lists proficiencies associated with a user.","ref":"AWS.Connect.html#list_user_proficiencies/6","title":"AWS.Connect.list_user_proficiencies/6","type":"function"},{"doc":"Provides summary information about the users for the specified Amazon Connect\ninstance.","ref":"AWS.Connect.html#list_users/5","title":"AWS.Connect.list_users/5","type":"function"},{"doc":"Returns all the available versions for the specified Amazon Connect instance and\nview identifier.\n\nResults will be sorted from highest to lowest.","ref":"AWS.Connect.html#list_view_versions/6","title":"AWS.Connect.list_view_versions/6","type":"function"},{"doc":"Returns views in the given instance.\n\nResults are sorted primarily by type, and secondarily by name.","ref":"AWS.Connect.html#list_views/6","title":"AWS.Connect.list_views/6","type":"function"},{"doc":"","ref":"AWS.Connect.html#metadata/0","title":"AWS.Connect.metadata/0","type":"function"},{"doc":"Initiates silent monitoring of a contact.\n\nThe Contact Control Panel (CCP) of the user specified by *userId* will be set to\nsilent monitoring mode on the contact.","ref":"AWS.Connect.html#monitor_contact/3","title":"AWS.Connect.monitor_contact/3","type":"function"},{"doc":"Allows pausing an ongoing task contact.","ref":"AWS.Connect.html#pause_contact/3","title":"AWS.Connect.pause_contact/3","type":"function"},{"doc":"Changes the current status of a user or agent in Amazon Connect.\n\nIf the agent is currently handling a contact, this sets the agent's next status.\n\nFor more information, see [Agent status](https://docs.aws.amazon.com/connect/latest/adminguide/metrics-agent-status.html)\nand [Set your next status](https://docs.aws.amazon.com/connect/latest/adminguide/set-next-status.html)\nin the *Amazon Connect Administrator Guide*.","ref":"AWS.Connect.html#put_user_status/5","title":"AWS.Connect.put_user_status/5","type":"function"},{"doc":"Releases a phone number previously claimed to an Amazon Connect instance or\ntraffic distribution group.\n\nYou can call this API only in the Amazon Web Services Region where the number\nwas claimed.\n\nTo release phone numbers from a traffic distribution group, use the\n`ReleasePhoneNumber` API, not the Amazon Connect admin website.\n\nAfter releasing a phone number, the phone number enters into a cooldown period\nof 30 days. It cannot be searched for or claimed again until the period has\nended. If you accidentally release a phone number, contact Amazon Web Services\nSupport.\n\nIf you plan to claim and release numbers frequently during a 30 day period,\ncontact us for a service quota exception. Otherwise, it is possible you will be\nblocked from claiming and releasing any more numbers until 30 days past the\noldest number released has expired.\n\nBy default you can claim and release up to 200% of your maximum number of active\nphone numbers during any 30 day period. If you claim and release phone numbers\nusing the UI or API during a rolling 30 day cycle that exceeds 200% of your\nphone number service level quota, you will be blocked from claiming any more\nnumbers until 30 days past the oldest number released has expired.\n\nFor example, if you already have 99 claimed numbers and a service level quota of\n99 phone numbers, and in any 30 day period you release 99, claim 99, and then\nrelease 99, you will have exceeded the 200% limit. At that point you are blocked\nfrom claiming any more numbers until you open an Amazon Web Services support\nticket.","ref":"AWS.Connect.html#release_phone_number/4","title":"AWS.Connect.release_phone_number/4","type":"function"},{"doc":"Replicates an Amazon Connect instance in the specified Amazon Web Services\nRegion and copies configuration information for Amazon Connect resources across\nAmazon Web Services Regions.\n\nFor more information about replicating an Amazon Connect instance, see [Create a replica of your existing Amazon Connect\ninstance](https://docs.aws.amazon.com/connect/latest/adminguide/create-replica-connect-instance.html)\nin the *Amazon Connect Administrator Guide*.","ref":"AWS.Connect.html#replicate_instance/4","title":"AWS.Connect.replicate_instance/4","type":"function"},{"doc":"Allows resuming a task contact in a paused state.","ref":"AWS.Connect.html#resume_contact/3","title":"AWS.Connect.resume_contact/3","type":"function"},{"doc":"When a contact is being recorded, and the recording has been suspended using\nSuspendContactRecording, this API resumes recording whatever recording is\nselected in the flow configuration: call, screen, or both.\n\nIf only call recording or only screen recording is enabled, then it would\nresume.\n\nVoice and screen recordings are supported.","ref":"AWS.Connect.html#resume_contact_recording/3","title":"AWS.Connect.resume_contact_recording/3","type":"function"},{"doc":"Searches for available phone numbers that you can claim to your Amazon Connect\ninstance or traffic distribution group.\n\nIf the provided `TargetArn` is a traffic distribution group, you can call this\nAPI in both Amazon Web Services Regions associated with the traffic distribution\ngroup.","ref":"AWS.Connect.html#search_available_phone_numbers/3","title":"AWS.Connect.search_available_phone_numbers/3","type":"function"},{"doc":"Searches contacts in an Amazon Connect instance.","ref":"AWS.Connect.html#search_contacts/3","title":"AWS.Connect.search_contacts/3","type":"function"},{"doc":"Searches the hours of operation in an Amazon Connect instance, with optional\nfiltering.","ref":"AWS.Connect.html#search_hours_of_operations/3","title":"AWS.Connect.search_hours_of_operations/3","type":"function"},{"doc":"Predefined attributes that meet certain criteria.","ref":"AWS.Connect.html#search_predefined_attributes/3","title":"AWS.Connect.search_predefined_attributes/3","type":"function"},{"doc":"Searches prompts in an Amazon Connect instance, with optional filtering.","ref":"AWS.Connect.html#search_prompts/3","title":"AWS.Connect.search_prompts/3","type":"function"},{"doc":"Searches queues in an Amazon Connect instance, with optional filtering.","ref":"AWS.Connect.html#search_queues/3","title":"AWS.Connect.search_queues/3","type":"function"},{"doc":"Searches quick connects in an Amazon Connect instance, with optional filtering.","ref":"AWS.Connect.html#search_quick_connects/3","title":"AWS.Connect.search_quick_connects/3","type":"function"},{"doc":"Searches tags used in an Amazon Connect instance using optional search criteria.","ref":"AWS.Connect.html#search_resource_tags/3","title":"AWS.Connect.search_resource_tags/3","type":"function"},{"doc":"Searches routing profiles in an Amazon Connect instance, with optional\nfiltering.","ref":"AWS.Connect.html#search_routing_profiles/3","title":"AWS.Connect.search_routing_profiles/3","type":"function"},{"doc":"Searches security profiles in an Amazon Connect instance, with optional\nfiltering.","ref":"AWS.Connect.html#search_security_profiles/3","title":"AWS.Connect.search_security_profiles/3","type":"function"},{"doc":"Searches users in an Amazon Connect instance, with optional filtering.\n\n`AfterContactWorkTimeLimit` is returned in milliseconds.","ref":"AWS.Connect.html#search_users/3","title":"AWS.Connect.search_users/3","type":"function"},{"doc":"Searches for vocabularies within a specific Amazon Connect instance using\n`State`, `NameStartsWith`, and `LanguageCode`.","ref":"AWS.Connect.html#search_vocabularies/4","title":"AWS.Connect.search_vocabularies/4","type":"function"},{"doc":"Processes chat integration events from Amazon Web Services or external\nintegrations to Amazon Connect.\n\nA chat integration event includes:\n\n  * SourceId, DestinationId, and Subtype: a set of identifiers,\nuniquely representing a chat\n\n  * ChatEvent: details of the chat action to perform such as sending a\nmessage, event, or disconnecting from a chat\n\nWhen a chat integration event is sent with chat identifiers that do not map to\nan active chat contact, a new chat contact is also created before handling chat\naction.\n\nAccess to this API is currently restricted to Amazon Pinpoint for supporting SMS\nintegration.","ref":"AWS.Connect.html#send_chat_integration_event/3","title":"AWS.Connect.send_chat_integration_event/3","type":"function"},{"doc":"Initiates a flow to start a new chat for the customer.\n\nResponse of this API provides a token required to obtain credentials from the\n[CreateParticipantConnection](https://docs.aws.amazon.com/connect-participant/latest/APIReference/API_CreateParticipantConnection.html) API in the Amazon Connect Participant Service.\n\nWhen a new chat contact is successfully created, clients must subscribe to the\nparticipant’s connection for the created chat within 5 minutes. This is achieved\nby invoking\n[CreateParticipantConnection](https://docs.aws.amazon.com/connect-participant/latest/APIReference/API_CreateParticipantConnection.html)\nwith WEBSOCKET and CONNECTION_CREDENTIALS.\n\nA 429 error occurs in the following situations:\n\n  * API rate limit is exceeded. API TPS throttling returns a\n`TooManyRequests` exception.\n\n  * The [quota for concurrent active chats](https://docs.aws.amazon.com/connect/latest/adminguide/amazon-connect-service-limits.html)\nis exceeded. Active chat throttling returns a `LimitExceededException`.\n\nIf you use the `ChatDurationInMinutes` parameter and receive a 400 error, your\naccount may not support the ability to configure custom chat durations. For more\ninformation, contact Amazon Web Services Support.\n\nFor more information about chat, see\n[Chat](https://docs.aws.amazon.com/connect/latest/adminguide/chat.html) in the\n*Amazon Connect Administrator Guide*.","ref":"AWS.Connect.html#start_chat_contact/3","title":"AWS.Connect.start_chat_contact/3","type":"function"},{"doc":"Starts an empty evaluation in the specified Amazon Connect instance, using the\ngiven evaluation form for the particular contact.\n\nThe evaluation form version used for the contact evaluation corresponds to the\ncurrently activated version. If no version is activated for the evaluation form,\nthe contact evaluation cannot be started.\n\nEvaluations created through the public API do not contain answer values\nsuggested from automation.","ref":"AWS.Connect.html#start_contact_evaluation/4","title":"AWS.Connect.start_contact_evaluation/4","type":"function"},{"doc":"Starts recording the contact:\n\n  * If the API is called *before* the agent joins the call, recording\nstarts when the agent joins the call.\n\n  * If the API is called *after* the agent joins the call, recording\nstarts at the time of the API call.\n\nStartContactRecording is a one-time action. For example, if you use\nStopContactRecording to stop recording an ongoing call, you can't use\nStartContactRecording to restart it. For scenarios where the recording has\nstarted and you want to suspend and resume it, such as when collecting sensitive\ninformation (for example, a credit card number), use SuspendContactRecording and\nResumeContactRecording.\n\nYou can use this API to override the recording behavior configured in the [Set recording\nbehavior](https://docs.aws.amazon.com/connect/latest/adminguide/set-recording-behavior.html)\nblock.\n\nOnly voice recordings are supported at this time.","ref":"AWS.Connect.html#start_contact_recording/3","title":"AWS.Connect.start_contact_recording/3","type":"function"},{"doc":"Initiates real-time message streaming for a new chat contact.\n\nFor more information about message streaming, see [Enable real-time chat message streaming](https://docs.aws.amazon.com/connect/latest/adminguide/chat-message-streaming.html)\nin the *Amazon Connect Administrator Guide*.","ref":"AWS.Connect.html#start_contact_streaming/3","title":"AWS.Connect.start_contact_streaming/3","type":"function"},{"doc":"Places an outbound call to a contact, and then initiates the flow.\n\nIt performs the actions in the flow that's specified (in `ContactFlowId`).\n\nAgents do not initiate the outbound API, which means that they do not dial the\ncontact. If the flow places an outbound call to a contact, and then puts the\ncontact in queue, the call is then routed to the agent, like any other inbound\ncase.\n\nThere is a 60-second dialing timeout for this operation. If the call is not\nconnected after 60 seconds, it fails.\n\nUK numbers with a 447 prefix are not allowed by default. Before you can dial\nthese UK mobile numbers, you must submit a service quota increase request. For\nmore information, see [Amazon Connect Service Quotas](https://docs.aws.amazon.com/connect/latest/adminguide/amazon-connect-service-limits.html)\nin the *Amazon Connect Administrator Guide*.\n\nCampaign calls are not allowed by default. Before you can make a call with\n`TrafficType` = `CAMPAIGN`, you must submit a service quota increase request to\nthe quota [Amazon Connect campaigns](https://docs.aws.amazon.com/connect/latest/adminguide/amazon-connect-service-limits.html#outbound-communications-quotas).","ref":"AWS.Connect.html#start_outbound_voice_contact/3","title":"AWS.Connect.start_outbound_voice_contact/3","type":"function"},{"doc":"Initiates a flow to start a new task contact.\n\nFor more information about task contacts, see [Concepts: Tasks in Amazon Connect](https://docs.aws.amazon.com/connect/latest/adminguide/tasks.html) in\nthe *Amazon Connect Administrator Guide*.\n\nWhen using `PreviousContactId` and `RelatedContactId` input parameters, note the\nfollowing:\n\n  * `PreviousContactId`\n\n    * Any updates to user-defined task contact attributes on\nany contact linked through the same `PreviousContactId` will affect every\ncontact in the chain.\n\n    * There can be a maximum of 12 linked task contacts in a\nchain. That is, 12 task contacts can be created that share the same\n`PreviousContactId`.\n\n  * `RelatedContactId`\n\n    * Copies contact attributes from the related task\ncontact to the new contact.\n\n    * Any update on attributes in a new task contact does\nnot update attributes on previous contact.\n\n    * There’s no limit on the number of task contacts that\ncan be created that use the same `RelatedContactId`.\n\nIn addition, when calling StartTaskContact include only one of these parameters:\n`ContactFlowID`, `QuickConnectID`, or `TaskTemplateID`. Only one parameter is\nrequired as long as the task template has a flow configured to run it. If more\nthan one parameter is specified, or only the `TaskTemplateID` is specified but\nit does not have a flow configured, the request returns an error because Amazon\nConnect cannot identify the unique flow to run when the task is created.\n\nA `ServiceQuotaExceededException` occurs when the number of open tasks exceeds\nthe active tasks quota or there are already 12 tasks referencing the same\n`PreviousContactId`. For more information about service quotas for task\ncontacts, see [Amazon Connect service quotas](https://docs.aws.amazon.com/connect/latest/adminguide/amazon-connect-service-limits.html)\nin the *Amazon Connect Administrator Guide*.","ref":"AWS.Connect.html#start_task_contact/3","title":"AWS.Connect.start_task_contact/3","type":"function"},{"doc":"Places an inbound in-app, web, or video call to a contact, and then initiates\nthe flow.\n\nIt performs the actions in the flow that are specified (in ContactFlowId) and\npresent in the Amazon Connect instance (specified as InstanceId).","ref":"AWS.Connect.html#start_web_r_t_c_contact/3","title":"AWS.Connect.start_web_r_t_c_contact/3","type":"function"},{"doc":"Ends the specified contact.\n\nThis call does not work for voice contacts that use the following initiation\nmethods:\n\n  * DISCONNECT\n\n  * TRANSFER\n\n  * QUEUE_TRANSFER\n\nChat and task contacts, however, can be terminated in any state, regardless of\ninitiation method.","ref":"AWS.Connect.html#stop_contact/3","title":"AWS.Connect.stop_contact/3","type":"function"},{"doc":"Stops recording a call when a contact is being recorded.\n\nStopContactRecording is a one-time action. If you use StopContactRecording to\nstop recording an ongoing call, you can't use StartContactRecording to restart\nit. For scenarios where the recording has started and you want to suspend it for\nsensitive information (for example, to collect a credit card number), and then\nrestart it, use SuspendContactRecording and ResumeContactRecording.\n\nOnly voice recordings are supported at this time.","ref":"AWS.Connect.html#stop_contact_recording/3","title":"AWS.Connect.stop_contact_recording/3","type":"function"},{"doc":"Ends message streaming on a specified contact.\n\nTo restart message streaming on that contact, call the\n[StartContactStreaming](https://docs.aws.amazon.com/connect/latest/APIReference/API_StartContactStreaming.html)\nAPI.","ref":"AWS.Connect.html#stop_contact_streaming/3","title":"AWS.Connect.stop_contact_streaming/3","type":"function"},{"doc":"Submits a contact evaluation in the specified Amazon Connect instance.\n\nAnswers included in the request are merged with existing answers for the given\nevaluation. If no answers or notes are passed, the evaluation is submitted with\nthe existing answers and notes. You can delete an answer or note by passing an\nempty object (`{}`) to the question identifier.\n\nIf a contact evaluation is already in submitted state, this operation will\ntrigger a resubmission.","ref":"AWS.Connect.html#submit_contact_evaluation/5","title":"AWS.Connect.submit_contact_evaluation/5","type":"function"},{"doc":"When a contact is being recorded, this API suspends recording whatever is\nselected in the flow configuration: call, screen, or both.\n\nIf only call recording or only screen recording is enabled, then it would be\nsuspended. For example, you might suspend the screen recording while collecting\nsensitive information, such as a credit card number. Then use\nResumeContactRecording to restart recording the screen.\n\nThe period of time that the recording is suspended is filled with silence in the\nfinal recording.\n\nVoice and screen recordings are supported.","ref":"AWS.Connect.html#suspend_contact_recording/3","title":"AWS.Connect.suspend_contact_recording/3","type":"function"},{"doc":"Adds the specified tags to the contact resource.\n\nFor more information about this API is used, see [Set up granular billing for a detailed view of your Amazon Connect\nusage](https://docs.aws.amazon.com/connect/latest/adminguide/granular-billing.html).","ref":"AWS.Connect.html#tag_contact/3","title":"AWS.Connect.tag_contact/3","type":"function"},{"doc":"Adds the specified tags to the specified resource.\n\nSome of the supported resource types are agents, routing profiles, queues, quick\nconnects, contact flows, agent statuses, hours of operation, phone numbers,\nsecurity profiles, and task templates. For a complete list, see [Tagging resources in Amazon\nConnect](https://docs.aws.amazon.com/connect/latest/adminguide/tagging.html).\n\nFor sample policies that use tags, see [Amazon Connect Identity-Based Policy Examples](https://docs.aws.amazon.com/connect/latest/adminguide/security_iam_id-based-policy-examples.html)\nin the *Amazon Connect Administrator Guide*.","ref":"AWS.Connect.html#tag_resource/4","title":"AWS.Connect.tag_resource/4","type":"function"},{"doc":"Transfers contacts from one agent or queue to another agent or queue at any\npoint after a contact is created.\n\nYou can transfer a contact to another queue by providing the flow which\norchestrates the contact to the destination queue. This gives you more control\nover contact handling and helps you adhere to the service level agreement (SLA)\nguaranteed to your customers.\n\nNote the following requirements:\n\n  * Transfer is supported for only `TASK` contacts.\n\n  * Do not use both `QueueId` and `UserId` in the same call.\n\n  * The following flow types are supported: Inbound flow, Transfer to\nagent flow, and Transfer to queue flow.\n\n  * The `TransferContact` API can be called only on active contacts.\n\n  * A contact cannot be transferred more than 11 times.","ref":"AWS.Connect.html#transfer_contact/3","title":"AWS.Connect.transfer_contact/3","type":"function"},{"doc":"Removes the specified tags from the contact resource.\n\nFor more information about this API is used, see [Set up granular billing for a detailed view of your Amazon Connect\nusage](https://docs.aws.amazon.com/connect/latest/adminguide/granular-billing.html).","ref":"AWS.Connect.html#untag_contact/5","title":"AWS.Connect.untag_contact/5","type":"function"},{"doc":"Removes the specified tags from the specified resource.","ref":"AWS.Connect.html#untag_resource/4","title":"AWS.Connect.untag_resource/4","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nUpdates agent status.","ref":"AWS.Connect.html#update_agent_status/5","title":"AWS.Connect.update_agent_status/5","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nAdds or updates user-defined contact information associated with the specified\ncontact. At least one field to be updated must be present in the request.\n\nYou can add or update user-defined contact information for both ongoing and\ncompleted contacts.","ref":"AWS.Connect.html#update_contact/5","title":"AWS.Connect.update_contact/5","type":"function"},{"doc":"Creates or updates user-defined contact attributes associated with the specified\ncontact.\n\nYou can create or update user-defined attributes for both ongoing and completed\ncontacts. For example, while the call is active, you can update the customer's\nname or the reason the customer called. You can add notes about steps that the\nagent took during the call that display to the next agent that takes the call.\nYou can also update attributes for a contact using data from your CRM\napplication and save the data with the contact in Amazon Connect. You could also\nflag calls for additional analysis, such as legal review or to identify abusive\ncallers.\n\nContact attributes are available in Amazon Connect for 24 months, and are then\ndeleted. For information about contact record retention and the maximum size of\nthe contact record attributes section, see [Feature specifications](https://docs.aws.amazon.com/connect/latest/adminguide/amazon-connect-service-limits.html#feature-limits)\nin the *Amazon Connect Administrator Guide*.","ref":"AWS.Connect.html#update_contact_attributes/3","title":"AWS.Connect.update_contact_attributes/3","type":"function"},{"doc":"Updates details about a contact evaluation in the specified Amazon Connect\ninstance.\n\nA contact evaluation must be in draft state. Answers included in the request are\nmerged with existing answers for the given evaluation. An answer or note can be\ndeleted by passing an empty object (`{}`) to the question identifier.","ref":"AWS.Connect.html#update_contact_evaluation/5","title":"AWS.Connect.update_contact_evaluation/5","type":"function"},{"doc":"Updates the specified flow.\n\nYou can also create and update flows using the [Amazon Connect Flow language](https://docs.aws.amazon.com/connect/latest/APIReference/flow-language.html).","ref":"AWS.Connect.html#update_contact_flow_content/5","title":"AWS.Connect.update_contact_flow_content/5","type":"function"},{"doc":"Updates metadata about specified flow.","ref":"AWS.Connect.html#update_contact_flow_metadata/5","title":"AWS.Connect.update_contact_flow_metadata/5","type":"function"},{"doc":"Updates specified flow module for the specified Amazon Connect instance.","ref":"AWS.Connect.html#update_contact_flow_module_content/5","title":"AWS.Connect.update_contact_flow_module_content/5","type":"function"},{"doc":"Updates metadata about specified flow module.","ref":"AWS.Connect.html#update_contact_flow_module_metadata/5","title":"AWS.Connect.update_contact_flow_module_metadata/5","type":"function"},{"doc":"The name of the flow.\n\nYou can also create and update flows using the [Amazon Connect Flow language](https://docs.aws.amazon.com/connect/latest/APIReference/flow-language.html).","ref":"AWS.Connect.html#update_contact_flow_name/5","title":"AWS.Connect.update_contact_flow_name/5","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nUpdates routing priority and age on the contact (**QueuePriority** and\n**QueueTimeAdjustmentInSeconds**). These properties can be used to change a\ncustomer's position in the queue. For example, you can move a contact to the\nback of the queue by setting a lower routing priority relative to other contacts\nin queue; or you can move a contact to the front of the queue by increasing the\nrouting age which will make the contact look artificially older and therefore\nhigher up in the first-in-first-out routing order. Note that adjusting the\nrouting age of a contact affects only its position in queue, and not its actual\nqueue wait time as reported through metrics. These properties can also be\nupdated by using [the Set routing priority / age flow block](https://docs.aws.amazon.com/connect/latest/adminguide/change-routing-priority.html).","ref":"AWS.Connect.html#update_contact_routing_data/5","title":"AWS.Connect.update_contact_routing_data/5","type":"function"},{"doc":"Updates the scheduled time of a task contact that is already scheduled.","ref":"AWS.Connect.html#update_contact_schedule/3","title":"AWS.Connect.update_contact_schedule/3","type":"function"},{"doc":"Updates details about a specific evaluation form version in the specified Amazon\nConnect instance.\n\nQuestion and section identifiers cannot be duplicated within the same evaluation\nform.\n\nThis operation does not support partial updates. Instead it does a full update\nof evaluation form content.","ref":"AWS.Connect.html#update_evaluation_form/5","title":"AWS.Connect.update_evaluation_form/5","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nUpdates the hours of operation.","ref":"AWS.Connect.html#update_hours_of_operation/5","title":"AWS.Connect.update_hours_of_operation/5","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nUpdates the value for the specified attribute type.","ref":"AWS.Connect.html#update_instance_attribute/5","title":"AWS.Connect.update_instance_attribute/5","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nUpdates an existing configuration for a resource type. This API is idempotent.","ref":"AWS.Connect.html#update_instance_storage_config/5","title":"AWS.Connect.update_instance_storage_config/5","type":"function"},{"doc":"Updates timeouts for when human chat participants are to be considered idle, and\nwhen agents are automatically disconnected from a chat due to idleness.\n\nYou can set four timers:\n\n  * Customer idle timeout\n\n  * Customer auto-disconnect timeout\n\n  * Agent idle timeout\n\n  * Agent auto-disconnect timeout\n\nFor more information about how chat timeouts work, see [Set up chat timeouts for human\nparticipants](https://docs.aws.amazon.com/connect/latest/adminguide/setup-chat-timeouts.html).","ref":"AWS.Connect.html#update_participant_role_config/5","title":"AWS.Connect.update_participant_role_config/5","type":"function"},{"doc":"Updates your claimed phone number from its current Amazon Connect instance or\ntraffic distribution group to another Amazon Connect instance or traffic\ndistribution group in the same Amazon Web Services Region.\n\nAfter using this API, you must verify that the phone number is attached to the\ncorrect flow in the target instance or traffic distribution group. You need to\ndo this because the API switches only the phone number to a new instance or\ntraffic distribution group. It doesn't migrate the flow configuration of the\nphone number, too.\n\nYou can call\n[DescribePhoneNumber](https://docs.aws.amazon.com/connect/latest/APIReference/API_DescribePhoneNumber.html) API to verify the status of a previous\n[UpdatePhoneNumber](https://docs.aws.amazon.com/connect/latest/APIReference/API_UpdatePhoneNumber.html)\noperation.","ref":"AWS.Connect.html#update_phone_number/4","title":"AWS.Connect.update_phone_number/4","type":"function"},{"doc":"Updates a phone number’s metadata.\n\nTo verify the status of a previous UpdatePhoneNumberMetadata operation, call the\n[DescribePhoneNumber](https://docs.aws.amazon.com/connect/latest/APIReference/API_DescribePhoneNumber.html)\nAPI.","ref":"AWS.Connect.html#update_phone_number_metadata/4","title":"AWS.Connect.update_phone_number_metadata/4","type":"function"},{"doc":"Updates a predefined attribute for the specified Amazon Connect instance.","ref":"AWS.Connect.html#update_predefined_attribute/5","title":"AWS.Connect.update_predefined_attribute/5","type":"function"},{"doc":"Updates a prompt.","ref":"AWS.Connect.html#update_prompt/5","title":"AWS.Connect.update_prompt/5","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nUpdates the hours of operation for the specified queue.","ref":"AWS.Connect.html#update_queue_hours_of_operation/5","title":"AWS.Connect.update_queue_hours_of_operation/5","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nUpdates the maximum number of contacts allowed in a queue before it is\nconsidered full.","ref":"AWS.Connect.html#update_queue_max_contacts/5","title":"AWS.Connect.update_queue_max_contacts/5","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nUpdates the name and description of a queue. At least `Name` or `Description`\nmust be provided.","ref":"AWS.Connect.html#update_queue_name/5","title":"AWS.Connect.update_queue_name/5","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nUpdates the outbound caller ID name, number, and outbound whisper flow for a\nspecified queue.\n\n   If the phone number is claimed to a traffic distribution group that\nwas created in the same Region as the Amazon Connect instance where you are\ncalling this API, then you can use a full phone number ARN or a UUID for\n`OutboundCallerIdNumberId`. However, if the phone number is claimed to a traffic\ndistribution group that is in one Region, and you are calling this API from an\ninstance in another Amazon Web Services Region that is associated with the\ntraffic distribution group, you must provide a full phone number ARN. If a UUID\nis provided in this scenario, you will receive a `ResourceNotFoundException`.\n\n   Only use the phone number ARN format that doesn't contain\n`instance` in the path, for example,\n`arn:aws:connect:us-east-1:1234567890:phone-number/uuid`. This is the same ARN\nformat that is returned when you call the\n[ListPhoneNumbersV2](https://docs.aws.amazon.com/connect/latest/APIReference/API_ListPhoneNumbersV2.html) API.\n\n   If you plan to use IAM policies to allow/deny access to this API\nfor phone number resources claimed to a traffic distribution group, see [Allow\nor Deny queue API actions for phone numbers in a replica\nRegion](https://docs.aws.amazon.com/connect/latest/adminguide/security_iam_resource-level-policy-examples.html#allow-deny-queue-actions-replica-region).","ref":"AWS.Connect.html#update_queue_outbound_caller_config/5","title":"AWS.Connect.update_queue_outbound_caller_config/5","type":"function"},{"doc":"This API is in preview release for Amazon Connect and is subject to change.\n\nUpdates the status of the queue.","ref":"AWS.Connect.html#update_queue_status/5","title":"AWS.Connect.update_queue_status/5","type":"function"},{"doc":"Updates the configuration settings for the specified quick connect.","ref":"AWS.Connect.html#update_quick_connect_config/5","title":"AWS.Connect.update_quick_connect_config/5","type":"function"},{"doc":"Updates the name and description of a quick connect.\n\nThe request accepts the following data in JSON format. At least `Name` or\n`Description` must be provided.","ref":"AWS.Connect.html#update_quick_connect_name/5","title":"AWS.Connect.update_quick_connect_name/5","type":"function"},{"doc":"Whether agents with this routing profile will have their routing order\ncalculated based on *time since their last inbound contact* or *longest idle\ntime*.","ref":"AWS.Connect.html#update_routing_profile_agent_availability_timer/5","title":"AWS.Connect.update_routing_profile_agent_availability_timer/5","type":"function"},{"doc":"Updates the channels that agents can handle in the Contact Control Panel (CCP)\nfor a routing profile.","ref":"AWS.Connect.html#update_routing_profile_concurrency/5","title":"AWS.Connect.update_routing_profile_concurrency/5","type":"function"},{"doc":"Updates the default outbound queue of a routing profile.","ref":"AWS.Connect.html#update_routing_profile_default_outbound_queue/5","title":"AWS.Connect.update_routing_profile_default_outbound_queue/5","type":"function"},{"doc":"Updates the name and description of a routing profile.\n\nThe request accepts the following data in JSON format. At least `Name` or\n`Description` must be provided.","ref":"AWS.Connect.html#update_routing_profile_name/5","title":"AWS.Connect.update_routing_profile_name/5","type":"function"},{"doc":"Updates the properties associated with a set of queues for a routing profile.","ref":"AWS.Connect.html#update_routing_profile_queues/5","title":"AWS.Connect.update_routing_profile_queues/5","type":"function"},{"doc":"Updates a rule for the specified Amazon Connect instance.\n\nUse the [Rules Function language](https://docs.aws.amazon.com/connect/latest/APIReference/connect-rules-language.html)\nto code conditions for the rule.","ref":"AWS.Connect.html#update_rule/5","title":"AWS.Connect.update_rule/5","type":"function"},{"doc":"Updates a security profile.","ref":"AWS.Connect.html#update_security_profile/5","title":"AWS.Connect.update_security_profile/5","type":"function"},{"doc":"Updates details about a specific task template in the specified Amazon Connect\ninstance.\n\nThis operation does not support partial updates. Instead it does a full update\nof template content.","ref":"AWS.Connect.html#update_task_template/5","title":"AWS.Connect.update_task_template/5","type":"function"},{"doc":"Updates the traffic distribution for a given traffic distribution group.\n\nThe `SignInConfig` distribution is available only on a default\n`TrafficDistributionGroup` (see the `IsDefault` parameter in the\n[TrafficDistributionGroup](https://docs.aws.amazon.com/connect/latest/APIReference/API_TrafficDistributionGroup.html) data type). If you call `UpdateTrafficDistribution` with a modified\n`SignInConfig` and a non-default `TrafficDistributionGroup`, an\n`InvalidRequestException` is returned.\n\nFor more information about updating a traffic distribution group, see [Update\ntelephony traffic distribution across Amazon Web Services Regions\n](https://docs.aws.amazon.com/connect/latest/adminguide/update-telephony-traffic-distribution.html)\nin the *Amazon Connect Administrator Guide*.","ref":"AWS.Connect.html#update_traffic_distribution/4","title":"AWS.Connect.update_traffic_distribution/4","type":"function"},{"doc":"Assigns the specified hierarchy group to the specified user.","ref":"AWS.Connect.html#update_user_hierarchy/5","title":"AWS.Connect.update_user_hierarchy/5","type":"function"},{"doc":"Updates the name of the user hierarchy group.","ref":"AWS.Connect.html#update_user_hierarchy_group_name/5","title":"AWS.Connect.update_user_hierarchy_group_name/5","type":"function"},{"doc":"Updates the user hierarchy structure: add, remove, and rename user hierarchy\nlevels.","ref":"AWS.Connect.html#update_user_hierarchy_structure/4","title":"AWS.Connect.update_user_hierarchy_structure/4","type":"function"},{"doc":"Updates the identity information for the specified user.\n\nWe strongly recommend limiting who has the ability to invoke\n`UpdateUserIdentityInfo`. Someone with that ability can change the login\ncredentials of other users by changing their email address. This poses a\nsecurity risk to your organization. They can change the email address of a user\nto the attacker's email address, and then reset the password through email. For\nmore information, see [Best Practices for Security Profiles](https://docs.aws.amazon.com/connect/latest/adminguide/security-profile-best-practices.html)\nin the *Amazon Connect Administrator Guide*.","ref":"AWS.Connect.html#update_user_identity_info/5","title":"AWS.Connect.update_user_identity_info/5","type":"function"},{"doc":"Updates the phone configuration settings for the specified user.","ref":"AWS.Connect.html#update_user_phone_config/5","title":"AWS.Connect.update_user_phone_config/5","type":"function"},{"doc":"Updates the properties associated with the proficiencies of a user.","ref":"AWS.Connect.html#update_user_proficiencies/5","title":"AWS.Connect.update_user_proficiencies/5","type":"function"},{"doc":"Assigns the specified routing profile to the specified user.","ref":"AWS.Connect.html#update_user_routing_profile/5","title":"AWS.Connect.update_user_routing_profile/5","type":"function"},{"doc":"Assigns the specified security profiles to the specified user.","ref":"AWS.Connect.html#update_user_security_profiles/5","title":"AWS.Connect.update_user_security_profiles/5","type":"function"},{"doc":"Updates the view content of the given view identifier in the specified Amazon\nConnect instance.\n\nIt performs content validation if `Status` is set to `SAVED` and performs full\ncontent validation if `Status` is `PUBLISHED`. Note that the `$SAVED` alias'\ncontent will always be updated, but the `$LATEST` alias' content will only be\nupdated if `Status` is `PUBLISHED`.","ref":"AWS.Connect.html#update_view_content/5","title":"AWS.Connect.update_view_content/5","type":"function"},{"doc":"Updates the view metadata.\n\nNote that either `Name` or `Description` must be provided.","ref":"AWS.Connect.html#update_view_metadata/5","title":"AWS.Connect.update_view_metadata/5","type":"function"},{"doc":"Provide APIs to create and manage Amazon Connect Campaigns.","ref":"AWS.ConnectCampaigns.html","title":"AWS.ConnectCampaigns","type":"module"},{"doc":"Creates a campaign for the specified Amazon Connect account.\n\nThis API is idempotent.","ref":"AWS.ConnectCampaigns.html#create_campaign/3","title":"AWS.ConnectCampaigns.create_campaign/3","type":"function"},{"doc":"Deletes a campaign from the specified Amazon Connect account.","ref":"AWS.ConnectCampaigns.html#delete_campaign/4","title":"AWS.ConnectCampaigns.delete_campaign/4","type":"function"},{"doc":"Deletes a connect instance config from the specified AWS account.","ref":"AWS.ConnectCampaigns.html#delete_connect_instance_config/4","title":"AWS.ConnectCampaigns.delete_connect_instance_config/4","type":"function"},{"doc":"Delete the Connect Campaigns onboarding job for the specified Amazon Connect\ninstance.","ref":"AWS.ConnectCampaigns.html#delete_instance_onboarding_job/4","title":"AWS.ConnectCampaigns.delete_instance_onboarding_job/4","type":"function"},{"doc":"Describes the specific campaign.","ref":"AWS.ConnectCampaigns.html#describe_campaign/3","title":"AWS.ConnectCampaigns.describe_campaign/3","type":"function"},{"doc":"Get state of a campaign for the specified Amazon Connect account.","ref":"AWS.ConnectCampaigns.html#get_campaign_state/3","title":"AWS.ConnectCampaigns.get_campaign_state/3","type":"function"},{"doc":"Get state of campaigns for the specified Amazon Connect account.","ref":"AWS.ConnectCampaigns.html#get_campaign_state_batch/3","title":"AWS.ConnectCampaigns.get_campaign_state_batch/3","type":"function"},{"doc":"Get the specific Connect instance config.","ref":"AWS.ConnectCampaigns.html#get_connect_instance_config/3","title":"AWS.ConnectCampaigns.get_connect_instance_config/3","type":"function"},{"doc":"Get the specific instance onboarding job status.","ref":"AWS.ConnectCampaigns.html#get_instance_onboarding_job_status/3","title":"AWS.ConnectCampaigns.get_instance_onboarding_job_status/3","type":"function"},{"doc":"Provides summary information about the campaigns under the specified Amazon\nConnect account.","ref":"AWS.ConnectCampaigns.html#list_campaigns/3","title":"AWS.ConnectCampaigns.list_campaigns/3","type":"function"},{"doc":"List tags for a resource.","ref":"AWS.ConnectCampaigns.html#list_tags_for_resource/3","title":"AWS.ConnectCampaigns.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.ConnectCampaigns.html#metadata/0","title":"AWS.ConnectCampaigns.metadata/0","type":"function"},{"doc":"Pauses a campaign for the specified Amazon Connect account.","ref":"AWS.ConnectCampaigns.html#pause_campaign/4","title":"AWS.ConnectCampaigns.pause_campaign/4","type":"function"},{"doc":"Creates dials requests for the specified campaign Amazon Connect account.\n\nThis API is idempotent.","ref":"AWS.ConnectCampaigns.html#put_dial_request_batch/4","title":"AWS.ConnectCampaigns.put_dial_request_batch/4","type":"function"},{"doc":"Stops a campaign for the specified Amazon Connect account.","ref":"AWS.ConnectCampaigns.html#resume_campaign/4","title":"AWS.ConnectCampaigns.resume_campaign/4","type":"function"},{"doc":"Starts a campaign for the specified Amazon Connect account.","ref":"AWS.ConnectCampaigns.html#start_campaign/4","title":"AWS.ConnectCampaigns.start_campaign/4","type":"function"},{"doc":"Onboard the specific Amazon Connect instance to Connect Campaigns.","ref":"AWS.ConnectCampaigns.html#start_instance_onboarding_job/4","title":"AWS.ConnectCampaigns.start_instance_onboarding_job/4","type":"function"},{"doc":"Stops a campaign for the specified Amazon Connect account.","ref":"AWS.ConnectCampaigns.html#stop_campaign/4","title":"AWS.ConnectCampaigns.stop_campaign/4","type":"function"},{"doc":"Tag a resource.","ref":"AWS.ConnectCampaigns.html#tag_resource/4","title":"AWS.ConnectCampaigns.tag_resource/4","type":"function"},{"doc":"Untag a resource.","ref":"AWS.ConnectCampaigns.html#untag_resource/4","title":"AWS.ConnectCampaigns.untag_resource/4","type":"function"},{"doc":"Updates the dialer config of a campaign.\n\nThis API is idempotent.","ref":"AWS.ConnectCampaigns.html#update_campaign_dialer_config/4","title":"AWS.ConnectCampaigns.update_campaign_dialer_config/4","type":"function"},{"doc":"Updates the name of a campaign.\n\nThis API is idempotent.","ref":"AWS.ConnectCampaigns.html#update_campaign_name/4","title":"AWS.ConnectCampaigns.update_campaign_name/4","type":"function"},{"doc":"Updates the outbound call config of a campaign.\n\nThis API is idempotent.","ref":"AWS.ConnectCampaigns.html#update_campaign_outbound_call_config/4","title":"AWS.ConnectCampaigns.update_campaign_outbound_call_config/4","type":"function"},{"doc":"With Amazon Connect Cases, your agents can track and manage customer issues that\nrequire multiple interactions, follow-up tasks, and teams in your contact\ncenter.\n\nA case represents a customer issue. It records the issue, the steps and\ninteractions taken to resolve the issue, and the outcome. For more information,\nsee [Amazon Connect Cases](https://docs.aws.amazon.com/connect/latest/adminguide/cases.html) in the\n*Amazon Connect Administrator Guide*.","ref":"AWS.ConnectCases.html","title":"AWS.ConnectCases","type":"module"},{"doc":"Returns the description for the list of fields in the request parameters.","ref":"AWS.ConnectCases.html#batch_get_field/4","title":"AWS.ConnectCases.batch_get_field/4","type":"function"},{"doc":"Creates and updates a set of field options for a single select field in a Cases\ndomain.","ref":"AWS.ConnectCases.html#batch_put_field_options/5","title":"AWS.ConnectCases.batch_put_field_options/5","type":"function"},{"doc":"If you provide a value for `PerformedBy.UserArn` you must also have\n[connect:DescribeUser](https://docs.aws.amazon.com/connect/latest/APIReference/API_DescribeUser.html)\npermission on the User ARN resource that you provide\n\n` Creates a case in the specified Cases domain.\n\nCase system and custom fields are taken as an array id/value pairs with a\ndeclared data types.\n\nThe following fields are required when creating a case:\n\n  * `customer_id` - You must provide the full customer profile ARN in\nthis format: `arn:aws:profile:your_AWS_Region:your_AWS_account\nID:domains/your_profiles_domain_name/profiles/profile_ID`\n\n  * `title`\n\n`","ref":"AWS.ConnectCases.html#create_case/4","title":"AWS.ConnectCases.create_case/4","type":"function"},{"doc":"Creates a domain, which is a container for all case data, such as cases, fields,\ntemplates and layouts.\n\nEach Amazon Connect instance can be associated with only one Cases domain.\n\nThis will not associate your connect instance to Cases domain. Instead, use the\nAmazon Connect\n[CreateIntegrationAssociation](https://docs.aws.amazon.com/connect/latest/APIReference/API_CreateIntegrationAssociation.html) API. You need specific IAM permissions to successfully associate the Cases\ndomain. For more information, see [Onboard to\nCases](https://docs.aws.amazon.com/connect/latest/adminguide/required-permissions-iam-cases.html#onboard-cases-iam).\n\n` `","ref":"AWS.ConnectCases.html#create_domain/3","title":"AWS.ConnectCases.create_domain/3","type":"function"},{"doc":"Creates a field in the Cases domain.\n\nThis field is used to define the case object model (that is, defines what data\ncan be captured on cases) in a Cases domain.","ref":"AWS.ConnectCases.html#create_field/4","title":"AWS.ConnectCases.create_field/4","type":"function"},{"doc":"Creates a layout in the Cases domain.\n\nLayouts define the following configuration in the top section and More Info tab\nof the Cases user interface:\n\n  * Fields to display to the users\n\n  * Field ordering\n\nTitle and Status fields cannot be part of layouts since they are not\nconfigurable.","ref":"AWS.ConnectCases.html#create_layout/4","title":"AWS.ConnectCases.create_layout/4","type":"function"},{"doc":"Creates a related item (comments, tasks, and contacts) and associates it with a\ncase.\n\n   A Related Item is a resource that is associated with a case. It may\nor may not have an external identifier linking it to an external resource (for\nexample, a `contactArn`). All Related Items have their own internal identifier,\nthe `relatedItemArn`. Examples of related items include `comments` and\n`contacts`.\n\n   If you provide a value for `performedBy.userArn` you must also have\n[DescribeUser](https://docs.aws.amazon.com/connect/latest/APIReference/API_DescribeUser.html)\npermission on the ARN of the user that you provide.\n\n` `","ref":"AWS.ConnectCases.html#create_related_item/5","title":"AWS.ConnectCases.create_related_item/5","type":"function"},{"doc":"Creates a template in the Cases domain.\n\nThis template is used to define the case object model (that is, to define what\ndata can be captured on cases) in a Cases domain. A template must have a unique\nname within a domain, and it must reference existing field IDs and layout IDs.\nAdditionally, multiple fields with same IDs are not allowed within the same\nTemplate. A template can be either Active or Inactive, as indicated by its\nstatus. Inactive templates cannot be used to create cases.","ref":"AWS.ConnectCases.html#create_template/4","title":"AWS.ConnectCases.create_template/4","type":"function"},{"doc":"Deletes a Cases domain.\n\n` After deleting your domain you must disassociate the deleted domain from your\nAmazon Connect instance with another API call before being able to use Cases\nagain with this Amazon Connect instance. See\n[DeleteIntegrationAssociation](https://docs.aws.amazon.com/connect/latest/APIReference/API_DeleteIntegrationAssociation.html).\n\n`","ref":"AWS.ConnectCases.html#delete_domain/4","title":"AWS.ConnectCases.delete_domain/4","type":"function"},{"doc":"Returns information about a specific case if it exists.","ref":"AWS.ConnectCases.html#get_case/5","title":"AWS.ConnectCases.get_case/5","type":"function"},{"doc":"Returns the audit history about a specific case if it exists.","ref":"AWS.ConnectCases.html#get_case_audit_events/5","title":"AWS.ConnectCases.get_case_audit_events/5","type":"function"},{"doc":"Returns the case event publishing configuration.","ref":"AWS.ConnectCases.html#get_case_event_configuration/4","title":"AWS.ConnectCases.get_case_event_configuration/4","type":"function"},{"doc":"Returns information about a specific domain if it exists.","ref":"AWS.ConnectCases.html#get_domain/4","title":"AWS.ConnectCases.get_domain/4","type":"function"},{"doc":"Returns the details for the requested layout.","ref":"AWS.ConnectCases.html#get_layout/5","title":"AWS.ConnectCases.get_layout/5","type":"function"},{"doc":"Returns the details for the requested template.","ref":"AWS.ConnectCases.html#get_template/5","title":"AWS.ConnectCases.get_template/5","type":"function"},{"doc":"Lists cases for a given contact.","ref":"AWS.ConnectCases.html#list_cases_for_contact/4","title":"AWS.ConnectCases.list_cases_for_contact/4","type":"function"},{"doc":"Lists all cases domains in the Amazon Web Services account.\n\nEach list item is a condensed summary object of the domain.","ref":"AWS.ConnectCases.html#list_domains/3","title":"AWS.ConnectCases.list_domains/3","type":"function"},{"doc":"Lists all of the field options for a field identifier in the domain.","ref":"AWS.ConnectCases.html#list_field_options/5","title":"AWS.ConnectCases.list_field_options/5","type":"function"},{"doc":"Lists all fields in a Cases domain.","ref":"AWS.ConnectCases.html#list_fields/4","title":"AWS.ConnectCases.list_fields/4","type":"function"},{"doc":"Lists all layouts in the given cases domain.\n\nEach list item is a condensed summary object of the layout.","ref":"AWS.ConnectCases.html#list_layouts/4","title":"AWS.ConnectCases.list_layouts/4","type":"function"},{"doc":"Lists tags for a resource.","ref":"AWS.ConnectCases.html#list_tags_for_resource/3","title":"AWS.ConnectCases.list_tags_for_resource/3","type":"function"},{"doc":"Lists all of the templates in a Cases domain.\n\nEach list item is a condensed summary object of the template.","ref":"AWS.ConnectCases.html#list_templates/4","title":"AWS.ConnectCases.list_templates/4","type":"function"},{"doc":"","ref":"AWS.ConnectCases.html#metadata/0","title":"AWS.ConnectCases.metadata/0","type":"function"},{"doc":"Adds case event publishing configuration.\n\nFor a complete list of fields you can add to the event message, see [Create case fields](https://docs.aws.amazon.com/connect/latest/adminguide/case-fields.html)\nin the *Amazon Connect Administrator Guide*","ref":"AWS.ConnectCases.html#put_case_event_configuration/4","title":"AWS.ConnectCases.put_case_event_configuration/4","type":"function"},{"doc":"Searches for cases within their associated Cases domain.\n\nSearch results are returned as a paginated list of abridged case documents.\n\nFor `customer_id` you must provide the full customer profile ARN in this format:\n` arn:aws:profile:your AWS Region:your AWS account ID:domains/profiles domain\nname/profiles/profile ID`.","ref":"AWS.ConnectCases.html#search_cases/4","title":"AWS.ConnectCases.search_cases/4","type":"function"},{"doc":"Searches for related items that are associated with a case.\n\nIf no filters are provided, this returns all related items associated with a\ncase.","ref":"AWS.ConnectCases.html#search_related_items/5","title":"AWS.ConnectCases.search_related_items/5","type":"function"},{"doc":"Adds tags to a resource.","ref":"AWS.ConnectCases.html#tag_resource/4","title":"AWS.ConnectCases.tag_resource/4","type":"function"},{"doc":"Untags a resource.","ref":"AWS.ConnectCases.html#untag_resource/4","title":"AWS.ConnectCases.untag_resource/4","type":"function"},{"doc":"If you provide a value for `PerformedBy.UserArn` you must also have\n[connect:DescribeUser](https://docs.aws.amazon.com/connect/latest/APIReference/API_DescribeUser.html)\npermission on the User ARN resource that you provide\n\n` Updates the values of fields on a case.\n\nFields to be updated are received as an array of id/value pairs identical to the\n`CreateCase` input .\n\nIf the action is successful, the service sends back an HTTP 200 response with an\nempty HTTP body.\n\n`","ref":"AWS.ConnectCases.html#update_case/5","title":"AWS.ConnectCases.update_case/5","type":"function"},{"doc":"Updates the properties of an existing field.","ref":"AWS.ConnectCases.html#update_field/5","title":"AWS.ConnectCases.update_field/5","type":"function"},{"doc":"Updates the attributes of an existing layout.\n\nIf the action is successful, the service sends back an HTTP 200 response with an\nempty HTTP body.\n\nA `ValidationException` is returned when you add non-existent `fieldIds` to a\nlayout.\n\nTitle and Status fields cannot be part of layouts because they are not\nconfigurable.","ref":"AWS.ConnectCases.html#update_layout/5","title":"AWS.ConnectCases.update_layout/5","type":"function"},{"doc":"Updates the attributes of an existing template.\n\nThe template attributes that can be modified include `name`, `description`,\n`layoutConfiguration`, `requiredFields`, and `status`. At least one of these\nattributes must not be null. If a null value is provided for a given attribute,\nthat attribute is ignored and its current value is preserved.","ref":"AWS.ConnectCases.html#update_template/5","title":"AWS.ConnectCases.update_template/5","type":"function"},{"doc":"Contact Lens for Amazon Connect enables you to analyze conversations between\ncustomer and agents, by using speech transcription, natural language processing,\nand intelligent search capabilities.\n\nIt performs sentiment analysis, detects issues, and enables you to automatically\ncategorize contacts.\n\nContact Lens for Amazon Connect provides both real-time and post-call analytics\nof customer-agent conversations. For more information, see [Analyze conversations using Contact\nLens](https://docs.aws.amazon.com/connect/latest/adminguide/analyze-conversations.html)\nin the *Amazon Connect Administrator Guide*.","ref":"AWS.ConnectContactLens.html","title":"AWS.ConnectContactLens","type":"module"},{"doc":"Provides a list of analysis segments for a real-time analysis session.","ref":"AWS.ConnectContactLens.html#list_realtime_contact_analysis_segments/3","title":"AWS.ConnectContactLens.list_realtime_contact_analysis_segments/3","type":"function"},{"doc":"","ref":"AWS.ConnectContactLens.html#metadata/0","title":"AWS.ConnectContactLens.metadata/0","type":"function"},{"doc":"Amazon Connect is an easy-to-use omnichannel cloud contact center service that\nenables companies of any size to deliver superior customer service at a lower\ncost.\n\nAmazon Connect communications capabilities make it easy for companies to deliver\npersonalized interactions across communication channels, including chat.\n\nUse the Amazon Connect Participant Service to manage participants (for example,\nagents, customers, and managers listening in), and to send messages and events\nwithin a chat contact. The APIs in the service enable the following: sending\nchat messages, attachment sharing, managing a participant's connection state and\nmessage events, and retrieving chat transcripts.","ref":"AWS.ConnectParticipant.html","title":"AWS.ConnectParticipant","type":"module"},{"doc":"Allows you to confirm that the attachment has been uploaded using the pre-signed\nURL provided in StartAttachmentUpload API.\n\n`ConnectionToken` is used for invoking this API instead of `ParticipantToken`.\n\nThe Amazon Connect Participant Service APIs do not use [Signature Version 4 authentication](https://docs.aws.amazon.com/general/latest/gr/signature-version-4.html).","ref":"AWS.ConnectParticipant.html#complete_attachment_upload/3","title":"AWS.ConnectParticipant.complete_attachment_upload/3","type":"function"},{"doc":"Creates the participant's connection.\n\n`ParticipantToken` is used for invoking this API instead of `ConnectionToken`.\n\nThe participant token is valid for the lifetime of the participant – until they\nare part of a contact.\n\nThe response URL for `WEBSOCKET` Type has a connect expiry timeout of 100s.\nClients must manually connect to the returned websocket URL and subscribe to the\ndesired topic.\n\nFor chat, you need to publish the following on the established websocket\nconnection:\n\n`{\"topic\":\"aws/subscribe\",\"content\":{\"topics\":[\"aws/chat\"]}}`  Upon websocket URL expiry, as specified in the response ConnectionExpiry\nparameter, clients need to call this API again to obtain a new websocket URL and\nperform the same steps as before.\n\n**Message streaming support**: This API can also be used together with the\n[StartContactStreaming](https://docs.aws.amazon.com/connect/latest/APIReference/API_StartContactStreaming.html)\nAPI to create a participant connection for chat contacts that are not using a\nwebsocket. For more information about message streaming, [Enable real-time chat message\nstreaming](https://docs.aws.amazon.com/connect/latest/adminguide/chat-message-streaming.html)\nin the *Amazon Connect Administrator Guide*.\n\n**Feature specifications**: For information about feature specifications, such\nas the allowed number of open websocket connections per participant, see\n[Feature specifications](https://docs.aws.amazon.com/connect/latest/adminguide/amazon-connect-service-limits.html#feature-limits)\nin the *Amazon Connect Administrator Guide*.\n\nThe Amazon Connect Participant Service APIs do not use [Signature Version 4 authentication](https://docs.aws.amazon.com/general/latest/gr/signature-version-4.html).","ref":"AWS.ConnectParticipant.html#create_participant_connection/3","title":"AWS.ConnectParticipant.create_participant_connection/3","type":"function"},{"doc":"Retrieves the view for the specified view token.","ref":"AWS.ConnectParticipant.html#describe_view/4","title":"AWS.ConnectParticipant.describe_view/4","type":"function"},{"doc":"Disconnects a participant.\n\n`ConnectionToken` is used for invoking this API instead of `ParticipantToken`.\n\nThe Amazon Connect Participant Service APIs do not use [Signature Version 4 authentication](https://docs.aws.amazon.com/general/latest/gr/signature-version-4.html).","ref":"AWS.ConnectParticipant.html#disconnect_participant/3","title":"AWS.ConnectParticipant.disconnect_participant/3","type":"function"},{"doc":"Provides a pre-signed URL for download of a completed attachment.\n\nThis is an asynchronous API for use with active contacts.\n\n`ConnectionToken` is used for invoking this API instead of `ParticipantToken`.\n\nThe Amazon Connect Participant Service APIs do not use [Signature Version 4 authentication](https://docs.aws.amazon.com/general/latest/gr/signature-version-4.html).","ref":"AWS.ConnectParticipant.html#get_attachment/3","title":"AWS.ConnectParticipant.get_attachment/3","type":"function"},{"doc":"Retrieves a transcript of the session, including details about any attachments.\n\nFor information about accessing past chat contact transcripts for a persistent\nchat, see [Enable persistent chat](https://docs.aws.amazon.com/connect/latest/adminguide/chat-persistence.html).\n\n`ConnectionToken` is used for invoking this API instead of `ParticipantToken`.\n\nThe Amazon Connect Participant Service APIs do not use [Signature Version 4 authentication](https://docs.aws.amazon.com/general/latest/gr/signature-version-4.html).","ref":"AWS.ConnectParticipant.html#get_transcript/3","title":"AWS.ConnectParticipant.get_transcript/3","type":"function"},{"doc":"","ref":"AWS.ConnectParticipant.html#metadata/0","title":"AWS.ConnectParticipant.metadata/0","type":"function"},{"doc":"Sends an event.\n\n`ConnectionToken` is used for invoking this API instead of `ParticipantToken`.\n\nThe Amazon Connect Participant Service APIs do not use [Signature Version 4 authentication](https://docs.aws.amazon.com/general/latest/gr/signature-version-4.html).","ref":"AWS.ConnectParticipant.html#send_event/3","title":"AWS.ConnectParticipant.send_event/3","type":"function"},{"doc":"Sends a message.\n\n`ConnectionToken` is used for invoking this API instead of `ParticipantToken`.\n\nThe Amazon Connect Participant Service APIs do not use [Signature Version 4 authentication](https://docs.aws.amazon.com/general/latest/gr/signature-version-4.html).","ref":"AWS.ConnectParticipant.html#send_message/3","title":"AWS.ConnectParticipant.send_message/3","type":"function"},{"doc":"Provides a pre-signed Amazon S3 URL in response for uploading the file directly\nto S3.\n\n`ConnectionToken` is used for invoking this API instead of `ParticipantToken`.\n\nThe Amazon Connect Participant Service APIs do not use [Signature Version 4 authentication](https://docs.aws.amazon.com/general/latest/gr/signature-version-4.html).","ref":"AWS.ConnectParticipant.html#start_attachment_upload/3","title":"AWS.ConnectParticipant.start_attachment_upload/3","type":"function"},{"doc":"These interfaces allow you to apply the Amazon Web Services library of\npre-defined *controls* to your organizational units, programmatically.\n\nIn Amazon Web Services Control Tower, the terms \"control\" and \"guardrail\" are\nsynonyms.\n\nTo call these APIs, you'll need to know:\n\n  * the `controlIdentifier` for the control--or guardrail--you are\ntargeting.\n\n  * the ARN associated with the target organizational unit (OU), which\nwe call the `targetIdentifier`.\n\n  * the ARN associated with a resource that you wish to tag or untag.","ref":"AWS.ControlTower.html","title":"AWS.ControlTower","type":"module"},{"doc":"control:\n\nThe `controlIdentifier` is an ARN that is specified for each control. You can\nview the `controlIdentifier` in the console on the **Control details** page, as\nwell as in the documentation.\n\nThe `controlIdentifier` is unique in each Amazon Web Services Region for each\ncontrol. You can find the `controlIdentifier` for each Region and control in the\n[Tables of control metadata](https://docs.aws.amazon.com/controltower/latest/userguide/control-metadata-tables.html)\nin the *Amazon Web Services Control Tower User Guide.*\n\nA quick-reference list of control identifers for the Amazon Web Services Control\nTower legacy *Strongly recommended* and *Elective* controls is given in\n[Resource identifiers for APIs and controls](https://docs.aws.amazon.com/controltower/latest/userguide/control-identifiers.html.html)\nin the [Controls reference guide section](https://docs.aws.amazon.com/controltower/latest/userguide/control-identifiers.html)\nof the *Amazon Web Services Control Tower User Guide*. Remember that *Mandatory*\ncontrols cannot be added or removed.\n\n**ARN format:** `arn:aws:controltower:{REGION}::control/{CONTROL_NAME}`","ref":"AWS.ControlTower.html#module-to-get-the-controlidentifier-for-your-amazon-web-services-control-tower","title":"To get the `controlIdentifier` for your Amazon Web Services Control Tower - AWS.ControlTower","type":"module"},{"doc":"`arn:aws:controltower:us-west-2::control/AWS-GR_AUTOSCALING_LAUNCH_CONFIG_PUBLIC_IP_DISABLED`","ref":"AWS.ControlTower.html#module-example","title":"Example: - AWS.ControlTower","type":"module"},{"doc":"The `targetIdentifier` is the ARN for an OU.\n\nIn the Amazon Web Services Organizations console, you can find the ARN for the\nOU on the **Organizational unit details** page associated with that OU.","ref":"AWS.ControlTower.html#module-to-get-the-targetidentifier","title":"To get the `targetIdentifier`: - AWS.ControlTower","type":"module"},{"doc":"`arn:${Partition}:organizations::${MasterAccountId}:ou/o-${OrganizationId}/ou-${OrganizationalUnitId}`","ref":"AWS.ControlTower.html#module-ou-arn-format","title":"OU ARN format: - AWS.ControlTower","type":"module"},{"doc":"* [Control API input and output examples with CLI](https://docs.aws.amazon.com/controltower/latest/userguide/control-api-examples-short.html)\n\n  * [Enable controls with CloudFormation](https://docs.aws.amazon.com/controltower/latest/userguide/enable-controls.html)\n\n  * [Control metadata tables](https://docs.aws.amazon.com/controltower/latest/userguide/control-metadata-tables.html)\n\n  * [List of identifiers for legacy controls](https://docs.aws.amazon.com/controltower/latest/userguide/control-identifiers.html)\n\n  * [Controls reference guide](https://docs.aws.amazon.com/controltower/latest/userguide/controls.html)\n\n  * [Controls library groupings](https://docs.aws.amazon.com/controltower/latest/userguide/controls-reference.html)\n\n  * [Creating Amazon Web Services Control Tower resources with Amazon Web Services\nCloudFormation](https://docs.aws.amazon.com/controltower/latest/userguide/creating-resources-with-cloudformation.html)\n\nTo view the open source resource repository on GitHub, see\n[aws-cloudformation/aws-cloudformation-resource-providers-controltower](https://github.com/aws-cloudformation/aws-cloudformation-resource-providers-controltower)","ref":"AWS.ControlTower.html#module-details-and-examples","title":"Details and examples - AWS.ControlTower","type":"module"},{"doc":"Amazon Web Services Control Tower supports Amazon Web Services CloudTrail, a\nservice that records Amazon Web Services API calls for your Amazon Web Services\naccount and delivers log files to an Amazon S3 bucket. By using information\ncollected by CloudTrail, you can determine which requests the Amazon Web\nServices Control Tower service received, who made the request and when, and so\non. For more about Amazon Web Services Control Tower and its support for\nCloudTrail, see [Logging Amazon Web Services Control Tower Actions with Amazon\nWeb Services\nCloudTrail](https://docs.aws.amazon.com/controltower/latest/userguide/logging-using-cloudtrail.html)\nin the Amazon Web Services Control Tower User Guide. To learn more about\nCloudTrail, including how to turn it on and find your log files, see the Amazon\nWeb Services CloudTrail User Guide.","ref":"AWS.ControlTower.html#module-recording-api-requests","title":"Recording API Requests - AWS.ControlTower","type":"module"},{"doc":"Decommissions a landing zone.\n\nThis API call starts an asynchronous operation that deletes Amazon Web Services\nControl Tower resources deployed in accounts managed by Amazon Web Services\nControl Tower.","ref":"AWS.ControlTower.html#delete_landing_zone/3","title":"AWS.ControlTower.delete_landing_zone/3","type":"function"},{"doc":"Disable an `EnabledBaseline` resource on the specified Target.\n\nThis API starts an asynchronous operation to remove all resources deployed as\npart of the baseline enablement. The resource will vary depending on the enabled\nbaseline.","ref":"AWS.ControlTower.html#disable_baseline/3","title":"AWS.ControlTower.disable_baseline/3","type":"function"},{"doc":"This API call turns off a control.\n\nIt starts an asynchronous operation that deletes AWS resources on the specified\norganizational unit and the accounts it contains. The resources will vary\naccording to the control that you specify. For usage examples, see [ *the Amazon Web Services Control Tower User Guide*\n](https://docs.aws.amazon.com/controltower/latest/userguide/control-api-examples-short.html).","ref":"AWS.ControlTower.html#disable_control/3","title":"AWS.ControlTower.disable_control/3","type":"function"},{"doc":"Enable (apply) a `Baseline` to a Target.\n\nThis API starts an asynchronous operation to deploy resources specified by the\n`Baseline` to the specified Target.","ref":"AWS.ControlTower.html#enable_baseline/3","title":"AWS.ControlTower.enable_baseline/3","type":"function"},{"doc":"This API call activates a control.\n\nIt starts an asynchronous operation that creates Amazon Web Services resources\non the specified organizational unit and the accounts it contains. The resources\ncreated will vary according to the control that you specify. For usage examples,\nsee [ *the Amazon Web Services Control Tower User Guide*\n](https://docs.aws.amazon.com/controltower/latest/userguide/control-api-examples-short.html).","ref":"AWS.ControlTower.html#enable_control/3","title":"AWS.ControlTower.enable_control/3","type":"function"},{"doc":"Retrieve details about an existing `Baseline` resource by specifying its\nidentifier.","ref":"AWS.ControlTower.html#get_baseline/3","title":"AWS.ControlTower.get_baseline/3","type":"function"},{"doc":"Returns the details of an asynchronous baseline operation, as initiated by any\nof these APIs: `EnableBaseline`, `DisableBaseline`, `UpdateEnabledBaseline`,\n`ResetEnabledBaseline`.\n\nA status message is displayed in case of operation failure.","ref":"AWS.ControlTower.html#get_baseline_operation/3","title":"AWS.ControlTower.get_baseline_operation/3","type":"function"},{"doc":"Returns the status of a particular `EnableControl` or `DisableControl`\noperation.\n\nDisplays a message in case of error. Details for an operation are available for\n90 days. For usage examples, see [ *the Amazon Web Services Control Tower User Guide*\n](https://docs.aws.amazon.com/controltower/latest/userguide/control-api-examples-short.html).","ref":"AWS.ControlTower.html#get_control_operation/3","title":"AWS.ControlTower.get_control_operation/3","type":"function"},{"doc":"Retrieve details of an `EnabledBaseline` resource by specifying its identifier.","ref":"AWS.ControlTower.html#get_enabled_baseline/3","title":"AWS.ControlTower.get_enabled_baseline/3","type":"function"},{"doc":"Retrieves details about an enabled control.\n\nFor usage examples, see [ *the Amazon Web Services Control Tower User Guide*\n](https://docs.aws.amazon.com/controltower/latest/userguide/control-api-examples-short.html).","ref":"AWS.ControlTower.html#get_enabled_control/3","title":"AWS.ControlTower.get_enabled_control/3","type":"function"},{"doc":"Returns the status of the specified landing zone operation.\n\nDetails for an operation are available for 60 days.","ref":"AWS.ControlTower.html#get_landing_zone_operation/3","title":"AWS.ControlTower.get_landing_zone_operation/3","type":"function"},{"doc":"Returns a summary list of all available baselines.","ref":"AWS.ControlTower.html#list_baselines/3","title":"AWS.ControlTower.list_baselines/3","type":"function"},{"doc":"Returns a list of summaries describing `EnabledBaseline` resources.\n\nYou can filter the list by the corresponding `Baseline` or `Target` of the\n`EnabledBaseline` resources.","ref":"AWS.ControlTower.html#list_enabled_baselines/3","title":"AWS.ControlTower.list_enabled_baselines/3","type":"function"},{"doc":"Lists the controls enabled by Amazon Web Services Control Tower on the specified\norganizational unit and the accounts it contains.\n\nFor usage examples, see [ *the Amazon Web Services Control Tower User Guide*\n](https://docs.aws.amazon.com/controltower/latest/userguide/control-api-examples-short.html).","ref":"AWS.ControlTower.html#list_enabled_controls/3","title":"AWS.ControlTower.list_enabled_controls/3","type":"function"},{"doc":"Returns the landing zone ARN for the landing zone deployed in your managed\naccount.\n\nThis API also creates an ARN for existing accounts that do not yet have a\nlanding zone ARN.\n\nReturns one landing zone ARN.","ref":"AWS.ControlTower.html#list_landing_zones/3","title":"AWS.ControlTower.list_landing_zones/3","type":"function"},{"doc":"Returns a list of tags associated with the resource.\n\nFor usage examples, see [ *the Amazon Web Services Control Tower User Guide*\n](https://docs.aws.amazon.com/controltower/latest/userguide/control-api-examples-short.html).","ref":"AWS.ControlTower.html#list_tags_for_resource/3","title":"AWS.ControlTower.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.ControlTower.html#metadata/0","title":"AWS.ControlTower.metadata/0","type":"function"},{"doc":"Re-enables an `EnabledBaseline` resource.\n\nFor example, this API can re-apply the existing `Baseline` after a new member\naccount is moved to the target OU.","ref":"AWS.ControlTower.html#reset_enabled_baseline/3","title":"AWS.ControlTower.reset_enabled_baseline/3","type":"function"},{"doc":"This API call resets a landing zone.\n\nIt starts an asynchronous operation that resets the landing zone to the\nparameters specified in its original configuration.","ref":"AWS.ControlTower.html#reset_landing_zone/3","title":"AWS.ControlTower.reset_landing_zone/3","type":"function"},{"doc":"Applies tags to a resource.\n\nFor usage examples, see [ *the Amazon Web Services Control Tower User Guide*\n](https://docs.aws.amazon.com/controltower/latest/userguide/control-api-examples-short.html).","ref":"AWS.ControlTower.html#tag_resource/4","title":"AWS.ControlTower.tag_resource/4","type":"function"},{"doc":"Removes tags from a resource.\n\nFor usage examples, see [ *the Amazon Web Services Control Tower User Guide*\n](https://docs.aws.amazon.com/controltower/latest/userguide/control-api-examples-short.html).","ref":"AWS.ControlTower.html#untag_resource/4","title":"AWS.ControlTower.untag_resource/4","type":"function"},{"doc":"Updates an `EnabledBaseline` resource's applied parameters or version.","ref":"AWS.ControlTower.html#update_enabled_baseline/3","title":"AWS.ControlTower.update_enabled_baseline/3","type":"function"},{"doc":"You can use the Cost Explorer API to programmatically query your cost and usage\ndata.\n\nYou can query for aggregated data such as total monthly costs or total daily\nusage. You can also query for granular data. This might include the number of\ndaily write operations for Amazon DynamoDB database tables in your production\nenvironment.\n\nService Endpoint\n\nThe Cost Explorer API provides the following endpoint:\n\n  * `https://ce.us-east-1.amazonaws.com`\n\nFor information about the costs that are associated with the Cost Explorer API,\nsee [Amazon Web Services Cost Management Pricing](http://aws.amazon.com/aws-cost-management/pricing/).","ref":"AWS.CostExplorer.html","title":"AWS.CostExplorer","type":"module"},{"doc":"Creates a new cost anomaly detection monitor with the requested type and monitor\nspecification.","ref":"AWS.CostExplorer.html#create_anomaly_monitor/3","title":"AWS.CostExplorer.create_anomaly_monitor/3","type":"function"},{"doc":"Adds an alert subscription to a cost anomaly detection monitor.\n\nYou can use each subscription to define subscribers with email or SNS\nnotifications. Email subscribers can set an absolute or percentage threshold and\na time frequency for receiving notifications.","ref":"AWS.CostExplorer.html#create_anomaly_subscription/3","title":"AWS.CostExplorer.create_anomaly_subscription/3","type":"function"},{"doc":"Creates a new Cost Category with the requested name and rules.","ref":"AWS.CostExplorer.html#create_cost_category_definition/3","title":"AWS.CostExplorer.create_cost_category_definition/3","type":"function"},{"doc":"Deletes a cost anomaly monitor.","ref":"AWS.CostExplorer.html#delete_anomaly_monitor/3","title":"AWS.CostExplorer.delete_anomaly_monitor/3","type":"function"},{"doc":"Deletes a cost anomaly subscription.","ref":"AWS.CostExplorer.html#delete_anomaly_subscription/3","title":"AWS.CostExplorer.delete_anomaly_subscription/3","type":"function"},{"doc":"Deletes a Cost Category.\n\nExpenses from this month going forward will no longer be categorized with this\nCost Category.","ref":"AWS.CostExplorer.html#delete_cost_category_definition/3","title":"AWS.CostExplorer.delete_cost_category_definition/3","type":"function"},{"doc":"Returns the name, Amazon Resource Name (ARN), rules, definition, and effective\ndates of a Cost Category that's defined in the account.\n\nYou have the option to use `EffectiveOn` to return a Cost Category that's active\non a specific date. If there's no `EffectiveOn` specified, you see a Cost\nCategory that's effective on the current date. If Cost Category is still\neffective, `EffectiveEnd` is omitted in the response.","ref":"AWS.CostExplorer.html#describe_cost_category_definition/3","title":"AWS.CostExplorer.describe_cost_category_definition/3","type":"function"},{"doc":"Retrieves all of the cost anomalies detected on your account during the time\nperiod that's specified by the `DateInterval` object.\n\nAnomalies are available for up to 90 days.","ref":"AWS.CostExplorer.html#get_anomalies/3","title":"AWS.CostExplorer.get_anomalies/3","type":"function"},{"doc":"Retrieves the cost anomaly monitor definitions for your account.\n\nYou can filter using a list of cost anomaly monitor Amazon Resource Names\n(ARNs).","ref":"AWS.CostExplorer.html#get_anomaly_monitors/3","title":"AWS.CostExplorer.get_anomaly_monitors/3","type":"function"},{"doc":"Retrieves the cost anomaly subscription objects for your account.\n\nYou can filter using a list of cost anomaly monitor Amazon Resource Names\n(ARNs).","ref":"AWS.CostExplorer.html#get_anomaly_subscriptions/3","title":"AWS.CostExplorer.get_anomaly_subscriptions/3","type":"function"},{"doc":"Retrieves cost and usage metrics for your account.\n\nYou can specify which cost and usage-related metric that you want the request to\nreturn. For example, you can specify `BlendedCosts` or `UsageQuantity`. You can\nalso filter and group your data by various dimensions, such as `SERVICE` or\n`AZ`, in a specific time range. For a complete list of valid dimensions, see the\n[GetDimensionValues](https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_GetDimensionValues.html) operation. Management account in an organization in Organizations have access to\nall member accounts.\n\nFor information about filter limitations, see [Quotas and\nrestrictions](https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-limits.html)\nin the *Billing and Cost Management User Guide*.","ref":"AWS.CostExplorer.html#get_cost_and_usage/3","title":"AWS.CostExplorer.get_cost_and_usage/3","type":"function"},{"doc":"Retrieves cost and usage metrics with resources for your account.\n\nYou can specify which cost and usage-related metric, such as `BlendedCosts` or\n`UsageQuantity`, that you want the request to return. You can also filter and\ngroup your data by various dimensions, such as `SERVICE` or `AZ`, in a specific\ntime range. For a complete list of valid dimensions, see the\n[GetDimensionValues](https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_GetDimensionValues.html) operation. Management account in an organization in Organizations have access to\nall member accounts. This API is currently available for the Amazon Elastic\nCompute Cloud – Compute service only.\n\nThis is an opt-in only feature. You can enable this feature from the Cost\nExplorer Settings page. For information about how to access the Settings page,\nsee [Controlling Access for Cost\nExplorer](https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/ce-access.html)\nin the *Billing and Cost Management User Guide*.","ref":"AWS.CostExplorer.html#get_cost_and_usage_with_resources/3","title":"AWS.CostExplorer.get_cost_and_usage_with_resources/3","type":"function"},{"doc":"Retrieves an array of Cost Category names and values incurred cost.\n\nIf some Cost Category names and values are not associated with any cost, they\nwill not be returned by this API.","ref":"AWS.CostExplorer.html#get_cost_categories/3","title":"AWS.CostExplorer.get_cost_categories/3","type":"function"},{"doc":"Retrieves a forecast for how much Amazon Web Services predicts that you will\nspend over the forecast time period that you select, based on your past costs.","ref":"AWS.CostExplorer.html#get_cost_forecast/3","title":"AWS.CostExplorer.get_cost_forecast/3","type":"function"},{"doc":"Retrieves all available filter values for a specified filter over a period of\ntime.\n\nYou can search the dimension values for an arbitrary string.","ref":"AWS.CostExplorer.html#get_dimension_values/3","title":"AWS.CostExplorer.get_dimension_values/3","type":"function"},{"doc":"Retrieves the reservation coverage for your account, which you can use to see\nhow much of your Amazon Elastic Compute Cloud, Amazon ElastiCache, Amazon\nRelational Database Service, or Amazon Redshift usage is covered by a\nreservation.\n\nAn organization's management account can see the coverage of the associated\nmember accounts. This supports dimensions, Cost Categories, and nested\nexpressions. For any time period, you can filter data about reservation usage by\nthe following dimensions:\n\n  * AZ\n\n  * CACHE_ENGINE\n\n  * DATABASE_ENGINE\n\n  * DEPLOYMENT_OPTION\n\n  * INSTANCE_TYPE\n\n  * LINKED_ACCOUNT\n\n  * OPERATING_SYSTEM\n\n  * PLATFORM\n\n  * REGION\n\n  * SERVICE\n\n  * TAG\n\n  * TENANCY\n\nTo determine valid values for a dimension, use the `GetDimensionValues`\noperation.","ref":"AWS.CostExplorer.html#get_reservation_coverage/3","title":"AWS.CostExplorer.get_reservation_coverage/3","type":"function"},{"doc":"Gets recommendations for reservation purchases.\n\nThese recommendations might help you to reduce your costs. Reservations provide\na discounted hourly rate (up to 75%) compared to On-Demand pricing.\n\nAmazon Web Services generates your recommendations by identifying your On-Demand\nusage during a specific time period and collecting your usage into categories\nthat are eligible for a reservation. After Amazon Web Services has these\ncategories, it simulates every combination of reservations in each category of\nusage to identify the best number of each type of Reserved Instance (RI) to\npurchase to maximize your estimated savings.\n\nFor example, Amazon Web Services automatically aggregates your Amazon EC2 Linux,\nshared tenancy, and c4 family usage in the US West (Oregon) Region and\nrecommends that you buy size-flexible regional reservations to apply to the c4\nfamily usage. Amazon Web Services recommends the smallest size instance in an\ninstance family. This makes it easier to purchase a size-flexible Reserved\nInstance (RI). Amazon Web Services also shows the equal number of normalized\nunits. This way, you can purchase any instance size that you want. For this\nexample, your RI recommendation is for `c4.large` because that is the smallest\nsize instance in the c4 instance family.","ref":"AWS.CostExplorer.html#get_reservation_purchase_recommendation/3","title":"AWS.CostExplorer.get_reservation_purchase_recommendation/3","type":"function"},{"doc":"Retrieves the reservation utilization for your account.\n\nManagement account in an organization have access to member accounts. You can\nfilter data by dimensions in a time period. You can use `GetDimensionValues` to\ndetermine the possible dimension values. Currently, you can group only by\n`SUBSCRIPTION_ID`.","ref":"AWS.CostExplorer.html#get_reservation_utilization/3","title":"AWS.CostExplorer.get_reservation_utilization/3","type":"function"},{"doc":"Creates recommendations that help you save cost by identifying idle and\nunderutilized Amazon EC2 instances.\n\nRecommendations are generated to either downsize or terminate instances, along\nwith providing savings detail and metrics. For more information about\ncalculation and function, see [Optimizing Your Cost with Rightsizing Recommendations](https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/ce-rightsizing.html)\nin the *Billing and Cost Management User Guide*.","ref":"AWS.CostExplorer.html#get_rightsizing_recommendation/3","title":"AWS.CostExplorer.get_rightsizing_recommendation/3","type":"function"},{"doc":"Retrieves the details for a Savings Plan recommendation.\n\nThese details include the hourly data-points that construct the cost, coverage,\nand utilization charts.","ref":"AWS.CostExplorer.html#get_savings_plan_purchase_recommendation_details/3","title":"AWS.CostExplorer.get_savings_plan_purchase_recommendation_details/3","type":"function"},{"doc":"Retrieves the Savings Plans covered for your account.\n\nThis enables you to see how much of your cost is covered by a Savings Plan. An\norganization’s management account can see the coverage of the associated member\naccounts. This supports dimensions, Cost Categories, and nested expressions. For\nany time period, you can filter data for Savings Plans usage with the following\ndimensions:\n\n  * `LINKED_ACCOUNT`\n\n  * `REGION`\n\n  * `SERVICE`\n\n  * `INSTANCE_FAMILY`\n\nTo determine valid values for a dimension, use the `GetDimensionValues`\noperation.","ref":"AWS.CostExplorer.html#get_savings_plans_coverage/3","title":"AWS.CostExplorer.get_savings_plans_coverage/3","type":"function"},{"doc":"Retrieves the Savings Plans recommendations for your account.\n\nFirst use `StartSavingsPlansPurchaseRecommendationGeneration` to generate a new\nset of recommendations, and then use `GetSavingsPlansPurchaseRecommendation` to\nretrieve them.","ref":"AWS.CostExplorer.html#get_savings_plans_purchase_recommendation/3","title":"AWS.CostExplorer.get_savings_plans_purchase_recommendation/3","type":"function"},{"doc":"Retrieves the Savings Plans utilization for your account across date ranges with\ndaily or monthly granularity.\n\nManagement account in an organization have access to member accounts. You can\nuse `GetDimensionValues` in `SAVINGS_PLANS` to determine the possible dimension\nvalues.\n\nYou can't group by any dimension values for `GetSavingsPlansUtilization`.","ref":"AWS.CostExplorer.html#get_savings_plans_utilization/3","title":"AWS.CostExplorer.get_savings_plans_utilization/3","type":"function"},{"doc":"Retrieves attribute data along with aggregate utilization and savings data for a\ngiven time period.\n\nThis doesn't support granular or grouped data (daily/monthly) in response. You\ncan't retrieve data by dates in a single response similar to\n`GetSavingsPlanUtilization`, but you have the option to make multiple calls to\n`GetSavingsPlanUtilizationDetails` by providing individual dates. You can use\n`GetDimensionValues` in `SAVINGS_PLANS` to determine the possible dimension\nvalues.\n\n`GetSavingsPlanUtilizationDetails` internally groups data by `SavingsPlansArn`.","ref":"AWS.CostExplorer.html#get_savings_plans_utilization_details/3","title":"AWS.CostExplorer.get_savings_plans_utilization_details/3","type":"function"},{"doc":"Queries for available tag keys and tag values for a specified period.\n\nYou can search the tag values for an arbitrary string.","ref":"AWS.CostExplorer.html#get_tags/3","title":"AWS.CostExplorer.get_tags/3","type":"function"},{"doc":"Retrieves a forecast for how much Amazon Web Services predicts that you will use\nover the forecast time period that you select, based on your past usage.","ref":"AWS.CostExplorer.html#get_usage_forecast/3","title":"AWS.CostExplorer.get_usage_forecast/3","type":"function"},{"doc":"Get a list of cost allocation tags.\n\nAll inputs in the API are optional and serve as filters. By default, all cost\nallocation tags are returned.","ref":"AWS.CostExplorer.html#list_cost_allocation_tags/3","title":"AWS.CostExplorer.list_cost_allocation_tags/3","type":"function"},{"doc":"Returns the name, Amazon Resource Name (ARN), `NumberOfRules` and effective\ndates of all Cost Categories defined in the account.\n\nYou have the option to use `EffectiveOn` to return a list of Cost Categories\nthat were active on a specific date. If there is no `EffectiveOn` specified,\nyou’ll see Cost Categories that are effective on the current date. If Cost\nCategory is still effective, `EffectiveEnd` is omitted in the response.\n`ListCostCategoryDefinitions` supports pagination. The request can have a\n`MaxResults` range up to 100.","ref":"AWS.CostExplorer.html#list_cost_category_definitions/3","title":"AWS.CostExplorer.list_cost_category_definitions/3","type":"function"},{"doc":"Retrieves a list of your historical recommendation generations within the past\n30 days.","ref":"AWS.CostExplorer.html#list_savings_plans_purchase_recommendation_generation/3","title":"AWS.CostExplorer.list_savings_plans_purchase_recommendation_generation/3","type":"function"},{"doc":"Returns a list of resource tags associated with the resource specified by the\nAmazon Resource Name (ARN).","ref":"AWS.CostExplorer.html#list_tags_for_resource/3","title":"AWS.CostExplorer.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.CostExplorer.html#metadata/0","title":"AWS.CostExplorer.metadata/0","type":"function"},{"doc":"Modifies the feedback property of a given cost anomaly.","ref":"AWS.CostExplorer.html#provide_anomaly_feedback/3","title":"AWS.CostExplorer.provide_anomaly_feedback/3","type":"function"},{"doc":"Requests a Savings Plans recommendation generation.\n\nThis enables you to calculate a fresh set of Savings Plans recommendations that\ntakes your latest usage data and current Savings Plans inventory into account.\nYou can refresh Savings Plans recommendations up to three times daily for a\nconsolidated billing family.\n\n`StartSavingsPlansPurchaseRecommendationGeneration` has no request syntax\nbecause no input parameters are needed to support this operation.","ref":"AWS.CostExplorer.html#start_savings_plans_purchase_recommendation_generation/3","title":"AWS.CostExplorer.start_savings_plans_purchase_recommendation_generation/3","type":"function"},{"doc":"An API operation for adding one or more tags (key-value pairs) to a resource.\n\nYou can use the `TagResource` operation with a resource that already has tags.\nIf you specify a new tag key for the resource, this tag is appended to the list\nof tags associated with the resource. If you specify a tag key that is already\nassociated with the resource, the new tag value you specify replaces the\nprevious value for that tag.\n\nAlthough the maximum number of array members is 200, user-tag maximum is 50. The\nremaining are reserved for Amazon Web Services use.","ref":"AWS.CostExplorer.html#tag_resource/3","title":"AWS.CostExplorer.tag_resource/3","type":"function"},{"doc":"Removes one or more tags from a resource.\n\nSpecify only tag keys in your request. Don't specify the value.","ref":"AWS.CostExplorer.html#untag_resource/3","title":"AWS.CostExplorer.untag_resource/3","type":"function"},{"doc":"Updates an existing cost anomaly monitor.\n\nThe changes made are applied going forward, and doesn't change anomalies\ndetected in the past.","ref":"AWS.CostExplorer.html#update_anomaly_monitor/3","title":"AWS.CostExplorer.update_anomaly_monitor/3","type":"function"},{"doc":"Updates an existing cost anomaly subscription.\n\nSpecify the fields that you want to update. Omitted fields are unchanged.\n\nThe JSON below describes the generic construct for each type. See [Request Parameters](https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_UpdateAnomalySubscription.html#API_UpdateAnomalySubscription_RequestParameters)\nfor possible values as they apply to `AnomalySubscription`.","ref":"AWS.CostExplorer.html#update_anomaly_subscription/3","title":"AWS.CostExplorer.update_anomaly_subscription/3","type":"function"},{"doc":"Updates status for cost allocation tags in bulk, with maximum batch size of 20.\n\nIf the tag status that's updated is the same as the existing tag status, the\nrequest doesn't fail. Instead, it doesn't have any effect on the tag status (for\nexample, activating the active tag).","ref":"AWS.CostExplorer.html#update_cost_allocation_tags_status/3","title":"AWS.CostExplorer.update_cost_allocation_tags_status/3","type":"function"},{"doc":"Updates an existing Cost Category.\n\nChanges made to the Cost Category rules will be used to categorize the current\nmonth’s expenses and future expenses. This won’t change categorization for the\nprevious months.","ref":"AWS.CostExplorer.html#update_cost_category_definition/3","title":"AWS.CostExplorer.update_cost_category_definition/3","type":"function"},{"doc":"You can use the Cost Optimization Hub API to programmatically identify, filter,\naggregate, and quantify savings for your cost optimization recommendations\nacross multiple Amazon Web Services Regions and Amazon Web Services accounts in\nyour organization.\n\nThe Cost Optimization Hub API provides the following endpoint:\n\n  * https://cost-optimization-hub.us-east-1.amazonaws.com","ref":"AWS.CostOptimizationHub.html","title":"AWS.CostOptimizationHub","type":"module"},{"doc":"Returns a set of preferences for an account in order to add account-specific\npreferences into the service.\n\nThese preferences impact how the savings associated with recommendations are\npresented—estimated savings after discounts or estimated savings before\ndiscounts, for example.","ref":"AWS.CostOptimizationHub.html#get_preferences/3","title":"AWS.CostOptimizationHub.get_preferences/3","type":"function"},{"doc":"Returns both the current and recommended resource configuration and the\nestimated cost impact for a recommendation.\n\nThe `recommendationId` is only valid for up to a maximum of 24 hours as\nrecommendations are refreshed daily. To retrieve the `recommendationId`, use the\n`ListRecommendations` API.","ref":"AWS.CostOptimizationHub.html#get_recommendation/3","title":"AWS.CostOptimizationHub.get_recommendation/3","type":"function"},{"doc":"Retrieves the enrollment status for an account.\n\nIt can also return the list of accounts that are enrolled under the\norganization.","ref":"AWS.CostOptimizationHub.html#list_enrollment_statuses/3","title":"AWS.CostOptimizationHub.list_enrollment_statuses/3","type":"function"},{"doc":"Returns a concise representation of savings estimates for resources.\n\nAlso returns de-duped savings across different types of recommendations.\n\nThe following filters are not supported for this API: `recommendationIds`,\n`resourceArns`, and `resourceIds`.","ref":"AWS.CostOptimizationHub.html#list_recommendation_summaries/3","title":"AWS.CostOptimizationHub.list_recommendation_summaries/3","type":"function"},{"doc":"Returns a list of recommendations.","ref":"AWS.CostOptimizationHub.html#list_recommendations/3","title":"AWS.CostOptimizationHub.list_recommendations/3","type":"function"},{"doc":"","ref":"AWS.CostOptimizationHub.html#metadata/0","title":"AWS.CostOptimizationHub.metadata/0","type":"function"},{"doc":"Updates the enrollment (opt in and opt out) status of an account to the Cost\nOptimization Hub service.\n\nIf the account is a management account of an organization, this action can also\nbe used to enroll member accounts of the organization.\n\nYou must have the appropriate permissions to opt in to Cost Optimization Hub and\nto view its recommendations. When you opt in, Cost Optimization Hub\nautomatically creates a service-linked role in your account to access its data.","ref":"AWS.CostOptimizationHub.html#update_enrollment_status/3","title":"AWS.CostOptimizationHub.update_enrollment_status/3","type":"function"},{"doc":"Updates a set of preferences for an account in order to add account-specific\npreferences into the service.\n\nThese preferences impact how the savings associated with recommendations are\npresented.","ref":"AWS.CostOptimizationHub.html#update_preferences/3","title":"AWS.CostOptimizationHub.update_preferences/3","type":"function"},{"doc":"You can use the Amazon Web Services Cost and Usage Report API to\nprogrammatically create, query, and delete Amazon Web Services Cost and Usage\nReport definitions.\n\nAmazon Web Services Cost and Usage Report track the monthly Amazon Web Services\ncosts and usage associated with your Amazon Web Services account. The report\ncontains line items for each unique combination of Amazon Web Services product,\nusage type, and operation that your Amazon Web Services account uses. You can\nconfigure the Amazon Web Services Cost and Usage Report to show only the data\nthat you want, using the Amazon Web Services Cost and Usage Report API.\n\nService Endpoint\n\nThe Amazon Web Services Cost and Usage Report API provides the following\nendpoint:\n\n  * cur.us-east-1.amazonaws.com","ref":"AWS.CostandUsageReport.html","title":"AWS.CostandUsageReport","type":"module"},{"doc":"Deletes the specified report.\n\nAny tags associated with the report are also deleted.","ref":"AWS.CostandUsageReport.html#delete_report_definition/3","title":"AWS.CostandUsageReport.delete_report_definition/3","type":"function"},{"doc":"Lists the Amazon Web Services Cost and Usage Report available to this account.","ref":"AWS.CostandUsageReport.html#describe_report_definitions/3","title":"AWS.CostandUsageReport.describe_report_definitions/3","type":"function"},{"doc":"Lists the tags associated with the specified report definition.","ref":"AWS.CostandUsageReport.html#list_tags_for_resource/3","title":"AWS.CostandUsageReport.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.CostandUsageReport.html#metadata/0","title":"AWS.CostandUsageReport.metadata/0","type":"function"},{"doc":"Allows you to programmatically update your report preferences.","ref":"AWS.CostandUsageReport.html#modify_report_definition/3","title":"AWS.CostandUsageReport.modify_report_definition/3","type":"function"},{"doc":"Creates a new report using the description that you provide.","ref":"AWS.CostandUsageReport.html#put_report_definition/3","title":"AWS.CostandUsageReport.put_report_definition/3","type":"function"},{"doc":"Associates a set of tags with a report definition.","ref":"AWS.CostandUsageReport.html#tag_resource/3","title":"AWS.CostandUsageReport.tag_resource/3","type":"function"},{"doc":"Disassociates a set of tags from a report definition.","ref":"AWS.CostandUsageReport.html#untag_resource/3","title":"AWS.CostandUsageReport.untag_resource/3","type":"function"},{"doc":"Amazon Connect Customer Profiles\n\nAmazon Connect Customer Profiles is a unified customer profile for your contact\ncenter that has pre-built connectors powered by AppFlow that make it easy to\ncombine customer information from third party applications, such as Salesforce\n(CRM), ServiceNow (ITSM), and your enterprise resource planning (ERP), with\ncontact history from your Amazon Connect contact center.\n\nIf you're new to Amazon Connect, you might find it helpful to review the [Amazon Connect Administrator\nGuide](https://docs.aws.amazon.com/connect/latest/adminguide/).","ref":"AWS.CustomerProfiles.html","title":"AWS.CustomerProfiles","type":"module"},{"doc":"Associates a new key value with a specific profile, such as a Contact Record\nContactId.\n\nA profile object can have a single unique key and any number of additional keys\nthat can be used to identify the profile that it belongs to.","ref":"AWS.CustomerProfiles.html#add_profile_key/4","title":"AWS.CustomerProfiles.add_profile_key/4","type":"function"},{"doc":"Creates a new calculated attribute definition.\n\nAfter creation, new object data ingested into Customer Profiles will be included\nin the calculated attribute, which can be retrieved for a profile using the\n[GetCalculatedAttributeForProfile](https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_GetCalculatedAttributeForProfile.html)\nAPI. Defining a calculated attribute makes it available for all profiles within\na domain. Each calculated attribute can only reference one `ObjectType` and at\nmost, two fields from that `ObjectType`.","ref":"AWS.CustomerProfiles.html#create_calculated_attribute_definition/5","title":"AWS.CustomerProfiles.create_calculated_attribute_definition/5","type":"function"},{"doc":"Creates a domain, which is a container for all customer data, such as customer\nprofile attributes, object types, profile keys, and encryption keys.\n\nYou can create multiple domains, and each domain can have multiple third-party\nintegrations.\n\nEach Amazon Connect instance can be associated with only one domain. Multiple\nAmazon Connect instances can be associated with one domain.\n\nUse this API or\n[UpdateDomain](https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_UpdateDomain.html) to enable [identity\nresolution](https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_GetMatches.html):\nset `Matching` to true.\n\nTo prevent cross-service impersonation when you call this API, see\n[Cross-service confused deputy prevention](https://docs.aws.amazon.com/connect/latest/adminguide/cross-service-confused-deputy-prevention.html)\nfor sample policies that you should apply.","ref":"AWS.CustomerProfiles.html#create_domain/4","title":"AWS.CustomerProfiles.create_domain/4","type":"function"},{"doc":"Creates an event stream, which is a subscription to real-time events, such as\nwhen profiles are created and updated through Amazon Connect Customer Profiles.\n\nEach event stream can be associated with only one Kinesis Data Stream\ndestination in the same region and Amazon Web Services account as the customer\nprofiles domain","ref":"AWS.CustomerProfiles.html#create_event_stream/5","title":"AWS.CustomerProfiles.create_event_stream/5","type":"function"},{"doc":"Creates an integration workflow.\n\nAn integration workflow is an async process which ingests historic data and sets\nup an integration for ongoing updates. The supported Amazon AppFlow sources are\nSalesforce, ServiceNow, and Marketo.","ref":"AWS.CustomerProfiles.html#create_integration_workflow/4","title":"AWS.CustomerProfiles.create_integration_workflow/4","type":"function"},{"doc":"Creates a standard profile.\n\nA standard profile represents the following attributes for a customer profile in\na domain.","ref":"AWS.CustomerProfiles.html#create_profile/4","title":"AWS.CustomerProfiles.create_profile/4","type":"function"},{"doc":"Deletes an existing calculated attribute definition.\n\nNote that deleting a default calculated attribute is possible, however once\ndeleted, you will be unable to undo that action and will need to recreate it on\nyour own using the CreateCalculatedAttributeDefinition API if you want it back.","ref":"AWS.CustomerProfiles.html#delete_calculated_attribute_definition/5","title":"AWS.CustomerProfiles.delete_calculated_attribute_definition/5","type":"function"},{"doc":"Deletes a specific domain and all of its customer data, such as customer profile\nattributes and their related objects.","ref":"AWS.CustomerProfiles.html#delete_domain/4","title":"AWS.CustomerProfiles.delete_domain/4","type":"function"},{"doc":"Disables and deletes the specified event stream.","ref":"AWS.CustomerProfiles.html#delete_event_stream/5","title":"AWS.CustomerProfiles.delete_event_stream/5","type":"function"},{"doc":"Removes an integration from a specific domain.","ref":"AWS.CustomerProfiles.html#delete_integration/4","title":"AWS.CustomerProfiles.delete_integration/4","type":"function"},{"doc":"Deletes the standard customer profile and all data pertaining to the profile.","ref":"AWS.CustomerProfiles.html#delete_profile/4","title":"AWS.CustomerProfiles.delete_profile/4","type":"function"},{"doc":"Removes a searchable key from a customer profile.","ref":"AWS.CustomerProfiles.html#delete_profile_key/4","title":"AWS.CustomerProfiles.delete_profile_key/4","type":"function"},{"doc":"Removes an object associated with a profile of a given ProfileObjectType.","ref":"AWS.CustomerProfiles.html#delete_profile_object/4","title":"AWS.CustomerProfiles.delete_profile_object/4","type":"function"},{"doc":"Removes a ProfileObjectType from a specific domain as well as removes all the\nProfileObjects of that type.\n\nIt also disables integrations from this specific ProfileObjectType. In addition,\nit scrubs all of the fields of the standard profile that were populated from\nthis ProfileObjectType.","ref":"AWS.CustomerProfiles.html#delete_profile_object_type/5","title":"AWS.CustomerProfiles.delete_profile_object_type/5","type":"function"},{"doc":"Deletes the specified workflow and all its corresponding resources.\n\nThis is an async process.","ref":"AWS.CustomerProfiles.html#delete_workflow/5","title":"AWS.CustomerProfiles.delete_workflow/5","type":"function"},{"doc":"The process of detecting profile object type mapping by using given objects.","ref":"AWS.CustomerProfiles.html#detect_profile_object_type/4","title":"AWS.CustomerProfiles.detect_profile_object_type/4","type":"function"},{"doc":"Tests the auto-merging settings of your Identity Resolution Job without merging\nyour data.\n\nIt randomly selects a sample of matching groups from the existing matching\nresults, and applies the automerging settings that you provided. You can then\nview the number of profiles in the sample, the number of matches, and the number\nof profiles identified to be merged. This enables you to evaluate the accuracy\nof the attributes in your matching list.\n\nYou can't view which profiles are matched and would be merged.\n\nWe strongly recommend you use this API to do a dry run of the automerging\nprocess before running the Identity Resolution Job. Include **at least** two\nmatching attributes. If your matching list includes too few attributes (such as\nonly `FirstName` or only `LastName`), there may be a large number of matches.\nThis increases the chances of erroneous merges.","ref":"AWS.CustomerProfiles.html#get_auto_merging_preview/4","title":"AWS.CustomerProfiles.get_auto_merging_preview/4","type":"function"},{"doc":"Provides more information on a calculated attribute definition for Customer\nProfiles.","ref":"AWS.CustomerProfiles.html#get_calculated_attribute_definition/4","title":"AWS.CustomerProfiles.get_calculated_attribute_definition/4","type":"function"},{"doc":"Retrieve a calculated attribute for a customer profile.","ref":"AWS.CustomerProfiles.html#get_calculated_attribute_for_profile/5","title":"AWS.CustomerProfiles.get_calculated_attribute_for_profile/5","type":"function"},{"doc":"Returns information about a specific domain.","ref":"AWS.CustomerProfiles.html#get_domain/3","title":"AWS.CustomerProfiles.get_domain/3","type":"function"},{"doc":"Returns information about the specified event stream in a specific domain.","ref":"AWS.CustomerProfiles.html#get_event_stream/4","title":"AWS.CustomerProfiles.get_event_stream/4","type":"function"},{"doc":"Returns information about an Identity Resolution Job in a specific domain.\n\nIdentity Resolution Jobs are set up using the Amazon Connect admin console. For\nmore information, see [Use Identity Resolution to consolidate similar profiles](https://docs.aws.amazon.com/connect/latest/adminguide/use-identity-resolution.html).","ref":"AWS.CustomerProfiles.html#get_identity_resolution_job/4","title":"AWS.CustomerProfiles.get_identity_resolution_job/4","type":"function"},{"doc":"Returns an integration for a domain.","ref":"AWS.CustomerProfiles.html#get_integration/4","title":"AWS.CustomerProfiles.get_integration/4","type":"function"},{"doc":"Before calling this API, use\n[CreateDomain](https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_CreateDomain.html) or\n[UpdateDomain](https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_UpdateDomain.html)\nto enable identity resolution: set `Matching` to true.\n\nGetMatches returns potentially matching profiles, based on the results of the\nlatest run of a machine learning process.\n\nThe process of matching duplicate profiles. If `Matching` = `true`, Amazon\nConnect Customer Profiles starts a weekly batch process called Identity\nResolution Job. If you do not specify a date and time for Identity Resolution\nJob to run, by default it runs every Saturday at 12AM UTC to detect duplicate\nprofiles in your domains.\n\nAfter the Identity Resolution Job completes, use the\n[GetMatches](https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_GetMatches.html)\nAPI to return and review the results. Or, if you have configured\n`ExportingConfig` in the `MatchingRequest`, you can download the results from\nS3.\n\nAmazon Connect uses the following profile attributes to identify matches:\n\n  * PhoneNumber\n\n  * HomePhoneNumber\n\n  * BusinessPhoneNumber\n\n  * MobilePhoneNumber\n\n  * EmailAddress\n\n  * PersonalEmailAddress\n\n  * BusinessEmailAddress\n\n  * FullName\n\nFor example, two or more profiles—with spelling mistakes such as","ref":"AWS.CustomerProfiles.html#get_matches/5","title":"AWS.CustomerProfiles.get_matches/5","type":"function"},{"doc":"and **Jhn Doe**, or different casing email addresses such as\n**JOHN_DOE@ANYCOMPANY.COM** and **johndoe@anycompany.com**, or different phone\nnumber formats such as **555-010-0000** and **+1-555-010-0000**—can be detected\nas belonging to the same customer **John Doe** and merged into a unified\nprofile.","ref":"AWS.CustomerProfiles.html#get_matches/5-john-doe","title":"John Doe - AWS.CustomerProfiles.get_matches/5","type":"function"},{"doc":"Returns the object types for a specific domain.","ref":"AWS.CustomerProfiles.html#get_profile_object_type/4","title":"AWS.CustomerProfiles.get_profile_object_type/4","type":"function"},{"doc":"Returns the template information for a specific object type.\n\nA template is a predefined ProfileObjectType, such as “Salesforce-Account” or\n“Salesforce-Contact.” When a user sends a ProfileObject, using the\nPutProfileObject API, with an ObjectTypeName that matches one of the\nTemplateIds, it uses the mappings from the template.","ref":"AWS.CustomerProfiles.html#get_profile_object_type_template/3","title":"AWS.CustomerProfiles.get_profile_object_type_template/3","type":"function"},{"doc":"Returns a set of profiles that belong to the same matching group using the\n`matchId` or `profileId`.\n\nYou can also specify the type of matching that you want for finding similar\nprofiles using either `RULE_BASED_MATCHING` or `ML_BASED_MATCHING`.","ref":"AWS.CustomerProfiles.html#get_similar_profiles/4","title":"AWS.CustomerProfiles.get_similar_profiles/4","type":"function"},{"doc":"Get details of specified workflow.","ref":"AWS.CustomerProfiles.html#get_workflow/4","title":"AWS.CustomerProfiles.get_workflow/4","type":"function"},{"doc":"Get granular list of steps in workflow.","ref":"AWS.CustomerProfiles.html#get_workflow_steps/6","title":"AWS.CustomerProfiles.get_workflow_steps/6","type":"function"},{"doc":"Lists all of the integrations associated to a specific URI in the AWS account.","ref":"AWS.CustomerProfiles.html#list_account_integrations/3","title":"AWS.CustomerProfiles.list_account_integrations/3","type":"function"},{"doc":"Lists calculated attribute definitions for Customer Profiles","ref":"AWS.CustomerProfiles.html#list_calculated_attribute_definitions/5","title":"AWS.CustomerProfiles.list_calculated_attribute_definitions/5","type":"function"},{"doc":"Retrieve a list of calculated attributes for a customer profile.","ref":"AWS.CustomerProfiles.html#list_calculated_attributes_for_profile/6","title":"AWS.CustomerProfiles.list_calculated_attributes_for_profile/6","type":"function"},{"doc":"Returns a list of all the domains for an AWS account that have been created.","ref":"AWS.CustomerProfiles.html#list_domains/4","title":"AWS.CustomerProfiles.list_domains/4","type":"function"},{"doc":"Returns a list of all the event streams in a specific domain.","ref":"AWS.CustomerProfiles.html#list_event_streams/5","title":"AWS.CustomerProfiles.list_event_streams/5","type":"function"},{"doc":"Lists all of the Identity Resolution Jobs in your domain.\n\nThe response sorts the list by `JobStartTime`.","ref":"AWS.CustomerProfiles.html#list_identity_resolution_jobs/5","title":"AWS.CustomerProfiles.list_identity_resolution_jobs/5","type":"function"},{"doc":"Lists all of the integrations in your domain.","ref":"AWS.CustomerProfiles.html#list_integrations/6","title":"AWS.CustomerProfiles.list_integrations/6","type":"function"},{"doc":"Lists all of the template information for object types.","ref":"AWS.CustomerProfiles.html#list_profile_object_type_templates/4","title":"AWS.CustomerProfiles.list_profile_object_type_templates/4","type":"function"},{"doc":"Lists all of the templates available within the service.","ref":"AWS.CustomerProfiles.html#list_profile_object_types/5","title":"AWS.CustomerProfiles.list_profile_object_types/5","type":"function"},{"doc":"Returns a list of objects associated with a profile of a given\nProfileObjectType.","ref":"AWS.CustomerProfiles.html#list_profile_objects/4","title":"AWS.CustomerProfiles.list_profile_objects/4","type":"function"},{"doc":"Returns a set of `MatchIds` that belong to the given domain.","ref":"AWS.CustomerProfiles.html#list_rule_based_matches/5","title":"AWS.CustomerProfiles.list_rule_based_matches/5","type":"function"},{"doc":"Displays the tags associated with an Amazon Connect Customer Profiles resource.\n\nIn Connect Customer Profiles, domains, profile object types, and integrations\ncan be tagged.","ref":"AWS.CustomerProfiles.html#list_tags_for_resource/3","title":"AWS.CustomerProfiles.list_tags_for_resource/3","type":"function"},{"doc":"Query to list all workflows.","ref":"AWS.CustomerProfiles.html#list_workflows/4","title":"AWS.CustomerProfiles.list_workflows/4","type":"function"},{"doc":"Runs an AWS Lambda job that does the following:\n\n  1.\n\nAll the profileKeys in the `ProfileToBeMerged` will be moved to the main\nprofile.\n\n  2. All the objects in the `ProfileToBeMerged` will be moved to the\nmain profile.\n\n  3. All the `ProfileToBeMerged` will be deleted at the end.\n\n  4. All the profileKeys in the `ProfileIdsToBeMerged` will be moved\nto the main profile.\n\n  5. Standard fields are merged as follows:\n\n    1. Fields are always \"union\"-ed if there are no\nconflicts in standard fields or attributeKeys.\n\n    2. When there are conflicting fields:\n\n      1. If no `SourceProfileIds` entry is\nspecified, the main Profile value is always taken.\n\n      2. If a `SourceProfileIds` entry is\nspecified, the specified profileId is always taken, even if it is a NULL value.\n\nYou can use MergeProfiles together with\n[GetMatches](https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_GetMatches.html),\nwhich returns potentially matching profiles, or use it with the results of\nanother matching system. After profiles have been merged, they cannot be\nseparated (unmerged).","ref":"AWS.CustomerProfiles.html#merge_profiles/4","title":"AWS.CustomerProfiles.merge_profiles/4","type":"function"},{"doc":"","ref":"AWS.CustomerProfiles.html#metadata/0","title":"AWS.CustomerProfiles.metadata/0","type":"function"},{"doc":"Adds an integration between the service and a third-party service, which\nincludes Amazon AppFlow and Amazon Connect.\n\nAn integration can belong to only one domain.\n\nTo add or remove tags on an existing Integration, see [ TagResource\n](https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_TagResource.html)/[\nUntagResource](https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_UntagResource.html).","ref":"AWS.CustomerProfiles.html#put_integration/4","title":"AWS.CustomerProfiles.put_integration/4","type":"function"},{"doc":"Adds additional objects to customer profiles of a given ObjectType.\n\nWhen adding a specific profile object, like a Contact Record, an inferred\nprofile can get created if it is not mapped to an existing profile. The\nresulting profile will only have a phone number populated in the standard\nProfileObject. Any additional Contact Records with the same phone number will be\nmapped to the same inferred profile.\n\nWhen a ProfileObject is created and if a ProfileObjectType already exists for\nthe ProfileObject, it will provide data to a standard profile depending on the\nProfileObjectType definition.\n\nPutProfileObject needs an ObjectType, which can be created using\nPutProfileObjectType.","ref":"AWS.CustomerProfiles.html#put_profile_object/4","title":"AWS.CustomerProfiles.put_profile_object/4","type":"function"},{"doc":"Defines a ProfileObjectType.\n\nTo add or remove tags on an existing ObjectType, see [\nTagResource](https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_TagResource.html)/[UntagResource](https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_UntagResource.html).","ref":"AWS.CustomerProfiles.html#put_profile_object_type/5","title":"AWS.CustomerProfiles.put_profile_object_type/5","type":"function"},{"doc":"Searches for profiles within a specific domain using one or more predefined\nsearch keys (e.g., _fullName, _phone, _email, _account, etc.) and/or\ncustom-defined search keys.\n\nA search key is a data type pair that consists of a `KeyName` and `Values` list.\n\nThis operation supports searching for profiles with a minimum of 1 key-value(s)\npair and up to 5 key-value(s) pairs using either `AND` or `OR` logic.","ref":"AWS.CustomerProfiles.html#search_profiles/4","title":"AWS.CustomerProfiles.search_profiles/4","type":"function"},{"doc":"Assigns one or more tags (key-value pairs) to the specified Amazon Connect\nCustomer Profiles resource.\n\nTags can help you organize and categorize your resources. You can also use them\nto scope user permissions by granting a user permission to access or change only\nresources with certain tag values. In Connect Customer Profiles, domains,\nprofile object types, and integrations can be tagged.\n\nTags don't have any semantic meaning to AWS and are interpreted strictly as\nstrings of characters.\n\nYou can use the TagResource action with a resource that already has tags. If you\nspecify a new tag key, this tag is appended to the list of tags associated with\nthe resource. If you specify a tag key that is already associated with the\nresource, the new tag value that you specify replaces the previous value for\nthat tag.\n\nYou can associate as many as 50 tags with a resource.","ref":"AWS.CustomerProfiles.html#tag_resource/4","title":"AWS.CustomerProfiles.tag_resource/4","type":"function"},{"doc":"Removes one or more tags from the specified Amazon Connect Customer Profiles\nresource.\n\nIn Connect Customer Profiles, domains, profile object types, and integrations\ncan be tagged.","ref":"AWS.CustomerProfiles.html#untag_resource/4","title":"AWS.CustomerProfiles.untag_resource/4","type":"function"},{"doc":"Updates an existing calculated attribute definition.\n\nWhen updating the Conditions, note that increasing the date range of a\ncalculated attribute will not trigger inclusion of historical data greater than\nthe current date range.","ref":"AWS.CustomerProfiles.html#update_calculated_attribute_definition/5","title":"AWS.CustomerProfiles.update_calculated_attribute_definition/5","type":"function"},{"doc":"Updates the properties of a domain, including creating or selecting a dead\nletter queue or an encryption key.\n\nAfter a domain is created, the name can’t be changed.\n\nUse this API or\n[CreateDomain](https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_CreateDomain.html) to enable [identity\nresolution](https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_GetMatches.html):\nset `Matching` to true.\n\nTo prevent cross-service impersonation when you call this API, see\n[Cross-service confused deputy prevention](https://docs.aws.amazon.com/connect/latest/adminguide/cross-service-confused-deputy-prevention.html)\nfor sample policies that you should apply.\n\nTo add or remove tags on an existing Domain, see\n[TagResource](https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_TagResource.html)/[UntagResource](https://docs.aws.amazon.com/customerprofiles/latest/APIReference/API_UntagResource.html).","ref":"AWS.CustomerProfiles.html#update_domain/4","title":"AWS.CustomerProfiles.update_domain/4","type":"function"},{"doc":"Updates the properties of a profile.\n\nThe ProfileId is required for updating a customer profile.\n\nWhen calling the UpdateProfile API, specifying an empty string value means that\nany existing value will be removed. Not specifying a string value means that any\nvalue already there will be kept.","ref":"AWS.CustomerProfiles.html#update_profile/4","title":"AWS.CustomerProfiles.update_profile/4","type":"function"},{"doc":"DAX is a managed caching service engineered for Amazon DynamoDB.\n\nDAX dramatically speeds up database reads by caching frequently-accessed data\nfrom DynamoDB, so applications can access that data with sub-millisecond\nlatency. You can create a DAX cluster easily, using the AWS Management Console.\nWith a few simple modifications to your code, your application can begin taking\nadvantage of the DAX cluster and realize significant improvements in read\nperformance.","ref":"AWS.DAX.html","title":"AWS.DAX","type":"module"},{"doc":"Creates a DAX cluster.\n\nAll nodes in the cluster run the same DAX caching software.","ref":"AWS.DAX.html#create_cluster/3","title":"AWS.DAX.create_cluster/3","type":"function"},{"doc":"Creates a new parameter group.\n\nA parameter group is a collection of parameters that you apply to all of the\nnodes in a DAX cluster.","ref":"AWS.DAX.html#create_parameter_group/3","title":"AWS.DAX.create_parameter_group/3","type":"function"},{"doc":"Creates a new subnet group.","ref":"AWS.DAX.html#create_subnet_group/3","title":"AWS.DAX.create_subnet_group/3","type":"function"},{"doc":"Removes one or more nodes from a DAX cluster.\n\nYou cannot use `DecreaseReplicationFactor` to remove the last node in a DAX\ncluster. If you need to do this, use `DeleteCluster` instead.","ref":"AWS.DAX.html#decrease_replication_factor/3","title":"AWS.DAX.decrease_replication_factor/3","type":"function"},{"doc":"Deletes a previously provisioned DAX cluster.\n\n*DeleteCluster* deletes all associated nodes, node endpoints and the DAX cluster\nitself. When you receive a successful response from this action, DAX immediately\nbegins deleting the cluster; you cannot cancel or revert this action.","ref":"AWS.DAX.html#delete_cluster/3","title":"AWS.DAX.delete_cluster/3","type":"function"},{"doc":"Deletes the specified parameter group.\n\nYou cannot delete a parameter group if it is associated with any DAX clusters.","ref":"AWS.DAX.html#delete_parameter_group/3","title":"AWS.DAX.delete_parameter_group/3","type":"function"},{"doc":"Deletes a subnet group.\n\nYou cannot delete a subnet group if it is associated with any DAX clusters.","ref":"AWS.DAX.html#delete_subnet_group/3","title":"AWS.DAX.delete_subnet_group/3","type":"function"},{"doc":"Returns information about all provisioned DAX clusters if no cluster identifier\nis specified, or about a specific DAX cluster if a cluster identifier is\nsupplied.\n\nIf the cluster is in the CREATING state, only cluster level information will be\ndisplayed until all of the nodes are successfully provisioned.\n\nIf the cluster is in the DELETING state, only cluster level information will be\ndisplayed.\n\nIf nodes are currently being added to the DAX cluster, node endpoint information\nand creation time for the additional nodes will not be displayed until they are\ncompletely provisioned. When the DAX cluster state is *available*, the cluster\nis ready for use.\n\nIf nodes are currently being removed from the DAX cluster, no endpoint\ninformation for the removed nodes is displayed.","ref":"AWS.DAX.html#describe_clusters/3","title":"AWS.DAX.describe_clusters/3","type":"function"},{"doc":"Returns the default system parameter information for the DAX caching software.","ref":"AWS.DAX.html#describe_default_parameters/3","title":"AWS.DAX.describe_default_parameters/3","type":"function"},{"doc":"Returns events related to DAX clusters and parameter groups.\n\nYou can obtain events specific to a particular DAX cluster or parameter group by\nproviding the name as a parameter.\n\nBy default, only the events occurring within the last 24 hours are returned;\nhowever, you can retrieve up to 14 days' worth of events if necessary.","ref":"AWS.DAX.html#describe_events/3","title":"AWS.DAX.describe_events/3","type":"function"},{"doc":"Returns a list of parameter group descriptions.\n\nIf a parameter group name is specified, the list will contain only the\ndescriptions for that group.","ref":"AWS.DAX.html#describe_parameter_groups/3","title":"AWS.DAX.describe_parameter_groups/3","type":"function"},{"doc":"Returns the detailed parameter list for a particular parameter group.","ref":"AWS.DAX.html#describe_parameters/3","title":"AWS.DAX.describe_parameters/3","type":"function"},{"doc":"Returns a list of subnet group descriptions.\n\nIf a subnet group name is specified, the list will contain only the description\nof that group.","ref":"AWS.DAX.html#describe_subnet_groups/3","title":"AWS.DAX.describe_subnet_groups/3","type":"function"},{"doc":"Adds one or more nodes to a DAX cluster.","ref":"AWS.DAX.html#increase_replication_factor/3","title":"AWS.DAX.increase_replication_factor/3","type":"function"},{"doc":"List all of the tags for a DAX cluster.\n\nYou can call `ListTags` up to 10 times per second, per account.","ref":"AWS.DAX.html#list_tags/3","title":"AWS.DAX.list_tags/3","type":"function"},{"doc":"","ref":"AWS.DAX.html#metadata/0","title":"AWS.DAX.metadata/0","type":"function"},{"doc":"Reboots a single node of a DAX cluster.\n\nThe reboot action takes place as soon as possible. During the reboot, the node\nstatus is set to REBOOTING.\n\n`RebootNode` restarts the DAX engine process and does not remove the contents of\nthe cache.","ref":"AWS.DAX.html#reboot_node/3","title":"AWS.DAX.reboot_node/3","type":"function"},{"doc":"Associates a set of tags with a DAX resource.\n\nYou can call `TagResource` up to 5 times per second, per account.","ref":"AWS.DAX.html#tag_resource/3","title":"AWS.DAX.tag_resource/3","type":"function"},{"doc":"Removes the association of tags from a DAX resource.\n\nYou can call `UntagResource` up to 5 times per second, per account.","ref":"AWS.DAX.html#untag_resource/3","title":"AWS.DAX.untag_resource/3","type":"function"},{"doc":"Modifies the settings for a DAX cluster.\n\nYou can use this action to change one or more cluster configuration parameters\nby specifying the parameters and the new values.","ref":"AWS.DAX.html#update_cluster/3","title":"AWS.DAX.update_cluster/3","type":"function"},{"doc":"Modifies the parameters of a parameter group.\n\nYou can modify up to 20 parameters in a single request by submitting a list\nparameter name and value pairs.","ref":"AWS.DAX.html#update_parameter_group/3","title":"AWS.DAX.update_parameter_group/3","type":"function"},{"doc":"Modifies an existing subnet group.","ref":"AWS.DAX.html#update_subnet_group/3","title":"AWS.DAX.update_subnet_group/3","type":"function"},{"doc":"Amazon Data Lifecycle Manager\n\nWith Amazon Data Lifecycle Manager, you can manage the lifecycle of your Amazon\nWeb Services resources.\n\nYou create lifecycle policies, which are used to automate operations on the\nspecified resources.\n\nAmazon Data Lifecycle Manager supports Amazon EBS volumes and snapshots. For\ninformation about using Amazon Data Lifecycle Manager with Amazon EBS, see [\nAmazon Data Lifecycle\nManager](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/snapshot-lifecycle.html)\nin the *Amazon EC2 User Guide*.","ref":"AWS.DLM.html","title":"AWS.DLM","type":"module"},{"doc":"Creates an Amazon Data Lifecycle Manager lifecycle policy.\n\nAmazon Data Lifecycle Manager supports the following policy types:\n\n  * Custom EBS snapshot policy\n\n  * Custom EBS-backed AMI policy\n\n  * Cross-account copy event policy\n\n  * Default policy for EBS snapshots\n\n  * Default policy for EBS-backed AMIs\n\nFor more information, see [ Default policies vs custom policies](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/policy-differences.html).\n\nIf you create a default policy, you can specify the request parameters either in\nthe request body, or in the PolicyDetails request structure, but not both.","ref":"AWS.DLM.html#create_lifecycle_policy/3","title":"AWS.DLM.create_lifecycle_policy/3","type":"function"},{"doc":"Deletes the specified lifecycle policy and halts the automated operations that\nthe policy specified.\n\nFor more information about deleting a policy, see [Delete lifecycle policies](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/view-modify-delete.html#delete).","ref":"AWS.DLM.html#delete_lifecycle_policy/4","title":"AWS.DLM.delete_lifecycle_policy/4","type":"function"},{"doc":"Gets summary information about all or the specified data lifecycle policies.\n\nTo get complete information about a policy, use\n[GetLifecyclePolicy](https://docs.aws.amazon.com/dlm/latest/APIReference/API_GetLifecyclePolicy.html).","ref":"AWS.DLM.html#get_lifecycle_policies/8","title":"AWS.DLM.get_lifecycle_policies/8","type":"function"},{"doc":"Gets detailed information about the specified lifecycle policy.","ref":"AWS.DLM.html#get_lifecycle_policy/3","title":"AWS.DLM.get_lifecycle_policy/3","type":"function"},{"doc":"Lists the tags for the specified resource.","ref":"AWS.DLM.html#list_tags_for_resource/3","title":"AWS.DLM.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.DLM.html#metadata/0","title":"AWS.DLM.metadata/0","type":"function"},{"doc":"Adds the specified tags to the specified resource.","ref":"AWS.DLM.html#tag_resource/4","title":"AWS.DLM.tag_resource/4","type":"function"},{"doc":"Removes the specified tags from the specified resource.","ref":"AWS.DLM.html#untag_resource/4","title":"AWS.DLM.untag_resource/4","type":"function"},{"doc":"Updates the specified lifecycle policy.\n\nFor more information about updating a policy, see [Modify lifecycle policies](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/view-modify-delete.html#modify).","ref":"AWS.DLM.html#update_lifecycle_policy/4","title":"AWS.DLM.update_lifecycle_policy/4","type":"function"},{"doc":"Glue DataBrew is a visual, cloud-scale data-preparation service.\n\nDataBrew simplifies data preparation tasks, targeting data issues that are hard\nto spot and time-consuming to fix. DataBrew empowers users of all technical\nlevels to visualize the data and perform one-click data transformations, with no\ncoding required.","ref":"AWS.DataBrew.html","title":"AWS.DataBrew","type":"module"},{"doc":"Deletes one or more versions of a recipe at a time.\n\nThe entire request will be rejected if:\n\n  * The recipe does not exist.\n\n  * There is an invalid version identifier in the list of versions.\n\n  * The version list is empty.\n\n  * The version list size exceeds 50.\n\n  * The version list contains duplicate entries.\n\nThe request will complete successfully, but with partial failures, if:\n\n  * A version does not exist.\n\n  * A version is being used by a job.\n\n  * You specify `LATEST_WORKING`, but it's being used by a project.\n\n  * The version fails to be deleted.\n\nThe `LATEST_WORKING` version will only be deleted if the recipe has no other\nversions. If you try to delete `LATEST_WORKING` while other versions exist (or\nif they can't be deleted), then `LATEST_WORKING` will be listed as partial\nfailure in the response.","ref":"AWS.DataBrew.html#batch_delete_recipe_version/4","title":"AWS.DataBrew.batch_delete_recipe_version/4","type":"function"},{"doc":"Creates a new DataBrew dataset.","ref":"AWS.DataBrew.html#create_dataset/3","title":"AWS.DataBrew.create_dataset/3","type":"function"},{"doc":"Creates a new job to analyze a dataset and create its data profile.","ref":"AWS.DataBrew.html#create_profile_job/3","title":"AWS.DataBrew.create_profile_job/3","type":"function"},{"doc":"Creates a new DataBrew project.","ref":"AWS.DataBrew.html#create_project/3","title":"AWS.DataBrew.create_project/3","type":"function"},{"doc":"Creates a new DataBrew recipe.","ref":"AWS.DataBrew.html#create_recipe/3","title":"AWS.DataBrew.create_recipe/3","type":"function"},{"doc":"Creates a new job to transform input data, using steps defined in an existing\nGlue DataBrew recipe","ref":"AWS.DataBrew.html#create_recipe_job/3","title":"AWS.DataBrew.create_recipe_job/3","type":"function"},{"doc":"Creates a new ruleset that can be used in a profile job to validate the data\nquality of a dataset.","ref":"AWS.DataBrew.html#create_ruleset/3","title":"AWS.DataBrew.create_ruleset/3","type":"function"},{"doc":"Creates a new schedule for one or more DataBrew jobs.\n\nJobs can be run at a specific date and time, or at regular intervals.","ref":"AWS.DataBrew.html#create_schedule/3","title":"AWS.DataBrew.create_schedule/3","type":"function"},{"doc":"Deletes a dataset from DataBrew.","ref":"AWS.DataBrew.html#delete_dataset/4","title":"AWS.DataBrew.delete_dataset/4","type":"function"},{"doc":"Deletes the specified DataBrew job.","ref":"AWS.DataBrew.html#delete_job/4","title":"AWS.DataBrew.delete_job/4","type":"function"},{"doc":"Deletes an existing DataBrew project.","ref":"AWS.DataBrew.html#delete_project/4","title":"AWS.DataBrew.delete_project/4","type":"function"},{"doc":"Deletes a single version of a DataBrew recipe.","ref":"AWS.DataBrew.html#delete_recipe_version/5","title":"AWS.DataBrew.delete_recipe_version/5","type":"function"},{"doc":"Deletes a ruleset.","ref":"AWS.DataBrew.html#delete_ruleset/4","title":"AWS.DataBrew.delete_ruleset/4","type":"function"},{"doc":"Deletes the specified DataBrew schedule.","ref":"AWS.DataBrew.html#delete_schedule/4","title":"AWS.DataBrew.delete_schedule/4","type":"function"},{"doc":"Returns the definition of a specific DataBrew dataset.","ref":"AWS.DataBrew.html#describe_dataset/3","title":"AWS.DataBrew.describe_dataset/3","type":"function"},{"doc":"Returns the definition of a specific DataBrew job.","ref":"AWS.DataBrew.html#describe_job/3","title":"AWS.DataBrew.describe_job/3","type":"function"},{"doc":"Represents one run of a DataBrew job.","ref":"AWS.DataBrew.html#describe_job_run/4","title":"AWS.DataBrew.describe_job_run/4","type":"function"},{"doc":"Returns the definition of a specific DataBrew project.","ref":"AWS.DataBrew.html#describe_project/3","title":"AWS.DataBrew.describe_project/3","type":"function"},{"doc":"Returns the definition of a specific DataBrew recipe corresponding to a\nparticular version.","ref":"AWS.DataBrew.html#describe_recipe/4","title":"AWS.DataBrew.describe_recipe/4","type":"function"},{"doc":"Retrieves detailed information about the ruleset.","ref":"AWS.DataBrew.html#describe_ruleset/3","title":"AWS.DataBrew.describe_ruleset/3","type":"function"},{"doc":"Returns the definition of a specific DataBrew schedule.","ref":"AWS.DataBrew.html#describe_schedule/3","title":"AWS.DataBrew.describe_schedule/3","type":"function"},{"doc":"Lists all of the DataBrew datasets.","ref":"AWS.DataBrew.html#list_datasets/4","title":"AWS.DataBrew.list_datasets/4","type":"function"},{"doc":"Lists all of the previous runs of a particular DataBrew job.","ref":"AWS.DataBrew.html#list_job_runs/5","title":"AWS.DataBrew.list_job_runs/5","type":"function"},{"doc":"Lists all of the DataBrew jobs that are defined.","ref":"AWS.DataBrew.html#list_jobs/6","title":"AWS.DataBrew.list_jobs/6","type":"function"},{"doc":"Lists all of the DataBrew projects that are defined.","ref":"AWS.DataBrew.html#list_projects/4","title":"AWS.DataBrew.list_projects/4","type":"function"},{"doc":"Lists the versions of a particular DataBrew recipe, except for `LATEST_WORKING`.","ref":"AWS.DataBrew.html#list_recipe_versions/5","title":"AWS.DataBrew.list_recipe_versions/5","type":"function"},{"doc":"Lists all of the DataBrew recipes that are defined.","ref":"AWS.DataBrew.html#list_recipes/5","title":"AWS.DataBrew.list_recipes/5","type":"function"},{"doc":"List all rulesets available in the current account or rulesets associated with a\nspecific resource (dataset).","ref":"AWS.DataBrew.html#list_rulesets/5","title":"AWS.DataBrew.list_rulesets/5","type":"function"},{"doc":"Lists the DataBrew schedules that are defined.","ref":"AWS.DataBrew.html#list_schedules/5","title":"AWS.DataBrew.list_schedules/5","type":"function"},{"doc":"Lists all the tags for a DataBrew resource.","ref":"AWS.DataBrew.html#list_tags_for_resource/3","title":"AWS.DataBrew.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.DataBrew.html#metadata/0","title":"AWS.DataBrew.metadata/0","type":"function"},{"doc":"Publishes a new version of a DataBrew recipe.","ref":"AWS.DataBrew.html#publish_recipe/4","title":"AWS.DataBrew.publish_recipe/4","type":"function"},{"doc":"Performs a recipe step within an interactive DataBrew session that's currently\nopen.","ref":"AWS.DataBrew.html#send_project_session_action/4","title":"AWS.DataBrew.send_project_session_action/4","type":"function"},{"doc":"Runs a DataBrew job.","ref":"AWS.DataBrew.html#start_job_run/4","title":"AWS.DataBrew.start_job_run/4","type":"function"},{"doc":"Creates an interactive session, enabling you to manipulate data in a DataBrew\nproject.","ref":"AWS.DataBrew.html#start_project_session/4","title":"AWS.DataBrew.start_project_session/4","type":"function"},{"doc":"Stops a particular run of a job.","ref":"AWS.DataBrew.html#stop_job_run/5","title":"AWS.DataBrew.stop_job_run/5","type":"function"},{"doc":"Adds metadata tags to a DataBrew resource, such as a dataset, project, recipe,\njob, or schedule.","ref":"AWS.DataBrew.html#tag_resource/4","title":"AWS.DataBrew.tag_resource/4","type":"function"},{"doc":"Removes metadata tags from a DataBrew resource.","ref":"AWS.DataBrew.html#untag_resource/4","title":"AWS.DataBrew.untag_resource/4","type":"function"},{"doc":"Modifies the definition of an existing DataBrew dataset.","ref":"AWS.DataBrew.html#update_dataset/4","title":"AWS.DataBrew.update_dataset/4","type":"function"},{"doc":"Modifies the definition of an existing profile job.","ref":"AWS.DataBrew.html#update_profile_job/4","title":"AWS.DataBrew.update_profile_job/4","type":"function"},{"doc":"Modifies the definition of an existing DataBrew project.","ref":"AWS.DataBrew.html#update_project/4","title":"AWS.DataBrew.update_project/4","type":"function"},{"doc":"Modifies the definition of the `LATEST_WORKING` version of a DataBrew recipe.","ref":"AWS.DataBrew.html#update_recipe/4","title":"AWS.DataBrew.update_recipe/4","type":"function"},{"doc":"Modifies the definition of an existing DataBrew recipe job.","ref":"AWS.DataBrew.html#update_recipe_job/4","title":"AWS.DataBrew.update_recipe_job/4","type":"function"},{"doc":"Updates specified ruleset.","ref":"AWS.DataBrew.html#update_ruleset/4","title":"AWS.DataBrew.update_ruleset/4","type":"function"},{"doc":"Modifies the definition of an existing DataBrew schedule.","ref":"AWS.DataBrew.html#update_schedule/4","title":"AWS.DataBrew.update_schedule/4","type":"function"},{"doc":"AWS Data Exchange is a service that makes it easy for AWS customers to exchange\ndata in the cloud.\n\nYou can use the AWS Data Exchange APIs to create, update, manage, and access\nfile-based data set in the AWS Cloud.\n\nAs a subscriber, you can view and access the data sets that you have an\nentitlement to through a subscription. You can use the APIs to download or copy\nyour entitled data sets to Amazon Simple Storage Service (Amazon S3) for use\nacross a variety of AWS analytics and machine learning services.\n\nAs a provider, you can create and manage your data sets that you would like to\npublish to a product. Being able to package and provide your data sets into\nproducts requires a few steps to determine eligibility. For more information,\nvisit the *AWS Data Exchange User Guide*.\n\nA data set is a collection of data that can be changed or updated over time.\nData sets can be updated using revisions, which represent a new version or\nincremental change to a data set. A revision contains one or more assets. An\nasset in AWS Data Exchange is a piece of data that can be stored as an Amazon S3\nobject, Redshift datashare, API Gateway API, AWS Lake Formation data permission,\nor Amazon S3 data access. The asset can be a structured data file, an image\nfile, or some other data file. Jobs are asynchronous import or export operations\nused to create or copy assets.","ref":"AWS.DataExchange.html","title":"AWS.DataExchange","type":"module"},{"doc":"This operation cancels a job.\n\nJobs can be cancelled only when they are in the WAITING state.","ref":"AWS.DataExchange.html#cancel_job/4","title":"AWS.DataExchange.cancel_job/4","type":"function"},{"doc":"This operation creates a data set.","ref":"AWS.DataExchange.html#create_data_set/3","title":"AWS.DataExchange.create_data_set/3","type":"function"},{"doc":"This operation creates an event action.","ref":"AWS.DataExchange.html#create_event_action/3","title":"AWS.DataExchange.create_event_action/3","type":"function"},{"doc":"This operation creates a job.","ref":"AWS.DataExchange.html#create_job/3","title":"AWS.DataExchange.create_job/3","type":"function"},{"doc":"This operation creates a revision for a data set.","ref":"AWS.DataExchange.html#create_revision/4","title":"AWS.DataExchange.create_revision/4","type":"function"},{"doc":"This operation deletes an asset.","ref":"AWS.DataExchange.html#delete_asset/6","title":"AWS.DataExchange.delete_asset/6","type":"function"},{"doc":"This operation deletes a data set.","ref":"AWS.DataExchange.html#delete_data_set/4","title":"AWS.DataExchange.delete_data_set/4","type":"function"},{"doc":"This operation deletes the event action.","ref":"AWS.DataExchange.html#delete_event_action/4","title":"AWS.DataExchange.delete_event_action/4","type":"function"},{"doc":"This operation deletes a revision.","ref":"AWS.DataExchange.html#delete_revision/5","title":"AWS.DataExchange.delete_revision/5","type":"function"},{"doc":"This operation returns information about an asset.","ref":"AWS.DataExchange.html#get_asset/5","title":"AWS.DataExchange.get_asset/5","type":"function"},{"doc":"This operation returns information about a data set.","ref":"AWS.DataExchange.html#get_data_set/3","title":"AWS.DataExchange.get_data_set/3","type":"function"},{"doc":"This operation retrieves information about an event action.","ref":"AWS.DataExchange.html#get_event_action/3","title":"AWS.DataExchange.get_event_action/3","type":"function"},{"doc":"This operation returns information about a job.","ref":"AWS.DataExchange.html#get_job/3","title":"AWS.DataExchange.get_job/3","type":"function"},{"doc":"This operation returns information about a revision.","ref":"AWS.DataExchange.html#get_revision/4","title":"AWS.DataExchange.get_revision/4","type":"function"},{"doc":"This operation lists a data set's revisions sorted by CreatedAt in descending\norder.","ref":"AWS.DataExchange.html#list_data_set_revisions/5","title":"AWS.DataExchange.list_data_set_revisions/5","type":"function"},{"doc":"This operation lists your data sets.\n\nWhen listing by origin OWNED, results are sorted by CreatedAt in descending\norder. When listing by origin ENTITLED, there is no order and the maxResults\nparameter is ignored.","ref":"AWS.DataExchange.html#list_data_sets/5","title":"AWS.DataExchange.list_data_sets/5","type":"function"},{"doc":"This operation lists your event actions.","ref":"AWS.DataExchange.html#list_event_actions/5","title":"AWS.DataExchange.list_event_actions/5","type":"function"},{"doc":"This operation lists your jobs sorted by CreatedAt in descending order.","ref":"AWS.DataExchange.html#list_jobs/6","title":"AWS.DataExchange.list_jobs/6","type":"function"},{"doc":"This operation lists a revision's assets sorted alphabetically in descending\norder.","ref":"AWS.DataExchange.html#list_revision_assets/6","title":"AWS.DataExchange.list_revision_assets/6","type":"function"},{"doc":"This operation lists the tags on the resource.","ref":"AWS.DataExchange.html#list_tags_for_resource/3","title":"AWS.DataExchange.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.DataExchange.html#metadata/0","title":"AWS.DataExchange.metadata/0","type":"function"},{"doc":"This operation revokes subscribers' access to a revision.","ref":"AWS.DataExchange.html#revoke_revision/5","title":"AWS.DataExchange.revoke_revision/5","type":"function"},{"doc":"This operation invokes an API Gateway API asset.\n\nThe request is proxied to the provider’s API Gateway API.","ref":"AWS.DataExchange.html#send_api_asset/3","title":"AWS.DataExchange.send_api_asset/3","type":"function"},{"doc":"The type of event associated with the data set.","ref":"AWS.DataExchange.html#send_data_set_notification/4","title":"AWS.DataExchange.send_data_set_notification/4","type":"function"},{"doc":"This operation starts a job.","ref":"AWS.DataExchange.html#start_job/4","title":"AWS.DataExchange.start_job/4","type":"function"},{"doc":"This operation tags a resource.","ref":"AWS.DataExchange.html#tag_resource/4","title":"AWS.DataExchange.tag_resource/4","type":"function"},{"doc":"This operation removes one or more tags from a resource.","ref":"AWS.DataExchange.html#untag_resource/4","title":"AWS.DataExchange.untag_resource/4","type":"function"},{"doc":"This operation updates an asset.","ref":"AWS.DataExchange.html#update_asset/6","title":"AWS.DataExchange.update_asset/6","type":"function"},{"doc":"This operation updates a data set.","ref":"AWS.DataExchange.html#update_data_set/4","title":"AWS.DataExchange.update_data_set/4","type":"function"},{"doc":"This operation updates the event action.","ref":"AWS.DataExchange.html#update_event_action/4","title":"AWS.DataExchange.update_event_action/4","type":"function"},{"doc":"This operation updates a revision.","ref":"AWS.DataExchange.html#update_revision/5","title":"AWS.DataExchange.update_revision/5","type":"function"},{"doc":"AWS Data Pipeline configures and manages a data-driven workflow called a\npipeline.\n\nAWS Data Pipeline handles the details of scheduling and ensuring that data\ndependencies are met so that your application can focus on processing the data.\n\nAWS Data Pipeline provides a JAR implementation of a task runner called AWS Data\nPipeline Task Runner. AWS Data Pipeline Task Runner provides logic for common\ndata management scenarios, such as performing database queries and running data\nanalysis using Amazon Elastic MapReduce (Amazon EMR). You can use AWS Data\nPipeline Task Runner as your task runner, or you can write your own task runner\nto provide custom data management.\n\nAWS Data Pipeline implements two main sets of functionality. Use the first set\nto create a pipeline and define data sources, schedules, dependencies, and the\ntransforms to be performed on the data. Use the second set in your task runner\napplication to receive the next task ready for processing. The logic for\nperforming the task, such as querying the data, running data analysis, or\nconverting the data from one format to another, is contained within the task\nrunner. The task runner performs the task assigned to it by the web service,\nreporting progress to the web service as it does so. When the task is done, the\ntask runner reports the final success or failure of the task to the web service.","ref":"AWS.DataPipeline.html","title":"AWS.DataPipeline","type":"module"},{"doc":"Validates the specified pipeline and starts processing pipeline tasks.\n\nIf the pipeline does not pass validation, activation fails.\n\nIf you need to pause the pipeline to investigate an issue with a component, such\nas a data source or script, call `DeactivatePipeline`.\n\nTo activate a finished pipeline, modify the end date for the pipeline and then\nactivate it.","ref":"AWS.DataPipeline.html#activate_pipeline/3","title":"AWS.DataPipeline.activate_pipeline/3","type":"function"},{"doc":"Adds or modifies tags for the specified pipeline.","ref":"AWS.DataPipeline.html#add_tags/3","title":"AWS.DataPipeline.add_tags/3","type":"function"},{"doc":"Creates a new, empty pipeline.\n\nUse `PutPipelineDefinition` to populate the pipeline.","ref":"AWS.DataPipeline.html#create_pipeline/3","title":"AWS.DataPipeline.create_pipeline/3","type":"function"},{"doc":"Deactivates the specified running pipeline.\n\nThe pipeline is set to the `DEACTIVATING` state until the deactivation process\ncompletes.\n\nTo resume a deactivated pipeline, use `ActivatePipeline`. By default, the\npipeline resumes from the last completed execution. Optionally, you can specify\nthe date and time to resume the pipeline.","ref":"AWS.DataPipeline.html#deactivate_pipeline/3","title":"AWS.DataPipeline.deactivate_pipeline/3","type":"function"},{"doc":"Deletes a pipeline, its pipeline definition, and its run history.\n\nAWS Data Pipeline attempts to cancel instances associated with the pipeline that\nare currently being processed by task runners.\n\nDeleting a pipeline cannot be undone. You cannot query or restore a deleted\npipeline. To temporarily pause a pipeline instead of deleting it, call\n`SetStatus` with the status set to `PAUSE` on individual components. Components\nthat are paused by `SetStatus` can be resumed.","ref":"AWS.DataPipeline.html#delete_pipeline/3","title":"AWS.DataPipeline.delete_pipeline/3","type":"function"},{"doc":"Gets the object definitions for a set of objects associated with the pipeline.\n\nObject definitions are composed of a set of fields that define the properties of\nthe object.","ref":"AWS.DataPipeline.html#describe_objects/3","title":"AWS.DataPipeline.describe_objects/3","type":"function"},{"doc":"Retrieves metadata about one or more pipelines.\n\nThe information retrieved includes the name of the pipeline, the pipeline\nidentifier, its current state, and the user account that owns the pipeline.\nUsing account credentials, you can retrieve metadata about pipelines that you or\nyour IAM users have created. If you are using an IAM user account, you can\nretrieve metadata about only those pipelines for which you have read\npermissions.\n\nTo retrieve the full pipeline definition instead of metadata about the pipeline,\ncall `GetPipelineDefinition`.","ref":"AWS.DataPipeline.html#describe_pipelines/3","title":"AWS.DataPipeline.describe_pipelines/3","type":"function"},{"doc":"Task runners call `EvaluateExpression` to evaluate a string in the context of\nthe specified object.\n\nFor example, a task runner can evaluate SQL queries stored in Amazon S3.","ref":"AWS.DataPipeline.html#evaluate_expression/3","title":"AWS.DataPipeline.evaluate_expression/3","type":"function"},{"doc":"Gets the definition of the specified pipeline.\n\nYou can call `GetPipelineDefinition` to retrieve the pipeline definition that\nyou provided using `PutPipelineDefinition`.","ref":"AWS.DataPipeline.html#get_pipeline_definition/3","title":"AWS.DataPipeline.get_pipeline_definition/3","type":"function"},{"doc":"Lists the pipeline identifiers for all active pipelines that you have permission\nto access.","ref":"AWS.DataPipeline.html#list_pipelines/3","title":"AWS.DataPipeline.list_pipelines/3","type":"function"},{"doc":"","ref":"AWS.DataPipeline.html#metadata/0","title":"AWS.DataPipeline.metadata/0","type":"function"},{"doc":"Task runners call `PollForTask` to receive a task to perform from AWS Data\nPipeline.\n\nThe task runner specifies which tasks it can perform by setting a value for the\n`workerGroup` parameter. The task returned can come from any of the pipelines\nthat match the `workerGroup` value passed in by the task runner and that was\nlaunched using the IAM user credentials specified by the task runner.\n\nIf tasks are ready in the work queue, `PollForTask` returns a response\nimmediately. If no tasks are available in the queue, `PollForTask` uses\nlong-polling and holds on to a poll connection for up to a 90 seconds, during\nwhich time the first newly scheduled task is handed to the task runner. To\naccomodate this, set the socket timeout in your task runner to 90 seconds. The\ntask runner should not call `PollForTask` again on the same `workerGroup` until\nit receives a response, and this can take up to 90 seconds.","ref":"AWS.DataPipeline.html#poll_for_task/3","title":"AWS.DataPipeline.poll_for_task/3","type":"function"},{"doc":"Adds tasks, schedules, and preconditions to the specified pipeline.\n\nYou can use `PutPipelineDefinition` to populate a new pipeline.\n\n`PutPipelineDefinition` also validates the configuration as it adds it to the\npipeline. Changes to the pipeline are saved unless one of the following three\nvalidation errors exists in the pipeline.\n\n  1. An object is missing a name or identifier field.\n  2. A string or reference field is empty.\n  3. The number of objects in the pipeline exceeds the maximum allowed\nobjects.\n  4. The pipeline is in a FINISHED state.\n\nPipeline object definitions are passed to the `PutPipelineDefinition` action and\nreturned by the `GetPipelineDefinition` action.","ref":"AWS.DataPipeline.html#put_pipeline_definition/3","title":"AWS.DataPipeline.put_pipeline_definition/3","type":"function"},{"doc":"Queries the specified pipeline for the names of objects that match the specified\nset of conditions.","ref":"AWS.DataPipeline.html#query_objects/3","title":"AWS.DataPipeline.query_objects/3","type":"function"},{"doc":"Removes existing tags from the specified pipeline.","ref":"AWS.DataPipeline.html#remove_tags/3","title":"AWS.DataPipeline.remove_tags/3","type":"function"},{"doc":"Task runners call `ReportTaskProgress` when assigned a task to acknowledge that\nit has the task.\n\nIf the web service does not receive this acknowledgement within 2 minutes, it\nassigns the task in a subsequent `PollForTask` call. After this initial\nacknowledgement, the task runner only needs to report progress every 15 minutes\nto maintain its ownership of the task. You can change this reporting time from\n15 minutes by specifying a `reportProgressTimeout` field in your pipeline.\n\nIf a task runner does not report its status after 5 minutes, AWS Data Pipeline\nassumes that the task runner is unable to process the task and reassigns the\ntask in a subsequent response to `PollForTask`. Task runners should call\n`ReportTaskProgress` every 60 seconds.","ref":"AWS.DataPipeline.html#report_task_progress/3","title":"AWS.DataPipeline.report_task_progress/3","type":"function"},{"doc":"Task runners call `ReportTaskRunnerHeartbeat` every 15 minutes to indicate that\nthey are operational.\n\nIf the AWS Data Pipeline Task Runner is launched on a resource managed by AWS\nData Pipeline, the web service can use this call to detect when the task runner\napplication has failed and restart a new instance.","ref":"AWS.DataPipeline.html#report_task_runner_heartbeat/3","title":"AWS.DataPipeline.report_task_runner_heartbeat/3","type":"function"},{"doc":"Requests that the status of the specified physical or logical pipeline objects\nbe updated in the specified pipeline.\n\nThis update might not occur immediately, but is eventually consistent. The\nstatus that can be set depends on the type of object (for example, DataNode or\nActivity). You cannot perform this operation on `FINISHED` pipelines and\nattempting to do so returns `InvalidRequestException`.","ref":"AWS.DataPipeline.html#set_status/3","title":"AWS.DataPipeline.set_status/3","type":"function"},{"doc":"Task runners call `SetTaskStatus` to notify AWS Data Pipeline that a task is\ncompleted and provide information about the final status.\n\nA task runner makes this call regardless of whether the task was sucessful. A\ntask runner does not need to call `SetTaskStatus` for tasks that are canceled by\nthe web service during a call to `ReportTaskProgress`.","ref":"AWS.DataPipeline.html#set_task_status/3","title":"AWS.DataPipeline.set_task_status/3","type":"function"},{"doc":"Validates the specified pipeline definition to ensure that it is well formed and\ncan be run without error.","ref":"AWS.DataPipeline.html#validate_pipeline_definition/3","title":"AWS.DataPipeline.validate_pipeline_definition/3","type":"function"},{"doc":"DataSync\n\nDataSync is an online data movement and discovery service that simplifies data\nmigration and helps you quickly, easily, and securely transfer your file or\nobject data to, from, and between Amazon Web Services storage services.\n\nThis API interface reference includes documentation for using DataSync\nprogrammatically. For complete information, see the * [DataSync User Guide](https://docs.aws.amazon.com/datasync/latest/userguide/what-is-datasync.html)\n*.","ref":"AWS.DataSync.html","title":"AWS.DataSync","type":"module"},{"doc":"Creates an Amazon Web Services resource for an on-premises storage system that\nyou want DataSync Discovery to collect information about.","ref":"AWS.DataSync.html#add_storage_system/3","title":"AWS.DataSync.add_storage_system/3","type":"function"},{"doc":"Stops an DataSync task execution that's in progress.\n\nThe transfer of some files are abruptly interrupted. File contents that're\ntransferred to the destination might be incomplete or inconsistent with the\nsource files.\n\nHowever, if you start a new task execution using the same task and allow it to\nfinish, file content on the destination will be complete and consistent. This\napplies to other unexpected failures that interrupt a task execution. In all of\nthese cases, DataSync successfully completes the transfer when you start the\nnext task execution.","ref":"AWS.DataSync.html#cancel_task_execution/3","title":"AWS.DataSync.cancel_task_execution/3","type":"function"},{"doc":"Activates an DataSync agent that you've deployed in your storage environment.\n\nThe activation process associates the agent with your Amazon Web Services\naccount.\n\nIf you haven't deployed an agent yet, see the following topics to learn more:\n\n  * [Agent requirements](https://docs.aws.amazon.com/datasync/latest/userguide/agent-requirements.html)\n\n  * [Create an agent](https://docs.aws.amazon.com/datasync/latest/userguide/configure-agent.html)\n\nIf you're transferring between Amazon Web Services storage services, you don't\nneed a DataSync agent.","ref":"AWS.DataSync.html#create_agent/3","title":"AWS.DataSync.create_agent/3","type":"function"},{"doc":"Creates a transfer *location* for a Microsoft Azure Blob Storage container.\n\nDataSync can use this location as a transfer source or destination.\n\nBefore you begin, make sure you know [how DataSync accesses Azure Blob Storage](https://docs.aws.amazon.com/datasync/latest/userguide/creating-azure-blob-location.html#azure-blob-access)\nand works with [access tiers](https://docs.aws.amazon.com/datasync/latest/userguide/creating-azure-blob-location.html#azure-blob-access-tiers)\nand [blob types](https://docs.aws.amazon.com/datasync/latest/userguide/creating-azure-blob-location.html#blob-types).\nYou also need a [DataSync agent](https://docs.aws.amazon.com/datasync/latest/userguide/creating-azure-blob-location.html#azure-blob-creating-agent)\nthat can connect to your container.","ref":"AWS.DataSync.html#create_location_azure_blob/3","title":"AWS.DataSync.create_location_azure_blob/3","type":"function"},{"doc":"Creates a transfer *location* for an Amazon EFS file system.\n\nDataSync can use this location as a source or destination for transferring data.\n\nBefore you begin, make sure that you understand how DataSync [accesses Amazon EFS file\nsystems](https://docs.aws.amazon.com/datasync/latest/userguide/create-efs-location.html#create-efs-location-access).","ref":"AWS.DataSync.html#create_location_efs/3","title":"AWS.DataSync.create_location_efs/3","type":"function"},{"doc":"Creates a transfer *location* for an Amazon FSx for Lustre file system.\n\nDataSync can use this location as a source or destination for transferring data.\n\nBefore you begin, make sure that you understand how DataSync [accesses FSx for Lustre file\nsystems](https://docs.aws.amazon.com/datasync/latest/userguide/create-lustre-location.html#create-lustre-location-access).","ref":"AWS.DataSync.html#create_location_fsx_lustre/3","title":"AWS.DataSync.create_location_fsx_lustre/3","type":"function"},{"doc":"Creates a transfer *location* for an Amazon FSx for NetApp ONTAP file system.\n\nDataSync can use this location as a source or destination for transferring data.\n\nBefore you begin, make sure that you understand how DataSync [accesses FSx for ONTAP file\nsystems](https://docs.aws.amazon.com/datasync/latest/userguide/create-ontap-location.html#create-ontap-location-access).","ref":"AWS.DataSync.html#create_location_fsx_ontap/3","title":"AWS.DataSync.create_location_fsx_ontap/3","type":"function"},{"doc":"Creates a transfer *location* for an Amazon FSx for OpenZFS file system.\n\nDataSync can use this location as a source or destination for transferring data.\n\nBefore you begin, make sure that you understand how DataSync [accesses FSx for OpenZFS file\nsystems](https://docs.aws.amazon.com/datasync/latest/userguide/create-openzfs-location.html#create-openzfs-access).\n\nRequest parameters related to `SMB` aren't supported with the\n`CreateLocationFsxOpenZfs` operation.","ref":"AWS.DataSync.html#create_location_fsx_open_zfs/3","title":"AWS.DataSync.create_location_fsx_open_zfs/3","type":"function"},{"doc":"Creates a transfer *location* for an Amazon FSx for Windows File Server file\nsystem.\n\nDataSync can use this location as a source or destination for transferring data.\n\nBefore you begin, make sure that you understand how DataSync [accesses FSx for Windows File Server file\nsystems](https://docs.aws.amazon.com/datasync/latest/userguide/create-fsx-location.html#create-fsx-location-access).","ref":"AWS.DataSync.html#create_location_fsx_windows/3","title":"AWS.DataSync.create_location_fsx_windows/3","type":"function"},{"doc":"Creates a transfer *location* for a Hadoop Distributed File System (HDFS).\n\nDataSync can use this location as a source or destination for transferring data.\n\nBefore you begin, make sure that you understand how DataSync [accesses HDFS clusters](https://docs.aws.amazon.com/datasync/latest/userguide/create-hdfs-location.html#accessing-hdfs).","ref":"AWS.DataSync.html#create_location_hdfs/3","title":"AWS.DataSync.create_location_hdfs/3","type":"function"},{"doc":"Creates a transfer *location* for a Network File System (NFS) file server.\n\nDataSync can use this location as a source or destination for transferring data.\n\nBefore you begin, make sure that you understand how DataSync [accesses NFS file servers](https://docs.aws.amazon.com/datasync/latest/userguide/create-nfs-location.html#accessing-nfs).\n\nIf you're copying data to or from an Snowcone device, you can also use\n`CreateLocationNfs` to create your transfer location. For more information, see\n[Configuring transfers with Snowcone](https://docs.aws.amazon.com/datasync/latest/userguide/nfs-on-snowcone.html).","ref":"AWS.DataSync.html#create_location_nfs/3","title":"AWS.DataSync.create_location_nfs/3","type":"function"},{"doc":"Creates a transfer *location* for an object storage system.\n\nDataSync can use this location as a source or destination for transferring data.\n\nBefore you begin, make sure that you understand the\n[prerequisites](https://docs.aws.amazon.com/datasync/latest/userguide/create-object-location.html#create-object-location-prerequisites)\nfor DataSync to work with object storage systems.","ref":"AWS.DataSync.html#create_location_object_storage/3","title":"AWS.DataSync.create_location_object_storage/3","type":"function"},{"doc":"Creates a transfer *location* for an Amazon S3 bucket.\n\nDataSync can use this location as a source or destination for transferring data.\n\nBefore you begin, make sure that you read the following topics:\n\n   [Storage class considerations with Amazon S3 locations](https://docs.aws.amazon.com/datasync/latest/userguide/create-s3-location.html#using-storage-classes)\n\n   [Evaluating S3 request costs when using DataSync](https://docs.aws.amazon.com/datasync/latest/userguide/create-s3-location.html#create-s3-location-s3-requests)\n\nFor more information, see [Configuring transfers with Amazon S3](https://docs.aws.amazon.com/datasync/latest/userguide/create-s3-location.html).","ref":"AWS.DataSync.html#create_location_s3/3","title":"AWS.DataSync.create_location_s3/3","type":"function"},{"doc":"Creates a transfer *location* for a Server Message Block (SMB) file server.\n\nDataSync can use this location as a source or destination for transferring data.\n\nBefore you begin, make sure that you understand how DataSync [accesses SMB file servers](https://docs.aws.amazon.com/datasync/latest/userguide/create-smb-location.html#configuring-smb).","ref":"AWS.DataSync.html#create_location_smb/3","title":"AWS.DataSync.create_location_smb/3","type":"function"},{"doc":"Configures a transfer task, which defines where and how DataSync moves your\ndata.\n\nA task includes a source location, destination location, and the options for how\nand when you want to transfer your data (such as bandwidth limits, scheduling,\namong other options).\n\nIf you're planning to transfer data to or from an Amazon S3 location, review\n[how DataSync can affect your S3 request charges](https://docs.aws.amazon.com/datasync/latest/userguide/create-s3-location.html#create-s3-location-s3-requests)\nand the [DataSync pricing page](http://aws.amazon.com/datasync/pricing/) before\nyou begin.","ref":"AWS.DataSync.html#create_task/3","title":"AWS.DataSync.create_task/3","type":"function"},{"doc":"Removes an DataSync agent resource from your Amazon Web Services account.\n\nKeep in mind that this operation (which can't be undone) doesn't remove the\nagent's virtual machine (VM) or Amazon EC2 instance from your storage\nenvironment. For next steps, you can delete the VM or instance from your storage\nenvironment or reuse it to [activate a new agent](https://docs.aws.amazon.com/datasync/latest/userguide/activate-agent.html).","ref":"AWS.DataSync.html#delete_agent/3","title":"AWS.DataSync.delete_agent/3","type":"function"},{"doc":"Deletes a transfer location resource from DataSync.","ref":"AWS.DataSync.html#delete_location/3","title":"AWS.DataSync.delete_location/3","type":"function"},{"doc":"Deletes a transfer task resource from DataSync.","ref":"AWS.DataSync.html#delete_task/3","title":"AWS.DataSync.delete_task/3","type":"function"},{"doc":"Returns information about an DataSync agent, such as its name, service endpoint\ntype, and status.","ref":"AWS.DataSync.html#describe_agent/3","title":"AWS.DataSync.describe_agent/3","type":"function"},{"doc":"Returns information about a DataSync discovery job.","ref":"AWS.DataSync.html#describe_discovery_job/3","title":"AWS.DataSync.describe_discovery_job/3","type":"function"},{"doc":"Provides details about how an DataSync transfer location for Microsoft Azure\nBlob Storage is configured.","ref":"AWS.DataSync.html#describe_location_azure_blob/3","title":"AWS.DataSync.describe_location_azure_blob/3","type":"function"},{"doc":"Provides details about how an DataSync transfer location for an Amazon EFS file\nsystem is configured.","ref":"AWS.DataSync.html#describe_location_efs/3","title":"AWS.DataSync.describe_location_efs/3","type":"function"},{"doc":"Provides details about how an DataSync transfer location for an Amazon FSx for\nLustre file system is configured.","ref":"AWS.DataSync.html#describe_location_fsx_lustre/3","title":"AWS.DataSync.describe_location_fsx_lustre/3","type":"function"},{"doc":"Provides details about how an DataSync transfer location for an Amazon FSx for\nNetApp ONTAP file system is configured.\n\nIf your location uses SMB, the `DescribeLocationFsxOntap` operation doesn't\nactually return a `Password`.","ref":"AWS.DataSync.html#describe_location_fsx_ontap/3","title":"AWS.DataSync.describe_location_fsx_ontap/3","type":"function"},{"doc":"Provides details about how an DataSync transfer location for an Amazon FSx for\nOpenZFS file system is configured.\n\nResponse elements related to `SMB` aren't supported with the\n`DescribeLocationFsxOpenZfs` operation.","ref":"AWS.DataSync.html#describe_location_fsx_open_zfs/3","title":"AWS.DataSync.describe_location_fsx_open_zfs/3","type":"function"},{"doc":"Provides details about how an DataSync transfer location for an Amazon FSx for\nWindows File Server file system is configured.","ref":"AWS.DataSync.html#describe_location_fsx_windows/3","title":"AWS.DataSync.describe_location_fsx_windows/3","type":"function"},{"doc":"Provides details about how an DataSync transfer location for a Hadoop\nDistributed File System (HDFS) is configured.","ref":"AWS.DataSync.html#describe_location_hdfs/3","title":"AWS.DataSync.describe_location_hdfs/3","type":"function"},{"doc":"Provides details about how an DataSync transfer location for a Network File\nSystem (NFS) file server is configured.","ref":"AWS.DataSync.html#describe_location_nfs/3","title":"AWS.DataSync.describe_location_nfs/3","type":"function"},{"doc":"Provides details about how an DataSync transfer location for an object storage\nsystem is configured.","ref":"AWS.DataSync.html#describe_location_object_storage/3","title":"AWS.DataSync.describe_location_object_storage/3","type":"function"},{"doc":"Provides details about how an DataSync transfer location for an S3 bucket is\nconfigured.","ref":"AWS.DataSync.html#describe_location_s3/3","title":"AWS.DataSync.describe_location_s3/3","type":"function"},{"doc":"Provides details about how an DataSync transfer location for a Server Message\nBlock (SMB) file server is configured.","ref":"AWS.DataSync.html#describe_location_smb/3","title":"AWS.DataSync.describe_location_smb/3","type":"function"},{"doc":"Returns information about an on-premises storage system that you're using with\nDataSync Discovery.","ref":"AWS.DataSync.html#describe_storage_system/3","title":"AWS.DataSync.describe_storage_system/3","type":"function"},{"doc":"Returns information, including performance data and capacity usage, which\nDataSync Discovery collects about a specific resource in your-premises storage\nsystem.","ref":"AWS.DataSync.html#describe_storage_system_resource_metrics/3","title":"AWS.DataSync.describe_storage_system_resource_metrics/3","type":"function"},{"doc":"Returns information that DataSync Discovery collects about resources in your\non-premises storage system.","ref":"AWS.DataSync.html#describe_storage_system_resources/3","title":"AWS.DataSync.describe_storage_system_resources/3","type":"function"},{"doc":"Provides information about an DataSync transfer task.","ref":"AWS.DataSync.html#describe_task/3","title":"AWS.DataSync.describe_task/3","type":"function"},{"doc":"Provides information about an execution of your DataSync task.\n\nYou can use this operation to help monitor the progress of an ongoing transfer\nor check the results of the transfer.","ref":"AWS.DataSync.html#describe_task_execution/3","title":"AWS.DataSync.describe_task_execution/3","type":"function"},{"doc":"Creates recommendations about where to migrate your data to in Amazon Web\nServices.\n\nRecommendations are generated based on information that DataSync Discovery\ncollects about your on-premises storage system's resources. For more\ninformation, see [Recommendations provided by DataSync Discovery](https://docs.aws.amazon.com/datasync/latest/userguide/discovery-understand-recommendations.html).\n\nOnce generated, you can view your recommendations by using the\n[DescribeStorageSystemResources](https://docs.aws.amazon.com/datasync/latest/userguide/API_DescribeStorageSystemResources.html)\noperation.","ref":"AWS.DataSync.html#generate_recommendations/3","title":"AWS.DataSync.generate_recommendations/3","type":"function"},{"doc":"Returns a list of DataSync agents that belong to an Amazon Web Services account\nin the Amazon Web Services Region specified in the request.\n\nWith pagination, you can reduce the number of agents returned in a response. If\nyou get a truncated list of agents in a response, the response contains a marker\nthat you can specify in your next request to fetch the next page of agents.\n\n`ListAgents` is eventually consistent. This means the result of running the\noperation might not reflect that you just created or deleted an agent. For\nexample, if you create an agent with\n[CreateAgent](https://docs.aws.amazon.com/datasync/latest/userguide/API_CreateAgent.html) and then immediately run `ListAgents`, that agent might not show up in the list\nright away. In situations like this, you can always confirm whether an agent has\nbeen created (or deleted) by using\n[DescribeAgent](https://docs.aws.amazon.com/datasync/latest/userguide/API_DescribeAgent.html).","ref":"AWS.DataSync.html#list_agents/3","title":"AWS.DataSync.list_agents/3","type":"function"},{"doc":"Provides a list of the existing discovery jobs in the Amazon Web Services Region\nand Amazon Web Services account where you're using DataSync Discovery.","ref":"AWS.DataSync.html#list_discovery_jobs/3","title":"AWS.DataSync.list_discovery_jobs/3","type":"function"},{"doc":"Returns a list of source and destination locations.\n\nIf you have more locations than are returned in a response (that is, the\nresponse returns only a truncated list of your agents), the response contains a\ntoken that you can specify in your next request to fetch the next page of\nlocations.","ref":"AWS.DataSync.html#list_locations/3","title":"AWS.DataSync.list_locations/3","type":"function"},{"doc":"Lists the on-premises storage systems that you're using with DataSync Discovery.","ref":"AWS.DataSync.html#list_storage_systems/3","title":"AWS.DataSync.list_storage_systems/3","type":"function"},{"doc":"Returns all the tags associated with an Amazon Web Services resource.","ref":"AWS.DataSync.html#list_tags_for_resource/3","title":"AWS.DataSync.list_tags_for_resource/3","type":"function"},{"doc":"Returns a list of executions for an DataSync transfer task.","ref":"AWS.DataSync.html#list_task_executions/3","title":"AWS.DataSync.list_task_executions/3","type":"function"},{"doc":"Returns a list of the DataSync tasks you created.","ref":"AWS.DataSync.html#list_tasks/3","title":"AWS.DataSync.list_tasks/3","type":"function"},{"doc":"","ref":"AWS.DataSync.html#metadata/0","title":"AWS.DataSync.metadata/0","type":"function"},{"doc":"Permanently removes a storage system resource from DataSync Discovery, including\nthe associated discovery jobs, collected data, and recommendations.","ref":"AWS.DataSync.html#remove_storage_system/3","title":"AWS.DataSync.remove_storage_system/3","type":"function"},{"doc":"Runs a DataSync discovery job on your on-premises storage system.\n\nIf you haven't added the storage system to DataSync Discovery yet, do this first\nby using the\n[AddStorageSystem](https://docs.aws.amazon.com/datasync/latest/userguide/API_AddStorageSystem.html)\noperation.","ref":"AWS.DataSync.html#start_discovery_job/3","title":"AWS.DataSync.start_discovery_job/3","type":"function"},{"doc":"Starts an DataSync transfer task.\n\nFor each task, you can only run one task execution at a time.\n\nThere are several phases to a task execution. For more information, see [Task execution\nstatuses](https://docs.aws.amazon.com/datasync/latest/userguide/working-with-task-executions.html#understand-task-execution-statuses).\n\nIf you're planning to transfer data to or from an Amazon S3 location, review\n[how DataSync can affect your S3 request charges](https://docs.aws.amazon.com/datasync/latest/userguide/create-s3-location.html#create-s3-location-s3-requests)\nand the [DataSync pricing page](http://aws.amazon.com/datasync/pricing/) before\nyou begin.","ref":"AWS.DataSync.html#start_task_execution/3","title":"AWS.DataSync.start_task_execution/3","type":"function"},{"doc":"Stops a running DataSync discovery job.\n\nYou can stop a discovery job anytime. A job that's stopped before it's scheduled\nto end likely will provide you some information about your on-premises storage\nsystem resources. To get recommendations for a stopped job, you must use the\n[GenerateRecommendations](https://docs.aws.amazon.com/datasync/latest/userguide/API_GenerateRecommendations.html)\noperation.","ref":"AWS.DataSync.html#stop_discovery_job/3","title":"AWS.DataSync.stop_discovery_job/3","type":"function"},{"doc":"Applies a *tag* to an Amazon Web Services resource.\n\nTags are key-value pairs that can help you manage, filter, and search for your\nresources.\n\nThese include DataSync resources, such as locations, tasks, and task executions.","ref":"AWS.DataSync.html#tag_resource/3","title":"AWS.DataSync.tag_resource/3","type":"function"},{"doc":"Removes tags from an Amazon Web Services resource.","ref":"AWS.DataSync.html#untag_resource/3","title":"AWS.DataSync.untag_resource/3","type":"function"},{"doc":"Updates the name of an DataSync agent.","ref":"AWS.DataSync.html#update_agent/3","title":"AWS.DataSync.update_agent/3","type":"function"},{"doc":"Edits a DataSync discovery job configuration.","ref":"AWS.DataSync.html#update_discovery_job/3","title":"AWS.DataSync.update_discovery_job/3","type":"function"},{"doc":"Modifies some configurations of the Microsoft Azure Blob Storage transfer\nlocation that you're using with DataSync.","ref":"AWS.DataSync.html#update_location_azure_blob/3","title":"AWS.DataSync.update_location_azure_blob/3","type":"function"},{"doc":"Updates some parameters of a previously created location for a Hadoop\nDistributed File System cluster.","ref":"AWS.DataSync.html#update_location_hdfs/3","title":"AWS.DataSync.update_location_hdfs/3","type":"function"},{"doc":"Modifies some configurations of the Network File System (NFS) transfer location\nthat you're using with DataSync.\n\nFor more information, see [Configuring transfers to or from an NFS file server](https://docs.aws.amazon.com/datasync/latest/userguide/create-nfs-location.html).","ref":"AWS.DataSync.html#update_location_nfs/3","title":"AWS.DataSync.update_location_nfs/3","type":"function"},{"doc":"Updates some parameters of an existing object storage location that DataSync\naccesses for a transfer.\n\nFor information about creating a self-managed object storage location, see\n[Creating a location for object storage](https://docs.aws.amazon.com/datasync/latest/userguide/create-object-location.html).","ref":"AWS.DataSync.html#update_location_object_storage/3","title":"AWS.DataSync.update_location_object_storage/3","type":"function"},{"doc":"Updates some of the parameters of a Server Message Block (SMB) file server\nlocation that you can use for DataSync transfers.","ref":"AWS.DataSync.html#update_location_smb/3","title":"AWS.DataSync.update_location_smb/3","type":"function"},{"doc":"Modifies some configurations of an on-premises storage system resource that\nyou're using with DataSync Discovery.","ref":"AWS.DataSync.html#update_storage_system/3","title":"AWS.DataSync.update_storage_system/3","type":"function"},{"doc":"Updates the configuration of an DataSync transfer task.","ref":"AWS.DataSync.html#update_task/3","title":"AWS.DataSync.update_task/3","type":"function"},{"doc":"Updates the configuration of a running DataSync task execution.\n\nCurrently, the only `Option` that you can modify with `UpdateTaskExecution` is `\n[BytesPerSecond](https://docs.aws.amazon.com/datasync/latest/userguide/API_Options.html#DataSync-Type-Options-BytesPerSecond)\n`, which throttles bandwidth for a running or queued task execution.","ref":"AWS.DataSync.html#update_task_execution/3","title":"AWS.DataSync.update_task_execution/3","type":"function"},{"doc":"Amazon DataZone is a data management service that enables you to catalog,\ndiscover, govern, share, and analyze your data.\n\nWith Amazon DataZone, you can share and access your data across accounts and\nsupported regions. Amazon DataZone simplifies your experience across Amazon Web\nServices services, including, but not limited to, Amazon Redshift, Amazon\nAthena, Amazon Web Services Glue, and Amazon Web Services Lake Formation.","ref":"AWS.DataZone.html","title":"AWS.DataZone","type":"module"},{"doc":"Accepts automatically generated business-friendly metadata for your Amazon\nDataZone assets.","ref":"AWS.DataZone.html#accept_predictions/5","title":"AWS.DataZone.accept_predictions/5","type":"function"},{"doc":"Accepts a subscription request to a specific asset.","ref":"AWS.DataZone.html#accept_subscription_request/5","title":"AWS.DataZone.accept_subscription_request/5","type":"function"},{"doc":"Cancels the subscription to the specified asset.","ref":"AWS.DataZone.html#cancel_subscription/5","title":"AWS.DataZone.cancel_subscription/5","type":"function"},{"doc":"Creates an asset in Amazon DataZone catalog.","ref":"AWS.DataZone.html#create_asset/4","title":"AWS.DataZone.create_asset/4","type":"function"},{"doc":"Creates a revision of the asset.","ref":"AWS.DataZone.html#create_asset_revision/5","title":"AWS.DataZone.create_asset_revision/5","type":"function"},{"doc":"Creates a custom asset type.","ref":"AWS.DataZone.html#create_asset_type/4","title":"AWS.DataZone.create_asset_type/4","type":"function"},{"doc":"Creates an Amazon DataZone data source.","ref":"AWS.DataZone.html#create_data_source/4","title":"AWS.DataZone.create_data_source/4","type":"function"},{"doc":"Creates an Amazon DataZone domain.","ref":"AWS.DataZone.html#create_domain/3","title":"AWS.DataZone.create_domain/3","type":"function"},{"doc":"Create an Amazon DataZone environment.","ref":"AWS.DataZone.html#create_environment/4","title":"AWS.DataZone.create_environment/4","type":"function"},{"doc":"Creates an Amazon DataZone environment profile.","ref":"AWS.DataZone.html#create_environment_profile/4","title":"AWS.DataZone.create_environment_profile/4","type":"function"},{"doc":"Creates a metadata form type.","ref":"AWS.DataZone.html#create_form_type/4","title":"AWS.DataZone.create_form_type/4","type":"function"},{"doc":"Creates an Amazon DataZone business glossary.","ref":"AWS.DataZone.html#create_glossary/4","title":"AWS.DataZone.create_glossary/4","type":"function"},{"doc":"Creates a business glossary term.","ref":"AWS.DataZone.html#create_glossary_term/4","title":"AWS.DataZone.create_glossary_term/4","type":"function"},{"doc":"Creates a group profile in Amazon DataZone.","ref":"AWS.DataZone.html#create_group_profile/4","title":"AWS.DataZone.create_group_profile/4","type":"function"},{"doc":"","ref":"AWS.DataZone.html#create_listing_change_set/4","title":"AWS.DataZone.create_listing_change_set/4","type":"function"},{"doc":"Creates an Amazon DataZone project.","ref":"AWS.DataZone.html#create_project/4","title":"AWS.DataZone.create_project/4","type":"function"},{"doc":"Creates a project membership in Amazon DataZone.","ref":"AWS.DataZone.html#create_project_membership/5","title":"AWS.DataZone.create_project_membership/5","type":"function"},{"doc":"Creates a subsscription grant in Amazon DataZone.","ref":"AWS.DataZone.html#create_subscription_grant/4","title":"AWS.DataZone.create_subscription_grant/4","type":"function"},{"doc":"Creates a subscription request in Amazon DataZone.","ref":"AWS.DataZone.html#create_subscription_request/4","title":"AWS.DataZone.create_subscription_request/4","type":"function"},{"doc":"Creates a subscription target in Amazon DataZone.","ref":"AWS.DataZone.html#create_subscription_target/5","title":"AWS.DataZone.create_subscription_target/5","type":"function"},{"doc":"Creates a user profile in Amazon DataZone.","ref":"AWS.DataZone.html#create_user_profile/4","title":"AWS.DataZone.create_user_profile/4","type":"function"},{"doc":"Delets an asset in Amazon DataZone.","ref":"AWS.DataZone.html#delete_asset/5","title":"AWS.DataZone.delete_asset/5","type":"function"},{"doc":"Deletes an asset type in Amazon DataZone.","ref":"AWS.DataZone.html#delete_asset_type/5","title":"AWS.DataZone.delete_asset_type/5","type":"function"},{"doc":"Deletes a data source in Amazon DataZone.","ref":"AWS.DataZone.html#delete_data_source/5","title":"AWS.DataZone.delete_data_source/5","type":"function"},{"doc":"Deletes a Amazon DataZone domain.","ref":"AWS.DataZone.html#delete_domain/4","title":"AWS.DataZone.delete_domain/4","type":"function"},{"doc":"Deletes an environment in Amazon DataZone.","ref":"AWS.DataZone.html#delete_environment/5","title":"AWS.DataZone.delete_environment/5","type":"function"},{"doc":"Deletes the blueprint configuration in Amazon DataZone.","ref":"AWS.DataZone.html#delete_environment_blueprint_configuration/5","title":"AWS.DataZone.delete_environment_blueprint_configuration/5","type":"function"},{"doc":"Deletes an environment profile in Amazon DataZone.","ref":"AWS.DataZone.html#delete_environment_profile/5","title":"AWS.DataZone.delete_environment_profile/5","type":"function"},{"doc":"Delets and metadata form type in Amazon DataZone.","ref":"AWS.DataZone.html#delete_form_type/5","title":"AWS.DataZone.delete_form_type/5","type":"function"},{"doc":"Deletes a business glossary in Amazon DataZone.","ref":"AWS.DataZone.html#delete_glossary/5","title":"AWS.DataZone.delete_glossary/5","type":"function"},{"doc":"Deletes a business glossary term in Amazon DataZone.","ref":"AWS.DataZone.html#delete_glossary_term/5","title":"AWS.DataZone.delete_glossary_term/5","type":"function"},{"doc":"","ref":"AWS.DataZone.html#delete_listing/5","title":"AWS.DataZone.delete_listing/5","type":"function"},{"doc":"Deletes a project in Amazon DataZone.","ref":"AWS.DataZone.html#delete_project/5","title":"AWS.DataZone.delete_project/5","type":"function"},{"doc":"Deletes project membership in Amazon DataZone.","ref":"AWS.DataZone.html#delete_project_membership/5","title":"AWS.DataZone.delete_project_membership/5","type":"function"},{"doc":"Deletes and subscription grant in Amazon DataZone.","ref":"AWS.DataZone.html#delete_subscription_grant/5","title":"AWS.DataZone.delete_subscription_grant/5","type":"function"},{"doc":"Deletes a subscription request in Amazon DataZone.","ref":"AWS.DataZone.html#delete_subscription_request/5","title":"AWS.DataZone.delete_subscription_request/5","type":"function"},{"doc":"Deletes a subscription target in Amazon DataZone.","ref":"AWS.DataZone.html#delete_subscription_target/6","title":"AWS.DataZone.delete_subscription_target/6","type":"function"},{"doc":"Gets an Amazon DataZone asset.","ref":"AWS.DataZone.html#get_asset/5","title":"AWS.DataZone.get_asset/5","type":"function"},{"doc":"Gets an Amazon DataZone asset type.","ref":"AWS.DataZone.html#get_asset_type/5","title":"AWS.DataZone.get_asset_type/5","type":"function"},{"doc":"Gets an Amazon DataZone data source.","ref":"AWS.DataZone.html#get_data_source/4","title":"AWS.DataZone.get_data_source/4","type":"function"},{"doc":"Gets an Amazon DataZone data source run.","ref":"AWS.DataZone.html#get_data_source_run/4","title":"AWS.DataZone.get_data_source_run/4","type":"function"},{"doc":"Gets an Amazon DataZone domain.","ref":"AWS.DataZone.html#get_domain/3","title":"AWS.DataZone.get_domain/3","type":"function"},{"doc":"Gets an Amazon DataZone environment.","ref":"AWS.DataZone.html#get_environment/4","title":"AWS.DataZone.get_environment/4","type":"function"},{"doc":"Gets an Amazon DataZone blueprint.","ref":"AWS.DataZone.html#get_environment_blueprint/4","title":"AWS.DataZone.get_environment_blueprint/4","type":"function"},{"doc":"Gets the blueprint configuration in Amazon DataZone.","ref":"AWS.DataZone.html#get_environment_blueprint_configuration/4","title":"AWS.DataZone.get_environment_blueprint_configuration/4","type":"function"},{"doc":"Gets an evinronment profile in Amazon DataZone.","ref":"AWS.DataZone.html#get_environment_profile/4","title":"AWS.DataZone.get_environment_profile/4","type":"function"},{"doc":"Gets a metadata form type in Amazon DataZone.","ref":"AWS.DataZone.html#get_form_type/5","title":"AWS.DataZone.get_form_type/5","type":"function"},{"doc":"Gets a business glossary in Amazon DataZone.","ref":"AWS.DataZone.html#get_glossary/4","title":"AWS.DataZone.get_glossary/4","type":"function"},{"doc":"Gets a business glossary term in Amazon DataZone.","ref":"AWS.DataZone.html#get_glossary_term/4","title":"AWS.DataZone.get_glossary_term/4","type":"function"},{"doc":"Gets a group profile in Amazon DataZone.","ref":"AWS.DataZone.html#get_group_profile/4","title":"AWS.DataZone.get_group_profile/4","type":"function"},{"doc":"Gets the data portal URL for the specified Amazon DataZone domain.","ref":"AWS.DataZone.html#get_iam_portal_login_url/4","title":"AWS.DataZone.get_iam_portal_login_url/4","type":"function"},{"doc":"","ref":"AWS.DataZone.html#get_listing/5","title":"AWS.DataZone.get_listing/5","type":"function"},{"doc":"Gets a project in Amazon DataZone.","ref":"AWS.DataZone.html#get_project/4","title":"AWS.DataZone.get_project/4","type":"function"},{"doc":"Gets a subscription in Amazon DataZone.","ref":"AWS.DataZone.html#get_subscription/4","title":"AWS.DataZone.get_subscription/4","type":"function"},{"doc":"Gets the subscription grant in Amazon DataZone.","ref":"AWS.DataZone.html#get_subscription_grant/4","title":"AWS.DataZone.get_subscription_grant/4","type":"function"},{"doc":"Gets the details of the specified subscription request.","ref":"AWS.DataZone.html#get_subscription_request_details/4","title":"AWS.DataZone.get_subscription_request_details/4","type":"function"},{"doc":"Gets the subscription target in Amazon DataZone.","ref":"AWS.DataZone.html#get_subscription_target/5","title":"AWS.DataZone.get_subscription_target/5","type":"function"},{"doc":"Gets a user profile in Amazon DataZone.","ref":"AWS.DataZone.html#get_user_profile/5","title":"AWS.DataZone.get_user_profile/5","type":"function"},{"doc":"Lists the revisions for the asset.","ref":"AWS.DataZone.html#list_asset_revisions/6","title":"AWS.DataZone.list_asset_revisions/6","type":"function"},{"doc":"Lists data source run activities.","ref":"AWS.DataZone.html#list_data_source_run_activities/7","title":"AWS.DataZone.list_data_source_run_activities/7","type":"function"},{"doc":"Lists data source runs in Amazon DataZone.","ref":"AWS.DataZone.html#list_data_source_runs/7","title":"AWS.DataZone.list_data_source_runs/7","type":"function"},{"doc":"Lists data sources in Amazon DataZone.","ref":"AWS.DataZone.html#list_data_sources/10","title":"AWS.DataZone.list_data_sources/10","type":"function"},{"doc":"Lists Amazon DataZone domains.","ref":"AWS.DataZone.html#list_domains/5","title":"AWS.DataZone.list_domains/5","type":"function"},{"doc":"Lists blueprint configurations for a Amazon DataZone environment.","ref":"AWS.DataZone.html#list_environment_blueprint_configurations/5","title":"AWS.DataZone.list_environment_blueprint_configurations/5","type":"function"},{"doc":"Lists blueprints in an Amazon DataZone environment.","ref":"AWS.DataZone.html#list_environment_blueprints/7","title":"AWS.DataZone.list_environment_blueprints/7","type":"function"},{"doc":"Lists Amazon DataZone environment profiles.","ref":"AWS.DataZone.html#list_environment_profiles/10","title":"AWS.DataZone.list_environment_profiles/10","type":"function"},{"doc":"Lists Amazon DataZone environments.","ref":"AWS.DataZone.html#list_environments/13","title":"AWS.DataZone.list_environments/13","type":"function"},{"doc":"Lists all Amazon DataZone notifications.","ref":"AWS.DataZone.html#list_notifications/10","title":"AWS.DataZone.list_notifications/10","type":"function"},{"doc":"Lists all members of the specified project.","ref":"AWS.DataZone.html#list_project_memberships/8","title":"AWS.DataZone.list_project_memberships/8","type":"function"},{"doc":"Lists Amazon DataZone projects.","ref":"AWS.DataZone.html#list_projects/8","title":"AWS.DataZone.list_projects/8","type":"function"},{"doc":"Lists subscription grants.","ref":"AWS.DataZone.html#list_subscription_grants/11","title":"AWS.DataZone.list_subscription_grants/11","type":"function"},{"doc":"Lists Amazon DataZone subscription requests.","ref":"AWS.DataZone.html#list_subscription_requests/11","title":"AWS.DataZone.list_subscription_requests/11","type":"function"},{"doc":"Lists subscription targets in Amazon DataZone.","ref":"AWS.DataZone.html#list_subscription_targets/8","title":"AWS.DataZone.list_subscription_targets/8","type":"function"},{"doc":"Lists subscriptions in Amazon DataZone.","ref":"AWS.DataZone.html#list_subscriptions/12","title":"AWS.DataZone.list_subscriptions/12","type":"function"},{"doc":"Lists tags for the specified resource in Amazon DataZone.","ref":"AWS.DataZone.html#list_tags_for_resource/3","title":"AWS.DataZone.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.DataZone.html#metadata/0","title":"AWS.DataZone.metadata/0","type":"function"},{"doc":"Writes the configuration for the specified environment blueprint in Amazon\nDataZone.","ref":"AWS.DataZone.html#put_environment_blueprint_configuration/5","title":"AWS.DataZone.put_environment_blueprint_configuration/5","type":"function"},{"doc":"Rejects automatically generated business-friendly metadata for your Amazon\nDataZone assets.","ref":"AWS.DataZone.html#reject_predictions/5","title":"AWS.DataZone.reject_predictions/5","type":"function"},{"doc":"Rejects the specified subscription request.","ref":"AWS.DataZone.html#reject_subscription_request/5","title":"AWS.DataZone.reject_subscription_request/5","type":"function"},{"doc":"Revokes a specified subscription in Amazon DataZone.","ref":"AWS.DataZone.html#revoke_subscription/5","title":"AWS.DataZone.revoke_subscription/5","type":"function"},{"doc":"Searches for assets in Amazon DataZone.","ref":"AWS.DataZone.html#search/4","title":"AWS.DataZone.search/4","type":"function"},{"doc":"Searches group profiles in Amazon DataZone.","ref":"AWS.DataZone.html#search_group_profiles/4","title":"AWS.DataZone.search_group_profiles/4","type":"function"},{"doc":"Searches listings in Amazon DataZone.","ref":"AWS.DataZone.html#search_listings/4","title":"AWS.DataZone.search_listings/4","type":"function"},{"doc":"Searches for types in Amazon DataZone.","ref":"AWS.DataZone.html#search_types/4","title":"AWS.DataZone.search_types/4","type":"function"},{"doc":"Searches user profiles in Amazon DataZone.","ref":"AWS.DataZone.html#search_user_profiles/4","title":"AWS.DataZone.search_user_profiles/4","type":"function"},{"doc":"Start the run of the specified data source in Amazon DataZone.","ref":"AWS.DataZone.html#start_data_source_run/5","title":"AWS.DataZone.start_data_source_run/5","type":"function"},{"doc":"Tags a resource in Amazon DataZone.","ref":"AWS.DataZone.html#tag_resource/4","title":"AWS.DataZone.tag_resource/4","type":"function"},{"doc":"Untags a resource in Amazon DataZone.","ref":"AWS.DataZone.html#untag_resource/4","title":"AWS.DataZone.untag_resource/4","type":"function"},{"doc":"Updates the specified data source in Amazon DataZone.","ref":"AWS.DataZone.html#update_data_source/5","title":"AWS.DataZone.update_data_source/5","type":"function"},{"doc":"Updates a Amazon DataZone domain.","ref":"AWS.DataZone.html#update_domain/4","title":"AWS.DataZone.update_domain/4","type":"function"},{"doc":"Updates the specified environment in Amazon DataZone.","ref":"AWS.DataZone.html#update_environment/5","title":"AWS.DataZone.update_environment/5","type":"function"},{"doc":"Updates the specified environment profile in Amazon DataZone.","ref":"AWS.DataZone.html#update_environment_profile/5","title":"AWS.DataZone.update_environment_profile/5","type":"function"},{"doc":"Updates the business glossary in Amazon DataZone.","ref":"AWS.DataZone.html#update_glossary/5","title":"AWS.DataZone.update_glossary/5","type":"function"},{"doc":"Updates a business glossary term in Amazon DataZone.","ref":"AWS.DataZone.html#update_glossary_term/5","title":"AWS.DataZone.update_glossary_term/5","type":"function"},{"doc":"Updates the specified group profile in Amazon DataZone.","ref":"AWS.DataZone.html#update_group_profile/5","title":"AWS.DataZone.update_group_profile/5","type":"function"},{"doc":"Updates the specified project in Amazon DataZone.","ref":"AWS.DataZone.html#update_project/5","title":"AWS.DataZone.update_project/5","type":"function"},{"doc":"Updates the status of the specified subscription grant status in Amazon\nDataZone.","ref":"AWS.DataZone.html#update_subscription_grant_status/6","title":"AWS.DataZone.update_subscription_grant_status/6","type":"function"},{"doc":"Updates a specified subscription request in Amazon DataZone.","ref":"AWS.DataZone.html#update_subscription_request/5","title":"AWS.DataZone.update_subscription_request/5","type":"function"},{"doc":"Updates the specified subscription target in Amazon DataZone.","ref":"AWS.DataZone.html#update_subscription_target/6","title":"AWS.DataZone.update_subscription_target/6","type":"function"},{"doc":"Updates the specified user profile in Amazon DataZone.","ref":"AWS.DataZone.html#update_user_profile/5","title":"AWS.DataZone.update_user_profile/5","type":"function"},{"doc":"Database Migration Service\n\nDatabase Migration Service (DMS) can migrate your data to and from the most\nwidely used commercial and open-source databases such as Oracle, PostgreSQL,\nMicrosoft SQL Server, Amazon Redshift, MariaDB, Amazon Aurora, MySQL, and SAP\nAdaptive Server Enterprise (ASE).\n\nThe service supports homogeneous migrations such as Oracle to Oracle, as well as\nheterogeneous migrations between different database platforms, such as Oracle to\nMySQL or SQL Server to PostgreSQL.\n\nFor more information about DMS, see [What Is Database Migration Service?](https://docs.aws.amazon.com/dms/latest/userguide/Welcome.html) in the\n*Database Migration Service User Guide.*","ref":"AWS.DatabaseMigration.html","title":"AWS.DatabaseMigration","type":"module"},{"doc":"Adds metadata tags to an DMS resource, including replication instance, endpoint,\nsubnet group, and migration task.\n\nThese tags can also be used with cost allocation reporting to track cost\nassociated with DMS resources, or used in a Condition statement in an IAM policy\nfor DMS. For more information, see [ `Tag`\n](https://docs.aws.amazon.com/dms/latest/APIReference/API_Tag.html) data type\ndescription.","ref":"AWS.DatabaseMigration.html#add_tags_to_resource/3","title":"AWS.DatabaseMigration.add_tags_to_resource/3","type":"function"},{"doc":"Applies a pending maintenance action to a resource (for example, to a\nreplication instance).","ref":"AWS.DatabaseMigration.html#apply_pending_maintenance_action/3","title":"AWS.DatabaseMigration.apply_pending_maintenance_action/3","type":"function"},{"doc":"Starts the analysis of up to 20 source databases to recommend target engines for\neach source database.\n\nThis is a batch version of\n[StartRecommendations](https://docs.aws.amazon.com/dms/latest/APIReference/API_StartRecommendations.html).\n\nThe result of analysis of each source database is reported individually in the\nresponse. Because the batch request can result in a combination of successful\nand unsuccessful actions, you should check for batch errors even when the call\nreturns an HTTP status code of `200`.","ref":"AWS.DatabaseMigration.html#batch_start_recommendations/3","title":"AWS.DatabaseMigration.batch_start_recommendations/3","type":"function"},{"doc":"Cancels a single premigration assessment run.\n\nThis operation prevents any individual assessments from running if they haven't\nstarted running. It also attempts to cancel any individual assessments that are\ncurrently running.","ref":"AWS.DatabaseMigration.html#cancel_replication_task_assessment_run/3","title":"AWS.DatabaseMigration.cancel_replication_task_assessment_run/3","type":"function"},{"doc":"Creates a data provider using the provided settings.\n\nA data provider stores a data store type and location information about your\ndatabase.","ref":"AWS.DatabaseMigration.html#create_data_provider/3","title":"AWS.DatabaseMigration.create_data_provider/3","type":"function"},{"doc":"Creates an endpoint using the provided settings.\n\nFor a MySQL source or target endpoint, don't explicitly specify the database\nusing the `DatabaseName` request parameter on the `CreateEndpoint` API call.\nSpecifying `DatabaseName` when you create a MySQL endpoint replicates all the\ntask tables to this single database. For MySQL endpoints, you specify the\ndatabase only when you specify the schema in the table-mapping rules of the DMS\ntask.","ref":"AWS.DatabaseMigration.html#create_endpoint/3","title":"AWS.DatabaseMigration.create_endpoint/3","type":"function"},{"doc":"Creates an DMS event notification subscription.\n\nYou can specify the type of source (`SourceType`) you want to be notified of,\nprovide a list of DMS source IDs (`SourceIds`) that triggers the events, and\nprovide a list of event categories (`EventCategories`) for events you want to be\nnotified of. If you specify both the `SourceType` and `SourceIds`, such as\n`SourceType = replication-instance` and `SourceIdentifier = my-replinstance`,\nyou will be notified of all the replication instance events for the specified\nsource. If you specify a `SourceType` but don't specify a `SourceIdentifier`,\nyou receive notice of the events for that source type for all your DMS sources.\nIf you don't specify either `SourceType` nor `SourceIdentifier`, you will be\nnotified of events generated from all DMS sources belonging to your customer\naccount.\n\nFor more information about DMS events, see [Working with Events and Notifications](https://docs.aws.amazon.com/dms/latest/userguide/CHAP_Events.html)\nin the *Database Migration Service User Guide.*","ref":"AWS.DatabaseMigration.html#create_event_subscription/3","title":"AWS.DatabaseMigration.create_event_subscription/3","type":"function"},{"doc":"Creates a Fleet Advisor collector using the specified parameters.","ref":"AWS.DatabaseMigration.html#create_fleet_advisor_collector/3","title":"AWS.DatabaseMigration.create_fleet_advisor_collector/3","type":"function"},{"doc":"Creates the instance profile using the specified parameters.","ref":"AWS.DatabaseMigration.html#create_instance_profile/3","title":"AWS.DatabaseMigration.create_instance_profile/3","type":"function"},{"doc":"Creates the migration project using the specified parameters.\n\nYou can run this action only after you create an instance profile and data\nproviders using\n[CreateInstanceProfile](https://docs.aws.amazon.com/dms/latest/APIReference/API_CreateInstanceProfile.html) and\n[CreateDataProvider](https://docs.aws.amazon.com/dms/latest/APIReference/API_CreateDataProvider.html).","ref":"AWS.DatabaseMigration.html#create_migration_project/3","title":"AWS.DatabaseMigration.create_migration_project/3","type":"function"},{"doc":"Creates a configuration that you can later provide to configure and start an DMS\nServerless replication.\n\nYou can also provide options to validate the configuration inputs before you\nstart the replication.","ref":"AWS.DatabaseMigration.html#create_replication_config/3","title":"AWS.DatabaseMigration.create_replication_config/3","type":"function"},{"doc":"Creates the replication instance using the specified parameters.\n\nDMS requires that your account have certain roles with appropriate permissions\nbefore you can create a replication instance. For information on the required\nroles, see [Creating the IAM Roles to Use With the CLI and DMS API](https://docs.aws.amazon.com/dms/latest/userguide/CHAP_Security.html#CHAP_Security.APIRole).\nFor information on the required permissions, see [IAM Permissions Needed to Use DMS](https://docs.aws.amazon.com/dms/latest/userguide/CHAP_Security.html#CHAP_Security.IAMPermissions).\n\nIf you don't specify a version when creating a replication instance, DMS will\ncreate the instance using the default engine version. For information about the\ndefault engine version, see [Release Notes](https://docs.aws.amazon.com/dms/latest/userguide/CHAP_ReleaseNotes.html).","ref":"AWS.DatabaseMigration.html#create_replication_instance/3","title":"AWS.DatabaseMigration.create_replication_instance/3","type":"function"},{"doc":"Creates a replication subnet group given a list of the subnet IDs in a VPC.\n\nThe VPC needs to have at least one subnet in at least two availability zones in\nthe Amazon Web Services Region, otherwise the service will throw a\n`ReplicationSubnetGroupDoesNotCoverEnoughAZs` exception.\n\nIf a replication subnet group exists in your Amazon Web Services account, the\nCreateReplicationSubnetGroup action returns the following error message: The\nReplication Subnet Group already exists. In this case, delete the existing\nreplication subnet group. To do so, use the\n[DeleteReplicationSubnetGroup](https://docs.aws.amazon.com/en_us/dms/latest/APIReference/API_DeleteReplicationSubnetGroup.html)\naction. Optionally, choose Subnet groups in the DMS console, then choose your\nsubnet group. Next, choose Delete from Actions.","ref":"AWS.DatabaseMigration.html#create_replication_subnet_group/3","title":"AWS.DatabaseMigration.create_replication_subnet_group/3","type":"function"},{"doc":"Creates a replication task using the specified parameters.","ref":"AWS.DatabaseMigration.html#create_replication_task/3","title":"AWS.DatabaseMigration.create_replication_task/3","type":"function"},{"doc":"Deletes the specified certificate.","ref":"AWS.DatabaseMigration.html#delete_certificate/3","title":"AWS.DatabaseMigration.delete_certificate/3","type":"function"},{"doc":"Deletes the connection between a replication instance and an endpoint.","ref":"AWS.DatabaseMigration.html#delete_connection/3","title":"AWS.DatabaseMigration.delete_connection/3","type":"function"},{"doc":"Deletes the specified data provider.\n\nAll migration projects associated with the data provider must be deleted or\nmodified before you can delete the data provider.","ref":"AWS.DatabaseMigration.html#delete_data_provider/3","title":"AWS.DatabaseMigration.delete_data_provider/3","type":"function"},{"doc":"Deletes the specified endpoint.\n\nAll tasks associated with the endpoint must be deleted before you can delete the\nendpoint.","ref":"AWS.DatabaseMigration.html#delete_endpoint/3","title":"AWS.DatabaseMigration.delete_endpoint/3","type":"function"},{"doc":"Deletes an DMS event subscription.","ref":"AWS.DatabaseMigration.html#delete_event_subscription/3","title":"AWS.DatabaseMigration.delete_event_subscription/3","type":"function"},{"doc":"Deletes the specified Fleet Advisor collector.","ref":"AWS.DatabaseMigration.html#delete_fleet_advisor_collector/3","title":"AWS.DatabaseMigration.delete_fleet_advisor_collector/3","type":"function"},{"doc":"Deletes the specified Fleet Advisor collector databases.","ref":"AWS.DatabaseMigration.html#delete_fleet_advisor_databases/3","title":"AWS.DatabaseMigration.delete_fleet_advisor_databases/3","type":"function"},{"doc":"Deletes the specified instance profile.\n\nAll migration projects associated with the instance profile must be deleted or\nmodified before you can delete the instance profile.","ref":"AWS.DatabaseMigration.html#delete_instance_profile/3","title":"AWS.DatabaseMigration.delete_instance_profile/3","type":"function"},{"doc":"Deletes the specified migration project.\n\nThe migration project must be closed before you can delete it.","ref":"AWS.DatabaseMigration.html#delete_migration_project/3","title":"AWS.DatabaseMigration.delete_migration_project/3","type":"function"},{"doc":"Deletes an DMS Serverless replication configuration.\n\nThis effectively deprovisions any and all replications that use this\nconfiguration. You can't delete the configuration for an DMS Serverless\nreplication that is ongoing. You can delete the configuration when the\nreplication is in a non-RUNNING and non-STARTING state.","ref":"AWS.DatabaseMigration.html#delete_replication_config/3","title":"AWS.DatabaseMigration.delete_replication_config/3","type":"function"},{"doc":"Deletes the specified replication instance.\n\nYou must delete any migration tasks that are associated with the replication\ninstance before you can delete it.","ref":"AWS.DatabaseMigration.html#delete_replication_instance/3","title":"AWS.DatabaseMigration.delete_replication_instance/3","type":"function"},{"doc":"Deletes a subnet group.","ref":"AWS.DatabaseMigration.html#delete_replication_subnet_group/3","title":"AWS.DatabaseMigration.delete_replication_subnet_group/3","type":"function"},{"doc":"Deletes the specified replication task.","ref":"AWS.DatabaseMigration.html#delete_replication_task/3","title":"AWS.DatabaseMigration.delete_replication_task/3","type":"function"},{"doc":"Deletes the record of a single premigration assessment run.\n\nThis operation removes all metadata that DMS maintains about this assessment\nrun. However, the operation leaves untouched all information about this\nassessment run that is stored in your Amazon S3 bucket.","ref":"AWS.DatabaseMigration.html#delete_replication_task_assessment_run/3","title":"AWS.DatabaseMigration.delete_replication_task_assessment_run/3","type":"function"},{"doc":"Lists all of the DMS attributes for a customer account.\n\nThese attributes include DMS quotas for the account and a unique account\nidentifier in a particular DMS region. DMS quotas include a list of resource\nquotas supported by the account, such as the number of replication instances\nallowed. The description for each resource quota, includes the quota name,\ncurrent usage toward that quota, and the quota's maximum value. DMS uses the\nunique account identifier to name each artifact used by DMS in the given region.\n\nThis command does not take any parameters.","ref":"AWS.DatabaseMigration.html#describe_account_attributes/3","title":"AWS.DatabaseMigration.describe_account_attributes/3","type":"function"},{"doc":"Provides a list of individual assessments that you can specify for a new\npremigration assessment run, given one or more parameters.\n\nIf you specify an existing migration task, this operation provides the default\nindividual assessments you can specify for that task. Otherwise, the specified\nparameters model elements of a possible migration task on which to base a\npremigration assessment run.\n\nTo use these migration task modeling parameters, you must specify an existing\nreplication instance, a source database engine, a target database engine, and a\nmigration type. This combination of parameters potentially limits the default\nindividual assessments available for an assessment run created for a\ncorresponding migration task.\n\nIf you specify no parameters, this operation provides a list of all possible\nindividual assessments that you can specify for an assessment run. If you\nspecify any one of the task modeling parameters, you must specify all of them or\nthe operation cannot provide a list of individual assessments. The only\nparameter that you can specify alone is for an existing migration task. The\nspecified task definition then determines the default list of individual\nassessments that you can specify in an assessment run for the task.","ref":"AWS.DatabaseMigration.html#describe_applicable_individual_assessments/3","title":"AWS.DatabaseMigration.describe_applicable_individual_assessments/3","type":"function"},{"doc":"Provides a description of the certificate.","ref":"AWS.DatabaseMigration.html#describe_certificates/3","title":"AWS.DatabaseMigration.describe_certificates/3","type":"function"},{"doc":"Describes the status of the connections that have been made between the\nreplication instance and an endpoint.\n\nConnections are created when you test an endpoint.","ref":"AWS.DatabaseMigration.html#describe_connections/3","title":"AWS.DatabaseMigration.describe_connections/3","type":"function"},{"doc":"Returns configuration parameters for a schema conversion project.","ref":"AWS.DatabaseMigration.html#describe_conversion_configuration/3","title":"AWS.DatabaseMigration.describe_conversion_configuration/3","type":"function"},{"doc":"Returns a paginated list of data providers for your account in the current\nregion.","ref":"AWS.DatabaseMigration.html#describe_data_providers/3","title":"AWS.DatabaseMigration.describe_data_providers/3","type":"function"},{"doc":"Returns information about the possible endpoint settings available when you\ncreate an endpoint for a specific database engine.","ref":"AWS.DatabaseMigration.html#describe_endpoint_settings/3","title":"AWS.DatabaseMigration.describe_endpoint_settings/3","type":"function"},{"doc":"Returns information about the type of endpoints available.","ref":"AWS.DatabaseMigration.html#describe_endpoint_types/3","title":"AWS.DatabaseMigration.describe_endpoint_types/3","type":"function"},{"doc":"Returns information about the endpoints for your account in the current region.","ref":"AWS.DatabaseMigration.html#describe_endpoints/3","title":"AWS.DatabaseMigration.describe_endpoints/3","type":"function"},{"doc":"Returns information about the replication instance versions used in the project.","ref":"AWS.DatabaseMigration.html#describe_engine_versions/3","title":"AWS.DatabaseMigration.describe_engine_versions/3","type":"function"},{"doc":"Lists categories for all event source types, or, if specified, for a specified\nsource type.\n\nYou can see a list of the event categories and source types in [Working with Events and\nNotifications](https://docs.aws.amazon.com/dms/latest/userguide/CHAP_Events.html)\nin the *Database Migration Service User Guide.*","ref":"AWS.DatabaseMigration.html#describe_event_categories/3","title":"AWS.DatabaseMigration.describe_event_categories/3","type":"function"},{"doc":"Lists all the event subscriptions for a customer account.\n\nThe description of a subscription includes `SubscriptionName`, `SNSTopicARN`,\n`CustomerID`, `SourceType`, `SourceID`, `CreationTime`, and `Status`.\n\nIf you specify `SubscriptionName`, this action lists the description for that\nsubscription.","ref":"AWS.DatabaseMigration.html#describe_event_subscriptions/3","title":"AWS.DatabaseMigration.describe_event_subscriptions/3","type":"function"},{"doc":"Lists events for a given source identifier and source type.\n\nYou can also specify a start and end time. For more information on DMS events,\nsee [Working with Events and Notifications](https://docs.aws.amazon.com/dms/latest/userguide/CHAP_Events.html)\nin the *Database Migration Service User Guide.*","ref":"AWS.DatabaseMigration.html#describe_events/3","title":"AWS.DatabaseMigration.describe_events/3","type":"function"},{"doc":"Returns a paginated list of extension pack associations for the specified\nmigration project.\n\nAn extension pack is an add-on module that emulates functions present in a\nsource database that are required when converting objects to the target\ndatabase.","ref":"AWS.DatabaseMigration.html#describe_extension_pack_associations/3","title":"AWS.DatabaseMigration.describe_extension_pack_associations/3","type":"function"},{"doc":"Returns a list of the Fleet Advisor collectors in your account.","ref":"AWS.DatabaseMigration.html#describe_fleet_advisor_collectors/3","title":"AWS.DatabaseMigration.describe_fleet_advisor_collectors/3","type":"function"},{"doc":"Returns a list of Fleet Advisor databases in your account.","ref":"AWS.DatabaseMigration.html#describe_fleet_advisor_databases/3","title":"AWS.DatabaseMigration.describe_fleet_advisor_databases/3","type":"function"},{"doc":"Provides descriptions of large-scale assessment (LSA) analyses produced by your\nFleet Advisor collectors.","ref":"AWS.DatabaseMigration.html#describe_fleet_advisor_lsa_analysis/3","title":"AWS.DatabaseMigration.describe_fleet_advisor_lsa_analysis/3","type":"function"},{"doc":"Provides descriptions of the schemas discovered by your Fleet Advisor\ncollectors.","ref":"AWS.DatabaseMigration.html#describe_fleet_advisor_schema_object_summary/3","title":"AWS.DatabaseMigration.describe_fleet_advisor_schema_object_summary/3","type":"function"},{"doc":"Returns a list of schemas detected by Fleet Advisor Collectors in your account.","ref":"AWS.DatabaseMigration.html#describe_fleet_advisor_schemas/3","title":"AWS.DatabaseMigration.describe_fleet_advisor_schemas/3","type":"function"},{"doc":"Returns a paginated list of instance profiles for your account in the current\nregion.","ref":"AWS.DatabaseMigration.html#describe_instance_profiles/3","title":"AWS.DatabaseMigration.describe_instance_profiles/3","type":"function"},{"doc":"Returns a paginated list of metadata model assessments for your account in the\ncurrent region.","ref":"AWS.DatabaseMigration.html#describe_metadata_model_assessments/3","title":"AWS.DatabaseMigration.describe_metadata_model_assessments/3","type":"function"},{"doc":"Returns a paginated list of metadata model conversions for a migration project.","ref":"AWS.DatabaseMigration.html#describe_metadata_model_conversions/3","title":"AWS.DatabaseMigration.describe_metadata_model_conversions/3","type":"function"},{"doc":"Returns a paginated list of metadata model exports.","ref":"AWS.DatabaseMigration.html#describe_metadata_model_exports_as_script/3","title":"AWS.DatabaseMigration.describe_metadata_model_exports_as_script/3","type":"function"},{"doc":"Returns a paginated list of metadata model exports.","ref":"AWS.DatabaseMigration.html#describe_metadata_model_exports_to_target/3","title":"AWS.DatabaseMigration.describe_metadata_model_exports_to_target/3","type":"function"},{"doc":"Returns a paginated list of metadata model imports.","ref":"AWS.DatabaseMigration.html#describe_metadata_model_imports/3","title":"AWS.DatabaseMigration.describe_metadata_model_imports/3","type":"function"},{"doc":"Returns a paginated list of migration projects for your account in the current\nregion.","ref":"AWS.DatabaseMigration.html#describe_migration_projects/3","title":"AWS.DatabaseMigration.describe_migration_projects/3","type":"function"},{"doc":"Returns information about the replication instance types that can be created in\nthe specified region.","ref":"AWS.DatabaseMigration.html#describe_orderable_replication_instances/3","title":"AWS.DatabaseMigration.describe_orderable_replication_instances/3","type":"function"},{"doc":"For internal use only","ref":"AWS.DatabaseMigration.html#describe_pending_maintenance_actions/3","title":"AWS.DatabaseMigration.describe_pending_maintenance_actions/3","type":"function"},{"doc":"Returns a paginated list of limitations for recommendations of target Amazon Web\nServices engines.","ref":"AWS.DatabaseMigration.html#describe_recommendation_limitations/3","title":"AWS.DatabaseMigration.describe_recommendation_limitations/3","type":"function"},{"doc":"Returns a paginated list of target engine recommendations for your source\ndatabases.","ref":"AWS.DatabaseMigration.html#describe_recommendations/3","title":"AWS.DatabaseMigration.describe_recommendations/3","type":"function"},{"doc":"Returns the status of the RefreshSchemas operation.","ref":"AWS.DatabaseMigration.html#describe_refresh_schemas_status/3","title":"AWS.DatabaseMigration.describe_refresh_schemas_status/3","type":"function"},{"doc":"Returns one or more existing DMS Serverless replication configurations as a list\nof structures.","ref":"AWS.DatabaseMigration.html#describe_replication_configs/3","title":"AWS.DatabaseMigration.describe_replication_configs/3","type":"function"},{"doc":"Returns information about the task logs for the specified task.","ref":"AWS.DatabaseMigration.html#describe_replication_instance_task_logs/3","title":"AWS.DatabaseMigration.describe_replication_instance_task_logs/3","type":"function"},{"doc":"Returns information about replication instances for your account in the current\nregion.","ref":"AWS.DatabaseMigration.html#describe_replication_instances/3","title":"AWS.DatabaseMigration.describe_replication_instances/3","type":"function"},{"doc":"Returns information about the replication subnet groups.","ref":"AWS.DatabaseMigration.html#describe_replication_subnet_groups/3","title":"AWS.DatabaseMigration.describe_replication_subnet_groups/3","type":"function"},{"doc":"Returns table and schema statistics for one or more provisioned replications\nthat use a given DMS Serverless replication configuration.","ref":"AWS.DatabaseMigration.html#describe_replication_table_statistics/3","title":"AWS.DatabaseMigration.describe_replication_table_statistics/3","type":"function"},{"doc":"Returns the task assessment results from the Amazon S3 bucket that DMS creates\nin your Amazon Web Services account.\n\nThis action always returns the latest results.\n\nFor more information about DMS task assessments, see [Creating a task assessment report](https://docs.aws.amazon.com/dms/latest/userguide/CHAP_Tasks.AssessmentReport.html)\nin the *Database Migration Service User Guide*.","ref":"AWS.DatabaseMigration.html#describe_replication_task_assessment_results/3","title":"AWS.DatabaseMigration.describe_replication_task_assessment_results/3","type":"function"},{"doc":"Returns a paginated list of premigration assessment runs based on filter\nsettings.\n\nThese filter settings can specify a combination of premigration assessment runs,\nmigration tasks, replication instances, and assessment run status values.\n\nThis operation doesn't return information about individual assessments. For this\ninformation, see the `DescribeReplicationTaskIndividualAssessments` operation.","ref":"AWS.DatabaseMigration.html#describe_replication_task_assessment_runs/3","title":"AWS.DatabaseMigration.describe_replication_task_assessment_runs/3","type":"function"},{"doc":"Returns a paginated list of individual assessments based on filter settings.\n\nThese filter settings can specify a combination of premigration assessment runs,\nmigration tasks, and assessment status values.","ref":"AWS.DatabaseMigration.html#describe_replication_task_individual_assessments/3","title":"AWS.DatabaseMigration.describe_replication_task_individual_assessments/3","type":"function"},{"doc":"Returns information about replication tasks for your account in the current\nregion.","ref":"AWS.DatabaseMigration.html#describe_replication_tasks/3","title":"AWS.DatabaseMigration.describe_replication_tasks/3","type":"function"},{"doc":"Provides details on replication progress by returning status information for one\nor more provisioned DMS Serverless replications.","ref":"AWS.DatabaseMigration.html#describe_replications/3","title":"AWS.DatabaseMigration.describe_replications/3","type":"function"},{"doc":"Returns information about the schema for the specified endpoint.","ref":"AWS.DatabaseMigration.html#describe_schemas/3","title":"AWS.DatabaseMigration.describe_schemas/3","type":"function"},{"doc":"Returns table statistics on the database migration task, including table name,\nrows inserted, rows updated, and rows deleted.\n\nNote that the \"last updated\" column the DMS console only indicates the time that\nDMS last updated the table statistics record for a table. It does not indicate\nthe time of the last update to the table.","ref":"AWS.DatabaseMigration.html#describe_table_statistics/3","title":"AWS.DatabaseMigration.describe_table_statistics/3","type":"function"},{"doc":"Saves a copy of a database migration assessment report to your Amazon S3 bucket.\n\nDMS can save your assessment report as a comma-separated value (CSV) or a PDF\nfile.","ref":"AWS.DatabaseMigration.html#export_metadata_model_assessment/3","title":"AWS.DatabaseMigration.export_metadata_model_assessment/3","type":"function"},{"doc":"Uploads the specified certificate.","ref":"AWS.DatabaseMigration.html#import_certificate/3","title":"AWS.DatabaseMigration.import_certificate/3","type":"function"},{"doc":"Lists all metadata tags attached to an DMS resource, including replication\ninstance, endpoint, subnet group, and migration task.\n\nFor more information, see [ `Tag`\n](https://docs.aws.amazon.com/dms/latest/APIReference/API_Tag.html) data type\ndescription.","ref":"AWS.DatabaseMigration.html#list_tags_for_resource/3","title":"AWS.DatabaseMigration.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.DatabaseMigration.html#metadata/0","title":"AWS.DatabaseMigration.metadata/0","type":"function"},{"doc":"Modifies the specified schema conversion configuration using the provided\nparameters.","ref":"AWS.DatabaseMigration.html#modify_conversion_configuration/3","title":"AWS.DatabaseMigration.modify_conversion_configuration/3","type":"function"},{"doc":"Modifies the specified data provider using the provided settings.\n\nYou must remove the data provider from all migration projects before you can\nmodify it.","ref":"AWS.DatabaseMigration.html#modify_data_provider/3","title":"AWS.DatabaseMigration.modify_data_provider/3","type":"function"},{"doc":"Modifies the specified endpoint.\n\nFor a MySQL source or target endpoint, don't explicitly specify the database\nusing the `DatabaseName` request parameter on the `ModifyEndpoint` API call.\nSpecifying `DatabaseName` when you modify a MySQL endpoint replicates all the\ntask tables to this single database. For MySQL endpoints, you specify the\ndatabase only when you specify the schema in the table-mapping rules of the DMS\ntask.","ref":"AWS.DatabaseMigration.html#modify_endpoint/3","title":"AWS.DatabaseMigration.modify_endpoint/3","type":"function"},{"doc":"Modifies an existing DMS event notification subscription.","ref":"AWS.DatabaseMigration.html#modify_event_subscription/3","title":"AWS.DatabaseMigration.modify_event_subscription/3","type":"function"},{"doc":"Modifies the specified instance profile using the provided parameters.\n\nAll migration projects associated with the instance profile must be deleted or\nmodified before you can modify the instance profile.","ref":"AWS.DatabaseMigration.html#modify_instance_profile/3","title":"AWS.DatabaseMigration.modify_instance_profile/3","type":"function"},{"doc":"Modifies the specified migration project using the provided parameters.\n\nThe migration project must be closed before you can modify it.","ref":"AWS.DatabaseMigration.html#modify_migration_project/3","title":"AWS.DatabaseMigration.modify_migration_project/3","type":"function"},{"doc":"Modifies an existing DMS Serverless replication configuration that you can use\nto start a replication.\n\nThis command includes input validation and logic to check the state of any\nreplication that uses this configuration. You can only modify a replication\nconfiguration before any replication that uses it has started. As soon as you\nhave initially started a replication with a given configuiration, you can't\nmodify that configuration, even if you stop it.\n\nOther run statuses that allow you to run this command include FAILED and\nCREATED. A provisioning state that allows you to run this command is\nFAILED_PROVISION.","ref":"AWS.DatabaseMigration.html#modify_replication_config/3","title":"AWS.DatabaseMigration.modify_replication_config/3","type":"function"},{"doc":"Modifies the replication instance to apply new settings.\n\nYou can change one or more parameters by specifying these parameters and the new\nvalues in the request.\n\nSome settings are applied during the maintenance window.","ref":"AWS.DatabaseMigration.html#modify_replication_instance/3","title":"AWS.DatabaseMigration.modify_replication_instance/3","type":"function"},{"doc":"Modifies the settings for the specified replication subnet group.","ref":"AWS.DatabaseMigration.html#modify_replication_subnet_group/3","title":"AWS.DatabaseMigration.modify_replication_subnet_group/3","type":"function"},{"doc":"Modifies the specified replication task.\n\nYou can't modify the task endpoints. The task must be stopped before you can\nmodify it.\n\nFor more information about DMS tasks, see [Working with Migration Tasks](https://docs.aws.amazon.com/dms/latest/userguide/CHAP_Tasks.html) in the\n*Database Migration Service User Guide*.","ref":"AWS.DatabaseMigration.html#modify_replication_task/3","title":"AWS.DatabaseMigration.modify_replication_task/3","type":"function"},{"doc":"Moves a replication task from its current replication instance to a different\ntarget replication instance using the specified parameters.\n\nThe target replication instance must be created with the same or later DMS\nversion as the current replication instance.","ref":"AWS.DatabaseMigration.html#move_replication_task/3","title":"AWS.DatabaseMigration.move_replication_task/3","type":"function"},{"doc":"Reboots a replication instance.\n\nRebooting results in a momentary outage, until the replication instance becomes\navailable again.","ref":"AWS.DatabaseMigration.html#reboot_replication_instance/3","title":"AWS.DatabaseMigration.reboot_replication_instance/3","type":"function"},{"doc":"Populates the schema for the specified endpoint.\n\nThis is an asynchronous operation and can take several minutes. You can check\nthe status of this operation by calling the DescribeRefreshSchemasStatus\noperation.","ref":"AWS.DatabaseMigration.html#refresh_schemas/3","title":"AWS.DatabaseMigration.refresh_schemas/3","type":"function"},{"doc":"Reloads the target database table with the source data for a given DMS\nServerless replication configuration.\n\nYou can only use this operation with a task in the RUNNING state, otherwise the\nservice will throw an `InvalidResourceStateFault` exception.","ref":"AWS.DatabaseMigration.html#reload_replication_tables/3","title":"AWS.DatabaseMigration.reload_replication_tables/3","type":"function"},{"doc":"Reloads the target database table with the source data.\n\nYou can only use this operation with a task in the `RUNNING` state, otherwise\nthe service will throw an `InvalidResourceStateFault` exception.","ref":"AWS.DatabaseMigration.html#reload_tables/3","title":"AWS.DatabaseMigration.reload_tables/3","type":"function"},{"doc":"Removes metadata tags from an DMS resource, including replication instance,\nendpoint, subnet group, and migration task.\n\nFor more information, see [ `Tag`\n](https://docs.aws.amazon.com/dms/latest/APIReference/API_Tag.html) data type\ndescription.","ref":"AWS.DatabaseMigration.html#remove_tags_from_resource/3","title":"AWS.DatabaseMigration.remove_tags_from_resource/3","type":"function"},{"doc":"Runs large-scale assessment (LSA) analysis on every Fleet Advisor collector in\nyour account.","ref":"AWS.DatabaseMigration.html#run_fleet_advisor_lsa_analysis/3","title":"AWS.DatabaseMigration.run_fleet_advisor_lsa_analysis/3","type":"function"},{"doc":"Applies the extension pack to your target database.\n\nAn extension pack is an add-on module that emulates functions present in a\nsource database that are required when converting objects to the target\ndatabase.","ref":"AWS.DatabaseMigration.html#start_extension_pack_association/3","title":"AWS.DatabaseMigration.start_extension_pack_association/3","type":"function"},{"doc":"Creates a database migration assessment report by assessing the migration\ncomplexity for your source database.\n\nA database migration assessment report summarizes all of the schema conversion\ntasks. It also details the action items for database objects that can't be\nconverted to the database engine of your target database instance.","ref":"AWS.DatabaseMigration.html#start_metadata_model_assessment/3","title":"AWS.DatabaseMigration.start_metadata_model_assessment/3","type":"function"},{"doc":"Converts your source database objects to a format compatible with the target\ndatabase.","ref":"AWS.DatabaseMigration.html#start_metadata_model_conversion/3","title":"AWS.DatabaseMigration.start_metadata_model_conversion/3","type":"function"},{"doc":"Saves your converted code to a file as a SQL script, and stores this file on\nyour Amazon S3 bucket.","ref":"AWS.DatabaseMigration.html#start_metadata_model_export_as_script/3","title":"AWS.DatabaseMigration.start_metadata_model_export_as_script/3","type":"function"},{"doc":"Applies converted database objects to your target database.","ref":"AWS.DatabaseMigration.html#start_metadata_model_export_to_target/3","title":"AWS.DatabaseMigration.start_metadata_model_export_to_target/3","type":"function"},{"doc":"Loads the metadata for all the dependent database objects of the parent object.\n\nThis operation uses your project's Amazon S3 bucket as a metadata cache to\nimprove performance.","ref":"AWS.DatabaseMigration.html#start_metadata_model_import/3","title":"AWS.DatabaseMigration.start_metadata_model_import/3","type":"function"},{"doc":"Starts the analysis of your source database to provide recommendations of target\nengines.\n\nYou can create recommendations for multiple source databases using\n[BatchStartRecommendations](https://docs.aws.amazon.com/dms/latest/APIReference/API_BatchStartRecommendations.html).","ref":"AWS.DatabaseMigration.html#start_recommendations/3","title":"AWS.DatabaseMigration.start_recommendations/3","type":"function"},{"doc":"For a given DMS Serverless replication configuration, DMS connects to the source\nendpoint and collects the metadata to analyze the replication workload.\n\nUsing this metadata, DMS then computes and provisions the required capacity and\nstarts replicating to the target endpoint using the server resources that DMS\nhas provisioned for the DMS Serverless replication.","ref":"AWS.DatabaseMigration.html#start_replication/3","title":"AWS.DatabaseMigration.start_replication/3","type":"function"},{"doc":"Starts the replication task.\n\nFor more information about DMS tasks, see [Working with Migration Tasks\n](https://docs.aws.amazon.com/dms/latest/userguide/CHAP_Tasks.html) in the\n*Database Migration Service User Guide.*","ref":"AWS.DatabaseMigration.html#start_replication_task/3","title":"AWS.DatabaseMigration.start_replication_task/3","type":"function"},{"doc":"Starts the replication task assessment for unsupported data types in the source\ndatabase.\n\nYou can only use this operation for a task if the following conditions are true:\n\n  * The task must be in the `stopped` state.\n\n  * The task must have successful connections to the source and\ntarget.\n\nIf either of these conditions are not met, an `InvalidResourceStateFault` error\nwill result.\n\nFor information about DMS task assessments, see [Creating a task assessment report](https://docs.aws.amazon.com/dms/latest/userguide/CHAP_Tasks.AssessmentReport.html)\nin the *Database Migration Service User Guide*.","ref":"AWS.DatabaseMigration.html#start_replication_task_assessment/3","title":"AWS.DatabaseMigration.start_replication_task_assessment/3","type":"function"},{"doc":"Starts a new premigration assessment run for one or more individual assessments\nof a migration task.\n\nThe assessments that you can specify depend on the source and target database\nengine and the migration type defined for the given task. To run this operation,\nyour migration task must already be created. After you run this operation, you\ncan review the status of each individual assessment. You can also run the\nmigration task manually after the assessment run and its individual assessments\ncomplete.","ref":"AWS.DatabaseMigration.html#start_replication_task_assessment_run/3","title":"AWS.DatabaseMigration.start_replication_task_assessment_run/3","type":"function"},{"doc":"For a given DMS Serverless replication configuration, DMS stops any and all\nongoing DMS Serverless replications.\n\nThis command doesn't deprovision the stopped replications.","ref":"AWS.DatabaseMigration.html#stop_replication/3","title":"AWS.DatabaseMigration.stop_replication/3","type":"function"},{"doc":"Stops the replication task.","ref":"AWS.DatabaseMigration.html#stop_replication_task/3","title":"AWS.DatabaseMigration.stop_replication_task/3","type":"function"},{"doc":"Tests the connection between the replication instance and the endpoint.","ref":"AWS.DatabaseMigration.html#test_connection/3","title":"AWS.DatabaseMigration.test_connection/3","type":"function"},{"doc":"Migrates 10 active and enabled Amazon SNS subscriptions at a time and converts\nthem to corresponding Amazon EventBridge rules.\n\nBy default, this operation migrates subscriptions only when all your replication\ninstance versions are 3.4.5 or higher. If any replication instances are from\nversions earlier than 3.4.5, the operation raises an error and tells you to\nupgrade these instances to version 3.4.5 or higher. To enable migration\nregardless of version, set the `Force` option to true. However, if you don't\nupgrade instances earlier than version 3.4.5, some types of events might not be\navailable when you use Amazon EventBridge.\n\nTo call this operation, make sure that you have certain permissions added to\nyour user account. For more information, see [Migrating event subscriptions to Amazon\nEventBridge](https://docs.aws.amazon.com/dms/latest/userguide/CHAP_Events.html#CHAP_Events-migrate-to-eventbridge)\nin the *Amazon Web Services Database Migration Service User Guide*.","ref":"AWS.DatabaseMigration.html#update_subscriptions_to_event_bridge/3","title":"AWS.DatabaseMigration.update_subscriptions_to_event_bridge/3","type":"function"},{"doc":"Detective uses machine learning and purpose-built visualizations to help you to\nanalyze and investigate security issues across your Amazon Web Services (Amazon\nWeb Services) workloads.\n\nDetective automatically extracts time-based events such as login attempts, API\ncalls, and network traffic from CloudTrail and Amazon Virtual Private Cloud\n(Amazon VPC) flow logs. It also extracts findings detected by Amazon GuardDuty.\n\nThe Detective API primarily supports the creation and management of behavior\ngraphs. A behavior graph contains the extracted data from a set of member\naccounts, and is created and managed by an administrator account.\n\nTo add a member account to the behavior graph, the administrator account sends\nan invitation to the account. When the account accepts the invitation, it\nbecomes a member account in the behavior graph.\n\nDetective is also integrated with Organizations. The organization management\naccount designates the Detective administrator account for the organization.\nThat account becomes the administrator account for the organization behavior\ngraph. The Detective administrator account is also the delegated administrator\naccount for Detective in Organizations.\n\nThe Detective administrator account can enable any organization account as a\nmember account in the organization behavior graph. The organization accounts do\nnot receive invitations. The Detective administrator account can also invite\nother accounts to the organization behavior graph.\n\nEvery behavior graph is specific to a Region. You can only use the API to manage\nbehavior graphs that belong to the Region that is associated with the currently\nselected endpoint.\n\nThe administrator account for a behavior graph can use the Detective API to do\nthe following:\n\n  * Enable and disable Detective. Enabling Detective creates a new\nbehavior graph.\n\n  * View the list of member accounts in a behavior graph.\n\n  * Add member accounts to a behavior graph.\n\n  * Remove member accounts from a behavior graph.\n\n  * Apply tags to a behavior graph.\n\nThe organization management account can use the Detective API to select the\ndelegated administrator for Detective.\n\nThe Detective administrator account for an organization can use the Detective\nAPI to do the following:\n\n  * Perform all of the functions of an administrator account.\n\n  * Determine whether to automatically enable new organization\naccounts as member accounts in the organization behavior graph.\n\nAn invited member account can use the Detective API to do the following:\n\n  * View the list of behavior graphs that they are invited to.\n\n  * Accept an invitation to contribute to a behavior graph.\n\n  * Decline an invitation to contribute to a behavior graph.\n\n  * Remove their account from a behavior graph.\n\nAll API actions are logged as CloudTrail events. See [Logging Detective API Calls with\nCloudTrail](https://docs.aws.amazon.com/detective/latest/adminguide/logging-using-cloudtrail.html).\n\nWe replaced the term \"master account\" with the term \"administrator account.\" An\nadministrator account is used to centrally manage multiple accounts. In the case\nof Detective, the administrator account manages the accounts in their behavior\ngraph.","ref":"AWS.Detective.html","title":"AWS.Detective","type":"module"},{"doc":"Accepts an invitation for the member account to contribute data to a behavior\ngraph.\n\nThis operation can only be called by an invited member account.\n\nThe request provides the ARN of behavior graph.\n\nThe member account status in the graph must be `INVITED`.","ref":"AWS.Detective.html#accept_invitation/3","title":"AWS.Detective.accept_invitation/3","type":"function"},{"doc":"Gets data source package information for the behavior graph.","ref":"AWS.Detective.html#batch_get_graph_member_datasources/3","title":"AWS.Detective.batch_get_graph_member_datasources/3","type":"function"},{"doc":"Gets information on the data source package history for an account.","ref":"AWS.Detective.html#batch_get_membership_datasources/3","title":"AWS.Detective.batch_get_membership_datasources/3","type":"function"},{"doc":"Creates a new behavior graph for the calling account, and sets that account as\nthe administrator account.\n\nThis operation is called by the account that is enabling Detective.\n\nBefore you try to enable Detective, make sure that your account has been\nenrolled in Amazon GuardDuty for at least 48 hours. If you do not meet this\nrequirement, you cannot enable Detective. If you do meet the GuardDuty\nprerequisite, then when you make the request to enable Detective, it checks\nwhether your data volume is within the Detective quota. If it exceeds the quota,\nthen you cannot enable Detective.\n\nThe operation also enables Detective for the calling account in the currently\nselected Region. It returns the ARN of the new behavior graph.\n\n`CreateGraph` triggers a process to create the corresponding data tables for the\nnew behavior graph.\n\nAn account can only be the administrator account for one behavior graph within a\nRegion. If the same account calls `CreateGraph` with the same administrator\naccount, it always returns the same behavior graph ARN. It does not create a new\nbehavior graph.","ref":"AWS.Detective.html#create_graph/3","title":"AWS.Detective.create_graph/3","type":"function"},{"doc":"`CreateMembers` is used to send invitations to accounts.\n\nFor the organization behavior graph, the Detective administrator account uses\n`CreateMembers` to enable organization accounts as member accounts.\n\nFor invited accounts, `CreateMembers` sends a request to invite the specified\nAmazon Web Services accounts to be member accounts in the behavior graph. This\noperation can only be called by the administrator account for a behavior graph.\n\n`CreateMembers` verifies the accounts and then invites the verified accounts.\nThe administrator can optionally specify to not send invitation emails to the\nmember accounts. This would be used when the administrator manages their member\naccounts centrally.\n\nFor organization accounts in the organization behavior graph, `CreateMembers`\nattempts to enable the accounts. The organization accounts do not receive\ninvitations.\n\nThe request provides the behavior graph ARN and the list of accounts to invite\nor to enable.\n\nThe response separates the requested accounts into two lists:\n\n  * The accounts that `CreateMembers` was able to process. For invited\naccounts, includes member accounts that are being verified, that have passed\nverification and are to be invited, and that have failed verification. For\norganization accounts in the organization behavior graph, includes accounts that\ncan be enabled and that cannot be enabled.\n\n  * The accounts that `CreateMembers` was unable to process. This list\nincludes accounts that were already invited to be member accounts in the\nbehavior graph.","ref":"AWS.Detective.html#create_members/3","title":"AWS.Detective.create_members/3","type":"function"},{"doc":"Disables the specified behavior graph and queues it to be deleted.\n\nThis operation removes the behavior graph from each member account's list of\nbehavior graphs.\n\n`DeleteGraph` can only be called by the administrator account for a behavior\ngraph.","ref":"AWS.Detective.html#delete_graph/3","title":"AWS.Detective.delete_graph/3","type":"function"},{"doc":"Removes the specified member accounts from the behavior graph.\n\nThe removed accounts no longer contribute data to the behavior graph. This\noperation can only be called by the administrator account for the behavior\ngraph.\n\nFor invited accounts, the removed accounts are deleted from the list of accounts\nin the behavior graph. To restore the account, the administrator account must\nsend another invitation.\n\nFor organization accounts in the organization behavior graph, the Detective\nadministrator account can always enable the organization account again.\nOrganization accounts that are not enabled as member accounts are not included\nin the `ListMembers` results for the organization behavior graph.\n\nAn administrator account cannot use `DeleteMembers` to remove their own account\nfrom the behavior graph. To disable a behavior graph, the administrator account\nuses the `DeleteGraph` API method.","ref":"AWS.Detective.html#delete_members/3","title":"AWS.Detective.delete_members/3","type":"function"},{"doc":"Returns information about the configuration for the organization behavior graph.\n\nCurrently indicates whether to automatically enable new organization accounts as\nmember accounts.\n\nCan only be called by the Detective administrator account for the organization.","ref":"AWS.Detective.html#describe_organization_configuration/3","title":"AWS.Detective.describe_organization_configuration/3","type":"function"},{"doc":"Removes the Detective administrator account in the current Region.\n\nDeletes the organization behavior graph.\n\nCan only be called by the organization management account.\n\nRemoving the Detective administrator account does not affect the delegated\nadministrator account for Detective in Organizations.\n\nTo remove the delegated administrator account in Organizations, use the\nOrganizations API. Removing the delegated administrator account also removes the\nDetective administrator account in all Regions, except for Regions where the\nDetective administrator account is the organization management account.","ref":"AWS.Detective.html#disable_organization_admin_account/3","title":"AWS.Detective.disable_organization_admin_account/3","type":"function"},{"doc":"Removes the member account from the specified behavior graph.\n\nThis operation can only be called by an invited member account that has the\n`ENABLED` status.\n\n`DisassociateMembership` cannot be called by an organization account in the\norganization behavior graph. For the organization behavior graph, the Detective\nadministrator account determines which organization accounts to enable or\ndisable as member accounts.","ref":"AWS.Detective.html#disassociate_membership/3","title":"AWS.Detective.disassociate_membership/3","type":"function"},{"doc":"Designates the Detective administrator account for the organization in the\ncurrent Region.\n\nIf the account does not have Detective enabled, then enables Detective for that\naccount and creates a new behavior graph.\n\nCan only be called by the organization management account.\n\nIf the organization has a delegated administrator account in Organizations, then\nthe Detective administrator account must be either the delegated administrator\naccount or the organization management account.\n\nIf the organization does not have a delegated administrator account in\nOrganizations, then you can choose any account in the organization. If you\nchoose an account other than the organization management account, Detective\ncalls Organizations to make that account the delegated administrator account for\nDetective. The organization management account cannot be the delegated\nadministrator account.","ref":"AWS.Detective.html#enable_organization_admin_account/3","title":"AWS.Detective.enable_organization_admin_account/3","type":"function"},{"doc":"Returns the investigation results of an investigation for a behavior graph.","ref":"AWS.Detective.html#get_investigation/3","title":"AWS.Detective.get_investigation/3","type":"function"},{"doc":"Returns the membership details for specified member accounts for a behavior\ngraph.","ref":"AWS.Detective.html#get_members/3","title":"AWS.Detective.get_members/3","type":"function"},{"doc":"Lists data source packages in the behavior graph.","ref":"AWS.Detective.html#list_datasource_packages/3","title":"AWS.Detective.list_datasource_packages/3","type":"function"},{"doc":"Returns the list of behavior graphs that the calling account is an administrator\naccount of.\n\nThis operation can only be called by an administrator account.\n\nBecause an account can currently only be the administrator of one behavior graph\nwithin a Region, the results always contain a single behavior graph.","ref":"AWS.Detective.html#list_graphs/3","title":"AWS.Detective.list_graphs/3","type":"function"},{"doc":"Get the indicators from an investigation","ref":"AWS.Detective.html#list_indicators/3","title":"AWS.Detective.list_indicators/3","type":"function"},{"doc":"List all Investigations.","ref":"AWS.Detective.html#list_investigations/3","title":"AWS.Detective.list_investigations/3","type":"function"},{"doc":"Retrieves the list of open and accepted behavior graph invitations for the\nmember account.\n\nThis operation can only be called by an invited member account.\n\nOpen invitations are invitations that the member account has not responded to.\n\nThe results do not include behavior graphs for which the member account declined\nthe invitation. The results also do not include behavior graphs that the member\naccount resigned from or was removed from.","ref":"AWS.Detective.html#list_invitations/3","title":"AWS.Detective.list_invitations/3","type":"function"},{"doc":"Retrieves the list of member accounts for a behavior graph.\n\nFor invited accounts, the results do not include member accounts that were\nremoved from the behavior graph.\n\nFor the organization behavior graph, the results do not include organization\naccounts that the Detective administrator account has not enabled as member\naccounts.","ref":"AWS.Detective.html#list_members/3","title":"AWS.Detective.list_members/3","type":"function"},{"doc":"Returns information about the Detective administrator account for an\norganization.\n\nCan only be called by the organization management account.","ref":"AWS.Detective.html#list_organization_admin_accounts/3","title":"AWS.Detective.list_organization_admin_accounts/3","type":"function"},{"doc":"Returns the tag values that are assigned to a behavior graph.","ref":"AWS.Detective.html#list_tags_for_resource/3","title":"AWS.Detective.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.Detective.html#metadata/0","title":"AWS.Detective.metadata/0","type":"function"},{"doc":"Rejects an invitation to contribute the account data to a behavior graph.\n\nThis operation must be called by an invited member account that has the\n`INVITED` status.\n\n`RejectInvitation` cannot be called by an organization account in the\norganization behavior graph. In the organization behavior graph, organization\naccounts do not receive an invitation.","ref":"AWS.Detective.html#reject_invitation/3","title":"AWS.Detective.reject_invitation/3","type":"function"},{"doc":"initiate an investigation on an entity in a graph","ref":"AWS.Detective.html#start_investigation/3","title":"AWS.Detective.start_investigation/3","type":"function"},{"doc":"Sends a request to enable data ingest for a member account that has a status of\n`ACCEPTED_BUT_DISABLED`.\n\nFor valid member accounts, the status is updated as follows.\n\n  * If Detective enabled the member account, then the new status is\n`ENABLED`.\n\n  * If Detective cannot enable the member account, the status remains\n`ACCEPTED_BUT_DISABLED`.","ref":"AWS.Detective.html#start_monitoring_member/3","title":"AWS.Detective.start_monitoring_member/3","type":"function"},{"doc":"Applies tag values to a behavior graph.","ref":"AWS.Detective.html#tag_resource/4","title":"AWS.Detective.tag_resource/4","type":"function"},{"doc":"Removes tags from a behavior graph.","ref":"AWS.Detective.html#untag_resource/4","title":"AWS.Detective.untag_resource/4","type":"function"},{"doc":"Starts a data source packages for the behavior graph.","ref":"AWS.Detective.html#update_datasource_packages/3","title":"AWS.Detective.update_datasource_packages/3","type":"function"},{"doc":"Update the state of an investigation.","ref":"AWS.Detective.html#update_investigation_state/3","title":"AWS.Detective.update_investigation_state/3","type":"function"},{"doc":"Updates the configuration for the Organizations integration in the current\nRegion.\n\nCan only be called by the Detective administrator account for the organization.","ref":"AWS.Detective.html#update_organization_configuration/3","title":"AWS.Detective.update_organization_configuration/3","type":"function"},{"doc":"Amazon DevOps Guru is a fully managed service that helps you identify anomalous\nbehavior in business critical operational applications.\n\nYou specify the Amazon Web Services resources that you want DevOps Guru to\ncover, then the Amazon CloudWatch metrics and Amazon Web Services CloudTrail\nevents related to those resources are analyzed. When anomalous behavior is\ndetected, DevOps Guru creates an *insight* that includes recommendations,\nrelated events, and related metrics that can help you improve your operational\napplications. For more information, see [What is Amazon DevOps Guru](https://docs.aws.amazon.com/devops-guru/latest/userguide/welcome.html).\n\nYou can specify 1 or 2 Amazon Simple Notification Service topics so you are\nnotified every time a new insight is created. You can also enable DevOps Guru to\ngenerate an OpsItem in Amazon Web Services Systems Manager for each insight to\nhelp you manage and track your work addressing insights.\n\nTo learn about the DevOps Guru workflow, see [How DevOps Guru works](https://docs.aws.amazon.com/devops-guru/latest/userguide/welcome.html#how-it-works).\nTo learn about DevOps Guru concepts, see [Concepts in DevOps Guru](https://docs.aws.amazon.com/devops-guru/latest/userguide/concepts.html).","ref":"AWS.DevOpsGuru.html","title":"AWS.DevOpsGuru","type":"module"},{"doc":"Adds a notification channel to DevOps Guru.\n\nA notification channel is used to notify you about important DevOps Guru events,\nsuch as when an insight is generated.\n\nIf you use an Amazon SNS topic in another account, you must attach a policy to\nit that grants DevOps Guru permission to send it notifications. DevOps Guru adds\nthe required policy on your behalf to send notifications using Amazon SNS in\nyour account. DevOps Guru only supports standard SNS topics. For more\ninformation, see [Permissions for Amazon SNS topics](https://docs.aws.amazon.com/devops-guru/latest/userguide/sns-required-permissions.html).\n\nIf you use an Amazon SNS topic that is encrypted by an Amazon Web Services Key\nManagement Service customer-managed key (CMK), then you must add permissions to\nthe CMK. For more information, see [Permissions for Amazon Web Services KMS–encrypted Amazon SNS\ntopics](https://docs.aws.amazon.com/devops-guru/latest/userguide/sns-kms-permissions.html).","ref":"AWS.DevOpsGuru.html#add_notification_channel/3","title":"AWS.DevOpsGuru.add_notification_channel/3","type":"function"},{"doc":"Deletes the insight along with the associated anomalies, events and\nrecommendations.","ref":"AWS.DevOpsGuru.html#delete_insight/4","title":"AWS.DevOpsGuru.delete_insight/4","type":"function"},{"doc":"Returns the number of open reactive insights, the number of open proactive\ninsights, and the number of metrics analyzed in your Amazon Web Services\naccount.\n\nUse these numbers to gauge the health of operations in your Amazon Web Services\naccount.","ref":"AWS.DevOpsGuru.html#describe_account_health/2","title":"AWS.DevOpsGuru.describe_account_health/2","type":"function"},{"doc":"For the time range passed in, returns the number of open reactive insight that\nwere created, the number of open proactive insights that were created, and the\nMean Time to Recover (MTTR) for all closed reactive insights.","ref":"AWS.DevOpsGuru.html#describe_account_overview/3","title":"AWS.DevOpsGuru.describe_account_overview/3","type":"function"},{"doc":"Returns details about an anomaly that you specify using its ID.","ref":"AWS.DevOpsGuru.html#describe_anomaly/4","title":"AWS.DevOpsGuru.describe_anomaly/4","type":"function"},{"doc":"Returns the integration status of services that are integrated with DevOps Guru\nas Consumer via EventBridge.\n\nThe one service that can be integrated with DevOps Guru is Amazon CodeGuru\nProfiler, which can produce proactive recommendations which can be stored and\nviewed in DevOps Guru.","ref":"AWS.DevOpsGuru.html#describe_event_sources_config/3","title":"AWS.DevOpsGuru.describe_event_sources_config/3","type":"function"},{"doc":"Returns the most recent feedback submitted in the current Amazon Web Services\naccount and Region.","ref":"AWS.DevOpsGuru.html#describe_feedback/3","title":"AWS.DevOpsGuru.describe_feedback/3","type":"function"},{"doc":"Returns details about an insight that you specify using its ID.","ref":"AWS.DevOpsGuru.html#describe_insight/4","title":"AWS.DevOpsGuru.describe_insight/4","type":"function"},{"doc":"Returns active insights, predictive insights, and resource hours analyzed in\nlast hour.","ref":"AWS.DevOpsGuru.html#describe_organization_health/3","title":"AWS.DevOpsGuru.describe_organization_health/3","type":"function"},{"doc":"Returns an overview of your organization's history based on the specified time\nrange.\n\nThe overview includes the total reactive and proactive insights.","ref":"AWS.DevOpsGuru.html#describe_organization_overview/3","title":"AWS.DevOpsGuru.describe_organization_overview/3","type":"function"},{"doc":"Provides an overview of your system's health.\n\nIf additional member accounts are part of your organization, you can filter\nthose accounts using the `AccountIds` field.","ref":"AWS.DevOpsGuru.html#describe_organization_resource_collection_health/3","title":"AWS.DevOpsGuru.describe_organization_resource_collection_health/3","type":"function"},{"doc":"Returns the number of open proactive insights, open reactive insights, and the\nMean Time to Recover (MTTR) for all closed insights in resource collections in\nyour account.\n\nYou specify the type of Amazon Web Services resources collection. The two types\nof Amazon Web Services resource collections supported are Amazon Web Services\nCloudFormation stacks and Amazon Web Services resources that contain the same\nAmazon Web Services tag. DevOps Guru can be configured to analyze the Amazon Web\nServices resources that are defined in the stacks or that are tagged using the\nsame tag *key*. You can specify up to 500 Amazon Web Services CloudFormation\nstacks.","ref":"AWS.DevOpsGuru.html#describe_resource_collection_health/4","title":"AWS.DevOpsGuru.describe_resource_collection_health/4","type":"function"},{"doc":"Returns the integration status of services that are integrated with DevOps Guru.\n\nThe one service that can be integrated with DevOps Guru is Amazon Web Services\nSystems Manager, which can be used to create an OpsItem for each generated\ninsight.","ref":"AWS.DevOpsGuru.html#describe_service_integration/2","title":"AWS.DevOpsGuru.describe_service_integration/2","type":"function"},{"doc":"Returns an estimate of the monthly cost for DevOps Guru to analyze your Amazon\nWeb Services resources.\n\nFor more information, see [Estimate your Amazon DevOps Guru costs](https://docs.aws.amazon.com/devops-guru/latest/userguide/cost-estimate.html)\nand [Amazon DevOps Guru pricing](http://aws.amazon.com/devops-guru/pricing/).","ref":"AWS.DevOpsGuru.html#get_cost_estimation/3","title":"AWS.DevOpsGuru.get_cost_estimation/3","type":"function"},{"doc":"Returns lists Amazon Web Services resources that are of the specified resource\ncollection type.\n\nThe two types of Amazon Web Services resource collections supported are Amazon\nWeb Services CloudFormation stacks and Amazon Web Services resources that\ncontain the same Amazon Web Services tag. DevOps Guru can be configured to\nanalyze the Amazon Web Services resources that are defined in the stacks or that\nare tagged using the same tag *key*. You can specify up to 500 Amazon Web\nServices CloudFormation stacks.","ref":"AWS.DevOpsGuru.html#get_resource_collection/4","title":"AWS.DevOpsGuru.get_resource_collection/4","type":"function"},{"doc":"Returns a list of the anomalies that belong to an insight that you specify using\nits ID.","ref":"AWS.DevOpsGuru.html#list_anomalies_for_insight/4","title":"AWS.DevOpsGuru.list_anomalies_for_insight/4","type":"function"},{"doc":"Returns the list of log groups that contain log anomalies.","ref":"AWS.DevOpsGuru.html#list_anomalous_log_groups/3","title":"AWS.DevOpsGuru.list_anomalous_log_groups/3","type":"function"},{"doc":"Returns a list of the events emitted by the resources that are evaluated by\nDevOps Guru.\n\nYou can use filters to specify which events are returned.","ref":"AWS.DevOpsGuru.html#list_events/3","title":"AWS.DevOpsGuru.list_events/3","type":"function"},{"doc":"Returns a list of insights in your Amazon Web Services account.\n\nYou can specify which insights are returned by their start time and status\n(`ONGOING`, `CLOSED`, or `ANY`).","ref":"AWS.DevOpsGuru.html#list_insights/3","title":"AWS.DevOpsGuru.list_insights/3","type":"function"},{"doc":"Returns the list of all log groups that are being monitored and tagged by DevOps\nGuru.","ref":"AWS.DevOpsGuru.html#list_monitored_resources/3","title":"AWS.DevOpsGuru.list_monitored_resources/3","type":"function"},{"doc":"Returns a list of notification channels configured for DevOps Guru.\n\nEach notification channel is used to notify you when DevOps Guru generates an\ninsight that contains information about how to improve your operations. The one\nsupported notification channel is Amazon Simple Notification Service (Amazon\nSNS).","ref":"AWS.DevOpsGuru.html#list_notification_channels/3","title":"AWS.DevOpsGuru.list_notification_channels/3","type":"function"},{"doc":"Returns a list of insights associated with the account or OU Id.","ref":"AWS.DevOpsGuru.html#list_organization_insights/3","title":"AWS.DevOpsGuru.list_organization_insights/3","type":"function"},{"doc":"Returns a list of a specified insight's recommendations.\n\nEach recommendation includes a list of related metrics and a list of related\nevents.","ref":"AWS.DevOpsGuru.html#list_recommendations/3","title":"AWS.DevOpsGuru.list_recommendations/3","type":"function"},{"doc":"","ref":"AWS.DevOpsGuru.html#metadata/0","title":"AWS.DevOpsGuru.metadata/0","type":"function"},{"doc":"Collects customer feedback about the specified insight.","ref":"AWS.DevOpsGuru.html#put_feedback/3","title":"AWS.DevOpsGuru.put_feedback/3","type":"function"},{"doc":"Removes a notification channel from DevOps Guru.\n\nA notification channel is used to notify you when DevOps Guru generates an\ninsight that contains information about how to improve your operations.","ref":"AWS.DevOpsGuru.html#remove_notification_channel/4","title":"AWS.DevOpsGuru.remove_notification_channel/4","type":"function"},{"doc":"Returns a list of insights in your Amazon Web Services account.\n\nYou can specify which insights are returned by their start time, one or more\nstatuses (`ONGOING` or `CLOSED`), one or more severities (`LOW`, `MEDIUM`, and\n`HIGH`), and type (`REACTIVE` or `PROACTIVE`).\n\nUse the `Filters` parameter to specify status and severity search parameters.\nUse the `Type` parameter to specify `REACTIVE` or `PROACTIVE` in your search.","ref":"AWS.DevOpsGuru.html#search_insights/3","title":"AWS.DevOpsGuru.search_insights/3","type":"function"},{"doc":"Returns a list of insights in your organization.\n\nYou can specify which insights are returned by their start time, one or more\nstatuses (`ONGOING`, `CLOSED`, and `CLOSED`), one or more severities (`LOW`,\n`MEDIUM`, and `HIGH`), and type (`REACTIVE` or `PROACTIVE`).\n\nUse the `Filters` parameter to specify status and severity search parameters.\nUse the `Type` parameter to specify `REACTIVE` or `PROACTIVE` in your search.","ref":"AWS.DevOpsGuru.html#search_organization_insights/3","title":"AWS.DevOpsGuru.search_organization_insights/3","type":"function"},{"doc":"Starts the creation of an estimate of the monthly cost to analyze your Amazon\nWeb Services resources.","ref":"AWS.DevOpsGuru.html#start_cost_estimation/3","title":"AWS.DevOpsGuru.start_cost_estimation/3","type":"function"},{"doc":"Enables or disables integration with a service that can be integrated with\nDevOps Guru.\n\nThe one service that can be integrated with DevOps Guru is Amazon CodeGuru\nProfiler, which can produce proactive recommendations which can be stored and\nviewed in DevOps Guru.","ref":"AWS.DevOpsGuru.html#update_event_sources_config/3","title":"AWS.DevOpsGuru.update_event_sources_config/3","type":"function"},{"doc":"Updates the collection of resources that DevOps Guru analyzes.\n\nThe two types of Amazon Web Services resource collections supported are Amazon\nWeb Services CloudFormation stacks and Amazon Web Services resources that\ncontain the same Amazon Web Services tag. DevOps Guru can be configured to\nanalyze the Amazon Web Services resources that are defined in the stacks or that\nare tagged using the same tag *key*. You can specify up to 500 Amazon Web\nServices CloudFormation stacks. This method also creates the IAM role required\nfor you to use DevOps Guru.","ref":"AWS.DevOpsGuru.html#update_resource_collection/3","title":"AWS.DevOpsGuru.update_resource_collection/3","type":"function"},{"doc":"Enables or disables integration with a service that can be integrated with\nDevOps Guru.\n\nThe one service that can be integrated with DevOps Guru is Amazon Web Services\nSystems Manager, which can be used to create an OpsItem for each generated\ninsight.","ref":"AWS.DevOpsGuru.html#update_service_integration/3","title":"AWS.DevOpsGuru.update_service_integration/3","type":"function"},{"doc":"Welcome to the AWS Device Farm API documentation, which contains APIs for:\n\n  * Testing on desktop browsers\n\nDevice Farm makes it possible for you to test your web applications on desktop\nbrowsers using Selenium.\n\nThe APIs for desktop browser testing contain `TestGrid` in their names. For more\ninformation, see [Testing Web Applications on Selenium with Device Farm](https://docs.aws.amazon.com/devicefarm/latest/testgrid/).\n\n  * Testing on real mobile devices\n\nDevice Farm makes it possible for you to test apps on physical phones, tablets,\nand other devices in the cloud. For more information, see the [Device Farm Developer Guide](https://docs.aws.amazon.com/devicefarm/latest/developerguide/).","ref":"AWS.DeviceFarm.html","title":"AWS.DeviceFarm","type":"module"},{"doc":"Creates a device pool.","ref":"AWS.DeviceFarm.html#create_device_pool/3","title":"AWS.DeviceFarm.create_device_pool/3","type":"function"},{"doc":"Creates a profile that can be applied to one or more private fleet device\ninstances.","ref":"AWS.DeviceFarm.html#create_instance_profile/3","title":"AWS.DeviceFarm.create_instance_profile/3","type":"function"},{"doc":"Creates a network profile.","ref":"AWS.DeviceFarm.html#create_network_profile/3","title":"AWS.DeviceFarm.create_network_profile/3","type":"function"},{"doc":"Creates a project.","ref":"AWS.DeviceFarm.html#create_project/3","title":"AWS.DeviceFarm.create_project/3","type":"function"},{"doc":"Specifies and starts a remote access session.","ref":"AWS.DeviceFarm.html#create_remote_access_session/3","title":"AWS.DeviceFarm.create_remote_access_session/3","type":"function"},{"doc":"Creates a Selenium testing project.\n\nProjects are used to track `TestGridSession` instances.","ref":"AWS.DeviceFarm.html#create_test_grid_project/3","title":"AWS.DeviceFarm.create_test_grid_project/3","type":"function"},{"doc":"Creates a signed, short-term URL that can be passed to a Selenium\n`RemoteWebDriver` constructor.","ref":"AWS.DeviceFarm.html#create_test_grid_url/3","title":"AWS.DeviceFarm.create_test_grid_url/3","type":"function"},{"doc":"Uploads an app or test scripts.","ref":"AWS.DeviceFarm.html#create_upload/3","title":"AWS.DeviceFarm.create_upload/3","type":"function"},{"doc":"Creates a configuration record in Device Farm for your Amazon Virtual Private\nCloud (VPC) endpoint.","ref":"AWS.DeviceFarm.html#create_vpce_configuration/3","title":"AWS.DeviceFarm.create_vpce_configuration/3","type":"function"},{"doc":"Deletes a device pool given the pool ARN.\n\nDoes not allow deletion of curated pools owned by the system.","ref":"AWS.DeviceFarm.html#delete_device_pool/3","title":"AWS.DeviceFarm.delete_device_pool/3","type":"function"},{"doc":"Deletes a profile that can be applied to one or more private device instances.","ref":"AWS.DeviceFarm.html#delete_instance_profile/3","title":"AWS.DeviceFarm.delete_instance_profile/3","type":"function"},{"doc":"Deletes a network profile.","ref":"AWS.DeviceFarm.html#delete_network_profile/3","title":"AWS.DeviceFarm.delete_network_profile/3","type":"function"},{"doc":"Deletes an AWS Device Farm project, given the project ARN.\n\nDeleting this resource does not stop an in-progress run.","ref":"AWS.DeviceFarm.html#delete_project/3","title":"AWS.DeviceFarm.delete_project/3","type":"function"},{"doc":"Deletes a completed remote access session and its results.","ref":"AWS.DeviceFarm.html#delete_remote_access_session/3","title":"AWS.DeviceFarm.delete_remote_access_session/3","type":"function"},{"doc":"Deletes the run, given the run ARN.\n\nDeleting this resource does not stop an in-progress run.","ref":"AWS.DeviceFarm.html#delete_run/3","title":"AWS.DeviceFarm.delete_run/3","type":"function"},{"doc":"Deletes a Selenium testing project and all content generated under it.\n\nYou cannot undo this operation.\n\nYou cannot delete a project if it has active sessions.","ref":"AWS.DeviceFarm.html#delete_test_grid_project/3","title":"AWS.DeviceFarm.delete_test_grid_project/3","type":"function"},{"doc":"Deletes an upload given the upload ARN.","ref":"AWS.DeviceFarm.html#delete_upload/3","title":"AWS.DeviceFarm.delete_upload/3","type":"function"},{"doc":"Deletes a configuration for your Amazon Virtual Private Cloud (VPC) endpoint.","ref":"AWS.DeviceFarm.html#delete_vpce_configuration/3","title":"AWS.DeviceFarm.delete_vpce_configuration/3","type":"function"},{"doc":"Returns the number of unmetered iOS or unmetered Android devices that have been\npurchased by the account.","ref":"AWS.DeviceFarm.html#get_account_settings/3","title":"AWS.DeviceFarm.get_account_settings/3","type":"function"},{"doc":"Gets information about a unique device type.","ref":"AWS.DeviceFarm.html#get_device/3","title":"AWS.DeviceFarm.get_device/3","type":"function"},{"doc":"Returns information about a device instance that belongs to a private device\nfleet.","ref":"AWS.DeviceFarm.html#get_device_instance/3","title":"AWS.DeviceFarm.get_device_instance/3","type":"function"},{"doc":"Gets information about a device pool.","ref":"AWS.DeviceFarm.html#get_device_pool/3","title":"AWS.DeviceFarm.get_device_pool/3","type":"function"},{"doc":"Gets information about compatibility with a device pool.","ref":"AWS.DeviceFarm.html#get_device_pool_compatibility/3","title":"AWS.DeviceFarm.get_device_pool_compatibility/3","type":"function"},{"doc":"Returns information about the specified instance profile.","ref":"AWS.DeviceFarm.html#get_instance_profile/3","title":"AWS.DeviceFarm.get_instance_profile/3","type":"function"},{"doc":"Gets information about a job.","ref":"AWS.DeviceFarm.html#get_job/3","title":"AWS.DeviceFarm.get_job/3","type":"function"},{"doc":"Returns information about a network profile.","ref":"AWS.DeviceFarm.html#get_network_profile/3","title":"AWS.DeviceFarm.get_network_profile/3","type":"function"},{"doc":"Gets the current status and future status of all offerings purchased by an AWS\naccount.\n\nThe response indicates how many offerings are currently available and the\nofferings that will be available in the next period. The API returns a\n`NotEligible` error if the user is not permitted to invoke the operation. If you\nmust be able to invoke this operation, contact\n[aws-devicefarm-support@amazon.com](mailto:aws-devicefarm-support@amazon.com).","ref":"AWS.DeviceFarm.html#get_offering_status/3","title":"AWS.DeviceFarm.get_offering_status/3","type":"function"},{"doc":"Gets information about a project.","ref":"AWS.DeviceFarm.html#get_project/3","title":"AWS.DeviceFarm.get_project/3","type":"function"},{"doc":"Returns a link to a currently running remote access session.","ref":"AWS.DeviceFarm.html#get_remote_access_session/3","title":"AWS.DeviceFarm.get_remote_access_session/3","type":"function"},{"doc":"Gets information about a run.","ref":"AWS.DeviceFarm.html#get_run/3","title":"AWS.DeviceFarm.get_run/3","type":"function"},{"doc":"Gets information about a suite.","ref":"AWS.DeviceFarm.html#get_suite/3","title":"AWS.DeviceFarm.get_suite/3","type":"function"},{"doc":"Gets information about a test.","ref":"AWS.DeviceFarm.html#get_test/3","title":"AWS.DeviceFarm.get_test/3","type":"function"},{"doc":"Retrieves information about a Selenium testing project.","ref":"AWS.DeviceFarm.html#get_test_grid_project/3","title":"AWS.DeviceFarm.get_test_grid_project/3","type":"function"},{"doc":"A session is an instance of a browser created through a `RemoteWebDriver` with\nthe URL from `CreateTestGridUrlResult$url`.\n\nYou can use the following to look up sessions:\n\n  * The session ARN (`GetTestGridSessionRequest$sessionArn`).\n\n  * The project ARN and a session ID\n(`GetTestGridSessionRequest$projectArn` and\n`GetTestGridSessionRequest$sessionId`).","ref":"AWS.DeviceFarm.html#get_test_grid_session/3","title":"AWS.DeviceFarm.get_test_grid_session/3","type":"function"},{"doc":"Gets information about an upload.","ref":"AWS.DeviceFarm.html#get_upload/3","title":"AWS.DeviceFarm.get_upload/3","type":"function"},{"doc":"Returns information about the configuration settings for your Amazon Virtual\nPrivate Cloud (VPC) endpoint.","ref":"AWS.DeviceFarm.html#get_vpce_configuration/3","title":"AWS.DeviceFarm.get_vpce_configuration/3","type":"function"},{"doc":"Installs an application to the device in a remote access session.\n\nFor Android applications, the file must be in .apk format. For iOS applications,\nthe file must be in .ipa format.","ref":"AWS.DeviceFarm.html#install_to_remote_access_session/3","title":"AWS.DeviceFarm.install_to_remote_access_session/3","type":"function"},{"doc":"Gets information about artifacts.","ref":"AWS.DeviceFarm.html#list_artifacts/3","title":"AWS.DeviceFarm.list_artifacts/3","type":"function"},{"doc":"Returns information about the private device instances associated with one or\nmore AWS accounts.","ref":"AWS.DeviceFarm.html#list_device_instances/3","title":"AWS.DeviceFarm.list_device_instances/3","type":"function"},{"doc":"Gets information about device pools.","ref":"AWS.DeviceFarm.html#list_device_pools/3","title":"AWS.DeviceFarm.list_device_pools/3","type":"function"},{"doc":"Gets information about unique device types.","ref":"AWS.DeviceFarm.html#list_devices/3","title":"AWS.DeviceFarm.list_devices/3","type":"function"},{"doc":"Returns information about all the instance profiles in an AWS account.","ref":"AWS.DeviceFarm.html#list_instance_profiles/3","title":"AWS.DeviceFarm.list_instance_profiles/3","type":"function"},{"doc":"Gets information about jobs for a given test run.","ref":"AWS.DeviceFarm.html#list_jobs/3","title":"AWS.DeviceFarm.list_jobs/3","type":"function"},{"doc":"Returns the list of available network profiles.","ref":"AWS.DeviceFarm.html#list_network_profiles/3","title":"AWS.DeviceFarm.list_network_profiles/3","type":"function"},{"doc":"Returns a list of offering promotions.\n\nEach offering promotion record contains the ID and description of the promotion.\nThe API returns a `NotEligible` error if the caller is not permitted to invoke\nthe operation. Contact\n[aws-devicefarm-support@amazon.com](mailto:aws-devicefarm-support@amazon.com) if\nyou must be able to invoke this operation.","ref":"AWS.DeviceFarm.html#list_offering_promotions/3","title":"AWS.DeviceFarm.list_offering_promotions/3","type":"function"},{"doc":"Returns a list of all historical purchases, renewals, and system renewal\ntransactions for an AWS account.\n\nThe list is paginated and ordered by a descending timestamp (most recent\ntransactions are first). The API returns a `NotEligible` error if the user is\nnot permitted to invoke the operation. If you must be able to invoke this\noperation, contact\n[aws-devicefarm-support@amazon.com](mailto:aws-devicefarm-support@amazon.com).","ref":"AWS.DeviceFarm.html#list_offering_transactions/3","title":"AWS.DeviceFarm.list_offering_transactions/3","type":"function"},{"doc":"Returns a list of products or offerings that the user can manage through the\nAPI.\n\nEach offering record indicates the recurring price per unit and the frequency\nfor that offering. The API returns a `NotEligible` error if the user is not\npermitted to invoke the operation. If you must be able to invoke this operation,\ncontact\n[aws-devicefarm-support@amazon.com](mailto:aws-devicefarm-support@amazon.com).","ref":"AWS.DeviceFarm.html#list_offerings/3","title":"AWS.DeviceFarm.list_offerings/3","type":"function"},{"doc":"Gets information about projects.","ref":"AWS.DeviceFarm.html#list_projects/3","title":"AWS.DeviceFarm.list_projects/3","type":"function"},{"doc":"Returns a list of all currently running remote access sessions.","ref":"AWS.DeviceFarm.html#list_remote_access_sessions/3","title":"AWS.DeviceFarm.list_remote_access_sessions/3","type":"function"},{"doc":"Gets information about runs, given an AWS Device Farm project ARN.","ref":"AWS.DeviceFarm.html#list_runs/3","title":"AWS.DeviceFarm.list_runs/3","type":"function"},{"doc":"Gets information about samples, given an AWS Device Farm job ARN.","ref":"AWS.DeviceFarm.html#list_samples/3","title":"AWS.DeviceFarm.list_samples/3","type":"function"},{"doc":"Gets information about test suites for a given job.","ref":"AWS.DeviceFarm.html#list_suites/3","title":"AWS.DeviceFarm.list_suites/3","type":"function"},{"doc":"List the tags for an AWS Device Farm resource.","ref":"AWS.DeviceFarm.html#list_tags_for_resource/3","title":"AWS.DeviceFarm.list_tags_for_resource/3","type":"function"},{"doc":"Gets a list of all Selenium testing projects in your account.","ref":"AWS.DeviceFarm.html#list_test_grid_projects/3","title":"AWS.DeviceFarm.list_test_grid_projects/3","type":"function"},{"doc":"Returns a list of the actions taken in a `TestGridSession`.","ref":"AWS.DeviceFarm.html#list_test_grid_session_actions/3","title":"AWS.DeviceFarm.list_test_grid_session_actions/3","type":"function"},{"doc":"Retrieves a list of artifacts created during the session.","ref":"AWS.DeviceFarm.html#list_test_grid_session_artifacts/3","title":"AWS.DeviceFarm.list_test_grid_session_artifacts/3","type":"function"},{"doc":"Retrieves a list of sessions for a `TestGridProject`.","ref":"AWS.DeviceFarm.html#list_test_grid_sessions/3","title":"AWS.DeviceFarm.list_test_grid_sessions/3","type":"function"},{"doc":"Gets information about tests in a given test suite.","ref":"AWS.DeviceFarm.html#list_tests/3","title":"AWS.DeviceFarm.list_tests/3","type":"function"},{"doc":"Gets information about unique problems, such as exceptions or crashes.\n\nUnique problems are defined as a single instance of an error across a run, job,\nor suite. For example, if a call in your application consistently raises an\nexception (`OutOfBoundsException in MyActivity.java:386`), `ListUniqueProblems`\nreturns a single entry instead of many individual entries for that exception.","ref":"AWS.DeviceFarm.html#list_unique_problems/3","title":"AWS.DeviceFarm.list_unique_problems/3","type":"function"},{"doc":"Gets information about uploads, given an AWS Device Farm project ARN.","ref":"AWS.DeviceFarm.html#list_uploads/3","title":"AWS.DeviceFarm.list_uploads/3","type":"function"},{"doc":"Returns information about all Amazon Virtual Private Cloud (VPC) endpoint\nconfigurations in the AWS account.","ref":"AWS.DeviceFarm.html#list_vpce_configurations/3","title":"AWS.DeviceFarm.list_vpce_configurations/3","type":"function"},{"doc":"","ref":"AWS.DeviceFarm.html#metadata/0","title":"AWS.DeviceFarm.metadata/0","type":"function"},{"doc":"Immediately purchases offerings for an AWS account.\n\nOfferings renew with the latest total purchased quantity for an offering, unless\nthe renewal was overridden. The API returns a `NotEligible` error if the user is\nnot permitted to invoke the operation. If you must be able to invoke this\noperation, contact\n[aws-devicefarm-support@amazon.com](mailto:aws-devicefarm-support@amazon.com).","ref":"AWS.DeviceFarm.html#purchase_offering/3","title":"AWS.DeviceFarm.purchase_offering/3","type":"function"},{"doc":"Explicitly sets the quantity of devices to renew for an offering, starting from\nthe `effectiveDate` of the next period.\n\nThe API returns a `NotEligible` error if the user is not permitted to invoke the\noperation. If you must be able to invoke this operation, contact\n[aws-devicefarm-support@amazon.com](mailto:aws-devicefarm-support@amazon.com).","ref":"AWS.DeviceFarm.html#renew_offering/3","title":"AWS.DeviceFarm.renew_offering/3","type":"function"},{"doc":"Schedules a run.","ref":"AWS.DeviceFarm.html#schedule_run/3","title":"AWS.DeviceFarm.schedule_run/3","type":"function"},{"doc":"Initiates a stop request for the current job.\n\nAWS Device Farm immediately stops the job on the device where tests have not\nstarted. You are not billed for this device. On the device where tests have\nstarted, setup suite and teardown suite tests run to completion on the device.\nYou are billed for setup, teardown, and any tests that were in progress or\nalready completed.","ref":"AWS.DeviceFarm.html#stop_job/3","title":"AWS.DeviceFarm.stop_job/3","type":"function"},{"doc":"Ends a specified remote access session.","ref":"AWS.DeviceFarm.html#stop_remote_access_session/3","title":"AWS.DeviceFarm.stop_remote_access_session/3","type":"function"},{"doc":"Initiates a stop request for the current test run.\n\nAWS Device Farm immediately stops the run on devices where tests have not\nstarted. You are not billed for these devices. On devices where tests have\nstarted executing, setup suite and teardown suite tests run to completion on\nthose devices. You are billed for setup, teardown, and any tests that were in\nprogress or already completed.","ref":"AWS.DeviceFarm.html#stop_run/3","title":"AWS.DeviceFarm.stop_run/3","type":"function"},{"doc":"Associates the specified tags to a resource with the specified `resourceArn`.\n\nIf existing tags on a resource are not specified in the request parameters, they\nare not changed. When a resource is deleted, the tags associated with that\nresource are also deleted.","ref":"AWS.DeviceFarm.html#tag_resource/3","title":"AWS.DeviceFarm.tag_resource/3","type":"function"},{"doc":"Deletes the specified tags from a resource.","ref":"AWS.DeviceFarm.html#untag_resource/3","title":"AWS.DeviceFarm.untag_resource/3","type":"function"},{"doc":"Updates information about a private device instance.","ref":"AWS.DeviceFarm.html#update_device_instance/3","title":"AWS.DeviceFarm.update_device_instance/3","type":"function"},{"doc":"Modifies the name, description, and rules in a device pool given the attributes\nand the pool ARN.\n\nRule updates are all-or-nothing, meaning they can only be updated as a whole (or\nnot at all).","ref":"AWS.DeviceFarm.html#update_device_pool/3","title":"AWS.DeviceFarm.update_device_pool/3","type":"function"},{"doc":"Updates information about an existing private device instance profile.","ref":"AWS.DeviceFarm.html#update_instance_profile/3","title":"AWS.DeviceFarm.update_instance_profile/3","type":"function"},{"doc":"Updates the network profile.","ref":"AWS.DeviceFarm.html#update_network_profile/3","title":"AWS.DeviceFarm.update_network_profile/3","type":"function"},{"doc":"Modifies the specified project name, given the project ARN and a new name.","ref":"AWS.DeviceFarm.html#update_project/3","title":"AWS.DeviceFarm.update_project/3","type":"function"},{"doc":"Change details of a project.","ref":"AWS.DeviceFarm.html#update_test_grid_project/3","title":"AWS.DeviceFarm.update_test_grid_project/3","type":"function"},{"doc":"Updates an uploaded test spec.","ref":"AWS.DeviceFarm.html#update_upload/3","title":"AWS.DeviceFarm.update_upload/3","type":"function"},{"doc":"Updates information about an Amazon Virtual Private Cloud (VPC) endpoint\nconfiguration.","ref":"AWS.DeviceFarm.html#update_vpce_configuration/3","title":"AWS.DeviceFarm.update_vpce_configuration/3","type":"function"},{"doc":"Direct Connect links your internal network to an Direct Connect location over a\nstandard Ethernet fiber-optic cable.\n\nOne end of the cable is connected to your router, the other to an Direct Connect\nrouter. With this connection in place, you can create virtual interfaces\ndirectly to the Amazon Web Services Cloud (for example, to Amazon EC2 and Amazon\nS3) and to Amazon VPC, bypassing Internet service providers in your network\npath. A connection provides access to all Amazon Web Services Regions except the\nChina (Beijing) and (China) Ningxia Regions. Amazon Web Services resources in\nthe China Regions can only be accessed through locations associated with those\nRegions.","ref":"AWS.DirectConnect.html","title":"AWS.DirectConnect","type":"module"},{"doc":"Accepts a proposal request to attach a virtual private gateway or transit\ngateway to a Direct Connect gateway.","ref":"AWS.DirectConnect.html#accept_direct_connect_gateway_association_proposal/3","title":"AWS.DirectConnect.accept_direct_connect_gateway_association_proposal/3","type":"function"},{"doc":"Deprecated.\n\nUse `AllocateHostedConnection` instead.\n\nCreates a hosted connection on an interconnect.\n\nAllocates a VLAN number and a specified amount of bandwidth for use by a hosted\nconnection on the specified interconnect.\n\nIntended for use by Direct Connect Partners only.","ref":"AWS.DirectConnect.html#allocate_connection_on_interconnect/3","title":"AWS.DirectConnect.allocate_connection_on_interconnect/3","type":"function"},{"doc":"Creates a hosted connection on the specified interconnect or a link aggregation\ngroup (LAG) of interconnects.\n\nAllocates a VLAN number and a specified amount of capacity (bandwidth) for use\nby a hosted connection on the specified interconnect or LAG of interconnects.\nAmazon Web Services polices the hosted connection for the specified capacity and\nthe Direct Connect Partner must also police the hosted connection for the\nspecified capacity.\n\nIntended for use by Direct Connect Partners only.","ref":"AWS.DirectConnect.html#allocate_hosted_connection/3","title":"AWS.DirectConnect.allocate_hosted_connection/3","type":"function"},{"doc":"Provisions a private virtual interface to be owned by the specified Amazon Web\nServices account.\n\nVirtual interfaces created using this action must be confirmed by the owner\nusing `ConfirmPrivateVirtualInterface`. Until then, the virtual interface is in\nthe `Confirming` state and is not available to handle traffic.","ref":"AWS.DirectConnect.html#allocate_private_virtual_interface/3","title":"AWS.DirectConnect.allocate_private_virtual_interface/3","type":"function"},{"doc":"Provisions a public virtual interface to be owned by the specified Amazon Web\nServices account.\n\nThe owner of a connection calls this function to provision a public virtual\ninterface to be owned by the specified Amazon Web Services account.\n\nVirtual interfaces created using this function must be confirmed by the owner\nusing `ConfirmPublicVirtualInterface`. Until this step has been completed, the\nvirtual interface is in the `confirming` state and is not available to handle\ntraffic.\n\nWhen creating an IPv6 public virtual interface, omit the Amazon address and\ncustomer address. IPv6 addresses are automatically assigned from the Amazon pool\nof IPv6 addresses; you cannot specify custom IPv6 addresses.","ref":"AWS.DirectConnect.html#allocate_public_virtual_interface/3","title":"AWS.DirectConnect.allocate_public_virtual_interface/3","type":"function"},{"doc":"Provisions a transit virtual interface to be owned by the specified Amazon Web\nServices account.\n\nUse this type of interface to connect a transit gateway to your Direct Connect\ngateway.\n\nThe owner of a connection provisions a transit virtual interface to be owned by\nthe specified Amazon Web Services account.\n\nAfter you create a transit virtual interface, it must be confirmed by the owner\nusing `ConfirmTransitVirtualInterface`. Until this step has been completed, the\ntransit virtual interface is in the `requested` state and is not available to\nhandle traffic.","ref":"AWS.DirectConnect.html#allocate_transit_virtual_interface/3","title":"AWS.DirectConnect.allocate_transit_virtual_interface/3","type":"function"},{"doc":"Associates an existing connection with a link aggregation group (LAG).\n\nThe connection is interrupted and re-established as a member of the LAG\n(connectivity to Amazon Web Services is interrupted). The connection must be\nhosted on the same Direct Connect endpoint as the LAG, and its bandwidth must\nmatch the bandwidth for the LAG. You can re-associate a connection that's\ncurrently associated with a different LAG; however, if removing the connection\nwould cause the original LAG to fall below its setting for minimum number of\noperational connections, the request fails.\n\nAny virtual interfaces that are directly associated with the connection are\nautomatically re-associated with the LAG. If the connection was originally\nassociated with a different LAG, the virtual interfaces remain associated with\nthe original LAG.\n\nFor interconnects, any hosted connections are automatically re-associated with\nthe LAG. If the interconnect was originally associated with a different LAG, the\nhosted connections remain associated with the original LAG.","ref":"AWS.DirectConnect.html#associate_connection_with_lag/3","title":"AWS.DirectConnect.associate_connection_with_lag/3","type":"function"},{"doc":"Associates a hosted connection and its virtual interfaces with a link\naggregation group (LAG) or interconnect.\n\nIf the target interconnect or LAG has an existing hosted connection with a\nconflicting VLAN number or IP address, the operation fails. This action\ntemporarily interrupts the hosted connection's connectivity to Amazon Web\nServices as it is being migrated.\n\nIntended for use by Direct Connect Partners only.","ref":"AWS.DirectConnect.html#associate_hosted_connection/3","title":"AWS.DirectConnect.associate_hosted_connection/3","type":"function"},{"doc":"Associates a MAC Security (MACsec) Connection Key Name (CKN)/ Connectivity\nAssociation Key (CAK) pair with an Direct Connect dedicated connection.\n\nYou must supply either the `secretARN,` or the CKN/CAK (`ckn` and `cak`) pair in\nthe request.\n\nFor information about MAC Security (MACsec) key considerations, see [MACsec pre-shared CKN/CAK key considerations\n](https://docs.aws.amazon.com/directconnect/latest/UserGuide/direct-connect-mac-sec-getting-started.html#mac-sec-key-consideration)\nin the *Direct Connect User Guide*.","ref":"AWS.DirectConnect.html#associate_mac_sec_key/3","title":"AWS.DirectConnect.associate_mac_sec_key/3","type":"function"},{"doc":"Associates a virtual interface with a specified link aggregation group (LAG) or\nconnection.\n\nConnectivity to Amazon Web Services is temporarily interrupted as the virtual\ninterface is being migrated. If the target connection or LAG has an associated\nvirtual interface with a conflicting VLAN number or a conflicting IP address,\nthe operation fails.\n\nVirtual interfaces associated with a hosted connection cannot be associated with\na LAG; hosted connections must be migrated along with their virtual interfaces\nusing `AssociateHostedConnection`.\n\nTo reassociate a virtual interface to a new connection or LAG, the requester\nmust own either the virtual interface itself or the connection to which the\nvirtual interface is currently associated. Additionally, the requester must own\nthe connection or LAG for the association.","ref":"AWS.DirectConnect.html#associate_virtual_interface/3","title":"AWS.DirectConnect.associate_virtual_interface/3","type":"function"},{"doc":"Confirms the creation of the specified hosted connection on an interconnect.\n\nUpon creation, the hosted connection is initially in the `Ordering` state, and\nremains in this state until the owner confirms creation of the hosted\nconnection.","ref":"AWS.DirectConnect.html#confirm_connection/3","title":"AWS.DirectConnect.confirm_connection/3","type":"function"},{"doc":"The confirmation of the terms of agreement when creating the connection/link\naggregation group (LAG).","ref":"AWS.DirectConnect.html#confirm_customer_agreement/3","title":"AWS.DirectConnect.confirm_customer_agreement/3","type":"function"},{"doc":"Accepts ownership of a private virtual interface created by another Amazon Web\nServices account.\n\nAfter the virtual interface owner makes this call, the virtual interface is\ncreated and attached to the specified virtual private gateway or Direct Connect\ngateway, and is made available to handle traffic.","ref":"AWS.DirectConnect.html#confirm_private_virtual_interface/3","title":"AWS.DirectConnect.confirm_private_virtual_interface/3","type":"function"},{"doc":"Accepts ownership of a public virtual interface created by another Amazon Web\nServices account.\n\nAfter the virtual interface owner makes this call, the specified virtual\ninterface is created and made available to handle traffic.","ref":"AWS.DirectConnect.html#confirm_public_virtual_interface/3","title":"AWS.DirectConnect.confirm_public_virtual_interface/3","type":"function"},{"doc":"Accepts ownership of a transit virtual interface created by another Amazon Web\nServices account.\n\nAfter the owner of the transit virtual interface makes this call, the specified\ntransit virtual interface is created and made available to handle traffic.","ref":"AWS.DirectConnect.html#confirm_transit_virtual_interface/3","title":"AWS.DirectConnect.confirm_transit_virtual_interface/3","type":"function"},{"doc":"Creates a BGP peer on the specified virtual interface.\n\nYou must create a BGP peer for the corresponding address family (IPv4/IPv6) in\norder to access Amazon Web Services resources that also use that address family.\n\nIf logical redundancy is not supported by the connection, interconnect, or LAG,\nthe BGP peer cannot be in the same address family as an existing BGP peer on the\nvirtual interface.\n\nWhen creating a IPv6 BGP peer, omit the Amazon address and customer address.\nIPv6 addresses are automatically assigned from the Amazon pool of IPv6\naddresses; you cannot specify custom IPv6 addresses.\n\nIf you let Amazon Web Services auto-assign IPv4 addresses, a /30 CIDR will be\nallocated from 169.254.0.0/16. Amazon Web Services does not recommend this\noption if you intend to use the customer router peer IP address as the source\nand destination for traffic. Instead you should use RFC 1918 or other\naddressing, and specify the address yourself. For more information about RFC\n1918 see [ Address Allocation for Private Internets](https://datatracker.ietf.org/doc/html/rfc1918).\n\nFor a public virtual interface, the Autonomous System Number (ASN) must be\nprivate or already on the allow list for the virtual interface.","ref":"AWS.DirectConnect.html#create_bgp_peer/3","title":"AWS.DirectConnect.create_bgp_peer/3","type":"function"},{"doc":"Creates a connection between a customer network and a specific Direct Connect\nlocation.\n\nA connection links your internal network to an Direct Connect location over a\nstandard Ethernet fiber-optic cable. One end of the cable is connected to your\nrouter, the other to an Direct Connect router.\n\nTo find the locations for your Region, use `DescribeLocations`.\n\nYou can automatically add the new connection to a link aggregation group (LAG)\nby specifying a LAG ID in the request. This ensures that the new connection is\nallocated on the same Direct Connect endpoint that hosts the specified LAG. If\nthere are no available ports on the endpoint, the request fails and no\nconnection is created.","ref":"AWS.DirectConnect.html#create_connection/3","title":"AWS.DirectConnect.create_connection/3","type":"function"},{"doc":"Creates a Direct Connect gateway, which is an intermediate object that enables\nyou to connect a set of virtual interfaces and virtual private gateways.\n\nA Direct Connect gateway is global and visible in any Amazon Web Services Region\nafter it is created. The virtual interfaces and virtual private gateways that\nare connected through a Direct Connect gateway can be in different Amazon Web\nServices Regions. This enables you to connect to a VPC in any Region, regardless\nof the Region in which the virtual interfaces are located, and pass traffic\nbetween them.","ref":"AWS.DirectConnect.html#create_direct_connect_gateway/3","title":"AWS.DirectConnect.create_direct_connect_gateway/3","type":"function"},{"doc":"Creates an association between a Direct Connect gateway and a virtual private\ngateway.\n\nThe virtual private gateway must be attached to a VPC and must not be associated\nwith another Direct Connect gateway.","ref":"AWS.DirectConnect.html#create_direct_connect_gateway_association/3","title":"AWS.DirectConnect.create_direct_connect_gateway_association/3","type":"function"},{"doc":"Creates a proposal to associate the specified virtual private gateway or transit\ngateway with the specified Direct Connect gateway.\n\nYou can associate a Direct Connect gateway and virtual private gateway or\ntransit gateway that is owned by any Amazon Web Services account.","ref":"AWS.DirectConnect.html#create_direct_connect_gateway_association_proposal/3","title":"AWS.DirectConnect.create_direct_connect_gateway_association_proposal/3","type":"function"},{"doc":"Creates an interconnect between an Direct Connect Partner's network and a\nspecific Direct Connect location.\n\nAn interconnect is a connection that is capable of hosting other connections.\nThe Direct Connect Partner can use an interconnect to provide Direct Connect\nhosted connections to customers through their own network services. Like a\nstandard connection, an interconnect links the partner's network to an Direct\nConnect location over a standard Ethernet fiber-optic cable. One end is\nconnected to the partner's router, the other to an Direct Connect router.\n\nYou can automatically add the new interconnect to a link aggregation group (LAG)\nby specifying a LAG ID in the request. This ensures that the new interconnect is\nallocated on the same Direct Connect endpoint that hosts the specified LAG. If\nthere are no available ports on the endpoint, the request fails and no\ninterconnect is created.\n\nFor each end customer, the Direct Connect Partner provisions a connection on\ntheir interconnect by calling `AllocateHostedConnection`. The end customer can\nthen connect to Amazon Web Services resources by creating a virtual interface on\ntheir connection, using the VLAN assigned to them by the Direct Connect Partner.\n\nIntended for use by Direct Connect Partners only.","ref":"AWS.DirectConnect.html#create_interconnect/3","title":"AWS.DirectConnect.create_interconnect/3","type":"function"},{"doc":"Creates a link aggregation group (LAG) with the specified number of bundled\nphysical dedicated connections between the customer network and a specific\nDirect Connect location.\n\nA LAG is a logical interface that uses the Link Aggregation Control Protocol\n(LACP) to aggregate multiple interfaces, enabling you to treat them as a single\ninterface.\n\nAll connections in a LAG must use the same bandwidth (either 1Gbps or 10Gbps)\nand must terminate at the same Direct Connect endpoint.\n\nYou can have up to 10 dedicated connections per LAG. Regardless of this limit,\nif you request more connections for the LAG than Direct Connect can allocate on\na single endpoint, no LAG is created.\n\nYou can specify an existing physical dedicated connection or interconnect to\ninclude in the LAG (which counts towards the total number of connections). Doing\nso interrupts the current physical dedicated connection, and re-establishes them\nas a member of the LAG. The LAG will be created on the same Direct Connect\nendpoint to which the dedicated connection terminates. Any virtual interfaces\nassociated with the dedicated connection are automatically disassociated and\nre-associated with the LAG. The connection ID does not change.\n\nIf the Amazon Web Services account used to create a LAG is a registered Direct\nConnect Partner, the LAG is automatically enabled to host sub-connections. For a\nLAG owned by a partner, any associated virtual interfaces cannot be directly\nconfigured.","ref":"AWS.DirectConnect.html#create_lag/3","title":"AWS.DirectConnect.create_lag/3","type":"function"},{"doc":"Creates a private virtual interface.\n\nA virtual interface is the VLAN that transports Direct Connect traffic. A\nprivate virtual interface can be connected to either a Direct Connect gateway or\na Virtual Private Gateway (VGW). Connecting the private virtual interface to a\nDirect Connect gateway enables the possibility for connecting to multiple VPCs,\nincluding VPCs in different Amazon Web Services Regions. Connecting the private\nvirtual interface to a VGW only provides access to a single VPC within the same\nRegion.\n\nSetting the MTU of a virtual interface to 9001 (jumbo frames) can cause an\nupdate to the underlying physical connection if it wasn't updated to support\njumbo frames. Updating the connection disrupts network connectivity for all\nvirtual interfaces associated with the connection for up to 30 seconds. To check\nwhether your connection supports jumbo frames, call `DescribeConnections`. To\ncheck whether your virtual interface supports jumbo frames, call\n`DescribeVirtualInterfaces`.","ref":"AWS.DirectConnect.html#create_private_virtual_interface/3","title":"AWS.DirectConnect.create_private_virtual_interface/3","type":"function"},{"doc":"Creates a public virtual interface.\n\nA virtual interface is the VLAN that transports Direct Connect traffic. A public\nvirtual interface supports sending traffic to public services of Amazon Web\nServices such as Amazon S3.\n\nWhen creating an IPv6 public virtual interface (`addressFamily` is `ipv6`),\nleave the `customer` and `amazon` address fields blank to use auto-assigned IPv6\nspace. Custom IPv6 addresses are not supported.","ref":"AWS.DirectConnect.html#create_public_virtual_interface/3","title":"AWS.DirectConnect.create_public_virtual_interface/3","type":"function"},{"doc":"Creates a transit virtual interface.\n\nA transit virtual interface should be used to access one or more transit\ngateways associated with Direct Connect gateways. A transit virtual interface\nenables the connection of multiple VPCs attached to a transit gateway to a\nDirect Connect gateway.\n\nIf you associate your transit gateway with one or more Direct Connect gateways,\nthe Autonomous System Number (ASN) used by the transit gateway and the Direct\nConnect gateway must be different. For example, if you use the default ASN 64512\nfor both your the transit gateway and Direct Connect gateway, the association\nrequest fails.\n\nA jumbo MTU value must be either 1500 or 8500. No other values will be accepted.\nSetting the MTU of a virtual interface to 8500 (jumbo frames) can cause an\nupdate to the underlying physical connection if it wasn't updated to support\njumbo frames. Updating the connection disrupts network connectivity for all\nvirtual interfaces associated with the connection for up to 30 seconds. To check\nwhether your connection supports jumbo frames, call `DescribeConnections`. To\ncheck whether your virtual interface supports jumbo frames, call\n`DescribeVirtualInterfaces`.","ref":"AWS.DirectConnect.html#create_transit_virtual_interface/3","title":"AWS.DirectConnect.create_transit_virtual_interface/3","type":"function"},{"doc":"Deletes the specified BGP peer on the specified virtual interface with the\nspecified customer address and ASN.\n\nYou cannot delete the last BGP peer from a virtual interface.","ref":"AWS.DirectConnect.html#delete_bgp_peer/3","title":"AWS.DirectConnect.delete_bgp_peer/3","type":"function"},{"doc":"Deletes the specified connection.\n\nDeleting a connection only stops the Direct Connect port hour and data transfer\ncharges. If you are partnering with any third parties to connect with the Direct\nConnect location, you must cancel your service with them separately.","ref":"AWS.DirectConnect.html#delete_connection/3","title":"AWS.DirectConnect.delete_connection/3","type":"function"},{"doc":"Deletes the specified Direct Connect gateway.\n\nYou must first delete all virtual interfaces that are attached to the Direct\nConnect gateway and disassociate all virtual private gateways associated with\nthe Direct Connect gateway.","ref":"AWS.DirectConnect.html#delete_direct_connect_gateway/3","title":"AWS.DirectConnect.delete_direct_connect_gateway/3","type":"function"},{"doc":"Deletes the association between the specified Direct Connect gateway and virtual\nprivate gateway.\n\nWe recommend that you specify the `associationID` to delete the association.\nAlternatively, if you own virtual gateway and a Direct Connect gateway\nassociation, you can specify the `virtualGatewayId` and `directConnectGatewayId`\nto delete an association.","ref":"AWS.DirectConnect.html#delete_direct_connect_gateway_association/3","title":"AWS.DirectConnect.delete_direct_connect_gateway_association/3","type":"function"},{"doc":"Deletes the association proposal request between the specified Direct Connect\ngateway and virtual private gateway or transit gateway.","ref":"AWS.DirectConnect.html#delete_direct_connect_gateway_association_proposal/3","title":"AWS.DirectConnect.delete_direct_connect_gateway_association_proposal/3","type":"function"},{"doc":"Deletes the specified interconnect.\n\nIntended for use by Direct Connect Partners only.","ref":"AWS.DirectConnect.html#delete_interconnect/3","title":"AWS.DirectConnect.delete_interconnect/3","type":"function"},{"doc":"Deletes the specified link aggregation group (LAG).\n\nYou cannot delete a LAG if it has active virtual interfaces or hosted\nconnections.","ref":"AWS.DirectConnect.html#delete_lag/3","title":"AWS.DirectConnect.delete_lag/3","type":"function"},{"doc":"Deletes a virtual interface.","ref":"AWS.DirectConnect.html#delete_virtual_interface/3","title":"AWS.DirectConnect.delete_virtual_interface/3","type":"function"},{"doc":"Deprecated.\n\nUse `DescribeLoa` instead.\n\nGets the LOA-CFA for a connection.\n\nThe Letter of Authorization - Connecting Facility Assignment (LOA-CFA) is a\ndocument that your APN partner or service provider uses when establishing your\ncross connect to Amazon Web Services at the colocation facility. For more\ninformation, see [Requesting Cross Connects at Direct Connect Locations](https://docs.aws.amazon.com/directconnect/latest/UserGuide/Colocation.html)\nin the *Direct Connect User Guide*.","ref":"AWS.DirectConnect.html#describe_connection_loa/3","title":"AWS.DirectConnect.describe_connection_loa/3","type":"function"},{"doc":"Displays the specified connection or all connections in this Region.","ref":"AWS.DirectConnect.html#describe_connections/3","title":"AWS.DirectConnect.describe_connections/3","type":"function"},{"doc":"Deprecated.\n\nUse `DescribeHostedConnections` instead.\n\nLists the connections that have been provisioned on the specified interconnect.\n\nIntended for use by Direct Connect Partners only.","ref":"AWS.DirectConnect.html#describe_connections_on_interconnect/3","title":"AWS.DirectConnect.describe_connections_on_interconnect/3","type":"function"},{"doc":"Get and view a list of customer agreements, along with their signed status and\nwhether the customer is an NNIPartner, NNIPartnerV2, or a nonPartner.","ref":"AWS.DirectConnect.html#describe_customer_metadata/3","title":"AWS.DirectConnect.describe_customer_metadata/3","type":"function"},{"doc":"Describes one or more association proposals for connection between a virtual\nprivate gateway or transit gateway and a Direct Connect gateway.","ref":"AWS.DirectConnect.html#describe_direct_connect_gateway_association_proposals/3","title":"AWS.DirectConnect.describe_direct_connect_gateway_association_proposals/3","type":"function"},{"doc":"Lists the associations between your Direct Connect gateways and virtual private\ngateways and transit gateways.\n\nYou must specify one of the following:\n\n  * A Direct Connect gateway\n\nThe response contains all virtual private gateways and transit gateways\nassociated with the Direct Connect gateway.\n\n  * A virtual private gateway\n\nThe response contains the Direct Connect gateway.\n\n  * A transit gateway\n\nThe response contains the Direct Connect gateway.\n\n  * A Direct Connect gateway and a virtual private gateway\n\nThe response contains the association between the Direct Connect gateway and\nvirtual private gateway.\n\n  * A Direct Connect gateway and a transit gateway\n\nThe response contains the association between the Direct Connect gateway and\ntransit gateway.","ref":"AWS.DirectConnect.html#describe_direct_connect_gateway_associations/3","title":"AWS.DirectConnect.describe_direct_connect_gateway_associations/3","type":"function"},{"doc":"Lists the attachments between your Direct Connect gateways and virtual\ninterfaces.\n\nYou must specify a Direct Connect gateway, a virtual interface, or both. If you\nspecify a Direct Connect gateway, the response contains all virtual interfaces\nattached to the Direct Connect gateway. If you specify a virtual interface, the\nresponse contains all Direct Connect gateways attached to the virtual interface.\nIf you specify both, the response contains the attachment between the Direct\nConnect gateway and the virtual interface.","ref":"AWS.DirectConnect.html#describe_direct_connect_gateway_attachments/3","title":"AWS.DirectConnect.describe_direct_connect_gateway_attachments/3","type":"function"},{"doc":"Lists all your Direct Connect gateways or only the specified Direct Connect\ngateway.\n\nDeleted Direct Connect gateways are not returned.","ref":"AWS.DirectConnect.html#describe_direct_connect_gateways/3","title":"AWS.DirectConnect.describe_direct_connect_gateways/3","type":"function"},{"doc":"Lists the hosted connections that have been provisioned on the specified\ninterconnect or link aggregation group (LAG).\n\nIntended for use by Direct Connect Partners only.","ref":"AWS.DirectConnect.html#describe_hosted_connections/3","title":"AWS.DirectConnect.describe_hosted_connections/3","type":"function"},{"doc":"Deprecated.\n\nUse `DescribeLoa` instead.\n\nGets the LOA-CFA for the specified interconnect.\n\nThe Letter of Authorization - Connecting Facility Assignment (LOA-CFA) is a\ndocument that is used when establishing your cross connect to Amazon Web\nServices at the colocation facility. For more information, see [Requesting Cross Connects at Direct Connect\nLocations](https://docs.aws.amazon.com/directconnect/latest/UserGuide/Colocation.html)\nin the *Direct Connect User Guide*.","ref":"AWS.DirectConnect.html#describe_interconnect_loa/3","title":"AWS.DirectConnect.describe_interconnect_loa/3","type":"function"},{"doc":"Lists the interconnects owned by the Amazon Web Services account or only the\nspecified interconnect.","ref":"AWS.DirectConnect.html#describe_interconnects/3","title":"AWS.DirectConnect.describe_interconnects/3","type":"function"},{"doc":"Describes all your link aggregation groups (LAG) or the specified LAG.","ref":"AWS.DirectConnect.html#describe_lags/3","title":"AWS.DirectConnect.describe_lags/3","type":"function"},{"doc":"Gets the LOA-CFA for a connection, interconnect, or link aggregation group\n(LAG).\n\nThe Letter of Authorization - Connecting Facility Assignment (LOA-CFA) is a\ndocument that is used when establishing your cross connect to Amazon Web\nServices at the colocation facility. For more information, see [Requesting Cross Connects at Direct Connect\nLocations](https://docs.aws.amazon.com/directconnect/latest/UserGuide/Colocation.html)\nin the *Direct Connect User Guide*.","ref":"AWS.DirectConnect.html#describe_loa/3","title":"AWS.DirectConnect.describe_loa/3","type":"function"},{"doc":"Lists the Direct Connect locations in the current Amazon Web Services Region.\n\nThese are the locations that can be selected when calling `CreateConnection` or\n`CreateInterconnect`.","ref":"AWS.DirectConnect.html#describe_locations/3","title":"AWS.DirectConnect.describe_locations/3","type":"function"},{"doc":"Details about the router.","ref":"AWS.DirectConnect.html#describe_router_configuration/3","title":"AWS.DirectConnect.describe_router_configuration/3","type":"function"},{"doc":"Describes the tags associated with the specified Direct Connect resources.","ref":"AWS.DirectConnect.html#describe_tags/3","title":"AWS.DirectConnect.describe_tags/3","type":"function"},{"doc":"Lists the virtual private gateways owned by the Amazon Web Services account.\n\nYou can create one or more Direct Connect private virtual interfaces linked to a\nvirtual private gateway.","ref":"AWS.DirectConnect.html#describe_virtual_gateways/3","title":"AWS.DirectConnect.describe_virtual_gateways/3","type":"function"},{"doc":"Displays all virtual interfaces for an Amazon Web Services account.\n\nVirtual interfaces deleted fewer than 15 minutes before you make the request are\nalso returned. If you specify a connection ID, only the virtual interfaces\nassociated with the connection are returned. If you specify a virtual interface\nID, then only a single virtual interface is returned.\n\nA virtual interface (VLAN) transmits the traffic between the Direct Connect\nlocation and the customer network.","ref":"AWS.DirectConnect.html#describe_virtual_interfaces/3","title":"AWS.DirectConnect.describe_virtual_interfaces/3","type":"function"},{"doc":"Disassociates a connection from a link aggregation group (LAG).\n\nThe connection is interrupted and re-established as a standalone connection (the\nconnection is not deleted; to delete the connection, use the `DeleteConnection`\nrequest). If the LAG has associated virtual interfaces or hosted connections,\nthey remain associated with the LAG. A disassociated connection owned by an\nDirect Connect Partner is automatically converted to an interconnect.\n\nIf disassociating the connection would cause the LAG to fall below its setting\nfor minimum number of operational connections, the request fails, except when\nit's the last member of the LAG. If all connections are disassociated, the LAG\ncontinues to exist as an empty LAG with no physical connections.","ref":"AWS.DirectConnect.html#disassociate_connection_from_lag/3","title":"AWS.DirectConnect.disassociate_connection_from_lag/3","type":"function"},{"doc":"Removes the association between a MAC Security (MACsec) security key and an\nDirect Connect dedicated connection.","ref":"AWS.DirectConnect.html#disassociate_mac_sec_key/3","title":"AWS.DirectConnect.disassociate_mac_sec_key/3","type":"function"},{"doc":"Lists the virtual interface failover test history.","ref":"AWS.DirectConnect.html#list_virtual_interface_test_history/3","title":"AWS.DirectConnect.list_virtual_interface_test_history/3","type":"function"},{"doc":"","ref":"AWS.DirectConnect.html#metadata/0","title":"AWS.DirectConnect.metadata/0","type":"function"},{"doc":"Starts the virtual interface failover test that verifies your configuration\nmeets your resiliency requirements by placing the BGP peering session in the\nDOWN state.\n\nYou can then send traffic to verify that there are no outages.\n\nYou can run the test on public, private, transit, and hosted virtual interfaces.\n\nYou can use\n[ListVirtualInterfaceTestHistory](https://docs.aws.amazon.com/directconnect/latest/APIReference/API_ListVirtualInterfaceTestHistory.html) to view the virtual interface test history.\n\nIf you need to stop the test before the test interval completes, use\n[StopBgpFailoverTest](https://docs.aws.amazon.com/directconnect/latest/APIReference/API_StopBgpFailoverTest.html).","ref":"AWS.DirectConnect.html#start_bgp_failover_test/3","title":"AWS.DirectConnect.start_bgp_failover_test/3","type":"function"},{"doc":"Stops the virtual interface failover test.","ref":"AWS.DirectConnect.html#stop_bgp_failover_test/3","title":"AWS.DirectConnect.stop_bgp_failover_test/3","type":"function"},{"doc":"Adds the specified tags to the specified Direct Connect resource.\n\nEach resource can have a maximum of 50 tags.\n\nEach tag consists of a key and an optional value. If a tag with the same key is\nalready associated with the resource, this action updates its value.","ref":"AWS.DirectConnect.html#tag_resource/3","title":"AWS.DirectConnect.tag_resource/3","type":"function"},{"doc":"Removes one or more tags from the specified Direct Connect resource.","ref":"AWS.DirectConnect.html#untag_resource/3","title":"AWS.DirectConnect.untag_resource/3","type":"function"},{"doc":"Updates the Direct Connect dedicated connection configuration.\n\nYou can update the following parameters for a connection:\n\n  * The connection name\n\n  * The connection's MAC Security (MACsec) encryption mode.","ref":"AWS.DirectConnect.html#update_connection/3","title":"AWS.DirectConnect.update_connection/3","type":"function"},{"doc":"Updates the name of a current Direct Connect gateway.","ref":"AWS.DirectConnect.html#update_direct_connect_gateway/3","title":"AWS.DirectConnect.update_direct_connect_gateway/3","type":"function"},{"doc":"Updates the specified attributes of the Direct Connect gateway association.\n\nAdd or remove prefixes from the association.","ref":"AWS.DirectConnect.html#update_direct_connect_gateway_association/3","title":"AWS.DirectConnect.update_direct_connect_gateway_association/3","type":"function"},{"doc":"Updates the attributes of the specified link aggregation group (LAG).\n\nYou can update the following LAG attributes:\n\n  * The name of the LAG.\n\n  * The value for the minimum number of connections that must be\noperational for the LAG itself to be operational.\n\n  * The LAG's MACsec encryption mode.\n\nAmazon Web Services assigns this value to each connection which is part of the\nLAG.\n\n  * The tags\n\nIf you adjust the threshold value for the minimum number of operational\nconnections, ensure that the new value does not cause the LAG to fall below the\nthreshold and become non-operational.","ref":"AWS.DirectConnect.html#update_lag/3","title":"AWS.DirectConnect.update_lag/3","type":"function"},{"doc":"Updates the specified attributes of the specified virtual private interface.\n\nSetting the MTU of a virtual interface to 9001 (jumbo frames) can cause an\nupdate to the underlying physical connection if it wasn't updated to support\njumbo frames. Updating the connection disrupts network connectivity for all\nvirtual interfaces associated with the connection for up to 30 seconds. To check\nwhether your connection supports jumbo frames, call `DescribeConnections`. To\ncheck whether your virtual interface supports jumbo frames, call\n`DescribeVirtualInterfaces`.","ref":"AWS.DirectConnect.html#update_virtual_interface_attributes/3","title":"AWS.DirectConnect.update_virtual_interface_attributes/3","type":"function"},{"doc":"Directory Service\n\nDirectory Service is a web service that makes it easy for you to setup and run\ndirectories in the Amazon Web Services cloud, or connect your Amazon Web\nServices resources with an existing self-managed Microsoft Active Directory.\n\nThis guide provides detailed information about Directory Service operations,\ndata types, parameters, and errors. For information about Directory Services\nfeatures, see [Directory Service](https://aws.amazon.com/directoryservice/) and the [Directory Service Administration\nGuide](http://docs.aws.amazon.com/directoryservice/latest/admin-guide/what_is.html).\n\nAmazon Web Services provides SDKs that consist of libraries and sample code for\nvarious programming languages and platforms (Java, Ruby, .Net, iOS, Android,\netc.). The SDKs provide a convenient way to create programmatic access to\nDirectory Service and other Amazon Web Services services. For more information\nabout the Amazon Web Services SDKs, including how to download and install them,\nsee [Tools for Amazon Web Services](http://aws.amazon.com/tools/).","ref":"AWS.Directory.html","title":"AWS.Directory","type":"module"},{"doc":"Accepts a directory sharing request that was sent from the directory owner\naccount.","ref":"AWS.Directory.html#accept_shared_directory/3","title":"AWS.Directory.accept_shared_directory/3","type":"function"},{"doc":"If the DNS server for your self-managed domain uses a publicly addressable IP\naddress, you must add a CIDR address block to correctly route traffic to and\nfrom your Microsoft AD on Amazon Web Services.\n\n*AddIpRoutes* adds this address block. You can also use *AddIpRoutes* to\nfacilitate routing traffic that uses public IP ranges from your Microsoft AD on\nAmazon Web Services to a peer VPC.\n\nBefore you call *AddIpRoutes*, ensure that all of the required permissions have\nbeen explicitly granted through a policy. For details about what permissions are\nrequired to run the *AddIpRoutes* operation, see [Directory Service API Permissions: Actions, Resources, and Conditions\nReference](http://docs.aws.amazon.com/directoryservice/latest/admin-guide/UsingWithDS_IAM_ResourcePermissions.html).","ref":"AWS.Directory.html#add_ip_routes/3","title":"AWS.Directory.add_ip_routes/3","type":"function"},{"doc":"Adds two domain controllers in the specified Region for the specified directory.","ref":"AWS.Directory.html#add_region/3","title":"AWS.Directory.add_region/3","type":"function"},{"doc":"Adds or overwrites one or more tags for the specified directory.\n\nEach directory can have a maximum of 50 tags. Each tag consists of a key and\noptional value. Tag keys must be unique to each resource.","ref":"AWS.Directory.html#add_tags_to_resource/3","title":"AWS.Directory.add_tags_to_resource/3","type":"function"},{"doc":"Cancels an in-progress schema extension to a Microsoft AD directory.\n\nOnce a schema extension has started replicating to all domain controllers, the\ntask can no longer be canceled. A schema extension can be canceled during any of\nthe following states; `Initializing`, `CreatingSnapshot`, and `UpdatingSchema`.","ref":"AWS.Directory.html#cancel_schema_extension/3","title":"AWS.Directory.cancel_schema_extension/3","type":"function"},{"doc":"Creates an AD Connector to connect to a self-managed directory.\n\nBefore you call `ConnectDirectory`, ensure that all of the required permissions\nhave been explicitly granted through a policy. For details about what\npermissions are required to run the `ConnectDirectory` operation, see [Directory Service API Permissions: Actions, Resources, and Conditions\nReference](http://docs.aws.amazon.com/directoryservice/latest/admin-guide/UsingWithDS_IAM_ResourcePermissions.html).","ref":"AWS.Directory.html#connect_directory/3","title":"AWS.Directory.connect_directory/3","type":"function"},{"doc":"Creates an alias for a directory and assigns the alias to the directory.\n\nThe alias is used to construct the access URL for the directory, such as\n`http:// .awsapps.com`.\n\nAfter an alias has been created, it cannot be deleted or reused, so this\noperation should only be used when absolutely necessary.","ref":"AWS.Directory.html#create_alias/3","title":"AWS.Directory.create_alias/3","type":"function"},{"doc":"Creates an Active Directory computer object in the specified directory.","ref":"AWS.Directory.html#create_computer/3","title":"AWS.Directory.create_computer/3","type":"function"},{"doc":"Creates a conditional forwarder associated with your Amazon Web Services\ndirectory.\n\nConditional forwarders are required in order to set up a trust relationship with\nanother domain. The conditional forwarder points to the trusted domain.","ref":"AWS.Directory.html#create_conditional_forwarder/3","title":"AWS.Directory.create_conditional_forwarder/3","type":"function"},{"doc":"Creates a Simple AD directory.\n\nFor more information, see [Simple Active Directory](https://docs.aws.amazon.com/directoryservice/latest/admin-guide/directory_simple_ad.html)\nin the *Directory Service Admin Guide*.\n\nBefore you call `CreateDirectory`, ensure that all of the required permissions\nhave been explicitly granted through a policy. For details about what\npermissions are required to run the `CreateDirectory` operation, see [Directory Service API Permissions: Actions, Resources, and Conditions\nReference](http://docs.aws.amazon.com/directoryservice/latest/admin-guide/UsingWithDS_IAM_ResourcePermissions.html).","ref":"AWS.Directory.html#create_directory/3","title":"AWS.Directory.create_directory/3","type":"function"},{"doc":"Creates a subscription to forward real-time Directory Service domain controller\nsecurity logs to the specified Amazon CloudWatch log group in your Amazon Web\nServices account.","ref":"AWS.Directory.html#create_log_subscription/3","title":"AWS.Directory.create_log_subscription/3","type":"function"},{"doc":"Creates a Microsoft AD directory in the Amazon Web Services Cloud.\n\nFor more information, see [Managed Microsoft AD](https://docs.aws.amazon.com/directoryservice/latest/admin-guide/directory_microsoft_ad.html)\nin the *Directory Service Admin Guide*.\n\nBefore you call *CreateMicrosoftAD*, ensure that all of the required permissions\nhave been explicitly granted through a policy. For details about what\npermissions are required to run the *CreateMicrosoftAD* operation, see\n[Directory Service API Permissions: Actions, Resources, and Conditions Reference](http://docs.aws.amazon.com/directoryservice/latest/admin-guide/UsingWithDS_IAM_ResourcePermissions.html).","ref":"AWS.Directory.html#create_microsoft_ad/3","title":"AWS.Directory.create_microsoft_ad/3","type":"function"},{"doc":"Creates a snapshot of a Simple AD or Microsoft AD directory in the Amazon Web\nServices cloud.\n\nYou cannot take snapshots of AD Connector directories.","ref":"AWS.Directory.html#create_snapshot/3","title":"AWS.Directory.create_snapshot/3","type":"function"},{"doc":"Directory Service for Microsoft Active Directory allows you to configure trust\nrelationships.\n\nFor example, you can establish a trust between your Managed Microsoft AD\ndirectory, and your existing self-managed Microsoft Active Directory. This would\nallow you to provide users and groups access to resources in either domain, with\na single set of credentials.\n\nThis action initiates the creation of the Amazon Web Services side of a trust\nrelationship between an Managed Microsoft AD directory and an external domain.\nYou can create either a forest trust or an external trust.","ref":"AWS.Directory.html#create_trust/3","title":"AWS.Directory.create_trust/3","type":"function"},{"doc":"Deletes a conditional forwarder that has been set up for your Amazon Web\nServices directory.","ref":"AWS.Directory.html#delete_conditional_forwarder/3","title":"AWS.Directory.delete_conditional_forwarder/3","type":"function"},{"doc":"Deletes an Directory Service directory.\n\nBefore you call `DeleteDirectory`, ensure that all of the required permissions\nhave been explicitly granted through a policy. For details about what\npermissions are required to run the `DeleteDirectory` operation, see [Directory Service API Permissions: Actions, Resources, and Conditions\nReference](http://docs.aws.amazon.com/directoryservice/latest/admin-guide/UsingWithDS_IAM_ResourcePermissions.html).","ref":"AWS.Directory.html#delete_directory/3","title":"AWS.Directory.delete_directory/3","type":"function"},{"doc":"Deletes the specified log subscription.","ref":"AWS.Directory.html#delete_log_subscription/3","title":"AWS.Directory.delete_log_subscription/3","type":"function"},{"doc":"Deletes a directory snapshot.","ref":"AWS.Directory.html#delete_snapshot/3","title":"AWS.Directory.delete_snapshot/3","type":"function"},{"doc":"Deletes an existing trust relationship between your Managed Microsoft AD\ndirectory and an external domain.","ref":"AWS.Directory.html#delete_trust/3","title":"AWS.Directory.delete_trust/3","type":"function"},{"doc":"Deletes from the system the certificate that was registered for secure LDAP or\nclient certificate authentication.","ref":"AWS.Directory.html#deregister_certificate/3","title":"AWS.Directory.deregister_certificate/3","type":"function"},{"doc":"Removes the specified directory as a publisher to the specified Amazon SNS\ntopic.","ref":"AWS.Directory.html#deregister_event_topic/3","title":"AWS.Directory.deregister_event_topic/3","type":"function"},{"doc":"Displays information about the certificate registered for secure LDAP or client\ncertificate authentication.","ref":"AWS.Directory.html#describe_certificate/3","title":"AWS.Directory.describe_certificate/3","type":"function"},{"doc":"Retrieves information about the type of client authentication for the specified\ndirectory, if the type is specified.\n\nIf no type is specified, information about all client authentication types that\nare supported for the specified directory is retrieved. Currently, only\n`SmartCard` is supported.","ref":"AWS.Directory.html#describe_client_authentication_settings/3","title":"AWS.Directory.describe_client_authentication_settings/3","type":"function"},{"doc":"Obtains information about the conditional forwarders for this account.\n\nIf no input parameters are provided for RemoteDomainNames, this request\ndescribes all conditional forwarders for the specified directory ID.","ref":"AWS.Directory.html#describe_conditional_forwarders/3","title":"AWS.Directory.describe_conditional_forwarders/3","type":"function"},{"doc":"Obtains information about the directories that belong to this account.\n\nYou can retrieve information about specific directories by passing the directory\nidentifiers in the `DirectoryIds` parameter. Otherwise, all directories that\nbelong to the current account are returned.\n\nThis operation supports pagination with the use of the `NextToken` request and\nresponse parameters. If more results are available, the\n`DescribeDirectoriesResult.NextToken` member contains a token that you pass in\nthe next call to `DescribeDirectories` to retrieve the next set of items.\n\nYou can also specify a maximum number of return results with the `Limit`\nparameter.","ref":"AWS.Directory.html#describe_directories/3","title":"AWS.Directory.describe_directories/3","type":"function"},{"doc":"Provides information about any domain controllers in your directory.","ref":"AWS.Directory.html#describe_domain_controllers/3","title":"AWS.Directory.describe_domain_controllers/3","type":"function"},{"doc":"Obtains information about which Amazon SNS topics receive status messages from\nthe specified directory.\n\nIf no input parameters are provided, such as DirectoryId or TopicName, this\nrequest describes all of the associations in the account.","ref":"AWS.Directory.html#describe_event_topics/3","title":"AWS.Directory.describe_event_topics/3","type":"function"},{"doc":"Describes the status of LDAP security for the specified directory.","ref":"AWS.Directory.html#describe_ldaps_settings/3","title":"AWS.Directory.describe_ldaps_settings/3","type":"function"},{"doc":"Provides information about the Regions that are configured for multi-Region\nreplication.","ref":"AWS.Directory.html#describe_regions/3","title":"AWS.Directory.describe_regions/3","type":"function"},{"doc":"Retrieves information about the configurable settings for the specified\ndirectory.","ref":"AWS.Directory.html#describe_settings/3","title":"AWS.Directory.describe_settings/3","type":"function"},{"doc":"Returns the shared directories in your account.","ref":"AWS.Directory.html#describe_shared_directories/3","title":"AWS.Directory.describe_shared_directories/3","type":"function"},{"doc":"Obtains information about the directory snapshots that belong to this account.\n\nThis operation supports pagination with the use of the *NextToken* request and\nresponse parameters. If more results are available, the\n*DescribeSnapshots.NextToken* member contains a token that you pass in the next\ncall to `DescribeSnapshots` to retrieve the next set of items.\n\nYou can also specify a maximum number of return results with the *Limit*\nparameter.","ref":"AWS.Directory.html#describe_snapshots/3","title":"AWS.Directory.describe_snapshots/3","type":"function"},{"doc":"Obtains information about the trust relationships for this account.\n\nIf no input parameters are provided, such as DirectoryId or TrustIds, this\nrequest describes all the trust relationships belonging to the account.","ref":"AWS.Directory.html#describe_trusts/3","title":"AWS.Directory.describe_trusts/3","type":"function"},{"doc":"Describes the updates of a directory for a particular update type.","ref":"AWS.Directory.html#describe_update_directory/3","title":"AWS.Directory.describe_update_directory/3","type":"function"},{"doc":"Disables alternative client authentication methods for the specified directory.","ref":"AWS.Directory.html#disable_client_authentication/3","title":"AWS.Directory.disable_client_authentication/3","type":"function"},{"doc":"Deactivates LDAP secure calls for the specified directory.","ref":"AWS.Directory.html#disable_ldaps/3","title":"AWS.Directory.disable_ldaps/3","type":"function"},{"doc":"Disables multi-factor authentication (MFA) with the Remote Authentication Dial\nIn User Service (RADIUS) server for an AD Connector or Microsoft AD directory.","ref":"AWS.Directory.html#disable_radius/3","title":"AWS.Directory.disable_radius/3","type":"function"},{"doc":"Disables single-sign on for a directory.","ref":"AWS.Directory.html#disable_sso/3","title":"AWS.Directory.disable_sso/3","type":"function"},{"doc":"Enables alternative client authentication methods for the specified directory.","ref":"AWS.Directory.html#enable_client_authentication/3","title":"AWS.Directory.enable_client_authentication/3","type":"function"},{"doc":"Activates the switch for the specific directory to always use LDAP secure calls.","ref":"AWS.Directory.html#enable_ldaps/3","title":"AWS.Directory.enable_ldaps/3","type":"function"},{"doc":"Enables multi-factor authentication (MFA) with the Remote Authentication Dial In\nUser Service (RADIUS) server for an AD Connector or Microsoft AD directory.","ref":"AWS.Directory.html#enable_radius/3","title":"AWS.Directory.enable_radius/3","type":"function"},{"doc":"Enables single sign-on for a directory.\n\nSingle sign-on allows users in your directory to access certain Amazon Web\nServices services from a computer joined to the directory without having to\nenter their credentials separately.","ref":"AWS.Directory.html#enable_sso/3","title":"AWS.Directory.enable_sso/3","type":"function"},{"doc":"Obtains directory limit information for the current Region.","ref":"AWS.Directory.html#get_directory_limits/3","title":"AWS.Directory.get_directory_limits/3","type":"function"},{"doc":"Obtains the manual snapshot limits for a directory.","ref":"AWS.Directory.html#get_snapshot_limits/3","title":"AWS.Directory.get_snapshot_limits/3","type":"function"},{"doc":"For the specified directory, lists all the certificates registered for a secure\nLDAP or client certificate authentication.","ref":"AWS.Directory.html#list_certificates/3","title":"AWS.Directory.list_certificates/3","type":"function"},{"doc":"Lists the address blocks that you have added to a directory.","ref":"AWS.Directory.html#list_ip_routes/3","title":"AWS.Directory.list_ip_routes/3","type":"function"},{"doc":"Lists the active log subscriptions for the Amazon Web Services account.","ref":"AWS.Directory.html#list_log_subscriptions/3","title":"AWS.Directory.list_log_subscriptions/3","type":"function"},{"doc":"Lists all schema extensions applied to a Microsoft AD Directory.","ref":"AWS.Directory.html#list_schema_extensions/3","title":"AWS.Directory.list_schema_extensions/3","type":"function"},{"doc":"Lists all tags on a directory.","ref":"AWS.Directory.html#list_tags_for_resource/3","title":"AWS.Directory.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.Directory.html#metadata/0","title":"AWS.Directory.metadata/0","type":"function"},{"doc":"Registers a certificate for a secure LDAP or client certificate authentication.","ref":"AWS.Directory.html#register_certificate/3","title":"AWS.Directory.register_certificate/3","type":"function"},{"doc":"Associates a directory with an Amazon SNS topic.\n\nThis establishes the directory as a publisher to the specified Amazon SNS topic.\nYou can then receive email or text (SMS) messages when the status of your\ndirectory changes. You get notified if your directory goes from an Active status\nto an Impaired or Inoperable status. You also receive a notification when the\ndirectory returns to an Active status.","ref":"AWS.Directory.html#register_event_topic/3","title":"AWS.Directory.register_event_topic/3","type":"function"},{"doc":"Rejects a directory sharing request that was sent from the directory owner\naccount.","ref":"AWS.Directory.html#reject_shared_directory/3","title":"AWS.Directory.reject_shared_directory/3","type":"function"},{"doc":"Removes IP address blocks from a directory.","ref":"AWS.Directory.html#remove_ip_routes/3","title":"AWS.Directory.remove_ip_routes/3","type":"function"},{"doc":"Stops all replication and removes the domain controllers from the specified\nRegion.\n\nYou cannot remove the primary Region with this operation. Instead, use the\n`DeleteDirectory` API.","ref":"AWS.Directory.html#remove_region/3","title":"AWS.Directory.remove_region/3","type":"function"},{"doc":"Removes tags from a directory.","ref":"AWS.Directory.html#remove_tags_from_resource/3","title":"AWS.Directory.remove_tags_from_resource/3","type":"function"},{"doc":"Resets the password for any user in your Managed Microsoft AD or Simple AD\ndirectory.\n\nYou can reset the password for any user in your directory with the following\nexceptions:\n\n  * For Simple AD, you cannot reset the password for any user that is\na member of either the **Domain Admins** or **Enterprise Admins** group except\nfor the administrator user.\n\n  * For Managed Microsoft AD, you can only reset the password for a\nuser that is in an OU based off of the NetBIOS name that you typed when you\ncreated your directory. For example, you cannot reset the password for a user in\nthe **Amazon Web Services Reserved** OU. For more information about the OU\nstructure for an Managed Microsoft AD directory, see [What Gets Created](https://docs.aws.amazon.com/directoryservice/latest/admin-guide/ms_ad_getting_started_what_gets_created.html)\nin the *Directory Service Administration Guide*.","ref":"AWS.Directory.html#reset_user_password/3","title":"AWS.Directory.reset_user_password/3","type":"function"},{"doc":"Restores a directory using an existing directory snapshot.\n\nWhen you restore a directory from a snapshot, any changes made to the directory\nafter the snapshot date are overwritten.\n\nThis action returns as soon as the restore operation is initiated. You can\nmonitor the progress of the restore operation by calling the\n`DescribeDirectories` operation with the directory identifier. When the\n**DirectoryDescription.Stage** value changes to `Active`, the restore operation\nis complete.","ref":"AWS.Directory.html#restore_from_snapshot/3","title":"AWS.Directory.restore_from_snapshot/3","type":"function"},{"doc":"Shares a specified directory (`DirectoryId`) in your Amazon Web Services account\n(directory owner) with another Amazon Web Services account (directory consumer).\n\nWith this operation you can use your directory from any Amazon Web Services\naccount and from any Amazon VPC within an Amazon Web Services Region.\n\nWhen you share your Managed Microsoft AD directory, Directory Service creates a\nshared directory in the directory consumer account. This shared directory\ncontains the metadata to provide access to the directory within the directory\nowner account. The shared directory is visible in all VPCs in the directory\nconsumer account.\n\nThe `ShareMethod` parameter determines whether the specified directory can be\nshared between Amazon Web Services accounts inside the same Amazon Web Services\norganization (`ORGANIZATIONS`). It also determines whether you can share the\ndirectory with any other Amazon Web Services account either inside or outside of\nthe organization (`HANDSHAKE`).\n\nThe `ShareNotes` parameter is only used when `HANDSHAKE` is called, which sends\na directory sharing request to the directory consumer.","ref":"AWS.Directory.html#share_directory/3","title":"AWS.Directory.share_directory/3","type":"function"},{"doc":"Applies a schema extension to a Microsoft AD directory.","ref":"AWS.Directory.html#start_schema_extension/3","title":"AWS.Directory.start_schema_extension/3","type":"function"},{"doc":"Stops the directory sharing between the directory owner and consumer accounts.","ref":"AWS.Directory.html#unshare_directory/3","title":"AWS.Directory.unshare_directory/3","type":"function"},{"doc":"Updates a conditional forwarder that has been set up for your Amazon Web\nServices directory.","ref":"AWS.Directory.html#update_conditional_forwarder/3","title":"AWS.Directory.update_conditional_forwarder/3","type":"function"},{"doc":"Updates the directory for a particular update type.","ref":"AWS.Directory.html#update_directory_setup/3","title":"AWS.Directory.update_directory_setup/3","type":"function"},{"doc":"Adds or removes domain controllers to or from the directory.\n\nBased on the difference between current value and new value (provided through\nthis API call), domain controllers will be added or removed. It may take up to\n45 minutes for any new domain controllers to become fully active once the\nrequested number of domain controllers is updated. During this time, you cannot\nmake another update request.","ref":"AWS.Directory.html#update_number_of_domain_controllers/3","title":"AWS.Directory.update_number_of_domain_controllers/3","type":"function"},{"doc":"Updates the Remote Authentication Dial In User Service (RADIUS) server\ninformation for an AD Connector or Microsoft AD directory.","ref":"AWS.Directory.html#update_radius/3","title":"AWS.Directory.update_radius/3","type":"function"},{"doc":"Updates the configurable settings for the specified directory.","ref":"AWS.Directory.html#update_settings/3","title":"AWS.Directory.update_settings/3","type":"function"},{"doc":"Updates the trust that has been set up between your Managed Microsoft AD\ndirectory and an self-managed Active Directory.","ref":"AWS.Directory.html#update_trust/3","title":"AWS.Directory.update_trust/3","type":"function"},{"doc":"Directory Service for Microsoft Active Directory allows you to configure and\nverify trust relationships.\n\nThis action verifies a trust relationship between your Managed Microsoft AD\ndirectory and an external domain.","ref":"AWS.Directory.html#verify_trust/3","title":"AWS.Directory.verify_trust/3","type":"function"},{"doc":"Amazon DocumentDB is a fast, reliable, and fully managed database service.\n\nAmazon DocumentDB makes it easy to set up, operate, and scale MongoDB-compatible\ndatabases in the cloud. With Amazon DocumentDB, you can run the same application\ncode and use the same drivers and tools that you use with MongoDB.","ref":"AWS.DocDB.html","title":"AWS.DocDB","type":"module"},{"doc":"Adds a source identifier to an existing event notification subscription.","ref":"AWS.DocDB.html#add_source_identifier_to_subscription/3","title":"AWS.DocDB.add_source_identifier_to_subscription/3","type":"function"},{"doc":"Adds metadata tags to an Amazon DocumentDB resource.\n\nYou can use these tags with cost allocation reporting to track costs that are\nassociated with Amazon DocumentDB resources or in a `Condition` statement in an\nIdentity and Access Management (IAM) policy for Amazon DocumentDB.","ref":"AWS.DocDB.html#add_tags_to_resource/3","title":"AWS.DocDB.add_tags_to_resource/3","type":"function"},{"doc":"Applies a pending maintenance action to a resource (for example, to an Amazon\nDocumentDB instance).","ref":"AWS.DocDB.html#apply_pending_maintenance_action/3","title":"AWS.DocDB.apply_pending_maintenance_action/3","type":"function"},{"doc":"Copies the specified cluster parameter group.","ref":"AWS.DocDB.html#copy_db_cluster_parameter_group/3","title":"AWS.DocDB.copy_db_cluster_parameter_group/3","type":"function"},{"doc":"Copies a snapshot of a cluster.\n\nTo copy a cluster snapshot from a shared manual cluster snapshot,\n`SourceDBClusterSnapshotIdentifier` must be the Amazon Resource Name (ARN) of\nthe shared cluster snapshot. You can only copy a shared DB cluster snapshot,\nwhether encrypted or not, in the same Amazon Web Services Region.\n\nTo cancel the copy operation after it is in progress, delete the target cluster\nsnapshot identified by `TargetDBClusterSnapshotIdentifier` while that cluster\nsnapshot is in the *copying* status.","ref":"AWS.DocDB.html#copy_db_cluster_snapshot/3","title":"AWS.DocDB.copy_db_cluster_snapshot/3","type":"function"},{"doc":"Creates a new Amazon DocumentDB cluster.","ref":"AWS.DocDB.html#create_db_cluster/3","title":"AWS.DocDB.create_db_cluster/3","type":"function"},{"doc":"Creates a new cluster parameter group.\n\nParameters in a cluster parameter group apply to all of the instances in a\ncluster.\n\nA cluster parameter group is initially created with the default parameters for\nthe database engine used by instances in the cluster. In Amazon DocumentDB, you\ncannot make modifications directly to the `default.docdb3.6` cluster parameter\ngroup. If your Amazon DocumentDB cluster is using the default cluster parameter\ngroup and you want to modify a value in it, you must first [ create a new parameter\ngroup](https://docs.aws.amazon.com/documentdb/latest/developerguide/cluster_parameter_group-create.html)\nor [ copy an existing parameter group](https://docs.aws.amazon.com/documentdb/latest/developerguide/cluster_parameter_group-copy.html),\nmodify it, and then apply the modified parameter group to your cluster. For the\nnew cluster parameter group and associated settings to take effect, you must\nthen reboot the instances in the cluster without failover. For more information,\nsee [ Modifying Amazon DocumentDB Cluster Parameter Groups](https://docs.aws.amazon.com/documentdb/latest/developerguide/cluster_parameter_group-modify.html).","ref":"AWS.DocDB.html#create_db_cluster_parameter_group/3","title":"AWS.DocDB.create_db_cluster_parameter_group/3","type":"function"},{"doc":"Creates a snapshot of a cluster.","ref":"AWS.DocDB.html#create_db_cluster_snapshot/3","title":"AWS.DocDB.create_db_cluster_snapshot/3","type":"function"},{"doc":"Creates a new instance.","ref":"AWS.DocDB.html#create_db_instance/3","title":"AWS.DocDB.create_db_instance/3","type":"function"},{"doc":"Creates a new subnet group.\n\nsubnet groups must contain at least one subnet in at least two Availability\nZones in the Amazon Web Services Region.","ref":"AWS.DocDB.html#create_db_subnet_group/3","title":"AWS.DocDB.create_db_subnet_group/3","type":"function"},{"doc":"Creates an Amazon DocumentDB event notification subscription.\n\nThis action requires a topic Amazon Resource Name (ARN) created by using the\nAmazon DocumentDB console, the Amazon SNS console, or the Amazon SNS API. To\nobtain an ARN with Amazon SNS, you must create a topic in Amazon SNS and\nsubscribe to the topic. The ARN is displayed in the Amazon SNS console.\n\nYou can specify the type of source (`SourceType`) that you want to be notified\nof. You can also provide a list of Amazon DocumentDB sources (`SourceIds`) that\ntrigger the events, and you can provide a list of event categories\n(`EventCategories`) for events that you want to be notified of. For example, you\ncan specify `SourceType = db-instance`, `SourceIds = mydbinstance1,\nmydbinstance2` and `EventCategories = Availability, Backup`.\n\nIf you specify both the `SourceType` and `SourceIds` (such as `SourceType =\ndb-instance` and `SourceIdentifier = myDBInstance1`), you are notified of all\nthe `db-instance` events for the specified source. If you specify a `SourceType`\nbut do not specify a `SourceIdentifier`, you receive notice of the events for\nthat source type for all your Amazon DocumentDB sources. If you do not specify\neither the `SourceType` or the `SourceIdentifier`, you are notified of events\ngenerated from all Amazon DocumentDB sources belonging to your customer account.","ref":"AWS.DocDB.html#create_event_subscription/3","title":"AWS.DocDB.create_event_subscription/3","type":"function"},{"doc":"Creates an Amazon DocumentDB global cluster that can span multiple multiple\nAmazon Web Services Regions.\n\nThe global cluster contains one primary cluster with read-write capability, and\nup-to give read-only secondary clusters. Global clusters uses storage-based fast\nreplication across regions with latencies less than one second, using dedicated\ninfrastructure with no impact to your workload’s performance.\n\nYou can create a global cluster that is initially empty, and then add a primary\nand a secondary to it. Or you can specify an existing cluster during the create\noperation, and this cluster becomes the primary of the global cluster.\n\nThis action only applies to Amazon DocumentDB clusters.","ref":"AWS.DocDB.html#create_global_cluster/3","title":"AWS.DocDB.create_global_cluster/3","type":"function"},{"doc":"Deletes a previously provisioned cluster.\n\nWhen you delete a cluster, all automated backups for that cluster are deleted\nand can't be recovered. Manual DB cluster snapshots of the specified cluster are\nnot deleted.","ref":"AWS.DocDB.html#delete_db_cluster/3","title":"AWS.DocDB.delete_db_cluster/3","type":"function"},{"doc":"Deletes a specified cluster parameter group.\n\nThe cluster parameter group to be deleted can't be associated with any clusters.","ref":"AWS.DocDB.html#delete_db_cluster_parameter_group/3","title":"AWS.DocDB.delete_db_cluster_parameter_group/3","type":"function"},{"doc":"Deletes a cluster snapshot.\n\nIf the snapshot is being copied, the copy operation is terminated.\n\nThe cluster snapshot must be in the `available` state to be deleted.","ref":"AWS.DocDB.html#delete_db_cluster_snapshot/3","title":"AWS.DocDB.delete_db_cluster_snapshot/3","type":"function"},{"doc":"Deletes a previously provisioned instance.","ref":"AWS.DocDB.html#delete_db_instance/3","title":"AWS.DocDB.delete_db_instance/3","type":"function"},{"doc":"Deletes a subnet group.\n\nThe specified database subnet group must not be associated with any DB\ninstances.","ref":"AWS.DocDB.html#delete_db_subnet_group/3","title":"AWS.DocDB.delete_db_subnet_group/3","type":"function"},{"doc":"Deletes an Amazon DocumentDB event notification subscription.","ref":"AWS.DocDB.html#delete_event_subscription/3","title":"AWS.DocDB.delete_event_subscription/3","type":"function"},{"doc":"Deletes a global cluster.\n\nThe primary and secondary clusters must already be detached or deleted before\nattempting to delete a global cluster.\n\nThis action only applies to Amazon DocumentDB clusters.","ref":"AWS.DocDB.html#delete_global_cluster/3","title":"AWS.DocDB.delete_global_cluster/3","type":"function"},{"doc":"Returns a list of certificate authority (CA) certificates provided by Amazon\nDocumentDB for this Amazon Web Services account.","ref":"AWS.DocDB.html#describe_certificates/3","title":"AWS.DocDB.describe_certificates/3","type":"function"},{"doc":"Returns a list of `DBClusterParameterGroup` descriptions.\n\nIf a `DBClusterParameterGroupName` parameter is specified, the list contains\nonly the description of the specified cluster parameter group.","ref":"AWS.DocDB.html#describe_db_cluster_parameter_groups/3","title":"AWS.DocDB.describe_db_cluster_parameter_groups/3","type":"function"},{"doc":"Returns the detailed parameter list for a particular cluster parameter group.","ref":"AWS.DocDB.html#describe_db_cluster_parameters/3","title":"AWS.DocDB.describe_db_cluster_parameters/3","type":"function"},{"doc":"Returns a list of cluster snapshot attribute names and values for a manual DB\ncluster snapshot.\n\nWhen you share snapshots with other Amazon Web Services accounts,\n`DescribeDBClusterSnapshotAttributes` returns the `restore` attribute and a list\nof IDs for the Amazon Web Services accounts that are authorized to copy or\nrestore the manual cluster snapshot. If `all` is included in the list of values\nfor the `restore` attribute, then the manual cluster snapshot is public and can\nbe copied or restored by all Amazon Web Services accounts.","ref":"AWS.DocDB.html#describe_db_cluster_snapshot_attributes/3","title":"AWS.DocDB.describe_db_cluster_snapshot_attributes/3","type":"function"},{"doc":"Returns information about cluster snapshots.\n\nThis API operation supports pagination.","ref":"AWS.DocDB.html#describe_db_cluster_snapshots/3","title":"AWS.DocDB.describe_db_cluster_snapshots/3","type":"function"},{"doc":"Returns information about provisioned Amazon DocumentDB clusters.\n\nThis API operation supports pagination. For certain management features such as\ncluster and instance lifecycle management, Amazon DocumentDB leverages\noperational technology that is shared with Amazon RDS and Amazon Neptune. Use\nthe `filterName=engine,Values=docdb` filter parameter to return only Amazon\nDocumentDB clusters.","ref":"AWS.DocDB.html#describe_db_clusters/3","title":"AWS.DocDB.describe_db_clusters/3","type":"function"},{"doc":"Returns a list of the available engines.","ref":"AWS.DocDB.html#describe_db_engine_versions/3","title":"AWS.DocDB.describe_db_engine_versions/3","type":"function"},{"doc":"Returns information about provisioned Amazon DocumentDB instances.\n\nThis API supports pagination.","ref":"AWS.DocDB.html#describe_db_instances/3","title":"AWS.DocDB.describe_db_instances/3","type":"function"},{"doc":"Returns a list of `DBSubnetGroup` descriptions.\n\nIf a `DBSubnetGroupName` is specified, the list will contain only the\ndescriptions of the specified `DBSubnetGroup`.","ref":"AWS.DocDB.html#describe_db_subnet_groups/3","title":"AWS.DocDB.describe_db_subnet_groups/3","type":"function"},{"doc":"Returns the default engine and system parameter information for the cluster\ndatabase engine.","ref":"AWS.DocDB.html#describe_engine_default_cluster_parameters/3","title":"AWS.DocDB.describe_engine_default_cluster_parameters/3","type":"function"},{"doc":"Displays a list of categories for all event source types, or, if specified, for\na specified source type.","ref":"AWS.DocDB.html#describe_event_categories/3","title":"AWS.DocDB.describe_event_categories/3","type":"function"},{"doc":"Lists all the subscription descriptions for a customer account.\n\nThe description for a subscription includes `SubscriptionName`, `SNSTopicARN`,\n`CustomerID`, `SourceType`, `SourceID`, `CreationTime`, and `Status`.\n\nIf you specify a `SubscriptionName`, lists the description for that\nsubscription.","ref":"AWS.DocDB.html#describe_event_subscriptions/3","title":"AWS.DocDB.describe_event_subscriptions/3","type":"function"},{"doc":"Returns events related to instances, security groups, snapshots, and DB\nparameter groups for the past 14 days.\n\nYou can obtain events specific to a particular DB instance, security group,\nsnapshot, or parameter group by providing the name as a parameter. By default,\nthe events of the past hour are returned.","ref":"AWS.DocDB.html#describe_events/3","title":"AWS.DocDB.describe_events/3","type":"function"},{"doc":"Returns information about Amazon DocumentDB global clusters.\n\nThis API supports pagination.\n\nThis action only applies to Amazon DocumentDB clusters.","ref":"AWS.DocDB.html#describe_global_clusters/3","title":"AWS.DocDB.describe_global_clusters/3","type":"function"},{"doc":"Returns a list of orderable instance options for the specified engine.","ref":"AWS.DocDB.html#describe_orderable_db_instance_options/3","title":"AWS.DocDB.describe_orderable_db_instance_options/3","type":"function"},{"doc":"Returns a list of resources (for example, instances) that have at least one\npending maintenance action.","ref":"AWS.DocDB.html#describe_pending_maintenance_actions/3","title":"AWS.DocDB.describe_pending_maintenance_actions/3","type":"function"},{"doc":"Forces a failover for a cluster.\n\nA failover for a cluster promotes one of the Amazon DocumentDB replicas\n(read-only instances) in the cluster to be the primary instance (the cluster\nwriter).\n\nIf the primary instance fails, Amazon DocumentDB automatically fails over to an\nAmazon DocumentDB replica, if one exists. You can force a failover when you want\nto simulate a failure of a primary instance for testing.","ref":"AWS.DocDB.html#failover_db_cluster/3","title":"AWS.DocDB.failover_db_cluster/3","type":"function"},{"doc":"Lists all tags on an Amazon DocumentDB resource.","ref":"AWS.DocDB.html#list_tags_for_resource/3","title":"AWS.DocDB.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.DocDB.html#metadata/0","title":"AWS.DocDB.metadata/0","type":"function"},{"doc":"Modifies a setting for an Amazon DocumentDB cluster.\n\nYou can change one or more database configuration parameters by specifying these\nparameters and the new values in the request.","ref":"AWS.DocDB.html#modify_db_cluster/3","title":"AWS.DocDB.modify_db_cluster/3","type":"function"},{"doc":"Modifies the parameters of a cluster parameter group.\n\nTo modify more than one parameter, submit a list of the following:\n`ParameterName`, `ParameterValue`, and `ApplyMethod`. A maximum of 20 parameters\ncan be modified in a single request.\n\nChanges to dynamic parameters are applied immediately. Changes to static\nparameters require a reboot or maintenance window before the change can take\neffect.\n\nAfter you create a cluster parameter group, you should wait at least 5 minutes\nbefore creating your first cluster that uses that cluster parameter group as the\ndefault parameter group. This allows Amazon DocumentDB to fully complete the\ncreate action before the parameter group is used as the default for a new\ncluster. This step is especially important for parameters that are critical when\ncreating the default database for a cluster, such as the character set for the\ndefault database defined by the `character_set_database` parameter.","ref":"AWS.DocDB.html#modify_db_cluster_parameter_group/3","title":"AWS.DocDB.modify_db_cluster_parameter_group/3","type":"function"},{"doc":"Adds an attribute and values to, or removes an attribute and values from, a\nmanual cluster snapshot.\n\nTo share a manual cluster snapshot with other Amazon Web Services accounts,\nspecify `restore` as the `AttributeName`, and use the `ValuesToAdd` parameter to\nadd a list of IDs of the Amazon Web Services accounts that are authorized to\nrestore the manual cluster snapshot. Use the value `all` to make the manual\ncluster snapshot public, which means that it can be copied or restored by all\nAmazon Web Services accounts. Do not add the `all` value for any manual cluster\nsnapshots that contain private information that you don't want available to all\nAmazon Web Services accounts. If a manual cluster snapshot is encrypted, it can\nbe shared, but only by specifying a list of authorized Amazon Web Services\naccount IDs for the `ValuesToAdd` parameter. You can't use `all` as a value for\nthat parameter in this case.","ref":"AWS.DocDB.html#modify_db_cluster_snapshot_attribute/3","title":"AWS.DocDB.modify_db_cluster_snapshot_attribute/3","type":"function"},{"doc":"Modifies settings for an instance.\n\nYou can change one or more database configuration parameters by specifying these\nparameters and the new values in the request.","ref":"AWS.DocDB.html#modify_db_instance/3","title":"AWS.DocDB.modify_db_instance/3","type":"function"},{"doc":"Modifies an existing subnet group.\n\nsubnet groups must contain at least one subnet in at least two Availability\nZones in the Amazon Web Services Region.","ref":"AWS.DocDB.html#modify_db_subnet_group/3","title":"AWS.DocDB.modify_db_subnet_group/3","type":"function"},{"doc":"Modifies an existing Amazon DocumentDB event notification subscription.","ref":"AWS.DocDB.html#modify_event_subscription/3","title":"AWS.DocDB.modify_event_subscription/3","type":"function"},{"doc":"Modify a setting for an Amazon DocumentDB global cluster.\n\nYou can change one or more configuration parameters (for example: deletion\nprotection), or the global cluster identifier by specifying these parameters and\nthe new values in the request.\n\nThis action only applies to Amazon DocumentDB clusters.","ref":"AWS.DocDB.html#modify_global_cluster/3","title":"AWS.DocDB.modify_global_cluster/3","type":"function"},{"doc":"You might need to reboot your instance, usually for maintenance reasons.\n\nFor example, if you make certain changes, or if you change the cluster parameter\ngroup that is associated with the instance, you must reboot the instance for the\nchanges to take effect.\n\nRebooting an instance restarts the database engine service. Rebooting an\ninstance results in a momentary outage, during which the instance status is set\nto *rebooting*.","ref":"AWS.DocDB.html#reboot_db_instance/3","title":"AWS.DocDB.reboot_db_instance/3","type":"function"},{"doc":"Detaches an Amazon DocumentDB secondary cluster from a global cluster.\n\nThe cluster becomes a standalone cluster with read-write capability instead of\nbeing read-only and receiving data from a primary in a different region.\n\nThis action only applies to Amazon DocumentDB clusters.","ref":"AWS.DocDB.html#remove_from_global_cluster/3","title":"AWS.DocDB.remove_from_global_cluster/3","type":"function"},{"doc":"Removes a source identifier from an existing Amazon DocumentDB event\nnotification subscription.","ref":"AWS.DocDB.html#remove_source_identifier_from_subscription/3","title":"AWS.DocDB.remove_source_identifier_from_subscription/3","type":"function"},{"doc":"Removes metadata tags from an Amazon DocumentDB resource.","ref":"AWS.DocDB.html#remove_tags_from_resource/3","title":"AWS.DocDB.remove_tags_from_resource/3","type":"function"},{"doc":"Modifies the parameters of a cluster parameter group to the default value.\n\nTo reset specific parameters, submit a list of the following: `ParameterName`\nand `ApplyMethod`. To reset the entire cluster parameter group, specify the\n`DBClusterParameterGroupName` and `ResetAllParameters` parameters.\n\nWhen you reset the entire group, dynamic parameters are updated immediately and\nstatic parameters are set to `pending-reboot` to take effect on the next DB\ninstance reboot.","ref":"AWS.DocDB.html#reset_db_cluster_parameter_group/3","title":"AWS.DocDB.reset_db_cluster_parameter_group/3","type":"function"},{"doc":"Creates a new cluster from a snapshot or cluster snapshot.\n\nIf a snapshot is specified, the target cluster is created from the source DB\nsnapshot with a default configuration and default security group.\n\nIf a cluster snapshot is specified, the target cluster is created from the\nsource cluster restore point with the same configuration as the original source\nDB cluster, except that the new cluster is created with the default security\ngroup.","ref":"AWS.DocDB.html#restore_db_cluster_from_snapshot/3","title":"AWS.DocDB.restore_db_cluster_from_snapshot/3","type":"function"},{"doc":"Restores a cluster to an arbitrary point in time.\n\nUsers can restore to any point in time before `LatestRestorableTime` for up to\n`BackupRetentionPeriod` days. The target cluster is created from the source\ncluster with the same configuration as the original cluster, except that the new\ncluster is created with the default security group.","ref":"AWS.DocDB.html#restore_db_cluster_to_point_in_time/3","title":"AWS.DocDB.restore_db_cluster_to_point_in_time/3","type":"function"},{"doc":"Restarts the stopped cluster that is specified by `DBClusterIdentifier`.\n\nFor more information, see [Stopping and Starting an Amazon DocumentDB Cluster](https://docs.aws.amazon.com/documentdb/latest/developerguide/db-cluster-stop-start.html).","ref":"AWS.DocDB.html#start_db_cluster/3","title":"AWS.DocDB.start_db_cluster/3","type":"function"},{"doc":"Stops the running cluster that is specified by `DBClusterIdentifier`.\n\nThe cluster must be in the *available* state. For more information, see\n[Stopping and Starting an Amazon DocumentDB Cluster](https://docs.aws.amazon.com/documentdb/latest/developerguide/db-cluster-stop-start.html).","ref":"AWS.DocDB.html#stop_db_cluster/3","title":"AWS.DocDB.stop_db_cluster/3","type":"function"},{"doc":"The new Amazon Elastic DocumentDB service endpoint.","ref":"AWS.DocDBElastic.html","title":"AWS.DocDBElastic","type":"module"},{"doc":"Creates a new Elastic DocumentDB cluster and returns its Cluster structure.","ref":"AWS.DocDBElastic.html#create_cluster/3","title":"AWS.DocDBElastic.create_cluster/3","type":"function"},{"doc":"Creates a snapshot of a cluster.","ref":"AWS.DocDBElastic.html#create_cluster_snapshot/3","title":"AWS.DocDBElastic.create_cluster_snapshot/3","type":"function"},{"doc":"Delete a Elastic DocumentDB cluster.","ref":"AWS.DocDBElastic.html#delete_cluster/4","title":"AWS.DocDBElastic.delete_cluster/4","type":"function"},{"doc":"Delete a Elastic DocumentDB snapshot.","ref":"AWS.DocDBElastic.html#delete_cluster_snapshot/4","title":"AWS.DocDBElastic.delete_cluster_snapshot/4","type":"function"},{"doc":"Returns information about a specific Elastic DocumentDB cluster.","ref":"AWS.DocDBElastic.html#get_cluster/3","title":"AWS.DocDBElastic.get_cluster/3","type":"function"},{"doc":"Returns information about a specific Elastic DocumentDB snapshot","ref":"AWS.DocDBElastic.html#get_cluster_snapshot/3","title":"AWS.DocDBElastic.get_cluster_snapshot/3","type":"function"},{"doc":"Returns information about Elastic DocumentDB snapshots for a specified cluster.","ref":"AWS.DocDBElastic.html#list_cluster_snapshots/5","title":"AWS.DocDBElastic.list_cluster_snapshots/5","type":"function"},{"doc":"Returns information about provisioned Elastic DocumentDB clusters.","ref":"AWS.DocDBElastic.html#list_clusters/4","title":"AWS.DocDBElastic.list_clusters/4","type":"function"},{"doc":"Lists all tags on a Elastic DocumentDB resource","ref":"AWS.DocDBElastic.html#list_tags_for_resource/3","title":"AWS.DocDBElastic.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.DocDBElastic.html#metadata/0","title":"AWS.DocDBElastic.metadata/0","type":"function"},{"doc":"Restores a Elastic DocumentDB cluster from a snapshot.","ref":"AWS.DocDBElastic.html#restore_cluster_from_snapshot/4","title":"AWS.DocDBElastic.restore_cluster_from_snapshot/4","type":"function"},{"doc":"Adds metadata tags to a Elastic DocumentDB resource","ref":"AWS.DocDBElastic.html#tag_resource/4","title":"AWS.DocDBElastic.tag_resource/4","type":"function"},{"doc":"Removes metadata tags to a Elastic DocumentDB resource","ref":"AWS.DocDBElastic.html#untag_resource/4","title":"AWS.DocDBElastic.untag_resource/4","type":"function"},{"doc":"Modifies a Elastic DocumentDB cluster.\n\nThis includes updating admin-username/password, upgrading API version setting up\na backup window and maintenance window","ref":"AWS.DocDBElastic.html#update_cluster/4","title":"AWS.DocDBElastic.update_cluster/4","type":"function"},{"doc":"AWS Elastic Disaster Recovery Service.","ref":"AWS.Drs.html","title":"AWS.Drs","type":"module"},{"doc":"Associate a Source Network to an existing CloudFormation Stack and modify launch\ntemplates to use this network.\n\nCan be used for reverting to previously deployed CloudFormation stacks.","ref":"AWS.Drs.html#associate_source_network_stack/3","title":"AWS.Drs.associate_source_network_stack/3","type":"function"},{"doc":"Create an extended source server in the target Account based on the source\nserver in staging account.","ref":"AWS.Drs.html#create_extended_source_server/3","title":"AWS.Drs.create_extended_source_server/3","type":"function"},{"doc":"Creates a new Launch Configuration Template.","ref":"AWS.Drs.html#create_launch_configuration_template/3","title":"AWS.Drs.create_launch_configuration_template/3","type":"function"},{"doc":"Creates a new ReplicationConfigurationTemplate.","ref":"AWS.Drs.html#create_replication_configuration_template/3","title":"AWS.Drs.create_replication_configuration_template/3","type":"function"},{"doc":"Create a new Source Network resource for a provided VPC ID.","ref":"AWS.Drs.html#create_source_network/3","title":"AWS.Drs.create_source_network/3","type":"function"},{"doc":"Deletes a single Job by ID.","ref":"AWS.Drs.html#delete_job/3","title":"AWS.Drs.delete_job/3","type":"function"},{"doc":"Deletes a resource launch action.","ref":"AWS.Drs.html#delete_launch_action/3","title":"AWS.Drs.delete_launch_action/3","type":"function"},{"doc":"Deletes a single Launch Configuration Template by ID.","ref":"AWS.Drs.html#delete_launch_configuration_template/3","title":"AWS.Drs.delete_launch_configuration_template/3","type":"function"},{"doc":"Deletes a single Recovery Instance by ID.\n\nThis deletes the Recovery Instance resource from Elastic Disaster Recovery. The\nRecovery Instance must be disconnected first in order to delete it.","ref":"AWS.Drs.html#delete_recovery_instance/3","title":"AWS.Drs.delete_recovery_instance/3","type":"function"},{"doc":"Deletes a single Replication Configuration Template by ID","ref":"AWS.Drs.html#delete_replication_configuration_template/3","title":"AWS.Drs.delete_replication_configuration_template/3","type":"function"},{"doc":"Delete Source Network resource.","ref":"AWS.Drs.html#delete_source_network/3","title":"AWS.Drs.delete_source_network/3","type":"function"},{"doc":"Deletes a single Source Server by ID.\n\nThe Source Server must be disconnected first.","ref":"AWS.Drs.html#delete_source_server/3","title":"AWS.Drs.delete_source_server/3","type":"function"},{"doc":"Retrieves a detailed Job log with pagination.","ref":"AWS.Drs.html#describe_job_log_items/3","title":"AWS.Drs.describe_job_log_items/3","type":"function"},{"doc":"Returns a list of Jobs.\n\nUse the JobsID and fromDate and toDate filters to limit which jobs are returned.\nThe response is sorted by creationDataTime - latest date first. Jobs are created\nby the StartRecovery, TerminateRecoveryInstances and StartFailbackLaunch APIs.\nJobs are also created by DiagnosticLaunch and TerminateDiagnosticInstances,\nwhich are APIs available only to *Support* and only used in response to relevant\nsupport tickets.","ref":"AWS.Drs.html#describe_jobs/3","title":"AWS.Drs.describe_jobs/3","type":"function"},{"doc":"Lists all Launch Configuration Templates, filtered by Launch Configuration\nTemplate IDs","ref":"AWS.Drs.html#describe_launch_configuration_templates/3","title":"AWS.Drs.describe_launch_configuration_templates/3","type":"function"},{"doc":"Lists all Recovery Instances or multiple Recovery Instances by ID.","ref":"AWS.Drs.html#describe_recovery_instances/3","title":"AWS.Drs.describe_recovery_instances/3","type":"function"},{"doc":"Lists all Recovery Snapshots for a single Source Server.","ref":"AWS.Drs.html#describe_recovery_snapshots/3","title":"AWS.Drs.describe_recovery_snapshots/3","type":"function"},{"doc":"Lists all ReplicationConfigurationTemplates, filtered by Source Server IDs.","ref":"AWS.Drs.html#describe_replication_configuration_templates/3","title":"AWS.Drs.describe_replication_configuration_templates/3","type":"function"},{"doc":"Lists all Source Networks or multiple Source Networks filtered by ID.","ref":"AWS.Drs.html#describe_source_networks/3","title":"AWS.Drs.describe_source_networks/3","type":"function"},{"doc":"Lists all Source Servers or multiple Source Servers filtered by ID.","ref":"AWS.Drs.html#describe_source_servers/3","title":"AWS.Drs.describe_source_servers/3","type":"function"},{"doc":"Disconnect a Recovery Instance from Elastic Disaster Recovery.\n\nData replication is stopped immediately. All AWS resources created by Elastic\nDisaster Recovery for enabling the replication of the Recovery Instance will be\nterminated / deleted within 90 minutes. If the agent on the Recovery Instance\nhas not been prevented from communicating with the Elastic Disaster Recovery\nservice, then it will receive a command to uninstall itself (within\napproximately 10 minutes). The following properties of the Recovery Instance\nwill be changed immediately: dataReplicationInfo.dataReplicationState will be\nset to DISCONNECTED; The totalStorageBytes property for each of\ndataReplicationInfo.replicatedDisks will be set to zero;\ndataReplicationInfo.lagDuration and dataReplicationInfo.lagDuration will be\nnullified.","ref":"AWS.Drs.html#disconnect_recovery_instance/3","title":"AWS.Drs.disconnect_recovery_instance/3","type":"function"},{"doc":"Disconnects a specific Source Server from Elastic Disaster Recovery.\n\nData replication is stopped immediately. All AWS resources created by Elastic\nDisaster Recovery for enabling the replication of the Source Server will be\nterminated / deleted within 90 minutes. You cannot disconnect a Source Server if\nit has a Recovery Instance. If the agent on the Source Server has not been\nprevented from communicating with the Elastic Disaster Recovery service, then it\nwill receive a command to uninstall itself (within approximately 10 minutes).\nThe following properties of the SourceServer will be changed immediately:\ndataReplicationInfo.dataReplicationState will be set to DISCONNECTED; The\ntotalStorageBytes property for each of dataReplicationInfo.replicatedDisks will\nbe set to zero; dataReplicationInfo.lagDuration and\ndataReplicationInfo.lagDuration will be nullified.","ref":"AWS.Drs.html#disconnect_source_server/3","title":"AWS.Drs.disconnect_source_server/3","type":"function"},{"doc":"Export the Source Network CloudFormation template to an S3 bucket.","ref":"AWS.Drs.html#export_source_network_cfn_template/3","title":"AWS.Drs.export_source_network_cfn_template/3","type":"function"},{"doc":"Lists all Failback ReplicationConfigurations, filtered by Recovery Instance ID.","ref":"AWS.Drs.html#get_failback_replication_configuration/3","title":"AWS.Drs.get_failback_replication_configuration/3","type":"function"},{"doc":"Gets a LaunchConfiguration, filtered by Source Server IDs.","ref":"AWS.Drs.html#get_launch_configuration/3","title":"AWS.Drs.get_launch_configuration/3","type":"function"},{"doc":"Gets a ReplicationConfiguration, filtered by Source Server ID.","ref":"AWS.Drs.html#get_replication_configuration/3","title":"AWS.Drs.get_replication_configuration/3","type":"function"},{"doc":"Initialize Elastic Disaster Recovery.","ref":"AWS.Drs.html#initialize_service/3","title":"AWS.Drs.initialize_service/3","type":"function"},{"doc":"Returns a list of source servers on a staging account that are extensible, which\nmeans that: a.\n\nThe source server is not already extended into this Account. b. The source\nserver on the Account we’re reading from is not an extension of another source\nserver.","ref":"AWS.Drs.html#list_extensible_source_servers/3","title":"AWS.Drs.list_extensible_source_servers/3","type":"function"},{"doc":"Lists resource launch actions.","ref":"AWS.Drs.html#list_launch_actions/3","title":"AWS.Drs.list_launch_actions/3","type":"function"},{"doc":"Returns an array of staging accounts for existing extended source servers.","ref":"AWS.Drs.html#list_staging_accounts/4","title":"AWS.Drs.list_staging_accounts/4","type":"function"},{"doc":"List all tags for your Elastic Disaster Recovery resources.","ref":"AWS.Drs.html#list_tags_for_resource/3","title":"AWS.Drs.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.Drs.html#metadata/0","title":"AWS.Drs.metadata/0","type":"function"},{"doc":"Puts a resource launch action.","ref":"AWS.Drs.html#put_launch_action/3","title":"AWS.Drs.put_launch_action/3","type":"function"},{"doc":"WARNING: RetryDataReplication is deprecated.\n\nCauses the data replication initiation sequence to begin immediately upon next\nHandshake for the specified Source Server ID, regardless of when the previous\ninitiation started. This command will work only if the Source Server is stalled\nor is in a DISCONNECTED or STOPPED state.","ref":"AWS.Drs.html#retry_data_replication/3","title":"AWS.Drs.retry_data_replication/3","type":"function"},{"doc":"Start replication to origin / target region - applies only to protected\ninstances that originated in EC2.\n\nFor recovery instances on target region - starts replication back to origin\nregion. For failback instances on origin region - starts replication to target\nregion to re-protect them.","ref":"AWS.Drs.html#reverse_replication/3","title":"AWS.Drs.reverse_replication/3","type":"function"},{"doc":"Initiates a Job for launching the machine that is being failed back to from the\nspecified Recovery Instance.\n\nThis will run conversion on the failback client and will reboot your machine,\nthus completing the failback process.","ref":"AWS.Drs.html#start_failback_launch/3","title":"AWS.Drs.start_failback_launch/3","type":"function"},{"doc":"Launches Recovery Instances for the specified Source Servers.\n\nFor each Source Server you may choose a point in time snapshot to launch from,\nor use an on demand snapshot.","ref":"AWS.Drs.html#start_recovery/3","title":"AWS.Drs.start_recovery/3","type":"function"},{"doc":"Starts replication for a stopped Source Server.\n\nThis action would make the Source Server protected again and restart billing for\nit.","ref":"AWS.Drs.html#start_replication/3","title":"AWS.Drs.start_replication/3","type":"function"},{"doc":"Deploy VPC for the specified Source Network and modify launch templates to use\nthis network.\n\nThe VPC will be deployed using a dedicated CloudFormation stack.","ref":"AWS.Drs.html#start_source_network_recovery/3","title":"AWS.Drs.start_source_network_recovery/3","type":"function"},{"doc":"Starts replication for a Source Network.\n\nThis action would make the Source Network protected.","ref":"AWS.Drs.html#start_source_network_replication/3","title":"AWS.Drs.start_source_network_replication/3","type":"function"},{"doc":"Stops the failback process for a specified Recovery Instance.\n\nThis changes the Failback State of the Recovery Instance back to\nFAILBACK_NOT_STARTED.","ref":"AWS.Drs.html#stop_failback/3","title":"AWS.Drs.stop_failback/3","type":"function"},{"doc":"Stops replication for a Source Server.\n\nThis action would make the Source Server unprotected, delete its existing\nsnapshots and stop billing for it.","ref":"AWS.Drs.html#stop_replication/3","title":"AWS.Drs.stop_replication/3","type":"function"},{"doc":"Stops replication for a Source Network.\n\nThis action would make the Source Network unprotected.","ref":"AWS.Drs.html#stop_source_network_replication/3","title":"AWS.Drs.stop_source_network_replication/3","type":"function"},{"doc":"Adds or overwrites only the specified tags for the specified Elastic Disaster\nRecovery resource or resources.\n\nWhen you specify an existing tag key, the value is overwritten with the new\nvalue. Each resource can have a maximum of 50 tags. Each tag consists of a key\nand optional value.","ref":"AWS.Drs.html#tag_resource/4","title":"AWS.Drs.tag_resource/4","type":"function"},{"doc":"Initiates a Job for terminating the EC2 resources associated with the specified\nRecovery Instances, and then will delete the Recovery Instances from the Elastic\nDisaster Recovery service.","ref":"AWS.Drs.html#terminate_recovery_instances/3","title":"AWS.Drs.terminate_recovery_instances/3","type":"function"},{"doc":"Deletes the specified set of tags from the specified set of Elastic Disaster\nRecovery resources.","ref":"AWS.Drs.html#untag_resource/4","title":"AWS.Drs.untag_resource/4","type":"function"},{"doc":"Allows you to update the failback replication configuration of a Recovery\nInstance by ID.","ref":"AWS.Drs.html#update_failback_replication_configuration/3","title":"AWS.Drs.update_failback_replication_configuration/3","type":"function"},{"doc":"Updates a LaunchConfiguration by Source Server ID.","ref":"AWS.Drs.html#update_launch_configuration/3","title":"AWS.Drs.update_launch_configuration/3","type":"function"},{"doc":"Updates an existing Launch Configuration Template by ID.","ref":"AWS.Drs.html#update_launch_configuration_template/3","title":"AWS.Drs.update_launch_configuration_template/3","type":"function"},{"doc":"Allows you to update a ReplicationConfiguration by Source Server ID.","ref":"AWS.Drs.html#update_replication_configuration/3","title":"AWS.Drs.update_replication_configuration/3","type":"function"},{"doc":"Updates a ReplicationConfigurationTemplate by ID.","ref":"AWS.Drs.html#update_replication_configuration_template/3","title":"AWS.Drs.update_replication_configuration_template/3","type":"function"},{"doc":"Amazon DynamoDB\n\nAmazon DynamoDB is a fully managed NoSQL database service that provides fast and\npredictable performance with seamless scalability.\n\nDynamoDB lets you offload the administrative burdens of operating and scaling a\ndistributed database, so that you don't have to worry about hardware\nprovisioning, setup and configuration, replication, software patching, or\ncluster scaling.\n\nWith DynamoDB, you can create database tables that can store and retrieve any\namount of data, and serve any level of request traffic. You can scale up or\nscale down your tables' throughput capacity without downtime or performance\ndegradation, and use the Amazon Web Services Management Console to monitor\nresource utilization and performance metrics.\n\nDynamoDB automatically spreads the data and traffic for your tables over a\nsufficient number of servers to handle your throughput and storage requirements,\nwhile maintaining consistent and fast performance. All of your data is stored on\nsolid state disks (SSDs) and automatically replicated across multiple\nAvailability Zones in an Amazon Web Services Region, providing built-in high\navailability and data durability.","ref":"AWS.DynamoDB.html","title":"AWS.DynamoDB","type":"module"},{"doc":"This operation allows you to perform batch reads or writes on data stored in\nDynamoDB, using PartiQL.\n\nEach read statement in a `BatchExecuteStatement` must specify an equality\ncondition on all key attributes. This enforces that each `SELECT` statement in a\nbatch returns at most a single item.\n\nThe entire batch must consist of either read statements or write statements, you\ncannot mix both in one batch.\n\nA HTTP 200 response does not mean that all statements in the\nBatchExecuteStatement succeeded. Error details for individual statements can be\nfound under the\n[Error](https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_BatchStatementResponse.html#DDB-Type-BatchStatementResponse-Error)\nfield of the `BatchStatementResponse` for each statement.","ref":"AWS.DynamoDB.html#batch_execute_statement/3","title":"AWS.DynamoDB.batch_execute_statement/3","type":"function"},{"doc":"The `BatchGetItem` operation returns the attributes of one or more items from\none or more tables.\n\nYou identify requested items by primary key.\n\nA single operation can retrieve up to 16 MB of data, which can contain as many\nas 100 items. `BatchGetItem` returns a partial result if the response size limit\nis exceeded, the table's provisioned throughput is exceeded, more than 1MB per\npartition is requested, or an internal processing failure occurs. If a partial\nresult is returned, the operation returns a value for `UnprocessedKeys`. You can\nuse this value to retry the operation starting with the next item to get.\n\nIf you request more than 100 items, `BatchGetItem` returns a\n`ValidationException` with the message \"Too many items requested for the\nBatchGetItem call.\"\n\nFor example, if you ask to retrieve 100 items, but each individual item is 300\nKB in size, the system returns 52 items (so as not to exceed the 16 MB limit).\nIt also returns an appropriate `UnprocessedKeys` value so you can get the next\npage of results. If desired, your application can include its own logic to\nassemble the pages of results into one dataset.\n\nIf *none* of the items can be processed due to insufficient provisioned\nthroughput on all of the tables in the request, then `BatchGetItem` returns a\n`ProvisionedThroughputExceededException`. If *at least one* of the items is\nsuccessfully processed, then `BatchGetItem` completes successfully, while\nreturning the keys of the unread items in `UnprocessedKeys`.\n\nIf DynamoDB returns any unprocessed items, you should retry the batch operation\non those items. However, *we strongly recommend that you use an exponential\nbackoff algorithm*. If you retry the batch operation immediately, the underlying\nread or write requests can still fail due to throttling on the individual\ntables. If you delay the batch operation using exponential backoff, the\nindividual requests in the batch are much more likely to succeed.\n\nFor more information, see [Batch Operations and Error Handling](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/ErrorHandling.html#BatchOperations)\nin the *Amazon DynamoDB Developer Guide*.\n\nBy default, `BatchGetItem` performs eventually consistent reads on every table\nin the request. If you want strongly consistent reads instead, you can set\n`ConsistentRead` to `true` for any or all tables.\n\nIn order to minimize response latency, `BatchGetItem` may retrieve items in\nparallel.\n\nWhen designing your application, keep in mind that DynamoDB does not return\nitems in any particular order. To help parse the response by item, include the\nprimary key values for the items in your request in the `ProjectionExpression`\nparameter.\n\nIf a requested item does not exist, it is not returned in the result. Requests\nfor nonexistent items consume the minimum read capacity units according to the\ntype of read. For more information, see [Working with Tables](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/WorkingWithTables.html#CapacityUnitCalculations)\nin the *Amazon DynamoDB Developer Guide*.","ref":"AWS.DynamoDB.html#batch_get_item/3","title":"AWS.DynamoDB.batch_get_item/3","type":"function"},{"doc":"The `BatchWriteItem` operation puts or deletes multiple items in one or more\ntables.\n\nA single call to `BatchWriteItem` can transmit up to 16MB of data over the\nnetwork, consisting of up to 25 item put or delete operations. While individual\nitems can be up to 400 KB once stored, it's important to note that an item's\nrepresentation might be greater than 400KB while being sent in DynamoDB's JSON\nformat for the API call. For more details on this distinction, see [Naming Rules and Data\nTypes](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/HowItWorks.NamingRulesDataTypes.html).\n\n`BatchWriteItem` cannot update items. If you perform a `BatchWriteItem`\noperation on an existing item, that item's values will be overwritten by the\noperation and it will appear like it was updated. To update items, we recommend\nyou use the `UpdateItem` action.\n\nThe individual `PutItem` and `DeleteItem` operations specified in\n`BatchWriteItem` are atomic; however `BatchWriteItem` as a whole is not. If any\nrequested operations fail because the table's provisioned throughput is exceeded\nor an internal processing failure occurs, the failed operations are returned in\nthe `UnprocessedItems` response parameter. You can investigate and optionally\nresend the requests. Typically, you would call `BatchWriteItem` in a loop. Each\niteration would check for unprocessed items and submit a new `BatchWriteItem`\nrequest with those unprocessed items until all items have been processed.\n\nIf *none* of the items can be processed due to insufficient provisioned\nthroughput on all of the tables in the request, then `BatchWriteItem` returns a\n`ProvisionedThroughputExceededException`.\n\nIf DynamoDB returns any unprocessed items, you should retry the batch operation\non those items. However, *we strongly recommend that you use an exponential\nbackoff algorithm*. If you retry the batch operation immediately, the underlying\nread or write requests can still fail due to throttling on the individual\ntables. If you delay the batch operation using exponential backoff, the\nindividual requests in the batch are much more likely to succeed.\n\nFor more information, see [Batch Operations and Error Handling](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/ErrorHandling.html#Programming.Errors.BatchOperations)\nin the *Amazon DynamoDB Developer Guide*.\n\nWith `BatchWriteItem`, you can efficiently write or delete large amounts of\ndata, such as from Amazon EMR, or copy data from another database into DynamoDB.\nIn order to improve performance with these large-scale operations,\n`BatchWriteItem` does not behave in the same way as individual `PutItem` and\n`DeleteItem` calls would. For example, you cannot specify conditions on\nindividual put and delete requests, and `BatchWriteItem` does not return deleted\nitems in the response.\n\nIf you use a programming language that supports concurrency, you can use threads\nto write items in parallel. Your application must include the necessary logic to\nmanage the threads. With languages that don't support threading, you must update\nor delete the specified items one at a time. In both situations,\n`BatchWriteItem` performs the specified put and delete operations in parallel,\ngiving you the power of the thread pool approach without having to introduce\ncomplexity into your application.\n\nParallel processing reduces latency, but each specified put and delete request\nconsumes the same number of write capacity units whether it is processed in\nparallel or not. Delete operations on nonexistent items consume one write\ncapacity unit.\n\nIf one or more of the following is true, DynamoDB rejects the entire batch write\noperation:\n\n  * One or more tables specified in the `BatchWriteItem` request does\nnot exist.\n\n  * Primary key attributes specified on an item in the request do not\nmatch those in the corresponding table's primary key schema.\n\n  * You try to perform multiple operations on the same item in the\nsame `BatchWriteItem` request. For example, you cannot put and delete the same\nitem in the same `BatchWriteItem` request.\n\n  * Your request contains at least two items with identical hash and\nrange keys (which essentially is two put operations).\n\n  * There are more than 25 requests in the batch.\n\n  * Any individual item in a batch exceeds 400 KB.\n\n  * The total request size exceeds 16 MB.","ref":"AWS.DynamoDB.html#batch_write_item/3","title":"AWS.DynamoDB.batch_write_item/3","type":"function"},{"doc":"Creates a backup for an existing table.\n\nEach time you create an on-demand backup, the entire table data is backed up.\nThere is no limit to the number of on-demand backups that can be taken.\n\nWhen you create an on-demand backup, a time marker of the request is cataloged,\nand the backup is created asynchronously, by applying all changes until the time\nof the request to the last full table snapshot. Backup requests are processed\ninstantaneously and become available for restore within minutes.\n\nYou can call `CreateBackup` at a maximum rate of 50 times per second.\n\nAll backups in DynamoDB work without consuming any provisioned throughput on the\ntable.\n\nIf you submit a backup request on 2018-12-14 at 14:25:00, the backup is\nguaranteed to contain all data committed to the table up to 14:24:00, and data\ncommitted after 14:26:00 will not be. The backup might contain data\nmodifications made between 14:24:00 and 14:26:00. On-demand backup does not\nsupport causal consistency.\n\nAlong with data, the following are also included on the backups:\n\n  * Global secondary indexes (GSIs)\n\n  * Local secondary indexes (LSIs)\n\n  * Streams\n\n  * Provisioned read and write capacity","ref":"AWS.DynamoDB.html#create_backup/3","title":"AWS.DynamoDB.create_backup/3","type":"function"},{"doc":"Creates a global table from an existing table.\n\nA global table creates a replication relationship between two or more DynamoDB\ntables with the same table name in the provided Regions.\n\nThis operation only applies to [Version 2017.11.29 (Legacy)](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/globaltables.V1.html)\nof global tables. We recommend using [Version 2019.11.21 (Current)](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/globaltables.V2.html)\nwhen creating new global tables, as it provides greater flexibility, higher\nefficiency and consumes less write capacity than 2017.11.29 (Legacy). To\ndetermine which version you are using, see [Determining the version](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/globaltables.DetermineVersion.html).\nTo update existing global tables from version 2017.11.29 (Legacy) to version\n2019.11.21 (Current), see [ Updating global tables](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/V2globaltables_upgrade.html).\n\nIf you want to add a new replica table to a global table, each of the following\nconditions must be true:\n\n  * The table must have the same primary key as all of the other\nreplicas.\n\n  * The table must have the same name as all of the other replicas.\n\n  * The table must have DynamoDB Streams enabled, with the stream\ncontaining both the new and the old images of the item.\n\n  * None of the replica tables in the global table can contain any\ndata.\n\nIf global secondary indexes are specified, then the following conditions must\nalso be met:\n\n  * The global secondary indexes must have the same name.\n\n  * The global secondary indexes must have the same hash key and sort\nkey (if present).\n\nIf local secondary indexes are specified, then the following conditions must\nalso be met:\n\n  * The local secondary indexes must have the same name.\n\n  * The local secondary indexes must have the same hash key and sort\nkey (if present).\n\nWrite capacity settings should be set consistently across your replica tables\nand secondary indexes. DynamoDB strongly recommends enabling auto scaling to\nmanage the write capacity settings for all of your global tables replicas and\nindexes.\n\nIf you prefer to manage write capacity settings manually, you should provision\nequal replicated write capacity units to your replica tables. You should also\nprovision equal replicated write capacity units to matching secondary indexes\nacross your global table.","ref":"AWS.DynamoDB.html#create_global_table/3","title":"AWS.DynamoDB.create_global_table/3","type":"function"},{"doc":"The `CreateTable` operation adds a new table to your account.\n\nIn an Amazon Web Services account, table names must be unique within each\nRegion. That is, you can have two tables with same name if you create the tables\nin different Regions.\n\n`CreateTable` is an asynchronous operation. Upon receiving a `CreateTable`\nrequest, DynamoDB immediately returns a response with a `TableStatus` of\n`CREATING`. After the table is created, DynamoDB sets the `TableStatus` to\n`ACTIVE`. You can perform read and write operations only on an `ACTIVE` table.\n\nYou can optionally define secondary indexes on the new table, as part of the\n`CreateTable` operation. If you want to create multiple tables with secondary\nindexes on them, you must create the tables sequentially. Only one table with\nsecondary indexes can be in the `CREATING` state at any given time.\n\nYou can use the `DescribeTable` action to check the table status.","ref":"AWS.DynamoDB.html#create_table/3","title":"AWS.DynamoDB.create_table/3","type":"function"},{"doc":"Deletes an existing backup of a table.\n\nYou can call `DeleteBackup` at a maximum rate of 10 times per second.","ref":"AWS.DynamoDB.html#delete_backup/3","title":"AWS.DynamoDB.delete_backup/3","type":"function"},{"doc":"Deletes a single item in a table by primary key.\n\nYou can perform a conditional delete operation that deletes the item if it\nexists, or if it has an expected attribute value.\n\nIn addition to deleting an item, you can also return the item's attribute values\nin the same operation, using the `ReturnValues` parameter.\n\nUnless you specify conditions, the `DeleteItem` is an idempotent operation;\nrunning it multiple times on the same item or attribute does *not* result in an\nerror response.\n\nConditional deletes are useful for deleting items only if specific conditions\nare met. If those conditions are met, DynamoDB performs the delete. Otherwise,\nthe item is not deleted.","ref":"AWS.DynamoDB.html#delete_item/3","title":"AWS.DynamoDB.delete_item/3","type":"function"},{"doc":"The `DeleteTable` operation deletes a table and all of its items.\n\nAfter a `DeleteTable` request, the specified table is in the `DELETING` state\nuntil DynamoDB completes the deletion. If the table is in the `ACTIVE` state,\nyou can delete it. If a table is in `CREATING` or `UPDATING` states, then\nDynamoDB returns a `ResourceInUseException`. If the specified table does not\nexist, DynamoDB returns a `ResourceNotFoundException`. If table is already in\nthe `DELETING` state, no error is returned.\n\nThis operation only applies to [Version 2019.11.21 (Current)](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/globaltables.V2.html)\nof global tables.\n\nDynamoDB might continue to accept data read and write operations, such as\n`GetItem` and `PutItem`, on a table in the `DELETING` state until the table\ndeletion is complete.\n\nWhen you delete a table, any indexes on that table are also deleted.\n\nIf you have DynamoDB Streams enabled on the table, then the corresponding stream\non that table goes into the `DISABLED` state, and the stream is automatically\ndeleted after 24 hours.\n\nUse the `DescribeTable` action to check the status of the table.","ref":"AWS.DynamoDB.html#delete_table/3","title":"AWS.DynamoDB.delete_table/3","type":"function"},{"doc":"Describes an existing backup of a table.\n\nYou can call `DescribeBackup` at a maximum rate of 10 times per second.","ref":"AWS.DynamoDB.html#describe_backup/3","title":"AWS.DynamoDB.describe_backup/3","type":"function"},{"doc":"Checks the status of continuous backups and point in time recovery on the\nspecified table.\n\nContinuous backups are `ENABLED` on all tables at table creation. If point in\ntime recovery is enabled, `PointInTimeRecoveryStatus` will be set to ENABLED.\n\nAfter continuous backups and point in time recovery are enabled, you can restore\nto any point in time within `EarliestRestorableDateTime` and\n`LatestRestorableDateTime`.\n\n`LatestRestorableDateTime` is typically 5 minutes before the current time. You\ncan restore your table to any point in time during the last 35 days.\n\nYou can call `DescribeContinuousBackups` at a maximum rate of 10 times per\nsecond.","ref":"AWS.DynamoDB.html#describe_continuous_backups/3","title":"AWS.DynamoDB.describe_continuous_backups/3","type":"function"},{"doc":"Returns information about contributor insights for a given table or global\nsecondary index.","ref":"AWS.DynamoDB.html#describe_contributor_insights/3","title":"AWS.DynamoDB.describe_contributor_insights/3","type":"function"},{"doc":"Returns the regional endpoint information.\n\nFor more information on policy permissions, please see [Internetwork traffic privacy](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/inter-network-traffic-privacy.html#inter-network-traffic-DescribeEndpoints).","ref":"AWS.DynamoDB.html#describe_endpoints/3","title":"AWS.DynamoDB.describe_endpoints/3","type":"function"},{"doc":"Describes an existing table export.","ref":"AWS.DynamoDB.html#describe_export/3","title":"AWS.DynamoDB.describe_export/3","type":"function"},{"doc":"Returns information about the specified global table.\n\nThis operation only applies to [Version 2017.11.29 (Legacy)](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/globaltables.V1.html)\nof global tables. We recommend using [Version 2019.11.21 (Current)](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/globaltables.V2.html)\nwhen creating new global tables, as it provides greater flexibility, higher\nefficiency and consumes less write capacity than 2017.11.29 (Legacy). To\ndetermine which version you are using, see [Determining the version](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/globaltables.DetermineVersion.html).\nTo update existing global tables from version 2017.11.29 (Legacy) to version\n2019.11.21 (Current), see [ Updating global tables](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/V2globaltables_upgrade.html).","ref":"AWS.DynamoDB.html#describe_global_table/3","title":"AWS.DynamoDB.describe_global_table/3","type":"function"},{"doc":"Describes Region-specific settings for a global table.\n\nThis operation only applies to [Version 2017.11.29 (Legacy)](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/globaltables.V1.html)\nof global tables. We recommend using [Version 2019.11.21 (Current)](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/globaltables.V2.html)\nwhen creating new global tables, as it provides greater flexibility, higher\nefficiency and consumes less write capacity than 2017.11.29 (Legacy). To\ndetermine which version you are using, see [Determining the version](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/globaltables.DetermineVersion.html).\nTo update existing global tables from version 2017.11.29 (Legacy) to version\n2019.11.21 (Current), see [ Updating global tables](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/V2globaltables_upgrade.html).","ref":"AWS.DynamoDB.html#describe_global_table_settings/3","title":"AWS.DynamoDB.describe_global_table_settings/3","type":"function"},{"doc":"Represents the properties of the import.","ref":"AWS.DynamoDB.html#describe_import/3","title":"AWS.DynamoDB.describe_import/3","type":"function"},{"doc":"Returns information about the status of Kinesis streaming.","ref":"AWS.DynamoDB.html#describe_kinesis_streaming_destination/3","title":"AWS.DynamoDB.describe_kinesis_streaming_destination/3","type":"function"},{"doc":"Returns the current provisioned-capacity quotas for your Amazon Web Services\naccount in a Region, both for the Region as a whole and for any one DynamoDB\ntable that you create there.\n\nWhen you establish an Amazon Web Services account, the account has initial\nquotas on the maximum read capacity units and write capacity units that you can\nprovision across all of your DynamoDB tables in a given Region. Also, there are\nper-table quotas that apply when you create a table there. For more information,\nsee [Service, Account, and Table Quotas](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/Limits.html)\npage in the *Amazon DynamoDB Developer Guide*.\n\nAlthough you can increase these quotas by filing a case at [Amazon Web Services Support Center](https://console.aws.amazon.com/support/home#/), obtaining the\nincrease is not instantaneous. The `DescribeLimits` action lets you write code\nto compare the capacity you are currently using to those quotas imposed by your\naccount so that you have enough time to apply for an increase before you hit a\nquota.\n\nFor example, you could use one of the Amazon Web Services SDKs to do the\nfollowing:\n\n  1. Call `DescribeLimits` for a particular Region to obtain your\ncurrent account quotas on provisioned capacity there.\n\n  2. Create a variable to hold the aggregate read capacity units\nprovisioned for all your tables in that Region, and one to hold the aggregate\nwrite capacity units. Zero them both.\n\n  3. Call `ListTables` to obtain a list of all your DynamoDB tables.\n\n  4. For each table name listed by `ListTables`, do the following:\n\n    * Call `DescribeTable` with the table name.\n\n    * Use the data returned by `DescribeTable` to add the\nread capacity units and write capacity units provisioned for the table itself to\nyour variables.\n\n    * If the table has one or more global secondary indexes\n(GSIs), loop over these GSIs and add their provisioned capacity values to your\nvariables as well.\n\n  5. Report the account quotas for that Region returned by\n`DescribeLimits`, along with the total current provisioned capacity levels you\nhave calculated.\n\nThis will let you see whether you are getting close to your account-level\nquotas.\n\nThe per-table quotas apply only when you are creating a new table. They restrict\nthe sum of the provisioned capacity of the new table itself and all its global\nsecondary indexes.\n\nFor existing tables and their GSIs, DynamoDB doesn't let you increase\nprovisioned capacity extremely rapidly, but the only quota that applies is that\nthe aggregate provisioned capacity over all your tables and GSIs cannot exceed\neither of the per-account quotas.\n\n`DescribeLimits` should only be called periodically. You can expect throttling\nerrors if you call it more than once in a minute.\n\nThe `DescribeLimits` Request element has no content.","ref":"AWS.DynamoDB.html#describe_limits/3","title":"AWS.DynamoDB.describe_limits/3","type":"function"},{"doc":"Returns information about the table, including the current status of the table,\nwhen it was created, the primary key schema, and any indexes on the table.\n\nThis operation only applies to [Version 2019.11.21 (Current)](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/globaltables.V2.html)\nof global tables.\n\nIf you issue a `DescribeTable` request immediately after a `CreateTable`\nrequest, DynamoDB might return a `ResourceNotFoundException`. This is because\n`DescribeTable` uses an eventually consistent query, and the metadata for your\ntable might not be available at that moment. Wait for a few seconds, and then\ntry the `DescribeTable` request again.","ref":"AWS.DynamoDB.html#describe_table/3","title":"AWS.DynamoDB.describe_table/3","type":"function"},{"doc":"Describes auto scaling settings across replicas of the global table at once.\n\nThis operation only applies to [Version 2019.11.21 (Current)](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/globaltables.V2.html)\nof global tables.","ref":"AWS.DynamoDB.html#describe_table_replica_auto_scaling/3","title":"AWS.DynamoDB.describe_table_replica_auto_scaling/3","type":"function"},{"doc":"Gives a description of the Time to Live (TTL) status on the specified table.","ref":"AWS.DynamoDB.html#describe_time_to_live/3","title":"AWS.DynamoDB.describe_time_to_live/3","type":"function"},{"doc":"Stops replication from the DynamoDB table to the Kinesis data stream.\n\nThis is done without deleting either of the resources.","ref":"AWS.DynamoDB.html#disable_kinesis_streaming_destination/3","title":"AWS.DynamoDB.disable_kinesis_streaming_destination/3","type":"function"},{"doc":"Starts table data replication to the specified Kinesis data stream at a\ntimestamp chosen during the enable workflow.\n\nIf this operation doesn't return results immediately, use\nDescribeKinesisStreamingDestination to check if streaming to the Kinesis data\nstream is ACTIVE.","ref":"AWS.DynamoDB.html#enable_kinesis_streaming_destination/3","title":"AWS.DynamoDB.enable_kinesis_streaming_destination/3","type":"function"},{"doc":"This operation allows you to perform reads and singleton writes on data stored\nin DynamoDB, using PartiQL.\n\nFor PartiQL reads (`SELECT` statement), if the total number of processed items\nexceeds the maximum dataset size limit of 1 MB, the read stops and results are\nreturned to the user as a `LastEvaluatedKey` value to continue the read in a\nsubsequent operation. If the filter criteria in `WHERE` clause does not match\nany data, the read will return an empty result set.\n\nA single `SELECT` statement response can return up to the maximum number of\nitems (if using the Limit parameter) or a maximum of 1 MB of data (and then\napply any filtering to the results using `WHERE` clause). If `LastEvaluatedKey`\nis present in the response, you need to paginate the result set. If `NextToken`\nis present, you need to paginate the result set and include `NextToken`.","ref":"AWS.DynamoDB.html#execute_statement/3","title":"AWS.DynamoDB.execute_statement/3","type":"function"},{"doc":"This operation allows you to perform transactional reads or writes on data\nstored in DynamoDB, using PartiQL.\n\nThe entire transaction must consist of either read statements or write\nstatements, you cannot mix both in one transaction. The EXISTS function is an\nexception and can be used to check the condition of specific attributes of the\nitem in a similar manner to `ConditionCheck` in the\n[TransactWriteItems](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/transaction-apis.html#transaction-apis-txwriteitems)\nAPI.","ref":"AWS.DynamoDB.html#execute_transaction/3","title":"AWS.DynamoDB.execute_transaction/3","type":"function"},{"doc":"Exports table data to an S3 bucket.\n\nThe table must have point in time recovery enabled, and you can export data from\nany time within the point in time recovery window.","ref":"AWS.DynamoDB.html#export_table_to_point_in_time/3","title":"AWS.DynamoDB.export_table_to_point_in_time/3","type":"function"},{"doc":"The `GetItem` operation returns a set of attributes for the item with the given\nprimary key.\n\nIf there is no matching item, `GetItem` does not return any data and there will\nbe no `Item` element in the response.\n\n`GetItem` provides an eventually consistent read by default. If your application\nrequires a strongly consistent read, set `ConsistentRead` to `true`. Although a\nstrongly consistent read might take more time than an eventually consistent\nread, it always returns the last updated value.","ref":"AWS.DynamoDB.html#get_item/3","title":"AWS.DynamoDB.get_item/3","type":"function"},{"doc":"Imports table data from an S3 bucket.","ref":"AWS.DynamoDB.html#import_table/3","title":"AWS.DynamoDB.import_table/3","type":"function"},{"doc":"List DynamoDB backups that are associated with an Amazon Web Services account\nand weren't made with Amazon Web Services Backup.\n\nTo list these backups for a given table, specify `TableName`. `ListBackups`\nreturns a paginated list of results with at most 1 MB worth of items in a page.\nYou can also specify a maximum number of entries to be returned in a page.\n\nIn the request, start time is inclusive, but end time is exclusive. Note that\nthese boundaries are for the time at which the original backup was requested.\n\nYou can call `ListBackups` a maximum of five times per second.\n\nIf you want to retrieve the complete list of backups made with Amazon Web\nServices Backup, use the [Amazon Web Services Backup list API.](https://docs.aws.amazon.com/aws-backup/latest/devguide/API_ListBackupJobs.html)","ref":"AWS.DynamoDB.html#list_backups/3","title":"AWS.DynamoDB.list_backups/3","type":"function"},{"doc":"Returns a list of ContributorInsightsSummary for a table and all its global\nsecondary indexes.","ref":"AWS.DynamoDB.html#list_contributor_insights/3","title":"AWS.DynamoDB.list_contributor_insights/3","type":"function"},{"doc":"Lists completed exports within the past 90 days.","ref":"AWS.DynamoDB.html#list_exports/3","title":"AWS.DynamoDB.list_exports/3","type":"function"},{"doc":"Lists all global tables that have a replica in the specified Region.\n\nThis operation only applies to [Version 2017.11.29 (Legacy)](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/globaltables.V1.html)\nof global tables. We recommend using [Version 2019.11.21 (Current)](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/globaltables.V2.html)\nwhen creating new global tables, as it provides greater flexibility, higher\nefficiency and consumes less write capacity than 2017.11.29 (Legacy). To\ndetermine which version you are using, see [Determining the version](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/globaltables.DetermineVersion.html).\nTo update existing global tables from version 2017.11.29 (Legacy) to version\n2019.11.21 (Current), see [ Updating global tables](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/V2globaltables_upgrade.html).","ref":"AWS.DynamoDB.html#list_global_tables/3","title":"AWS.DynamoDB.list_global_tables/3","type":"function"},{"doc":"Lists completed imports within the past 90 days.","ref":"AWS.DynamoDB.html#list_imports/3","title":"AWS.DynamoDB.list_imports/3","type":"function"},{"doc":"Returns an array of table names associated with the current account and\nendpoint.\n\nThe output from `ListTables` is paginated, with each page returning a maximum of\n100 table names.","ref":"AWS.DynamoDB.html#list_tables/3","title":"AWS.DynamoDB.list_tables/3","type":"function"},{"doc":"List all tags on an Amazon DynamoDB resource.\n\nYou can call ListTagsOfResource up to 10 times per second, per account.\n\nFor an overview on tagging DynamoDB resources, see [Tagging for DynamoDB](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/Tagging.html)\nin the *Amazon DynamoDB Developer Guide*.","ref":"AWS.DynamoDB.html#list_tags_of_resource/3","title":"AWS.DynamoDB.list_tags_of_resource/3","type":"function"},{"doc":"","ref":"AWS.DynamoDB.html#metadata/0","title":"AWS.DynamoDB.metadata/0","type":"function"},{"doc":"Creates a new item, or replaces an old item with a new item.\n\nIf an item that has the same primary key as the new item already exists in the\nspecified table, the new item completely replaces the existing item. You can\nperform a conditional put operation (add a new item if one with the specified\nprimary key doesn't exist), or replace an existing item if it has certain\nattribute values. You can return the item's attribute values in the same\noperation, using the `ReturnValues` parameter.\n\nWhen you add an item, the primary key attributes are the only required\nattributes.\n\nEmpty String and Binary attribute values are allowed. Attribute values of type\nString and Binary must have a length greater than zero if the attribute is used\nas a key attribute for a table or index. Set type attributes cannot be empty.\n\nInvalid Requests with empty values will be rejected with a `ValidationException`\nexception.\n\nTo prevent a new item from replacing an existing item, use a conditional\nexpression that contains the `attribute_not_exists` function with the name of\nthe attribute being used as the partition key for the table. Since every record\nmust contain that attribute, the `attribute_not_exists` function will only\nsucceed if no matching item exists.\n\nFor more information about `PutItem`, see [Working with Items](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/WorkingWithItems.html)\nin the *Amazon DynamoDB Developer Guide*.","ref":"AWS.DynamoDB.html#put_item/3","title":"AWS.DynamoDB.put_item/3","type":"function"},{"doc":"You must provide the name of the partition key attribute and a single value for\nthat attribute.\n\n`Query` returns all items with that partition key value. Optionally, you can\nprovide a sort key attribute and use a comparison operator to refine the search\nresults.\n\nUse the `KeyConditionExpression` parameter to provide a specific value for the\npartition key. The `Query` operation will return all of the items from the table\nor index with that partition key value. You can optionally narrow the scope of\nthe `Query` operation by specifying a sort key value and a comparison operator\nin `KeyConditionExpression`. To further refine the `Query` results, you can\noptionally provide a `FilterExpression`. A `FilterExpression` determines which\nitems within the results should be returned to you. All of the other results are\ndiscarded.\n\nA `Query` operation always returns a result set. If no matching items are found,\nthe result set will be empty. Queries that do not return results consume the\nminimum number of read capacity units for that type of read operation.\n\nDynamoDB calculates the number of read capacity units consumed based on item\nsize, not on the amount of data that is returned to an application. The number\nof capacity units consumed will be the same whether you request all of the\nattributes (the default behavior) or just some of them (using a projection\nexpression). The number will also be the same whether or not you use a\n`FilterExpression`.\n\n`Query` results are always sorted by the sort key value. If the data type of the\nsort key is Number, the results are returned in numeric order; otherwise, the\nresults are returned in order of UTF-8 bytes. By default, the sort order is\nascending. To reverse the order, set the `ScanIndexForward` parameter to false.\n\nA single `Query` operation will read up to the maximum number of items set (if\nusing the `Limit` parameter) or a maximum of 1 MB of data and then apply any\nfiltering to the results using `FilterExpression`. If `LastEvaluatedKey` is\npresent in the response, you will need to paginate the result set. For more\ninformation, see [Paginating the Results](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/Query.html#Query.Pagination)\nin the *Amazon DynamoDB Developer Guide*.\n\n`FilterExpression` is applied after a `Query` finishes, but before the results\nare returned. A `FilterExpression` cannot contain partition key or sort key\nattributes. You need to specify those attributes in the\n`KeyConditionExpression`.\n\nA `Query` operation can return an empty result set and a `LastEvaluatedKey` if\nall the items read for the page of results are filtered out.\n\nYou can query a table, a local secondary index, or a global secondary index. For\na query on a table or on a local secondary index, you can set the\n`ConsistentRead` parameter to `true` and obtain a strongly consistent result.\nGlobal secondary indexes support eventually consistent reads only, so do not\nspecify `ConsistentRead` when querying a global secondary index.","ref":"AWS.DynamoDB.html#query/3","title":"AWS.DynamoDB.query/3","type":"function"},{"doc":"Creates a new table from an existing backup.\n\nAny number of users can execute up to 50 concurrent restores (any type of\nrestore) in a given account.\n\nYou can call `RestoreTableFromBackup` at a maximum rate of 10 times per second.\n\nYou must manually set up the following on the restored table:\n\n  * Auto scaling policies\n\n  * IAM policies\n\n  * Amazon CloudWatch metrics and alarms\n\n  * Tags\n\n  * Stream settings\n\n  * Time to Live (TTL) settings","ref":"AWS.DynamoDB.html#restore_table_from_backup/3","title":"AWS.DynamoDB.restore_table_from_backup/3","type":"function"},{"doc":"Restores the specified table to the specified point in time within\n`EarliestRestorableDateTime` and `LatestRestorableDateTime`.\n\nYou can restore your table to any point in time during the last 35 days. Any\nnumber of users can execute up to 50 concurrent restores (any type of restore)\nin a given account.\n\nWhen you restore using point in time recovery, DynamoDB restores your table data\nto the state based on the selected date and time (day:hour:minute:second) to a\nnew table.\n\nAlong with data, the following are also included on the new restored table using\npoint in time recovery:\n\n  * Global secondary indexes (GSIs)\n\n  * Local secondary indexes (LSIs)\n\n  * Provisioned read and write capacity\n\n  * Encryption settings\n\nAll these settings come from the current settings of the source table at the\ntime of restore.\n\nYou must manually set up the following on the restored table:\n\n  * Auto scaling policies\n\n  * IAM policies\n\n  * Amazon CloudWatch metrics and alarms\n\n  * Tags\n\n  * Stream settings\n\n  * Time to Live (TTL) settings\n\n  * Point in time recovery settings","ref":"AWS.DynamoDB.html#restore_table_to_point_in_time/3","title":"AWS.DynamoDB.restore_table_to_point_in_time/3","type":"function"},{"doc":"The `Scan` operation returns one or more items and item attributes by accessing\nevery item in a table or a secondary index.\n\nTo have DynamoDB return fewer items, you can provide a `FilterExpression`\noperation.\n\nIf the total size of scanned items exceeds the maximum dataset size limit of 1\nMB, the scan completes and results are returned to the user. The\n`LastEvaluatedKey` value is also returned and the requestor can use the\n`LastEvaluatedKey` to continue the scan in a subsequent operation. Each scan\nresponse also includes number of items that were scanned (ScannedCount) as part\nof the request. If using a `FilterExpression`, a scan result can result in no\nitems meeting the criteria and the `Count` will result in zero. If you did not\nuse a `FilterExpression` in the scan request, then `Count` is the same as\n`ScannedCount`.\n\n`Count` and `ScannedCount` only return the count of items specific to a single\nscan request and, unless the table is less than 1MB, do not represent the total\nnumber of items in the table.\n\nA single `Scan` operation first reads up to the maximum number of items set (if\nusing the `Limit` parameter) or a maximum of 1 MB of data and then applies any\nfiltering to the results if a `FilterExpression` is provided. If\n`LastEvaluatedKey` is present in the response, pagination is required to\ncomplete the full table scan. For more information, see [Paginating the Results](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/Scan.html#Scan.Pagination)\nin the *Amazon DynamoDB Developer Guide*.\n\n`Scan` operations proceed sequentially; however, for faster performance on a\nlarge table or secondary index, applications can request a parallel `Scan`\noperation by providing the `Segment` and `TotalSegments` parameters. For more\ninformation, see [Parallel Scan](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/Scan.html#Scan.ParallelScan)\nin the *Amazon DynamoDB Developer Guide*.\n\nBy default, a `Scan` uses eventually consistent reads when accessing the items\nin a table. Therefore, the results from an eventually consistent `Scan` may not\ninclude the latest item changes at the time the scan iterates through each item\nin the table. If you require a strongly consistent read of each item as the scan\niterates through the items in the table, you can set the `ConsistentRead`\nparameter to true. Strong consistency only relates to the consistency of the\nread at the item level.\n\nDynamoDB does not provide snapshot isolation for a scan operation when the\n`ConsistentRead` parameter is set to true. Thus, a DynamoDB scan operation does\nnot guarantee that all reads in a scan see a consistent snapshot of the table\nwhen the scan operation was requested.","ref":"AWS.DynamoDB.html#scan/3","title":"AWS.DynamoDB.scan/3","type":"function"},{"doc":"Associate a set of tags with an Amazon DynamoDB resource.\n\nYou can then activate these user-defined tags so that they appear on the Billing\nand Cost Management console for cost allocation tracking. You can call\nTagResource up to five times per second, per account.\n\nFor an overview on tagging DynamoDB resources, see [Tagging for DynamoDB](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/Tagging.html)\nin the *Amazon DynamoDB Developer Guide*.","ref":"AWS.DynamoDB.html#tag_resource/3","title":"AWS.DynamoDB.tag_resource/3","type":"function"},{"doc":"`TransactGetItems` is a synchronous operation that atomically retrieves multiple\nitems from one or more tables (but not from indexes) in a single account and\nRegion.\n\nA `TransactGetItems` call can contain up to 100 `TransactGetItem` objects, each\nof which contains a `Get` structure that specifies an item to retrieve from a\ntable in the account and Region. A call to `TransactGetItems` cannot retrieve\nitems from tables in more than one Amazon Web Services account or Region. The\naggregate size of the items in the transaction cannot exceed 4 MB.\n\nDynamoDB rejects the entire `TransactGetItems` request if any of the following\nis true:\n\n  * A conflicting operation is in the process of updating an item to\nbe read.\n\n  * There is insufficient provisioned capacity for the transaction to\nbe completed.\n\n  * There is a user error, such as an invalid data format.\n\n  * The aggregate size of the items in the transaction exceeded 4 MB.","ref":"AWS.DynamoDB.html#transact_get_items/3","title":"AWS.DynamoDB.transact_get_items/3","type":"function"},{"doc":"`TransactWriteItems` is a synchronous write operation that groups up to 100\naction requests.\n\nThese actions can target items in different tables, but not in different Amazon\nWeb Services accounts or Regions, and no two actions can target the same item.\nFor example, you cannot both `ConditionCheck` and `Update` the same item. The\naggregate size of the items in the transaction cannot exceed 4 MB.\n\nThe actions are completed atomically so that either all of them succeed, or all\nof them fail. They are defined by the following objects:\n\n  * `Put`  —   Initiates a `PutItem` operation to write a new item.\nThis structure specifies the primary key of the item to be written, the name of\nthe table to write it in, an optional condition expression that must be\nsatisfied for the write to succeed, a list of the item's attributes, and a field\nindicating whether to retrieve the item's attributes if the condition is not\nmet.\n\n  * `Update`  —   Initiates an `UpdateItem` operation to update an\nexisting item. This structure specifies the primary key of the item to be\nupdated, the name of the table where it resides, an optional condition\nexpression that must be satisfied for the update to succeed, an expression that\ndefines one or more attributes to be updated, and a field indicating whether to\nretrieve the item's attributes if the condition is not met.\n\n  * `Delete`  —   Initiates a `DeleteItem` operation to delete an\nexisting item. This structure specifies the primary key of the item to be\ndeleted, the name of the table where it resides, an optional condition\nexpression that must be satisfied for the deletion to succeed, and a field\nindicating whether to retrieve the item's attributes if the condition is not\nmet.\n\n  * `ConditionCheck`  —   Applies a condition to an item that is not\nbeing modified by the transaction. This structure specifies the primary key of\nthe item to be checked, the name of the table where it resides, a condition\nexpression that must be satisfied for the transaction to succeed, and a field\nindicating whether to retrieve the item's attributes if the condition is not\nmet.\n\nDynamoDB rejects the entire `TransactWriteItems` request if any of the following\nis true:\n\n  * A condition in one of the condition expressions is not met.\n\n  * An ongoing operation is in the process of updating the same item.\n\n  * There is insufficient provisioned capacity for the transaction to\nbe completed.\n\n  * An item size becomes too large (bigger than 400 KB), a local\nsecondary index (LSI) becomes too large, or a similar validation error occurs\nbecause of changes made by the transaction.\n\n  * The aggregate size of the items in the transaction exceeds 4 MB.\n\n  * There is a user error, such as an invalid data format.","ref":"AWS.DynamoDB.html#transact_write_items/3","title":"AWS.DynamoDB.transact_write_items/3","type":"function"},{"doc":"Removes the association of tags from an Amazon DynamoDB resource.\n\nYou can call `UntagResource` up to five times per second, per account.\n\nFor an overview on tagging DynamoDB resources, see [Tagging for DynamoDB](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/Tagging.html)\nin the *Amazon DynamoDB Developer Guide*.","ref":"AWS.DynamoDB.html#untag_resource/3","title":"AWS.DynamoDB.untag_resource/3","type":"function"},{"doc":"`UpdateContinuousBackups` enables or disables point in time recovery for the\nspecified table.\n\nA successful `UpdateContinuousBackups` call returns the current\n`ContinuousBackupsDescription`. Continuous backups are `ENABLED` on all tables\nat table creation. If point in time recovery is enabled,\n`PointInTimeRecoveryStatus` will be set to ENABLED.\n\nOnce continuous backups and point in time recovery are enabled, you can restore\nto any point in time within `EarliestRestorableDateTime` and\n`LatestRestorableDateTime`.\n\n`LatestRestorableDateTime` is typically 5 minutes before the current time. You\ncan restore your table to any point in time during the last 35 days.","ref":"AWS.DynamoDB.html#update_continuous_backups/3","title":"AWS.DynamoDB.update_continuous_backups/3","type":"function"},{"doc":"Updates the status for contributor insights for a specific table or index.\n\nCloudWatch Contributor Insights for DynamoDB graphs display the partition key\nand (if applicable) sort key of frequently accessed items and frequently\nthrottled items in plaintext. If you require the use of Amazon Web Services Key\nManagement Service (KMS) to encrypt this table’s partition key and sort key data\nwith an Amazon Web Services managed key or customer managed key, you should not\nenable CloudWatch Contributor Insights for DynamoDB for this table.","ref":"AWS.DynamoDB.html#update_contributor_insights/3","title":"AWS.DynamoDB.update_contributor_insights/3","type":"function"},{"doc":"Adds or removes replicas in the specified global table.\n\nThe global table must already exist to be able to use this operation. Any\nreplica to be added must be empty, have the same name as the global table, have\nthe same key schema, have DynamoDB Streams enabled, and have the same\nprovisioned and maximum write capacity units.\n\nThis operation only applies to [Version 2017.11.29 (Legacy)](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/globaltables.V1.html)\nof global tables. We recommend using [Version 2019.11.21 (Current)](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/globaltables.V2.html)\nwhen creating new global tables, as it provides greater flexibility, higher\nefficiency and consumes less write capacity than 2017.11.29 (Legacy). To\ndetermine which version you are using, see [Determining the version](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/globaltables.DetermineVersion.html).\nTo update existing global tables from version 2017.11.29 (Legacy) to version\n2019.11.21 (Current), see [ Updating global tables](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/V2globaltables_upgrade.html).\n\nThis operation only applies to [Version 2017.11.29](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/globaltables.V1.html)\nof global tables. If you are using global tables [Version 2019.11.21](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/globaltables.V2.html)\nyou can use\n[DescribeTable](https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_DescribeTable.html)\ninstead.\n\nAlthough you can use `UpdateGlobalTable` to add replicas and remove replicas in\na single request, for simplicity we recommend that you issue separate requests\nfor adding or removing replicas.\n\nIf global secondary indexes are specified, then the following conditions must\nalso be met:\n\n  * The global secondary indexes must have the same name.\n\n  * The global secondary indexes must have the same hash key and sort\nkey (if present).\n\n  * The global secondary indexes must have the same provisioned and\nmaximum write capacity units.","ref":"AWS.DynamoDB.html#update_global_table/3","title":"AWS.DynamoDB.update_global_table/3","type":"function"},{"doc":"Updates settings for a global table.\n\nThis operation only applies to [Version 2017.11.29 (Legacy)](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/globaltables.V1.html)\nof global tables. We recommend using [Version 2019.11.21 (Current)](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/globaltables.V2.html)\nwhen creating new global tables, as it provides greater flexibility, higher\nefficiency and consumes less write capacity than 2017.11.29 (Legacy). To\ndetermine which version you are using, see [Determining the version](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/globaltables.DetermineVersion.html).\nTo update existing global tables from version 2017.11.29 (Legacy) to version\n2019.11.21 (Current), see [ Updating global tables](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/V2globaltables_upgrade.html).","ref":"AWS.DynamoDB.html#update_global_table_settings/3","title":"AWS.DynamoDB.update_global_table_settings/3","type":"function"},{"doc":"Edits an existing item's attributes, or adds a new item to the table if it does\nnot already exist.\n\nYou can put, delete, or add attribute values. You can also perform a conditional\nupdate on an existing item (insert a new attribute name-value pair if it doesn't\nexist, or replace an existing name-value pair if it has certain expected\nattribute values).\n\nYou can also return the item's attribute values in the same `UpdateItem`\noperation using the `ReturnValues` parameter.","ref":"AWS.DynamoDB.html#update_item/3","title":"AWS.DynamoDB.update_item/3","type":"function"},{"doc":"The command to update the Kinesis stream destination.","ref":"AWS.DynamoDB.html#update_kinesis_streaming_destination/3","title":"AWS.DynamoDB.update_kinesis_streaming_destination/3","type":"function"},{"doc":"Modifies the provisioned throughput settings, global secondary indexes, or\nDynamoDB Streams settings for a given table.\n\nThis operation only applies to [Version 2019.11.21 (Current)](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/globaltables.V2.html)\nof global tables.\n\nYou can only perform one of the following operations at once:\n\n  * Modify the provisioned throughput settings of the table.\n\n  * Remove a global secondary index from the table.\n\n  * Create a new global secondary index on the table. After the index\nbegins backfilling, you can use `UpdateTable` to perform other operations.\n\n`UpdateTable` is an asynchronous operation; while it is executing, the table\nstatus changes from `ACTIVE` to `UPDATING`. While it is `UPDATING`, you cannot\nissue another `UpdateTable` request. When the table returns to the `ACTIVE`\nstate, the `UpdateTable` operation is complete.","ref":"AWS.DynamoDB.html#update_table/3","title":"AWS.DynamoDB.update_table/3","type":"function"},{"doc":"Updates auto scaling settings on your global tables at once.\n\nThis operation only applies to [Version 2019.11.21 (Current)](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/globaltables.V2.html)\nof global tables.","ref":"AWS.DynamoDB.html#update_table_replica_auto_scaling/3","title":"AWS.DynamoDB.update_table_replica_auto_scaling/3","type":"function"},{"doc":"The `UpdateTimeToLive` method enables or disables Time to Live (TTL) for the\nspecified table.\n\nA successful `UpdateTimeToLive` call returns the current\n`TimeToLiveSpecification`. It can take up to one hour for the change to fully\nprocess. Any additional `UpdateTimeToLive` calls for the same table during this\none hour duration result in a `ValidationException`.\n\nTTL compares the current time in epoch time format to the time stored in the TTL\nattribute of an item. If the epoch time value stored in the attribute is less\nthan the current time, the item is marked as expired and subsequently deleted.\n\nThe epoch time format is the number of seconds elapsed since 12:00:00 AM January\n1, 1970 UTC.\n\nDynamoDB deletes expired items on a best-effort basis to ensure availability of\nthroughput for other data operations.\n\nDynamoDB typically deletes expired items within two days of expiration. The\nexact duration within which an item gets deleted after expiration is specific to\nthe nature of the workload. Items that have expired and not been deleted will\nstill show up in reads, queries, and scans.\n\nAs items are deleted, they are removed from any local secondary index and global\nsecondary index immediately in the same eventually consistent way as a standard\ndelete operation.\n\nFor more information, see [Time To Live](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/TTL.html)\nin the Amazon DynamoDB Developer Guide.","ref":"AWS.DynamoDB.html#update_time_to_live/3","title":"AWS.DynamoDB.update_time_to_live/3","type":"function"},{"doc":"Amazon DynamoDB\n\nAmazon DynamoDB Streams provides API actions for accessing streams and\nprocessing stream records.\n\nTo learn more about application development with Streams, see [Capturing Table Activity with DynamoDB\nStreams](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/Streams.html)\nin the Amazon DynamoDB Developer Guide.","ref":"AWS.DynamoDBStreams.html","title":"AWS.DynamoDBStreams","type":"module"},{"doc":"Returns information about a stream, including the current status of the stream,\nits Amazon Resource Name (ARN), the composition of its shards, and its\ncorresponding DynamoDB table.\n\nYou can call `DescribeStream` at a maximum rate of 10 times per second.\n\nEach shard in the stream has a `SequenceNumberRange` associated with it. If the\n`SequenceNumberRange` has a `StartingSequenceNumber` but no\n`EndingSequenceNumber`, then the shard is still open (able to receive more\nstream records). If both `StartingSequenceNumber` and `EndingSequenceNumber` are\npresent, then that shard is closed and can no longer receive more data.","ref":"AWS.DynamoDBStreams.html#describe_stream/3","title":"AWS.DynamoDBStreams.describe_stream/3","type":"function"},{"doc":"Retrieves the stream records from a given shard.\n\nSpecify a shard iterator using the `ShardIterator` parameter. The shard iterator\nspecifies the position in the shard from which you want to start reading stream\nrecords sequentially. If there are no stream records available in the portion of\nthe shard that the iterator points to, `GetRecords` returns an empty list. Note\nthat it might take multiple calls to get to a portion of the shard that contains\nstream records.\n\n`GetRecords` can retrieve a maximum of 1 MB of data or 1000 stream records,\nwhichever comes first.","ref":"AWS.DynamoDBStreams.html#get_records/3","title":"AWS.DynamoDBStreams.get_records/3","type":"function"},{"doc":"Returns a shard iterator.\n\nA shard iterator provides information about how to retrieve the stream records\nfrom within a shard. Use the shard iterator in a subsequent `GetRecords` request\nto read the stream records from the shard.\n\nA shard iterator expires 15 minutes after it is returned to the requester.","ref":"AWS.DynamoDBStreams.html#get_shard_iterator/3","title":"AWS.DynamoDBStreams.get_shard_iterator/3","type":"function"},{"doc":"Returns an array of stream ARNs associated with the current account and\nendpoint.\n\nIf the `TableName` parameter is present, then `ListStreams` will return only the\nstreams ARNs for that table.\n\nYou can call `ListStreams` at a maximum rate of 5 times per second.","ref":"AWS.DynamoDBStreams.html#list_streams/3","title":"AWS.DynamoDBStreams.list_streams/3","type":"function"},{"doc":"","ref":"AWS.DynamoDBStreams.html#metadata/0","title":"AWS.DynamoDBStreams.metadata/0","type":"function"},{"doc":"You can use the Amazon Elastic Block Store (Amazon EBS) direct APIs to create\nAmazon EBS snapshots, write data directly to your snapshots, read data on your\nsnapshots, and identify the differences or changes between two snapshots.\n\nIf you’re an independent software vendor (ISV) who offers backup services for\nAmazon EBS, the EBS direct APIs make it more efficient and cost-effective to\ntrack incremental changes on your Amazon EBS volumes through snapshots. This can\nbe done without having to create new volumes from snapshots, and then use Amazon\nElastic Compute Cloud (Amazon EC2) instances to compare the differences.\n\nYou can create incremental snapshots directly from data on-premises into volumes\nand the cloud to use for quick disaster recovery. With the ability to write and\nread snapshots, you can write your on-premises data to an snapshot during a\ndisaster. Then after recovery, you can restore it back to Amazon Web Services or\non-premises from the snapshot. You no longer need to build and maintain complex\nmechanisms to copy data to and from Amazon EBS.\n\nThis API reference provides detailed information about the actions, data types,\nparameters, and errors of the EBS direct APIs. For more information about the\nelements that make up the EBS direct APIs, and examples of how to use them\neffectively, see [Accessing the Contents of an Amazon EBS Snapshot](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ebs-accessing-snapshot.html)\nin the *Amazon Elastic Compute Cloud User Guide*. For more information about the\nsupported Amazon Web Services Regions, endpoints, and service quotas for the EBS\ndirect APIs, see [Amazon Elastic Block Store Endpoints and Quotas](https://docs.aws.amazon.com/general/latest/gr/ebs-service.html) in the\n*Amazon Web Services General Reference*.","ref":"AWS.EBS.html","title":"AWS.EBS","type":"module"},{"doc":"Seals and completes the snapshot after all of the required blocks of data have\nbeen written to it.\n\nCompleting the snapshot changes the status to `completed`. You cannot write new\nblocks to a snapshot after it has been completed.\n\nYou should always retry requests that receive server (`5xx`) error responses,\nand `ThrottlingException` and `RequestThrottledException` client error\nresponses. For more information see [Error retries](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/error-retries.html)\nin the *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.EBS.html#complete_snapshot/4","title":"AWS.EBS.complete_snapshot/4","type":"function"},{"doc":"Returns the data in a block in an Amazon Elastic Block Store snapshot.\n\nYou should always retry requests that receive server (`5xx`) error responses,\nand `ThrottlingException` and `RequestThrottledException` client error\nresponses. For more information see [Error retries](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/error-retries.html)\nin the *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.EBS.html#get_snapshot_block/5","title":"AWS.EBS.get_snapshot_block/5","type":"function"},{"doc":"Returns information about the blocks that are different between two Amazon\nElastic Block Store snapshots of the same volume/snapshot lineage.\n\nYou should always retry requests that receive server (`5xx`) error responses,\nand `ThrottlingException` and `RequestThrottledException` client error\nresponses. For more information see [Error retries](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/error-retries.html)\nin the *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.EBS.html#list_changed_blocks/7","title":"AWS.EBS.list_changed_blocks/7","type":"function"},{"doc":"Returns information about the blocks in an Amazon Elastic Block Store snapshot.\n\nYou should always retry requests that receive server (`5xx`) error responses,\nand `ThrottlingException` and `RequestThrottledException` client error\nresponses. For more information see [Error retries](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/error-retries.html)\nin the *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.EBS.html#list_snapshot_blocks/6","title":"AWS.EBS.list_snapshot_blocks/6","type":"function"},{"doc":"","ref":"AWS.EBS.html#metadata/0","title":"AWS.EBS.metadata/0","type":"function"},{"doc":"Writes a block of data to a snapshot.\n\nIf the specified block contains data, the existing data is overwritten. The\ntarget snapshot must be in the `pending` state.\n\nData written to a snapshot must be aligned with 512-KiB sectors.\n\nYou should always retry requests that receive server (`5xx`) error responses,\nand `ThrottlingException` and `RequestThrottledException` client error\nresponses. For more information see [Error retries](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/error-retries.html)\nin the *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.EBS.html#put_snapshot_block/5","title":"AWS.EBS.put_snapshot_block/5","type":"function"},{"doc":"Creates a new Amazon EBS snapshot.\n\nThe new snapshot enters the `pending` state after the request completes.\n\nAfter creating the snapshot, use [\nPutSnapshotBlock](https://docs.aws.amazon.com/ebs/latest/APIReference/API_PutSnapshotBlock.html)\nto write blocks of data to the snapshot.\n\nYou should always retry requests that receive server (`5xx`) error responses,\nand `ThrottlingException` and `RequestThrottledException` client error\nresponses. For more information see [Error retries](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/error-retries.html)\nin the *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.EBS.html#start_snapshot/3","title":"AWS.EBS.start_snapshot/3","type":"function"},{"doc":"Amazon Elastic Compute Cloud\n\nAmazon Elastic Compute Cloud (Amazon EC2) provides secure and resizable\ncomputing capacity in the Amazon Web Services Cloud.\n\nUsing Amazon EC2 eliminates the need to invest in hardware up front, so you can\ndevelop and deploy applications faster. Amazon Virtual Private Cloud (Amazon\nVPC) enables you to provision a logically isolated section of the Amazon Web\nServices Cloud where you can launch Amazon Web Services resources in a virtual\nnetwork that you've defined. Amazon Elastic Block Store (Amazon EBS) provides\nblock level storage volumes for use with EC2 instances. EBS volumes are highly\navailable and reliable storage volumes that can be attached to any running\ninstance and used like a hard drive.\n\nTo learn more, see the following resources:\n\n  * Amazon EC2: [Amazon EC2 product page](http://aws.amazon.com/ec2), [Amazon EC2 documentation](https://docs.aws.amazon.com/ec2/index.html)\n\n  * Amazon EBS: [Amazon EBS product page](http://aws.amazon.com/ebs), [Amazon EBS documentation](https://docs.aws.amazon.com/ebs/index.html)\n\n  * Amazon VPC: [Amazon VPC product page](http://aws.amazon.com/vpc), [Amazon VPC documentation](https://docs.aws.amazon.com/vpc/index.html)\n\n  * VPN: [VPN product page](http://aws.amazon.com/vpn), [VPN documentation](https://docs.aws.amazon.com/vpn/index.html)","ref":"AWS.EC2.html","title":"AWS.EC2","type":"module"},{"doc":"Accepts an Elastic IP address transfer.\n\nFor more information, see [Accept a transferred Elastic IP address](https://docs.aws.amazon.com/vpc/latest/userguide/vpc-eips.html#using-instance-addressing-eips-transfer-accept)\nin the *Amazon Virtual Private Cloud User Guide*.","ref":"AWS.EC2.html#accept_address_transfer/3","title":"AWS.EC2.accept_address_transfer/3","type":"function"},{"doc":"Accepts the Convertible Reserved Instance exchange quote described in the\n`GetReservedInstancesExchangeQuote` call.","ref":"AWS.EC2.html#accept_reserved_instances_exchange_quote/3","title":"AWS.EC2.accept_reserved_instances_exchange_quote/3","type":"function"},{"doc":"Accepts a request to associate subnets with a transit gateway multicast domain.","ref":"AWS.EC2.html#accept_transit_gateway_multicast_domain_associations/3","title":"AWS.EC2.accept_transit_gateway_multicast_domain_associations/3","type":"function"},{"doc":"Accepts a transit gateway peering attachment request.\n\nThe peering attachment must be in the `pendingAcceptance` state.","ref":"AWS.EC2.html#accept_transit_gateway_peering_attachment/3","title":"AWS.EC2.accept_transit_gateway_peering_attachment/3","type":"function"},{"doc":"Accepts a request to attach a VPC to a transit gateway.\n\nThe VPC attachment must be in the `pendingAcceptance` state. Use\n`DescribeTransitGatewayVpcAttachments` to view your pending VPC attachment\nrequests. Use `RejectTransitGatewayVpcAttachment` to reject a VPC attachment\nrequest.","ref":"AWS.EC2.html#accept_transit_gateway_vpc_attachment/3","title":"AWS.EC2.accept_transit_gateway_vpc_attachment/3","type":"function"},{"doc":"Accepts connection requests to your VPC endpoint service.","ref":"AWS.EC2.html#accept_vpc_endpoint_connections/3","title":"AWS.EC2.accept_vpc_endpoint_connections/3","type":"function"},{"doc":"Accept a VPC peering connection request.\n\nTo accept a request, the VPC peering connection must be in the\n`pending-acceptance` state, and you must be the owner of the peer VPC. Use\n`DescribeVpcPeeringConnections` to view your outstanding VPC peering connection\nrequests.\n\nFor an inter-Region VPC peering connection request, you must accept the VPC\npeering connection in the Region of the accepter VPC.","ref":"AWS.EC2.html#accept_vpc_peering_connection/3","title":"AWS.EC2.accept_vpc_peering_connection/3","type":"function"},{"doc":"Advertises an IPv4 or IPv6 address range that is provisioned for use with your\nAmazon Web Services resources through bring your own IP addresses (BYOIP).\n\nYou can perform this operation at most once every 10 seconds, even if you\nspecify different address ranges each time.\n\nWe recommend that you stop advertising the BYOIP CIDR from other locations when\nyou advertise it from Amazon Web Services. To minimize down time, you can\nconfigure your Amazon Web Services resources to use an address from a BYOIP CIDR\nbefore it is advertised, and then simultaneously stop advertising it from the\ncurrent location and start advertising it through Amazon Web Services.\n\nIt can take a few minutes before traffic to the specified addresses starts\nrouting to Amazon Web Services because of BGP propagation delays.\n\nTo stop advertising the BYOIP CIDR, use `WithdrawByoipCidr`.","ref":"AWS.EC2.html#advertise_byoip_cidr/3","title":"AWS.EC2.advertise_byoip_cidr/3","type":"function"},{"doc":"Allocates an Elastic IP address to your Amazon Web Services account.\n\nAfter you allocate the Elastic IP address you can associate it with an instance\nor network interface. After you release an Elastic IP address, it is released to\nthe IP address pool and can be allocated to a different Amazon Web Services\naccount.\n\nYou can allocate an Elastic IP address from an address pool owned by Amazon Web\nServices or from an address pool created from a public IPv4 address range that\nyou have brought to Amazon Web Services for use with your Amazon Web Services\nresources using bring your own IP addresses (BYOIP). For more information, see\n[Bring Your Own IP Addresses (BYOIP)](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-byoip.html) in\nthe *Amazon Elastic Compute Cloud User Guide*.\n\nIf you release an Elastic IP address, you might be able to recover it. You\ncannot recover an Elastic IP address that you released after it is allocated to\nanother Amazon Web Services account. To attempt to recover an Elastic IP address\nthat you released, specify it in this operation.\n\nFor more information, see [Elastic IP Addresses](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/elastic-ip-addresses-eip.html)\nin the *Amazon Elastic Compute Cloud User Guide*.\n\nYou can allocate a carrier IP address which is a public IP address from a\ntelecommunication carrier, to a network interface which resides in a subnet in a\nWavelength Zone (for example an EC2 instance).","ref":"AWS.EC2.html#allocate_address/3","title":"AWS.EC2.allocate_address/3","type":"function"},{"doc":"Allocates a Dedicated Host to your account.\n\nAt a minimum, specify the supported instance type or instance family, the\nAvailability Zone in which to allocate the host, and the number of hosts to\nallocate.","ref":"AWS.EC2.html#allocate_hosts/3","title":"AWS.EC2.allocate_hosts/3","type":"function"},{"doc":"Allocate a CIDR from an IPAM pool.\n\nThe Region you use should be the IPAM pool locale. The locale is the Amazon Web\nServices Region where this IPAM pool is available for allocations.\n\nIn IPAM, an allocation is a CIDR assignment from an IPAM pool to another IPAM\npool or to a resource. For more information, see [Allocate CIDRs](https://docs.aws.amazon.com/vpc/latest/ipam/allocate-cidrs-ipam.html) in\nthe *Amazon VPC IPAM User Guide*.\n\nThis action creates an allocation with strong consistency. The returned CIDR\nwill not overlap with any other allocations from the same pool.","ref":"AWS.EC2.html#allocate_ipam_pool_cidr/3","title":"AWS.EC2.allocate_ipam_pool_cidr/3","type":"function"},{"doc":"Applies a security group to the association between the target network and the\nClient VPN endpoint.\n\nThis action replaces the existing security groups with the specified security\ngroups.","ref":"AWS.EC2.html#apply_security_groups_to_client_vpn_target_network/3","title":"AWS.EC2.apply_security_groups_to_client_vpn_target_network/3","type":"function"},{"doc":"Assigns one or more IPv6 addresses to the specified network interface.\n\nYou can specify one or more specific IPv6 addresses, or you can specify the\nnumber of IPv6 addresses to be automatically assigned from within the subnet's\nIPv6 CIDR block range. You can assign as many IPv6 addresses to a network\ninterface as you can assign private IPv4 addresses, and the limit varies per\ninstance type. For information, see [IP Addresses Per Network Interface Per Instance\nType](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/using-eni.html#AvailableIpPerENI)\nin the *Amazon Elastic Compute Cloud User Guide*.\n\nYou must specify either the IPv6 addresses or the IPv6 address count in the\nrequest.\n\nYou can optionally use Prefix Delegation on the network interface. You must\nspecify either the IPV6 Prefix Delegation prefixes, or the IPv6 Prefix\nDelegation count. For information, see [ Assigning prefixes to Amazon EC2 network\ninterfaces](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-prefix-eni.html)\nin the *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.EC2.html#assign_ipv6_addresses/3","title":"AWS.EC2.assign_ipv6_addresses/3","type":"function"},{"doc":"Assigns one or more secondary private IP addresses to the specified network\ninterface.\n\nYou can specify one or more specific secondary IP addresses, or you can specify\nthe number of secondary IP addresses to be automatically assigned within the\nsubnet's CIDR block range. The number of secondary IP addresses that you can\nassign to an instance varies by instance type. For information about instance\ntypes, see [Instance Types](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html)\nin the *Amazon Elastic Compute Cloud User Guide*. For more information about\nElastic IP addresses, see [Elastic IP Addresses](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/elastic-ip-addresses-eip.html)\nin the *Amazon Elastic Compute Cloud User Guide*.\n\nWhen you move a secondary private IP address to another network interface, any\nElastic IP address that is associated with the IP address is also moved.\n\nRemapping an IP address is an asynchronous operation. When you move an IP\naddress from one network interface to another, check\n`network/interfaces/macs/mac/local-ipv4s` in the instance metadata to confirm\nthat the remapping is complete.\n\nYou must specify either the IP addresses or the IP address count in the request.\n\nYou can optionally use Prefix Delegation on the network interface. You must\nspecify either the IPv4 Prefix Delegation prefixes, or the IPv4 Prefix\nDelegation count. For information, see [ Assigning prefixes to Amazon EC2 network\ninterfaces](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-prefix-eni.html)\nin the *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.EC2.html#assign_private_ip_addresses/3","title":"AWS.EC2.assign_private_ip_addresses/3","type":"function"},{"doc":"Assigns one or more private IPv4 addresses to a private NAT gateway.\n\nFor more information, see [Work with NAT gateways](https://docs.aws.amazon.com/vpc/latest/userguide/vpc-nat-gateway.html#nat-gateway-working-with)\nin the *Amazon VPC User Guide*.","ref":"AWS.EC2.html#assign_private_nat_gateway_address/3","title":"AWS.EC2.assign_private_nat_gateway_address/3","type":"function"},{"doc":"Associates an Elastic IP address, or carrier IP address (for instances that are\nin subnets in Wavelength Zones) with an instance or a network interface.\n\nBefore you can use an Elastic IP address, you must allocate it to your account.\n\nIf the Elastic IP address is already associated with a different instance, it is\ndisassociated from that instance and associated with the specified instance. If\nyou associate an Elastic IP address with an instance that has an existing\nElastic IP address, the existing address is disassociated from the instance, but\nremains allocated to your account.\n\n[Subnets in Wavelength Zones] You can associate an IP address from the telecommunication carrier to the instance or network interface.\n\nYou cannot associate an Elastic IP address with an interface in a different\nnetwork border group.\n\nThis is an idempotent operation. If you perform the operation more than once,\nAmazon EC2 doesn't return an error, and you may be charged for each time the\nElastic IP address is remapped to the same instance. For more information, see\nthe *Elastic IP Addresses* section of [Amazon EC2\nPricing](http://aws.amazon.com/ec2/pricing/).","ref":"AWS.EC2.html#associate_address/3","title":"AWS.EC2.associate_address/3","type":"function"},{"doc":"Associates a target network with a Client VPN endpoint.\n\nA target network is a subnet in a VPC. You can associate multiple subnets from\nthe same VPC with a Client VPN endpoint. You can associate only one subnet in\neach Availability Zone. We recommend that you associate at least two subnets to\nprovide Availability Zone redundancy.\n\nIf you specified a VPC when you created the Client VPN endpoint or if you have\nprevious subnet associations, the specified subnet must be in the same VPC. To\nspecify a subnet that's in a different VPC, you must first modify the Client VPN\nendpoint (`ModifyClientVpnEndpoint`) and change the VPC that's associated with\nit.","ref":"AWS.EC2.html#associate_client_vpn_target_network/3","title":"AWS.EC2.associate_client_vpn_target_network/3","type":"function"},{"doc":"Associates a set of DHCP options (that you've previously created) with the\nspecified VPC, or associates no DHCP options with the VPC.\n\nAfter you associate the options with the VPC, any existing instances and all new\ninstances that you launch in that VPC use the options. You don't need to restart\nor relaunch the instances. They automatically pick up the changes within a few\nhours, depending on how frequently the instance renews its DHCP lease. You can\nexplicitly renew the lease using the operating system on the instance.\n\nFor more information, see [DHCP options sets](https://docs.aws.amazon.com/vpc/latest/userguide/VPC_DHCP_Options.html) in\nthe *Amazon VPC User Guide*.","ref":"AWS.EC2.html#associate_dhcp_options/3","title":"AWS.EC2.associate_dhcp_options/3","type":"function"},{"doc":"Associates an Identity and Access Management (IAM) role with an Certificate\nManager (ACM) certificate.\n\nThis enables the certificate to be used by the ACM for Nitro Enclaves\napplication inside an enclave. For more information, see [Certificate Manager for Nitro\nEnclaves](https://docs.aws.amazon.com/enclaves/latest/user/nitro-enclave-refapp.html)\nin the *Amazon Web Services Nitro Enclaves User Guide*.\n\nWhen the IAM role is associated with the ACM certificate, the certificate,\ncertificate chain, and encrypted private key are placed in an Amazon S3 location\nthat only the associated IAM role can access. The private key of the certificate\nis encrypted with an Amazon Web Services managed key that has an attached\nattestation-based key policy.\n\nTo enable the IAM role to access the Amazon S3 object, you must grant it\npermission to call `s3:GetObject` on the Amazon S3 bucket returned by the\ncommand. To enable the IAM role to access the KMS key, you must grant it\npermission to call `kms:Decrypt` on the KMS key returned by the command. For\nmore information, see [ Grant the role permission to access the certificate and encryption\nkey](https://docs.aws.amazon.com/enclaves/latest/user/nitro-enclave-refapp.html#add-policy)\nin the *Amazon Web Services Nitro Enclaves User Guide*.","ref":"AWS.EC2.html#associate_enclave_certificate_iam_role/3","title":"AWS.EC2.associate_enclave_certificate_iam_role/3","type":"function"},{"doc":"Associates an IAM instance profile with a running or stopped instance.\n\nYou cannot associate more than one IAM instance profile with an instance.","ref":"AWS.EC2.html#associate_iam_instance_profile/3","title":"AWS.EC2.associate_iam_instance_profile/3","type":"function"},{"doc":"Associates one or more targets with an event window.\n\nOnly one type of target (instance IDs, Dedicated Host IDs, or tags) can be\nspecified with an event window.\n\nFor more information, see [Define event windows for scheduled events](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/event-windows.html)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#associate_instance_event_window/3","title":"AWS.EC2.associate_instance_event_window/3","type":"function"},{"doc":"Associates your Autonomous System Number (ASN) with a BYOIP CIDR that you own in\nthe same Amazon Web Services Region.\n\nFor more information, see [Tutorial: Bring your ASN to IPAM](https://docs.aws.amazon.com/vpc/latest/ipam/tutorials-byoasn.html) in the\n*Amazon VPC IPAM guide*.\n\nAfter the association succeeds, the ASN is eligible for advertisement. You can\nview the association with\n[DescribeByoipCidrs](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeByoipCidrs.html). You can advertise the CIDR with\n[AdvertiseByoipCidr](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AdvertiseByoipCidr.html).","ref":"AWS.EC2.html#associate_ipam_byoasn/3","title":"AWS.EC2.associate_ipam_byoasn/3","type":"function"},{"doc":"Associates an IPAM resource discovery with an Amazon VPC IPAM.\n\nA resource discovery is an IPAM component that enables IPAM to manage and\nmonitor resources that belong to the owning account.","ref":"AWS.EC2.html#associate_ipam_resource_discovery/3","title":"AWS.EC2.associate_ipam_resource_discovery/3","type":"function"},{"doc":"Associates Elastic IP addresses (EIPs) and private IPv4 addresses with a public\nNAT gateway.\n\nFor more information, see [Work with NAT gateways](https://docs.aws.amazon.com/vpc/latest/userguide/vpc-nat-gateway.html#nat-gateway-working-with)\nin the *Amazon VPC User Guide*.\n\nBy default, you can associate up to 2 Elastic IP addresses per public NAT\ngateway. You can increase the limit by requesting a quota adjustment. For more\ninformation, see [Elastic IP address quotas](https://docs.aws.amazon.com/vpc/latest/userguide/amazon-vpc-limits.html#vpc-limits-eips)\nin the *Amazon VPC User Guide*.\n\nWhen you associate an EIP or secondary EIPs with a public NAT gateway, the\nnetwork border group of the EIPs must match the network border group of the\nAvailability Zone (AZ) that the public NAT gateway is in. If it's not the same,\nthe EIP will fail to associate. You can see the network border group for the\nsubnet's AZ by viewing the details of the subnet. Similarly, you can view the\nnetwork border group of an EIP by viewing the details of the EIP address. For\nmore information about network border groups and EIPs, see [Allocate an Elastic IP\naddress](https://docs.aws.amazon.com/vpc/latest/userguide/vpc-eips.html#allocate-eip)\nin the *Amazon VPC User Guide*.","ref":"AWS.EC2.html#associate_nat_gateway_address/3","title":"AWS.EC2.associate_nat_gateway_address/3","type":"function"},{"doc":"Associates a subnet in your VPC or an internet gateway or virtual private\ngateway attached to your VPC with a route table in your VPC.\n\nThis association causes traffic from the subnet or gateway to be routed\naccording to the routes in the route table. The action returns an association\nID, which you need in order to disassociate the route table later. A route table\ncan be associated with multiple subnets.\n\nFor more information, see [Route tables](https://docs.aws.amazon.com/vpc/latest/userguide/VPC_Route_Tables.html)\nin the *Amazon VPC User Guide*.","ref":"AWS.EC2.html#associate_route_table/3","title":"AWS.EC2.associate_route_table/3","type":"function"},{"doc":"Associates a CIDR block with your subnet.\n\nYou can only associate a single IPv6 CIDR block with your subnet.","ref":"AWS.EC2.html#associate_subnet_cidr_block/3","title":"AWS.EC2.associate_subnet_cidr_block/3","type":"function"},{"doc":"Associates the specified subnets and transit gateway attachments with the\nspecified transit gateway multicast domain.\n\nThe transit gateway attachment must be in the available state before you can add\na resource. Use\n[DescribeTransitGatewayAttachments](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeTransitGatewayAttachments.html)\nto see the state of the attachment.","ref":"AWS.EC2.html#associate_transit_gateway_multicast_domain/3","title":"AWS.EC2.associate_transit_gateway_multicast_domain/3","type":"function"},{"doc":"Associates the specified transit gateway attachment with a transit gateway\npolicy table.","ref":"AWS.EC2.html#associate_transit_gateway_policy_table/3","title":"AWS.EC2.associate_transit_gateway_policy_table/3","type":"function"},{"doc":"Associates the specified attachment with the specified transit gateway route\ntable.\n\nYou can associate only one route table with an attachment.","ref":"AWS.EC2.html#associate_transit_gateway_route_table/3","title":"AWS.EC2.associate_transit_gateway_route_table/3","type":"function"},{"doc":"Associates a branch network interface with a trunk network interface.\n\nBefore you create the association, run the\n[create-network-interface](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateNetworkInterface.html)\ncommand and set `--interface-type` to `trunk`. You must also create a network\ninterface for each branch network interface that you want to associate with the\ntrunk network interface.","ref":"AWS.EC2.html#associate_trunk_interface/3","title":"AWS.EC2.associate_trunk_interface/3","type":"function"},{"doc":"Associates a CIDR block with your VPC.\n\nYou can associate a secondary IPv4 CIDR block, an Amazon-provided IPv6 CIDR\nblock, or an IPv6 CIDR block from an IPv6 address pool that you provisioned\nthrough bring your own IP addresses\n([BYOIP](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-byoip.html)).  You must specify one of the following in the request: an IPv4 CIDR block, an\nIPv6 pool, or an Amazon-provided IPv6 CIDR block.\n\nFor more information about associating CIDR blocks with your VPC and applicable\nrestrictions, see [IP addressing for your VPCs and\nsubnets](https://docs.aws.amazon.com/vpc/latest/userguide/vpc-ip-addressing.html)\nin the *Amazon VPC User Guide*.","ref":"AWS.EC2.html#associate_vpc_cidr_block/3","title":"AWS.EC2.associate_vpc_cidr_block/3","type":"function"},{"doc":"This action is deprecated.\n\nLinks an EC2-Classic instance to a ClassicLink-enabled VPC through one or more\nof the VPC security groups. You cannot link an EC2-Classic instance to more than\none VPC at a time. You can only link an instance that's in the `running` state.\nAn instance is automatically unlinked from a VPC when it's stopped - you can\nlink it to the VPC again when you restart it.\n\nAfter you've linked an instance, you cannot change the VPC security groups that\nare associated with it. To change the security groups, you must first unlink the\ninstance, and then link it again.\n\nLinking your instance to a VPC is sometimes referred to as *attaching* your\ninstance.","ref":"AWS.EC2.html#attach_classic_link_vpc/3","title":"AWS.EC2.attach_classic_link_vpc/3","type":"function"},{"doc":"Attaches an internet gateway or a virtual private gateway to a VPC, enabling\nconnectivity between the internet and the VPC.\n\nFor more information, see [Internet gateways](https://docs.aws.amazon.com/vpc/latest/userguide/VPC_Internet_Gateway.html)\nin the *Amazon VPC User Guide*.","ref":"AWS.EC2.html#attach_internet_gateway/3","title":"AWS.EC2.attach_internet_gateway/3","type":"function"},{"doc":"Attaches a network interface to an instance.","ref":"AWS.EC2.html#attach_network_interface/3","title":"AWS.EC2.attach_network_interface/3","type":"function"},{"doc":"Attaches the specified Amazon Web Services Verified Access trust provider to the\nspecified Amazon Web Services Verified Access instance.","ref":"AWS.EC2.html#attach_verified_access_trust_provider/3","title":"AWS.EC2.attach_verified_access_trust_provider/3","type":"function"},{"doc":"Attaches an EBS volume to a running or stopped instance and exposes it to the\ninstance with the specified device name.\n\nEncrypted EBS volumes must be attached to instances that support Amazon EBS\nencryption. For more information, see [Amazon EBS encryption](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSEncryption.html)\nin the *Amazon Elastic Compute Cloud User Guide*.\n\nAfter you attach an EBS volume, you must make it available. For more\ninformation, see [Make an EBS volume available for use](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ebs-using-volumes.html).\n\nIf a volume has an Amazon Web Services Marketplace product code:\n\n  * The volume can be attached only to a stopped instance.\n\n  * Amazon Web Services Marketplace product codes are copied from the\nvolume to the instance.\n\n  * You must be subscribed to the product.\n\n  * The instance type and operating system of the instance must\nsupport the product. For example, you can't detach a volume from a Windows\ninstance and attach it to a Linux instance.\n\nFor more information, see [Attach an Amazon EBS volume to an instance](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ebs-attaching-volume.html)\nin the *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.EC2.html#attach_volume/3","title":"AWS.EC2.attach_volume/3","type":"function"},{"doc":"Attaches a virtual private gateway to a VPC.\n\nYou can attach one virtual private gateway to one VPC at a time.\n\nFor more information, see [Amazon Web Services Site-to-Site VPN](https://docs.aws.amazon.com/vpn/latest/s2svpn/VPC_VPN.html) in the *Amazon\nWeb Services Site-to-Site VPN User Guide*.","ref":"AWS.EC2.html#attach_vpn_gateway/3","title":"AWS.EC2.attach_vpn_gateway/3","type":"function"},{"doc":"Adds an ingress authorization rule to a Client VPN endpoint.\n\nIngress authorization rules act as firewall rules that grant access to networks.\nYou must configure ingress authorization rules to enable clients to access\nresources in Amazon Web Services or on-premises networks.","ref":"AWS.EC2.html#authorize_client_vpn_ingress/3","title":"AWS.EC2.authorize_client_vpn_ingress/3","type":"function"},{"doc":"Adds the specified outbound (egress) rules to a security group for use with a\nVPC.\n\nAn outbound rule permits instances to send traffic to the specified IPv4 or IPv6\nCIDR address ranges, or to the instances that are associated with the specified\nsource security groups. When specifying an outbound rule for your security group\nin a VPC, the `IpPermissions` must include a destination for the traffic.\n\nYou specify a protocol for each rule (for example, TCP). For the TCP and UDP\nprotocols, you must also specify the destination port or port range. For the\nICMP protocol, you must also specify the ICMP type and code. You can use -1 for\nthe type or code to mean all types or all codes.\n\nRule changes are propagated to affected instances as quickly as possible.\nHowever, a small delay might occur.\n\nFor information about VPC security group quotas, see [Amazon VPC quotas](https://docs.aws.amazon.com/vpc/latest/userguide/amazon-vpc-limits.html).\n\nIf you want to reference a security group across VPCs attached to a transit\ngateway using the [security group referencing feature](https://docs.aws.amazon.com/vpc/latest/tgw/tgw-transit-gateways.html#create-tgw),\nnote that you can only reference security groups for ingress rules. You cannot\nreference a security group for egress rules.","ref":"AWS.EC2.html#authorize_security_group_egress/3","title":"AWS.EC2.authorize_security_group_egress/3","type":"function"},{"doc":"Adds the specified inbound (ingress) rules to a security group.\n\nAn inbound rule permits instances to receive traffic from the specified IPv4 or\nIPv6 CIDR address range, or from the instances that are associated with the\nspecified destination security groups. When specifying an inbound rule for your\nsecurity group in a VPC, the `IpPermissions` must include a source for the\ntraffic.\n\nYou specify a protocol for each rule (for example, TCP). For TCP and UDP, you\nmust also specify the destination port or port range. For ICMP/ICMPv6, you must\nalso specify the ICMP/ICMPv6 type and code. You can use -1 to mean all types or\nall codes.\n\nRule changes are propagated to instances within the security group as quickly as\npossible. However, a small delay might occur.\n\nFor more information about VPC security group quotas, see [Amazon VPC quotas](https://docs.aws.amazon.com/vpc/latest/userguide/amazon-vpc-limits.html).","ref":"AWS.EC2.html#authorize_security_group_ingress/3","title":"AWS.EC2.authorize_security_group_ingress/3","type":"function"},{"doc":"Bundles an Amazon instance store-backed Windows instance.\n\nDuring bundling, only the root device volume (C:) is bundled. Data on other\ninstance store volumes is not preserved.\n\nThis action is not applicable for Linux/Unix instances or Windows instances that\nare backed by Amazon EBS.","ref":"AWS.EC2.html#bundle_instance/3","title":"AWS.EC2.bundle_instance/3","type":"function"},{"doc":"Cancels a bundling operation for an instance store-backed Windows instance.","ref":"AWS.EC2.html#cancel_bundle_task/3","title":"AWS.EC2.cancel_bundle_task/3","type":"function"},{"doc":"Cancels the specified Capacity Reservation, releases the reserved capacity, and\nchanges the Capacity Reservation's state to `cancelled`.\n\nInstances running in the reserved capacity continue running until you stop them.\nStopped instances that target the Capacity Reservation can no longer launch.\nModify these instances to either target a different Capacity Reservation, launch\nOn-Demand Instance capacity, or run in any open Capacity Reservation that has\nmatching attributes and sufficient capacity.","ref":"AWS.EC2.html#cancel_capacity_reservation/3","title":"AWS.EC2.cancel_capacity_reservation/3","type":"function"},{"doc":"Cancels one or more Capacity Reservation Fleets.\n\nWhen you cancel a Capacity Reservation Fleet, the following happens:\n\n  * The Capacity Reservation Fleet's status changes to `cancelled`.\n\n  * The individual Capacity Reservations in the Fleet are cancelled.\nInstances running in the Capacity Reservations at the time of cancelling the\nFleet continue to run in shared capacity.\n\n  * The Fleet stops creating new Capacity Reservations.","ref":"AWS.EC2.html#cancel_capacity_reservation_fleets/3","title":"AWS.EC2.cancel_capacity_reservation_fleets/3","type":"function"},{"doc":"Cancels an active conversion task.\n\nThe task can be the import of an instance or volume. The action removes all\nartifacts of the conversion, including a partially uploaded volume or instance.\nIf the conversion is complete or is in the process of transferring the final\ndisk image, the command fails and returns an exception.\n\nFor more information, see [Importing a Virtual Machine Using the Amazon EC2 CLI](https://docs.aws.amazon.com/AWSEC2/latest/CommandLineReference/ec2-cli-vmimport-export.html).","ref":"AWS.EC2.html#cancel_conversion_task/3","title":"AWS.EC2.cancel_conversion_task/3","type":"function"},{"doc":"Cancels an active export task.\n\nThe request removes all artifacts of the export, including any partially-created\nAmazon S3 objects. If the export task is complete or is in the process of\ntransferring the final disk image, the command fails and returns an error.","ref":"AWS.EC2.html#cancel_export_task/3","title":"AWS.EC2.cancel_export_task/3","type":"function"},{"doc":"Removes your Amazon Web Services account from the launch permissions for the\nspecified AMI.\n\nFor more information, see [ Cancel having an AMI shared with your Amazon Web Services\naccount](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/cancel-sharing-an-AMI.html)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#cancel_image_launch_permission/3","title":"AWS.EC2.cancel_image_launch_permission/3","type":"function"},{"doc":"Cancels an in-process import virtual machine or import snapshot task.","ref":"AWS.EC2.html#cancel_import_task/3","title":"AWS.EC2.cancel_import_task/3","type":"function"},{"doc":"Cancels the specified Reserved Instance listing in the Reserved Instance\nMarketplace.\n\nFor more information, see [Reserved Instance Marketplace](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ri-market-general.html)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#cancel_reserved_instances_listing/3","title":"AWS.EC2.cancel_reserved_instances_listing/3","type":"function"},{"doc":"Cancels the specified Spot Fleet requests.\n\nAfter you cancel a Spot Fleet request, the Spot Fleet launches no new instances.\n\nYou must also specify whether a canceled Spot Fleet request should terminate its\ninstances. If you choose to terminate the instances, the Spot Fleet request\nenters the `cancelled_terminating` state. Otherwise, the Spot Fleet request\nenters the `cancelled_running` state and the instances continue to run until\nthey are interrupted or you terminate them manually.","ref":"AWS.EC2.html#cancel_spot_fleet_requests/3","title":"AWS.EC2.cancel_spot_fleet_requests/3","type":"function"},{"doc":"Cancels one or more Spot Instance requests.\n\nCanceling a Spot Instance request does not terminate running Spot Instances\nassociated with the request.","ref":"AWS.EC2.html#cancel_spot_instance_requests/3","title":"AWS.EC2.cancel_spot_instance_requests/3","type":"function"},{"doc":"Determines whether a product code is associated with an instance.\n\nThis action can only be used by the owner of the product code. It is useful when\na product code owner must verify whether another user's instance is eligible for\nsupport.","ref":"AWS.EC2.html#confirm_product_instance/3","title":"AWS.EC2.confirm_product_instance/3","type":"function"},{"doc":"Copies the specified Amazon FPGA Image (AFI) to the current Region.","ref":"AWS.EC2.html#copy_fpga_image/3","title":"AWS.EC2.copy_fpga_image/3","type":"function"},{"doc":"Initiates the copy of an AMI.\n\nYou can copy an AMI from one Region to another, or from a Region to an Outpost.\nYou can't copy an AMI from an Outpost to a Region, from one Outpost to another,\nor within the same Outpost. To copy an AMI to another partition, see\n[CreateStoreImageTask](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateStoreImageTask.html).  To copy an AMI from one Region to another, specify the source Region using the\n**SourceRegion** parameter, and specify the destination Region using its\nendpoint. Copies of encrypted backing snapshots for the AMI are encrypted.\nCopies of unencrypted backing snapshots remain unencrypted, unless you set\n`Encrypted` during the copy operation. You cannot create an unencrypted copy of\nan encrypted backing snapshot.\n\nTo copy an AMI from a Region to an Outpost, specify the source Region using the\n**SourceRegion** parameter, and specify the ARN of the destination Outpost using\n**DestinationOutpostArn**. Backing snapshots copied to an Outpost are encrypted\nby default using the default encryption key for the Region, or a different key\nthat you specify in the request using **KmsKeyId**. Outposts do not support\nunencrypted snapshots. For more information, [ Amazon EBS local snapshots on\nOutposts](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/snapshots-outposts.html#ami)\nin the *Amazon EC2 User Guide*.\n\nFor more information about the prerequisites and limits when copying an AMI, see\n[Copy an AMI](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/CopyingAMIs.html) in\nthe *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#copy_image/3","title":"AWS.EC2.copy_image/3","type":"function"},{"doc":"Copies a point-in-time snapshot of an EBS volume and stores it in Amazon S3.\n\nYou can copy a snapshot within the same Region, from one Region to another, or\nfrom a Region to an Outpost. You can't copy a snapshot from an Outpost to a\nRegion, from one Outpost to another, or within the same Outpost.\n\nYou can use the snapshot to create EBS volumes or Amazon Machine Images (AMIs).\n\nWhen copying snapshots to a Region, copies of encrypted EBS snapshots remain\nencrypted. Copies of unencrypted snapshots remain unencrypted, unless you enable\nencryption for the snapshot copy operation. By default, encrypted snapshot\ncopies use the default Key Management Service (KMS) KMS key; however, you can\nspecify a different KMS key. To copy an encrypted snapshot that has been shared\nfrom another account, you must have permissions for the KMS key used to encrypt\nthe snapshot.\n\nSnapshots copied to an Outpost are encrypted by default using the default\nencryption key for the Region, or a different key that you specify in the\nrequest using **KmsKeyId**. Outposts do not support unencrypted snapshots. For\nmore information, [ Amazon EBS local snapshots on Outposts](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/snapshots-outposts.html#ami)\nin the *Amazon Elastic Compute Cloud User Guide*.\n\nSnapshots created by copying another snapshot have an arbitrary volume ID that\nshould not be used for any purpose.\n\nFor more information, see [Copy an Amazon EBS snapshot](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ebs-copy-snapshot.html)\nin the *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.EC2.html#copy_snapshot/3","title":"AWS.EC2.copy_snapshot/3","type":"function"},{"doc":"Creates a new Capacity Reservation with the specified attributes.\n\nCapacity Reservations enable you to reserve capacity for your Amazon EC2\ninstances in a specific Availability Zone for any duration. This gives you the\nflexibility to selectively add capacity reservations and still get the Regional\nRI discounts for that usage. By creating Capacity Reservations, you ensure that\nyou always have access to Amazon EC2 capacity when you need it, for as long as\nyou need it. For more information, see [Capacity Reservations](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-capacity-reservations.html)\nin the *Amazon EC2 User Guide*.\n\nYour request to create a Capacity Reservation could fail if Amazon EC2 does not\nhave sufficient capacity to fulfill the request. If your request fails due to\nAmazon EC2 capacity constraints, either try again at a later time, try in a\ndifferent Availability Zone, or request a smaller capacity reservation. If your\napplication is flexible across instance types and sizes, try to create a\nCapacity Reservation with different instance attributes.\n\nYour request could also fail if the requested quantity exceeds your On-Demand\nInstance limit for the selected instance type. If your request fails due to\nlimit constraints, increase your On-Demand Instance limit for the required\ninstance type and try again. For more information about increasing your instance\nlimits, see [Amazon EC2 Service Quotas](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-resource-limits.html)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#create_capacity_reservation/3","title":"AWS.EC2.create_capacity_reservation/3","type":"function"},{"doc":"Creates a Capacity Reservation Fleet.\n\nFor more information, see [Create a Capacity Reservation Fleet](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/work-with-cr-fleets.html#create-crfleet)\nin the Amazon EC2 User Guide.","ref":"AWS.EC2.html#create_capacity_reservation_fleet/3","title":"AWS.EC2.create_capacity_reservation_fleet/3","type":"function"},{"doc":"Creates a carrier gateway.\n\nFor more information about carrier gateways, see [Carrier gateways](https://docs.aws.amazon.com/wavelength/latest/developerguide/how-wavelengths-work.html#wavelength-carrier-gateway)\nin the *Amazon Web Services Wavelength Developer Guide*.","ref":"AWS.EC2.html#create_carrier_gateway/3","title":"AWS.EC2.create_carrier_gateway/3","type":"function"},{"doc":"Creates a Client VPN endpoint.\n\nA Client VPN endpoint is the resource you create and configure to enable and\nmanage client VPN sessions. It is the destination endpoint at which all client\nVPN sessions are terminated.","ref":"AWS.EC2.html#create_client_vpn_endpoint/3","title":"AWS.EC2.create_client_vpn_endpoint/3","type":"function"},{"doc":"Adds a route to a network to a Client VPN endpoint.\n\nEach Client VPN endpoint has a route table that describes the available\ndestination network routes. Each route in the route table specifies the path for\ntraﬃc to speciﬁc resources or networks.","ref":"AWS.EC2.html#create_client_vpn_route/3","title":"AWS.EC2.create_client_vpn_route/3","type":"function"},{"doc":"Creates a range of customer-owned IP addresses.","ref":"AWS.EC2.html#create_coip_cidr/3","title":"AWS.EC2.create_coip_cidr/3","type":"function"},{"doc":"Creates a pool of customer-owned IP (CoIP) addresses.","ref":"AWS.EC2.html#create_coip_pool/3","title":"AWS.EC2.create_coip_pool/3","type":"function"},{"doc":"Provides information to Amazon Web Services about your customer gateway device.\n\nThe customer gateway device is the appliance at your end of the VPN connection.\nYou must provide the IP address of the customer gateway device’s external\ninterface. The IP address must be static and can be behind a device performing\nnetwork address translation (NAT).\n\nFor devices that use Border Gateway Protocol (BGP), you can also provide the\ndevice's BGP Autonomous System Number (ASN). You can use an existing ASN\nassigned to your network. If you don't have an ASN already, you can use a\nprivate ASN. For more information, see [Customer gateway options for your Site-to-Site VPN\nconnection](https://docs.aws.amazon.com/vpn/latest/s2svpn/cgw-options.html) in\nthe *Amazon Web Services Site-to-Site VPN User Guide*.\n\nTo create more than one customer gateway with the same VPN type, IP address, and\nBGP ASN, specify a unique device name for each customer gateway. An identical\nrequest returns information about the existing customer gateway; it doesn't\ncreate a new customer gateway.","ref":"AWS.EC2.html#create_customer_gateway/3","title":"AWS.EC2.create_customer_gateway/3","type":"function"},{"doc":"Creates a default subnet with a size `/20` IPv4 CIDR block in the specified\nAvailability Zone in your default VPC.\n\nYou can have only one default subnet per Availability Zone. For more\ninformation, see [Create a default subnet](https://docs.aws.amazon.com/vpc/latest/userguide/default-vpc.html#create-default-subnet)\nin the *Amazon VPC User Guide*.","ref":"AWS.EC2.html#create_default_subnet/3","title":"AWS.EC2.create_default_subnet/3","type":"function"},{"doc":"Creates a default VPC with a size `/16` IPv4 CIDR block and a default subnet in\neach Availability Zone.\n\nFor more information about the components of a default VPC, see [Default VPCs](https://docs.aws.amazon.com/vpc/latest/userguide/default-vpc.html) in the\n*Amazon VPC User Guide*. You cannot specify the components of the default VPC\nyourself.\n\nIf you deleted your previous default VPC, you can create a default VPC. You\ncannot have more than one default VPC per Region.","ref":"AWS.EC2.html#create_default_vpc/3","title":"AWS.EC2.create_default_vpc/3","type":"function"},{"doc":"Creates a set of DHCP options for your VPC.\n\nAfter creating the set, you must associate it with the VPC, causing all existing\nand new instances that you launch in the VPC to use this set of DHCP options.\nThe following are the individual DHCP options you can specify. For more\ninformation about the options, see [RFC 2132](http://www.ietf.org/rfc/rfc2132.txt).\n\n  * `domain-name-servers` - The IP addresses of up to four domain name\nservers, or AmazonProvidedDNS. The default DHCP option set specifies\nAmazonProvidedDNS. If specifying more than one domain name server, specify the\nIP addresses in a single parameter, separated by commas. To have your instance\nreceive a custom DNS hostname as specified in `domain-name`, you must set\n`domain-name-servers` to a custom DNS server.\n\n  * `domain-name` - If you're using AmazonProvidedDNS in `us-east-1`,\nspecify `ec2.internal`. If you're using AmazonProvidedDNS in another Region,\nspecify `region.compute.internal` (for example,\n`ap-northeast-1.compute.internal`). Otherwise, specify a domain name (for\nexample, `ExampleCompany.com`). This value is used to complete unqualified DNS\nhostnames. **Important**: Some Linux operating systems accept multiple domain\nnames separated by spaces. However, Windows and other Linux operating systems\ntreat the value as a single domain, which results in unexpected behavior. If\nyour DHCP options set is associated with a VPC that has instances with multiple\noperating systems, specify only one domain name.\n\n  * `ntp-servers` - The IP addresses of up to four Network Time\nProtocol (NTP) servers.\n\n  * `netbios-name-servers` - The IP addresses of up to four NetBIOS\nname servers.\n\n  * `netbios-node-type` - The NetBIOS node type (1, 2, 4, or 8). We\nrecommend that you specify 2 (broadcast and multicast are not currently\nsupported). For more information about these node types, see [RFC 2132](http://www.ietf.org/rfc/rfc2132.txt).\n\nYour VPC automatically starts out with a set of DHCP options that includes only\na DNS server that we provide (AmazonProvidedDNS). If you create a set of\noptions, and if your VPC has an internet gateway, make sure to set the\n`domain-name-servers` option either to `AmazonProvidedDNS` or to a domain name\nserver of your choice. For more information, see [DHCP options sets](https://docs.aws.amazon.com/vpc/latest/userguide/VPC_DHCP_Options.html) in\nthe *Amazon VPC User Guide*.","ref":"AWS.EC2.html#create_dhcp_options/3","title":"AWS.EC2.create_dhcp_options/3","type":"function"},{"doc":"[IPv6 only] Creates an egress-only internet gateway for your VPC.\n\nAn egress-only internet gateway is used to enable outbound communication over\nIPv6 from instances in your VPC to the internet, and prevents hosts outside of\nyour VPC from initiating an IPv6 connection with your instance.","ref":"AWS.EC2.html#create_egress_only_internet_gateway/3","title":"AWS.EC2.create_egress_only_internet_gateway/3","type":"function"},{"doc":"Creates an EC2 Fleet that contains the configuration information for On-Demand\nInstances and Spot Instances.\n\nInstances are launched immediately if there is available capacity.\n\nA single EC2 Fleet can include multiple launch specifications that vary by\ninstance type, AMI, Availability Zone, or subnet.\n\nFor more information, see [EC2 Fleet](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-fleet.html) in\nthe *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#create_fleet/3","title":"AWS.EC2.create_fleet/3","type":"function"},{"doc":"Creates one or more flow logs to capture information about IP traffic for a\nspecific network interface, subnet, or VPC.\n\nFlow log data for a monitored network interface is recorded as flow log records,\nwhich are log events consisting of fields that describe the traffic flow. For\nmore information, see [Flow log records](https://docs.aws.amazon.com/vpc/latest/userguide/flow-logs.html#flow-log-records)\nin the *Amazon Virtual Private Cloud User Guide*.\n\nWhen publishing to CloudWatch Logs, flow log records are published to a log\ngroup, and each network interface has a unique log stream in the log group. When\npublishing to Amazon S3, flow log records for all of the monitored network\ninterfaces are published to a single log file object that is stored in the\nspecified bucket.\n\nFor more information, see [VPC Flow Logs](https://docs.aws.amazon.com/vpc/latest/userguide/flow-logs.html) in the\n*Amazon Virtual Private Cloud User Guide*.","ref":"AWS.EC2.html#create_flow_logs/3","title":"AWS.EC2.create_flow_logs/3","type":"function"},{"doc":"Creates an Amazon FPGA Image (AFI) from the specified design checkpoint (DCP).\n\nThe create operation is asynchronous. To verify that the AFI is ready for use,\ncheck the output logs.\n\nAn AFI contains the FPGA bitstream that is ready to download to an FPGA. You can\nsecurely deploy an AFI on multiple FPGA-accelerated instances. For more\ninformation, see the [Amazon Web Services FPGA Hardware Development Kit](https://github.com/aws/aws-fpga/).","ref":"AWS.EC2.html#create_fpga_image/3","title":"AWS.EC2.create_fpga_image/3","type":"function"},{"doc":"Creates an Amazon EBS-backed AMI from an Amazon EBS-backed instance that is\neither running or stopped.\n\nIf you customized your instance with instance store volumes or Amazon EBS\nvolumes in addition to the root device volume, the new AMI contains block device\nmapping information for those volumes. When you launch an instance from this new\nAMI, the instance automatically launches with those additional volumes.\n\nFor more information, see [Create an Amazon EBS-backed Linux AMI](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/creating-an-ami-ebs.html)\nin the *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.EC2.html#create_image/3","title":"AWS.EC2.create_image/3","type":"function"},{"doc":"Creates an EC2 Instance Connect Endpoint.\n\nAn EC2 Instance Connect Endpoint allows you to connect to an instance, without\nrequiring the instance to have a public IPv4 address. For more information, see\n[Connect to your instances without requiring a public IPv4 address using EC2 Instance Connect\nEndpoint](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Connect-using-EC2-Instance-Connect-Endpoint.html)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#create_instance_connect_endpoint/3","title":"AWS.EC2.create_instance_connect_endpoint/3","type":"function"},{"doc":"Creates an event window in which scheduled events for the associated Amazon EC2\ninstances can run.\n\nYou can define either a set of time ranges or a cron expression when creating\nthe event window, but not both. All event window times are in UTC.\n\nYou can create up to 200 event windows per Amazon Web Services Region.\n\nWhen you create the event window, targets (instance IDs, Dedicated Host IDs, or\ntags) are not yet associated with it. To ensure that the event window can be\nused, you must associate one or more targets with it by using the\n`AssociateInstanceEventWindow` API.\n\nEvent windows are applicable only for scheduled events that stop, reboot, or\nterminate instances.\n\nEvent windows are *not* applicable for:\n\n   Expedited scheduled events and network maintenance events.\n\n   Unscheduled maintenance such as AutoRecovery and unplanned reboots.\n\nFor more information, see [Define event windows for scheduled events](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/event-windows.html)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#create_instance_event_window/3","title":"AWS.EC2.create_instance_event_window/3","type":"function"},{"doc":"Exports a running or stopped instance to an Amazon S3 bucket.\n\nFor information about the prerequisites for your Amazon S3 bucket, supported\noperating systems, image formats, and known limitations for the types of\ninstances you can export, see [Exporting an instance as a VM Using VM Import/Export](https://docs.aws.amazon.com/vm-import/latest/userguide/vmexport.html)\nin the *VM Import/Export User Guide*.","ref":"AWS.EC2.html#create_instance_export_task/3","title":"AWS.EC2.create_instance_export_task/3","type":"function"},{"doc":"Creates an internet gateway for use with a VPC.\n\nAfter creating the internet gateway, you attach it to a VPC using\n`AttachInternetGateway`.\n\nFor more information, see [Internet gateways](https://docs.aws.amazon.com/vpc/latest/userguide/VPC_Internet_Gateway.html)\nin the *Amazon VPC User Guide*.","ref":"AWS.EC2.html#create_internet_gateway/3","title":"AWS.EC2.create_internet_gateway/3","type":"function"},{"doc":"Create an IPAM.\n\nAmazon VPC IP Address Manager (IPAM) is a VPC feature that you can use to\nautomate your IP address management workflows including assigning, tracking,\ntroubleshooting, and auditing IP addresses across Amazon Web Services Regions\nand accounts throughout your Amazon Web Services Organization.\n\nFor more information, see [Create an IPAM](https://docs.aws.amazon.com/vpc/latest/ipam/create-ipam.html) in the\n*Amazon VPC IPAM User Guide*.","ref":"AWS.EC2.html#create_ipam/3","title":"AWS.EC2.create_ipam/3","type":"function"},{"doc":"Create an IP address pool for Amazon VPC IP Address Manager (IPAM).\n\nIn IPAM, a pool is a collection of contiguous IP addresses CIDRs. Pools enable\nyou to organize your IP addresses according to your routing and security needs.\nFor example, if you have separate routing and security needs for development and\nproduction applications, you can create a pool for each.\n\nFor more information, see [Create a top-level pool](https://docs.aws.amazon.com/vpc/latest/ipam/create-top-ipam.html) in the\n*Amazon VPC IPAM User Guide*.","ref":"AWS.EC2.html#create_ipam_pool/3","title":"AWS.EC2.create_ipam_pool/3","type":"function"},{"doc":"Creates an IPAM resource discovery.\n\nA resource discovery is an IPAM component that enables IPAM to manage and\nmonitor resources that belong to the owning account.","ref":"AWS.EC2.html#create_ipam_resource_discovery/3","title":"AWS.EC2.create_ipam_resource_discovery/3","type":"function"},{"doc":"Create an IPAM scope.\n\nIn IPAM, a scope is the highest-level container within IPAM. An IPAM contains\ntwo default scopes. Each scope represents the IP space for a single network. The\nprivate scope is intended for all private IP address space. The public scope is\nintended for all public IP address space. Scopes enable you to reuse IP\naddresses across multiple unconnected networks without causing IP address\noverlap or conflict.\n\nFor more information, see [Add a scope](https://docs.aws.amazon.com/vpc/latest/ipam/add-scope-ipam.html) in the\n*Amazon VPC IPAM User Guide*.","ref":"AWS.EC2.html#create_ipam_scope/3","title":"AWS.EC2.create_ipam_scope/3","type":"function"},{"doc":"Creates an ED25519 or 2048-bit RSA key pair with the specified name and in the\nspecified PEM or PPK format.\n\nAmazon EC2 stores the public key and displays the private key for you to save to\na file. The private key is returned as an unencrypted PEM encoded PKCS#1 private\nkey or an unencrypted PPK formatted private key for use with PuTTY. If a key\nwith the specified name already exists, Amazon EC2 returns an error.\n\nThe key pair returned to you is available only in the Amazon Web Services Region\nin which you create it. If you prefer, you can create your own key pair using a\nthird-party tool and upload it to any Region using `ImportKeyPair`.\n\nYou can have up to 5,000 key pairs per Amazon Web Services Region.\n\nFor more information, see [Amazon EC2 key pairs](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-key-pairs.html)\nin the *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.EC2.html#create_key_pair/3","title":"AWS.EC2.create_key_pair/3","type":"function"},{"doc":"Creates a launch template.\n\nA launch template contains the parameters to launch an instance. When you launch\nan instance using `RunInstances`, you can specify a launch template instead of\nproviding the launch parameters in the request. For more information, see\n[Launch an instance from a launch template](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-launch-templates.html)\nin the *Amazon Elastic Compute Cloud User Guide*.\n\nIf you want to clone an existing launch template as the basis for creating a new\nlaunch template, you can use the Amazon EC2 console. The API, SDKs, and CLI do\nnot support cloning a template. For more information, see [Create a launch template from an existing launch\ntemplate](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-launch-templates.html#create-launch-template-from-existing-launch-template)\nin the *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.EC2.html#create_launch_template/3","title":"AWS.EC2.create_launch_template/3","type":"function"},{"doc":"Creates a new version of a launch template.\n\nYou can specify an existing version of launch template from which to base the\nnew version.\n\nLaunch template versions are numbered in the order in which they are created.\nYou cannot specify, change, or replace the numbering of launch template\nversions.\n\nLaunch templates are immutable; after you create a launch template, you can't\nmodify it. Instead, you can create a new version of the launch template that\nincludes any changes you require.\n\nFor more information, see [Modify a launch template (manage launch template versions)](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-launch-templates.html#manage-launch-template-versions)\nin the *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.EC2.html#create_launch_template_version/3","title":"AWS.EC2.create_launch_template_version/3","type":"function"},{"doc":"Creates a static route for the specified local gateway route table.\n\nYou must specify one of the following targets:\n\n  * `LocalGatewayVirtualInterfaceGroupId`\n\n  * `NetworkInterfaceId`","ref":"AWS.EC2.html#create_local_gateway_route/3","title":"AWS.EC2.create_local_gateway_route/3","type":"function"},{"doc":"Creates a local gateway route table.","ref":"AWS.EC2.html#create_local_gateway_route_table/3","title":"AWS.EC2.create_local_gateway_route_table/3","type":"function"},{"doc":"Creates a local gateway route table virtual interface group association.","ref":"AWS.EC2.html#create_local_gateway_route_table_virtual_interface_group_association/3","title":"AWS.EC2.create_local_gateway_route_table_virtual_interface_group_association/3","type":"function"},{"doc":"Associates the specified VPC with the specified local gateway route table.","ref":"AWS.EC2.html#create_local_gateway_route_table_vpc_association/3","title":"AWS.EC2.create_local_gateway_route_table_vpc_association/3","type":"function"},{"doc":"Creates a managed prefix list.\n\nYou can specify one or more entries for the prefix list. Each entry consists of\na CIDR block and an optional description.","ref":"AWS.EC2.html#create_managed_prefix_list/3","title":"AWS.EC2.create_managed_prefix_list/3","type":"function"},{"doc":"Creates a NAT gateway in the specified subnet.\n\nThis action creates a network interface in the specified subnet with a private\nIP address from the IP address range of the subnet. You can create either a\npublic NAT gateway or a private NAT gateway.\n\nWith a public NAT gateway, internet-bound traffic from a private subnet can be\nrouted to the NAT gateway, so that instances in a private subnet can connect to\nthe internet.\n\nWith a private NAT gateway, private communication is routed across VPCs and\non-premises networks through a transit gateway or virtual private gateway.\nCommon use cases include running large workloads behind a small pool of\nallowlisted IPv4 addresses, preserving private IPv4 addresses, and communicating\nbetween overlapping networks.\n\nFor more information, see [NAT gateways](https://docs.aws.amazon.com/vpc/latest/userguide/vpc-nat-gateway.html)\nin the *Amazon VPC User Guide*.\n\nWhen you create a public NAT gateway and assign it an EIP or secondary EIPs, the\nnetwork border group of the EIPs must match the network border group of the\nAvailability Zone (AZ) that the public NAT gateway is in. If it's not the same,\nthe NAT gateway will fail to launch. You can see the network border group for\nthe subnet's AZ by viewing the details of the subnet. Similarly, you can view\nthe network border group of an EIP by viewing the details of the EIP address.\nFor more information about network border groups and EIPs, see [Allocate an Elastic IP\naddress](https://docs.aws.amazon.com/vpc/latest/userguide/vpc-eips.html#allocate-eip)\nin the *Amazon VPC User Guide*.","ref":"AWS.EC2.html#create_nat_gateway/3","title":"AWS.EC2.create_nat_gateway/3","type":"function"},{"doc":"Creates a network ACL in a VPC.\n\nNetwork ACLs provide an optional layer of security (in addition to security\ngroups) for the instances in your VPC.\n\nFor more information, see [Network ACLs](https://docs.aws.amazon.com/vpc/latest/userguide/vpc-network-acls.html) in\nthe *Amazon VPC User Guide*.","ref":"AWS.EC2.html#create_network_acl/3","title":"AWS.EC2.create_network_acl/3","type":"function"},{"doc":"Creates an entry (a rule) in a network ACL with the specified rule number.\n\nEach network ACL has a set of numbered ingress rules and a separate set of\nnumbered egress rules. When determining whether a packet should be allowed in or\nout of a subnet associated with the ACL, we process the entries in the ACL\naccording to the rule numbers, in ascending order. Each network ACL has a set of\ningress rules and a separate set of egress rules.\n\nWe recommend that you leave room between the rule numbers (for example, 100,\n110, 120, ...), and not number them one right after the other (for example, 101,\n102, 103, ...). This makes it easier to add a rule between existing ones without\nhaving to renumber the rules.\n\nAfter you add an entry, you can't modify it; you must either replace it, or\ncreate an entry and delete the old one.\n\nFor more information about network ACLs, see [Network ACLs](https://docs.aws.amazon.com/vpc/latest/userguide/vpc-network-acls.html) in\nthe *Amazon VPC User Guide*.","ref":"AWS.EC2.html#create_network_acl_entry/3","title":"AWS.EC2.create_network_acl_entry/3","type":"function"},{"doc":"Creates a Network Access Scope.\n\nAmazon Web Services Network Access Analyzer enables cloud networking and cloud\noperations teams to verify that their networks on Amazon Web Services conform to\ntheir network security and governance objectives. For more information, see the\n[Amazon Web Services Network Access Analyzer Guide](https://docs.aws.amazon.com/vpc/latest/network-access-analyzer/).","ref":"AWS.EC2.html#create_network_insights_access_scope/3","title":"AWS.EC2.create_network_insights_access_scope/3","type":"function"},{"doc":"Creates a path to analyze for reachability.\n\nReachability Analyzer enables you to analyze and debug network reachability\nbetween two resources in your virtual private cloud (VPC). For more information,\nsee the [Reachability Analyzer Guide](https://docs.aws.amazon.com/vpc/latest/reachability/).","ref":"AWS.EC2.html#create_network_insights_path/3","title":"AWS.EC2.create_network_insights_path/3","type":"function"},{"doc":"Creates a network interface in the specified subnet.\n\nThe number of IP addresses you can assign to a network interface varies by\ninstance type. For more information, see [IP Addresses Per ENI Per Instance Type](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/using-eni.html#AvailableIpPerENI)\nin the *Amazon Virtual Private Cloud User Guide*.\n\nFor more information about network interfaces, see [Elastic network interfaces](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/using-eni.html)\nin the *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.EC2.html#create_network_interface/3","title":"AWS.EC2.create_network_interface/3","type":"function"},{"doc":"Grants an Amazon Web Services-authorized account permission to attach the\nspecified network interface to an instance in their account.\n\nYou can grant permission to a single Amazon Web Services account only, and only\none account at a time.","ref":"AWS.EC2.html#create_network_interface_permission/3","title":"AWS.EC2.create_network_interface_permission/3","type":"function"},{"doc":"Creates a placement group in which to launch instances.\n\nThe strategy of the placement group determines how the instances are organized\nwithin the group.\n\nA `cluster` placement group is a logical grouping of instances within a single\nAvailability Zone that benefit from low network latency, high network\nthroughput. A `spread` placement group places instances on distinct hardware. A\n`partition` placement group places groups of instances in different partitions,\nwhere instances in one partition do not share the same hardware with instances\nin another partition.\n\nFor more information, see [Placement groups](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/placement-groups.html)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#create_placement_group/3","title":"AWS.EC2.create_placement_group/3","type":"function"},{"doc":"Creates a public IPv4 address pool.\n\nA public IPv4 pool is an EC2 IP address pool required for the public IPv4 CIDRs\nthat you own and bring to Amazon Web Services to manage with IPAM. IPv6\naddresses you bring to Amazon Web Services, however, use IPAM pools only. To\nmonitor the status of pool creation, use\n[DescribePublicIpv4Pools](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribePublicIpv4Pools.html).","ref":"AWS.EC2.html#create_public_ipv4_pool/3","title":"AWS.EC2.create_public_ipv4_pool/3","type":"function"},{"doc":"Replaces the EBS-backed root volume for a `running` instance with a new volume\nthat is restored to the original root volume's launch state, that is restored to\na specific snapshot taken from the original root volume, or that is restored\nfrom an AMI that has the same key characteristics as that of the instance.\n\nFor more information, see [Replace a root volume](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/replace-root.html)\nin the *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.EC2.html#create_replace_root_volume_task/3","title":"AWS.EC2.create_replace_root_volume_task/3","type":"function"},{"doc":"Creates a listing for Amazon EC2 Standard Reserved Instances to be sold in the\nReserved Instance Marketplace.\n\nYou can submit one Standard Reserved Instance listing at a time. To get a list\nof your Standard Reserved Instances, you can use the `DescribeReservedInstances`\noperation.\n\nOnly Standard Reserved Instances can be sold in the Reserved Instance\nMarketplace. Convertible Reserved Instances cannot be sold.\n\nThe Reserved Instance Marketplace matches sellers who want to resell Standard\nReserved Instance capacity that they no longer need with buyers who want to\npurchase additional capacity. Reserved Instances bought and sold through the\nReserved Instance Marketplace work like any other Reserved Instances.\n\nTo sell your Standard Reserved Instances, you must first register as a seller in\nthe Reserved Instance Marketplace. After completing the registration process,\nyou can create a Reserved Instance Marketplace listing of some or all of your\nStandard Reserved Instances, and specify the upfront price to receive for them.\nYour Standard Reserved Instance listings then become available for purchase. To\nview the details of your Standard Reserved Instance listing, you can use the\n`DescribeReservedInstancesListings` operation.\n\nFor more information, see [Reserved Instance Marketplace](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ri-market-general.html)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#create_reserved_instances_listing/3","title":"AWS.EC2.create_reserved_instances_listing/3","type":"function"},{"doc":"Starts a task that restores an AMI from an Amazon S3 object that was previously\ncreated by using\n[CreateStoreImageTask](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateStoreImageTask.html).   To use this API, you must have the required permissions. For more information,\nsee [Permissions for storing and restoring AMIs using Amazon\nS3](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ami-store-restore.html#ami-s3-permissions)\nin the *Amazon EC2 User Guide*.\n\nFor more information, see [Store and restore an AMI using Amazon S3](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ami-store-restore.html)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#create_restore_image_task/3","title":"AWS.EC2.create_restore_image_task/3","type":"function"},{"doc":"Creates a route in a route table within a VPC.\n\nYou must specify either a destination CIDR block or a prefix list ID. You must\nalso specify exactly one of the resources from the parameter list.\n\nWhen determining how to route traffic, we use the route with the most specific\nmatch. For example, traffic is destined for the IPv4 address `192.0.2.3`, and\nthe route table includes the following two IPv4 routes:\n\n  * `192.0.2.0/24` (goes to some target A)\n\n  * `192.0.2.0/28` (goes to some target B)\n\nBoth routes apply to the traffic destined for `192.0.2.3`. However, the second\nroute in the list covers a smaller number of IP addresses and is therefore more\nspecific, so we use that route to determine where to target the traffic.\n\nFor more information about route tables, see [Route tables](https://docs.aws.amazon.com/vpc/latest/userguide/VPC_Route_Tables.html)\nin the *Amazon VPC User Guide*.","ref":"AWS.EC2.html#create_route/3","title":"AWS.EC2.create_route/3","type":"function"},{"doc":"Creates a route table for the specified VPC.\n\nAfter you create a route table, you can add routes and associate the table with\na subnet.\n\nFor more information, see [Route tables](https://docs.aws.amazon.com/vpc/latest/userguide/VPC_Route_Tables.html)\nin the *Amazon VPC User Guide*.","ref":"AWS.EC2.html#create_route_table/3","title":"AWS.EC2.create_route_table/3","type":"function"},{"doc":"Creates a security group.\n\nA security group acts as a virtual firewall for your instance to control inbound\nand outbound traffic. For more information, see [Amazon EC2 security groups](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/using-network-security.html)\nin the *Amazon Elastic Compute Cloud User Guide* and [Security groups for your VPC](https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/VPC_SecurityGroups.html)\nin the *Amazon Virtual Private Cloud User Guide*.\n\nWhen you create a security group, you specify a friendly name of your choice.\nYou can't have two security groups for the same VPC with the same name.\n\nYou have a default security group for use in your VPC. If you don't specify a\nsecurity group when you launch an instance, the instance is launched into the\nappropriate default security group. A default security group includes a default\nrule that grants instances unrestricted network access to each other.\n\nYou can add or remove rules from your security groups using\n`AuthorizeSecurityGroupIngress`, `AuthorizeSecurityGroupEgress`,\n`RevokeSecurityGroupIngress`, and `RevokeSecurityGroupEgress`.\n\nFor more information about VPC security group limits, see [Amazon VPC Limits](https://docs.aws.amazon.com/vpc/latest/userguide/amazon-vpc-limits.html).","ref":"AWS.EC2.html#create_security_group/3","title":"AWS.EC2.create_security_group/3","type":"function"},{"doc":"Creates a snapshot of an EBS volume and stores it in Amazon S3.\n\nYou can use snapshots for backups, to make copies of EBS volumes, and to save\ndata before shutting down an instance.\n\nYou can create snapshots of volumes in a Region and volumes on an Outpost. If\nyou create a snapshot of a volume in a Region, the snapshot must be stored in\nthe same Region as the volume. If you create a snapshot of a volume on an\nOutpost, the snapshot can be stored on the same Outpost as the volume, or in the\nRegion for that Outpost.\n\nWhen a snapshot is created, any Amazon Web Services Marketplace product codes\nthat are associated with the source volume are propagated to the snapshot.\n\nYou can take a snapshot of an attached volume that is in use. However, snapshots\nonly capture data that has been written to your Amazon EBS volume at the time\nthe snapshot command is issued; this might exclude any data that has been cached\nby any applications or the operating system. If you can pause any file systems\non the volume long enough to take a snapshot, your snapshot should be complete.\nHowever, if you cannot pause all file writes to the volume, you should unmount\nthe volume from within the instance, issue the snapshot command, and then\nremount the volume to ensure a consistent and complete snapshot. You may remount\nand use your volume while the snapshot status is `pending`.\n\nWhen you create a snapshot for an EBS volume that serves as a root device, we\nrecommend that you stop the instance before taking the snapshot.\n\nSnapshots that are taken from encrypted volumes are automatically encrypted.\nVolumes that are created from encrypted snapshots are also automatically\nencrypted. Your encrypted volumes and any associated snapshots always remain\nprotected.\n\nYou can tag your snapshots during creation. For more information, see [Tag your Amazon EC2\nresources](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Using_Tags.html)\nin the *Amazon Elastic Compute Cloud User Guide*.\n\nFor more information, see [Amazon Elastic Block Store](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/AmazonEBS.html) and\n[Amazon EBS encryption](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSEncryption.html)\nin the *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.EC2.html#create_snapshot/3","title":"AWS.EC2.create_snapshot/3","type":"function"},{"doc":"Creates crash-consistent snapshots of multiple EBS volumes and stores the data\nin S3.\n\nVolumes are chosen by specifying an instance. Any attached volumes will produce\none snapshot each that is crash-consistent across the instance.\n\nYou can include all of the volumes currently attached to the instance, or you\ncan exclude the root volume or specific data (non-root) volumes from the\nmulti-volume snapshot set.\n\nYou can create multi-volume snapshots of instances in a Region and instances on\nan Outpost. If you create snapshots from an instance in a Region, the snapshots\nmust be stored in the same Region as the instance. If you create snapshots from\nan instance on an Outpost, the snapshots can be stored on the same Outpost as\nthe instance, or in the Region for that Outpost.","ref":"AWS.EC2.html#create_snapshots/3","title":"AWS.EC2.create_snapshots/3","type":"function"},{"doc":"Creates a data feed for Spot Instances, enabling you to view Spot Instance usage\nlogs.\n\nYou can create one data feed per Amazon Web Services account. For more\ninformation, see [Spot Instance data feed](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/spot-data-feeds.html)\nin the *Amazon EC2 User Guide for Linux Instances*.","ref":"AWS.EC2.html#create_spot_datafeed_subscription/3","title":"AWS.EC2.create_spot_datafeed_subscription/3","type":"function"},{"doc":"Stores an AMI as a single object in an Amazon S3 bucket.\n\nTo use this API, you must have the required permissions. For more information,\nsee [Permissions for storing and restoring AMIs using Amazon S3](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ami-store-restore.html#ami-s3-permissions)\nin the *Amazon EC2 User Guide*.\n\nFor more information, see [Store and restore an AMI using Amazon S3](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ami-store-restore.html)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#create_store_image_task/3","title":"AWS.EC2.create_store_image_task/3","type":"function"},{"doc":"Creates a subnet in the specified VPC.\n\nFor an IPv4 only subnet, specify an IPv4 CIDR block. If the VPC has an IPv6 CIDR\nblock, you can create an IPv6 only subnet or a dual stack subnet instead. For an\nIPv6 only subnet, specify an IPv6 CIDR block. For a dual stack subnet, specify\nboth an IPv4 CIDR block and an IPv6 CIDR block.\n\nA subnet CIDR block must not overlap the CIDR block of an existing subnet in the\nVPC. After you create a subnet, you can't change its CIDR block.\n\nThe allowed size for an IPv4 subnet is between a /28 netmask (16 IP addresses)\nand a /16 netmask (65,536 IP addresses). Amazon Web Services reserves both the\nfirst four and the last IPv4 address in each subnet's CIDR block. They're not\navailable for your use.\n\nIf you've associated an IPv6 CIDR block with your VPC, you can associate an IPv6\nCIDR block with a subnet when you create it.\n\nIf you add more than one subnet to a VPC, they're set up in a star topology with\na logical router in the middle.\n\nWhen you stop an instance in a subnet, it retains its private IPv4 address. It's\ntherefore possible to have a subnet with no running instances (they're all\nstopped), but no remaining IP addresses available.\n\nFor more information, see\n[Subnets](https://docs.aws.amazon.com/vpc/latest/userguide/configure-subnets.html)\nin the *Amazon VPC User Guide*.","ref":"AWS.EC2.html#create_subnet/3","title":"AWS.EC2.create_subnet/3","type":"function"},{"doc":"Creates a subnet CIDR reservation.\n\nFor more information, see [Subnet CIDR reservations](https://docs.aws.amazon.com/vpc/latest/userguide/subnet-cidr-reservation.html)\nin the *Amazon Virtual Private Cloud User Guide* and [Assign prefixes to network interfaces](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-prefix-eni.html)\nin the *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.EC2.html#create_subnet_cidr_reservation/3","title":"AWS.EC2.create_subnet_cidr_reservation/3","type":"function"},{"doc":"Adds or overwrites only the specified tags for the specified Amazon EC2 resource\nor resources.\n\nWhen you specify an existing tag key, the value is overwritten with the new\nvalue. Each resource can have a maximum of 50 tags. Each tag consists of a key\nand optional value. Tag keys must be unique per resource.\n\nFor more information about tags, see [Tag your Amazon EC2 resources](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Using_Tags.html)\nin the *Amazon Elastic Compute Cloud User Guide*. For more information about\ncreating IAM policies that control users' access to resources based on tags, see\n[Supported resource-level permissions for Amazon EC2 API actions](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-supported-iam-actions-resources.html)\nin the *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.EC2.html#create_tags/3","title":"AWS.EC2.create_tags/3","type":"function"},{"doc":"Creates a Traffic Mirror filter.\n\nA Traffic Mirror filter is a set of rules that defines the traffic to mirror.\n\nBy default, no traffic is mirrored. To mirror traffic, use\n[CreateTrafficMirrorFilterRule](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateTrafficMirrorFilterRule.htm) to add Traffic Mirror rules to the filter. The rules you add define what traffic\ngets mirrored. You can also use\n[ModifyTrafficMirrorFilterNetworkServices](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyTrafficMirrorFilterNetworkServices.html)\nto mirror supported network services.","ref":"AWS.EC2.html#create_traffic_mirror_filter/3","title":"AWS.EC2.create_traffic_mirror_filter/3","type":"function"},{"doc":"Creates a Traffic Mirror filter rule.\n\nA Traffic Mirror rule defines the Traffic Mirror source traffic to mirror.\n\nYou need the Traffic Mirror filter ID when you create the rule.","ref":"AWS.EC2.html#create_traffic_mirror_filter_rule/3","title":"AWS.EC2.create_traffic_mirror_filter_rule/3","type":"function"},{"doc":"Creates a Traffic Mirror session.\n\nA Traffic Mirror session actively copies packets from a Traffic Mirror source to\na Traffic Mirror target. Create a filter, and then assign it to the session to\ndefine a subset of the traffic to mirror, for example all TCP traffic.\n\nThe Traffic Mirror source and the Traffic Mirror target (monitoring appliances)\ncan be in the same VPC, or in a different VPC connected via VPC peering or a\ntransit gateway.\n\nBy default, no traffic is mirrored. Use\n[CreateTrafficMirrorFilter](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateTrafficMirrorFilter.htm)\nto create filter rules that specify the traffic to mirror.","ref":"AWS.EC2.html#create_traffic_mirror_session/3","title":"AWS.EC2.create_traffic_mirror_session/3","type":"function"},{"doc":"Creates a target for your Traffic Mirror session.\n\nA Traffic Mirror target is the destination for mirrored traffic. The Traffic\nMirror source and the Traffic Mirror target (monitoring appliances) can be in\nthe same VPC, or in different VPCs connected via VPC peering or a transit\ngateway.\n\nA Traffic Mirror target can be a network interface, a Network Load Balancer, or\na Gateway Load Balancer endpoint.\n\nTo use the target in a Traffic Mirror session, use\n[CreateTrafficMirrorSession](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateTrafficMirrorSession.htm).","ref":"AWS.EC2.html#create_traffic_mirror_target/3","title":"AWS.EC2.create_traffic_mirror_target/3","type":"function"},{"doc":"Creates a transit gateway.\n\nYou can use a transit gateway to interconnect your virtual private clouds (VPC)\nand on-premises networks. After the transit gateway enters the `available`\nstate, you can attach your VPCs and VPN connections to the transit gateway.\n\nTo attach your VPCs, use `CreateTransitGatewayVpcAttachment`.\n\nTo attach a VPN connection, use `CreateCustomerGateway` to create a customer\ngateway and specify the ID of the customer gateway and the ID of the transit\ngateway in a call to `CreateVpnConnection`.\n\nWhen you create a transit gateway, we create a default transit gateway route\ntable and use it as the default association route table and the default\npropagation route table. You can use `CreateTransitGatewayRouteTable` to create\nadditional transit gateway route tables. If you disable automatic route\npropagation, we do not create a default transit gateway route table. You can use\n`EnableTransitGatewayRouteTablePropagation` to propagate routes from a resource\nattachment to a transit gateway route table. If you disable automatic\nassociations, you can use `AssociateTransitGatewayRouteTable` to associate a\nresource attachment with a transit gateway route table.","ref":"AWS.EC2.html#create_transit_gateway/3","title":"AWS.EC2.create_transit_gateway/3","type":"function"},{"doc":"Creates a Connect attachment from a specified transit gateway attachment.\n\nA Connect attachment is a GRE-based tunnel attachment that you can use to\nestablish a connection between a transit gateway and an appliance.\n\nA Connect attachment uses an existing VPC or Amazon Web Services Direct Connect\nattachment as the underlying transport mechanism.","ref":"AWS.EC2.html#create_transit_gateway_connect/3","title":"AWS.EC2.create_transit_gateway_connect/3","type":"function"},{"doc":"Creates a Connect peer for a specified transit gateway Connect attachment\nbetween a transit gateway and an appliance.\n\nThe peer address and transit gateway address must be the same IP address family\n(IPv4 or IPv6).\n\nFor more information, see [Connect peers](https://docs.aws.amazon.com/vpc/latest/tgw/tgw-connect.html#tgw-connect-peer)\nin the *Transit Gateways Guide*.","ref":"AWS.EC2.html#create_transit_gateway_connect_peer/3","title":"AWS.EC2.create_transit_gateway_connect_peer/3","type":"function"},{"doc":"Creates a multicast domain using the specified transit gateway.\n\nThe transit gateway must be in the available state before you create a domain.\nUse\n[DescribeTransitGateways](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeTransitGateways.html)\nto see the state of transit gateway.","ref":"AWS.EC2.html#create_transit_gateway_multicast_domain/3","title":"AWS.EC2.create_transit_gateway_multicast_domain/3","type":"function"},{"doc":"Requests a transit gateway peering attachment between the specified transit\ngateway (requester) and a peer transit gateway (accepter).\n\nThe peer transit gateway can be in your account or a different Amazon Web\nServices account.\n\nAfter you create the peering attachment, the owner of the accepter transit\ngateway must accept the attachment request.","ref":"AWS.EC2.html#create_transit_gateway_peering_attachment/3","title":"AWS.EC2.create_transit_gateway_peering_attachment/3","type":"function"},{"doc":"Creates a transit gateway policy table.","ref":"AWS.EC2.html#create_transit_gateway_policy_table/3","title":"AWS.EC2.create_transit_gateway_policy_table/3","type":"function"},{"doc":"Creates a reference (route) to a prefix list in a specified transit gateway\nroute table.","ref":"AWS.EC2.html#create_transit_gateway_prefix_list_reference/3","title":"AWS.EC2.create_transit_gateway_prefix_list_reference/3","type":"function"},{"doc":"Creates a static route for the specified transit gateway route table.","ref":"AWS.EC2.html#create_transit_gateway_route/3","title":"AWS.EC2.create_transit_gateway_route/3","type":"function"},{"doc":"Creates a route table for the specified transit gateway.","ref":"AWS.EC2.html#create_transit_gateway_route_table/3","title":"AWS.EC2.create_transit_gateway_route_table/3","type":"function"},{"doc":"Advertises a new transit gateway route table.","ref":"AWS.EC2.html#create_transit_gateway_route_table_announcement/3","title":"AWS.EC2.create_transit_gateway_route_table_announcement/3","type":"function"},{"doc":"Attaches the specified VPC to the specified transit gateway.\n\nIf you attach a VPC with a CIDR range that overlaps the CIDR range of a VPC that\nis already attached, the new VPC CIDR range is not propagated to the default\npropagation route table.\n\nTo send VPC traffic to an attached transit gateway, add a route to the VPC route\ntable using `CreateRoute`.","ref":"AWS.EC2.html#create_transit_gateway_vpc_attachment/3","title":"AWS.EC2.create_transit_gateway_vpc_attachment/3","type":"function"},{"doc":"An Amazon Web Services Verified Access endpoint is where you define your\napplication along with an optional endpoint-level access policy.","ref":"AWS.EC2.html#create_verified_access_endpoint/3","title":"AWS.EC2.create_verified_access_endpoint/3","type":"function"},{"doc":"An Amazon Web Services Verified Access group is a collection of Amazon Web\nServices Verified Access endpoints who's associated applications have similar\nsecurity requirements.\n\nEach instance within a Verified Access group shares an Verified Access policy.\nFor example, you can group all Verified Access instances associated with \"sales\"\napplications together and use one common Verified Access policy.","ref":"AWS.EC2.html#create_verified_access_group/3","title":"AWS.EC2.create_verified_access_group/3","type":"function"},{"doc":"An Amazon Web Services Verified Access instance is a regional entity that\nevaluates application requests and grants access only when your security\nrequirements are met.","ref":"AWS.EC2.html#create_verified_access_instance/3","title":"AWS.EC2.create_verified_access_instance/3","type":"function"},{"doc":"A trust provider is a third-party entity that creates, maintains, and manages\nidentity information for users and devices.\n\nWhen an application request is made, the identity information sent by the trust\nprovider is evaluated by Verified Access before allowing or denying the\napplication request.","ref":"AWS.EC2.html#create_verified_access_trust_provider/3","title":"AWS.EC2.create_verified_access_trust_provider/3","type":"function"},{"doc":"Creates an EBS volume that can be attached to an instance in the same\nAvailability Zone.\n\nYou can create a new empty volume or restore a volume from an EBS snapshot. Any\nAmazon Web Services Marketplace product codes from the snapshot are propagated\nto the volume.\n\nYou can create encrypted volumes. Encrypted volumes must be attached to\ninstances that support Amazon EBS encryption. Volumes that are created from\nencrypted snapshots are also automatically encrypted. For more information, see\n[Amazon EBS encryption](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSEncryption.html)\nin the *Amazon Elastic Compute Cloud User Guide*.\n\nYou can tag your volumes during creation. For more information, see [Tag your Amazon EC2\nresources](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Using_Tags.html)\nin the *Amazon Elastic Compute Cloud User Guide*.\n\nFor more information, see [Create an Amazon EBS volume](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ebs-creating-volume.html)\nin the *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.EC2.html#create_volume/3","title":"AWS.EC2.create_volume/3","type":"function"},{"doc":"Creates a VPC with the specified CIDR blocks.\n\nFor more information, see [IP addressing for your VPCs and subnets](https://docs.aws.amazon.com/vpc/latest/userguide/vpc-ip-addressing.html)\nin the *Amazon VPC User Guide*.\n\nYou can optionally request an IPv6 CIDR block for the VPC. You can request an\nAmazon-provided IPv6 CIDR block from Amazon's pool of IPv6 addresses or an IPv6\nCIDR block from an IPv6 address pool that you provisioned through bring your own\nIP addresses\n([BYOIP](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-byoip.html)).  By default, each instance that you launch in the VPC has the default DHCP\noptions, which include only a default DNS server that we provide\n(AmazonProvidedDNS). For more information, see [DHCP option\nsets](https://docs.aws.amazon.com/vpc/latest/userguide/VPC_DHCP_Options.html) in\nthe *Amazon VPC User Guide*.\n\nYou can specify the instance tenancy value for the VPC when you create it. You\ncan't change this value for the VPC after you create it. For more information,\nsee [Dedicated Instances](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/dedicated-instance.html)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#create_vpc/3","title":"AWS.EC2.create_vpc/3","type":"function"},{"doc":"Creates a VPC endpoint.\n\nA VPC endpoint provides a private connection between the specified VPC and the\nspecified endpoint service. You can use an endpoint service provided by Amazon\nWeb Services, an Amazon Web Services Marketplace Partner, or another Amazon Web\nServices account. For more information, see the [Amazon Web Services PrivateLink User Guide](https://docs.aws.amazon.com/vpc/latest/privatelink/).","ref":"AWS.EC2.html#create_vpc_endpoint/3","title":"AWS.EC2.create_vpc_endpoint/3","type":"function"},{"doc":"Creates a connection notification for a specified VPC endpoint or VPC endpoint\nservice.\n\nA connection notification notifies you of specific endpoint events. You must\ncreate an SNS topic to receive notifications. For more information, see [Create a Topic](https://docs.aws.amazon.com/sns/latest/dg/CreateTopic.html) in the\n*Amazon Simple Notification Service Developer Guide*.\n\nYou can create a connection notification for interface endpoints only.","ref":"AWS.EC2.html#create_vpc_endpoint_connection_notification/3","title":"AWS.EC2.create_vpc_endpoint_connection_notification/3","type":"function"},{"doc":"Creates a VPC endpoint service to which service consumers (Amazon Web Services\naccounts, users, and IAM roles) can connect.\n\nBefore you create an endpoint service, you must create one of the following for\nyour service:\n\n  * A [Network Load Balancer](https://docs.aws.amazon.com/elasticloadbalancing/latest/network/).\nService consumers connect to your service using an interface endpoint.\n\n  * A [Gateway Load Balancer](https://docs.aws.amazon.com/elasticloadbalancing/latest/gateway/).\nService consumers connect to your service using a Gateway Load Balancer\nendpoint.\n\nIf you set the private DNS name, you must prove that you own the private DNS\ndomain name.\n\nFor more information, see the [Amazon Web Services PrivateLink Guide](https://docs.aws.amazon.com/vpc/latest/privatelink/).","ref":"AWS.EC2.html#create_vpc_endpoint_service_configuration/3","title":"AWS.EC2.create_vpc_endpoint_service_configuration/3","type":"function"},{"doc":"Requests a VPC peering connection between two VPCs: a requester VPC that you own\nand an accepter VPC with which to create the connection.\n\nThe accepter VPC can belong to another Amazon Web Services account and can be in\na different Region to the requester VPC. The requester VPC and accepter VPC\ncannot have overlapping CIDR blocks.\n\nLimitations and rules apply to a VPC peering connection. For more information,\nsee the\n[limitations](https://docs.aws.amazon.com/vpc/latest/peering/vpc-peering-basics.html#vpc-peering-limitations)\nsection in the *VPC Peering Guide*.\n\nThe owner of the accepter VPC must accept the peering request to activate the\npeering connection. The VPC peering connection request expires after 7 days,\nafter which it cannot be accepted or rejected.\n\nIf you create a VPC peering connection request between VPCs with overlapping\nCIDR blocks, the VPC peering connection has a status of `failed`.","ref":"AWS.EC2.html#create_vpc_peering_connection/3","title":"AWS.EC2.create_vpc_peering_connection/3","type":"function"},{"doc":"Creates a VPN connection between an existing virtual private gateway or transit\ngateway and a customer gateway.\n\nThe supported connection type is `ipsec.1`.\n\nThe response includes information that you need to give to your network\nadministrator to configure your customer gateway.\n\nWe strongly recommend that you use HTTPS when calling this operation because the\nresponse contains sensitive cryptographic information for configuring your\ncustomer gateway device.\n\nIf you decide to shut down your VPN connection for any reason and later create a\nnew VPN connection, you must reconfigure your customer gateway with the new\ninformation returned from this call.\n\nThis is an idempotent operation. If you perform the operation more than once,\nAmazon EC2 doesn't return an error.\n\nFor more information, see [Amazon Web Services Site-to-Site VPN](https://docs.aws.amazon.com/vpn/latest/s2svpn/VPC_VPN.html) in the *Amazon\nWeb Services Site-to-Site VPN User Guide*.","ref":"AWS.EC2.html#create_vpn_connection/3","title":"AWS.EC2.create_vpn_connection/3","type":"function"},{"doc":"Creates a static route associated with a VPN connection between an existing\nvirtual private gateway and a VPN customer gateway.\n\nThe static route allows traffic to be routed from the virtual private gateway to\nthe VPN customer gateway.\n\nFor more information, see [Amazon Web Services Site-to-Site VPN](https://docs.aws.amazon.com/vpn/latest/s2svpn/VPC_VPN.html) in the *Amazon\nWeb Services Site-to-Site VPN User Guide*.","ref":"AWS.EC2.html#create_vpn_connection_route/3","title":"AWS.EC2.create_vpn_connection_route/3","type":"function"},{"doc":"Creates a virtual private gateway.\n\nA virtual private gateway is the endpoint on the VPC side of your VPN\nconnection. You can create a virtual private gateway before creating the VPC\nitself.\n\nFor more information, see [Amazon Web Services Site-to-Site VPN](https://docs.aws.amazon.com/vpn/latest/s2svpn/VPC_VPN.html) in the *Amazon\nWeb Services Site-to-Site VPN User Guide*.","ref":"AWS.EC2.html#create_vpn_gateway/3","title":"AWS.EC2.create_vpn_gateway/3","type":"function"},{"doc":"Deletes a carrier gateway.\n\nIf you do not delete the route that contains the carrier gateway as the Target,\nthe route is a blackhole route. For information about how to delete a route, see\n[DeleteRoute](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteRoute.html).","ref":"AWS.EC2.html#delete_carrier_gateway/3","title":"AWS.EC2.delete_carrier_gateway/3","type":"function"},{"doc":"Deletes the specified Client VPN endpoint.\n\nYou must disassociate all target networks before you can delete a Client VPN\nendpoint.","ref":"AWS.EC2.html#delete_client_vpn_endpoint/3","title":"AWS.EC2.delete_client_vpn_endpoint/3","type":"function"},{"doc":"Deletes a route from a Client VPN endpoint.\n\nYou can only delete routes that you manually added using the\n**CreateClientVpnRoute** action. You cannot delete routes that were\nautomatically added when associating a subnet. To remove routes that have been\nautomatically added, disassociate the target subnet from the Client VPN\nendpoint.","ref":"AWS.EC2.html#delete_client_vpn_route/3","title":"AWS.EC2.delete_client_vpn_route/3","type":"function"},{"doc":"Deletes a range of customer-owned IP addresses.","ref":"AWS.EC2.html#delete_coip_cidr/3","title":"AWS.EC2.delete_coip_cidr/3","type":"function"},{"doc":"Deletes a pool of customer-owned IP (CoIP) addresses.","ref":"AWS.EC2.html#delete_coip_pool/3","title":"AWS.EC2.delete_coip_pool/3","type":"function"},{"doc":"Deletes the specified customer gateway.\n\nYou must delete the VPN connection before you can delete the customer gateway.","ref":"AWS.EC2.html#delete_customer_gateway/3","title":"AWS.EC2.delete_customer_gateway/3","type":"function"},{"doc":"Deletes the specified set of DHCP options.\n\nYou must disassociate the set of DHCP options before you can delete it. You can\ndisassociate the set of DHCP options by associating either a new set of options\nor the default set of options with the VPC.","ref":"AWS.EC2.html#delete_dhcp_options/3","title":"AWS.EC2.delete_dhcp_options/3","type":"function"},{"doc":"Deletes an egress-only internet gateway.","ref":"AWS.EC2.html#delete_egress_only_internet_gateway/3","title":"AWS.EC2.delete_egress_only_internet_gateway/3","type":"function"},{"doc":"Deletes the specified EC2 Fleets.\n\nAfter you delete an EC2 Fleet, it launches no new instances.\n\nYou must also specify whether a deleted EC2 Fleet should terminate its\ninstances. If you choose to terminate the instances, the EC2 Fleet enters the\n`deleted_terminating` state. Otherwise, the EC2 Fleet enters the\n`deleted_running` state, and the instances continue to run until they are\ninterrupted or you terminate them manually.\n\nFor `instant` fleets, EC2 Fleet must terminate the instances when the fleet is\ndeleted. A deleted `instant` fleet with running instances is not supported.","ref":"AWS.EC2.html#delete_fleets/3","title":"AWS.EC2.delete_fleets/3","type":"function"},{"doc":"* You can delete up to 25 `instant` fleets in a single request. If\nyou exceed this number, no `instant` fleets are deleted and an error is\nreturned. There is no restriction on the number of fleets of type `maintain` or\n`request` that can be deleted in a single request.\n\n  * Up to 1000 instances can be terminated in a single request to\ndelete `instant` fleets.\n\nFor more information, see [Delete an EC2 Fleet](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/manage-ec2-fleet.html#delete-fleet)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#delete_fleets/3-restrictions","title":"Restrictions - AWS.EC2.delete_fleets/3","type":"function"},{"doc":"Deletes one or more flow logs.","ref":"AWS.EC2.html#delete_flow_logs/3","title":"AWS.EC2.delete_flow_logs/3","type":"function"},{"doc":"Deletes the specified Amazon FPGA Image (AFI).","ref":"AWS.EC2.html#delete_fpga_image/3","title":"AWS.EC2.delete_fpga_image/3","type":"function"},{"doc":"Deletes the specified EC2 Instance Connect Endpoint.","ref":"AWS.EC2.html#delete_instance_connect_endpoint/3","title":"AWS.EC2.delete_instance_connect_endpoint/3","type":"function"},{"doc":"Deletes the specified event window.\n\nFor more information, see [Define event windows for scheduled events](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/event-windows.html)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#delete_instance_event_window/3","title":"AWS.EC2.delete_instance_event_window/3","type":"function"},{"doc":"Deletes the specified internet gateway.\n\nYou must detach the internet gateway from the VPC before you can delete it.","ref":"AWS.EC2.html#delete_internet_gateway/3","title":"AWS.EC2.delete_internet_gateway/3","type":"function"},{"doc":"Delete an IPAM.\n\nDeleting an IPAM removes all monitored data associated with the IPAM including\nthe historical data for CIDRs.\n\nFor more information, see [Delete an IPAM](https://docs.aws.amazon.com/vpc/latest/ipam/delete-ipam.html) in the\n*Amazon VPC IPAM User Guide*.","ref":"AWS.EC2.html#delete_ipam/3","title":"AWS.EC2.delete_ipam/3","type":"function"},{"doc":"Delete an IPAM pool.\n\nYou cannot delete an IPAM pool if there are allocations in it or CIDRs\nprovisioned to it. To release allocations, see\n[ReleaseIpamPoolAllocation](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ReleaseIpamPoolAllocation.html). To deprovision pool CIDRs, see\n[DeprovisionIpamPoolCidr](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeprovisionIpamPoolCidr.html).\n\nFor more information, see [Delete a pool](https://docs.aws.amazon.com/vpc/latest/ipam/delete-pool-ipam.html) in the\n*Amazon VPC IPAM User Guide*.","ref":"AWS.EC2.html#delete_ipam_pool/3","title":"AWS.EC2.delete_ipam_pool/3","type":"function"},{"doc":"Deletes an IPAM resource discovery.\n\nA resource discovery is an IPAM component that enables IPAM to manage and\nmonitor resources that belong to the owning account.","ref":"AWS.EC2.html#delete_ipam_resource_discovery/3","title":"AWS.EC2.delete_ipam_resource_discovery/3","type":"function"},{"doc":"Delete the scope for an IPAM.\n\nYou cannot delete the default scopes.\n\nFor more information, see [Delete a scope](https://docs.aws.amazon.com/vpc/latest/ipam/delete-scope-ipam.html) in\nthe *Amazon VPC IPAM User Guide*.","ref":"AWS.EC2.html#delete_ipam_scope/3","title":"AWS.EC2.delete_ipam_scope/3","type":"function"},{"doc":"Deletes the specified key pair, by removing the public key from Amazon EC2.","ref":"AWS.EC2.html#delete_key_pair/3","title":"AWS.EC2.delete_key_pair/3","type":"function"},{"doc":"Deletes a launch template.\n\nDeleting a launch template deletes all of its versions.","ref":"AWS.EC2.html#delete_launch_template/3","title":"AWS.EC2.delete_launch_template/3","type":"function"},{"doc":"Deletes one or more versions of a launch template.\n\nYou can't delete the default version of a launch template; you must first assign\na different version as the default. If the default version is the only version\nfor the launch template, you must delete the entire launch template using\n`DeleteLaunchTemplate`.\n\nYou can delete up to 200 launch template versions in a single request. To delete\nmore than 200 versions in a single request, use `DeleteLaunchTemplate`, which\ndeletes the launch template and all of its versions.\n\nFor more information, see [Delete a launch template version](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/manage-launch-template-versions.html#delete-launch-template-version)\nin the *EC2 User Guide*.","ref":"AWS.EC2.html#delete_launch_template_versions/3","title":"AWS.EC2.delete_launch_template_versions/3","type":"function"},{"doc":"Deletes the specified route from the specified local gateway route table.","ref":"AWS.EC2.html#delete_local_gateway_route/3","title":"AWS.EC2.delete_local_gateway_route/3","type":"function"},{"doc":"Deletes a local gateway route table.","ref":"AWS.EC2.html#delete_local_gateway_route_table/3","title":"AWS.EC2.delete_local_gateway_route_table/3","type":"function"},{"doc":"Deletes a local gateway route table virtual interface group association.","ref":"AWS.EC2.html#delete_local_gateway_route_table_virtual_interface_group_association/3","title":"AWS.EC2.delete_local_gateway_route_table_virtual_interface_group_association/3","type":"function"},{"doc":"Deletes the specified association between a VPC and local gateway route table.","ref":"AWS.EC2.html#delete_local_gateway_route_table_vpc_association/3","title":"AWS.EC2.delete_local_gateway_route_table_vpc_association/3","type":"function"},{"doc":"Deletes the specified managed prefix list.\n\nYou must first remove all references to the prefix list in your resources.","ref":"AWS.EC2.html#delete_managed_prefix_list/3","title":"AWS.EC2.delete_managed_prefix_list/3","type":"function"},{"doc":"Deletes the specified NAT gateway.\n\nDeleting a public NAT gateway disassociates its Elastic IP address, but does not\nrelease the address from your account. Deleting a NAT gateway does not delete\nany NAT gateway routes in your route tables.","ref":"AWS.EC2.html#delete_nat_gateway/3","title":"AWS.EC2.delete_nat_gateway/3","type":"function"},{"doc":"Deletes the specified network ACL.\n\nYou can't delete the ACL if it's associated with any subnets. You can't delete\nthe default network ACL.","ref":"AWS.EC2.html#delete_network_acl/3","title":"AWS.EC2.delete_network_acl/3","type":"function"},{"doc":"Deletes the specified ingress or egress entry (rule) from the specified network\nACL.","ref":"AWS.EC2.html#delete_network_acl_entry/3","title":"AWS.EC2.delete_network_acl_entry/3","type":"function"},{"doc":"Deletes the specified Network Access Scope.","ref":"AWS.EC2.html#delete_network_insights_access_scope/3","title":"AWS.EC2.delete_network_insights_access_scope/3","type":"function"},{"doc":"Deletes the specified Network Access Scope analysis.","ref":"AWS.EC2.html#delete_network_insights_access_scope_analysis/3","title":"AWS.EC2.delete_network_insights_access_scope_analysis/3","type":"function"},{"doc":"Deletes the specified network insights analysis.","ref":"AWS.EC2.html#delete_network_insights_analysis/3","title":"AWS.EC2.delete_network_insights_analysis/3","type":"function"},{"doc":"Deletes the specified path.","ref":"AWS.EC2.html#delete_network_insights_path/3","title":"AWS.EC2.delete_network_insights_path/3","type":"function"},{"doc":"Deletes the specified network interface.\n\nYou must detach the network interface before you can delete it.","ref":"AWS.EC2.html#delete_network_interface/3","title":"AWS.EC2.delete_network_interface/3","type":"function"},{"doc":"Deletes a permission for a network interface.\n\nBy default, you cannot delete the permission if the account for which you're\nremoving the permission has attached the network interface to an instance.\nHowever, you can force delete the permission, regardless of any attachment.","ref":"AWS.EC2.html#delete_network_interface_permission/3","title":"AWS.EC2.delete_network_interface_permission/3","type":"function"},{"doc":"Deletes the specified placement group.\n\nYou must terminate all instances in the placement group before you can delete\nthe placement group. For more information, see [Placement groups](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/placement-groups.html)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#delete_placement_group/3","title":"AWS.EC2.delete_placement_group/3","type":"function"},{"doc":"Delete a public IPv4 pool.\n\nA public IPv4 pool is an EC2 IP address pool required for the public IPv4 CIDRs\nthat you own and bring to Amazon Web Services to manage with IPAM. IPv6\naddresses you bring to Amazon Web Services, however, use IPAM pools only.","ref":"AWS.EC2.html#delete_public_ipv4_pool/3","title":"AWS.EC2.delete_public_ipv4_pool/3","type":"function"},{"doc":"Deletes the queued purchases for the specified Reserved Instances.","ref":"AWS.EC2.html#delete_queued_reserved_instances/3","title":"AWS.EC2.delete_queued_reserved_instances/3","type":"function"},{"doc":"Deletes the specified route from the specified route table.","ref":"AWS.EC2.html#delete_route/3","title":"AWS.EC2.delete_route/3","type":"function"},{"doc":"Deletes the specified route table.\n\nYou must disassociate the route table from any subnets before you can delete it.\nYou can't delete the main route table.","ref":"AWS.EC2.html#delete_route_table/3","title":"AWS.EC2.delete_route_table/3","type":"function"},{"doc":"Deletes a security group.\n\nIf you attempt to delete a security group that is associated with an instance or\nnetwork interface or is referenced by another security group, the operation\nfails with `DependencyViolation`.","ref":"AWS.EC2.html#delete_security_group/3","title":"AWS.EC2.delete_security_group/3","type":"function"},{"doc":"Deletes the specified snapshot.\n\nWhen you make periodic snapshots of a volume, the snapshots are incremental, and\nonly the blocks on the device that have changed since your last snapshot are\nsaved in the new snapshot. When you delete a snapshot, only the data not needed\nfor any other snapshot is removed. So regardless of which prior snapshots have\nbeen deleted, all active snapshots will have access to all the information\nneeded to restore the volume.\n\nYou cannot delete a snapshot of the root device of an EBS volume used by a\nregistered AMI. You must first de-register the AMI before you can delete the\nsnapshot.\n\nFor more information, see [Delete an Amazon EBS snapshot](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ebs-deleting-snapshot.html)\nin the *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.EC2.html#delete_snapshot/3","title":"AWS.EC2.delete_snapshot/3","type":"function"},{"doc":"Deletes the data feed for Spot Instances.","ref":"AWS.EC2.html#delete_spot_datafeed_subscription/3","title":"AWS.EC2.delete_spot_datafeed_subscription/3","type":"function"},{"doc":"Deletes the specified subnet.\n\nYou must terminate all running instances in the subnet before you can delete the\nsubnet.","ref":"AWS.EC2.html#delete_subnet/3","title":"AWS.EC2.delete_subnet/3","type":"function"},{"doc":"Deletes a subnet CIDR reservation.","ref":"AWS.EC2.html#delete_subnet_cidr_reservation/3","title":"AWS.EC2.delete_subnet_cidr_reservation/3","type":"function"},{"doc":"Deletes the specified set of tags from the specified set of resources.\n\nTo list the current tags, use `DescribeTags`. For more information about tags,\nsee [Tag your Amazon EC2 resources](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Using_Tags.html)\nin the *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.EC2.html#delete_tags/3","title":"AWS.EC2.delete_tags/3","type":"function"},{"doc":"Deletes the specified Traffic Mirror filter.\n\nYou cannot delete a Traffic Mirror filter that is in use by a Traffic Mirror\nsession.","ref":"AWS.EC2.html#delete_traffic_mirror_filter/3","title":"AWS.EC2.delete_traffic_mirror_filter/3","type":"function"},{"doc":"Deletes the specified Traffic Mirror rule.","ref":"AWS.EC2.html#delete_traffic_mirror_filter_rule/3","title":"AWS.EC2.delete_traffic_mirror_filter_rule/3","type":"function"},{"doc":"Deletes the specified Traffic Mirror session.","ref":"AWS.EC2.html#delete_traffic_mirror_session/3","title":"AWS.EC2.delete_traffic_mirror_session/3","type":"function"},{"doc":"Deletes the specified Traffic Mirror target.\n\nYou cannot delete a Traffic Mirror target that is in use by a Traffic Mirror\nsession.","ref":"AWS.EC2.html#delete_traffic_mirror_target/3","title":"AWS.EC2.delete_traffic_mirror_target/3","type":"function"},{"doc":"Deletes the specified transit gateway.","ref":"AWS.EC2.html#delete_transit_gateway/3","title":"AWS.EC2.delete_transit_gateway/3","type":"function"},{"doc":"Deletes the specified Connect attachment.\n\nYou must first delete any Connect peers for the attachment.","ref":"AWS.EC2.html#delete_transit_gateway_connect/3","title":"AWS.EC2.delete_transit_gateway_connect/3","type":"function"},{"doc":"Deletes the specified Connect peer.","ref":"AWS.EC2.html#delete_transit_gateway_connect_peer/3","title":"AWS.EC2.delete_transit_gateway_connect_peer/3","type":"function"},{"doc":"Deletes the specified transit gateway multicast domain.","ref":"AWS.EC2.html#delete_transit_gateway_multicast_domain/3","title":"AWS.EC2.delete_transit_gateway_multicast_domain/3","type":"function"},{"doc":"Deletes a transit gateway peering attachment.","ref":"AWS.EC2.html#delete_transit_gateway_peering_attachment/3","title":"AWS.EC2.delete_transit_gateway_peering_attachment/3","type":"function"},{"doc":"Deletes the specified transit gateway policy table.","ref":"AWS.EC2.html#delete_transit_gateway_policy_table/3","title":"AWS.EC2.delete_transit_gateway_policy_table/3","type":"function"},{"doc":"Deletes a reference (route) to a prefix list in a specified transit gateway\nroute table.","ref":"AWS.EC2.html#delete_transit_gateway_prefix_list_reference/3","title":"AWS.EC2.delete_transit_gateway_prefix_list_reference/3","type":"function"},{"doc":"Deletes the specified route from the specified transit gateway route table.","ref":"AWS.EC2.html#delete_transit_gateway_route/3","title":"AWS.EC2.delete_transit_gateway_route/3","type":"function"},{"doc":"Deletes the specified transit gateway route table.\n\nYou must disassociate the route table from any transit gateway route tables\nbefore you can delete it.","ref":"AWS.EC2.html#delete_transit_gateway_route_table/3","title":"AWS.EC2.delete_transit_gateway_route_table/3","type":"function"},{"doc":"Advertises to the transit gateway that a transit gateway route table is deleted.","ref":"AWS.EC2.html#delete_transit_gateway_route_table_announcement/3","title":"AWS.EC2.delete_transit_gateway_route_table_announcement/3","type":"function"},{"doc":"Deletes the specified VPC attachment.","ref":"AWS.EC2.html#delete_transit_gateway_vpc_attachment/3","title":"AWS.EC2.delete_transit_gateway_vpc_attachment/3","type":"function"},{"doc":"Delete an Amazon Web Services Verified Access endpoint.","ref":"AWS.EC2.html#delete_verified_access_endpoint/3","title":"AWS.EC2.delete_verified_access_endpoint/3","type":"function"},{"doc":"Delete an Amazon Web Services Verified Access group.","ref":"AWS.EC2.html#delete_verified_access_group/3","title":"AWS.EC2.delete_verified_access_group/3","type":"function"},{"doc":"Delete an Amazon Web Services Verified Access instance.","ref":"AWS.EC2.html#delete_verified_access_instance/3","title":"AWS.EC2.delete_verified_access_instance/3","type":"function"},{"doc":"Delete an Amazon Web Services Verified Access trust provider.","ref":"AWS.EC2.html#delete_verified_access_trust_provider/3","title":"AWS.EC2.delete_verified_access_trust_provider/3","type":"function"},{"doc":"Deletes the specified EBS volume.\n\nThe volume must be in the `available` state (not attached to an instance).\n\nThe volume can remain in the `deleting` state for several minutes.\n\nFor more information, see [Delete an Amazon EBS volume](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ebs-deleting-volume.html)\nin the *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.EC2.html#delete_volume/3","title":"AWS.EC2.delete_volume/3","type":"function"},{"doc":"Deletes the specified VPC.\n\nYou must detach or delete all gateways and resources that are associated with\nthe VPC before you can delete it. For example, you must terminate all instances\nrunning in the VPC, delete all security groups associated with the VPC (except\nthe default one), delete all route tables associated with the VPC (except the\ndefault one), and so on. When you delete the VPC, it deletes the VPC's default\nsecurity group, network ACL, and route table.","ref":"AWS.EC2.html#delete_vpc/3","title":"AWS.EC2.delete_vpc/3","type":"function"},{"doc":"Deletes the specified VPC endpoint connection notifications.","ref":"AWS.EC2.html#delete_vpc_endpoint_connection_notifications/3","title":"AWS.EC2.delete_vpc_endpoint_connection_notifications/3","type":"function"},{"doc":"Deletes the specified VPC endpoint service configurations.\n\nBefore you can delete an endpoint service configuration, you must reject any\n`Available` or `PendingAcceptance` interface endpoint connections that are\nattached to the service.","ref":"AWS.EC2.html#delete_vpc_endpoint_service_configurations/3","title":"AWS.EC2.delete_vpc_endpoint_service_configurations/3","type":"function"},{"doc":"Deletes the specified VPC endpoints.\n\nWhen you delete a gateway endpoint, we delete the endpoint routes in the route\ntables for the endpoint.\n\nWhen you delete a Gateway Load Balancer endpoint, we delete its endpoint network\ninterfaces. You can only delete Gateway Load Balancer endpoints when the routes\nthat are associated with the endpoint are deleted.\n\nWhen you delete an interface endpoint, we delete its endpoint network\ninterfaces.","ref":"AWS.EC2.html#delete_vpc_endpoints/3","title":"AWS.EC2.delete_vpc_endpoints/3","type":"function"},{"doc":"Deletes a VPC peering connection.\n\nEither the owner of the requester VPC or the owner of the accepter VPC can\ndelete the VPC peering connection if it's in the `active` state. The owner of\nthe requester VPC can delete a VPC peering connection in the\n`pending-acceptance` state. You cannot delete a VPC peering connection that's in\nthe `failed` or `rejected` state.","ref":"AWS.EC2.html#delete_vpc_peering_connection/3","title":"AWS.EC2.delete_vpc_peering_connection/3","type":"function"},{"doc":"Deletes the specified VPN connection.\n\nIf you're deleting the VPC and its associated components, we recommend that you\ndetach the virtual private gateway from the VPC and delete the VPC before\ndeleting the VPN connection. If you believe that the tunnel credentials for your\nVPN connection have been compromised, you can delete the VPN connection and\ncreate a new one that has new keys, without needing to delete the VPC or virtual\nprivate gateway. If you create a new VPN connection, you must reconfigure the\ncustomer gateway device using the new configuration information returned with\nthe new VPN connection ID.\n\nFor certificate-based authentication, delete all Certificate Manager (ACM)\nprivate certificates used for the Amazon Web Services-side tunnel endpoints for\nthe VPN connection before deleting the VPN connection.","ref":"AWS.EC2.html#delete_vpn_connection/3","title":"AWS.EC2.delete_vpn_connection/3","type":"function"},{"doc":"Deletes the specified static route associated with a VPN connection between an\nexisting virtual private gateway and a VPN customer gateway.\n\nThe static route allows traffic to be routed from the virtual private gateway to\nthe VPN customer gateway.","ref":"AWS.EC2.html#delete_vpn_connection_route/3","title":"AWS.EC2.delete_vpn_connection_route/3","type":"function"},{"doc":"Deletes the specified virtual private gateway.\n\nYou must first detach the virtual private gateway from the VPC. Note that you\ndon't need to delete the virtual private gateway if you plan to delete and\nrecreate the VPN connection between your VPC and your network.","ref":"AWS.EC2.html#delete_vpn_gateway/3","title":"AWS.EC2.delete_vpn_gateway/3","type":"function"},{"doc":"Releases the specified address range that you provisioned for use with your\nAmazon Web Services resources through bring your own IP addresses (BYOIP) and\ndeletes the corresponding address pool.\n\nBefore you can release an address range, you must stop advertising it using\n`WithdrawByoipCidr` and you must not have any IP addresses allocated from its\naddress range.","ref":"AWS.EC2.html#deprovision_byoip_cidr/3","title":"AWS.EC2.deprovision_byoip_cidr/3","type":"function"},{"doc":"Deprovisions your Autonomous System Number (ASN) from your Amazon Web Services\naccount.\n\nThis action can only be called after any BYOIP CIDR associations are removed\nfrom your Amazon Web Services account with\n[DisassociateIpamByoasn](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DisassociateIpamByoasn.html). For more information, see [Tutorial: Bring your ASN to\nIPAM](https://docs.aws.amazon.com/vpc/latest/ipam/tutorials-byoasn.html) in the\n*Amazon VPC IPAM guide*.","ref":"AWS.EC2.html#deprovision_ipam_byoasn/3","title":"AWS.EC2.deprovision_ipam_byoasn/3","type":"function"},{"doc":"Deprovision a CIDR provisioned from an IPAM pool.\n\nIf you deprovision a CIDR from a pool that has a source pool, the CIDR is\nrecycled back into the source pool. For more information, see [Deprovision pool CIDRs](https://docs.aws.amazon.com/vpc/latest/ipam/depro-pool-cidr-ipam.html) in\nthe *Amazon VPC IPAM User Guide*.","ref":"AWS.EC2.html#deprovision_ipam_pool_cidr/3","title":"AWS.EC2.deprovision_ipam_pool_cidr/3","type":"function"},{"doc":"Deprovision a CIDR from a public IPv4 pool.","ref":"AWS.EC2.html#deprovision_public_ipv4_pool_cidr/3","title":"AWS.EC2.deprovision_public_ipv4_pool_cidr/3","type":"function"},{"doc":"Deregisters the specified AMI.\n\nAfter you deregister an AMI, it can't be used to launch new instances.\n\nIf you deregister an AMI that matches a Recycle Bin retention rule, the AMI is\nretained in the Recycle Bin for the specified retention period. For more\ninformation, see [Recycle Bin](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/recycle-bin.html) in\nthe *Amazon EC2 User Guide*.\n\nWhen you deregister an AMI, it doesn't affect any instances that you've already\nlaunched from the AMI. You'll continue to incur usage costs for those instances\nuntil you terminate them.\n\nWhen you deregister an Amazon EBS-backed AMI, it doesn't affect the snapshot\nthat was created for the root volume of the instance during the AMI creation\nprocess. When you deregister an instance store-backed AMI, it doesn't affect the\nfiles that you uploaded to Amazon S3 when you created the AMI.","ref":"AWS.EC2.html#deregister_image/3","title":"AWS.EC2.deregister_image/3","type":"function"},{"doc":"Deregisters tag keys to prevent tags that have the specified tag keys from being\nincluded in scheduled event notifications for resources in the Region.","ref":"AWS.EC2.html#deregister_instance_event_notification_attributes/3","title":"AWS.EC2.deregister_instance_event_notification_attributes/3","type":"function"},{"doc":"Deregisters the specified members (network interfaces) from the transit gateway\nmulticast group.","ref":"AWS.EC2.html#deregister_transit_gateway_multicast_group_members/3","title":"AWS.EC2.deregister_transit_gateway_multicast_group_members/3","type":"function"},{"doc":"Deregisters the specified sources (network interfaces) from the transit gateway\nmulticast group.","ref":"AWS.EC2.html#deregister_transit_gateway_multicast_group_sources/3","title":"AWS.EC2.deregister_transit_gateway_multicast_group_sources/3","type":"function"},{"doc":"Describes attributes of your Amazon Web Services account.\n\nThe following are the supported account attributes:\n\n  * `default-vpc`: The ID of the default VPC for your account, or\n`none`.\n\n  * `max-instances`: This attribute is no longer supported. The\nreturned value does not reflect your actual vCPU limit for running On-Demand\nInstances. For more information, see [On-Demand Instance Limits](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-on-demand-instances.html#ec2-on-demand-instances-limits)\nin the *Amazon Elastic Compute Cloud User Guide*.\n\n  * `max-elastic-ips`: The maximum number of Elastic IP addresses that\nyou can allocate.\n\n  * `supported-platforms`: This attribute is deprecated.\n\n  * `vpc-max-elastic-ips`: The maximum number of Elastic IP addresses\nthat you can allocate.\n\n  * `vpc-max-security-groups-per-interface`: The maximum number of\nsecurity groups that you can assign to a network interface.","ref":"AWS.EC2.html#describe_account_attributes/3","title":"AWS.EC2.describe_account_attributes/3","type":"function"},{"doc":"Describes an Elastic IP address transfer.\n\nFor more information, see [Transfer Elastic IP addresses](https://docs.aws.amazon.com/vpc/latest/userguide/vpc-eips.html#transfer-EIPs-intro)\nin the *Amazon Virtual Private Cloud User Guide*.\n\nWhen you transfer an Elastic IP address, there is a two-step handshake between\nthe source and transfer Amazon Web Services accounts. When the source account\nstarts the transfer, the transfer account has seven days to accept the Elastic\nIP address transfer. During those seven days, the source account can view the\npending transfer by using this action. After seven days, the transfer expires\nand ownership of the Elastic IP address returns to the source account. Accepted\ntransfers are visible to the source account for three days after the transfers\nhave been accepted.","ref":"AWS.EC2.html#describe_address_transfers/3","title":"AWS.EC2.describe_address_transfers/3","type":"function"},{"doc":"Describes the specified Elastic IP addresses or all of your Elastic IP\naddresses.","ref":"AWS.EC2.html#describe_addresses/3","title":"AWS.EC2.describe_addresses/3","type":"function"},{"doc":"Describes the attributes of the specified Elastic IP addresses.\n\nFor requirements, see [Using reverse DNS for email applications](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/elastic-ip-addresses-eip.html#Using_Elastic_Addressing_Reverse_DNS).","ref":"AWS.EC2.html#describe_addresses_attribute/3","title":"AWS.EC2.describe_addresses_attribute/3","type":"function"},{"doc":"Describes the longer ID format settings for all resource types in a specific\nRegion.\n\nThis request is useful for performing a quick audit to determine whether a\nspecific Region is fully opted in for longer IDs (17-character IDs).\n\nThis request only returns information about resource types that support longer\nIDs.\n\nThe following resource types support longer IDs: `bundle` | `conversion-task` |\n`customer-gateway` | `dhcp-options` | `elastic-ip-allocation` |\n`elastic-ip-association` | `export-task` | `flow-log` | `image` | `import-task`\n| `instance` | `internet-gateway` | `network-acl` | `network-acl-association` |\n`network-interface` | `network-interface-attachment` | `prefix-list` |\n`reservation` | `route-table` | `route-table-association` | `security-group` |\n`snapshot` | `subnet` | `subnet-cidr-block-association` | `volume` | `vpc` |\n`vpc-cidr-block-association` | `vpc-endpoint` | `vpc-peering-connection` |\n`vpn-connection` | `vpn-gateway`.","ref":"AWS.EC2.html#describe_aggregate_id_format/3","title":"AWS.EC2.describe_aggregate_id_format/3","type":"function"},{"doc":"Describes the Availability Zones, Local Zones, and Wavelength Zones that are\navailable to you.\n\nIf there is an event impacting a zone, you can use this request to view the\nstate and any provided messages for that zone.\n\nFor more information about Availability Zones, Local Zones, and Wavelength\nZones, see [Regions and zones](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/using-regions-availability-zones.html)\nin the *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.EC2.html#describe_availability_zones/3","title":"AWS.EC2.describe_availability_zones/3","type":"function"},{"doc":"Describes the current Infrastructure Performance metric subscriptions.","ref":"AWS.EC2.html#describe_aws_network_performance_metric_subscriptions/3","title":"AWS.EC2.describe_aws_network_performance_metric_subscriptions/3","type":"function"},{"doc":"Describes the specified bundle tasks or all of your bundle tasks.\n\nCompleted bundle tasks are listed for only a limited time. If your bundle task\nis no longer in the list, you can still register an AMI from it. Just use\n`RegisterImage` with the Amazon S3 bucket name and image manifest name you\nprovided to the bundle task.","ref":"AWS.EC2.html#describe_bundle_tasks/3","title":"AWS.EC2.describe_bundle_tasks/3","type":"function"},{"doc":"Describes the IP address ranges that were specified in calls to\n`ProvisionByoipCidr`.\n\nTo describe the address pools that were created when you provisioned the address\nranges, use `DescribePublicIpv4Pools` or `DescribeIpv6Pools`.","ref":"AWS.EC2.html#describe_byoip_cidrs/3","title":"AWS.EC2.describe_byoip_cidrs/3","type":"function"},{"doc":"Describes Capacity Block offerings available for purchase.\n\nWith Capacity Blocks, you purchase a specific instance type for a period of\ntime.","ref":"AWS.EC2.html#describe_capacity_block_offerings/3","title":"AWS.EC2.describe_capacity_block_offerings/3","type":"function"},{"doc":"Describes one or more Capacity Reservation Fleets.","ref":"AWS.EC2.html#describe_capacity_reservation_fleets/3","title":"AWS.EC2.describe_capacity_reservation_fleets/3","type":"function"},{"doc":"Describes one or more of your Capacity Reservations.\n\nThe results describe only the Capacity Reservations in the Amazon Web Services\nRegion that you're currently using.","ref":"AWS.EC2.html#describe_capacity_reservations/3","title":"AWS.EC2.describe_capacity_reservations/3","type":"function"},{"doc":"Describes one or more of your carrier gateways.","ref":"AWS.EC2.html#describe_carrier_gateways/3","title":"AWS.EC2.describe_carrier_gateways/3","type":"function"},{"doc":"This action is deprecated.\n\nDescribes one or more of your linked EC2-Classic instances. This request only\nreturns information about EC2-Classic instances linked to a VPC through\nClassicLink. You cannot use this request to return information about other\ninstances.","ref":"AWS.EC2.html#describe_classic_link_instances/3","title":"AWS.EC2.describe_classic_link_instances/3","type":"function"},{"doc":"Describes the authorization rules for a specified Client VPN endpoint.","ref":"AWS.EC2.html#describe_client_vpn_authorization_rules/3","title":"AWS.EC2.describe_client_vpn_authorization_rules/3","type":"function"},{"doc":"Describes active client connections and connections that have been terminated\nwithin the last 60 minutes for the specified Client VPN endpoint.","ref":"AWS.EC2.html#describe_client_vpn_connections/3","title":"AWS.EC2.describe_client_vpn_connections/3","type":"function"},{"doc":"Describes one or more Client VPN endpoints in the account.","ref":"AWS.EC2.html#describe_client_vpn_endpoints/3","title":"AWS.EC2.describe_client_vpn_endpoints/3","type":"function"},{"doc":"Describes the routes for the specified Client VPN endpoint.","ref":"AWS.EC2.html#describe_client_vpn_routes/3","title":"AWS.EC2.describe_client_vpn_routes/3","type":"function"},{"doc":"Describes the target networks associated with the specified Client VPN endpoint.","ref":"AWS.EC2.html#describe_client_vpn_target_networks/3","title":"AWS.EC2.describe_client_vpn_target_networks/3","type":"function"},{"doc":"Describes the specified customer-owned address pools or all of your\ncustomer-owned address pools.","ref":"AWS.EC2.html#describe_coip_pools/3","title":"AWS.EC2.describe_coip_pools/3","type":"function"},{"doc":"Describes the specified conversion tasks or all your conversion tasks.\n\nFor more information, see the [VM Import/Export User Guide](https://docs.aws.amazon.com/vm-import/latest/userguide/).\n\nFor information about the import manifest referenced by this API action, see [VM Import\nManifest](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/manifest.html).","ref":"AWS.EC2.html#describe_conversion_tasks/3","title":"AWS.EC2.describe_conversion_tasks/3","type":"function"},{"doc":"Describes one or more of your VPN customer gateways.\n\nFor more information, see [Amazon Web Services Site-to-Site VPN](https://docs.aws.amazon.com/vpn/latest/s2svpn/VPC_VPN.html) in the *Amazon\nWeb Services Site-to-Site VPN User Guide*.","ref":"AWS.EC2.html#describe_customer_gateways/3","title":"AWS.EC2.describe_customer_gateways/3","type":"function"},{"doc":"Describes one or more of your DHCP options sets.\n\nFor more information, see [DHCP options sets](https://docs.aws.amazon.com/vpc/latest/userguide/VPC_DHCP_Options.html) in\nthe *Amazon VPC User Guide*.","ref":"AWS.EC2.html#describe_dhcp_options/3","title":"AWS.EC2.describe_dhcp_options/3","type":"function"},{"doc":"Describes one or more of your egress-only internet gateways.","ref":"AWS.EC2.html#describe_egress_only_internet_gateways/3","title":"AWS.EC2.describe_egress_only_internet_gateways/3","type":"function"},{"doc":"Amazon Elastic Graphics reached end of life on January 8, 2024.\n\nFor workloads that require graphics acceleration, we recommend that you use\nAmazon EC2 G4ad, G4dn, or G5 instances.\n\nDescribes the Elastic Graphics accelerator associated with your instances. For\nmore information about Elastic Graphics, see [Amazon Elastic Graphics](https://docs.aws.amazon.com/AWSEC2/latest/WindowsGuide/elastic-graphics.html).","ref":"AWS.EC2.html#describe_elastic_gpus/3","title":"AWS.EC2.describe_elastic_gpus/3","type":"function"},{"doc":"Describes the specified export image tasks or all of your export image tasks.","ref":"AWS.EC2.html#describe_export_image_tasks/3","title":"AWS.EC2.describe_export_image_tasks/3","type":"function"},{"doc":"Describes the specified export instance tasks or all of your export instance\ntasks.","ref":"AWS.EC2.html#describe_export_tasks/3","title":"AWS.EC2.describe_export_tasks/3","type":"function"},{"doc":"Describe details for Windows AMIs that are configured for Windows fast launch.","ref":"AWS.EC2.html#describe_fast_launch_images/3","title":"AWS.EC2.describe_fast_launch_images/3","type":"function"},{"doc":"Describes the state of fast snapshot restores for your snapshots.","ref":"AWS.EC2.html#describe_fast_snapshot_restores/3","title":"AWS.EC2.describe_fast_snapshot_restores/3","type":"function"},{"doc":"Describes the events for the specified EC2 Fleet during the specified time.\n\nEC2 Fleet events are delayed by up to 30 seconds before they can be described.\nThis ensures that you can query by the last evaluated time and not miss a\nrecorded event. EC2 Fleet events are available for 48 hours.\n\nFor more information, see [Monitor fleet events using Amazon EventBridge](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/fleet-monitor.html)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#describe_fleet_history/3","title":"AWS.EC2.describe_fleet_history/3","type":"function"},{"doc":"Describes the running instances for the specified EC2 Fleet.\n\nFor more information, see [Monitor your EC2 Fleet](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/manage-ec2-fleet.html#monitor-ec2-fleet)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#describe_fleet_instances/3","title":"AWS.EC2.describe_fleet_instances/3","type":"function"},{"doc":"Describes the specified EC2 Fleets or all of your EC2 Fleets.\n\nFor more information, see [Monitor your EC2 Fleet](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/manage-ec2-fleet.html#monitor-ec2-fleet)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#describe_fleets/3","title":"AWS.EC2.describe_fleets/3","type":"function"},{"doc":"Describes one or more flow logs.\n\nTo view the published flow log records, you must view the log destination. For\nexample, the CloudWatch Logs log group, the Amazon S3 bucket, or the Kinesis\nData Firehose delivery stream.","ref":"AWS.EC2.html#describe_flow_logs/3","title":"AWS.EC2.describe_flow_logs/3","type":"function"},{"doc":"Describes the specified attribute of the specified Amazon FPGA Image (AFI).","ref":"AWS.EC2.html#describe_fpga_image_attribute/3","title":"AWS.EC2.describe_fpga_image_attribute/3","type":"function"},{"doc":"Describes the Amazon FPGA Images (AFIs) available to you.\n\nThese include public AFIs, private AFIs that you own, and AFIs owned by other\nAmazon Web Services accounts for which you have load permissions.","ref":"AWS.EC2.html#describe_fpga_images/3","title":"AWS.EC2.describe_fpga_images/3","type":"function"},{"doc":"Describes the Dedicated Host reservations that are available to purchase.\n\nThe results describe all of the Dedicated Host reservation offerings, including\nofferings that might not match the instance family and Region of your Dedicated\nHosts. When purchasing an offering, ensure that the instance family and Region\nof the offering matches that of the Dedicated Hosts with which it is to be\nassociated. For more information about supported instance types, see [Dedicated Hosts](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/dedicated-hosts-overview.html)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#describe_host_reservation_offerings/3","title":"AWS.EC2.describe_host_reservation_offerings/3","type":"function"},{"doc":"Describes reservations that are associated with Dedicated Hosts in your account.","ref":"AWS.EC2.html#describe_host_reservations/3","title":"AWS.EC2.describe_host_reservations/3","type":"function"},{"doc":"Describes the specified Dedicated Hosts or all your Dedicated Hosts.\n\nThe results describe only the Dedicated Hosts in the Region you're currently\nusing. All listed instances consume capacity on your Dedicated Host. Dedicated\nHosts that have recently been released are listed with the state `released`.","ref":"AWS.EC2.html#describe_hosts/3","title":"AWS.EC2.describe_hosts/3","type":"function"},{"doc":"Describes your IAM instance profile associations.","ref":"AWS.EC2.html#describe_iam_instance_profile_associations/3","title":"AWS.EC2.describe_iam_instance_profile_associations/3","type":"function"},{"doc":"Describes the ID format settings for your resources on a per-Region basis, for\nexample, to view which resource types are enabled for longer IDs.\n\nThis request only returns information about resource types whose ID formats can\nbe modified; it does not return information about other resource types.\n\nThe following resource types support longer IDs: `bundle` | `conversion-task` |\n`customer-gateway` | `dhcp-options` | `elastic-ip-allocation` |\n`elastic-ip-association` | `export-task` | `flow-log` | `image` | `import-task`\n| `instance` | `internet-gateway` | `network-acl` | `network-acl-association` |\n`network-interface` | `network-interface-attachment` | `prefix-list` |\n`reservation` | `route-table` | `route-table-association` | `security-group` |\n`snapshot` | `subnet` | `subnet-cidr-block-association` | `volume` | `vpc` |\n`vpc-cidr-block-association` | `vpc-endpoint` | `vpc-peering-connection` |\n`vpn-connection` | `vpn-gateway`.\n\nThese settings apply to the IAM user who makes the request; they do not apply to\nthe entire Amazon Web Services account. By default, an IAM user defaults to the\nsame settings as the root user, unless they explicitly override the settings by\nrunning the `ModifyIdFormat` command. Resources created with longer IDs are\nvisible to all IAM users, regardless of these settings and provided that they\nhave permission to use the relevant `Describe` command for the resource type.","ref":"AWS.EC2.html#describe_id_format/3","title":"AWS.EC2.describe_id_format/3","type":"function"},{"doc":"Describes the ID format settings for resources for the specified IAM user, IAM\nrole, or root user.\n\nFor example, you can view the resource types that are enabled for longer IDs.\nThis request only returns information about resource types whose ID formats can\nbe modified; it does not return information about other resource types. For more\ninformation, see [Resource IDs](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/resource-ids.html) in\nthe *Amazon Elastic Compute Cloud User Guide*.\n\nThe following resource types support longer IDs: `bundle` | `conversion-task` |\n`customer-gateway` | `dhcp-options` | `elastic-ip-allocation` |\n`elastic-ip-association` | `export-task` | `flow-log` | `image` | `import-task`\n| `instance` | `internet-gateway` | `network-acl` | `network-acl-association` |\n`network-interface` | `network-interface-attachment` | `prefix-list` |\n`reservation` | `route-table` | `route-table-association` | `security-group` |\n`snapshot` | `subnet` | `subnet-cidr-block-association` | `volume` | `vpc` |\n`vpc-cidr-block-association` | `vpc-endpoint` | `vpc-peering-connection` |\n`vpn-connection` | `vpn-gateway`.\n\nThese settings apply to the principal specified in the request. They do not\napply to the principal that makes the request.","ref":"AWS.EC2.html#describe_identity_id_format/3","title":"AWS.EC2.describe_identity_id_format/3","type":"function"},{"doc":"Describes the specified attribute of the specified AMI.\n\nYou can specify only one attribute at a time.","ref":"AWS.EC2.html#describe_image_attribute/3","title":"AWS.EC2.describe_image_attribute/3","type":"function"},{"doc":"Describes the specified images (AMIs, AKIs, and ARIs) available to you or all of\nthe images available to you.\n\nThe images available to you include public images, private images that you own,\nand private images owned by other Amazon Web Services accounts for which you\nhave explicit launch permissions.\n\nRecently deregistered images appear in the returned results for a short interval\nand then return empty results. After all instances that reference a deregistered\nAMI are terminated, specifying the ID of the image will eventually return an\nerror indicating that the AMI ID cannot be found.","ref":"AWS.EC2.html#describe_images/3","title":"AWS.EC2.describe_images/3","type":"function"},{"doc":"Displays details about an import virtual machine or import snapshot tasks that\nare already created.","ref":"AWS.EC2.html#describe_import_image_tasks/3","title":"AWS.EC2.describe_import_image_tasks/3","type":"function"},{"doc":"Describes your import snapshot tasks.","ref":"AWS.EC2.html#describe_import_snapshot_tasks/3","title":"AWS.EC2.describe_import_snapshot_tasks/3","type":"function"},{"doc":"Describes the specified attribute of the specified instance.\n\nYou can specify only one attribute at a time. Valid attribute values are:\n`instanceType` | `kernel` | `ramdisk` | `userData` | `disableApiTermination` |\n`instanceInitiatedShutdownBehavior` | `rootDeviceName` | `blockDeviceMapping` |\n`productCodes` | `sourceDestCheck` | `groupSet` | `ebsOptimized` |\n`sriovNetSupport`","ref":"AWS.EC2.html#describe_instance_attribute/3","title":"AWS.EC2.describe_instance_attribute/3","type":"function"},{"doc":"Describes the specified EC2 Instance Connect Endpoints or all EC2 Instance\nConnect Endpoints.","ref":"AWS.EC2.html#describe_instance_connect_endpoints/3","title":"AWS.EC2.describe_instance_connect_endpoints/3","type":"function"},{"doc":"Describes the credit option for CPU usage of the specified burstable performance\ninstances.\n\nThe credit options are `standard` and `unlimited`.\n\nIf you do not specify an instance ID, Amazon EC2 returns burstable performance\ninstances with the `unlimited` credit option, as well as instances that were\npreviously configured as T2, T3, and T3a with the `unlimited` credit option. For\nexample, if you resize a T2 instance, while it is configured as `unlimited`, to\nan M4 instance, Amazon EC2 returns the M4 instance.\n\nIf you specify one or more instance IDs, Amazon EC2 returns the credit option\n(`standard` or `unlimited`) of those instances. If you specify an instance ID\nthat is not valid, such as an instance that is not a burstable performance\ninstance, an error is returned.\n\nRecently terminated instances might appear in the returned results. This\ninterval is usually less than one hour.\n\nIf an Availability Zone is experiencing a service disruption and you specify\ninstance IDs in the affected zone, or do not specify any instance IDs at all,\nthe call fails. If you specify only instance IDs in an unaffected zone, the call\nworks normally.\n\nFor more information, see [Burstable performance instances](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/burstable-performance-instances.html)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#describe_instance_credit_specifications/3","title":"AWS.EC2.describe_instance_credit_specifications/3","type":"function"},{"doc":"Describes the tag keys that are registered to appear in scheduled event\nnotifications for resources in the current Region.","ref":"AWS.EC2.html#describe_instance_event_notification_attributes/3","title":"AWS.EC2.describe_instance_event_notification_attributes/3","type":"function"},{"doc":"Describes the specified event windows or all event windows.\n\nIf you specify event window IDs, the output includes information for only the\nspecified event windows. If you specify filters, the output includes information\nfor only those event windows that meet the filter criteria. If you do not\nspecify event windows IDs or filters, the output includes information for all\nevent windows, which can affect performance. We recommend that you use\npagination to ensure that the operation returns quickly and successfully.\n\nFor more information, see [Define event windows for scheduled events](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/event-windows.html)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#describe_instance_event_windows/3","title":"AWS.EC2.describe_instance_event_windows/3","type":"function"},{"doc":"Describes the status of the specified instances or all of your instances.\n\nBy default, only running instances are described, unless you specifically\nindicate to return the status of all instances.\n\nInstance status includes the following components:\n\n  * **Status checks** - Amazon EC2 performs status checks on running\nEC2 instances to identify hardware and software issues. For more information,\nsee [Status checks for your instances](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/monitoring-system-instance-status-check.html)\nand [Troubleshoot instances with failed status checks](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/TroubleshootingInstances.html)\nin the *Amazon EC2 User Guide*.\n\n  * **Scheduled events** - Amazon EC2 can schedule events (such as\nreboot, stop, or terminate) for your instances related to hardware issues,\nsoftware updates, or system maintenance. For more information, see [Scheduled events for your\ninstances](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/monitoring-instances-status-check_sched.html)\nin the *Amazon EC2 User Guide*.\n\n  * **Instance state** - You can manage your instances from the moment\nyou launch them through their termination. For more information, see [Instance lifecycle](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-instance-lifecycle.html)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#describe_instance_status/3","title":"AWS.EC2.describe_instance_status/3","type":"function"},{"doc":"Describes a tree-based hierarchy that represents the physical host placement of\nyour EC2 instances within an Availability Zone or Local Zone.\n\nYou can use this information to determine the relative proximity of your EC2\ninstances within the Amazon Web Services network to support your tightly coupled\nworkloads.","ref":"AWS.EC2.html#describe_instance_topology/3","title":"AWS.EC2.describe_instance_topology/3","type":"function"},{"doc":"* Supported zones\n\n    * Availability Zone\n\n    * Local Zone\n\n  * Supported instance types\n\n    * `hpc6a.48xlarge` | `hpc6id.32xlarge` |\n`hpc7a.12xlarge` | `hpc7a.24xlarge` | `hpc7a.48xlarge` | `hpc7a.96xlarge` |\n`hpc7g.4xlarge` | `hpc7g.8xlarge` | `hpc7g.16xlarge`\n\n    * `p3dn.24xlarge` | `p4d.24xlarge` | `p4de.24xlarge` |\n`p5.48xlarge`\n\n    * `trn1.2xlarge` | `trn1.32xlarge` | `trn1n.32xlarge`\n\nFor more information, see [Amazon EC2 instance topology](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-instance-topology.html)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#describe_instance_topology/3-limitations","title":"Limitations - AWS.EC2.describe_instance_topology/3","type":"function"},{"doc":"Returns a list of all instance types offered.\n\nThe results can be filtered by location (Region or Availability Zone). If no\nlocation is specified, the instance types offered in the current Region are\nreturned.","ref":"AWS.EC2.html#describe_instance_type_offerings/3","title":"AWS.EC2.describe_instance_type_offerings/3","type":"function"},{"doc":"Describes the details of the instance types that are offered in a location.\n\nThe results can be filtered by the attributes of the instance types.","ref":"AWS.EC2.html#describe_instance_types/3","title":"AWS.EC2.describe_instance_types/3","type":"function"},{"doc":"Describes the specified instances or all instances.\n\nIf you specify instance IDs, the output includes information for only the\nspecified instances. If you specify filters, the output includes information for\nonly those instances that meet the filter criteria. If you do not specify\ninstance IDs or filters, the output includes information for all instances,\nwhich can affect performance. We recommend that you use pagination to ensure\nthat the operation returns quickly and successfully.\n\nIf you specify an instance ID that is not valid, an error is returned. If you\nspecify an instance that you do not own, it is not included in the output.\n\nRecently terminated instances might appear in the returned results. This\ninterval is usually less than one hour.\n\nIf you describe instances in the rare case where an Availability Zone is\nexperiencing a service disruption and you specify instance IDs that are in the\naffected zone, or do not specify any instance IDs at all, the call fails. If you\ndescribe instances and specify only instance IDs that are in an unaffected zone,\nthe call works normally.","ref":"AWS.EC2.html#describe_instances/3","title":"AWS.EC2.describe_instances/3","type":"function"},{"doc":"Describes one or more of your internet gateways.","ref":"AWS.EC2.html#describe_internet_gateways/3","title":"AWS.EC2.describe_internet_gateways/3","type":"function"},{"doc":"Describes your Autonomous System Numbers (ASNs), their provisioning statuses,\nand the BYOIP CIDRs with which they are associated.\n\nFor more information, see [Tutorial: Bring your ASN to IPAM](https://docs.aws.amazon.com/vpc/latest/ipam/tutorials-byoasn.html) in the\n*Amazon VPC IPAM guide*.","ref":"AWS.EC2.html#describe_ipam_byoasn/3","title":"AWS.EC2.describe_ipam_byoasn/3","type":"function"},{"doc":"Get information about your IPAM pools.","ref":"AWS.EC2.html#describe_ipam_pools/3","title":"AWS.EC2.describe_ipam_pools/3","type":"function"},{"doc":"Describes IPAM resource discoveries.\n\nA resource discovery is an IPAM component that enables IPAM to manage and\nmonitor resources that belong to the owning account.","ref":"AWS.EC2.html#describe_ipam_resource_discoveries/3","title":"AWS.EC2.describe_ipam_resource_discoveries/3","type":"function"},{"doc":"Describes resource discovery association with an Amazon VPC IPAM.\n\nAn associated resource discovery is a resource discovery that has been\nassociated with an IPAM..","ref":"AWS.EC2.html#describe_ipam_resource_discovery_associations/3","title":"AWS.EC2.describe_ipam_resource_discovery_associations/3","type":"function"},{"doc":"Get information about your IPAM scopes.","ref":"AWS.EC2.html#describe_ipam_scopes/3","title":"AWS.EC2.describe_ipam_scopes/3","type":"function"},{"doc":"Get information about your IPAM pools.\n\nFor more information, see [What is IPAM?](https://docs.aws.amazon.com/vpc/latest/ipam/what-is-it-ipam.html) in the\n*Amazon VPC IPAM User Guide*.","ref":"AWS.EC2.html#describe_ipams/3","title":"AWS.EC2.describe_ipams/3","type":"function"},{"doc":"Describes your IPv6 address pools.","ref":"AWS.EC2.html#describe_ipv6_pools/3","title":"AWS.EC2.describe_ipv6_pools/3","type":"function"},{"doc":"Describes the specified key pairs or all of your key pairs.\n\nFor more information about key pairs, see [Amazon EC2 key pairs](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-key-pairs.html)\nin the *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.EC2.html#describe_key_pairs/3","title":"AWS.EC2.describe_key_pairs/3","type":"function"},{"doc":"Describes one or more versions of a specified launch template.\n\nYou can describe all versions, individual versions, or a range of versions. You\ncan also describe all the latest versions or all the default versions of all the\nlaunch templates in your account.","ref":"AWS.EC2.html#describe_launch_template_versions/3","title":"AWS.EC2.describe_launch_template_versions/3","type":"function"},{"doc":"Describes one or more launch templates.","ref":"AWS.EC2.html#describe_launch_templates/3","title":"AWS.EC2.describe_launch_templates/3","type":"function"},{"doc":"Describes the associations between virtual interface groups and local gateway\nroute tables.","ref":"AWS.EC2.html#describe_local_gateway_route_table_virtual_interface_group_associations/3","title":"AWS.EC2.describe_local_gateway_route_table_virtual_interface_group_associations/3","type":"function"},{"doc":"Describes the specified associations between VPCs and local gateway route\ntables.","ref":"AWS.EC2.html#describe_local_gateway_route_table_vpc_associations/3","title":"AWS.EC2.describe_local_gateway_route_table_vpc_associations/3","type":"function"},{"doc":"Describes one or more local gateway route tables.\n\nBy default, all local gateway route tables are described. Alternatively, you can\nfilter the results.","ref":"AWS.EC2.html#describe_local_gateway_route_tables/3","title":"AWS.EC2.describe_local_gateway_route_tables/3","type":"function"},{"doc":"Describes the specified local gateway virtual interface groups.","ref":"AWS.EC2.html#describe_local_gateway_virtual_interface_groups/3","title":"AWS.EC2.describe_local_gateway_virtual_interface_groups/3","type":"function"},{"doc":"Describes the specified local gateway virtual interfaces.","ref":"AWS.EC2.html#describe_local_gateway_virtual_interfaces/3","title":"AWS.EC2.describe_local_gateway_virtual_interfaces/3","type":"function"},{"doc":"Describes one or more local gateways.\n\nBy default, all local gateways are described. Alternatively, you can filter the\nresults.","ref":"AWS.EC2.html#describe_local_gateways/3","title":"AWS.EC2.describe_local_gateways/3","type":"function"},{"doc":"Describes the lock status for a snapshot.","ref":"AWS.EC2.html#describe_locked_snapshots/3","title":"AWS.EC2.describe_locked_snapshots/3","type":"function"},{"doc":"Describes your managed prefix lists and any Amazon Web Services-managed prefix\nlists.\n\nTo view the entries for your prefix list, use `GetManagedPrefixListEntries`.","ref":"AWS.EC2.html#describe_managed_prefix_lists/3","title":"AWS.EC2.describe_managed_prefix_lists/3","type":"function"},{"doc":"This action is deprecated.\n\nDescribes your Elastic IP addresses that are being moved from or being restored\nto the EC2-Classic platform. This request does not return information about any\nother Elastic IP addresses in your account.","ref":"AWS.EC2.html#describe_moving_addresses/3","title":"AWS.EC2.describe_moving_addresses/3","type":"function"},{"doc":"Describes one or more of your NAT gateways.","ref":"AWS.EC2.html#describe_nat_gateways/3","title":"AWS.EC2.describe_nat_gateways/3","type":"function"},{"doc":"Describes one or more of your network ACLs.\n\nFor more information, see [Network ACLs](https://docs.aws.amazon.com/vpc/latest/userguide/vpc-network-acls.html) in\nthe *Amazon VPC User Guide*.","ref":"AWS.EC2.html#describe_network_acls/3","title":"AWS.EC2.describe_network_acls/3","type":"function"},{"doc":"Describes the specified Network Access Scope analyses.","ref":"AWS.EC2.html#describe_network_insights_access_scope_analyses/3","title":"AWS.EC2.describe_network_insights_access_scope_analyses/3","type":"function"},{"doc":"Describes the specified Network Access Scopes.","ref":"AWS.EC2.html#describe_network_insights_access_scopes/3","title":"AWS.EC2.describe_network_insights_access_scopes/3","type":"function"},{"doc":"Describes one or more of your network insights analyses.","ref":"AWS.EC2.html#describe_network_insights_analyses/3","title":"AWS.EC2.describe_network_insights_analyses/3","type":"function"},{"doc":"Describes one or more of your paths.","ref":"AWS.EC2.html#describe_network_insights_paths/3","title":"AWS.EC2.describe_network_insights_paths/3","type":"function"},{"doc":"Describes a network interface attribute.\n\nYou can specify only one attribute at a time.","ref":"AWS.EC2.html#describe_network_interface_attribute/3","title":"AWS.EC2.describe_network_interface_attribute/3","type":"function"},{"doc":"Describes the permissions for your network interfaces.","ref":"AWS.EC2.html#describe_network_interface_permissions/3","title":"AWS.EC2.describe_network_interface_permissions/3","type":"function"},{"doc":"Describes one or more of your network interfaces.\n\nIf you have a large number of network interfaces, the operation fails unless you\nuse pagination or one of the following filters: `group-id`, `mac-address`,\n`private-dns-name`, `private-ip-address`, `private-dns-name`, `subnet-id`, or\n`vpc-id`.","ref":"AWS.EC2.html#describe_network_interfaces/3","title":"AWS.EC2.describe_network_interfaces/3","type":"function"},{"doc":"Describes the specified placement groups or all of your placement groups.\n\nFor more information, see [Placement groups](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/placement-groups.html)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#describe_placement_groups/3","title":"AWS.EC2.describe_placement_groups/3","type":"function"},{"doc":"Describes available Amazon Web Services services in a prefix list format, which\nincludes the prefix list name and prefix list ID of the service and the IP\naddress range for the service.\n\nWe recommend that you use `DescribeManagedPrefixLists` instead.","ref":"AWS.EC2.html#describe_prefix_lists/3","title":"AWS.EC2.describe_prefix_lists/3","type":"function"},{"doc":"Describes the ID format settings for the root user and all IAM roles and IAM\nusers that have explicitly specified a longer ID (17-character ID) preference.\n\nBy default, all IAM roles and IAM users default to the same ID settings as the\nroot user, unless they explicitly override the settings. This request is useful\nfor identifying those IAM users and IAM roles that have overridden the default\nID settings.\n\nThe following resource types support longer IDs: `bundle` | `conversion-task` |\n`customer-gateway` | `dhcp-options` | `elastic-ip-allocation` |\n`elastic-ip-association` | `export-task` | `flow-log` | `image` | `import-task`\n| `instance` | `internet-gateway` | `network-acl` | `network-acl-association` |\n`network-interface` | `network-interface-attachment` | `prefix-list` |\n`reservation` | `route-table` | `route-table-association` | `security-group` |\n`snapshot` | `subnet` | `subnet-cidr-block-association` | `volume` | `vpc` |\n`vpc-cidr-block-association` | `vpc-endpoint` | `vpc-peering-connection` |\n`vpn-connection` | `vpn-gateway`.","ref":"AWS.EC2.html#describe_principal_id_format/3","title":"AWS.EC2.describe_principal_id_format/3","type":"function"},{"doc":"Describes the specified IPv4 address pools.","ref":"AWS.EC2.html#describe_public_ipv4_pools/3","title":"AWS.EC2.describe_public_ipv4_pools/3","type":"function"},{"doc":"Describes the Regions that are enabled for your account, or all Regions.\n\nFor a list of the Regions supported by Amazon EC2, see [ Amazon Elastic Compute Cloud endpoints and\nquotas](https://docs.aws.amazon.com/general/latest/gr/ec2-service.html).\n\nFor information about enabling and disabling Regions for your account, see\n[Managing Amazon Web Services Regions](https://docs.aws.amazon.com/general/latest/gr/rande-manage.html) in the\n*Amazon Web Services General Reference*.","ref":"AWS.EC2.html#describe_regions/3","title":"AWS.EC2.describe_regions/3","type":"function"},{"doc":"Describes a root volume replacement task.\n\nFor more information, see [Replace a root volume](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/replace-root.html)\nin the *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.EC2.html#describe_replace_root_volume_tasks/3","title":"AWS.EC2.describe_replace_root_volume_tasks/3","type":"function"},{"doc":"Describes one or more of the Reserved Instances that you purchased.\n\nFor more information about Reserved Instances, see [Reserved Instances](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/concepts-on-demand-reserved-instances.html)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#describe_reserved_instances/3","title":"AWS.EC2.describe_reserved_instances/3","type":"function"},{"doc":"Describes your account's Reserved Instance listings in the Reserved Instance\nMarketplace.\n\nThe Reserved Instance Marketplace matches sellers who want to resell Reserved\nInstance capacity that they no longer need with buyers who want to purchase\nadditional capacity. Reserved Instances bought and sold through the Reserved\nInstance Marketplace work like any other Reserved Instances.\n\nAs a seller, you choose to list some or all of your Reserved Instances, and you\nspecify the upfront price to receive for them. Your Reserved Instances are then\nlisted in the Reserved Instance Marketplace and are available for purchase.\n\nAs a buyer, you specify the configuration of the Reserved Instance to purchase,\nand the Marketplace matches what you're searching for with what's available. The\nMarketplace first sells the lowest priced Reserved Instances to you, and\ncontinues to sell available Reserved Instance listings to you until your demand\nis met. You are charged based on the total price of all of the listings that you\npurchase.\n\nFor more information, see [Reserved Instance Marketplace](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ri-market-general.html)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#describe_reserved_instances_listings/3","title":"AWS.EC2.describe_reserved_instances_listings/3","type":"function"},{"doc":"Describes the modifications made to your Reserved Instances.\n\nIf no parameter is specified, information about all your Reserved Instances\nmodification requests is returned. If a modification ID is specified, only\ninformation about the specific modification is returned.\n\nFor more information, see [Modifying Reserved Instances](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ri-modifying.html)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#describe_reserved_instances_modifications/3","title":"AWS.EC2.describe_reserved_instances_modifications/3","type":"function"},{"doc":"Describes Reserved Instance offerings that are available for purchase.\n\nWith Reserved Instances, you purchase the right to launch instances for a period\nof time. During that time period, you do not receive insufficient capacity\nerrors, and you pay a lower usage rate than the rate charged for On-Demand\ninstances for the actual time used.\n\nIf you have listed your own Reserved Instances for sale in the Reserved Instance\nMarketplace, they will be excluded from these results. This is to ensure that\nyou do not purchase your own Reserved Instances.\n\nFor more information, see [Reserved Instance Marketplace](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ri-market-general.html)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#describe_reserved_instances_offerings/3","title":"AWS.EC2.describe_reserved_instances_offerings/3","type":"function"},{"doc":"Describes one or more of your route tables.\n\nEach subnet in your VPC must be associated with a route table. If a subnet is\nnot explicitly associated with any route table, it is implicitly associated with\nthe main route table. This command does not return the subnet ID for implicit\nassociations.\n\nFor more information, see [Route tables](https://docs.aws.amazon.com/vpc/latest/userguide/VPC_Route_Tables.html)\nin the *Amazon VPC User Guide*.","ref":"AWS.EC2.html#describe_route_tables/3","title":"AWS.EC2.describe_route_tables/3","type":"function"},{"doc":"Finds available schedules that meet the specified criteria.\n\nYou can search for an available schedule no more than 3 months in advance. You\nmust meet the minimum required duration of 1,200 hours per year. For example,\nthe minimum daily schedule is 4 hours, the minimum weekly schedule is 24 hours,\nand the minimum monthly schedule is 100 hours.\n\nAfter you find a schedule that meets your needs, call\n`PurchaseScheduledInstances` to purchase Scheduled Instances with that schedule.","ref":"AWS.EC2.html#describe_scheduled_instance_availability/3","title":"AWS.EC2.describe_scheduled_instance_availability/3","type":"function"},{"doc":"Describes the specified Scheduled Instances or all your Scheduled Instances.","ref":"AWS.EC2.html#describe_scheduled_instances/3","title":"AWS.EC2.describe_scheduled_instances/3","type":"function"},{"doc":"Describes the VPCs on the other side of a VPC peering connection or the VPCs\nattached to a transit gateway that are referencing the security groups you've\nspecified in this request.","ref":"AWS.EC2.html#describe_security_group_references/3","title":"AWS.EC2.describe_security_group_references/3","type":"function"},{"doc":"Describes one or more of your security group rules.","ref":"AWS.EC2.html#describe_security_group_rules/3","title":"AWS.EC2.describe_security_group_rules/3","type":"function"},{"doc":"Describes the specified security groups or all of your security groups.","ref":"AWS.EC2.html#describe_security_groups/3","title":"AWS.EC2.describe_security_groups/3","type":"function"},{"doc":"Describes the specified attribute of the specified snapshot.\n\nYou can specify only one attribute at a time.\n\nFor more information about EBS snapshots, see [Amazon EBS snapshots](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSSnapshots.html)\nin the *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.EC2.html#describe_snapshot_attribute/3","title":"AWS.EC2.describe_snapshot_attribute/3","type":"function"},{"doc":"Describes the storage tier status of one or more Amazon EBS snapshots.","ref":"AWS.EC2.html#describe_snapshot_tier_status/3","title":"AWS.EC2.describe_snapshot_tier_status/3","type":"function"},{"doc":"Describes the specified EBS snapshots available to you or all of the EBS\nsnapshots available to you.\n\nThe snapshots available to you include public snapshots, private snapshots that\nyou own, and private snapshots owned by other Amazon Web Services accounts for\nwhich you have explicit create volume permissions.\n\nThe create volume permissions fall into the following categories:\n\n  * *public*: The owner of the snapshot granted create volume\npermissions for the snapshot to the `all` group. All Amazon Web Services\naccounts have create volume permissions for these snapshots.\n\n  * *explicit*: The owner of the snapshot granted create volume\npermissions to a specific Amazon Web Services account.\n\n  * *implicit*: An Amazon Web Services account has implicit create\nvolume permissions for all snapshots it owns.\n\nThe list of snapshots returned can be filtered by specifying snapshot IDs,\nsnapshot owners, or Amazon Web Services accounts with create volume permissions.\nIf no options are specified, Amazon EC2 returns all snapshots for which you have\ncreate volume permissions.\n\nIf you specify one or more snapshot IDs, only snapshots that have the specified\nIDs are returned. If you specify an invalid snapshot ID, an error is returned.\nIf you specify a snapshot ID for which you do not have access, it is not\nincluded in the returned results.\n\nIf you specify one or more snapshot owners using the `OwnerIds` option, only\nsnapshots from the specified owners and for which you have access are returned.\nThe results can include the Amazon Web Services account IDs of the specified\nowners, `amazon` for snapshots owned by Amazon, or `self` for snapshots that you\nown.\n\nIf you specify a list of restorable users, only snapshots with create snapshot\npermissions for those users are returned. You can specify Amazon Web Services\naccount IDs (if you own the snapshots), `self` for snapshots for which you own\nor have explicit permissions, or `all` for public snapshots.\n\nIf you are describing a long list of snapshots, we recommend that you paginate\nthe output to make the list more manageable. For more information, see\n[Pagination](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination).  To get the state of fast snapshot restores for a snapshot, use\n`DescribeFastSnapshotRestores`.\n\nFor more information about EBS snapshots, see [Amazon EBS\nsnapshots](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSSnapshots.html)\nin the *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.EC2.html#describe_snapshots/3","title":"AWS.EC2.describe_snapshots/3","type":"function"},{"doc":"Describes the data feed for Spot Instances.\n\nFor more information, see [Spot Instance data feed](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/spot-data-feeds.html)\nin the *Amazon EC2 User Guide for Linux Instances*.","ref":"AWS.EC2.html#describe_spot_datafeed_subscription/3","title":"AWS.EC2.describe_spot_datafeed_subscription/3","type":"function"},{"doc":"Describes the running instances for the specified Spot Fleet.","ref":"AWS.EC2.html#describe_spot_fleet_instances/3","title":"AWS.EC2.describe_spot_fleet_instances/3","type":"function"},{"doc":"Describes the events for the specified Spot Fleet request during the specified\ntime.\n\nSpot Fleet events are delayed by up to 30 seconds before they can be described.\nThis ensures that you can query by the last evaluated time and not miss a\nrecorded event. Spot Fleet events are available for 48 hours.\n\nFor more information, see [Monitor fleet events using Amazon EventBridge](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/fleet-monitor.html)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#describe_spot_fleet_request_history/3","title":"AWS.EC2.describe_spot_fleet_request_history/3","type":"function"},{"doc":"Describes your Spot Fleet requests.\n\nSpot Fleet requests are deleted 48 hours after they are canceled and their\ninstances are terminated.","ref":"AWS.EC2.html#describe_spot_fleet_requests/3","title":"AWS.EC2.describe_spot_fleet_requests/3","type":"function"},{"doc":"Describes the specified Spot Instance requests.\n\nYou can use `DescribeSpotInstanceRequests` to find a running Spot Instance by\nexamining the response. If the status of the Spot Instance is `fulfilled`, the\ninstance ID appears in the response and contains the identifier of the instance.\nAlternatively, you can use\n[DescribeInstances](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeInstances)\nwith a filter to look for instances where the instance lifecycle is `spot`.\n\nWe recommend that you set `MaxResults` to a value between 5 and 1000 to limit\nthe number of items returned. This paginates the output, which makes the list\nmore manageable and returns the items faster. If the list of items exceeds your\n`MaxResults` value, then that number of items is returned along with a\n`NextToken` value that can be passed to a subsequent\n`DescribeSpotInstanceRequests` request to retrieve the remaining items.\n\nSpot Instance requests are deleted four hours after they are canceled and their\ninstances are terminated.","ref":"AWS.EC2.html#describe_spot_instance_requests/3","title":"AWS.EC2.describe_spot_instance_requests/3","type":"function"},{"doc":"Describes the Spot price history.\n\nFor more information, see [Spot Instance pricing history](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/using-spot-instances-history.html)\nin the *Amazon EC2 User Guide for Linux Instances*.\n\nWhen you specify a start and end time, the operation returns the prices of the\ninstance types within that time range. It also returns the last price change\nbefore the start time, which is the effective price as of the start time.","ref":"AWS.EC2.html#describe_spot_price_history/3","title":"AWS.EC2.describe_spot_price_history/3","type":"function"},{"doc":"Describes the stale security group rules for security groups in a specified VPC.\n\nRules are stale when they reference a deleted security group in the same VPC,\npeered VPC, or in separate VPCs attached to a transit gateway (with [security group referencing\nsupport](https://docs.aws.amazon.com/vpc/latest/tgw/tgw-transit-gateways.html#create-tgw)\nenabled). Rules can also be stale if they reference a security group in a peer\nVPC for which the VPC peering connection has been deleted or if they reference a\nsecurity group in a VPC that has been detached from a transit gateway.","ref":"AWS.EC2.html#describe_stale_security_groups/3","title":"AWS.EC2.describe_stale_security_groups/3","type":"function"},{"doc":"Describes the progress of the AMI store tasks.\n\nYou can describe the store tasks for specified AMIs. If you don't specify the\nAMIs, you get a paginated list of store tasks from the last 31 days.\n\nFor each AMI task, the response indicates if the task is `InProgress`,\n`Completed`, or `Failed`. For tasks `InProgress`, the response shows the\nestimated progress as a percentage.\n\nTasks are listed in reverse chronological order. Currently, only tasks from the\npast 31 days can be viewed.\n\nTo use this API, you must have the required permissions. For more information,\nsee [Permissions for storing and restoring AMIs using Amazon S3](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ami-store-restore.html#ami-s3-permissions)\nin the *Amazon EC2 User Guide*.\n\nFor more information, see [Store and restore an AMI using Amazon S3](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ami-store-restore.html)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#describe_store_image_tasks/3","title":"AWS.EC2.describe_store_image_tasks/3","type":"function"},{"doc":"Describes one or more of your subnets.\n\nFor more information, see\n[Subnets](https://docs.aws.amazon.com/vpc/latest/userguide/configure-subnets.html)\nin the *Amazon VPC User Guide*.","ref":"AWS.EC2.html#describe_subnets/3","title":"AWS.EC2.describe_subnets/3","type":"function"},{"doc":"Describes the specified tags for your EC2 resources.\n\nFor more information about tags, see [Tag your Amazon EC2 resources](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Using_Tags.html)\nin the *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.EC2.html#describe_tags/3","title":"AWS.EC2.describe_tags/3","type":"function"},{"doc":"Describes one or more Traffic Mirror filters.","ref":"AWS.EC2.html#describe_traffic_mirror_filters/3","title":"AWS.EC2.describe_traffic_mirror_filters/3","type":"function"},{"doc":"Describes one or more Traffic Mirror sessions.\n\nBy default, all Traffic Mirror sessions are described. Alternatively, you can\nfilter the results.","ref":"AWS.EC2.html#describe_traffic_mirror_sessions/3","title":"AWS.EC2.describe_traffic_mirror_sessions/3","type":"function"},{"doc":"Information about one or more Traffic Mirror targets.","ref":"AWS.EC2.html#describe_traffic_mirror_targets/3","title":"AWS.EC2.describe_traffic_mirror_targets/3","type":"function"},{"doc":"Describes one or more attachments between resources and transit gateways.\n\nBy default, all attachments are described. Alternatively, you can filter the\nresults by attachment ID, attachment state, resource ID, or resource owner.","ref":"AWS.EC2.html#describe_transit_gateway_attachments/3","title":"AWS.EC2.describe_transit_gateway_attachments/3","type":"function"},{"doc":"Describes one or more Connect peers.","ref":"AWS.EC2.html#describe_transit_gateway_connect_peers/3","title":"AWS.EC2.describe_transit_gateway_connect_peers/3","type":"function"},{"doc":"Describes one or more Connect attachments.","ref":"AWS.EC2.html#describe_transit_gateway_connects/3","title":"AWS.EC2.describe_transit_gateway_connects/3","type":"function"},{"doc":"Describes one or more transit gateway multicast domains.","ref":"AWS.EC2.html#describe_transit_gateway_multicast_domains/3","title":"AWS.EC2.describe_transit_gateway_multicast_domains/3","type":"function"},{"doc":"Describes your transit gateway peering attachments.","ref":"AWS.EC2.html#describe_transit_gateway_peering_attachments/3","title":"AWS.EC2.describe_transit_gateway_peering_attachments/3","type":"function"},{"doc":"Describes one or more transit gateway route policy tables.","ref":"AWS.EC2.html#describe_transit_gateway_policy_tables/3","title":"AWS.EC2.describe_transit_gateway_policy_tables/3","type":"function"},{"doc":"Describes one or more transit gateway route table advertisements.","ref":"AWS.EC2.html#describe_transit_gateway_route_table_announcements/3","title":"AWS.EC2.describe_transit_gateway_route_table_announcements/3","type":"function"},{"doc":"Describes one or more transit gateway route tables.\n\nBy default, all transit gateway route tables are described. Alternatively, you\ncan filter the results.","ref":"AWS.EC2.html#describe_transit_gateway_route_tables/3","title":"AWS.EC2.describe_transit_gateway_route_tables/3","type":"function"},{"doc":"Describes one or more VPC attachments.\n\nBy default, all VPC attachments are described. Alternatively, you can filter the\nresults.","ref":"AWS.EC2.html#describe_transit_gateway_vpc_attachments/3","title":"AWS.EC2.describe_transit_gateway_vpc_attachments/3","type":"function"},{"doc":"Describes one or more transit gateways.\n\nBy default, all transit gateways are described. Alternatively, you can filter\nthe results.","ref":"AWS.EC2.html#describe_transit_gateways/3","title":"AWS.EC2.describe_transit_gateways/3","type":"function"},{"doc":"Describes one or more network interface trunk associations.","ref":"AWS.EC2.html#describe_trunk_interface_associations/3","title":"AWS.EC2.describe_trunk_interface_associations/3","type":"function"},{"doc":"Describes the specified Amazon Web Services Verified Access endpoints.","ref":"AWS.EC2.html#describe_verified_access_endpoints/3","title":"AWS.EC2.describe_verified_access_endpoints/3","type":"function"},{"doc":"Describes the specified Verified Access groups.","ref":"AWS.EC2.html#describe_verified_access_groups/3","title":"AWS.EC2.describe_verified_access_groups/3","type":"function"},{"doc":"Describes the specified Amazon Web Services Verified Access instances.","ref":"AWS.EC2.html#describe_verified_access_instance_logging_configurations/3","title":"AWS.EC2.describe_verified_access_instance_logging_configurations/3","type":"function"},{"doc":"Describes the specified Amazon Web Services Verified Access instances.","ref":"AWS.EC2.html#describe_verified_access_instances/3","title":"AWS.EC2.describe_verified_access_instances/3","type":"function"},{"doc":"Describes the specified Amazon Web Services Verified Access trust providers.","ref":"AWS.EC2.html#describe_verified_access_trust_providers/3","title":"AWS.EC2.describe_verified_access_trust_providers/3","type":"function"},{"doc":"Describes the specified attribute of the specified volume.\n\nYou can specify only one attribute at a time.\n\nFor more information about EBS volumes, see [Amazon EBS volumes](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumes.html) in\nthe *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.EC2.html#describe_volume_attribute/3","title":"AWS.EC2.describe_volume_attribute/3","type":"function"},{"doc":"Describes the status of the specified volumes.\n\nVolume status provides the result of the checks performed on your volumes to\ndetermine events that can impair the performance of your volumes. The\nperformance of a volume can be affected if an issue occurs on the volume's\nunderlying host. If the volume's underlying host experiences a power outage or\nsystem issue, after the system is restored, there could be data inconsistencies\non the volume. Volume events notify you if this occurs. Volume actions notify\nyou if any action needs to be taken in response to the event.\n\nThe `DescribeVolumeStatus` operation provides the following information about\nthe specified volumes:\n\n*Status*: Reflects the current status of the volume. The possible values are\n`ok`, `impaired` , `warning`, or `insufficient-data`. If all checks pass, the\noverall status of the volume is `ok`. If the check fails, the overall status is\n`impaired`. If the status is `insufficient-data`, then the checks might still be\ntaking place on your volume at the time. We recommend that you retry the\nrequest. For more information about volume status, see [Monitor the status of your\nvolumes](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/monitoring-volume-status.html)\nin the *Amazon Elastic Compute Cloud User Guide*.\n\n*Events*: Reflect the cause of a volume status and might require you to take\naction. For example, if your volume returns an `impaired` status, then the\nvolume event might be `potential-data-inconsistency`. This means that your\nvolume has been affected by an issue with the underlying host, has all I/O\noperations disabled, and might have inconsistent data.\n\n*Actions*: Reflect the actions you might have to take in response to an event.\nFor example, if the status of the volume is `impaired` and the volume event\nshows `potential-data-inconsistency`, then the action shows `enable-volume-io`.\nThis means that you may want to enable the I/O operations for the volume by\ncalling the `EnableVolumeIO` action and then check the volume for data\nconsistency.\n\nVolume status is based on the volume status checks, and does not reflect the\nvolume state. Therefore, volume status does not indicate volumes in the `error`\nstate (for example, when a volume is incapable of accepting I/O.)","ref":"AWS.EC2.html#describe_volume_status/3","title":"AWS.EC2.describe_volume_status/3","type":"function"},{"doc":"Describes the specified EBS volumes or all of your EBS volumes.\n\nIf you are describing a long list of volumes, we recommend that you paginate the\noutput to make the list more manageable. For more information, see\n[Pagination](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination).  For more information about EBS volumes, see [Amazon EBS\nvolumes](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumes.html) in\nthe *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.EC2.html#describe_volumes/3","title":"AWS.EC2.describe_volumes/3","type":"function"},{"doc":"Describes the most recent volume modification request for the specified EBS\nvolumes.\n\nIf a volume has never been modified, some information in the output will be\nnull. If a volume has been modified more than once, the output includes only the\nmost recent modification request.\n\nYou can also use CloudWatch Events to check the status of a modification to an\nEBS volume. For information about CloudWatch Events, see the [Amazon CloudWatch Events User Guide](https://docs.aws.amazon.com/AmazonCloudWatch/latest/events/).\nFor more information, see [Monitor the progress of volume modifications](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/monitoring-volume-modifications.html)\nin the *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.EC2.html#describe_volumes_modifications/3","title":"AWS.EC2.describe_volumes_modifications/3","type":"function"},{"doc":"Describes the specified attribute of the specified VPC.\n\nYou can specify only one attribute at a time.","ref":"AWS.EC2.html#describe_vpc_attribute/3","title":"AWS.EC2.describe_vpc_attribute/3","type":"function"},{"doc":"This action is deprecated.\n\nDescribes the ClassicLink status of the specified VPCs.","ref":"AWS.EC2.html#describe_vpc_classic_link/3","title":"AWS.EC2.describe_vpc_classic_link/3","type":"function"},{"doc":"This action is deprecated.\n\nDescribes the ClassicLink DNS support status of one or more VPCs. If enabled,\nthe DNS hostname of a linked EC2-Classic instance resolves to its private IP\naddress when addressed from an instance in the VPC to which it's linked.\nSimilarly, the DNS hostname of an instance in a VPC resolves to its private IP\naddress when addressed from a linked EC2-Classic instance.","ref":"AWS.EC2.html#describe_vpc_classic_link_dns_support/3","title":"AWS.EC2.describe_vpc_classic_link_dns_support/3","type":"function"},{"doc":"Describes the connection notifications for VPC endpoints and VPC endpoint\nservices.","ref":"AWS.EC2.html#describe_vpc_endpoint_connection_notifications/3","title":"AWS.EC2.describe_vpc_endpoint_connection_notifications/3","type":"function"},{"doc":"Describes the VPC endpoint connections to your VPC endpoint services, including\nany endpoints that are pending your acceptance.","ref":"AWS.EC2.html#describe_vpc_endpoint_connections/3","title":"AWS.EC2.describe_vpc_endpoint_connections/3","type":"function"},{"doc":"Describes the VPC endpoint service configurations in your account (your\nservices).","ref":"AWS.EC2.html#describe_vpc_endpoint_service_configurations/3","title":"AWS.EC2.describe_vpc_endpoint_service_configurations/3","type":"function"},{"doc":"Describes the principals (service consumers) that are permitted to discover your\nVPC endpoint service.","ref":"AWS.EC2.html#describe_vpc_endpoint_service_permissions/3","title":"AWS.EC2.describe_vpc_endpoint_service_permissions/3","type":"function"},{"doc":"Describes available services to which you can create a VPC endpoint.\n\nWhen the service provider and the consumer have different accounts in multiple\nAvailability Zones, and the consumer views the VPC endpoint service information,\nthe response only includes the common Availability Zones. For example, when the\nservice provider account uses `us-east-1a` and `us-east-1c` and the consumer\nuses `us-east-1a` and `us-east-1b`, the response includes the VPC endpoint\nservices in the common Availability Zone, `us-east-1a`.","ref":"AWS.EC2.html#describe_vpc_endpoint_services/3","title":"AWS.EC2.describe_vpc_endpoint_services/3","type":"function"},{"doc":"Describes your VPC endpoints.","ref":"AWS.EC2.html#describe_vpc_endpoints/3","title":"AWS.EC2.describe_vpc_endpoints/3","type":"function"},{"doc":"Describes one or more of your VPC peering connections.","ref":"AWS.EC2.html#describe_vpc_peering_connections/3","title":"AWS.EC2.describe_vpc_peering_connections/3","type":"function"},{"doc":"Describes one or more of your VPCs.","ref":"AWS.EC2.html#describe_vpcs/3","title":"AWS.EC2.describe_vpcs/3","type":"function"},{"doc":"Describes one or more of your VPN connections.\n\nFor more information, see [Amazon Web Services Site-to-Site VPN](https://docs.aws.amazon.com/vpn/latest/s2svpn/VPC_VPN.html) in the *Amazon\nWeb Services Site-to-Site VPN User Guide*.","ref":"AWS.EC2.html#describe_vpn_connections/3","title":"AWS.EC2.describe_vpn_connections/3","type":"function"},{"doc":"Describes one or more of your virtual private gateways.\n\nFor more information, see [Amazon Web Services Site-to-Site VPN](https://docs.aws.amazon.com/vpn/latest/s2svpn/VPC_VPN.html) in the *Amazon\nWeb Services Site-to-Site VPN User Guide*.","ref":"AWS.EC2.html#describe_vpn_gateways/3","title":"AWS.EC2.describe_vpn_gateways/3","type":"function"},{"doc":"This action is deprecated.\n\nUnlinks (detaches) a linked EC2-Classic instance from a VPC. After the instance\nhas been unlinked, the VPC security groups are no longer associated with it. An\ninstance is automatically unlinked from a VPC when it's stopped.","ref":"AWS.EC2.html#detach_classic_link_vpc/3","title":"AWS.EC2.detach_classic_link_vpc/3","type":"function"},{"doc":"Detaches an internet gateway from a VPC, disabling connectivity between the\ninternet and the VPC.\n\nThe VPC must not contain any running instances with Elastic IP addresses or\npublic IPv4 addresses.","ref":"AWS.EC2.html#detach_internet_gateway/3","title":"AWS.EC2.detach_internet_gateway/3","type":"function"},{"doc":"Detaches a network interface from an instance.","ref":"AWS.EC2.html#detach_network_interface/3","title":"AWS.EC2.detach_network_interface/3","type":"function"},{"doc":"Detaches the specified Amazon Web Services Verified Access trust provider from\nthe specified Amazon Web Services Verified Access instance.","ref":"AWS.EC2.html#detach_verified_access_trust_provider/3","title":"AWS.EC2.detach_verified_access_trust_provider/3","type":"function"},{"doc":"Detaches an EBS volume from an instance.\n\nMake sure to unmount any file systems on the device within your operating system\nbefore detaching the volume. Failure to do so can result in the volume becoming\nstuck in the `busy` state while detaching. If this happens, detachment can be\ndelayed indefinitely until you unmount the volume, force detachment, reboot the\ninstance, or all three. If an EBS volume is the root device of an instance, it\ncan't be detached while the instance is running. To detach the root volume, stop\nthe instance first.\n\nWhen a volume with an Amazon Web Services Marketplace product code is detached\nfrom an instance, the product code is no longer associated with the instance.\n\nYou can't detach or force detach volumes that are attached to Amazon ECS or\nFargate tasks. Attempting to do this results in the\n`UnsupportedOperationException` exception with the `Unable to detach volume\nattached to ECS tasks` error message.\n\nFor more information, see [Detach an Amazon EBS volume](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ebs-detaching-volume.html)\nin the *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.EC2.html#detach_volume/3","title":"AWS.EC2.detach_volume/3","type":"function"},{"doc":"Detaches a virtual private gateway from a VPC.\n\nYou do this if you're planning to turn off the VPC and not use it anymore. You\ncan confirm a virtual private gateway has been completely detached from a VPC by\ndescribing the virtual private gateway (any attachments to the virtual private\ngateway are also described).\n\nYou must wait for the attachment's state to switch to `detached` before you can\ndelete the VPC or attach a different VPC to the virtual private gateway.","ref":"AWS.EC2.html#detach_vpn_gateway/3","title":"AWS.EC2.detach_vpn_gateway/3","type":"function"},{"doc":"Disables Elastic IP address transfer.\n\nFor more information, see [Transfer Elastic IP addresses](https://docs.aws.amazon.com/vpc/latest/userguide/vpc-eips.html#transfer-EIPs-intro)\nin the *Amazon Virtual Private Cloud User Guide*.","ref":"AWS.EC2.html#disable_address_transfer/3","title":"AWS.EC2.disable_address_transfer/3","type":"function"},{"doc":"Disables Infrastructure Performance metric subscriptions.","ref":"AWS.EC2.html#disable_aws_network_performance_metric_subscription/3","title":"AWS.EC2.disable_aws_network_performance_metric_subscription/3","type":"function"},{"doc":"Disables EBS encryption by default for your account in the current Region.\n\nAfter you disable encryption by default, you can still create encrypted volumes\nby enabling encryption when you create each volume.\n\nDisabling encryption by default does not change the encryption status of your\nexisting volumes.\n\nFor more information, see [Amazon EBS encryption](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSEncryption.html)\nin the *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.EC2.html#disable_ebs_encryption_by_default/3","title":"AWS.EC2.disable_ebs_encryption_by_default/3","type":"function"},{"doc":"Discontinue Windows fast launch for a Windows AMI, and clean up existing\npre-provisioned snapshots.\n\nAfter you disable Windows fast launch, the AMI uses the standard launch process\nfor each new instance. Amazon EC2 must remove all pre-provisioned snapshots\nbefore you can enable Windows fast launch again.\n\nYou can only change these settings for Windows AMIs that you own or that have\nbeen shared with you.","ref":"AWS.EC2.html#disable_fast_launch/3","title":"AWS.EC2.disable_fast_launch/3","type":"function"},{"doc":"Disables fast snapshot restores for the specified snapshots in the specified\nAvailability Zones.","ref":"AWS.EC2.html#disable_fast_snapshot_restores/3","title":"AWS.EC2.disable_fast_snapshot_restores/3","type":"function"},{"doc":"Sets the AMI state to `disabled` and removes all launch permissions from the\nAMI.\n\nA disabled AMI can't be used for instance launches.\n\nA disabled AMI can't be shared. If an AMI was public or previously shared, it is\nmade private. If an AMI was shared with an Amazon Web Services account,\norganization, or Organizational Unit, they lose access to the disabled AMI.\n\nA disabled AMI does not appear in\n[DescribeImages](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeImages.html) API calls by default.\n\nOnly the AMI owner can disable an AMI.\n\nYou can re-enable a disabled AMI using\n[EnableImage](http://amazonaws.com/AWSEC2/latest/APIReference/API_EnableImage.html).\n\nFor more information, see [Disable an AMI](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/disable-an-ami.html) in\nthe *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#disable_image/3","title":"AWS.EC2.disable_image/3","type":"function"},{"doc":"Disables *block public access for AMIs* at the account level in the specified\nAmazon Web Services Region.\n\nThis removes the *block public access* restriction from your account. With the\nrestriction removed, you can publicly share your AMIs in the specified Amazon\nWeb Services Region.\n\nThe API can take up to 10 minutes to configure this setting. During this time,\nif you run\n[GetImageBlockPublicAccessState](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetImageBlockPublicAccessState.html), the response will be `block-new-sharing`. When the API has completed the\nconfiguration, the response will be `unblocked`.\n\nFor more information, see [Block public access to your\nAMIs](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/sharingamis-intro.html#block-public-access-to-amis)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#disable_image_block_public_access/3","title":"AWS.EC2.disable_image_block_public_access/3","type":"function"},{"doc":"Cancels the deprecation of the specified AMI.\n\nFor more information, see [Deprecate an AMI](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ami-deprecate.html) in\nthe *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#disable_image_deprecation/3","title":"AWS.EC2.disable_image_deprecation/3","type":"function"},{"doc":"Disable the IPAM account.\n\nFor more information, see [Enable integration with Organizations](https://docs.aws.amazon.com/vpc/latest/ipam/enable-integ-ipam.html)\nin the *Amazon VPC IPAM User Guide*.","ref":"AWS.EC2.html#disable_ipam_organization_admin_account/3","title":"AWS.EC2.disable_ipam_organization_admin_account/3","type":"function"},{"doc":"Disables access to the EC2 serial console of all instances for your account.\n\nBy default, access to the EC2 serial console is disabled for your account. For\nmore information, see [Manage account access to the EC2 serial console](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/configure-access-to-serial-console.html#serial-console-account-access)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#disable_serial_console_access/3","title":"AWS.EC2.disable_serial_console_access/3","type":"function"},{"doc":"Disables the *block public access for snapshots* setting at the account level\nfor the specified Amazon Web Services Region.\n\nAfter you disable block public access for snapshots in a Region, users can\npublicly share snapshots in that Region.\n\nIf block public access is enabled in `block-all-sharing` mode, and you disable\nblock public access, all snapshots that were previously publicly shared are no\nlonger treated as private and they become publicly accessible again.\n\nFor more information, see [ Block public access for snapshots](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/block-public-access-snapshots.html)\nin the *Amazon Elastic Compute Cloud User Guide* .","ref":"AWS.EC2.html#disable_snapshot_block_public_access/3","title":"AWS.EC2.disable_snapshot_block_public_access/3","type":"function"},{"doc":"Disables the specified resource attachment from propagating routes to the\nspecified propagation route table.","ref":"AWS.EC2.html#disable_transit_gateway_route_table_propagation/3","title":"AWS.EC2.disable_transit_gateway_route_table_propagation/3","type":"function"},{"doc":"Disables a virtual private gateway (VGW) from propagating routes to a specified\nroute table of a VPC.","ref":"AWS.EC2.html#disable_vgw_route_propagation/3","title":"AWS.EC2.disable_vgw_route_propagation/3","type":"function"},{"doc":"This action is deprecated.\n\nDisables ClassicLink for a VPC. You cannot disable ClassicLink for a VPC that\nhas EC2-Classic instances linked to it.","ref":"AWS.EC2.html#disable_vpc_classic_link/3","title":"AWS.EC2.disable_vpc_classic_link/3","type":"function"},{"doc":"This action is deprecated.\n\nDisables ClassicLink DNS support for a VPC. If disabled, DNS hostnames resolve\nto public IP addresses when addressed between a linked EC2-Classic instance and\ninstances in the VPC to which it's linked.\n\nYou must specify a VPC ID in the request.","ref":"AWS.EC2.html#disable_vpc_classic_link_dns_support/3","title":"AWS.EC2.disable_vpc_classic_link_dns_support/3","type":"function"},{"doc":"Disassociates an Elastic IP address from the instance or network interface it's\nassociated with.\n\nThis is an idempotent operation. If you perform the operation more than once,\nAmazon EC2 doesn't return an error.","ref":"AWS.EC2.html#disassociate_address/3","title":"AWS.EC2.disassociate_address/3","type":"function"},{"doc":"Disassociates a target network from the specified Client VPN endpoint.\n\nWhen you disassociate the last target network from a Client VPN, the following\nhappens:\n\n  * The route that was automatically added for the VPC is deleted\n\n  * All active client connections are terminated\n\n  * New client connections are disallowed\n\n  * The Client VPN endpoint's status changes to `pending-associate`","ref":"AWS.EC2.html#disassociate_client_vpn_target_network/3","title":"AWS.EC2.disassociate_client_vpn_target_network/3","type":"function"},{"doc":"Disassociates an IAM role from an Certificate Manager (ACM) certificate.\n\nDisassociating an IAM role from an ACM certificate removes the Amazon S3 object\nthat contains the certificate, certificate chain, and encrypted private key from\nthe Amazon S3 bucket. It also revokes the IAM role's permission to use the KMS\nkey used to encrypt the private key. This effectively revokes the role's\npermission to use the certificate.","ref":"AWS.EC2.html#disassociate_enclave_certificate_iam_role/3","title":"AWS.EC2.disassociate_enclave_certificate_iam_role/3","type":"function"},{"doc":"Disassociates an IAM instance profile from a running or stopped instance.\n\nUse `DescribeIamInstanceProfileAssociations` to get the association ID.","ref":"AWS.EC2.html#disassociate_iam_instance_profile/3","title":"AWS.EC2.disassociate_iam_instance_profile/3","type":"function"},{"doc":"Disassociates one or more targets from an event window.\n\nFor more information, see [Define event windows for scheduled events](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/event-windows.html)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#disassociate_instance_event_window/3","title":"AWS.EC2.disassociate_instance_event_window/3","type":"function"},{"doc":"Remove the association between your Autonomous System Number (ASN) and your\nBYOIP CIDR.\n\nYou may want to use this action to disassociate an ASN from a CIDR or if you\nwant to swap ASNs. For more information, see [Tutorial: Bring your ASN to IPAM](https://docs.aws.amazon.com/vpc/latest/ipam/tutorials-byoasn.html) in the\n*Amazon VPC IPAM guide*.","ref":"AWS.EC2.html#disassociate_ipam_byoasn/3","title":"AWS.EC2.disassociate_ipam_byoasn/3","type":"function"},{"doc":"Disassociates a resource discovery from an Amazon VPC IPAM.\n\nA resource discovery is an IPAM component that enables IPAM to manage and\nmonitor resources that belong to the owning account.","ref":"AWS.EC2.html#disassociate_ipam_resource_discovery/3","title":"AWS.EC2.disassociate_ipam_resource_discovery/3","type":"function"},{"doc":"Disassociates secondary Elastic IP addresses (EIPs) from a public NAT gateway.\n\nYou cannot disassociate your primary EIP. For more information, see [Edit secondary IP address\nassociations](https://docs.aws.amazon.com/vpc/latest/userguide/vpc-nat-gateway.html#nat-gateway-edit-secondary)\nin the *Amazon VPC User Guide*.\n\nWhile disassociating is in progress, you cannot associate/disassociate\nadditional EIPs while the connections are being drained. You are, however,\nallowed to delete the NAT gateway.\n\nAn EIP is released only at the end of MaxDrainDurationSeconds. It stays\nassociated and supports the existing connections but does not support any new\nconnections (new connections are distributed across the remaining associated\nEIPs). As the existing connections drain out, the EIPs (and the corresponding\nprivate IP addresses mapped to them) are released.","ref":"AWS.EC2.html#disassociate_nat_gateway_address/3","title":"AWS.EC2.disassociate_nat_gateway_address/3","type":"function"},{"doc":"Disassociates a subnet or gateway from a route table.\n\nAfter you perform this action, the subnet no longer uses the routes in the route\ntable. Instead, it uses the routes in the VPC's main route table. For more\ninformation about route tables, see [Route tables](https://docs.aws.amazon.com/vpc/latest/userguide/VPC_Route_Tables.html)\nin the *Amazon VPC User Guide*.","ref":"AWS.EC2.html#disassociate_route_table/3","title":"AWS.EC2.disassociate_route_table/3","type":"function"},{"doc":"Disassociates a CIDR block from a subnet.\n\nCurrently, you can disassociate an IPv6 CIDR block only. You must detach or\ndelete all gateways and resources that are associated with the CIDR block before\nyou can disassociate it.","ref":"AWS.EC2.html#disassociate_subnet_cidr_block/3","title":"AWS.EC2.disassociate_subnet_cidr_block/3","type":"function"},{"doc":"Disassociates the specified subnets from the transit gateway multicast domain.","ref":"AWS.EC2.html#disassociate_transit_gateway_multicast_domain/3","title":"AWS.EC2.disassociate_transit_gateway_multicast_domain/3","type":"function"},{"doc":"Removes the association between an an attachment and a policy table.","ref":"AWS.EC2.html#disassociate_transit_gateway_policy_table/3","title":"AWS.EC2.disassociate_transit_gateway_policy_table/3","type":"function"},{"doc":"Disassociates a resource attachment from a transit gateway route table.","ref":"AWS.EC2.html#disassociate_transit_gateway_route_table/3","title":"AWS.EC2.disassociate_transit_gateway_route_table/3","type":"function"},{"doc":"Removes an association between a branch network interface with a trunk network\ninterface.","ref":"AWS.EC2.html#disassociate_trunk_interface/3","title":"AWS.EC2.disassociate_trunk_interface/3","type":"function"},{"doc":"Disassociates a CIDR block from a VPC.\n\nTo disassociate the CIDR block, you must specify its association ID. You can get\nthe association ID by using `DescribeVpcs`. You must detach or delete all\ngateways and resources that are associated with the CIDR block before you can\ndisassociate it.\n\nYou cannot disassociate the CIDR block with which you originally created the VPC\n(the primary CIDR block).","ref":"AWS.EC2.html#disassociate_vpc_cidr_block/3","title":"AWS.EC2.disassociate_vpc_cidr_block/3","type":"function"},{"doc":"Enables Elastic IP address transfer.\n\nFor more information, see [Transfer Elastic IP addresses](https://docs.aws.amazon.com/vpc/latest/userguide/vpc-eips.html#transfer-EIPs-intro)\nin the *Amazon Virtual Private Cloud User Guide*.","ref":"AWS.EC2.html#enable_address_transfer/3","title":"AWS.EC2.enable_address_transfer/3","type":"function"},{"doc":"Enables Infrastructure Performance subscriptions.","ref":"AWS.EC2.html#enable_aws_network_performance_metric_subscription/3","title":"AWS.EC2.enable_aws_network_performance_metric_subscription/3","type":"function"},{"doc":"Enables EBS encryption by default for your account in the current Region.\n\nAfter you enable encryption by default, the EBS volumes that you create are\nalways encrypted, either using the default KMS key or the KMS key that you\nspecified when you created each volume. For more information, see [Amazon EBS encryption](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSEncryption.html)\nin the *Amazon Elastic Compute Cloud User Guide*.\n\nYou can specify the default KMS key for encryption by default using\n`ModifyEbsDefaultKmsKeyId` or `ResetEbsDefaultKmsKeyId`.\n\nEnabling encryption by default has no effect on the encryption status of your\nexisting volumes.\n\nAfter you enable encryption by default, you can no longer launch instances using\ninstance types that do not support encryption. For more information, see\n[Supported instance types](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSEncryption.html#EBSEncryption_supported_instances).","ref":"AWS.EC2.html#enable_ebs_encryption_by_default/3","title":"AWS.EC2.enable_ebs_encryption_by_default/3","type":"function"},{"doc":"When you enable Windows fast launch for a Windows AMI, images are\npre-provisioned, using snapshots to launch instances up to 65% faster.\n\nTo create the optimized Windows image, Amazon EC2 launches an instance and runs\nthrough Sysprep steps, rebooting as required. Then it creates a set of reserved\nsnapshots that are used for subsequent launches. The reserved snapshots are\nautomatically replenished as they are used, depending on your settings for\nlaunch frequency.\n\nYou can only change these settings for Windows AMIs that you own or that have\nbeen shared with you.","ref":"AWS.EC2.html#enable_fast_launch/3","title":"AWS.EC2.enable_fast_launch/3","type":"function"},{"doc":"Enables fast snapshot restores for the specified snapshots in the specified\nAvailability Zones.\n\nYou get the full benefit of fast snapshot restores after they enter the\n`enabled` state. To get the current state of fast snapshot restores, use\n`DescribeFastSnapshotRestores`. To disable fast snapshot restores, use\n`DisableFastSnapshotRestores`.\n\nFor more information, see [Amazon EBS fast snapshot restore](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ebs-fast-snapshot-restore.html)\nin the *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.EC2.html#enable_fast_snapshot_restores/3","title":"AWS.EC2.enable_fast_snapshot_restores/3","type":"function"},{"doc":"Re-enables a disabled AMI.\n\nThe re-enabled AMI is marked as `available` and can be used for instance\nlaunches, appears in describe operations, and can be shared. Amazon Web Services\naccounts, organizations, and Organizational Units that lost access to the AMI\nwhen it was disabled do not regain access automatically. Once the AMI is\navailable, it can be shared with them again.\n\nOnly the AMI owner can re-enable a disabled AMI.\n\nFor more information, see [Disable an AMI](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/disable-an-ami.html) in\nthe *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#enable_image/3","title":"AWS.EC2.enable_image/3","type":"function"},{"doc":"Enables *block public access for AMIs* at the account level in the specified\nAmazon Web Services Region.\n\nThis prevents the public sharing of your AMIs. However, if you already have\npublic AMIs, they will remain publicly available.\n\nThe API can take up to 10 minutes to configure this setting. During this time,\nif you run\n[GetImageBlockPublicAccessState](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetImageBlockPublicAccessState.html), the response will be `unblocked`. When the API has completed the configuration,\nthe response will be `block-new-sharing`.\n\nFor more information, see [Block public access to your\nAMIs](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/sharingamis-intro.html#block-public-access-to-amis)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#enable_image_block_public_access/3","title":"AWS.EC2.enable_image_block_public_access/3","type":"function"},{"doc":"Enables deprecation of the specified AMI at the specified date and time.\n\nFor more information, see [Deprecate an AMI](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ami-deprecate.html) in\nthe *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#enable_image_deprecation/3","title":"AWS.EC2.enable_image_deprecation/3","type":"function"},{"doc":"Enable an Organizations member account as the IPAM admin account.\n\nYou cannot select the Organizations management account as the IPAM admin\naccount. For more information, see [Enable integration with Organizations](https://docs.aws.amazon.com/vpc/latest/ipam/enable-integ-ipam.html)\nin the *Amazon VPC IPAM User Guide*.","ref":"AWS.EC2.html#enable_ipam_organization_admin_account/3","title":"AWS.EC2.enable_ipam_organization_admin_account/3","type":"function"},{"doc":"Establishes a trust relationship between Reachability Analyzer and\nOrganizations.\n\nThis operation must be performed by the management account for the organization.\n\nAfter you establish a trust relationship, a user in the management account or a\ndelegated administrator account can run a cross-account analysis using resources\nfrom the member accounts.","ref":"AWS.EC2.html#enable_reachability_analyzer_organization_sharing/3","title":"AWS.EC2.enable_reachability_analyzer_organization_sharing/3","type":"function"},{"doc":"Enables access to the EC2 serial console of all instances for your account.\n\nBy default, access to the EC2 serial console is disabled for your account. For\nmore information, see [Manage account access to the EC2 serial console](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/configure-access-to-serial-console.html#serial-console-account-access)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#enable_serial_console_access/3","title":"AWS.EC2.enable_serial_console_access/3","type":"function"},{"doc":"Enables or modifies the *block public access for snapshots* setting at the\naccount level for the specified Amazon Web Services Region.\n\nAfter you enable block public access for snapshots in a Region, users can no\nlonger request public sharing for snapshots in that Region. Snapshots that are\nalready publicly shared are either treated as private or they remain publicly\nshared, depending on the **State** that you specify.\n\nIf block public access is enabled in `block-all-sharing` mode, and you change\nthe mode to `block-new-sharing`, all snapshots that were previously publicly\nshared are no longer treated as private and they become publicly accessible\nagain.\n\nFor more information, see [ Block public access for snapshots](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/block-public-access-snapshots.html)\nin the *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.EC2.html#enable_snapshot_block_public_access/3","title":"AWS.EC2.enable_snapshot_block_public_access/3","type":"function"},{"doc":"Enables the specified attachment to propagate routes to the specified\npropagation route table.","ref":"AWS.EC2.html#enable_transit_gateway_route_table_propagation/3","title":"AWS.EC2.enable_transit_gateway_route_table_propagation/3","type":"function"},{"doc":"Enables a virtual private gateway (VGW) to propagate routes to the specified\nroute table of a VPC.","ref":"AWS.EC2.html#enable_vgw_route_propagation/3","title":"AWS.EC2.enable_vgw_route_propagation/3","type":"function"},{"doc":"Enables I/O operations for a volume that had I/O operations disabled because the\ndata on the volume was potentially inconsistent.","ref":"AWS.EC2.html#enable_volume_i_o/3","title":"AWS.EC2.enable_volume_i_o/3","type":"function"},{"doc":"This action is deprecated.\n\nEnables a VPC for ClassicLink. You can then link EC2-Classic instances to your\nClassicLink-enabled VPC to allow communication over private IP addresses. You\ncannot enable your VPC for ClassicLink if any of your VPC route tables have\nexisting routes for address ranges within the `10.0.0.0/8` IP address range,\nexcluding local routes for VPCs in the `10.0.0.0/16` and `10.1.0.0/16` IP\naddress ranges.","ref":"AWS.EC2.html#enable_vpc_classic_link/3","title":"AWS.EC2.enable_vpc_classic_link/3","type":"function"},{"doc":"This action is deprecated.\n\nEnables a VPC to support DNS hostname resolution for ClassicLink. If enabled,\nthe DNS hostname of a linked EC2-Classic instance resolves to its private IP\naddress when addressed from an instance in the VPC to which it's linked.\nSimilarly, the DNS hostname of an instance in a VPC resolves to its private IP\naddress when addressed from a linked EC2-Classic instance.\n\nYou must specify a VPC ID in the request.","ref":"AWS.EC2.html#enable_vpc_classic_link_dns_support/3","title":"AWS.EC2.enable_vpc_classic_link_dns_support/3","type":"function"},{"doc":"Downloads the client certificate revocation list for the specified Client VPN\nendpoint.","ref":"AWS.EC2.html#export_client_vpn_client_certificate_revocation_list/3","title":"AWS.EC2.export_client_vpn_client_certificate_revocation_list/3","type":"function"},{"doc":"Downloads the contents of the Client VPN endpoint configuration file for the\nspecified Client VPN endpoint.\n\nThe Client VPN endpoint configuration file includes the Client VPN endpoint and\ncertificate information clients need to establish a connection with the Client\nVPN endpoint.","ref":"AWS.EC2.html#export_client_vpn_client_configuration/3","title":"AWS.EC2.export_client_vpn_client_configuration/3","type":"function"},{"doc":"Exports an Amazon Machine Image (AMI) to a VM file.\n\nFor more information, see [Exporting a VM directly from an Amazon Machine Image (AMI)](https://docs.aws.amazon.com/vm-import/latest/userguide/vmexport_image.html)\nin the *VM Import/Export User Guide*.","ref":"AWS.EC2.html#export_image/3","title":"AWS.EC2.export_image/3","type":"function"},{"doc":"Exports routes from the specified transit gateway route table to the specified\nS3 bucket.\n\nBy default, all routes are exported. Alternatively, you can filter by CIDR\nrange.\n\nThe routes are saved to the specified bucket in a JSON file. For more\ninformation, see [Export Route Tables to Amazon S3](https://docs.aws.amazon.com/vpc/latest/tgw/tgw-route-tables.html#tgw-export-route-tables)\nin *Transit Gateways*.","ref":"AWS.EC2.html#export_transit_gateway_routes/3","title":"AWS.EC2.export_transit_gateway_routes/3","type":"function"},{"doc":"Returns the IAM roles that are associated with the specified ACM (ACM)\ncertificate.\n\nIt also returns the name of the Amazon S3 bucket and the Amazon S3 object key\nwhere the certificate, certificate chain, and encrypted private key bundle are\nstored, and the ARN of the KMS key that's used to encrypt the private key.","ref":"AWS.EC2.html#get_associated_enclave_certificate_iam_roles/3","title":"AWS.EC2.get_associated_enclave_certificate_iam_roles/3","type":"function"},{"doc":"Gets information about the IPv6 CIDR block associations for a specified IPv6\naddress pool.","ref":"AWS.EC2.html#get_associated_ipv6_pool_cidrs/3","title":"AWS.EC2.get_associated_ipv6_pool_cidrs/3","type":"function"},{"doc":"Gets network performance data.","ref":"AWS.EC2.html#get_aws_network_performance_data/3","title":"AWS.EC2.get_aws_network_performance_data/3","type":"function"},{"doc":"Gets usage information about a Capacity Reservation.\n\nIf the Capacity Reservation is shared, it shows usage information for the\nCapacity Reservation owner and each Amazon Web Services account that is\ncurrently using the shared capacity. If the Capacity Reservation is not shared,\nit shows only the Capacity Reservation owner's usage.","ref":"AWS.EC2.html#get_capacity_reservation_usage/3","title":"AWS.EC2.get_capacity_reservation_usage/3","type":"function"},{"doc":"Describes the allocations from the specified customer-owned address pool.","ref":"AWS.EC2.html#get_coip_pool_usage/3","title":"AWS.EC2.get_coip_pool_usage/3","type":"function"},{"doc":"Gets the console output for the specified instance.\n\nFor Linux instances, the instance console output displays the exact console\noutput that would normally be displayed on a physical monitor attached to a\ncomputer. For Windows instances, the instance console output includes the last\nthree system event log errors.\n\nBy default, the console output returns buffered information that was posted\nshortly after an instance transition state (start, stop, reboot, or terminate).\nThis information is available for at least one hour after the most recent post.\nOnly the most recent 64 KB of console output is available.\n\nYou can optionally retrieve the latest serial console output at any time during\nthe instance lifecycle. This option is supported on instance types that use the\nNitro hypervisor.\n\nFor more information, see [Instance console output](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-console.html#instance-console-console-output)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#get_console_output/3","title":"AWS.EC2.get_console_output/3","type":"function"},{"doc":"Retrieve a JPG-format screenshot of a running instance to help with\ntroubleshooting.\n\nThe returned content is Base64-encoded.","ref":"AWS.EC2.html#get_console_screenshot/3","title":"AWS.EC2.get_console_screenshot/3","type":"function"},{"doc":"Describes the default credit option for CPU usage of a burstable performance\ninstance family.\n\nFor more information, see [Burstable performance instances](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/burstable-performance-instances.html)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#get_default_credit_specification/3","title":"AWS.EC2.get_default_credit_specification/3","type":"function"},{"doc":"Describes the default KMS key for EBS encryption by default for your account in\nthis Region.\n\nYou can change the default KMS key for encryption by default using\n`ModifyEbsDefaultKmsKeyId` or `ResetEbsDefaultKmsKeyId`.\n\nFor more information, see [Amazon EBS encryption](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSEncryption.html)\nin the *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.EC2.html#get_ebs_default_kms_key_id/3","title":"AWS.EC2.get_ebs_default_kms_key_id/3","type":"function"},{"doc":"Describes whether EBS encryption by default is enabled for your account in the\ncurrent Region.\n\nFor more information, see [Amazon EBS encryption](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSEncryption.html)\nin the *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.EC2.html#get_ebs_encryption_by_default/3","title":"AWS.EC2.get_ebs_encryption_by_default/3","type":"function"},{"doc":"Generates a CloudFormation template that streamlines and automates the\nintegration of VPC flow logs with Amazon Athena.\n\nThis make it easier for you to query and gain insights from VPC flow logs data.\nBased on the information that you provide, we configure resources in the\ntemplate to do the following:\n\n  * Create a table in Athena that maps fields to a custom log format\n\n  * Create a Lambda function that updates the table with new\npartitions on a daily, weekly, or monthly basis\n\n  * Create a table partitioned between two timestamps in the past\n\n  * Create a set of named queries in Athena that you can use to get\nstarted quickly\n\n`GetFlowLogsIntegrationTemplate` does not support integration between Amazon Web\nServices Transit Gateway Flow Logs and Amazon Athena.","ref":"AWS.EC2.html#get_flow_logs_integration_template/3","title":"AWS.EC2.get_flow_logs_integration_template/3","type":"function"},{"doc":"Lists the resource groups to which a Capacity Reservation has been added.","ref":"AWS.EC2.html#get_groups_for_capacity_reservation/3","title":"AWS.EC2.get_groups_for_capacity_reservation/3","type":"function"},{"doc":"Preview a reservation purchase with configurations that match those of your\nDedicated Host.\n\nYou must have active Dedicated Hosts in your account before you purchase a\nreservation.\n\nThis is a preview of the `PurchaseHostReservation` action and does not result in\nthe offering being purchased.","ref":"AWS.EC2.html#get_host_reservation_purchase_preview/3","title":"AWS.EC2.get_host_reservation_purchase_preview/3","type":"function"},{"doc":"Gets the current state of *block public access for AMIs* at the account level in\nthe specified Amazon Web Services Region.\n\nFor more information, see [Block public access to your AMIs](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/sharingamis-intro.html#block-public-access-to-amis)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#get_image_block_public_access_state/3","title":"AWS.EC2.get_image_block_public_access_state/3","type":"function"},{"doc":"Returns a list of instance types with the specified instance attributes.\n\nYou can use the response to preview the instance types without launching\ninstances. Note that the response does not consider capacity.\n\nWhen you specify multiple parameters, you get instance types that satisfy all of\nthe specified parameters. If you specify multiple values for a parameter, you\nget instance types that satisfy any of the specified values.\n\nFor more information, see [Preview instance types with specified attributes](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/spot-fleet-attribute-based-instance-type-selection.html#spotfleet-get-instance-types-from-instance-requirements),\n[Attribute-based instance type selection for EC2 Fleet](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-fleet-attribute-based-instance-type-selection.html),\n[Attribute-based instance type selection for Spot Fleet](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/spot-fleet-attribute-based-instance-type-selection.html),\nand [Spot placement score](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/spot-placement-score.html)\nin the *Amazon EC2 User Guide*, and [Creating an Auto Scaling group using attribute-based instance type\nselection](https://docs.aws.amazon.com/autoscaling/ec2/userguide/create-asg-instance-type-requirements.html)\nin the *Amazon EC2 Auto Scaling User Guide*.","ref":"AWS.EC2.html#get_instance_types_from_instance_requirements/3","title":"AWS.EC2.get_instance_types_from_instance_requirements/3","type":"function"},{"doc":"A binary representation of the UEFI variable store.\n\nOnly non-volatile variables are stored. This is a base64 encoded and zlib\ncompressed binary value that must be properly encoded.\n\nWhen you use\n[register-image](https://docs.aws.amazon.com/cli/latest/reference/ec2/register-image.html) to create an AMI, you can create an exact copy of your variable store by passing\nthe UEFI data in the `UefiData` parameter. You can modify the UEFI data by using\nthe [python-uefivars tool](https://github.com/awslabs/python-uefivars) on\nGitHub. You can use the tool to convert the UEFI data into a human-readable\nformat (JSON), which you can inspect and modify, and then convert back into the\nbinary format to use with register-image.\n\nFor more information, see [UEFI Secure Boot](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/uefi-secure-boot.html)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#get_instance_uefi_data/3","title":"AWS.EC2.get_instance_uefi_data/3","type":"function"},{"doc":"Retrieve historical information about a CIDR within an IPAM scope.\n\nFor more information, see [View the history of IP addresses](https://docs.aws.amazon.com/vpc/latest/ipam/view-history-cidr-ipam.html)\nin the *Amazon VPC IPAM User Guide*.","ref":"AWS.EC2.html#get_ipam_address_history/3","title":"AWS.EC2.get_ipam_address_history/3","type":"function"},{"doc":"Gets IPAM discovered accounts.\n\nA discovered account is an Amazon Web Services account that is monitored under a\nresource discovery. If you have integrated IPAM with Amazon Web Services\nOrganizations, all accounts in the organization are discovered accounts. Only\nthe IPAM account can get all discovered accounts in the organization.","ref":"AWS.EC2.html#get_ipam_discovered_accounts/3","title":"AWS.EC2.get_ipam_discovered_accounts/3","type":"function"},{"doc":"Gets the public IP addresses that have been discovered by IPAM.","ref":"AWS.EC2.html#get_ipam_discovered_public_addresses/3","title":"AWS.EC2.get_ipam_discovered_public_addresses/3","type":"function"},{"doc":"Returns the resource CIDRs that are monitored as part of a resource discovery.\n\nA discovered resource is a resource CIDR monitored under a resource discovery.\nThe following resources can be discovered: VPCs, Public IPv4 pools, VPC subnets,\nand Elastic IP addresses.","ref":"AWS.EC2.html#get_ipam_discovered_resource_cidrs/3","title":"AWS.EC2.get_ipam_discovered_resource_cidrs/3","type":"function"},{"doc":"Get a list of all the CIDR allocations in an IPAM pool.\n\nThe Region you use should be the IPAM pool locale. The locale is the Amazon Web\nServices Region where this IPAM pool is available for allocations.\n\nIf you use this action after\n[AllocateIpamPoolCidr](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AllocateIpamPoolCidr.html) or\n[ReleaseIpamPoolAllocation](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ReleaseIpamPoolAllocation.html),\nnote that all EC2 API actions follow an [eventual consistency](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/query-api-troubleshooting.html#eventual-consistency)\nmodel.","ref":"AWS.EC2.html#get_ipam_pool_allocations/3","title":"AWS.EC2.get_ipam_pool_allocations/3","type":"function"},{"doc":"Get the CIDRs provisioned to an IPAM pool.","ref":"AWS.EC2.html#get_ipam_pool_cidrs/3","title":"AWS.EC2.get_ipam_pool_cidrs/3","type":"function"},{"doc":"Returns resource CIDRs managed by IPAM in a given scope.\n\nIf an IPAM is associated with more than one resource discovery, the resource\nCIDRs across all of the resource discoveries is returned. A resource discovery\nis an IPAM component that enables IPAM to manage and monitor resources that\nbelong to the owning account.","ref":"AWS.EC2.html#get_ipam_resource_cidrs/3","title":"AWS.EC2.get_ipam_resource_cidrs/3","type":"function"},{"doc":"Retrieves the configuration data of the specified instance.\n\nYou can use this data to create a launch template.\n\nThis action calls on other describe actions to get instance information.\nDepending on your instance configuration, you may need to allow the following\nactions in your IAM policy: `DescribeSpotInstanceRequests`,\n`DescribeInstanceCreditSpecifications`, `DescribeVolumes`, and\n`DescribeInstanceAttribute`. Or, you can allow `describe*` depending on your\ninstance requirements.","ref":"AWS.EC2.html#get_launch_template_data/3","title":"AWS.EC2.get_launch_template_data/3","type":"function"},{"doc":"Gets information about the resources that are associated with the specified\nmanaged prefix list.","ref":"AWS.EC2.html#get_managed_prefix_list_associations/3","title":"AWS.EC2.get_managed_prefix_list_associations/3","type":"function"},{"doc":"Gets information about the entries for a specified managed prefix list.","ref":"AWS.EC2.html#get_managed_prefix_list_entries/3","title":"AWS.EC2.get_managed_prefix_list_entries/3","type":"function"},{"doc":"Gets the findings for the specified Network Access Scope analysis.","ref":"AWS.EC2.html#get_network_insights_access_scope_analysis_findings/3","title":"AWS.EC2.get_network_insights_access_scope_analysis_findings/3","type":"function"},{"doc":"Gets the content for the specified Network Access Scope.","ref":"AWS.EC2.html#get_network_insights_access_scope_content/3","title":"AWS.EC2.get_network_insights_access_scope_content/3","type":"function"},{"doc":"Retrieves the encrypted administrator password for a running Windows instance.\n\nThe Windows password is generated at boot by the `EC2Config` service or\n`EC2Launch` scripts (Windows Server 2016 and later). This usually only happens\nthe first time an instance is launched. For more information, see\n[EC2Config](https://docs.aws.amazon.com/AWSEC2/latest/WindowsGuide/UsingConfig_WinAMI.html) and\n[EC2Launch](https://docs.aws.amazon.com/AWSEC2/latest/WindowsGuide/ec2launch.html)\nin the *Amazon EC2 User Guide*.\n\nFor the `EC2Config` service, the password is not generated for rebundled AMIs\nunless `Ec2SetPassword` is enabled before bundling.\n\nThe password is encrypted using the key pair that you specified when you\nlaunched the instance. You must provide the corresponding key pair file.\n\nWhen you launch an instance, password generation and encryption may take a few\nminutes. If you try to retrieve the password before it's available, the output\nreturns an empty string. We recommend that you wait up to 15 minutes after\nlaunching an instance before trying to retrieve the generated password.","ref":"AWS.EC2.html#get_password_data/3","title":"AWS.EC2.get_password_data/3","type":"function"},{"doc":"Returns a quote and exchange information for exchanging one or more specified\nConvertible Reserved Instances for a new Convertible Reserved Instance.\n\nIf the exchange cannot be performed, the reason is returned in the response. Use\n`AcceptReservedInstancesExchangeQuote` to perform the exchange.","ref":"AWS.EC2.html#get_reserved_instances_exchange_quote/3","title":"AWS.EC2.get_reserved_instances_exchange_quote/3","type":"function"},{"doc":"Gets security groups that can be associated by the Amazon Web Services account\nmaking the request with network interfaces in the specified VPC.","ref":"AWS.EC2.html#get_security_groups_for_vpc/3","title":"AWS.EC2.get_security_groups_for_vpc/3","type":"function"},{"doc":"Retrieves the access status of your account to the EC2 serial console of all\ninstances.\n\nBy default, access to the EC2 serial console is disabled for your account. For\nmore information, see [Manage account access to the EC2 serial console](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/configure-access-to-serial-console.html#serial-console-account-access)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#get_serial_console_access_status/3","title":"AWS.EC2.get_serial_console_access_status/3","type":"function"},{"doc":"Gets the current state of *block public access for snapshots* setting for the\naccount and Region.\n\nFor more information, see [ Block public access for snapshots](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/block-public-access-snapshots.html)\nin the *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.EC2.html#get_snapshot_block_public_access_state/3","title":"AWS.EC2.get_snapshot_block_public_access_state/3","type":"function"},{"doc":"Calculates the Spot placement score for a Region or Availability Zone based on\nthe specified target capacity and compute requirements.\n\nYou can specify your compute requirements either by using\n`InstanceRequirementsWithMetadata` and letting Amazon EC2 choose the optimal\ninstance types to fulfill your Spot request, or you can specify the instance\ntypes by using `InstanceTypes`.\n\nFor more information, see [Spot placement score](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/spot-placement-score.html)\nin the Amazon EC2 User Guide.","ref":"AWS.EC2.html#get_spot_placement_scores/3","title":"AWS.EC2.get_spot_placement_scores/3","type":"function"},{"doc":"Gets information about the subnet CIDR reservations.","ref":"AWS.EC2.html#get_subnet_cidr_reservations/3","title":"AWS.EC2.get_subnet_cidr_reservations/3","type":"function"},{"doc":"Lists the route tables to which the specified resource attachment propagates\nroutes.","ref":"AWS.EC2.html#get_transit_gateway_attachment_propagations/3","title":"AWS.EC2.get_transit_gateway_attachment_propagations/3","type":"function"},{"doc":"Gets information about the associations for the transit gateway multicast\ndomain.","ref":"AWS.EC2.html#get_transit_gateway_multicast_domain_associations/3","title":"AWS.EC2.get_transit_gateway_multicast_domain_associations/3","type":"function"},{"doc":"Gets a list of the transit gateway policy table associations.","ref":"AWS.EC2.html#get_transit_gateway_policy_table_associations/3","title":"AWS.EC2.get_transit_gateway_policy_table_associations/3","type":"function"},{"doc":"Returns a list of transit gateway policy table entries.","ref":"AWS.EC2.html#get_transit_gateway_policy_table_entries/3","title":"AWS.EC2.get_transit_gateway_policy_table_entries/3","type":"function"},{"doc":"Gets information about the prefix list references in a specified transit gateway\nroute table.","ref":"AWS.EC2.html#get_transit_gateway_prefix_list_references/3","title":"AWS.EC2.get_transit_gateway_prefix_list_references/3","type":"function"},{"doc":"Gets information about the associations for the specified transit gateway route\ntable.","ref":"AWS.EC2.html#get_transit_gateway_route_table_associations/3","title":"AWS.EC2.get_transit_gateway_route_table_associations/3","type":"function"},{"doc":"Gets information about the route table propagations for the specified transit\ngateway route table.","ref":"AWS.EC2.html#get_transit_gateway_route_table_propagations/3","title":"AWS.EC2.get_transit_gateway_route_table_propagations/3","type":"function"},{"doc":"Get the Verified Access policy associated with the endpoint.","ref":"AWS.EC2.html#get_verified_access_endpoint_policy/3","title":"AWS.EC2.get_verified_access_endpoint_policy/3","type":"function"},{"doc":"Shows the contents of the Verified Access policy associated with the group.","ref":"AWS.EC2.html#get_verified_access_group_policy/3","title":"AWS.EC2.get_verified_access_group_policy/3","type":"function"},{"doc":"Download an Amazon Web Services-provided sample configuration file to be used\nwith the customer gateway device specified for your Site-to-Site VPN connection.","ref":"AWS.EC2.html#get_vpn_connection_device_sample_configuration/3","title":"AWS.EC2.get_vpn_connection_device_sample_configuration/3","type":"function"},{"doc":"Obtain a list of customer gateway devices for which sample configuration files\ncan be provided.\n\nThe request has no additional parameters. You can also see the list of device\ntypes with sample configuration files available under [Your customer gateway device](https://docs.aws.amazon.com/vpn/latest/s2svpn/your-cgw.html) in the\n*Amazon Web Services Site-to-Site VPN User Guide*.","ref":"AWS.EC2.html#get_vpn_connection_device_types/3","title":"AWS.EC2.get_vpn_connection_device_types/3","type":"function"},{"doc":"Get details of available tunnel endpoint maintenance.","ref":"AWS.EC2.html#get_vpn_tunnel_replacement_status/3","title":"AWS.EC2.get_vpn_tunnel_replacement_status/3","type":"function"},{"doc":"Uploads a client certificate revocation list to the specified Client VPN\nendpoint.\n\nUploading a client certificate revocation list overwrites the existing client\ncertificate revocation list.\n\nUploading a client certificate revocation list resets existing client\nconnections.","ref":"AWS.EC2.html#import_client_vpn_client_certificate_revocation_list/3","title":"AWS.EC2.import_client_vpn_client_certificate_revocation_list/3","type":"function"},{"doc":"To import your virtual machines (VMs) with a console-based experience, you can\nuse the *Import virtual machine images to Amazon Web Services* template in the\n[Migration Hub Orchestrator console](https://console.aws.amazon.com/migrationhub/orchestrator).\n\nFor more information, see the [ *Migration Hub Orchestrator User Guide*\n](https://docs.aws.amazon.com/migrationhub-orchestrator/latest/userguide/import-vm-images.html).\n\nImport single or multi-volume disk images or EBS snapshots into an Amazon\nMachine Image (AMI).\n\nAmazon Web Services VM Import/Export strongly recommends specifying a value for\neither the `--license-type` or `--usage-operation` parameter when you create a\nnew VM Import task. This ensures your operating system is licensed appropriately\nand your billing is optimized.\n\nFor more information, see [Importing a VM as an image using VM Import/Export](https://docs.aws.amazon.com/vm-import/latest/userguide/vmimport-image-import.html)\nin the *VM Import/Export User Guide*.","ref":"AWS.EC2.html#import_image/3","title":"AWS.EC2.import_image/3","type":"function"},{"doc":"We recommend that you use the [ `ImportImage`\n](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ImportImage.html)\nAPI.\n\nFor more information, see [Importing a VM as an image using VM Import/Export](https://docs.aws.amazon.com/vm-import/latest/userguide/vmimport-image-import.html)\nin the *VM Import/Export User Guide*.\n\nCreates an import instance task using metadata from the specified disk image.\n\nThis API action is not supported by the Command Line Interface (CLI). For\ninformation about using the Amazon EC2 CLI, which is deprecated, see [Importing a VM to Amazon\nEC2](https://awsdocs.s3.amazonaws.com/EC2/ec2-clt.pdf#UsingVirtualMachinesinAmazonEC2)\nin the *Amazon EC2 CLI Reference* PDF file.\n\nThis API action supports only single-volume VMs. To import multi-volume VMs, use\n`ImportImage` instead.\n\nFor information about the import manifest referenced by this API action, see [VM Import\nManifest](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/manifest.html).","ref":"AWS.EC2.html#import_instance/3","title":"AWS.EC2.import_instance/3","type":"function"},{"doc":"Imports the public key from an RSA or ED25519 key pair that you created with a\nthird-party tool.\n\nCompare this with `CreateKeyPair`, in which Amazon Web Services creates the key\npair and gives the keys to you (Amazon Web Services keeps a copy of the public\nkey). With ImportKeyPair, you create the key pair and give Amazon Web Services\njust the public key. The private key is never transferred between you and Amazon\nWeb Services.\n\nFor more information about key pairs, see [Amazon EC2 key pairs](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-key-pairs.html)\nin the *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.EC2.html#import_key_pair/3","title":"AWS.EC2.import_key_pair/3","type":"function"},{"doc":"Imports a disk into an EBS snapshot.\n\nFor more information, see [Importing a disk as a snapshot using VM Import/Export](https://docs.aws.amazon.com/vm-import/latest/userguide/vmimport-import-snapshot.html)\nin the *VM Import/Export User Guide*.","ref":"AWS.EC2.html#import_snapshot/3","title":"AWS.EC2.import_snapshot/3","type":"function"},{"doc":"Creates an import volume task using metadata from the specified disk image.\n\nThis API action supports only single-volume VMs. To import multi-volume VMs, use\n`ImportImage` instead. To import a disk to a snapshot, use `ImportSnapshot`\ninstead.\n\nThis API action is not supported by the Command Line Interface (CLI). For\ninformation about using the Amazon EC2 CLI, which is deprecated, see [Importing Disks to Amazon\nEBS](https://awsdocs.s3.amazonaws.com/EC2/ec2-clt.pdf#importing-your-volumes-into-amazon-ebs)\nin the *Amazon EC2 CLI Reference* PDF file.\n\nFor information about the import manifest referenced by this API action, see [VM Import\nManifest](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/manifest.html).","ref":"AWS.EC2.html#import_volume/3","title":"AWS.EC2.import_volume/3","type":"function"},{"doc":"Lists one or more AMIs that are currently in the Recycle Bin.\n\nFor more information, see [Recycle Bin](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/recycle-bin.html) in\nthe *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#list_images_in_recycle_bin/3","title":"AWS.EC2.list_images_in_recycle_bin/3","type":"function"},{"doc":"Lists one or more snapshots that are currently in the Recycle Bin.","ref":"AWS.EC2.html#list_snapshots_in_recycle_bin/3","title":"AWS.EC2.list_snapshots_in_recycle_bin/3","type":"function"},{"doc":"Locks an Amazon EBS snapshot in either *governance* or *compliance* mode to\nprotect it against accidental or malicious deletions for a specific duration.\n\nA locked snapshot can't be deleted.\n\nYou can also use this action to modify the lock settings for a snapshot that is\nalready locked. The allowed modifications depend on the lock mode and lock\nstate:\n\n  * If the snapshot is locked in governance mode, you can modify the\nlock mode and the lock duration or lock expiration date.\n\n  * If the snapshot is locked in compliance mode and it is in the\ncooling-off period, you can modify the lock mode and the lock duration or lock\nexpiration date.\n\n  * If the snapshot is locked in compliance mode and the cooling-off\nperiod has lapsed, you can only increase the lock duration or extend the lock\nexpiration date.","ref":"AWS.EC2.html#lock_snapshot/3","title":"AWS.EC2.lock_snapshot/3","type":"function"},{"doc":"","ref":"AWS.EC2.html#metadata/0","title":"AWS.EC2.metadata/0","type":"function"},{"doc":"Modifies an attribute of the specified Elastic IP address.\n\nFor requirements, see [Using reverse DNS for email applications](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/elastic-ip-addresses-eip.html#Using_Elastic_Addressing_Reverse_DNS).","ref":"AWS.EC2.html#modify_address_attribute/3","title":"AWS.EC2.modify_address_attribute/3","type":"function"},{"doc":"Changes the opt-in status of the Local Zone and Wavelength Zone group for your\naccount.\n\nUse [\nDescribeAvailabilityZones](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeAvailabilityZones.html)\nto view the value for `GroupName`.","ref":"AWS.EC2.html#modify_availability_zone_group/3","title":"AWS.EC2.modify_availability_zone_group/3","type":"function"},{"doc":"Modifies a Capacity Reservation's capacity and the conditions under which it is\nto be released.\n\nYou cannot change a Capacity Reservation's instance type, EBS optimization,\ninstance store settings, platform, Availability Zone, or instance eligibility.\nIf you need to modify any of these attributes, we recommend that you cancel the\nCapacity Reservation, and then create a new one with the required attributes.","ref":"AWS.EC2.html#modify_capacity_reservation/3","title":"AWS.EC2.modify_capacity_reservation/3","type":"function"},{"doc":"Modifies a Capacity Reservation Fleet.\n\nWhen you modify the total target capacity of a Capacity Reservation Fleet, the\nFleet automatically creates new Capacity Reservations, or modifies or cancels\nexisting Capacity Reservations in the Fleet to meet the new total target\ncapacity. When you modify the end date for the Fleet, the end dates for all of\nthe individual Capacity Reservations in the Fleet are updated accordingly.","ref":"AWS.EC2.html#modify_capacity_reservation_fleet/3","title":"AWS.EC2.modify_capacity_reservation_fleet/3","type":"function"},{"doc":"Modifies the specified Client VPN endpoint.\n\nModifying the DNS server resets existing client connections.","ref":"AWS.EC2.html#modify_client_vpn_endpoint/3","title":"AWS.EC2.modify_client_vpn_endpoint/3","type":"function"},{"doc":"Modifies the default credit option for CPU usage of burstable performance\ninstances.\n\nThe default credit option is set at the account level per Amazon Web Services\nRegion, and is specified per instance family. All new burstable performance\ninstances in the account launch using the default credit option.\n\n`ModifyDefaultCreditSpecification` is an asynchronous operation, which works at\nan Amazon Web Services Region level and modifies the credit option for each\nAvailability Zone. All zones in a Region are updated within five minutes. But if\ninstances are launched during this operation, they might not get the new credit\noption until the zone is updated. To verify whether the update has occurred, you\ncan call `GetDefaultCreditSpecification` and check `DefaultCreditSpecification`\nfor updates.\n\nFor more information, see [Burstable performance instances](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/burstable-performance-instances.html)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#modify_default_credit_specification/3","title":"AWS.EC2.modify_default_credit_specification/3","type":"function"},{"doc":"Changes the default KMS key for EBS encryption by default for your account in\nthis Region.\n\nAmazon Web Services creates a unique Amazon Web Services managed KMS key in each\nRegion for use with encryption by default. If you change the default KMS key to\na symmetric customer managed KMS key, it is used instead of the Amazon Web\nServices managed KMS key. To reset the default KMS key to the Amazon Web\nServices managed KMS key for EBS, use `ResetEbsDefaultKmsKeyId`. Amazon EBS does\nnot support asymmetric KMS keys.\n\nIf you delete or disable the customer managed KMS key that you specified for use\nwith encryption by default, your instances will fail to launch.\n\nFor more information, see [Amazon EBS encryption](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSEncryption.html)\nin the *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.EC2.html#modify_ebs_default_kms_key_id/3","title":"AWS.EC2.modify_ebs_default_kms_key_id/3","type":"function"},{"doc":"Modifies the specified EC2 Fleet.\n\nYou can only modify an EC2 Fleet request of type `maintain`.\n\nWhile the EC2 Fleet is being modified, it is in the `modifying` state.\n\nTo scale up your EC2 Fleet, increase its target capacity. The EC2 Fleet launches\nthe additional Spot Instances according to the allocation strategy for the EC2\nFleet request. If the allocation strategy is `lowest-price`, the EC2 Fleet\nlaunches instances using the Spot Instance pool with the lowest price. If the\nallocation strategy is `diversified`, the EC2 Fleet distributes the instances\nacross the Spot Instance pools. If the allocation strategy is\n`capacity-optimized`, EC2 Fleet launches instances from Spot Instance pools with\noptimal capacity for the number of instances that are launching.\n\nTo scale down your EC2 Fleet, decrease its target capacity. First, the EC2 Fleet\ncancels any open requests that exceed the new target capacity. You can request\nthat the EC2 Fleet terminate Spot Instances until the size of the fleet no\nlonger exceeds the new target capacity. If the allocation strategy is\n`lowest-price`, the EC2 Fleet terminates the instances with the highest price\nper unit. If the allocation strategy is `capacity-optimized`, the EC2 Fleet\nterminates the instances in the Spot Instance pools that have the least\navailable Spot Instance capacity. If the allocation strategy is `diversified`,\nthe EC2 Fleet terminates instances across the Spot Instance pools.\nAlternatively, you can request that the EC2 Fleet keep the fleet at its current\nsize, but not replace any Spot Instances that are interrupted or that you\nterminate manually.\n\nIf you are finished with your EC2 Fleet for now, but will use it again later,\nyou can set the target capacity to 0.","ref":"AWS.EC2.html#modify_fleet/3","title":"AWS.EC2.modify_fleet/3","type":"function"},{"doc":"Modifies the specified attribute of the specified Amazon FPGA Image (AFI).","ref":"AWS.EC2.html#modify_fpga_image_attribute/3","title":"AWS.EC2.modify_fpga_image_attribute/3","type":"function"},{"doc":"Modify the auto-placement setting of a Dedicated Host.\n\nWhen auto-placement is enabled, any instances that you launch with a tenancy of\n`host` but without a specific host ID are placed onto any available Dedicated\nHost in your account that has auto-placement enabled. When auto-placement is\ndisabled, you need to provide a host ID to have the instance launch onto a\nspecific host. If no host ID is provided, the instance is launched onto a\nsuitable host with auto-placement enabled.\n\nYou can also use this API action to modify a Dedicated Host to support either\nmultiple instance types in an instance family, or to support a specific instance\ntype only.","ref":"AWS.EC2.html#modify_hosts/3","title":"AWS.EC2.modify_hosts/3","type":"function"},{"doc":"Modifies the ID format for the specified resource on a per-Region basis.\n\nYou can specify that resources should receive longer IDs (17-character IDs) when\nthey are created.\n\nThis request can only be used to modify longer ID settings for resource types\nthat are within the opt-in period. Resources currently in their opt-in period\ninclude: `bundle` | `conversion-task` | `customer-gateway` | `dhcp-options` |\n`elastic-ip-allocation` | `elastic-ip-association` | `export-task` | `flow-log`\n| `image` | `import-task` | `internet-gateway` | `network-acl` |\n`network-acl-association` | `network-interface` | `network-interface-attachment`\n| `prefix-list` | `route-table` | `route-table-association` | `security-group` |\n`subnet` | `subnet-cidr-block-association` | `vpc` |\n`vpc-cidr-block-association` | `vpc-endpoint` | `vpc-peering-connection` |\n`vpn-connection` | `vpn-gateway`.\n\nThis setting applies to the IAM user who makes the request; it does not apply to\nthe entire Amazon Web Services account. By default, an IAM user defaults to the\nsame settings as the root user. If you're using this action as the root user,\nthen these settings apply to the entire account, unless an IAM user explicitly\noverrides these settings for themselves. For more information, see [Resource IDs](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/resource-ids.html) in\nthe *Amazon Elastic Compute Cloud User Guide*.\n\nResources created with longer IDs are visible to all IAM roles and users,\nregardless of these settings and provided that they have permission to use the\nrelevant `Describe` command for the resource type.","ref":"AWS.EC2.html#modify_id_format/3","title":"AWS.EC2.modify_id_format/3","type":"function"},{"doc":"Modifies the ID format of a resource for a specified IAM user, IAM role, or the\nroot user for an account; or all IAM users, IAM roles, and the root user for an\naccount.\n\nYou can specify that resources should receive longer IDs (17-character IDs) when\nthey are created.\n\nThis request can only be used to modify longer ID settings for resource types\nthat are within the opt-in period. Resources currently in their opt-in period\ninclude: `bundle` | `conversion-task` | `customer-gateway` | `dhcp-options` |\n`elastic-ip-allocation` | `elastic-ip-association` | `export-task` | `flow-log`\n| `image` | `import-task` | `internet-gateway` | `network-acl` |\n`network-acl-association` | `network-interface` | `network-interface-attachment`\n| `prefix-list` | `route-table` | `route-table-association` | `security-group` |\n`subnet` | `subnet-cidr-block-association` | `vpc` |\n`vpc-cidr-block-association` | `vpc-endpoint` | `vpc-peering-connection` |\n`vpn-connection` | `vpn-gateway`.\n\nFor more information, see [Resource IDs](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/resource-ids.html) in\nthe *Amazon Elastic Compute Cloud User Guide*.\n\nThis setting applies to the principal specified in the request; it does not\napply to the principal that makes the request.\n\nResources created with longer IDs are visible to all IAM roles and users,\nregardless of these settings and provided that they have permission to use the\nrelevant `Describe` command for the resource type.","ref":"AWS.EC2.html#modify_identity_id_format/3","title":"AWS.EC2.modify_identity_id_format/3","type":"function"},{"doc":"Modifies the specified attribute of the specified AMI.\n\nYou can specify only one attribute at a time.\n\nTo specify the attribute, you can use the `Attribute` parameter, or one of the\nfollowing parameters: `Description`, `ImdsSupport`, or `LaunchPermission`.\n\nImages with an Amazon Web Services Marketplace product code cannot be made\npublic.\n\nTo enable the SriovNetSupport enhanced networking attribute of an image, enable\nSriovNetSupport on an instance and create an AMI from the instance.","ref":"AWS.EC2.html#modify_image_attribute/3","title":"AWS.EC2.modify_image_attribute/3","type":"function"},{"doc":"Modifies the specified attribute of the specified instance.\n\nYou can specify only one attribute at a time.\n\n**Note: **Using this action to change the security groups associated with an\nelastic network interface (ENI) attached to an instance can result in an error\nif the instance has more than one ENI. To change the security groups associated\nwith an ENI attached to an instance that has multiple ENIs, we recommend that\nyou use the `ModifyNetworkInterfaceAttribute` action.\n\nTo modify some attributes, the instance must be stopped. For more information,\nsee [Modify a stopped instance](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Using_ChangingAttributesWhileInstanceStopped.html)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#modify_instance_attribute/3","title":"AWS.EC2.modify_instance_attribute/3","type":"function"},{"doc":"Modifies the Capacity Reservation settings for a stopped instance.\n\nUse this action to configure an instance to target a specific Capacity\nReservation, run in any `open` Capacity Reservation with matching attributes, or\nrun On-Demand Instance capacity.","ref":"AWS.EC2.html#modify_instance_capacity_reservation_attributes/3","title":"AWS.EC2.modify_instance_capacity_reservation_attributes/3","type":"function"},{"doc":"Modifies the credit option for CPU usage on a running or stopped burstable\nperformance instance.\n\nThe credit options are `standard` and `unlimited`.\n\nFor more information, see [Burstable performance instances](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/burstable-performance-instances.html)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#modify_instance_credit_specification/3","title":"AWS.EC2.modify_instance_credit_specification/3","type":"function"},{"doc":"Modifies the start time for a scheduled Amazon EC2 instance event.","ref":"AWS.EC2.html#modify_instance_event_start_time/3","title":"AWS.EC2.modify_instance_event_start_time/3","type":"function"},{"doc":"Modifies the specified event window.\n\nYou can define either a set of time ranges or a cron expression when modifying\nthe event window, but not both.\n\nTo modify the targets associated with the event window, use the\n`AssociateInstanceEventWindow` and `DisassociateInstanceEventWindow` API.\n\nIf Amazon Web Services has already scheduled an event, modifying an event window\nwon't change the time of the scheduled event.\n\nFor more information, see [Define event windows for scheduled events](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/event-windows.html)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#modify_instance_event_window/3","title":"AWS.EC2.modify_instance_event_window/3","type":"function"},{"doc":"Modifies the recovery behavior of your instance to disable simplified automatic\nrecovery or set the recovery behavior to default.\n\nThe default configuration will not enable simplified automatic recovery for an\nunsupported instance type. For more information, see [Simplified automatic recovery](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-instance-recover.html#instance-configuration-recovery).","ref":"AWS.EC2.html#modify_instance_maintenance_options/3","title":"AWS.EC2.modify_instance_maintenance_options/3","type":"function"},{"doc":"Modify the instance metadata parameters on a running or stopped instance.\n\nWhen you modify the parameters on a stopped instance, they are applied when the\ninstance is started. When you modify the parameters on a running instance, the\nAPI responds with a state of “pending”. After the parameter modifications are\nsuccessfully applied to the instance, the state of the modifications changes\nfrom “pending” to “applied” in subsequent describe-instances API calls. For more\ninformation, see [Instance metadata and user data](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-instance-metadata.html)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#modify_instance_metadata_options/3","title":"AWS.EC2.modify_instance_metadata_options/3","type":"function"},{"doc":"Modifies the placement attributes for a specified instance.\n\nYou can do the following:\n\n  * Modify the affinity between an instance and a [Dedicated Host](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/dedicated-hosts-overview.html).\nWhen affinity is set to `host` and the instance is not associated with a\nspecific Dedicated Host, the next time the instance is launched, it is\nautomatically associated with the host on which it lands. If the instance is\nrestarted or rebooted, this relationship persists.\n\n  * Change the Dedicated Host with which an instance is associated.\n\n  * Change the instance tenancy of an instance.\n\n  * Move an instance to or from a [placement group](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/placement-groups.html).\n\nAt least one attribute for affinity, host ID, tenancy, or placement group name\nmust be specified in the request. Affinity and tenancy can be modified in the\nsame request.\n\nTo modify the host ID, tenancy, placement group, or partition for an instance,\nthe instance must be in the `stopped` state.","ref":"AWS.EC2.html#modify_instance_placement/3","title":"AWS.EC2.modify_instance_placement/3","type":"function"},{"doc":"Modify the configurations of an IPAM.","ref":"AWS.EC2.html#modify_ipam/3","title":"AWS.EC2.modify_ipam/3","type":"function"},{"doc":"Modify the configurations of an IPAM pool.\n\nFor more information, see [Modify a pool](https://docs.aws.amazon.com/vpc/latest/ipam/mod-pool-ipam.html) in the\n*Amazon VPC IPAM User Guide*.","ref":"AWS.EC2.html#modify_ipam_pool/3","title":"AWS.EC2.modify_ipam_pool/3","type":"function"},{"doc":"Modify a resource CIDR.\n\nYou can use this action to transfer resource CIDRs between scopes and ignore\nresource CIDRs that you do not want to manage. If set to false, the resource\nwill not be tracked for overlap, it cannot be auto-imported into a pool, and it\nwill be removed from any pool it has an allocation in.\n\nFor more information, see [Move resource CIDRs between scopes](https://docs.aws.amazon.com/vpc/latest/ipam/move-resource-ipam.html) and\n[Change the monitoring state of resource CIDRs](https://docs.aws.amazon.com/vpc/latest/ipam/change-monitoring-state-ipam.html)\nin the *Amazon VPC IPAM User Guide*.","ref":"AWS.EC2.html#modify_ipam_resource_cidr/3","title":"AWS.EC2.modify_ipam_resource_cidr/3","type":"function"},{"doc":"Modifies a resource discovery.\n\nA resource discovery is an IPAM component that enables IPAM to manage and\nmonitor resources that belong to the owning account.","ref":"AWS.EC2.html#modify_ipam_resource_discovery/3","title":"AWS.EC2.modify_ipam_resource_discovery/3","type":"function"},{"doc":"Modify an IPAM scope.","ref":"AWS.EC2.html#modify_ipam_scope/3","title":"AWS.EC2.modify_ipam_scope/3","type":"function"},{"doc":"Modifies a launch template.\n\nYou can specify which version of the launch template to set as the default\nversion. When launching an instance, the default version applies when a launch\ntemplate version is not specified.","ref":"AWS.EC2.html#modify_launch_template/3","title":"AWS.EC2.modify_launch_template/3","type":"function"},{"doc":"Modifies the specified local gateway route.","ref":"AWS.EC2.html#modify_local_gateway_route/3","title":"AWS.EC2.modify_local_gateway_route/3","type":"function"},{"doc":"Modifies the specified managed prefix list.\n\nAdding or removing entries in a prefix list creates a new version of the prefix\nlist. Changing the name of the prefix list does not affect the version.\n\nIf you specify a current version number that does not match the true current\nversion number, the request fails.","ref":"AWS.EC2.html#modify_managed_prefix_list/3","title":"AWS.EC2.modify_managed_prefix_list/3","type":"function"},{"doc":"Modifies the specified network interface attribute.\n\nYou can specify only one attribute at a time. You can use this action to attach\nand detach security groups from an existing EC2 instance.","ref":"AWS.EC2.html#modify_network_interface_attribute/3","title":"AWS.EC2.modify_network_interface_attribute/3","type":"function"},{"doc":"Modifies the options for instance hostnames for the specified instance.","ref":"AWS.EC2.html#modify_private_dns_name_options/3","title":"AWS.EC2.modify_private_dns_name_options/3","type":"function"},{"doc":"Modifies the configuration of your Reserved Instances, such as the Availability\nZone, instance count, or instance type.\n\nThe Reserved Instances to be modified must be identical, except for Availability\nZone, network platform, and instance type.\n\nFor more information, see [Modifying Reserved Instances](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ri-modifying.html)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#modify_reserved_instances/3","title":"AWS.EC2.modify_reserved_instances/3","type":"function"},{"doc":"Modifies the rules of a security group.","ref":"AWS.EC2.html#modify_security_group_rules/3","title":"AWS.EC2.modify_security_group_rules/3","type":"function"},{"doc":"Adds or removes permission settings for the specified snapshot.\n\nYou may add or remove specified Amazon Web Services account IDs from a\nsnapshot's list of create volume permissions, but you cannot do both in a single\noperation. If you need to both add and remove account IDs for a snapshot, you\nmust use multiple operations. You can make up to 500 modifications to a snapshot\nin a single operation.\n\nEncrypted snapshots and snapshots with Amazon Web Services Marketplace product\ncodes cannot be made public. Snapshots encrypted with your default KMS key\ncannot be shared with other accounts.\n\nFor more information about modifying snapshot permissions, see [Share a snapshot](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ebs-modifying-snapshot-permissions.html)\nin the *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.EC2.html#modify_snapshot_attribute/3","title":"AWS.EC2.modify_snapshot_attribute/3","type":"function"},{"doc":"Archives an Amazon EBS snapshot.\n\nWhen you archive a snapshot, it is converted to a full snapshot that includes\nall of the blocks of data that were written to the volume at the time the\nsnapshot was created, and moved from the standard tier to the archive tier. For\nmore information, see [Archive Amazon EBS snapshots](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/snapshot-archive.html)\nin the *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.EC2.html#modify_snapshot_tier/3","title":"AWS.EC2.modify_snapshot_tier/3","type":"function"},{"doc":"Modifies the specified Spot Fleet request.\n\nYou can only modify a Spot Fleet request of type `maintain`.\n\nWhile the Spot Fleet request is being modified, it is in the `modifying` state.\n\nTo scale up your Spot Fleet, increase its target capacity. The Spot Fleet\nlaunches the additional Spot Instances according to the allocation strategy for\nthe Spot Fleet request. If the allocation strategy is `lowestPrice`, the Spot\nFleet launches instances using the Spot Instance pool with the lowest price. If\nthe allocation strategy is `diversified`, the Spot Fleet distributes the\ninstances across the Spot Instance pools. If the allocation strategy is\n`capacityOptimized`, Spot Fleet launches instances from Spot Instance pools with\noptimal capacity for the number of instances that are launching.\n\nTo scale down your Spot Fleet, decrease its target capacity. First, the Spot\nFleet cancels any open requests that exceed the new target capacity. You can\nrequest that the Spot Fleet terminate Spot Instances until the size of the fleet\nno longer exceeds the new target capacity. If the allocation strategy is\n`lowestPrice`, the Spot Fleet terminates the instances with the highest price\nper unit. If the allocation strategy is `capacityOptimized`, the Spot Fleet\nterminates the instances in the Spot Instance pools that have the least\navailable Spot Instance capacity. If the allocation strategy is `diversified`,\nthe Spot Fleet terminates instances across the Spot Instance pools.\nAlternatively, you can request that the Spot Fleet keep the fleet at its current\nsize, but not replace any Spot Instances that are interrupted or that you\nterminate manually.\n\nIf you are finished with your Spot Fleet for now, but will use it again later,\nyou can set the target capacity to 0.","ref":"AWS.EC2.html#modify_spot_fleet_request/3","title":"AWS.EC2.modify_spot_fleet_request/3","type":"function"},{"doc":"Modifies a subnet attribute.\n\nYou can only modify one attribute at a time.\n\nUse this action to modify subnets on Amazon Web Services Outposts.\n\n  * To modify a subnet on an Outpost rack, set both\n`MapCustomerOwnedIpOnLaunch` and `CustomerOwnedIpv4Pool`. These two parameters\nact as a single attribute.\n\n  * To modify a subnet on an Outpost server, set either\n`EnableLniAtDeviceIndex` or `DisableLniAtDeviceIndex`.\n\nFor more information about Amazon Web Services Outposts, see the following:\n\n  * [Outpost servers](https://docs.aws.amazon.com/outposts/latest/userguide/how-servers-work.html)\n\n  * [Outpost racks](https://docs.aws.amazon.com/outposts/latest/userguide/how-racks-work.html)","ref":"AWS.EC2.html#modify_subnet_attribute/3","title":"AWS.EC2.modify_subnet_attribute/3","type":"function"},{"doc":"Allows or restricts mirroring network services.\n\nBy default, Amazon DNS network services are not eligible for Traffic Mirror. Use\n`AddNetworkServices` to add network services to a Traffic Mirror filter. When a\nnetwork service is added to the Traffic Mirror filter, all traffic related to\nthat network service will be mirrored. When you no longer want to mirror network\nservices, use `RemoveNetworkServices` to remove the network services from the\nTraffic Mirror filter.","ref":"AWS.EC2.html#modify_traffic_mirror_filter_network_services/3","title":"AWS.EC2.modify_traffic_mirror_filter_network_services/3","type":"function"},{"doc":"Modifies the specified Traffic Mirror rule.\n\n`DestinationCidrBlock` and `SourceCidrBlock` must both be an IPv4 range or an\nIPv6 range.","ref":"AWS.EC2.html#modify_traffic_mirror_filter_rule/3","title":"AWS.EC2.modify_traffic_mirror_filter_rule/3","type":"function"},{"doc":"Modifies a Traffic Mirror session.","ref":"AWS.EC2.html#modify_traffic_mirror_session/3","title":"AWS.EC2.modify_traffic_mirror_session/3","type":"function"},{"doc":"Modifies the specified transit gateway.\n\nWhen you modify a transit gateway, the modified options are applied to new\ntransit gateway attachments only. Your existing transit gateway attachments are\nnot modified.","ref":"AWS.EC2.html#modify_transit_gateway/3","title":"AWS.EC2.modify_transit_gateway/3","type":"function"},{"doc":"Modifies a reference (route) to a prefix list in a specified transit gateway\nroute table.","ref":"AWS.EC2.html#modify_transit_gateway_prefix_list_reference/3","title":"AWS.EC2.modify_transit_gateway_prefix_list_reference/3","type":"function"},{"doc":"Modifies the specified VPC attachment.","ref":"AWS.EC2.html#modify_transit_gateway_vpc_attachment/3","title":"AWS.EC2.modify_transit_gateway_vpc_attachment/3","type":"function"},{"doc":"Modifies the configuration of the specified Amazon Web Services Verified Access\nendpoint.","ref":"AWS.EC2.html#modify_verified_access_endpoint/3","title":"AWS.EC2.modify_verified_access_endpoint/3","type":"function"},{"doc":"Modifies the specified Amazon Web Services Verified Access endpoint policy.","ref":"AWS.EC2.html#modify_verified_access_endpoint_policy/3","title":"AWS.EC2.modify_verified_access_endpoint_policy/3","type":"function"},{"doc":"Modifies the specified Amazon Web Services Verified Access group configuration.","ref":"AWS.EC2.html#modify_verified_access_group/3","title":"AWS.EC2.modify_verified_access_group/3","type":"function"},{"doc":"Modifies the specified Amazon Web Services Verified Access group policy.","ref":"AWS.EC2.html#modify_verified_access_group_policy/3","title":"AWS.EC2.modify_verified_access_group_policy/3","type":"function"},{"doc":"Modifies the configuration of the specified Amazon Web Services Verified Access\ninstance.","ref":"AWS.EC2.html#modify_verified_access_instance/3","title":"AWS.EC2.modify_verified_access_instance/3","type":"function"},{"doc":"Modifies the logging configuration for the specified Amazon Web Services\nVerified Access instance.","ref":"AWS.EC2.html#modify_verified_access_instance_logging_configuration/3","title":"AWS.EC2.modify_verified_access_instance_logging_configuration/3","type":"function"},{"doc":"Modifies the configuration of the specified Amazon Web Services Verified Access\ntrust provider.","ref":"AWS.EC2.html#modify_verified_access_trust_provider/3","title":"AWS.EC2.modify_verified_access_trust_provider/3","type":"function"},{"doc":"You can modify several parameters of an existing EBS volume, including volume\nsize, volume type, and IOPS capacity.\n\nIf your EBS volume is attached to a current-generation EC2 instance type, you\nmight be able to apply these changes without stopping the instance or detaching\nthe volume from it. For more information about modifying EBS volumes, see\n[Amazon EBS Elastic Volumes](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ebs-modify-volume.html)\n(Linux instances) or [Amazon EBS Elastic Volumes](https://docs.aws.amazon.com/AWSEC2/latest/WindowsGuide/ebs-modify-volume.html)\n(Windows instances).\n\nWhen you complete a resize operation on your volume, you need to extend the\nvolume's file-system size to take advantage of the new storage capacity. For\nmore information, see [Extend a Linux file system](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ebs-expand-volume.html#recognize-expanded-volume-linux)\nor [Extend a Windows file system](https://docs.aws.amazon.com/AWSEC2/latest/WindowsGuide/ebs-expand-volume.html#recognize-expanded-volume-windows).\n\nYou can use CloudWatch Events to check the status of a modification to an EBS\nvolume. For information about CloudWatch Events, see the [Amazon CloudWatch Events User Guide](https://docs.aws.amazon.com/AmazonCloudWatch/latest/events/).\nYou can also track the status of a modification using\n`DescribeVolumesModifications`. For information about tracking status changes\nusing either method, see [Monitor the progress of volume modifications](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/monitoring-volume-modifications.html).\n\nWith previous-generation instance types, resizing an EBS volume might require\ndetaching and reattaching the volume or stopping and restarting the instance.\n\nAfter modifying a volume, you must wait at least six hours and ensure that the\nvolume is in the `in-use` or `available` state before you can modify the same\nvolume. This is sometimes referred to as a cooldown period.","ref":"AWS.EC2.html#modify_volume/3","title":"AWS.EC2.modify_volume/3","type":"function"},{"doc":"Modifies a volume attribute.\n\nBy default, all I/O operations for the volume are suspended when the data on the\nvolume is determined to be potentially inconsistent, to prevent undetectable,\nlatent data corruption. The I/O access to the volume can be resumed by first\nenabling I/O access and then checking the data consistency on your volume.\n\nYou can change the default behavior to resume I/O operations. We recommend that\nyou change this only for boot volumes or for volumes that are stateless or\ndisposable.","ref":"AWS.EC2.html#modify_volume_attribute/3","title":"AWS.EC2.modify_volume_attribute/3","type":"function"},{"doc":"Modifies the specified attribute of the specified VPC.","ref":"AWS.EC2.html#modify_vpc_attribute/3","title":"AWS.EC2.modify_vpc_attribute/3","type":"function"},{"doc":"Modifies attributes of a specified VPC endpoint.\n\nThe attributes that you can modify depend on the type of VPC endpoint\n(interface, gateway, or Gateway Load Balancer). For more information, see the\n[Amazon Web Services PrivateLink Guide](https://docs.aws.amazon.com/vpc/latest/privatelink/).","ref":"AWS.EC2.html#modify_vpc_endpoint/3","title":"AWS.EC2.modify_vpc_endpoint/3","type":"function"},{"doc":"Modifies a connection notification for VPC endpoint or VPC endpoint service.\n\nYou can change the SNS topic for the notification, or the events for which to be\nnotified.","ref":"AWS.EC2.html#modify_vpc_endpoint_connection_notification/3","title":"AWS.EC2.modify_vpc_endpoint_connection_notification/3","type":"function"},{"doc":"Modifies the attributes of your VPC endpoint service configuration.\n\nYou can change the Network Load Balancers or Gateway Load Balancers for your\nservice, and you can specify whether acceptance is required for requests to\nconnect to your endpoint service through an interface VPC endpoint.\n\nIf you set or modify the private DNS name, you must prove that you own the\nprivate DNS domain name.","ref":"AWS.EC2.html#modify_vpc_endpoint_service_configuration/3","title":"AWS.EC2.modify_vpc_endpoint_service_configuration/3","type":"function"},{"doc":"Modifies the payer responsibility for your VPC endpoint service.","ref":"AWS.EC2.html#modify_vpc_endpoint_service_payer_responsibility/3","title":"AWS.EC2.modify_vpc_endpoint_service_payer_responsibility/3","type":"function"},{"doc":"Modifies the permissions for your VPC endpoint service.\n\nYou can add or remove permissions for service consumers (Amazon Web Services\naccounts, users, and IAM roles) to connect to your endpoint service.\n\nIf you grant permissions to all principals, the service is public. Any users who\nknow the name of a public service can send a request to attach an endpoint. If\nthe service does not require manual approval, attachments are automatically\napproved.","ref":"AWS.EC2.html#modify_vpc_endpoint_service_permissions/3","title":"AWS.EC2.modify_vpc_endpoint_service_permissions/3","type":"function"},{"doc":"Modifies the VPC peering connection options on one side of a VPC peering\nconnection.\n\nIf the peered VPCs are in the same Amazon Web Services account, you can enable\nDNS resolution for queries from the local VPC. This ensures that queries from\nthe local VPC resolve to private IP addresses in the peer VPC. This option is\nnot available if the peered VPCs are in different Amazon Web Services accounts\nor different Regions. For peered VPCs in different Amazon Web Services accounts,\neach Amazon Web Services account owner must initiate a separate request to\nmodify the peering connection options. For inter-region peering connections, you\nmust use the Region for the requester VPC to modify the requester VPC peering\noptions and the Region for the accepter VPC to modify the accepter VPC peering\noptions. To verify which VPCs are the accepter and the requester for a VPC\npeering connection, use the `DescribeVpcPeeringConnections` command.","ref":"AWS.EC2.html#modify_vpc_peering_connection_options/3","title":"AWS.EC2.modify_vpc_peering_connection_options/3","type":"function"},{"doc":"Modifies the instance tenancy attribute of the specified VPC.\n\nYou can change the instance tenancy attribute of a VPC to `default` only. You\ncannot change the instance tenancy attribute to `dedicated`.\n\nAfter you modify the tenancy of the VPC, any new instances that you launch into\nthe VPC have a tenancy of `default`, unless you specify otherwise during launch.\nThe tenancy of any existing instances in the VPC is not affected.\n\nFor more information, see [Dedicated Instances](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/dedicated-instance.html)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#modify_vpc_tenancy/3","title":"AWS.EC2.modify_vpc_tenancy/3","type":"function"},{"doc":"Modifies the customer gateway or the target gateway of an Amazon Web Services\nSite-to-Site VPN connection.\n\nTo modify the target gateway, the following migration options are available:\n\n  * An existing virtual private gateway to a new virtual private\ngateway\n\n  * An existing virtual private gateway to a transit gateway\n\n  * An existing transit gateway to a new transit gateway\n\n  * An existing transit gateway to a virtual private gateway\n\nBefore you perform the migration to the new gateway, you must configure the new\ngateway. Use `CreateVpnGateway` to create a virtual private gateway, or\n`CreateTransitGateway` to create a transit gateway.\n\nThis step is required when you migrate from a virtual private gateway with\nstatic routes to a transit gateway.\n\nYou must delete the static routes before you migrate to the new gateway.\n\nKeep a copy of the static route before you delete it. You will need to add back\nthese routes to the transit gateway after the VPN connection migration is\ncomplete.\n\nAfter you migrate to the new gateway, you might need to modify your VPC route\ntable. Use `CreateRoute` and `DeleteRoute` to make the changes described in\n[Update VPC route tables](https://docs.aws.amazon.com/vpn/latest/s2svpn/modify-vpn-target.html#step-update-routing)\nin the *Amazon Web Services Site-to-Site VPN User Guide*.\n\nWhen the new gateway is a transit gateway, modify the transit gateway route\ntable to allow traffic between the VPC and the Amazon Web Services Site-to-Site\nVPN connection. Use `CreateTransitGatewayRoute` to add the routes.\n\nIf you deleted VPN static routes, you must add the static routes to the transit\ngateway route table.\n\nAfter you perform this operation, the VPN endpoint's IP addresses on the Amazon\nWeb Services side and the tunnel options remain intact. Your Amazon Web Services\nSite-to-Site VPN connection will be temporarily unavailable for a brief period\nwhile we provision the new endpoints.","ref":"AWS.EC2.html#modify_vpn_connection/3","title":"AWS.EC2.modify_vpn_connection/3","type":"function"},{"doc":"Modifies the connection options for your Site-to-Site VPN connection.\n\nWhen you modify the VPN connection options, the VPN endpoint IP addresses on the\nAmazon Web Services side do not change, and the tunnel options do not change.\nYour VPN connection will be temporarily unavailable for a brief period while the\nVPN connection is updated.","ref":"AWS.EC2.html#modify_vpn_connection_options/3","title":"AWS.EC2.modify_vpn_connection_options/3","type":"function"},{"doc":"Modifies the VPN tunnel endpoint certificate.","ref":"AWS.EC2.html#modify_vpn_tunnel_certificate/3","title":"AWS.EC2.modify_vpn_tunnel_certificate/3","type":"function"},{"doc":"Modifies the options for a VPN tunnel in an Amazon Web Services Site-to-Site VPN\nconnection.\n\nYou can modify multiple options for a tunnel in a single request, but you can\nonly modify one tunnel at a time. For more information, see [Site-to-Site VPN tunnel options for your Site-to-Site VPN\nconnection](https://docs.aws.amazon.com/vpn/latest/s2svpn/VPNTunnels.html) in\nthe *Amazon Web Services Site-to-Site VPN User Guide*.","ref":"AWS.EC2.html#modify_vpn_tunnel_options/3","title":"AWS.EC2.modify_vpn_tunnel_options/3","type":"function"},{"doc":"Enables detailed monitoring for a running instance.\n\nOtherwise, basic monitoring is enabled. For more information, see [Monitor your instances using\nCloudWatch](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/using-cloudwatch.html)\nin the *Amazon EC2 User Guide*.\n\nTo disable detailed monitoring, see\n[UnmonitorInstances](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_UnmonitorInstances.html).","ref":"AWS.EC2.html#monitor_instances/3","title":"AWS.EC2.monitor_instances/3","type":"function"},{"doc":"This action is deprecated.\n\nMoves an Elastic IP address from the EC2-Classic platform to the EC2-VPC\nplatform. The Elastic IP address must be allocated to your account for more than\n24 hours, and it must not be associated with an instance. After the Elastic IP\naddress is moved, it is no longer available for use in the EC2-Classic platform,\nunless you move it back using the `RestoreAddressToClassic` request. You cannot\nmove an Elastic IP address that was originally allocated for use in the EC2-VPC\nplatform to the EC2-Classic platform.","ref":"AWS.EC2.html#move_address_to_vpc/3","title":"AWS.EC2.move_address_to_vpc/3","type":"function"},{"doc":"Move a BYOIPv4 CIDR to IPAM from a public IPv4 pool.\n\nIf you already have a BYOIPv4 CIDR with Amazon Web Services, you can move the\nCIDR to IPAM from a public IPv4 pool. You cannot move an IPv6 CIDR to IPAM. If\nyou are bringing a new IP address to Amazon Web Services for the first time,\ncomplete the steps in [Tutorial: BYOIP address CIDRs to IPAM](https://docs.aws.amazon.com/vpc/latest/ipam/tutorials-byoip-ipam.html).","ref":"AWS.EC2.html#move_byoip_cidr_to_ipam/3","title":"AWS.EC2.move_byoip_cidr_to_ipam/3","type":"function"},{"doc":"Provisions an IPv4 or IPv6 address range for use with your Amazon Web Services\nresources through bring your own IP addresses (BYOIP) and creates a\ncorresponding address pool.\n\nAfter the address range is provisioned, it is ready to be advertised using\n`AdvertiseByoipCidr`.\n\nAmazon Web Services verifies that you own the address range and are authorized\nto advertise it. You must ensure that the address range is registered to you and\nthat you created an RPKI ROA to authorize Amazon ASNs 16509 and 14618 to\nadvertise the address range. For more information, see [Bring your own IP addresses\n(BYOIP)](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-byoip.html) in\nthe *Amazon Elastic Compute Cloud User Guide*.\n\nProvisioning an address range is an asynchronous operation, so the call returns\nimmediately, but the address range is not ready to use until its status changes\nfrom `pending-provision` to `provisioned`. To monitor the status of an address\nrange, use `DescribeByoipCidrs`. To allocate an Elastic IP address from your\nIPv4 address pool, use `AllocateAddress` with either the specific address from\nthe address pool or the ID of the address pool.","ref":"AWS.EC2.html#provision_byoip_cidr/3","title":"AWS.EC2.provision_byoip_cidr/3","type":"function"},{"doc":"Provisions your Autonomous System Number (ASN) for use in your Amazon Web\nServices account.\n\nThis action requires authorization context for Amazon to bring the ASN to an\nAmazon Web Services account. For more information, see [Tutorial: Bring your ASN to IPAM](https://docs.aws.amazon.com/vpc/latest/ipam/tutorials-byoasn.html) in\nthe *Amazon VPC IPAM guide*.","ref":"AWS.EC2.html#provision_ipam_byoasn/3","title":"AWS.EC2.provision_ipam_byoasn/3","type":"function"},{"doc":"Provision a CIDR to an IPAM pool.\n\nYou can use this action to provision new CIDRs to a top-level pool or to\ntransfer a CIDR from a top-level pool to a pool within it.\n\nFor more information, see [Provision CIDRs to pools](https://docs.aws.amazon.com/vpc/latest/ipam/prov-cidr-ipam.html) in the\n*Amazon VPC IPAM User Guide*.","ref":"AWS.EC2.html#provision_ipam_pool_cidr/3","title":"AWS.EC2.provision_ipam_pool_cidr/3","type":"function"},{"doc":"Provision a CIDR to a public IPv4 pool.\n\nFor more information about IPAM, see [What is IPAM?](https://docs.aws.amazon.com/vpc/latest/ipam/what-is-it-ipam.html) in the\n*Amazon VPC IPAM User Guide*.","ref":"AWS.EC2.html#provision_public_ipv4_pool_cidr/3","title":"AWS.EC2.provision_public_ipv4_pool_cidr/3","type":"function"},{"doc":"Purchase the Capacity Block for use with your account.\n\nWith Capacity Blocks you ensure GPU capacity is available for machine learning\n(ML) workloads. You must specify the ID of the Capacity Block offering you are\npurchasing.","ref":"AWS.EC2.html#purchase_capacity_block/3","title":"AWS.EC2.purchase_capacity_block/3","type":"function"},{"doc":"Purchase a reservation with configurations that match those of your Dedicated\nHost.\n\nYou must have active Dedicated Hosts in your account before you purchase a\nreservation. This action results in the specified reservation being purchased\nand charged to your account.","ref":"AWS.EC2.html#purchase_host_reservation/3","title":"AWS.EC2.purchase_host_reservation/3","type":"function"},{"doc":"Purchases a Reserved Instance for use with your account.\n\nWith Reserved Instances, you pay a lower hourly rate compared to On-Demand\ninstance pricing.\n\nUse `DescribeReservedInstancesOfferings` to get a list of Reserved Instance\nofferings that match your specifications. After you've purchased a Reserved\nInstance, you can check for your new Reserved Instance with\n`DescribeReservedInstances`.\n\nTo queue a purchase for a future date and time, specify a purchase time. If you\ndo not specify a purchase time, the default is the current time.\n\nFor more information, see [Reserved Instances](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/concepts-on-demand-reserved-instances.html)\nand [Reserved Instance Marketplace](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ri-market-general.html)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#purchase_reserved_instances_offering/3","title":"AWS.EC2.purchase_reserved_instances_offering/3","type":"function"},{"doc":"You can no longer purchase Scheduled Instances.\n\nPurchases the Scheduled Instances with the specified schedule.\n\nScheduled Instances enable you to purchase Amazon EC2 compute capacity by the\nhour for a one-year term. Before you can purchase a Scheduled Instance, you must\ncall `DescribeScheduledInstanceAvailability` to check for available schedules\nand obtain a purchase token. After you purchase a Scheduled Instance, you must\ncall `RunScheduledInstances` during each scheduled time period.\n\nAfter you purchase a Scheduled Instance, you can't cancel, modify, or resell\nyour purchase.","ref":"AWS.EC2.html#purchase_scheduled_instances/3","title":"AWS.EC2.purchase_scheduled_instances/3","type":"function"},{"doc":"Requests a reboot of the specified instances.\n\nThis operation is asynchronous; it only queues a request to reboot the specified\ninstances. The operation succeeds if the instances are valid and belong to you.\nRequests to reboot terminated instances are ignored.\n\nIf an instance does not cleanly shut down within a few minutes, Amazon EC2\nperforms a hard reboot.\n\nFor more information about troubleshooting, see [Troubleshoot an unreachable instance](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-console.html)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#reboot_instances/3","title":"AWS.EC2.reboot_instances/3","type":"function"},{"doc":"Registers an AMI.\n\nWhen you're creating an AMI, this is the final step you must complete before you\ncan launch an instance from the AMI. For more information about creating AMIs,\nsee [Create your own AMI](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/creating-an-ami.html)\nin the *Amazon Elastic Compute Cloud User Guide*.\n\nFor Amazon EBS-backed instances, `CreateImage` creates and registers the AMI in\na single request, so you don't have to register the AMI yourself. We recommend\nthat you always use `CreateImage` unless you have a specific reason to use\nRegisterImage.\n\nIf needed, you can deregister an AMI at any time. Any modifications you make to\nan AMI backed by an instance store volume invalidates its registration. If you\nmake changes to an image, deregister the previous image and register the new\nimage.","ref":"AWS.EC2.html#register_image/3","title":"AWS.EC2.register_image/3","type":"function"},{"doc":"You can use `RegisterImage` to create an Amazon EBS-backed Linux AMI from a\nsnapshot of a root device volume. You specify the snapshot using a block device\nmapping. You can't set the encryption state of the volume using the block device\nmapping. If the snapshot is encrypted, or encryption by default is enabled, the\nroot volume of an instance launched from the AMI is encrypted.\n\nFor more information, see [Create a Linux AMI from a snapshot](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/creating-an-ami-ebs.html#creating-launching-ami-from-snapshot)\nand [Use encryption with Amazon EBS-backed AMIs](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/AMIEncryption.html) in\nthe *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.EC2.html#register_image/3-register-a-snapshot-of-a-root-device-volume","title":"Register a snapshot of a root device volume - AWS.EC2.register_image/3","type":"function"},{"doc":"If any snapshots have Amazon Web Services Marketplace product codes, they are\ncopied to the new AMI.\n\nWindows and some Linux distributions, such as Red Hat Enterprise Linux (RHEL)\nand SUSE Linux Enterprise Server (SLES), use the Amazon EC2 billing product code\nassociated with an AMI to verify the subscription status for package updates. To\ncreate a new AMI for operating systems that require a billing product code,\ninstead of registering the AMI, do the following to preserve the billing product\ncode association:\n\n  1. Launch an instance from an existing AMI with that billing product\ncode.\n\n  2. Customize the instance.\n\n  3. Create an AMI from the instance using `CreateImage`.\n\nIf you purchase a Reserved Instance to apply to an On-Demand Instance that was\nlaunched from an AMI with a billing product code, make sure that the Reserved\nInstance has the matching billing product code. If you purchase a Reserved\nInstance without the matching billing product code, the Reserved Instance will\nnot be applied to the On-Demand Instance. For information about how to obtain\nthe platform details and billing information of an AMI, see [Understand AMI billing\ninformation](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ami-billing-info.html)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#register_image/3-amazon-web-services-marketplace-product-codes","title":"Amazon Web Services Marketplace product codes - AWS.EC2.register_image/3","type":"function"},{"doc":"Registers a set of tag keys to include in scheduled event notifications for your\nresources.\n\nTo remove tags, use\n[DeregisterInstanceEventNotificationAttributes](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeregisterInstanceEventNotificationAttributes.html).","ref":"AWS.EC2.html#register_instance_event_notification_attributes/3","title":"AWS.EC2.register_instance_event_notification_attributes/3","type":"function"},{"doc":"Registers members (network interfaces) with the transit gateway multicast group.\n\nA member is a network interface associated with a supported EC2 instance that\nreceives multicast traffic. For information about supported instances, see\n[Multicast Consideration](https://docs.aws.amazon.com/vpc/latest/tgw/transit-gateway-limits.html#multicast-limits)\nin *Amazon VPC Transit Gateways*.\n\nAfter you add the members, use\n[SearchTransitGatewayMulticastGroups](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_SearchTransitGatewayMulticastGroups.html)\nto verify that the members were added to the transit gateway multicast group.","ref":"AWS.EC2.html#register_transit_gateway_multicast_group_members/3","title":"AWS.EC2.register_transit_gateway_multicast_group_members/3","type":"function"},{"doc":"Registers sources (network interfaces) with the specified transit gateway\nmulticast group.\n\nA multicast source is a network interface attached to a supported instance that\nsends multicast traffic. For information about supported instances, see\n[Multicast Considerations](https://docs.aws.amazon.com/vpc/latest/tgw/transit-gateway-limits.html#multicast-limits)\nin *Amazon VPC Transit Gateways*.\n\nAfter you add the source, use\n[SearchTransitGatewayMulticastGroups](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_SearchTransitGatewayMulticastGroups.html)\nto verify that the source was added to the multicast group.","ref":"AWS.EC2.html#register_transit_gateway_multicast_group_sources/3","title":"AWS.EC2.register_transit_gateway_multicast_group_sources/3","type":"function"},{"doc":"Rejects a request to associate cross-account subnets with a transit gateway\nmulticast domain.","ref":"AWS.EC2.html#reject_transit_gateway_multicast_domain_associations/3","title":"AWS.EC2.reject_transit_gateway_multicast_domain_associations/3","type":"function"},{"doc":"Rejects a transit gateway peering attachment request.","ref":"AWS.EC2.html#reject_transit_gateway_peering_attachment/3","title":"AWS.EC2.reject_transit_gateway_peering_attachment/3","type":"function"},{"doc":"Rejects a request to attach a VPC to a transit gateway.\n\nThe VPC attachment must be in the `pendingAcceptance` state. Use\n`DescribeTransitGatewayVpcAttachments` to view your pending VPC attachment\nrequests. Use `AcceptTransitGatewayVpcAttachment` to accept a VPC attachment\nrequest.","ref":"AWS.EC2.html#reject_transit_gateway_vpc_attachment/3","title":"AWS.EC2.reject_transit_gateway_vpc_attachment/3","type":"function"},{"doc":"Rejects VPC endpoint connection requests to your VPC endpoint service.","ref":"AWS.EC2.html#reject_vpc_endpoint_connections/3","title":"AWS.EC2.reject_vpc_endpoint_connections/3","type":"function"},{"doc":"Rejects a VPC peering connection request.\n\nThe VPC peering connection must be in the `pending-acceptance` state. Use the\n`DescribeVpcPeeringConnections` request to view your outstanding VPC peering\nconnection requests. To delete an active VPC peering connection, or to delete a\nVPC peering connection request that you initiated, use\n`DeleteVpcPeeringConnection`.","ref":"AWS.EC2.html#reject_vpc_peering_connection/3","title":"AWS.EC2.reject_vpc_peering_connection/3","type":"function"},{"doc":"Releases the specified Elastic IP address.\n\n[Default VPC] Releasing an Elastic IP address automatically disassociates it from any instance that it's associated with. To disassociate an Elastic IP\naddress without releasing it, use `DisassociateAddress`.\n\n[Nondefault VPC] You must use `DisassociateAddress` to disassociate the Elastic\nIP address before you can release it. Otherwise, Amazon EC2 returns an error\n(`InvalidIPAddress.InUse`).\n\nAfter releasing an Elastic IP address, it is released to the IP address pool. Be\nsure to update your DNS records and any servers or devices that communicate with\nthe address. If you attempt to release an Elastic IP address that you already\nreleased, you'll get an `AuthFailure` error if the address is already allocated\nto another Amazon Web Services account.\n\nAfter you release an Elastic IP address, you might be able to recover it. For\nmore information, see `AllocateAddress`.","ref":"AWS.EC2.html#release_address/3","title":"AWS.EC2.release_address/3","type":"function"},{"doc":"When you no longer want to use an On-Demand Dedicated Host it can be released.\n\nOn-Demand billing is stopped and the host goes into `released` state. The host\nID of Dedicated Hosts that have been released can no longer be specified in\nanother request, for example, to modify the host. You must stop or terminate all\ninstances on a host before it can be released.\n\nWhen Dedicated Hosts are released, it may take some time for them to stop\ncounting toward your limit and you may receive capacity errors when trying to\nallocate new Dedicated Hosts. Wait a few minutes and then try again.\n\nReleased hosts still appear in a `DescribeHosts` response.","ref":"AWS.EC2.html#release_hosts/3","title":"AWS.EC2.release_hosts/3","type":"function"},{"doc":"Release an allocation within an IPAM pool.\n\nThe Region you use should be the IPAM pool locale. The locale is the Amazon Web\nServices Region where this IPAM pool is available for allocations. You can only\nuse this action to release manual allocations. To remove an allocation for a\nresource without deleting the resource, set its monitored state to false using\n[ModifyIpamResourceCidr](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyIpamResourceCidr.html). For more information, see [Release an\nallocation](https://docs.aws.amazon.com/vpc/latest/ipam/release-alloc-ipam.html)\nin the *Amazon VPC IPAM User Guide*.\n\nAll EC2 API actions follow an [eventual consistency](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/query-api-troubleshooting.html#eventual-consistency)\nmodel.","ref":"AWS.EC2.html#release_ipam_pool_allocation/3","title":"AWS.EC2.release_ipam_pool_allocation/3","type":"function"},{"doc":"Replaces an IAM instance profile for the specified running instance.\n\nYou can use this action to change the IAM instance profile that's associated\nwith an instance without having to disassociate the existing IAM instance\nprofile first.\n\nUse `DescribeIamInstanceProfileAssociations` to get the association ID.","ref":"AWS.EC2.html#replace_iam_instance_profile_association/3","title":"AWS.EC2.replace_iam_instance_profile_association/3","type":"function"},{"doc":"Changes which network ACL a subnet is associated with.\n\nBy default when you create a subnet, it's automatically associated with the\ndefault network ACL. For more information, see [Network ACLs](https://docs.aws.amazon.com/vpc/latest/userguide/vpc-network-acls.html) in\nthe *Amazon VPC User Guide*.\n\nThis is an idempotent operation.","ref":"AWS.EC2.html#replace_network_acl_association/3","title":"AWS.EC2.replace_network_acl_association/3","type":"function"},{"doc":"Replaces an entry (rule) in a network ACL.\n\nFor more information, see [Network ACLs](https://docs.aws.amazon.com/vpc/latest/userguide/vpc-network-acls.html) in\nthe *Amazon VPC User Guide*.","ref":"AWS.EC2.html#replace_network_acl_entry/3","title":"AWS.EC2.replace_network_acl_entry/3","type":"function"},{"doc":"Replaces an existing route within a route table in a VPC.\n\nYou must specify either a destination CIDR block or a prefix list ID. You must\nalso specify exactly one of the resources from the parameter list, or reset the\nlocal route to its default target.\n\nFor more information, see [Route tables](https://docs.aws.amazon.com/vpc/latest/userguide/VPC_Route_Tables.html)\nin the *Amazon VPC User Guide*.","ref":"AWS.EC2.html#replace_route/3","title":"AWS.EC2.replace_route/3","type":"function"},{"doc":"Changes the route table associated with a given subnet, internet gateway, or\nvirtual private gateway in a VPC.\n\nAfter the operation completes, the subnet or gateway uses the routes in the new\nroute table. For more information about route tables, see [Route tables](https://docs.aws.amazon.com/vpc/latest/userguide/VPC_Route_Tables.html)\nin the *Amazon VPC User Guide*.\n\nYou can also use this operation to change which table is the main route table in\nthe VPC. Specify the main route table's association ID and the route table ID of\nthe new main route table.","ref":"AWS.EC2.html#replace_route_table_association/3","title":"AWS.EC2.replace_route_table_association/3","type":"function"},{"doc":"Replaces the specified route in the specified transit gateway route table.","ref":"AWS.EC2.html#replace_transit_gateway_route/3","title":"AWS.EC2.replace_transit_gateway_route/3","type":"function"},{"doc":"Trigger replacement of specified VPN tunnel.","ref":"AWS.EC2.html#replace_vpn_tunnel/3","title":"AWS.EC2.replace_vpn_tunnel/3","type":"function"},{"doc":"Submits feedback about the status of an instance.\n\nThe instance must be in the `running` state. If your experience with the\ninstance differs from the instance status returned by `DescribeInstanceStatus`,\nuse `ReportInstanceStatus` to report your experience with the instance. Amazon\nEC2 collects this information to improve the accuracy of status checks.\n\nUse of this action does not change the value returned by\n`DescribeInstanceStatus`.","ref":"AWS.EC2.html#report_instance_status/3","title":"AWS.EC2.report_instance_status/3","type":"function"},{"doc":"Creates a Spot Fleet request.\n\nThe Spot Fleet request specifies the total target capacity and the On-Demand\ntarget capacity. Amazon EC2 calculates the difference between the total capacity\nand On-Demand capacity, and launches the difference as Spot capacity.\n\nYou can submit a single request that includes multiple launch specifications\nthat vary by instance type, AMI, Availability Zone, or subnet.\n\nBy default, the Spot Fleet requests Spot Instances in the Spot Instance pool\nwhere the price per unit is the lowest. Each launch specification can include\nits own instance weighting that reflects the value of the instance type to your\napplication workload.\n\nAlternatively, you can specify that the Spot Fleet distribute the target\ncapacity across the Spot pools included in its launch specifications. By\nensuring that the Spot Instances in your Spot Fleet are in different Spot pools,\nyou can improve the availability of your fleet.\n\nYou can specify tags for the Spot Fleet request and instances launched by the\nfleet. You cannot tag other resource types in a Spot Fleet request because only\nthe `spot-fleet-request` and `instance` resource types are supported.\n\nFor more information, see [Spot Fleet requests](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/spot-fleet-requests.html)\nin the *Amazon EC2 User Guide*.\n\nWe strongly discourage using the RequestSpotFleet API because it is a legacy API\nwith no planned investment. For options for requesting Spot Instances, see\n[Which is the best Spot request method to use?](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/spot-best-practices.html#which-spot-request-method-to-use)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#request_spot_fleet/3","title":"AWS.EC2.request_spot_fleet/3","type":"function"},{"doc":"Creates a Spot Instance request.\n\nFor more information, see [Spot Instance requests](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/spot-requests.html)\nin the *Amazon EC2 User Guide for Linux Instances*.\n\nWe strongly discourage using the RequestSpotInstances API because it is a legacy\nAPI with no planned investment. For options for requesting Spot Instances, see\n[Which is the best Spot request method to use?](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/spot-best-practices.html#which-spot-request-method-to-use)\nin the *Amazon EC2 User Guide for Linux Instances*.","ref":"AWS.EC2.html#request_spot_instances/3","title":"AWS.EC2.request_spot_instances/3","type":"function"},{"doc":"Resets the attribute of the specified IP address.\n\nFor requirements, see [Using reverse DNS for email applications](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/elastic-ip-addresses-eip.html#Using_Elastic_Addressing_Reverse_DNS).","ref":"AWS.EC2.html#reset_address_attribute/3","title":"AWS.EC2.reset_address_attribute/3","type":"function"},{"doc":"Resets the default KMS key for EBS encryption for your account in this Region to\nthe Amazon Web Services managed KMS key for EBS.\n\nAfter resetting the default KMS key to the Amazon Web Services managed KMS key,\nyou can continue to encrypt by a customer managed KMS key by specifying it when\nyou create the volume. For more information, see [Amazon EBS encryption](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSEncryption.html)\nin the *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.EC2.html#reset_ebs_default_kms_key_id/3","title":"AWS.EC2.reset_ebs_default_kms_key_id/3","type":"function"},{"doc":"Resets the specified attribute of the specified Amazon FPGA Image (AFI) to its\ndefault value.\n\nYou can only reset the load permission attribute.","ref":"AWS.EC2.html#reset_fpga_image_attribute/3","title":"AWS.EC2.reset_fpga_image_attribute/3","type":"function"},{"doc":"Resets an attribute of an AMI to its default value.","ref":"AWS.EC2.html#reset_image_attribute/3","title":"AWS.EC2.reset_image_attribute/3","type":"function"},{"doc":"Resets an attribute of an instance to its default value.\n\nTo reset the `kernel` or `ramdisk`, the instance must be in a stopped state. To\nreset the `sourceDestCheck`, the instance can be either running or stopped.\n\nThe `sourceDestCheck` attribute controls whether source/destination checking is\nenabled. The default value is `true`, which means checking is enabled. This\nvalue must be `false` for a NAT instance to perform NAT. For more information,\nsee [NAT Instances](https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/VPC_NAT_Instance.html)\nin the *Amazon VPC User Guide*.","ref":"AWS.EC2.html#reset_instance_attribute/3","title":"AWS.EC2.reset_instance_attribute/3","type":"function"},{"doc":"Resets a network interface attribute.\n\nYou can specify only one attribute at a time.","ref":"AWS.EC2.html#reset_network_interface_attribute/3","title":"AWS.EC2.reset_network_interface_attribute/3","type":"function"},{"doc":"Resets permission settings for the specified snapshot.\n\nFor more information about modifying snapshot permissions, see [Share a snapshot](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ebs-modifying-snapshot-permissions.html)\nin the *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.EC2.html#reset_snapshot_attribute/3","title":"AWS.EC2.reset_snapshot_attribute/3","type":"function"},{"doc":"This action is deprecated.\n\nRestores an Elastic IP address that was previously moved to the EC2-VPC platform\nback to the EC2-Classic platform. You cannot move an Elastic IP address that was\noriginally allocated for use in EC2-VPC. The Elastic IP address must not be\nassociated with an instance or network interface.","ref":"AWS.EC2.html#restore_address_to_classic/3","title":"AWS.EC2.restore_address_to_classic/3","type":"function"},{"doc":"Restores an AMI from the Recycle Bin.\n\nFor more information, see [Recycle Bin](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/recycle-bin.html) in\nthe *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#restore_image_from_recycle_bin/3","title":"AWS.EC2.restore_image_from_recycle_bin/3","type":"function"},{"doc":"Restores the entries from a previous version of a managed prefix list to a new\nversion of the prefix list.","ref":"AWS.EC2.html#restore_managed_prefix_list_version/3","title":"AWS.EC2.restore_managed_prefix_list_version/3","type":"function"},{"doc":"Restores a snapshot from the Recycle Bin.\n\nFor more information, see [Restore snapshots from the Recycle Bin](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/recycle-bin-working-with-snaps.html#recycle-bin-restore-snaps)\nin the *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.EC2.html#restore_snapshot_from_recycle_bin/3","title":"AWS.EC2.restore_snapshot_from_recycle_bin/3","type":"function"},{"doc":"Restores an archived Amazon EBS snapshot for use temporarily or permanently, or\nmodifies the restore period or restore type for a snapshot that was previously\ntemporarily restored.\n\nFor more information see [ Restore an archived snapshot](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/working-with-snapshot-archiving.html#restore-archived-snapshot)\nand [ modify the restore period or restore type for a temporarily restored snapshot](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/working-with-snapshot-archiving.html#modify-temp-restore-period)\nin the *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.EC2.html#restore_snapshot_tier/3","title":"AWS.EC2.restore_snapshot_tier/3","type":"function"},{"doc":"Removes an ingress authorization rule from a Client VPN endpoint.","ref":"AWS.EC2.html#revoke_client_vpn_ingress/3","title":"AWS.EC2.revoke_client_vpn_ingress/3","type":"function"},{"doc":"Removes the specified outbound (egress) rules from the specified security group.\n\nYou can specify rules using either rule IDs or security group rule properties.\nIf you use rule properties, the values that you specify (for example, ports)\nmust match the existing rule's values exactly. Each rule has a protocol, from\nand to ports, and destination (CIDR range, security group, or prefix list). For\nthe TCP and UDP protocols, you must also specify the destination port or range\nof ports. For the ICMP protocol, you must also specify the ICMP type and code.\nIf the security group rule has a description, you do not need to specify the\ndescription to revoke the rule.\n\nFor a default VPC, if the values you specify do not match the existing rule's\nvalues, no error is returned, and the output describes the security group rules\nthat were not revoked.\n\nAmazon Web Services recommends that you describe the security group to verify\nthat the rules were removed.\n\nRule changes are propagated to instances within the security group as quickly as\npossible. However, a small delay might occur.","ref":"AWS.EC2.html#revoke_security_group_egress/3","title":"AWS.EC2.revoke_security_group_egress/3","type":"function"},{"doc":"Removes the specified inbound (ingress) rules from a security group.\n\nYou can specify rules using either rule IDs or security group rule properties.\nIf you use rule properties, the values that you specify (for example, ports)\nmust match the existing rule's values exactly. Each rule has a protocol, from\nand to ports, and source (CIDR range, security group, or prefix list). For the\nTCP and UDP protocols, you must also specify the destination port or range of\nports. For the ICMP protocol, you must also specify the ICMP type and code. If\nthe security group rule has a description, you do not need to specify the\ndescription to revoke the rule.\n\nFor a default VPC, if the values you specify do not match the existing rule's\nvalues, no error is returned, and the output describes the security group rules\nthat were not revoked.\n\nFor a non-default VPC, if the values you specify do not match the existing\nrule's values, an `InvalidPermission.NotFound` client error is returned, and no\nrules are revoked.\n\nAmazon Web Services recommends that you describe the security group to verify\nthat the rules were removed.\n\nRule changes are propagated to instances within the security group as quickly as\npossible. However, a small delay might occur.","ref":"AWS.EC2.html#revoke_security_group_ingress/3","title":"AWS.EC2.revoke_security_group_ingress/3","type":"function"},{"doc":"Launches the specified number of instances using an AMI for which you have\npermissions.\n\nYou can specify a number of options, or leave the default options. The following\nrules apply:\n\n  * If you don't specify a subnet ID, we choose a default subnet from\nyour default VPC for you. If you don't have a default VPC, you must specify a\nsubnet ID in the request.\n\n  * All instances have a network interface with a primary private IPv4\naddress. If you don't specify this address, we choose one from the IPv4 range of\nyour subnet.\n\n  * Not all instance types support IPv6 addresses. For more\ninformation, see [Instance types](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html).\n\n  * If you don't specify a security group ID, we use the default\nsecurity group. For more information, see [Security groups](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/using-network-security.html).\n\n  * If any of the AMIs have a product code attached for which the user\nhas not subscribed, the request fails.\n\nYou can create a [launch template](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-launch-templates.html),\nwhich is a resource that contains the parameters to launch an instance. When you\nlaunch an instance using `RunInstances`, you can specify the launch template\ninstead of specifying the launch parameters.\n\nTo ensure faster instance launches, break up large requests into smaller\nbatches. For example, create five separate launch requests for 100 instances\neach instead of one launch request for 500 instances.\n\nAn instance is ready for you to use when it's in the `running` state. You can\ncheck the state of your instance using `DescribeInstances`. You can tag\ninstances and EBS volumes during launch, after launch, or both. For more\ninformation, see `CreateTags` and [Tagging your Amazon EC2 resources](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Using_Tags.html).\n\nLinux instances have access to the public key of the key pair at boot. You can\nuse this key to provide secure access to the instance. Amazon EC2 public images\nuse this feature to provide secure access without passwords. For more\ninformation, see [Key pairs](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-key-pairs.html).\n\nFor troubleshooting, see [What to do if an instance immediately terminates](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Using_InstanceStraightToTerminated.html),\nand [Troubleshooting connecting to your instance](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/TroubleshootingInstancesConnecting.html).","ref":"AWS.EC2.html#run_instances/3","title":"AWS.EC2.run_instances/3","type":"function"},{"doc":"Launches the specified Scheduled Instances.\n\nBefore you can launch a Scheduled Instance, you must purchase it and obtain an\nidentifier using `PurchaseScheduledInstances`.\n\nYou must launch a Scheduled Instance during its scheduled time period. You can't\nstop or reboot a Scheduled Instance, but you can terminate it as needed. If you\nterminate a Scheduled Instance before the current scheduled time period ends,\nyou can launch it again after a few minutes. For more information, see\n[Scheduled Instances](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-scheduled-instances.html)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#run_scheduled_instances/3","title":"AWS.EC2.run_scheduled_instances/3","type":"function"},{"doc":"Searches for routes in the specified local gateway route table.","ref":"AWS.EC2.html#search_local_gateway_routes/3","title":"AWS.EC2.search_local_gateway_routes/3","type":"function"},{"doc":"Searches one or more transit gateway multicast groups and returns the group\nmembership information.","ref":"AWS.EC2.html#search_transit_gateway_multicast_groups/3","title":"AWS.EC2.search_transit_gateway_multicast_groups/3","type":"function"},{"doc":"Searches for routes in the specified transit gateway route table.","ref":"AWS.EC2.html#search_transit_gateway_routes/3","title":"AWS.EC2.search_transit_gateway_routes/3","type":"function"},{"doc":"Sends a diagnostic interrupt to the specified Amazon EC2 instance to trigger a\n*kernel panic* (on Linux instances), or a *blue screen*/*stop error* (on Windows\ninstances).\n\nFor instances based on Intel and AMD processors, the interrupt is received as a\n*non-maskable interrupt* (NMI).\n\nIn general, the operating system crashes and reboots when a kernel panic or stop\nerror is triggered. The operating system can also be configured to perform\ndiagnostic tasks, such as generating a memory dump file, loading a secondary\nkernel, or obtaining a call trace.\n\nBefore sending a diagnostic interrupt to your instance, ensure that its\noperating system is configured to perform the required diagnostic tasks.\n\nFor more information about configuring your operating system to generate a crash\ndump when a kernel panic or stop error occurs, see [Send a diagnostic interrupt (for advanced\nusers)](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/diagnostic-interrupt.html)\n(Linux instances) or [Send a diagnostic interrupt (for advanced users)](https://docs.aws.amazon.com/AWSEC2/latest/WindowsGuide/diagnostic-interrupt.html)\n(Windows instances).","ref":"AWS.EC2.html#send_diagnostic_interrupt/3","title":"AWS.EC2.send_diagnostic_interrupt/3","type":"function"},{"doc":"Starts an Amazon EBS-backed instance that you've previously stopped.\n\nInstances that use Amazon EBS volumes as their root devices can be quickly\nstopped and started. When an instance is stopped, the compute resources are\nreleased and you are not billed for instance usage. However, your root partition\nAmazon EBS volume remains and continues to persist your data, and you are\ncharged for Amazon EBS volume usage. You can restart your instance at any time.\nEvery time you start your instance, Amazon EC2 charges a one-minute minimum for\ninstance usage, and thereafter charges per second for instance usage.\n\nBefore stopping an instance, make sure it is in a state from which it can be\nrestarted. Stopping an instance does not preserve data stored in RAM.\n\nPerforming this operation on an instance that uses an instance store as its root\ndevice returns an error.\n\nIf you attempt to start a T3 instance with `host` tenancy and the `unlimited`\nCPU credit option, the request fails. The `unlimited` CPU credit option is not\nsupported on Dedicated Hosts. Before you start the instance, either change its\nCPU credit option to `standard`, or change its tenancy to `default` or\n`dedicated`.\n\nFor more information, see [Stop and start your instance](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Stop_Start.html)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#start_instances/3","title":"AWS.EC2.start_instances/3","type":"function"},{"doc":"Starts analyzing the specified Network Access Scope.","ref":"AWS.EC2.html#start_network_insights_access_scope_analysis/3","title":"AWS.EC2.start_network_insights_access_scope_analysis/3","type":"function"},{"doc":"Starts analyzing the specified path.\n\nIf the path is reachable, the operation returns the shortest feasible path.","ref":"AWS.EC2.html#start_network_insights_analysis/3","title":"AWS.EC2.start_network_insights_analysis/3","type":"function"},{"doc":"Initiates the verification process to prove that the service provider owns the\nprivate DNS name domain for the endpoint service.\n\nThe service provider must successfully perform the verification before the\nconsumer can use the name to access the service.\n\nBefore the service provider runs this command, they must add a record to the DNS\nserver.","ref":"AWS.EC2.html#start_vpc_endpoint_service_private_dns_verification/3","title":"AWS.EC2.start_vpc_endpoint_service_private_dns_verification/3","type":"function"},{"doc":"Stops an Amazon EBS-backed instance.\n\nFor more information, see [Stop and start your instance](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Stop_Start.html)\nin the *Amazon EC2 User Guide*.\n\nYou can use the Stop action to hibernate an instance if the instance is [enabled for\nhibernation](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/enabling-hibernation.html)\nand it meets the [hibernation prerequisites](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/hibernating-prerequisites.html).\nFor more information, see [Hibernate your instance](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Hibernate.html) in\nthe *Amazon EC2 User Guide*.\n\nWe don't charge usage for a stopped instance, or data transfer fees; however,\nyour root partition Amazon EBS volume remains and continues to persist your\ndata, and you are charged for Amazon EBS volume usage. Every time you start your\ninstance, Amazon EC2 charges a one-minute minimum for instance usage, and\nthereafter charges per second for instance usage.\n\nYou can't stop or hibernate instance store-backed instances. You can't use the\nStop action to hibernate Spot Instances, but you can specify that Amazon EC2\nshould hibernate Spot Instances when they are interrupted. For more information,\nsee [Hibernating interrupted Spot Instances](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/spot-interruptions.html#hibernate-spot-instances)\nin the *Amazon EC2 User Guide*.\n\nWhen you stop or hibernate an instance, we shut it down. You can restart your\ninstance at any time. Before stopping or hibernating an instance, make sure it\nis in a state from which it can be restarted. Stopping an instance does not\npreserve data stored in RAM, but hibernating an instance does preserve data\nstored in RAM. If an instance cannot hibernate successfully, a normal shutdown\noccurs.\n\nStopping and hibernating an instance is different to rebooting or terminating\nit. For example, when you stop or hibernate an instance, the root device and any\nother devices attached to the instance persist. When you terminate an instance,\nthe root device and any other devices attached during the instance launch are\nautomatically deleted. For more information about the differences between\nrebooting, stopping, hibernating, and terminating instances, see [Instance lifecycle](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-instance-lifecycle.html)\nin the *Amazon EC2 User Guide*.\n\nWhen you stop an instance, we attempt to shut it down forcibly after a short\nwhile. If your instance appears stuck in the stopping state after a period of\ntime, there may be an issue with the underlying host computer. For more\ninformation, see [Troubleshoot stopping your instance](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/TroubleshootingInstancesStopping.html)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#stop_instances/3","title":"AWS.EC2.stop_instances/3","type":"function"},{"doc":"Terminates active Client VPN endpoint connections.\n\nThis action can be used to terminate a specific client connection, or up to five\nconnections established by a specific user.","ref":"AWS.EC2.html#terminate_client_vpn_connections/3","title":"AWS.EC2.terminate_client_vpn_connections/3","type":"function"},{"doc":"Shuts down the specified instances.\n\nThis operation is idempotent; if you terminate an instance more than once, each\ncall succeeds.\n\nIf you specify multiple instances and the request fails (for example, because of\na single incorrect instance ID), none of the instances are terminated.\n\nIf you terminate multiple instances across multiple Availability Zones, and one\nor more of the specified instances are enabled for termination protection, the\nrequest fails with the following results:\n\n  * The specified instances that are in the same Availability Zone as\nthe protected instance are not terminated.\n\n  * The specified instances that are in different Availability Zones,\nwhere no other specified instances are protected, are successfully terminated.\n\nFor example, say you have the following instances:\n\n  * Instance A: `us-east-1a`; Not protected\n\n  * Instance B: `us-east-1a`; Not protected\n\n  * Instance C: `us-east-1b`; Protected\n\n  * Instance D: `us-east-1b`; not protected\n\nIf you attempt to terminate all of these instances in the same request, the\nrequest reports failure with the following results:\n\n  * Instance A and Instance B are successfully terminated because none\nof the specified instances in `us-east-1a` are enabled for termination\nprotection.\n\n  * Instance C and Instance D fail to terminate because at least one\nof the specified instances in `us-east-1b` (Instance C) is enabled for\ntermination protection.\n\nTerminated instances remain visible after termination (for approximately one\nhour).\n\nBy default, Amazon EC2 deletes all EBS volumes that were attached when the\ninstance launched. Volumes attached after instance launch continue running.\n\nYou can stop, start, and terminate EBS-backed instances. You can only terminate\ninstance store-backed instances. What happens to an instance differs if you stop\nit or terminate it. For example, when you stop an instance, the root device and\nany other devices attached to the instance persist. When you terminate an\ninstance, any attached EBS volumes with the `DeleteOnTermination` block device\nmapping parameter set to `true` are automatically deleted. For more information\nabout the differences between stopping and terminating instances, see [Instance lifecycle](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-instance-lifecycle.html)\nin the *Amazon EC2 User Guide*.\n\nFor more information about troubleshooting, see [Troubleshooting terminating your\ninstance](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/TroubleshootingInstancesShuttingDown.html)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#terminate_instances/3","title":"AWS.EC2.terminate_instances/3","type":"function"},{"doc":"Unassigns one or more IPv6 addresses IPv4 Prefix Delegation prefixes from a\nnetwork interface.","ref":"AWS.EC2.html#unassign_ipv6_addresses/3","title":"AWS.EC2.unassign_ipv6_addresses/3","type":"function"},{"doc":"Unassigns one or more secondary private IP addresses, or IPv4 Prefix Delegation\nprefixes from a network interface.","ref":"AWS.EC2.html#unassign_private_ip_addresses/3","title":"AWS.EC2.unassign_private_ip_addresses/3","type":"function"},{"doc":"Unassigns secondary private IPv4 addresses from a private NAT gateway.\n\nYou cannot unassign your primary private IP. For more information, see [Edit secondary IP address\nassociations](https://docs.aws.amazon.com/vpc/latest/userguide/vpc-nat-gateway.html#nat-gateway-edit-secondary)\nin the *Amazon VPC User Guide*.\n\nWhile unassigning is in progress, you cannot assign/unassign additional IP\naddresses while the connections are being drained. You are, however, allowed to\ndelete the NAT gateway.\n\nA private IP address will only be released at the end of\nMaxDrainDurationSeconds. The private IP addresses stay associated and support\nthe existing connections, but do not support any new connections (new\nconnections are distributed across the remaining assigned private IP address).\nAfter the existing connections drain out, the private IP addresses are released.","ref":"AWS.EC2.html#unassign_private_nat_gateway_address/3","title":"AWS.EC2.unassign_private_nat_gateway_address/3","type":"function"},{"doc":"Unlocks a snapshot that is locked in governance mode or that is locked in\ncompliance mode but still in the cooling-off period.\n\nYou can't unlock a snapshot that is locked in compliance mode after the\ncooling-off period has expired.","ref":"AWS.EC2.html#unlock_snapshot/3","title":"AWS.EC2.unlock_snapshot/3","type":"function"},{"doc":"Disables detailed monitoring for a running instance.\n\nFor more information, see [Monitoring your instances and volumes](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/using-cloudwatch.html)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2.html#unmonitor_instances/3","title":"AWS.EC2.unmonitor_instances/3","type":"function"},{"doc":"Updates the description of an egress (outbound) security group rule.\n\nYou can replace an existing description, or add a description to a rule that did\nnot have one previously. You can remove a description for a security group rule\nby omitting the description parameter in the request.","ref":"AWS.EC2.html#update_security_group_rule_descriptions_egress/3","title":"AWS.EC2.update_security_group_rule_descriptions_egress/3","type":"function"},{"doc":"Updates the description of an ingress (inbound) security group rule.\n\nYou can replace an existing description, or add a description to a rule that did\nnot have one previously. You can remove a description for a security group rule\nby omitting the description parameter in the request.","ref":"AWS.EC2.html#update_security_group_rule_descriptions_ingress/3","title":"AWS.EC2.update_security_group_rule_descriptions_ingress/3","type":"function"},{"doc":"Stops advertising an address range that is provisioned as an address pool.\n\nYou can perform this operation at most once every 10 seconds, even if you\nspecify different address ranges each time.\n\nIt can take a few minutes before traffic to the specified addresses stops\nrouting to Amazon Web Services because of BGP propagation delays.","ref":"AWS.EC2.html#withdraw_byoip_cidr/3","title":"AWS.EC2.withdraw_byoip_cidr/3","type":"function"},{"doc":"Amazon EC2 Instance Connect enables system administrators to publish one-time\nuse SSH public keys to EC2, providing users a simple and secure way to connect\nto their instances.","ref":"AWS.EC2InstanceConnect.html","title":"AWS.EC2InstanceConnect","type":"module"},{"doc":"","ref":"AWS.EC2InstanceConnect.html#metadata/0","title":"AWS.EC2InstanceConnect.metadata/0","type":"function"},{"doc":"Pushes an SSH public key to the specified EC2 instance.\n\nThe key remains for 60 seconds, which gives you 60 seconds to establish a serial\nconsole connection to the instance using SSH. For more information, see [EC2 Serial\nConsole](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-serial-console.html)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2InstanceConnect.html#send_serial_console_ssh_public_key/3","title":"AWS.EC2InstanceConnect.send_serial_console_ssh_public_key/3","type":"function"},{"doc":"Pushes an SSH public key to the specified EC2 instance for use by the specified\nuser.\n\nThe key remains for 60 seconds. For more information, see [Connect to your Linux instance using EC2 Instance\nConnect](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Connect-using-EC2-Instance-Connect.html)\nin the *Amazon EC2 User Guide*.","ref":"AWS.EC2InstanceConnect.html#send_ssh_public_key/3","title":"AWS.EC2InstanceConnect.send_ssh_public_key/3","type":"function"},{"doc":"Amazon Elastic Container Registry\n\nAmazon Elastic Container Registry (Amazon ECR) is a managed container image\nregistry service.\n\nCustomers can use the familiar Docker CLI, or their preferred client, to push,\npull, and manage images. Amazon ECR provides a secure, scalable, and reliable\nregistry for your Docker or Open Container Initiative (OCI) images. Amazon ECR\nsupports private repositories with resource-based permissions using IAM so that\nspecific users or Amazon EC2 instances can access repositories and images.\n\nAmazon ECR has service endpoints in each supported Region. For more information,\nsee [Amazon ECR endpoints](https://docs.aws.amazon.com/general/latest/gr/ecr.html) in the\n*Amazon Web Services General Reference*.","ref":"AWS.ECR.html","title":"AWS.ECR","type":"module"},{"doc":"Checks the availability of one or more image layers in a repository.\n\nWhen an image is pushed to a repository, each image layer is checked to verify\nif it has been uploaded before. If it has been uploaded, then the image layer is\nskipped.\n\nThis operation is used by the Amazon ECR proxy and is not generally used by\ncustomers for pulling and pushing images. In most cases, you should use the\n`docker` CLI to pull, tag, and push images.","ref":"AWS.ECR.html#batch_check_layer_availability/3","title":"AWS.ECR.batch_check_layer_availability/3","type":"function"},{"doc":"Deletes a list of specified images within a repository.\n\nImages are specified with either an `imageTag` or `imageDigest`.\n\nYou can remove a tag from an image by specifying the image's tag in your\nrequest. When you remove the last tag from an image, the image is deleted from\nyour repository.\n\nYou can completely delete an image (and all of its tags) by specifying the\nimage's digest in your request.","ref":"AWS.ECR.html#batch_delete_image/3","title":"AWS.ECR.batch_delete_image/3","type":"function"},{"doc":"Gets detailed information for an image.\n\nImages are specified with either an `imageTag` or `imageDigest`.\n\nWhen an image is pulled, the BatchGetImage API is called once to retrieve the\nimage manifest.","ref":"AWS.ECR.html#batch_get_image/3","title":"AWS.ECR.batch_get_image/3","type":"function"},{"doc":"Gets the scanning configuration for one or more repositories.","ref":"AWS.ECR.html#batch_get_repository_scanning_configuration/3","title":"AWS.ECR.batch_get_repository_scanning_configuration/3","type":"function"},{"doc":"Informs Amazon ECR that the image layer upload has completed for a specified\nregistry, repository name, and upload ID.\n\nYou can optionally provide a `sha256` digest of the image layer for data\nvalidation purposes.\n\nWhen an image is pushed, the CompleteLayerUpload API is called once per each new\nimage layer to verify that the upload has completed.\n\nThis operation is used by the Amazon ECR proxy and is not generally used by\ncustomers for pulling and pushing images. In most cases, you should use the\n`docker` CLI to pull, tag, and push images.","ref":"AWS.ECR.html#complete_layer_upload/3","title":"AWS.ECR.complete_layer_upload/3","type":"function"},{"doc":"Creates a pull through cache rule.\n\nA pull through cache rule provides a way to cache images from an upstream\nregistry source in your Amazon ECR private registry. For more information, see\n[Using pull through cache rules](https://docs.aws.amazon.com/AmazonECR/latest/userguide/pull-through-cache.html)\nin the *Amazon Elastic Container Registry User Guide*.","ref":"AWS.ECR.html#create_pull_through_cache_rule/3","title":"AWS.ECR.create_pull_through_cache_rule/3","type":"function"},{"doc":"Creates a repository.\n\nFor more information, see [Amazon ECR repositories](https://docs.aws.amazon.com/AmazonECR/latest/userguide/Repositories.html)\nin the *Amazon Elastic Container Registry User Guide*.","ref":"AWS.ECR.html#create_repository/3","title":"AWS.ECR.create_repository/3","type":"function"},{"doc":"Deletes the lifecycle policy associated with the specified repository.","ref":"AWS.ECR.html#delete_lifecycle_policy/3","title":"AWS.ECR.delete_lifecycle_policy/3","type":"function"},{"doc":"Deletes a pull through cache rule.","ref":"AWS.ECR.html#delete_pull_through_cache_rule/3","title":"AWS.ECR.delete_pull_through_cache_rule/3","type":"function"},{"doc":"Deletes the registry permissions policy.","ref":"AWS.ECR.html#delete_registry_policy/3","title":"AWS.ECR.delete_registry_policy/3","type":"function"},{"doc":"Deletes a repository.\n\nIf the repository isn't empty, you must either delete the contents of the\nrepository or use the `force` option to delete the repository and have Amazon\nECR delete all of its contents on your behalf.","ref":"AWS.ECR.html#delete_repository/3","title":"AWS.ECR.delete_repository/3","type":"function"},{"doc":"Deletes the repository policy associated with the specified repository.","ref":"AWS.ECR.html#delete_repository_policy/3","title":"AWS.ECR.delete_repository_policy/3","type":"function"},{"doc":"Returns the replication status for a specified image.","ref":"AWS.ECR.html#describe_image_replication_status/3","title":"AWS.ECR.describe_image_replication_status/3","type":"function"},{"doc":"Returns the scan findings for the specified image.","ref":"AWS.ECR.html#describe_image_scan_findings/3","title":"AWS.ECR.describe_image_scan_findings/3","type":"function"},{"doc":"Returns metadata about the images in a repository.\n\nBeginning with Docker version 1.9, the Docker client compresses image layers\nbefore pushing them to a V2 Docker registry. The output of the `docker images`\ncommand shows the uncompressed image size, so it may return a larger image size\nthan the image sizes returned by `DescribeImages`.","ref":"AWS.ECR.html#describe_images/3","title":"AWS.ECR.describe_images/3","type":"function"},{"doc":"Returns the pull through cache rules for a registry.","ref":"AWS.ECR.html#describe_pull_through_cache_rules/3","title":"AWS.ECR.describe_pull_through_cache_rules/3","type":"function"},{"doc":"Describes the settings for a registry.\n\nThe replication configuration for a repository can be created or updated with\nthe `PutReplicationConfiguration` API action.","ref":"AWS.ECR.html#describe_registry/3","title":"AWS.ECR.describe_registry/3","type":"function"},{"doc":"Describes image repositories in a registry.","ref":"AWS.ECR.html#describe_repositories/3","title":"AWS.ECR.describe_repositories/3","type":"function"},{"doc":"Retrieves an authorization token.\n\nAn authorization token represents your IAM authentication credentials and can be\nused to access any Amazon ECR registry that your IAM principal has access to.\nThe authorization token is valid for 12 hours.\n\nThe `authorizationToken` returned is a base64 encoded string that can be decoded\nand used in a `docker login` command to authenticate to a registry. The CLI\noffers an `get-login-password` command that simplifies the login process. For\nmore information, see [Registry authentication](https://docs.aws.amazon.com/AmazonECR/latest/userguide/Registries.html#registry_auth)\nin the *Amazon Elastic Container Registry User Guide*.","ref":"AWS.ECR.html#get_authorization_token/3","title":"AWS.ECR.get_authorization_token/3","type":"function"},{"doc":"Retrieves the pre-signed Amazon S3 download URL corresponding to an image layer.\n\nYou can only get URLs for image layers that are referenced in an image.\n\nWhen an image is pulled, the GetDownloadUrlForLayer API is called once per image\nlayer that is not already cached.\n\nThis operation is used by the Amazon ECR proxy and is not generally used by\ncustomers for pulling and pushing images. In most cases, you should use the\n`docker` CLI to pull, tag, and push images.","ref":"AWS.ECR.html#get_download_url_for_layer/3","title":"AWS.ECR.get_download_url_for_layer/3","type":"function"},{"doc":"Retrieves the lifecycle policy for the specified repository.","ref":"AWS.ECR.html#get_lifecycle_policy/3","title":"AWS.ECR.get_lifecycle_policy/3","type":"function"},{"doc":"Retrieves the results of the lifecycle policy preview request for the specified\nrepository.","ref":"AWS.ECR.html#get_lifecycle_policy_preview/3","title":"AWS.ECR.get_lifecycle_policy_preview/3","type":"function"},{"doc":"Retrieves the permissions policy for a registry.","ref":"AWS.ECR.html#get_registry_policy/3","title":"AWS.ECR.get_registry_policy/3","type":"function"},{"doc":"Retrieves the scanning configuration for a registry.","ref":"AWS.ECR.html#get_registry_scanning_configuration/3","title":"AWS.ECR.get_registry_scanning_configuration/3","type":"function"},{"doc":"Retrieves the repository policy for the specified repository.","ref":"AWS.ECR.html#get_repository_policy/3","title":"AWS.ECR.get_repository_policy/3","type":"function"},{"doc":"Notifies Amazon ECR that you intend to upload an image layer.\n\nWhen an image is pushed, the InitiateLayerUpload API is called once per image\nlayer that has not already been uploaded. Whether or not an image layer has been\nuploaded is determined by the BatchCheckLayerAvailability API action.\n\nThis operation is used by the Amazon ECR proxy and is not generally used by\ncustomers for pulling and pushing images. In most cases, you should use the\n`docker` CLI to pull, tag, and push images.","ref":"AWS.ECR.html#initiate_layer_upload/3","title":"AWS.ECR.initiate_layer_upload/3","type":"function"},{"doc":"Lists all the image IDs for the specified repository.\n\nYou can filter images based on whether or not they are tagged by using the\n`tagStatus` filter and specifying either `TAGGED`, `UNTAGGED` or `ANY`. For\nexample, you can filter your results to return only `UNTAGGED` images and then\npipe that result to a `BatchDeleteImage` operation to delete them. Or, you can\nfilter your results to return only `TAGGED` images to list all of the tags in\nyour repository.","ref":"AWS.ECR.html#list_images/3","title":"AWS.ECR.list_images/3","type":"function"},{"doc":"List the tags for an Amazon ECR resource.","ref":"AWS.ECR.html#list_tags_for_resource/3","title":"AWS.ECR.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.ECR.html#metadata/0","title":"AWS.ECR.metadata/0","type":"function"},{"doc":"Creates or updates the image manifest and tags associated with an image.\n\nWhen an image is pushed and all new image layers have been uploaded, the\nPutImage API is called once to create or update the image manifest and the tags\nassociated with the image.\n\nThis operation is used by the Amazon ECR proxy and is not generally used by\ncustomers for pulling and pushing images. In most cases, you should use the\n`docker` CLI to pull, tag, and push images.","ref":"AWS.ECR.html#put_image/3","title":"AWS.ECR.put_image/3","type":"function"},{"doc":"The `PutImageScanningConfiguration` API is being deprecated, in favor of\nspecifying the image scanning configuration at the registry level.\n\nFor more information, see `PutRegistryScanningConfiguration`.\n\nUpdates the image scanning configuration for the specified repository.","ref":"AWS.ECR.html#put_image_scanning_configuration/3","title":"AWS.ECR.put_image_scanning_configuration/3","type":"function"},{"doc":"Updates the image tag mutability settings for the specified repository.\n\nFor more information, see [Image tag mutability](https://docs.aws.amazon.com/AmazonECR/latest/userguide/image-tag-mutability.html)\nin the *Amazon Elastic Container Registry User Guide*.","ref":"AWS.ECR.html#put_image_tag_mutability/3","title":"AWS.ECR.put_image_tag_mutability/3","type":"function"},{"doc":"Creates or updates the lifecycle policy for the specified repository.\n\nFor more information, see [Lifecycle policy template](https://docs.aws.amazon.com/AmazonECR/latest/userguide/LifecyclePolicies.html).","ref":"AWS.ECR.html#put_lifecycle_policy/3","title":"AWS.ECR.put_lifecycle_policy/3","type":"function"},{"doc":"Creates or updates the permissions policy for your registry.\n\nA registry policy is used to specify permissions for another Amazon Web Services\naccount and is used when configuring cross-account replication. For more\ninformation, see [Registry permissions](https://docs.aws.amazon.com/AmazonECR/latest/userguide/registry-permissions.html)\nin the *Amazon Elastic Container Registry User Guide*.","ref":"AWS.ECR.html#put_registry_policy/3","title":"AWS.ECR.put_registry_policy/3","type":"function"},{"doc":"Creates or updates the scanning configuration for your private registry.","ref":"AWS.ECR.html#put_registry_scanning_configuration/3","title":"AWS.ECR.put_registry_scanning_configuration/3","type":"function"},{"doc":"Creates or updates the replication configuration for a registry.\n\nThe existing replication configuration for a repository can be retrieved with\nthe `DescribeRegistry` API action. The first time the\nPutReplicationConfiguration API is called, a service-linked IAM role is created\nin your account for the replication process. For more information, see [Using service-linked roles for Amazon\nECR](https://docs.aws.amazon.com/AmazonECR/latest/userguide/using-service-linked-roles.html)\nin the *Amazon Elastic Container Registry User Guide*.\n\nWhen configuring cross-account replication, the destination account must grant\nthe source account permission to replicate. This permission is controlled using\na registry permissions policy. For more information, see `PutRegistryPolicy`.","ref":"AWS.ECR.html#put_replication_configuration/3","title":"AWS.ECR.put_replication_configuration/3","type":"function"},{"doc":"Applies a repository policy to the specified repository to control access\npermissions.\n\nFor more information, see [Amazon ECR Repository policies](https://docs.aws.amazon.com/AmazonECR/latest/userguide/repository-policies.html)\nin the *Amazon Elastic Container Registry User Guide*.","ref":"AWS.ECR.html#set_repository_policy/3","title":"AWS.ECR.set_repository_policy/3","type":"function"},{"doc":"Starts an image vulnerability scan.\n\nAn image scan can only be started once per 24 hours on an individual image. This\nlimit includes if an image was scanned on initial push. For more information,\nsee [Image scanning](https://docs.aws.amazon.com/AmazonECR/latest/userguide/image-scanning.html)\nin the *Amazon Elastic Container Registry User Guide*.","ref":"AWS.ECR.html#start_image_scan/3","title":"AWS.ECR.start_image_scan/3","type":"function"},{"doc":"Starts a preview of a lifecycle policy for the specified repository.\n\nThis allows you to see the results before associating the lifecycle policy with\nthe repository.","ref":"AWS.ECR.html#start_lifecycle_policy_preview/3","title":"AWS.ECR.start_lifecycle_policy_preview/3","type":"function"},{"doc":"Adds specified tags to a resource with the specified ARN.\n\nExisting tags on a resource are not changed if they are not specified in the\nrequest parameters.","ref":"AWS.ECR.html#tag_resource/3","title":"AWS.ECR.tag_resource/3","type":"function"},{"doc":"Deletes specified tags from a resource.","ref":"AWS.ECR.html#untag_resource/3","title":"AWS.ECR.untag_resource/3","type":"function"},{"doc":"Updates an existing pull through cache rule.","ref":"AWS.ECR.html#update_pull_through_cache_rule/3","title":"AWS.ECR.update_pull_through_cache_rule/3","type":"function"},{"doc":"Uploads an image layer part to Amazon ECR.\n\nWhen an image is pushed, each new image layer is uploaded in parts. The maximum\nsize of each image layer part can be 20971520 bytes (or about 20MB). The\nUploadLayerPart API is called once per each new image layer part.\n\nThis operation is used by the Amazon ECR proxy and is not generally used by\ncustomers for pulling and pushing images. In most cases, you should use the\n`docker` CLI to pull, tag, and push images.","ref":"AWS.ECR.html#upload_layer_part/3","title":"AWS.ECR.upload_layer_part/3","type":"function"},{"doc":"Validates an existing pull through cache rule for an upstream registry that\nrequires authentication.\n\nThis will retrieve the contents of the Amazon Web Services Secrets Manager\nsecret, verify the syntax, and then validate that authentication to the upstream\nregistry is successful.","ref":"AWS.ECR.html#validate_pull_through_cache_rule/3","title":"AWS.ECR.validate_pull_through_cache_rule/3","type":"function"},{"doc":"Amazon Elastic Container Registry Public\n\nAmazon Elastic Container Registry Public (Amazon ECR Public) is a managed\ncontainer image registry service.\n\nAmazon ECR provides both public and private registries to host your container\nimages. You can use the Docker CLI or your preferred client to push, pull, and\nmanage images. Amazon ECR provides a secure, scalable, and reliable registry for\nyour Docker or Open Container Initiative (OCI) images. Amazon ECR supports\npublic repositories with this API. For information about the Amazon ECR API for\nprivate repositories, see [Amazon Elastic Container Registry API Reference](https://docs.aws.amazon.com/AmazonECR/latest/APIReference/Welcome.html).","ref":"AWS.ECRPUBLIC.html","title":"AWS.ECRPUBLIC","type":"module"},{"doc":"Checks the availability of one or more image layers that are within a repository\nin a public registry.\n\nWhen an image is pushed to a repository, each image layer is checked to verify\nif it has been uploaded before. If it has been uploaded, then the image layer is\nskipped.\n\nThis operation is used by the Amazon ECR proxy and is not generally used by\ncustomers for pulling and pushing images. In most cases, you should use the\n`docker` CLI to pull, tag, and push images.","ref":"AWS.ECRPUBLIC.html#batch_check_layer_availability/3","title":"AWS.ECRPUBLIC.batch_check_layer_availability/3","type":"function"},{"doc":"Deletes a list of specified images that are within a repository in a public\nregistry.\n\nImages are specified with either an `imageTag` or `imageDigest`.\n\nYou can remove a tag from an image by specifying the image's tag in your\nrequest. When you remove the last tag from an image, the image is deleted from\nyour repository.\n\nYou can completely delete an image (and all of its tags) by specifying the\ndigest of the image in your request.","ref":"AWS.ECRPUBLIC.html#batch_delete_image/3","title":"AWS.ECRPUBLIC.batch_delete_image/3","type":"function"},{"doc":"Informs Amazon ECR that the image layer upload is complete for a specified\npublic registry, repository name, and upload ID.\n\nYou can optionally provide a `sha256` digest of the image layer for data\nvalidation purposes.\n\nWhen an image is pushed, the CompleteLayerUpload API is called once for each new\nimage layer to verify that the upload is complete.\n\nThis operation is used by the Amazon ECR proxy and is not generally used by\ncustomers for pulling and pushing images. In most cases, you should use the\n`docker` CLI to pull, tag, and push images.","ref":"AWS.ECRPUBLIC.html#complete_layer_upload/3","title":"AWS.ECRPUBLIC.complete_layer_upload/3","type":"function"},{"doc":"Creates a repository in a public registry.\n\nFor more information, see [Amazon ECR repositories](https://docs.aws.amazon.com/AmazonECR/latest/userguide/Repositories.html)\nin the *Amazon Elastic Container Registry User Guide*.","ref":"AWS.ECRPUBLIC.html#create_repository/3","title":"AWS.ECRPUBLIC.create_repository/3","type":"function"},{"doc":"Deletes a repository in a public registry.\n\nIf the repository contains images, you must either manually delete all images in\nthe repository or use the `force` option. This option deletes all images on your\nbehalf before deleting the repository.","ref":"AWS.ECRPUBLIC.html#delete_repository/3","title":"AWS.ECRPUBLIC.delete_repository/3","type":"function"},{"doc":"Deletes the repository policy that's associated with the specified repository.","ref":"AWS.ECRPUBLIC.html#delete_repository_policy/3","title":"AWS.ECRPUBLIC.delete_repository_policy/3","type":"function"},{"doc":"Returns the image tag details for a repository in a public registry.","ref":"AWS.ECRPUBLIC.html#describe_image_tags/3","title":"AWS.ECRPUBLIC.describe_image_tags/3","type":"function"},{"doc":"Returns metadata that's related to the images in a repository in a public\nregistry.\n\nBeginning with Docker version 1.9, the Docker client compresses image layers\nbefore pushing them to a V2 Docker registry. The output of the `docker images`\ncommand shows the uncompressed image size. Therefore, it might return a larger\nimage size than the image sizes that are returned by `DescribeImages`.","ref":"AWS.ECRPUBLIC.html#describe_images/3","title":"AWS.ECRPUBLIC.describe_images/3","type":"function"},{"doc":"Returns details for a public registry.","ref":"AWS.ECRPUBLIC.html#describe_registries/3","title":"AWS.ECRPUBLIC.describe_registries/3","type":"function"},{"doc":"Describes repositories that are in a public registry.","ref":"AWS.ECRPUBLIC.html#describe_repositories/3","title":"AWS.ECRPUBLIC.describe_repositories/3","type":"function"},{"doc":"Retrieves an authorization token.\n\nAn authorization token represents your IAM authentication credentials. You can\nuse it to access any Amazon ECR registry that your IAM principal has access to.\nThe authorization token is valid for 12 hours. This API requires the\n`ecr-public:GetAuthorizationToken` and `sts:GetServiceBearerToken` permissions.","ref":"AWS.ECRPUBLIC.html#get_authorization_token/3","title":"AWS.ECRPUBLIC.get_authorization_token/3","type":"function"},{"doc":"Retrieves catalog metadata for a public registry.","ref":"AWS.ECRPUBLIC.html#get_registry_catalog_data/3","title":"AWS.ECRPUBLIC.get_registry_catalog_data/3","type":"function"},{"doc":"Retrieve catalog metadata for a repository in a public registry.\n\nThis metadata is displayed publicly in the Amazon ECR Public Gallery.","ref":"AWS.ECRPUBLIC.html#get_repository_catalog_data/3","title":"AWS.ECRPUBLIC.get_repository_catalog_data/3","type":"function"},{"doc":"Retrieves the repository policy for the specified repository.","ref":"AWS.ECRPUBLIC.html#get_repository_policy/3","title":"AWS.ECRPUBLIC.get_repository_policy/3","type":"function"},{"doc":"Notifies Amazon ECR that you intend to upload an image layer.\n\nWhen an image is pushed, the InitiateLayerUpload API is called once for each\nimage layer that hasn't already been uploaded. Whether an image layer uploads is\ndetermined by the BatchCheckLayerAvailability API action.\n\nThis operation is used by the Amazon ECR proxy and is not generally used by\ncustomers for pulling and pushing images. In most cases, you should use the\n`docker` CLI to pull, tag, and push images.","ref":"AWS.ECRPUBLIC.html#initiate_layer_upload/3","title":"AWS.ECRPUBLIC.initiate_layer_upload/3","type":"function"},{"doc":"List the tags for an Amazon ECR Public resource.","ref":"AWS.ECRPUBLIC.html#list_tags_for_resource/3","title":"AWS.ECRPUBLIC.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.ECRPUBLIC.html#metadata/0","title":"AWS.ECRPUBLIC.metadata/0","type":"function"},{"doc":"Creates or updates the image manifest and tags that are associated with an\nimage.\n\nWhen an image is pushed and all new image layers have been uploaded, the\nPutImage API is called once to create or update the image manifest and the tags\nthat are associated with the image.\n\nThis operation is used by the Amazon ECR proxy and is not generally used by\ncustomers for pulling and pushing images. In most cases, you should use the\n`docker` CLI to pull, tag, and push images.","ref":"AWS.ECRPUBLIC.html#put_image/3","title":"AWS.ECRPUBLIC.put_image/3","type":"function"},{"doc":"Create or update the catalog data for a public registry.","ref":"AWS.ECRPUBLIC.html#put_registry_catalog_data/3","title":"AWS.ECRPUBLIC.put_registry_catalog_data/3","type":"function"},{"doc":"Creates or updates the catalog data for a repository in a public registry.","ref":"AWS.ECRPUBLIC.html#put_repository_catalog_data/3","title":"AWS.ECRPUBLIC.put_repository_catalog_data/3","type":"function"},{"doc":"Applies a repository policy to the specified public repository to control access\npermissions.\n\nFor more information, see [Amazon ECR Repository Policies](https://docs.aws.amazon.com/AmazonECR/latest/userguide/repository-policies.html)\nin the *Amazon Elastic Container Registry User Guide*.","ref":"AWS.ECRPUBLIC.html#set_repository_policy/3","title":"AWS.ECRPUBLIC.set_repository_policy/3","type":"function"},{"doc":"Associates the specified tags to a resource with the specified `resourceArn`.\n\nIf existing tags on a resource aren't specified in the request parameters, they\naren't changed. When a resource is deleted, the tags associated with that\nresource are also deleted.","ref":"AWS.ECRPUBLIC.html#tag_resource/3","title":"AWS.ECRPUBLIC.tag_resource/3","type":"function"},{"doc":"Deletes specified tags from a resource.","ref":"AWS.ECRPUBLIC.html#untag_resource/3","title":"AWS.ECRPUBLIC.untag_resource/3","type":"function"},{"doc":"Uploads an image layer part to Amazon ECR.\n\nWhen an image is pushed, each new image layer is uploaded in parts. The maximum\nsize of each image layer part can be 20971520 bytes (about 20MB). The\nUploadLayerPart API is called once for each new image layer part.\n\nThis operation is used by the Amazon ECR proxy and is not generally used by\ncustomers for pulling and pushing images. In most cases, you should use the\n`docker` CLI to pull, tag, and push images.","ref":"AWS.ECRPUBLIC.html#upload_layer_part/3","title":"AWS.ECRPUBLIC.upload_layer_part/3","type":"function"},{"doc":"Amazon Elastic Container Service\n\nAmazon Elastic Container Service (Amazon ECS) is a highly scalable, fast,\ncontainer management service.\n\nIt makes it easy to run, stop, and manage Docker containers. You can host your\ncluster on a serverless infrastructure that's managed by Amazon ECS by launching\nyour services or tasks on Fargate. For more control, you can host your tasks on\na cluster of Amazon Elastic Compute Cloud (Amazon EC2) or External (on-premises)\ninstances that you manage.\n\nAmazon ECS makes it easy to launch and stop container-based applications with\nsimple API calls. This makes it easy to get the state of your cluster from a\ncentralized service, and gives you access to many familiar Amazon EC2 features.\n\nYou can use Amazon ECS to schedule the placement of containers across your\ncluster based on your resource needs, isolation policies, and availability\nrequirements. With Amazon ECS, you don't need to operate your own cluster\nmanagement and configuration management systems. You also don't need to worry\nabout scaling your management infrastructure.","ref":"AWS.ECS.html","title":"AWS.ECS","type":"module"},{"doc":"Creates a new capacity provider.\n\nCapacity providers are associated with an Amazon ECS cluster and are used in\ncapacity provider strategies to facilitate cluster auto scaling.\n\nOnly capacity providers that use an Auto Scaling group can be created. Amazon\nECS tasks on Fargate use the `FARGATE` and `FARGATE_SPOT` capacity providers.\nThese providers are available to all accounts in the Amazon Web Services Regions\nthat Fargate supports.","ref":"AWS.ECS.html#create_capacity_provider/3","title":"AWS.ECS.create_capacity_provider/3","type":"function"},{"doc":"Creates a new Amazon ECS cluster.\n\nBy default, your account receives a `default` cluster when you launch your first\ncontainer instance. However, you can create your own cluster with a unique name\nwith the `CreateCluster` action.\n\nWhen you call the `CreateCluster` API operation, Amazon ECS attempts to create\nthe Amazon ECS service-linked role for your account. This is so that it can\nmanage required resources in other Amazon Web Services services on your behalf.\nHowever, if the user that makes the call doesn't have permissions to create the\nservice-linked role, it isn't created. For more information, see [Using service-linked roles for Amazon\nECS](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/using-service-linked-roles.html)\nin the *Amazon Elastic Container Service Developer Guide*.","ref":"AWS.ECS.html#create_cluster/3","title":"AWS.ECS.create_cluster/3","type":"function"},{"doc":"Runs and maintains your desired number of tasks from a specified task\ndefinition.\n\nIf the number of tasks running in a service drops below the `desiredCount`,\nAmazon ECS runs another copy of the task in the specified cluster. To update an\nexisting service, see the `UpdateService` action.\n\nStarting April 15, 2023, Amazon Web Services will not onboard new customers to\nAmazon Elastic Inference (EI), and will help current customers migrate their\nworkloads to options that offer better price and performance. After April 15,\n2023, new customers will not be able to launch instances with Amazon EI\naccelerators in Amazon SageMaker, Amazon ECS, or Amazon EC2. However, customers\nwho have used Amazon EI at least once during the past 30-day period are\nconsidered current customers and will be able to continue using the service.\n\nIn addition to maintaining the desired count of tasks in your service, you can\noptionally run your service behind one or more load balancers. The load\nbalancers distribute traffic across the tasks that are associated with the\nservice. For more information, see [Service load balancing](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/service-load-balancing.html)\nin the *Amazon Elastic Container Service Developer Guide*.\n\nYou can attach Amazon EBS volumes to Amazon ECS tasks by configuring the volume\nwhen creating or updating a service. `volumeConfigurations` is only supported\nfor REPLICA service and not DAEMON service. For more infomation, see [Amazon EBS volumes](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ebs-volumes.html#ebs-volume-types)\nin the *Amazon Elastic Container Service Developer Guide*.\n\nTasks for services that don't use a load balancer are considered healthy if\nthey're in the `RUNNING` state. Tasks for services that use a load balancer are\nconsidered healthy if they're in the `RUNNING` state and are reported as healthy\nby the load balancer.\n\nThere are two service scheduler strategies available:\n\n  * `REPLICA` - The replica scheduling strategy places and maintains\nyour desired number of tasks across your cluster. By default, the service\nscheduler spreads tasks across Availability Zones. You can use task placement\nstrategies and constraints to customize task placement decisions. For more\ninformation, see [Service scheduler concepts](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs_services.html)\nin the *Amazon Elastic Container Service Developer Guide*.\n\n  * `DAEMON` - The daemon scheduling strategy deploys exactly one task\non each active container instance that meets all of the task placement\nconstraints that you specify in your cluster. The service scheduler also\nevaluates the task placement constraints for running tasks. It also stops tasks\nthat don't meet the placement constraints. When using this strategy, you don't\nneed to specify a desired number of tasks, a task placement strategy, or use\nService Auto Scaling policies. For more information, see [Service scheduler concepts](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs_services.html)\nin the *Amazon Elastic Container Service Developer Guide*.\n\nYou can optionally specify a deployment configuration for your service. The\ndeployment is initiated by changing properties. For example, the deployment\nmight be initiated by the task definition or by your desired count of a service.\nThis is done with an `UpdateService` operation. The default value for a replica\nservice for `minimumHealthyPercent` is 100%. The default value for a daemon\nservice for `minimumHealthyPercent` is 0%.\n\nIf a service uses the `ECS` deployment controller, the minimum healthy percent\nrepresents a lower limit on the number of tasks in a service that must remain in\nthe `RUNNING` state during a deployment. Specifically, it represents it as a\npercentage of your desired number of tasks (rounded up to the nearest integer).\nThis happens when any of your container instances are in the `DRAINING` state if\nthe service contains tasks using the EC2 launch type. Using this parameter, you\ncan deploy without using additional cluster capacity. For example, if you set\nyour service to have desired number of four tasks and a minimum healthy percent\nof 50%, the scheduler might stop two existing tasks to free up cluster capacity\nbefore starting two new tasks. If they're in the `RUNNING` state, tasks for\nservices that don't use a load balancer are considered healthy . If they're in\nthe `RUNNING` state and reported as healthy by the load balancer, tasks for\nservices that *do* use a load balancer are considered healthy . The default\nvalue for minimum healthy percent is 100%.\n\nIf a service uses the `ECS` deployment controller, the","ref":"AWS.ECS.html#create_service/3","title":"AWS.ECS.create_service/3","type":"function"},{"doc":"parameter represents an upper limit on the number of tasks in a service that are\nallowed in the `RUNNING` or `PENDING` state during a deployment. Specifically,\nit represents it as a percentage of the desired number of tasks (rounded down to\nthe nearest integer). This happens when any of your container instances are in\nthe `DRAINING` state if the service contains tasks using the EC2 launch type.\nUsing this parameter, you can define the deployment batch size. For example, if\nyour service has a desired number of four tasks and a maximum percent value of\n200%, the scheduler may start four new tasks before stopping the four older\ntasks (provided that the cluster resources required to do this are available).\nThe default value for maximum percent is 200%.\n\nIf a service uses either the `CODE_DEPLOY` or `EXTERNAL` deployment controller\ntypes and tasks that use the EC2 launch type, the","ref":"AWS.ECS.html#create_service/3-maximum-percent","title":"maximum percent - AWS.ECS.create_service/3","type":"function"},{"doc":"and **maximum percent** values are used only to define the lower and upper limit\non the number of the tasks in the service that remain in the `RUNNING` state.\nThis is while the container instances are in the `DRAINING` state. If the tasks\nin the service use the Fargate launch type, the minimum healthy percent and\nmaximum percent values aren't used. This is the case even if they're currently\nvisible when describing your service.\n\nWhen creating a service that uses the `EXTERNAL` deployment controller, you can\nspecify only parameters that aren't controlled at the task set level. The only\nrequired parameter is the service name. You control your services using the\n`CreateTaskSet` operation. For more information, see [Amazon ECS deployment types](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/deployment-types.html)\nin the *Amazon Elastic Container Service Developer Guide*.\n\nWhen the service scheduler launches new tasks, it determines task placement. For\ninformation about task placement and task placement strategies, see [Amazon ECS task\nplacement](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/task-placement.html)\nin the *Amazon Elastic Container Service Developer Guide*.","ref":"AWS.ECS.html#create_service/3-minimum-healthy-percent","title":"minimum healthy percent - AWS.ECS.create_service/3","type":"function"},{"doc":"Create a task set in the specified cluster and service.\n\nThis is used when a service uses the `EXTERNAL` deployment controller type. For\nmore information, see [Amazon ECS deployment types](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/deployment-types.html)\nin the *Amazon Elastic Container Service Developer Guide*.\n\nFor information about the maximum number of task sets and otther quotas, see\n[Amazon ECS service quotas](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/service-quotas.html)\nin the *Amazon Elastic Container Service Developer Guide*.","ref":"AWS.ECS.html#create_task_set/3","title":"AWS.ECS.create_task_set/3","type":"function"},{"doc":"Disables an account setting for a specified user, role, or the root user for an\naccount.","ref":"AWS.ECS.html#delete_account_setting/3","title":"AWS.ECS.delete_account_setting/3","type":"function"},{"doc":"Deletes one or more custom attributes from an Amazon ECS resource.","ref":"AWS.ECS.html#delete_attributes/3","title":"AWS.ECS.delete_attributes/3","type":"function"},{"doc":"Deletes the specified capacity provider.\n\nThe `FARGATE` and `FARGATE_SPOT` capacity providers are reserved and can't be\ndeleted. You can disassociate them from a cluster using either the\n`PutClusterCapacityProviders` API or by deleting the cluster.\n\nPrior to a capacity provider being deleted, the capacity provider must be\nremoved from the capacity provider strategy from all services. The\n`UpdateService` API can be used to remove a capacity provider from a service's\ncapacity provider strategy. When updating a service, the `forceNewDeployment`\noption can be used to ensure that any tasks using the Amazon EC2 instance\ncapacity provided by the capacity provider are transitioned to use the capacity\nfrom the remaining capacity providers. Only capacity providers that aren't\nassociated with a cluster can be deleted. To remove a capacity provider from a\ncluster, you can either use `PutClusterCapacityProviders` or delete the cluster.","ref":"AWS.ECS.html#delete_capacity_provider/3","title":"AWS.ECS.delete_capacity_provider/3","type":"function"},{"doc":"Deletes the specified cluster.\n\nThe cluster transitions to the `INACTIVE` state. Clusters with an `INACTIVE`\nstatus might remain discoverable in your account for a period of time. However,\nthis behavior is subject to change in the future. We don't recommend that you\nrely on `INACTIVE` clusters persisting.\n\nYou must deregister all container instances from this cluster before you may\ndelete it. You can list the container instances in a cluster with\n`ListContainerInstances` and deregister them with `DeregisterContainerInstance`.","ref":"AWS.ECS.html#delete_cluster/3","title":"AWS.ECS.delete_cluster/3","type":"function"},{"doc":"Deletes a specified service within a cluster.\n\nYou can delete a service if you have no running tasks in it and the desired task\ncount is zero. If the service is actively maintaining tasks, you can't delete\nit, and you must update the service to a desired task count of zero. For more\ninformation, see `UpdateService`.\n\nWhen you delete a service, if there are still running tasks that require\ncleanup, the service status moves from `ACTIVE` to `DRAINING`, and the service\nis no longer visible in the console or in the `ListServices` API operation.\nAfter all tasks have transitioned to either `STOPPING` or `STOPPED` status, the\nservice status moves from `DRAINING` to `INACTIVE`. Services in the `DRAINING`\nor `INACTIVE` status can still be viewed with the `DescribeServices` API\noperation. However, in the future, `INACTIVE` services may be cleaned up and\npurged from Amazon ECS record keeping, and `DescribeServices` calls on those\nservices return a `ServiceNotFoundException` error.\n\nIf you attempt to create a new service with the same name as an existing service\nin either `ACTIVE` or `DRAINING` status, you receive an error.","ref":"AWS.ECS.html#delete_service/3","title":"AWS.ECS.delete_service/3","type":"function"},{"doc":"Deletes one or more task definitions.\n\nYou must deregister a task definition revision before you delete it. For more\ninformation, see\n[DeregisterTaskDefinition](https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_DeregisterTaskDefinition.html).\n\nWhen you delete a task definition revision, it is immediately transitions from\nthe `INACTIVE` to `DELETE_IN_PROGRESS`. Existing tasks and services that\nreference a `DELETE_IN_PROGRESS` task definition revision continue to run\nwithout disruption. Existing services that reference a `DELETE_IN_PROGRESS` task\ndefinition revision can still scale up or down by modifying the service's\ndesired count.\n\nYou can't use a `DELETE_IN_PROGRESS` task definition revision to run new tasks\nor create new services. You also can't update an existing service to reference a\n`DELETE_IN_PROGRESS` task definition revision.\n\nA task definition revision will stay in `DELETE_IN_PROGRESS` status until all\nthe associated tasks and services have been terminated.\n\nWhen you delete all `INACTIVE` task definition revisions, the task definition\nname is not displayed in the console and not returned in the API. If a task\ndefinition revisions are in the `DELETE_IN_PROGRESS` state, the task definition\nname is displayed in the console and returned in the API. The task definition\nname is retained by Amazon ECS and the revision is incremented the next time you\ncreate a task definition with that name.","ref":"AWS.ECS.html#delete_task_definitions/3","title":"AWS.ECS.delete_task_definitions/3","type":"function"},{"doc":"Deletes a specified task set within a service.\n\nThis is used when a service uses the `EXTERNAL` deployment controller type. For\nmore information, see [Amazon ECS deployment types](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/deployment-types.html)\nin the *Amazon Elastic Container Service Developer Guide*.","ref":"AWS.ECS.html#delete_task_set/3","title":"AWS.ECS.delete_task_set/3","type":"function"},{"doc":"Deregisters an Amazon ECS container instance from the specified cluster.\n\nThis instance is no longer available to run tasks.\n\nIf you intend to use the container instance for some other purpose after\nderegistration, we recommend that you stop all of the tasks running on the\ncontainer instance before deregistration. That prevents any orphaned tasks from\nconsuming resources.\n\nDeregistering a container instance removes the instance from a cluster, but it\ndoesn't terminate the EC2 instance. If you are finished using the instance, be\nsure to terminate it in the Amazon EC2 console to stop billing.\n\nIf you terminate a running container instance, Amazon ECS automatically\nderegisters the instance from your cluster (stopped container instances or\ninstances with disconnected agents aren't automatically deregistered when\nterminated).","ref":"AWS.ECS.html#deregister_container_instance/3","title":"AWS.ECS.deregister_container_instance/3","type":"function"},{"doc":"Deregisters the specified task definition by family and revision.\n\nUpon deregistration, the task definition is marked as `INACTIVE`. Existing tasks\nand services that reference an `INACTIVE` task definition continue to run\nwithout disruption. Existing services that reference an `INACTIVE` task\ndefinition can still scale up or down by modifying the service's desired count.\nIf you want to delete a task definition revision, you must first deregister the\ntask definition revision.\n\nYou can't use an `INACTIVE` task definition to run new tasks or create new\nservices, and you can't update an existing service to reference an `INACTIVE`\ntask definition. However, there may be up to a 10-minute window following\nderegistration where these restrictions have not yet taken effect.\n\nAt this time, `INACTIVE` task definitions remain discoverable in your account\nindefinitely. However, this behavior is subject to change in the future. We\ndon't recommend that you rely on `INACTIVE` task definitions persisting beyond\nthe lifecycle of any associated tasks and services.\n\nYou must deregister a task definition revision before you delete it. For more\ninformation, see\n[DeleteTaskDefinitions](https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_DeleteTaskDefinitions.html).","ref":"AWS.ECS.html#deregister_task_definition/3","title":"AWS.ECS.deregister_task_definition/3","type":"function"},{"doc":"Describes one or more of your capacity providers.","ref":"AWS.ECS.html#describe_capacity_providers/3","title":"AWS.ECS.describe_capacity_providers/3","type":"function"},{"doc":"Describes one or more of your clusters.","ref":"AWS.ECS.html#describe_clusters/3","title":"AWS.ECS.describe_clusters/3","type":"function"},{"doc":"Describes one or more container instances.\n\nReturns metadata about each container instance requested.","ref":"AWS.ECS.html#describe_container_instances/3","title":"AWS.ECS.describe_container_instances/3","type":"function"},{"doc":"Describes the specified services running in your cluster.","ref":"AWS.ECS.html#describe_services/3","title":"AWS.ECS.describe_services/3","type":"function"},{"doc":"Describes a task definition.\n\nYou can specify a `family` and `revision` to find information about a specific\ntask definition, or you can simply specify the family to find the latest\n`ACTIVE` revision in that family.\n\nYou can only describe `INACTIVE` task definitions while an active task or\nservice references them.","ref":"AWS.ECS.html#describe_task_definition/3","title":"AWS.ECS.describe_task_definition/3","type":"function"},{"doc":"Describes the task sets in the specified cluster and service.\n\nThis is used when a service uses the `EXTERNAL` deployment controller type. For\nmore information, see [Amazon ECS Deployment Types](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/deployment-types.html)\nin the *Amazon Elastic Container Service Developer Guide*.","ref":"AWS.ECS.html#describe_task_sets/3","title":"AWS.ECS.describe_task_sets/3","type":"function"},{"doc":"Describes a specified task or tasks.\n\nCurrently, stopped tasks appear in the returned results for at least one hour.\n\nIf you have tasks with tags, and then delete the cluster, the tagged tasks are\nreturned in the response. If you create a new cluster with the same name as the\ndeleted cluster, the tagged tasks are not included in the response.","ref":"AWS.ECS.html#describe_tasks/3","title":"AWS.ECS.describe_tasks/3","type":"function"},{"doc":"This action is only used by the Amazon ECS agent, and it is not intended for use\noutside of the agent.\n\nReturns an endpoint for the Amazon ECS agent to poll for updates.","ref":"AWS.ECS.html#discover_poll_endpoint/3","title":"AWS.ECS.discover_poll_endpoint/3","type":"function"},{"doc":"Runs a command remotely on a container within a task.\n\nIf you use a condition key in your IAM policy to refine the conditions for the\npolicy statement, for example limit the actions to a specific cluster, you\nreceive an `AccessDeniedException` when there is a mismatch between the\ncondition key value and the corresponding parameter value.\n\nFor information about required permissions and considerations, see [Using Amazon ECS Exec for\ndebugging](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-exec.html)\nin the *Amazon ECS Developer Guide*.","ref":"AWS.ECS.html#execute_command/3","title":"AWS.ECS.execute_command/3","type":"function"},{"doc":"Retrieves the protection status of tasks in an Amazon ECS service.","ref":"AWS.ECS.html#get_task_protection/3","title":"AWS.ECS.get_task_protection/3","type":"function"},{"doc":"Lists the account settings for a specified principal.","ref":"AWS.ECS.html#list_account_settings/3","title":"AWS.ECS.list_account_settings/3","type":"function"},{"doc":"Lists the attributes for Amazon ECS resources within a specified target type and\ncluster.\n\nWhen you specify a target type and cluster, `ListAttributes` returns a list of\nattribute objects, one for each attribute on each resource. You can filter the\nlist of results to a single attribute name to only return results that have that\nname. You can also filter the results by attribute name and value. You can do\nthis, for example, to see which container instances in a cluster are running a\nLinux AMI (`ecs.os-type=linux`).","ref":"AWS.ECS.html#list_attributes/3","title":"AWS.ECS.list_attributes/3","type":"function"},{"doc":"Returns a list of existing clusters.","ref":"AWS.ECS.html#list_clusters/3","title":"AWS.ECS.list_clusters/3","type":"function"},{"doc":"Returns a list of container instances in a specified cluster.\n\nYou can filter the results of a `ListContainerInstances` operation with cluster\nquery language statements inside the `filter` parameter. For more information,\nsee [Cluster Query Language](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/cluster-query-language.html)\nin the *Amazon Elastic Container Service Developer Guide*.","ref":"AWS.ECS.html#list_container_instances/3","title":"AWS.ECS.list_container_instances/3","type":"function"},{"doc":"Returns a list of services.\n\nYou can filter the results by cluster, launch type, and scheduling strategy.","ref":"AWS.ECS.html#list_services/3","title":"AWS.ECS.list_services/3","type":"function"},{"doc":"This operation lists all of the services that are associated with a Cloud Map\nnamespace.\n\nThis list might include services in different clusters. In contrast,\n`ListServices` can only list services in one cluster at a time. If you need to\nfilter the list of services in a single cluster by various parameters, use\n`ListServices`. For more information, see [Service Connect](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/service-connect.html)\nin the *Amazon Elastic Container Service Developer Guide*.","ref":"AWS.ECS.html#list_services_by_namespace/3","title":"AWS.ECS.list_services_by_namespace/3","type":"function"},{"doc":"List the tags for an Amazon ECS resource.","ref":"AWS.ECS.html#list_tags_for_resource/3","title":"AWS.ECS.list_tags_for_resource/3","type":"function"},{"doc":"Returns a list of task definition families that are registered to your account.\n\nThis list includes task definition families that no longer have any `ACTIVE`\ntask definition revisions.\n\nYou can filter out task definition families that don't contain any `ACTIVE` task\ndefinition revisions by setting the `status` parameter to `ACTIVE`. You can also\nfilter the results with the `familyPrefix` parameter.","ref":"AWS.ECS.html#list_task_definition_families/3","title":"AWS.ECS.list_task_definition_families/3","type":"function"},{"doc":"Returns a list of task definitions that are registered to your account.\n\nYou can filter the results by family name with the `familyPrefix` parameter or\nby status with the `status` parameter.","ref":"AWS.ECS.html#list_task_definitions/3","title":"AWS.ECS.list_task_definitions/3","type":"function"},{"doc":"Returns a list of tasks.\n\nYou can filter the results by cluster, task definition family, container\ninstance, launch type, what IAM principal started the task, or by the desired\nstatus of the task.\n\nRecently stopped tasks might appear in the returned results.","ref":"AWS.ECS.html#list_tasks/3","title":"AWS.ECS.list_tasks/3","type":"function"},{"doc":"","ref":"AWS.ECS.html#metadata/0","title":"AWS.ECS.metadata/0","type":"function"},{"doc":"Modifies an account setting.\n\nAccount settings are set on a per-Region basis.\n\nIf you change the root user account setting, the default settings are reset for\nusers and roles that do not have specified individual account settings. For more\ninformation, see [Account Settings](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-account-settings.html)\nin the *Amazon Elastic Container Service Developer Guide*.","ref":"AWS.ECS.html#put_account_setting/3","title":"AWS.ECS.put_account_setting/3","type":"function"},{"doc":"Modifies an account setting for all users on an account for whom no individual\naccount setting has been specified.\n\nAccount settings are set on a per-Region basis.","ref":"AWS.ECS.html#put_account_setting_default/3","title":"AWS.ECS.put_account_setting_default/3","type":"function"},{"doc":"Create or update an attribute on an Amazon ECS resource.\n\nIf the attribute doesn't exist, it's created. If the attribute exists, its value\nis replaced with the specified value. To delete an attribute, use\n`DeleteAttributes`. For more information, see\n[Attributes](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/task-placement-constraints.html#attributes)\nin the *Amazon Elastic Container Service Developer Guide*.","ref":"AWS.ECS.html#put_attributes/3","title":"AWS.ECS.put_attributes/3","type":"function"},{"doc":"Modifies the available capacity providers and the default capacity provider\nstrategy for a cluster.\n\nYou must specify both the available capacity providers and a default capacity\nprovider strategy for the cluster. If the specified cluster has existing\ncapacity providers associated with it, you must specify all existing capacity\nproviders in addition to any new ones you want to add. Any existing capacity\nproviders that are associated with a cluster that are omitted from a\n`PutClusterCapacityProviders` API call will be disassociated with the cluster.\nYou can only disassociate an existing capacity provider from a cluster if it's\nnot being used by any existing tasks.\n\nWhen creating a service or running a task on a cluster, if no capacity provider\nor launch type is specified, then the cluster's default capacity provider\nstrategy is used. We recommend that you define a default capacity provider\nstrategy for your cluster. However, you must specify an empty array (`[]`) to\nbypass defining a default strategy.","ref":"AWS.ECS.html#put_cluster_capacity_providers/3","title":"AWS.ECS.put_cluster_capacity_providers/3","type":"function"},{"doc":"This action is only used by the Amazon ECS agent, and it is not intended for use\noutside of the agent.\n\nRegisters an EC2 instance into the specified cluster. This instance becomes\navailable to place containers on.","ref":"AWS.ECS.html#register_container_instance/3","title":"AWS.ECS.register_container_instance/3","type":"function"},{"doc":"Registers a new task definition from the supplied `family` and\n`containerDefinitions`.\n\nOptionally, you can add data volumes to your containers with the `volumes`\nparameter. For more information about task definition parameters and defaults,\nsee [Amazon ECS Task Definitions](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/task_defintions.html)\nin the *Amazon Elastic Container Service Developer Guide*.\n\nYou can specify a role for your task with the `taskRoleArn` parameter. When you\nspecify a role for a task, its containers can then use the latest versions of\nthe CLI or SDKs to make API requests to the Amazon Web Services services that\nare specified in the policy that's associated with the role. For more\ninformation, see [IAM Roles for Tasks](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/task-iam-roles.html)\nin the *Amazon Elastic Container Service Developer Guide*.\n\nYou can specify a Docker networking mode for the containers in your task\ndefinition with the `networkMode` parameter. The available network modes\ncorrespond to those described in [Network settings](https://docs.docker.com/engine/reference/run/#/network-settings) in\nthe Docker run reference. If you specify the `awsvpc` network mode, the task is\nallocated an elastic network interface, and you must specify a\n`NetworkConfiguration` when you create a service or run a task with the task\ndefinition. For more information, see [Task Networking](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/task-networking.html)\nin the *Amazon Elastic Container Service Developer Guide*.","ref":"AWS.ECS.html#register_task_definition/3","title":"AWS.ECS.register_task_definition/3","type":"function"},{"doc":"Starts a new task using the specified task definition.\n\nYou can allow Amazon ECS to place tasks for you, or you can customize how Amazon\nECS places tasks using placement constraints and placement strategies. For more\ninformation, see [Scheduling Tasks](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/scheduling_tasks.html)\nin the *Amazon Elastic Container Service Developer Guide*.\n\nAlternatively, you can use `StartTask` to use your own scheduler or place tasks\nmanually on specific container instances.\n\nStarting April 15, 2023, Amazon Web Services will not onboard new customers to\nAmazon Elastic Inference (EI), and will help current customers migrate their\nworkloads to options that offer better price and performance. After April 15,\n2023, new customers will not be able to launch instances with Amazon EI\naccelerators in Amazon SageMaker, Amazon ECS, or Amazon EC2. However, customers\nwho have used Amazon EI at least once during the past 30-day period are\nconsidered current customers and will be able to continue using the service.\n\nYou can attach Amazon EBS volumes to Amazon ECS tasks by configuring the volume\nwhen creating or updating a service. For more infomation, see [Amazon EBS volumes](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ebs-volumes.html#ebs-volume-types)\nin the *Amazon Elastic Container Service Developer Guide*.\n\nThe Amazon ECS API follows an eventual consistency model. This is because of the\ndistributed nature of the system supporting the API. This means that the result\nof an API command you run that affects your Amazon ECS resources might not be\nimmediately visible to all subsequent commands you run. Keep this in mind when\nyou carry out an API command that immediately follows a previous API command.\n\nTo manage eventual consistency, you can do the following:\n\n  * Confirm the state of the resource before you run a command to\nmodify it. Run the DescribeTasks command using an exponential backoff algorithm\nto ensure that you allow enough time for the previous command to propagate\nthrough the system. To do this, run the DescribeTasks command repeatedly,\nstarting with a couple of seconds of wait time and increasing gradually up to\nfive minutes of wait time.\n\n  * Add wait time between subsequent commands, even if the\nDescribeTasks command returns an accurate response. Apply an exponential backoff\nalgorithm starting with a couple of seconds of wait time, and increase gradually\nup to about five minutes of wait time.","ref":"AWS.ECS.html#run_task/3","title":"AWS.ECS.run_task/3","type":"function"},{"doc":"Starts a new task from the specified task definition on the specified container\ninstance or instances.\n\nStarting April 15, 2023, Amazon Web Services will not onboard new customers to\nAmazon Elastic Inference (EI), and will help current customers migrate their\nworkloads to options that offer better price and performance. After April 15,\n2023, new customers will not be able to launch instances with Amazon EI\naccelerators in Amazon SageMaker, Amazon ECS, or Amazon EC2. However, customers\nwho have used Amazon EI at least once during the past 30-day period are\nconsidered current customers and will be able to continue using the service.\n\nAlternatively, you can use `RunTask` to place tasks for you. For more\ninformation, see [Scheduling Tasks](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/scheduling_tasks.html)\nin the *Amazon Elastic Container Service Developer Guide*.\n\nYou can attach Amazon EBS volumes to Amazon ECS tasks by configuring the volume\nwhen creating or updating a service. For more infomation, see [Amazon EBS volumes](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ebs-volumes.html#ebs-volume-types)\nin the *Amazon Elastic Container Service Developer Guide*.","ref":"AWS.ECS.html#start_task/3","title":"AWS.ECS.start_task/3","type":"function"},{"doc":"Stops a running task.\n\nAny tags associated with the task will be deleted.\n\nWhen `StopTask` is called on a task, the equivalent of `docker stop` is issued\nto the containers running in the task. This results in a `SIGTERM` value and a\ndefault 30-second timeout, after which the `SIGKILL` value is sent and the\ncontainers are forcibly stopped. If the container handles the `SIGTERM` value\ngracefully and exits within 30 seconds from receiving it, no `SIGKILL` value is\nsent.\n\nThe default 30-second timeout can be configured on the Amazon ECS container\nagent with the `ECS_CONTAINER_STOP_TIMEOUT` variable. For more information, see\n[Amazon ECS Container Agent Configuration](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-agent-config.html)\nin the *Amazon Elastic Container Service Developer Guide*.","ref":"AWS.ECS.html#stop_task/3","title":"AWS.ECS.stop_task/3","type":"function"},{"doc":"This action is only used by the Amazon ECS agent, and it is not intended for use\noutside of the agent.\n\nSent to acknowledge that an attachment changed states.","ref":"AWS.ECS.html#submit_attachment_state_changes/3","title":"AWS.ECS.submit_attachment_state_changes/3","type":"function"},{"doc":"This action is only used by the Amazon ECS agent, and it is not intended for use\noutside of the agent.\n\nSent to acknowledge that a container changed states.","ref":"AWS.ECS.html#submit_container_state_change/3","title":"AWS.ECS.submit_container_state_change/3","type":"function"},{"doc":"This action is only used by the Amazon ECS agent, and it is not intended for use\noutside of the agent.\n\nSent to acknowledge that a task changed states.","ref":"AWS.ECS.html#submit_task_state_change/3","title":"AWS.ECS.submit_task_state_change/3","type":"function"},{"doc":"Associates the specified tags to a resource with the specified `resourceArn`.\n\nIf existing tags on a resource aren't specified in the request parameters, they\naren't changed. When a resource is deleted, the tags that are associated with\nthat resource are deleted as well.","ref":"AWS.ECS.html#tag_resource/3","title":"AWS.ECS.tag_resource/3","type":"function"},{"doc":"Deletes specified tags from a resource.","ref":"AWS.ECS.html#untag_resource/3","title":"AWS.ECS.untag_resource/3","type":"function"},{"doc":"Modifies the parameters for a capacity provider.","ref":"AWS.ECS.html#update_capacity_provider/3","title":"AWS.ECS.update_capacity_provider/3","type":"function"},{"doc":"Updates the cluster.","ref":"AWS.ECS.html#update_cluster/3","title":"AWS.ECS.update_cluster/3","type":"function"},{"doc":"Modifies the settings to use for a cluster.","ref":"AWS.ECS.html#update_cluster_settings/3","title":"AWS.ECS.update_cluster_settings/3","type":"function"},{"doc":"Updates the Amazon ECS container agent on a specified container instance.\n\nUpdating the Amazon ECS container agent doesn't interrupt running tasks or\nservices on the container instance. The process for updating the agent differs\ndepending on whether your container instance was launched with the Amazon\nECS-optimized AMI or another operating system.\n\nThe `UpdateContainerAgent` API isn't supported for container instances using the\nAmazon ECS-optimized Amazon Linux 2 (arm64) AMI. To update the container agent,\nyou can update the `ecs-init` package. This updates the agent. For more\ninformation, see [Updating the Amazon ECS container agent](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/agent-update-ecs-ami.html)\nin the *Amazon Elastic Container Service Developer Guide*.\n\nAgent updates with the `UpdateContainerAgent` API operation do not apply to\nWindows container instances. We recommend that you launch new container\ninstances to update the agent version in your Windows clusters.\n\nThe `UpdateContainerAgent` API requires an Amazon ECS-optimized AMI or Amazon\nLinux AMI with the `ecs-init` service installed and running. For help updating\nthe Amazon ECS container agent on other operating systems, see [Manually updating the Amazon ECS container\nagent](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-agent-update.html#manually_update_agent)\nin the *Amazon Elastic Container Service Developer Guide*.","ref":"AWS.ECS.html#update_container_agent/3","title":"AWS.ECS.update_container_agent/3","type":"function"},{"doc":"Modifies the status of an Amazon ECS container instance.\n\nOnce a container instance has reached an `ACTIVE` state, you can change the\nstatus of a container instance to `DRAINING` to manually remove an instance from\na cluster, for example to perform system updates, update the Docker daemon, or\nscale down the cluster size.\n\nA container instance can't be changed to `DRAINING` until it has reached an\n`ACTIVE` status. If the instance is in any other status, an error will be\nreceived.\n\nWhen you set a container instance to `DRAINING`, Amazon ECS prevents new tasks\nfrom being scheduled for placement on the container instance and replacement\nservice tasks are started on other container instances in the cluster if the\nresources are available. Service tasks on the container instance that are in the\n`PENDING` state are stopped immediately.\n\nService tasks on the container instance that are in the `RUNNING` state are\nstopped and replaced according to the service's deployment configuration\nparameters, `minimumHealthyPercent` and `maximumPercent`. You can change the\ndeployment configuration of your service using `UpdateService`.\n\n  * If `minimumHealthyPercent` is below 100%, the scheduler can ignore\n`desiredCount` temporarily during task replacement. For example, `desiredCount`\nis four tasks, a minimum of 50% allows the scheduler to stop two existing tasks\nbefore starting two new tasks. If the minimum is 100%, the service scheduler\ncan't remove existing tasks until the replacement tasks are considered healthy.\nTasks for services that do not use a load balancer are considered healthy if\nthey're in the `RUNNING` state. Tasks for services that use a load balancer are\nconsidered healthy if they're in the `RUNNING` state and are reported as healthy\nby the load balancer.\n\n  * The `maximumPercent` parameter represents an upper limit on the\nnumber of running tasks during task replacement. You can use this to define the\nreplacement batch size. For example, if `desiredCount` is four tasks, a maximum\nof 200% starts four new tasks before stopping the four tasks to be drained,\nprovided that the cluster resources required to do this are available. If the\nmaximum is 100%, then replacement tasks can't start until the draining tasks\nhave stopped.\n\nAny `PENDING` or `RUNNING` tasks that do not belong to a service aren't\naffected. You must wait for them to finish or stop them manually.\n\nA container instance has completed draining when it has no more `RUNNING` tasks.\nYou can verify this using `ListTasks`.\n\nWhen a container instance has been drained, you can set a container instance to\n`ACTIVE` status and once it has reached that status the Amazon ECS scheduler can\nbegin scheduling tasks on the instance again.","ref":"AWS.ECS.html#update_container_instances_state/3","title":"AWS.ECS.update_container_instances_state/3","type":"function"},{"doc":"Modifies the parameters of a service.\n\nFor services using the rolling update (`ECS`) you can update the desired count,\ndeployment configuration, network configuration, load balancers, service\nregistries, enable ECS managed tags option, propagate tags option, task\nplacement constraints and strategies, and task definition. When you update any\nof these parameters, Amazon ECS starts new tasks with the new configuration.\n\nYou can attach Amazon EBS volumes to Amazon ECS tasks by configuring the volume\nwhen starting or running a task, or when creating or updating a service. For\nmore infomation, see [Amazon EBS volumes](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ebs-volumes.html#ebs-volume-types)\nin the *Amazon Elastic Container Service Developer Guide*. You can update your\nvolume configurations and trigger a new deployment. `volumeConfigurations` is\nonly supported for REPLICA service and not DAEMON service. If you leave\n`volumeConfigurations` `null`, it doesn't trigger a new deployment. For more\ninfomation on volumes, see [Amazon EBS volumes](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ebs-volumes.html#ebs-volume-types)\nin the *Amazon Elastic Container Service Developer Guide*.\n\nFor services using the blue/green (`CODE_DEPLOY`) deployment controller, only\nthe desired count, deployment configuration, health check grace period, task\nplacement constraints and strategies, enable ECS managed tags option, and\npropagate tags can be updated using this API. If the network configuration,\nplatform version, task definition, or load balancer need to be updated, create a\nnew CodeDeploy deployment. For more information, see\n[CreateDeployment](https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_CreateDeployment.html) in the *CodeDeploy API Reference*.\n\nFor services using an external deployment controller, you can update only the\ndesired count, task placement constraints and strategies, health check grace\nperiod, enable ECS managed tags option, and propagate tags option, using this\nAPI. If the launch type, load balancer, network configuration, platform version,\nor task definition need to be updated, create a new task set For more\ninformation, see `CreateTaskSet`.\n\nYou can add to or subtract from the number of instantiations of a task\ndefinition in a service by specifying the cluster that the service is running in\nand a new `desiredCount` parameter.\n\nYou can attach Amazon EBS volumes to Amazon ECS tasks by configuring the volume\nwhen starting or running a task, or when creating or updating a service. For\nmore infomation, see [Amazon EBS\nvolumes](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ebs-volumes.html#ebs-volume-types)\nin the *Amazon Elastic Container Service Developer Guide*.\n\nIf you have updated the container image of your application, you can create a\nnew task definition with that image and deploy it to your service. The service\nscheduler uses the minimum healthy percent and maximum percent parameters (in\nthe service's deployment configuration) to determine the deployment strategy.\n\nIf your updated Docker image uses the same tag as what is in the existing task\ndefinition for your service (for example, `my_image:latest`), you don't need to\ncreate a new revision of your task definition. You can update the service using\nthe `forceNewDeployment` option. The new tasks launched by the deployment pull\nthe current image/tag combination from your repository when they start.\n\nYou can also update the deployment configuration of a service. When a deployment\nis triggered by updating the task definition of a service, the service scheduler\nuses the deployment configuration parameters, `minimumHealthyPercent` and\n`maximumPercent`, to determine the deployment strategy.\n\n  * If `minimumHealthyPercent` is below 100%, the scheduler can ignore\n`desiredCount` temporarily during a deployment. For example, if `desiredCount`\nis four tasks, a minimum of 50% allows the scheduler to stop two existing tasks\nbefore starting two new tasks. Tasks for services that don't use a load balancer\nare considered healthy if they're in the `RUNNING` state. Tasks for services\nthat use a load balancer are considered healthy if they're in the `RUNNING`\nstate and are reported as healthy by the load balancer.\n\n  * The `maximumPercent` parameter represents an upper limit on the\nnumber of running tasks during a deployment. You can use it to define the\ndeployment batch size. For example, if `desiredCount` is four tasks, a maximum\nof 200% starts four new tasks before stopping the four older tasks (provided\nthat the cluster resources required to do this are available).\n\nWhen `UpdateService` stops a task during a deployment, the equivalent of `docker\nstop` is issued to the containers running in the task. This results in a\n`SIGTERM` and a 30-second timeout. After this, `SIGKILL` is sent and the\ncontainers are forcibly stopped. If the container handles the `SIGTERM`\ngracefully and exits within 30 seconds from receiving it, no `SIGKILL` is sent.\n\nWhen the service scheduler launches new tasks, it determines task placement in\nyour cluster with the following logic.\n\n  * Determine which of the container instances in your cluster can\nsupport your service's task definition. For example, they have the required CPU,\nmemory, ports, and container instance attributes.\n\n  * By default, the service scheduler attempts to balance tasks across\nAvailability Zones in this manner even though you can choose a different\nplacement strategy.\n\n    * Sort the valid container instances by the fewest\nnumber of running tasks for this service in the same Availability Zone as the\ninstance. For example, if zone A has one running service task and zones B and C\neach have zero, valid container instances in either zone B or C are considered\noptimal for placement.\n\n    * Place the new service task on a valid container\ninstance in an optimal Availability Zone (based on the previous steps), favoring\ncontainer instances with the fewest number of running tasks for this service.\n\nWhen the service scheduler stops running tasks, it attempts to maintain balance\nacross the Availability Zones in your cluster using the following logic:\n\n  * Sort the container instances by the largest number of running\ntasks for this service in the same Availability Zone as the instance. For\nexample, if zone A has one running service task and zones B and C each have two,\ncontainer instances in either zone B or C are considered optimal for\ntermination.\n\n  * Stop the task on a container instance in an optimal Availability\nZone (based on the previous steps), favoring container instances with the\nlargest number of running tasks for this service.\n\nYou must have a service-linked role when you update any of the following service\nproperties:\n\n   `loadBalancers`,\n\n   `serviceRegistries`\n\nFor more information about the role see the `CreateService` request parameter [\n`role`\n](https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_CreateService.html#ECS-CreateService-request-role).","ref":"AWS.ECS.html#update_service/3","title":"AWS.ECS.update_service/3","type":"function"},{"doc":"Modifies which task set in a service is the primary task set.\n\nAny parameters that are updated on the primary task set in a service will\ntransition to the service. This is used when a service uses the `EXTERNAL`\ndeployment controller type. For more information, see [Amazon ECS Deployment Types](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/deployment-types.html)\nin the *Amazon Elastic Container Service Developer Guide*.","ref":"AWS.ECS.html#update_service_primary_task_set/3","title":"AWS.ECS.update_service_primary_task_set/3","type":"function"},{"doc":"Updates the protection status of a task.\n\nYou can set `protectionEnabled` to `true` to protect your task from termination\nduring scale-in events from [Service Autoscaling](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/service-auto-scaling.html)\nor\n[deployments](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/deployment-types.html).  Task-protection, by default, expires after 2 hours at which point Amazon ECS\nclears the `protectionEnabled` property making the task eligible for termination\nby a subsequent scale-in event.\n\nYou can specify a custom expiration period for task protection from 1 minute to\nup to 2,880 minutes (48 hours). To specify the custom expiration period, set the\n`expiresInMinutes` property. The `expiresInMinutes` property is always reset\nwhen you invoke this operation for a task that already has `protectionEnabled`\nset to `true`. You can keep extending the protection expiration period of a task\nby invoking this operation repeatedly.\n\nTo learn more about Amazon ECS task protection, see [Task scale-in\nprotection](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/task-scale-in-protection.html)\nin the * *Amazon Elastic Container Service Developer Guide* *.\n\nThis operation is only supported for tasks belonging to an Amazon ECS service.\nInvoking this operation for a standalone task will result in an `TASK_NOT_VALID`\nfailure. For more information, see [API failure reasons](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/api_failures_messages.html).\n\nIf you prefer to set task protection from within the container, we recommend\nusing the [Task scale-in protection endpoint](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/task-scale-in-protection-endpoint.html).","ref":"AWS.ECS.html#update_task_protection/3","title":"AWS.ECS.update_task_protection/3","type":"function"},{"doc":"Modifies a task set.\n\nThis is used when a service uses the `EXTERNAL` deployment controller type. For\nmore information, see [Amazon ECS Deployment Types](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/deployment-types.html)\nin the *Amazon Elastic Container Service Developer Guide*.","ref":"AWS.ECS.html#update_task_set/3","title":"AWS.ECS.update_task_set/3","type":"function"},{"doc":"Amazon Elastic File System\n\nAmazon Elastic File System (Amazon EFS) provides simple, scalable file storage\nfor use with Amazon EC2 Linux and Mac instances in the Amazon Web Services\nCloud.\n\nWith Amazon EFS, storage capacity is elastic, growing and shrinking\nautomatically as you add and remove files, so that your applications have the\nstorage they need, when they need it. For more information, see the [Amazon Elastic File System API\nReference](https://docs.aws.amazon.com/efs/latest/ug/api-reference.html) and the\n[Amazon Elastic File System User Guide](https://docs.aws.amazon.com/efs/latest/ug/whatisefs.html).","ref":"AWS.EFS.html","title":"AWS.EFS","type":"module"},{"doc":"Creates an EFS access point.\n\nAn access point is an application-specific view into an EFS file system that\napplies an operating system user and group, and a file system path, to any file\nsystem request made through the access point. The operating system user and\ngroup override any identity information provided by the NFS client. The file\nsystem path is exposed as the access point's root directory. Applications using\nthe access point can only access data in the application's own directory and any\nsubdirectories. To learn more, see [Mounting a file system using EFS access points](https://docs.aws.amazon.com/efs/latest/ug/efs-access-points.html).\n\nIf multiple requests to create access points on the same file system are sent in\nquick succession, and the file system is near the limit of 1,000 access points,\nyou may experience a throttling response for these requests. This is to ensure\nthat the file system does not exceed the stated access point limit.\n\nThis operation requires permissions for the\n`elasticfilesystem:CreateAccessPoint` action.\n\nAccess points can be tagged on creation. If tags are specified in the creation\naction, IAM performs additional authorization on the\n`elasticfilesystem:TagResource` action to verify if users have permissions to\ncreate tags. Therefore, you must grant explicit permissions to use the\n`elasticfilesystem:TagResource` action. For more information, see [Granting permissions to tag resources during\ncreation](https://docs.aws.amazon.com/efs/latest/ug/using-tags-efs.html#supported-iam-actions-tagging.html).","ref":"AWS.EFS.html#create_access_point/3","title":"AWS.EFS.create_access_point/3","type":"function"},{"doc":"Creates a new, empty file system.\n\nThe operation requires a creation token in the request that Amazon EFS uses to\nensure idempotent creation (calling the operation with same creation token has\nno effect). If a file system does not currently exist that is owned by the\ncaller's Amazon Web Services account with the specified creation token, this\noperation does the following:\n\n  * Creates a new, empty file system. The file system will have an\nAmazon EFS assigned ID, and an initial lifecycle state `creating`.\n\n  * Returns with the description of the created file system.\n\nOtherwise, this operation returns a `FileSystemAlreadyExists` error with the ID\nof the existing file system.\n\nFor basic use cases, you can use a randomly generated UUID for the creation\ntoken.\n\nThe idempotent operation allows you to retry a `CreateFileSystem` call without\nrisk of creating an extra file system. This can happen when an initial call\nfails in a way that leaves it uncertain whether or not a file system was\nactually created. An example might be that a transport level timeout occurred or\nyour connection was reset. As long as you use the same creation token, if the\ninitial call had succeeded in creating a file system, the client can learn of\nits existence from the `FileSystemAlreadyExists` error.\n\nFor more information, see [Creating a file system](https://docs.aws.amazon.com/efs/latest/ug/creating-using-create-fs.html#creating-using-create-fs-part1)\nin the *Amazon EFS User Guide*.\n\nThe `CreateFileSystem` call returns while the file system's lifecycle state is\nstill `creating`. You can check the file system creation status by calling the\n`DescribeFileSystems` operation, which among other things returns the file\nsystem state.\n\nThis operation accepts an optional `PerformanceMode` parameter that you choose\nfor your file system. We recommend `generalPurpose` performance mode for all\nfile systems. File systems using the `maxIO` mode is a previous generation\nperformance type that is designed for highly parallelized workloads that can\ntolerate higher latencies than the General Purpose mode. Max I/O mode is not\nsupported for One Zone file systems or file systems that use Elastic throughput.\n\nDue to the higher per-operation latencies with Max I/O, we recommend using\nGeneral Purpose performance mode for all file systems.\n\nThe performance mode can't be changed after the file system has been created.\nFor more information, see [Amazon EFS performance modes](https://docs.aws.amazon.com/efs/latest/ug/performance.html#performancemodes.html).\n\nYou can set the throughput mode for the file system using the `ThroughputMode`\nparameter.\n\nAfter the file system is fully created, Amazon EFS sets its lifecycle state to\n`available`, at which point you can create one or more mount targets for the\nfile system in your VPC. For more information, see `CreateMountTarget`. You\nmount your Amazon EFS file system on an EC2 instances in your VPC by using the\nmount target. For more information, see [Amazon EFS: How it Works](https://docs.aws.amazon.com/efs/latest/ug/how-it-works.html).\n\nThis operation requires permissions for the `elasticfilesystem:CreateFileSystem`\naction.\n\nFile systems can be tagged on creation. If tags are specified in the creation\naction, IAM performs additional authorization on the\n`elasticfilesystem:TagResource` action to verify if users have permissions to\ncreate tags. Therefore, you must grant explicit permissions to use the\n`elasticfilesystem:TagResource` action. For more information, see [Granting permissions to tag resources during\ncreation](https://docs.aws.amazon.com/efs/latest/ug/using-tags-efs.html#supported-iam-actions-tagging.html).","ref":"AWS.EFS.html#create_file_system/3","title":"AWS.EFS.create_file_system/3","type":"function"},{"doc":"Creates a mount target for a file system.\n\nYou can then mount the file system on EC2 instances by using the mount target.\n\nYou can create one mount target in each Availability Zone in your VPC. All EC2\ninstances in a VPC within a given Availability Zone share a single mount target\nfor a given file system. If you have multiple subnets in an Availability Zone,\nyou create a mount target in one of the subnets. EC2 instances do not need to be\nin the same subnet as the mount target in order to access their file system.\n\nYou can create only one mount target for a One Zone file system. You must create\nthat mount target in the same Availability Zone in which the file system is\nlocated. Use the `AvailabilityZoneName` and `AvailabiltyZoneId` properties in\nthe `DescribeFileSystems` response object to get this information. Use the\n`subnetId` associated with the file system's Availability Zone when creating the\nmount target.\n\nFor more information, see [Amazon EFS: How it Works](https://docs.aws.amazon.com/efs/latest/ug/how-it-works.html).\n\nTo create a mount target for a file system, the file system's lifecycle state\nmust be `available`. For more information, see `DescribeFileSystems`.\n\nIn the request, provide the following:\n\n  * The file system ID for which you are creating the mount target.\n\n  * A subnet ID, which determines the following:\n\n    * The VPC in which Amazon EFS creates the mount target\n\n    * The Availability Zone in which Amazon EFS creates the\nmount target\n\n    * The IP address range from which Amazon EFS selects the\nIP address of the mount target (if you don't specify an IP address in the\nrequest)\n\nAfter creating the mount target, Amazon EFS returns a response that includes, a\n`MountTargetId` and an `IpAddress`. You use this IP address when mounting the\nfile system in an EC2 instance. You can also use the mount target's DNS name\nwhen mounting the file system. The EC2 instance on which you mount the file\nsystem by using the mount target can resolve the mount target's DNS name to its\nIP address. For more information, see [How it Works: Implementation Overview](https://docs.aws.amazon.com/efs/latest/ug/how-it-works.html#how-it-works-implementation).\n\nNote that you can create mount targets for a file system in only one VPC, and\nthere can be only one mount target per Availability Zone. That is, if the file\nsystem already has one or more mount targets created for it, the subnet\nspecified in the request to add another mount target must meet the following\nrequirements:\n\n  * Must belong to the same VPC as the subnets of the existing mount\ntargets\n\n  * Must not be in the same Availability Zone as any of the subnets of\nthe existing mount targets\n\nIf the request satisfies the requirements, Amazon EFS does the following:\n\n  * Creates a new mount target in the specified subnet.\n\n  * Also creates a new network interface in the subnet as follows:\n\n    * If the request provides an `IpAddress`, Amazon EFS\nassigns that IP address to the network interface. Otherwise, Amazon EFS assigns\na free address in the subnet (in the same way that the Amazon EC2\n`CreateNetworkInterface` call does when a request does not specify a primary\nprivate IP address).\n\n    * If the request provides `SecurityGroups`, this network\ninterface is associated with those security groups. Otherwise, it belongs to the\ndefault security group for the subnet's VPC.\n\n    * Assigns the description `Mount target *fsmt-id* for\nfile system *fs-id* ` where ` *fsmt-id* ` is the mount target ID, and ` *fs-id*\n` is the `FileSystemId`.\n\n    * Sets the `requesterManaged` property of the network\ninterface to `true`, and the `requesterId` value to `EFS`.\n\nEach Amazon EFS mount target has one corresponding requester-managed EC2 network\ninterface. After the network interface is created, Amazon EFS sets the\n`NetworkInterfaceId` field in the mount target's description to the network\ninterface ID, and the `IpAddress` field to its address. If network interface\ncreation fails, the entire `CreateMountTarget` operation fails.\n\nThe `CreateMountTarget` call returns only after creating the network interface,\nbut while the mount target state is still `creating`, you can check the mount\ntarget creation status by calling the `DescribeMountTargets` operation, which\namong other things returns the mount target state.\n\nWe recommend that you create a mount target in each of the Availability Zones.\nThere are cost considerations for using a file system in an Availability Zone\nthrough a mount target created in another Availability Zone. For more\ninformation, see [Amazon EFS](http://aws.amazon.com/efs/). In addition, by\nalways using a mount target local to the instance's Availability Zone, you\neliminate a partial failure scenario. If the Availability Zone in which your\nmount target is created goes down, then you can't access your file system\nthrough that mount target.\n\nThis operation requires permissions for the following action on the file system:\n\n  * `elasticfilesystem:CreateMountTarget`\n\nThis operation also requires permissions for the following Amazon EC2 actions:\n\n  * `ec2:DescribeSubnets`\n\n  * `ec2:DescribeNetworkInterfaces`\n\n  * `ec2:CreateNetworkInterface`","ref":"AWS.EFS.html#create_mount_target/3","title":"AWS.EFS.create_mount_target/3","type":"function"},{"doc":"Creates a replication configuration that replicates an existing EFS file system\nto a new, read-only file system.\n\nFor more information, see [Amazon EFS replication](https://docs.aws.amazon.com/efs/latest/ug/efs-replication.html) in\nthe *Amazon EFS User Guide*. The replication configuration specifies the\nfollowing:\n\n  * **Source file system** – The EFS file system that you want\nreplicated. The source file system cannot be a destination file system in an\nexisting replication configuration.\n\n  * **Amazon Web Services Region** – The Amazon Web Services Region in\nwhich the destination file system is created. Amazon EFS replication is\navailable in all Amazon Web Services Regions in which EFS is available. The\nRegion must be enabled. For more information, see [Managing Amazon Web Services Regions](https://docs.aws.amazon.com/general/latest/gr/rande-manage.html#rande-manage-enable)\nin the *Amazon Web Services General Reference Reference Guide*.\n\n  * **Destination file system configuration** – The configuration of\nthe destination file system to which the source file system will be replicated.\nThere can only be one destination file system in a replication configuration.\n\nParameters for the replication configuration include:\n\n    * **File system ID** – The ID of the destination file\nsystem for the replication. If no ID is provided, then EFS creates a new file\nsystem with the default settings. For existing file systems, the file system's\nreplication overwrite protection must be disabled. For more information, see [\nReplicating to an existing file\nsystem](https://docs.aws.amazon.com/efs/latest/ug/efs-replication#replicate-existing-destination).\n\n    * **Availability Zone** – If you want the destination\nfile system to use One Zone storage, you must specify the Availability Zone to\ncreate the file system in. For more information, see [ EFS file system types](https://docs.aws.amazon.com/efs/latest/ug/storage-classes.html) in the\n*Amazon EFS User Guide*.\n\n    * **Encryption** – All destination file systems are\ncreated with encryption at rest enabled. You can specify the Key Management\nService (KMS) key that is used to encrypt the destination file system. If you\ndon't specify a KMS key, your service-managed KMS key for Amazon EFS is used.\n\nAfter the file system is created, you cannot change the KMS key.\n\nAfter the file system is created, you cannot change the KMS key.\n\nFor new destination file systems, the following properties are set by default:\n\n  * **Performance mode** - The destination file system's performance\nmode matches that of the source file system, unless the destination file system\nuses EFS One Zone storage. In that case, the General Purpose performance mode is\nused. The performance mode cannot be changed.\n\n  * **Throughput mode** - The destination file system's throughput\nmode matches that of the source file system. After the file system is created,\nyou can modify the throughput mode.\n\n  * **Lifecycle management** – Lifecycle management is not enabled on\nthe destination file system. After the destination file system is created, you\ncan enable lifecycle management.\n\n  * **Automatic backups** – Automatic daily backups are enabled on the\ndestination file system. After the file system is created, you can change this\nsetting.\n\nFor more information, see [Amazon EFS replication](https://docs.aws.amazon.com/efs/latest/ug/efs-replication.html) in\nthe *Amazon EFS User Guide*.","ref":"AWS.EFS.html#create_replication_configuration/4","title":"AWS.EFS.create_replication_configuration/4","type":"function"},{"doc":"DEPRECATED - `CreateTags` is deprecated and not maintained.\n\nTo create tags for EFS resources, use the API action.\n\nCreates or overwrites tags associated with a file system. Each tag is a\nkey-value pair. If a tag key specified in the request already exists on the file\nsystem, this operation overwrites its value with the value provided in the\nrequest. If you add the `Name` tag to your file system, Amazon EFS returns it in\nthe response to the `DescribeFileSystems` operation.\n\nThis operation requires permission for the `elasticfilesystem:CreateTags`\naction.","ref":"AWS.EFS.html#create_tags/4","title":"AWS.EFS.create_tags/4","type":"function"},{"doc":"Deletes the specified access point.\n\nAfter deletion is complete, new clients can no longer connect to the access\npoints. Clients connected to the access point at the time of deletion will\ncontinue to function until they terminate their connection.\n\nThis operation requires permissions for the\n`elasticfilesystem:DeleteAccessPoint` action.","ref":"AWS.EFS.html#delete_access_point/4","title":"AWS.EFS.delete_access_point/4","type":"function"},{"doc":"Deletes a file system, permanently severing access to its contents.\n\nUpon return, the file system no longer exists and you can't access any contents\nof the deleted file system.\n\nYou need to manually delete mount targets attached to a file system before you\ncan delete an EFS file system. This step is performed for you when you use the\nAmazon Web Services console to delete a file system.\n\nYou cannot delete a file system that is part of an EFS Replication\nconfiguration. You need to delete the replication configuration first.\n\nYou can't delete a file system that is in use. That is, if the file system has\nany mount targets, you must first delete them. For more information, see\n`DescribeMountTargets` and `DeleteMountTarget`.\n\nThe `DeleteFileSystem` call returns while the file system state is still\n`deleting`. You can check the file system deletion status by calling the\n`DescribeFileSystems` operation, which returns a list of file systems in your\naccount. If you pass file system ID or creation token for the deleted file\nsystem, the `DescribeFileSystems` returns a `404 FileSystemNotFound` error.\n\nThis operation requires permissions for the `elasticfilesystem:DeleteFileSystem`\naction.","ref":"AWS.EFS.html#delete_file_system/4","title":"AWS.EFS.delete_file_system/4","type":"function"},{"doc":"Deletes the `FileSystemPolicy` for the specified file system.\n\nThe default `FileSystemPolicy` goes into effect once the existing policy is\ndeleted. For more information about the default file system policy, see [Using Resource-based Policies with\nEFS](https://docs.aws.amazon.com/efs/latest/ug/res-based-policies-efs.html).\n\nThis operation requires permissions for the\n`elasticfilesystem:DeleteFileSystemPolicy` action.","ref":"AWS.EFS.html#delete_file_system_policy/4","title":"AWS.EFS.delete_file_system_policy/4","type":"function"},{"doc":"Deletes the specified mount target.\n\nThis operation forcibly breaks any mounts of the file system by using the mount\ntarget that is being deleted, which might disrupt instances or applications\nusing those mounts. To avoid applications getting cut off abruptly, you might\nconsider unmounting any mounts of the mount target, if feasible. The operation\nalso deletes the associated network interface. Uncommitted writes might be lost,\nbut breaking a mount target using this operation does not corrupt the file\nsystem itself. The file system you created remains. You can mount an EC2\ninstance in your VPC by using another mount target.\n\nThis operation requires permissions for the following action on the file system:\n\n  * `elasticfilesystem:DeleteMountTarget`\n\nThe `DeleteMountTarget` call returns while the mount target state is still\n`deleting`. You can check the mount target deletion by calling the\n`DescribeMountTargets` operation, which returns a list of mount target\ndescriptions for the given file system.\n\nThe operation also requires permissions for the following Amazon EC2 action on\nthe mount target's network interface:\n\n  * `ec2:DeleteNetworkInterface`","ref":"AWS.EFS.html#delete_mount_target/4","title":"AWS.EFS.delete_mount_target/4","type":"function"},{"doc":"Deletes a replication configuration.\n\nDeleting a replication configuration ends the replication process. After a\nreplication configuration is deleted, the destination file system becomes\n`Writeable` and its replication overwrite protection is re-enabled. For more\ninformation, see [Delete a replication configuration](https://docs.aws.amazon.com/efs/latest/ug/delete-replications.html).\n\nThis operation requires permissions for the\n`elasticfilesystem:DeleteReplicationConfiguration` action.","ref":"AWS.EFS.html#delete_replication_configuration/4","title":"AWS.EFS.delete_replication_configuration/4","type":"function"},{"doc":"DEPRECATED - `DeleteTags` is deprecated and not maintained.\n\nTo remove tags from EFS resources, use the API action.\n\nDeletes the specified tags from a file system. If the `DeleteTags` request\nincludes a tag key that doesn't exist, Amazon EFS ignores it and doesn't cause\nan error. For more information about tags and related restrictions, see [Tag restrictions](https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/cost-alloc-tags.html)\nin the *Billing and Cost Management User Guide*.\n\nThis operation requires permissions for the `elasticfilesystem:DeleteTags`\naction.","ref":"AWS.EFS.html#delete_tags/4","title":"AWS.EFS.delete_tags/4","type":"function"},{"doc":"Returns the description of a specific Amazon EFS access point if the\n`AccessPointId` is provided.\n\nIf you provide an EFS `FileSystemId`, it returns descriptions of all access\npoints for that file system. You can provide either an `AccessPointId` or a\n`FileSystemId` in the request, but not both.\n\nThis operation requires permissions for the\n`elasticfilesystem:DescribeAccessPoints` action.","ref":"AWS.EFS.html#describe_access_points/6","title":"AWS.EFS.describe_access_points/6","type":"function"},{"doc":"Returns the account preferences settings for the Amazon Web Services account\nassociated with the user making the request, in the current Amazon Web Services\nRegion.","ref":"AWS.EFS.html#describe_account_preferences/2","title":"AWS.EFS.describe_account_preferences/2","type":"function"},{"doc":"Returns the backup policy for the specified EFS file system.","ref":"AWS.EFS.html#describe_backup_policy/3","title":"AWS.EFS.describe_backup_policy/3","type":"function"},{"doc":"Returns the `FileSystemPolicy` for the specified EFS file system.\n\nThis operation requires permissions for the\n`elasticfilesystem:DescribeFileSystemPolicy` action.","ref":"AWS.EFS.html#describe_file_system_policy/3","title":"AWS.EFS.describe_file_system_policy/3","type":"function"},{"doc":"Returns the description of a specific Amazon EFS file system if either the file\nsystem `CreationToken` or the `FileSystemId` is provided.\n\nOtherwise, it returns descriptions of all file systems owned by the caller's\nAmazon Web Services account in the Amazon Web Services Region of the endpoint\nthat you're calling.\n\nWhen retrieving all file system descriptions, you can optionally specify the\n`MaxItems` parameter to limit the number of descriptions in a response. This\nnumber is automatically set to 100. If more file system descriptions remain,\nAmazon EFS returns a `NextMarker`, an opaque token, in the response. In this\ncase, you should send a subsequent request with the `Marker` request parameter\nset to the value of `NextMarker`.\n\nTo retrieve a list of your file system descriptions, this operation is used in\nan iterative process, where `DescribeFileSystems` is called first without the\n`Marker` and then the operation continues to call it with the `Marker` parameter\nset to the value of the `NextMarker` from the previous response until the\nresponse has no `NextMarker`.\n\nThe order of file systems returned in the response of one `DescribeFileSystems`\ncall and the order of file systems returned across the responses of a multi-call\niteration is unspecified.\n\nThis operation requires permissions for the\n`elasticfilesystem:DescribeFileSystems` action.","ref":"AWS.EFS.html#describe_file_systems/6","title":"AWS.EFS.describe_file_systems/6","type":"function"},{"doc":"Returns the current `LifecycleConfiguration` object for the specified Amazon EFS\nfile system.\n\nLifecycle management uses the `LifecycleConfiguration` object to identify when\nto move files between storage classes. For a file system without a\n`LifecycleConfiguration` object, the call returns an empty array in the\nresponse.\n\nThis operation requires permissions for the\n`elasticfilesystem:DescribeLifecycleConfiguration` operation.","ref":"AWS.EFS.html#describe_lifecycle_configuration/3","title":"AWS.EFS.describe_lifecycle_configuration/3","type":"function"},{"doc":"Returns the security groups currently in effect for a mount target.\n\nThis operation requires that the network interface of the mount target has been\ncreated and the lifecycle state of the mount target is not `deleted`.\n\nThis operation requires permissions for the following actions:\n\n  * `elasticfilesystem:DescribeMountTargetSecurityGroups` action on\nthe mount target's file system.\n\n  * `ec2:DescribeNetworkInterfaceAttribute` action on the mount\ntarget's network interface.","ref":"AWS.EFS.html#describe_mount_target_security_groups/3","title":"AWS.EFS.describe_mount_target_security_groups/3","type":"function"},{"doc":"Returns the descriptions of all the current mount targets, or a specific mount\ntarget, for a file system.\n\nWhen requesting all of the current mount targets, the order of mount targets\nreturned in the response is unspecified.\n\nThis operation requires permissions for the\n`elasticfilesystem:DescribeMountTargets` action, on either the file system ID\nthat you specify in `FileSystemId`, or on the file system of the mount target\nthat you specify in `MountTargetId`.","ref":"AWS.EFS.html#describe_mount_targets/7","title":"AWS.EFS.describe_mount_targets/7","type":"function"},{"doc":"Retrieves the replication configuration for a specific file system.\n\nIf a file system is not specified, all of the replication configurations for the\nAmazon Web Services account in an Amazon Web Services Region are retrieved.","ref":"AWS.EFS.html#describe_replication_configurations/5","title":"AWS.EFS.describe_replication_configurations/5","type":"function"},{"doc":"DEPRECATED - The `DescribeTags` action is deprecated and not maintained.\n\nTo view tags associated with EFS resources, use the `ListTagsForResource` API\naction.\n\nReturns the tags associated with a file system. The order of tags returned in\nthe response of one `DescribeTags` call and the order of tags returned across\nthe responses of a multiple-call iteration (when using pagination) is\nunspecified.\n\nThis operation requires permissions for the `elasticfilesystem:DescribeTags`\naction.","ref":"AWS.EFS.html#describe_tags/5","title":"AWS.EFS.describe_tags/5","type":"function"},{"doc":"Lists all tags for a top-level EFS resource.\n\nYou must provide the ID of the resource that you want to retrieve the tags for.\n\nThis operation requires permissions for the\n`elasticfilesystem:DescribeAccessPoints` action.","ref":"AWS.EFS.html#list_tags_for_resource/5","title":"AWS.EFS.list_tags_for_resource/5","type":"function"},{"doc":"","ref":"AWS.EFS.html#metadata/0","title":"AWS.EFS.metadata/0","type":"function"},{"doc":"Modifies the set of security groups in effect for a mount target.\n\nWhen you create a mount target, Amazon EFS also creates a new network interface.\nFor more information, see `CreateMountTarget`. This operation replaces the\nsecurity groups in effect for the network interface associated with a mount\ntarget, with the `SecurityGroups` provided in the request. This operation\nrequires that the network interface of the mount target has been created and the\nlifecycle state of the mount target is not `deleted`.\n\nThe operation requires permissions for the following actions:\n\n  * `elasticfilesystem:ModifyMountTargetSecurityGroups` action on the\nmount target's file system.\n\n  * `ec2:ModifyNetworkInterfaceAttribute` action on the mount target's\nnetwork interface.","ref":"AWS.EFS.html#modify_mount_target_security_groups/4","title":"AWS.EFS.modify_mount_target_security_groups/4","type":"function"},{"doc":"Use this operation to set the account preference in the current Amazon Web\nServices Region to use long 17 character (63 bit) or short 8 character (32 bit)\nresource IDs for new EFS file system and mount target resources.\n\nAll existing resource IDs are not affected by any changes you make. You can set\nthe ID preference during the opt-in period as EFS transitions to long resource\nIDs. For more information, see [Managing Amazon EFS resource IDs](https://docs.aws.amazon.com/efs/latest/ug/manage-efs-resource-ids.html).\n\nStarting in October, 2021, you will receive an error if you try to set the\naccount preference to use the short 8 character format resource ID. Contact\nAmazon Web Services support if you receive an error and must use short IDs for\nfile system and mount target resources.","ref":"AWS.EFS.html#put_account_preferences/3","title":"AWS.EFS.put_account_preferences/3","type":"function"},{"doc":"Updates the file system's backup policy.\n\nUse this action to start or stop automatic backups of the file system.","ref":"AWS.EFS.html#put_backup_policy/4","title":"AWS.EFS.put_backup_policy/4","type":"function"},{"doc":"Applies an Amazon EFS `FileSystemPolicy` to an Amazon EFS file system.\n\nA file system policy is an IAM resource-based policy and can contain multiple\npolicy statements. A file system always has exactly one file system policy,\nwhich can be the default policy or an explicit policy set or updated using this\nAPI operation. EFS file system policies have a 20,000 character limit. When an\nexplicit policy is set, it overrides the default policy. For more information\nabout the default file system policy, see [Default EFS File System Policy](https://docs.aws.amazon.com/efs/latest/ug/iam-access-control-nfs-efs.html#default-filesystempolicy).\n\nEFS file system policies have a 20,000 character limit.\n\nThis operation requires permissions for the\n`elasticfilesystem:PutFileSystemPolicy` action.","ref":"AWS.EFS.html#put_file_system_policy/4","title":"AWS.EFS.put_file_system_policy/4","type":"function"},{"doc":"Use this action to manage storage for your file system.\n\nA `LifecycleConfiguration` consists of one or more `LifecyclePolicy` objects\nthat define the following:\n\n  * ** `TransitionToIA` ** – When to move files in the file system\nfrom primary storage (Standard storage class) into the Infrequent Access (IA)\nstorage.\n\n  * ** `TransitionToArchive` ** – When to move files in the file\nsystem from their current storage class (either IA or Standard storage) into the\nArchive storage.\n\nFile systems cannot transition into Archive storage before transitioning into IA\nstorage. Therefore, TransitionToArchive must either not be set or must be later\nthan TransitionToIA.\n\nThe Archive storage class is available only for file systems that use the\nElastic Throughput mode and the General Purpose Performance mode.\n\n  * ** `TransitionToPrimaryStorageClass` ** – Whether to move files in\nthe file system back to primary storage (Standard storage class) after they are\naccessed in IA or Archive storage.\n\nFor more information, see [ Managing file system storage](https://docs.aws.amazon.com/efs/latest/ug/lifecycle-management-efs.html).\n\nEach Amazon EFS file system supports one lifecycle configuration, which applies\nto all files in the file system. If a `LifecycleConfiguration` object already\nexists for the specified file system, a `PutLifecycleConfiguration` call\nmodifies the existing configuration. A `PutLifecycleConfiguration` call with an\nempty `LifecyclePolicies` array in the request body deletes any existing\n`LifecycleConfiguration`. In the request, specify the following:\n\n  * The ID for the file system for which you are enabling, disabling,\nor modifying Lifecycle management.\n\n  * A `LifecyclePolicies` array of `LifecyclePolicy` objects that\ndefine when to move files to IA storage, to Archive storage, and back to primary\nstorage.\n\nAmazon EFS requires that each `LifecyclePolicy` object have only have a single\ntransition, so the `LifecyclePolicies` array needs to be structured with\nseparate `LifecyclePolicy` objects. See the example requests in the following\nsection for more information.\n\nThis operation requires permissions for the\n`elasticfilesystem:PutLifecycleConfiguration` operation.\n\nTo apply a `LifecycleConfiguration` object to an encrypted file system, you need\nthe same Key Management Service permissions as when you created the encrypted\nfile system.","ref":"AWS.EFS.html#put_lifecycle_configuration/4","title":"AWS.EFS.put_lifecycle_configuration/4","type":"function"},{"doc":"Creates a tag for an EFS resource.\n\nYou can create tags for EFS file systems and access points using this API\noperation.\n\nThis operation requires permissions for the `elasticfilesystem:TagResource`\naction.","ref":"AWS.EFS.html#tag_resource/4","title":"AWS.EFS.tag_resource/4","type":"function"},{"doc":"Removes tags from an EFS resource.\n\nYou can remove tags from EFS file systems and access points using this API\noperation.\n\nThis operation requires permissions for the `elasticfilesystem:UntagResource`\naction.","ref":"AWS.EFS.html#untag_resource/4","title":"AWS.EFS.untag_resource/4","type":"function"},{"doc":"Updates the throughput mode or the amount of provisioned throughput of an\nexisting file system.","ref":"AWS.EFS.html#update_file_system/4","title":"AWS.EFS.update_file_system/4","type":"function"},{"doc":"Updates protection on the file system.\n\nThis operation requires permissions for the\n`elasticfilesystem:UpdateFileSystemProtection` action.","ref":"AWS.EFS.html#update_file_system_protection/4","title":"AWS.EFS.update_file_system_protection/4","type":"function"},{"doc":"Amazon Elastic Kubernetes Service (Amazon EKS) is a managed service that makes\nit easy for you to run Kubernetes on Amazon Web Services without needing to\nsetup or maintain your own Kubernetes control plane.\n\nKubernetes is an open-source system for automating the deployment, scaling, and\nmanagement of containerized applications.\n\nAmazon EKS runs up-to-date versions of the open-source Kubernetes software, so\nyou can use all the existing plugins and tooling from the Kubernetes community.\nApplications running on Amazon EKS are fully compatible with applications\nrunning on any standard Kubernetes environment, whether running in on-premises\ndata centers or public clouds. This means that you can easily migrate any\nstandard Kubernetes application to Amazon EKS without any code modification\nrequired.","ref":"AWS.EKS.html","title":"AWS.EKS","type":"module"},{"doc":"Associates an access policy and its scope to an access entry.\n\nFor more information about associating access policies, see [Associating and disassociating access policies to and from access\nentries](https://docs.aws.amazon.com/eks/latest/userguide/access-policies.html)\nin the *Amazon EKS User Guide*.","ref":"AWS.EKS.html#associate_access_policy/5","title":"AWS.EKS.associate_access_policy/5","type":"function"},{"doc":"Associates an encryption configuration to an existing cluster.\n\nUse this API to enable encryption on existing clusters that don't already have\nencryption enabled. This allows you to implement a defense-in-depth security\nstrategy without migrating applications to new Amazon EKS clusters.","ref":"AWS.EKS.html#associate_encryption_config/4","title":"AWS.EKS.associate_encryption_config/4","type":"function"},{"doc":"Associates an identity provider configuration to a cluster.\n\nIf you want to authenticate identities using an identity provider, you can\ncreate an identity provider configuration and associate it to your cluster.\nAfter configuring authentication to your cluster you can create Kubernetes\n`Role` and `ClusterRole` objects, assign permissions to them, and then bind them\nto the identities using Kubernetes `RoleBinding` and `ClusterRoleBinding`\nobjects. For more information see [Using RBAC Authorization](https://kubernetes.io/docs/reference/access-authn-authz/rbac/) in\nthe Kubernetes documentation.","ref":"AWS.EKS.html#associate_identity_provider_config/4","title":"AWS.EKS.associate_identity_provider_config/4","type":"function"},{"doc":"Creates an access entry.\n\nAn access entry allows an IAM principal to access your cluster. Access entries\ncan replace the need to maintain entries in the `aws-auth` `ConfigMap` for\nauthentication. You have the following options for authorizing an IAM principal\nto access Kubernetes objects on your cluster: Kubernetes role-based access\ncontrol (RBAC), Amazon EKS, or both. Kubernetes RBAC authorization requires you\nto create and manage Kubernetes `Role`, `ClusterRole`, `RoleBinding`, and\n`ClusterRoleBinding` objects, in addition to managing access entries. If you use\nAmazon EKS authorization exclusively, you don't need to create and manage\nKubernetes `Role`, `ClusterRole`, `RoleBinding`, and `ClusterRoleBinding`\nobjects.\n\nFor more information about access entries, see [Access entries](https://docs.aws.amazon.com/eks/latest/userguide/access-entries.html)\nin the *Amazon EKS User Guide*.","ref":"AWS.EKS.html#create_access_entry/4","title":"AWS.EKS.create_access_entry/4","type":"function"},{"doc":"Creates an Amazon EKS add-on.\n\nAmazon EKS add-ons help to automate the provisioning and lifecycle management of\ncommon operational software for Amazon EKS clusters. For more information, see\n[Amazon EKS add-ons](https://docs.aws.amazon.com/eks/latest/userguide/eks-add-ons.html) in\nthe *Amazon EKS User Guide*.","ref":"AWS.EKS.html#create_addon/4","title":"AWS.EKS.create_addon/4","type":"function"},{"doc":"Creates an Amazon EKS control plane.\n\nThe Amazon EKS control plane consists of control plane instances that run the\nKubernetes software, such as `etcd` and the API server. The control plane runs\nin an account managed by Amazon Web Services, and the Kubernetes API is exposed\nby the Amazon EKS API server endpoint. Each Amazon EKS cluster control plane is\nsingle tenant and unique. It runs on its own set of Amazon EC2 instances.\n\nThe cluster control plane is provisioned across multiple Availability Zones and\nfronted by an Elastic Load Balancing Network Load Balancer. Amazon EKS also\nprovisions elastic network interfaces in your VPC subnets to provide\nconnectivity from the control plane instances to the nodes (for example, to\nsupport `kubectl exec`, `logs`, and `proxy` data flows).\n\nAmazon EKS nodes run in your Amazon Web Services account and connect to your\ncluster's control plane over the Kubernetes API server endpoint and a\ncertificate file that is created for your cluster.\n\nYou can use the `endpointPublicAccess` and `endpointPrivateAccess` parameters to\nenable or disable public and private access to your cluster's Kubernetes API\nserver endpoint. By default, public access is enabled, and private access is\ndisabled. For more information, see [Amazon EKS Cluster Endpoint Access Control](https://docs.aws.amazon.com/eks/latest/userguide/cluster-endpoint.html)\nin the * *Amazon EKS User Guide* *.\n\nYou can use the `logging` parameter to enable or disable exporting the\nKubernetes control plane logs for your cluster to CloudWatch Logs. By default,\ncluster control plane logs aren't exported to CloudWatch Logs. For more\ninformation, see [Amazon EKS Cluster Control Plane Logs](https://docs.aws.amazon.com/eks/latest/userguide/control-plane-logs.html)\nin the * *Amazon EKS User Guide* *.\n\nCloudWatch Logs ingestion, archive storage, and data scanning rates apply to\nexported control plane logs. For more information, see [CloudWatch Pricing](http://aws.amazon.com/cloudwatch/pricing/).\n\nIn most cases, it takes several minutes to create a cluster. After you create an\nAmazon EKS cluster, you must configure your Kubernetes tooling to communicate\nwith the API server and launch nodes into your cluster. For more information,\nsee [Managing Cluster Authentication](https://docs.aws.amazon.com/eks/latest/userguide/managing-auth.html)\nand [Launching Amazon EKS nodes](https://docs.aws.amazon.com/eks/latest/userguide/launch-workers.html) in\nthe *Amazon EKS User Guide*.","ref":"AWS.EKS.html#create_cluster/3","title":"AWS.EKS.create_cluster/3","type":"function"},{"doc":"Creates an EKS Anywhere subscription.\n\nWhen a subscription is created, it is a contract agreement for the length of the\nterm specified in the request. Licenses that are used to validate support are\nprovisioned in Amazon Web Services License Manager and the caller account is\ngranted access to EKS Anywhere Curated Packages.","ref":"AWS.EKS.html#create_eks_anywhere_subscription/3","title":"AWS.EKS.create_eks_anywhere_subscription/3","type":"function"},{"doc":"Creates an Fargate profile for your Amazon EKS cluster.\n\nYou must have at least one Fargate profile in a cluster to be able to run pods\non Fargate.\n\nThe Fargate profile allows an administrator to declare which pods run on Fargate\nand specify which pods run on which Fargate profile. This declaration is done\nthrough the profile’s selectors. Each profile can have up to five selectors that\ncontain a namespace and labels. A namespace is required for every selector. The\nlabel field consists of multiple optional key-value pairs. Pods that match the\nselectors are scheduled on Fargate. If a to-be-scheduled pod matches any of the\nselectors in the Fargate profile, then that pod is run on Fargate.\n\nWhen you create a Fargate profile, you must specify a pod execution role to use\nwith the pods that are scheduled with the profile. This role is added to the\ncluster's Kubernetes [Role Based Access Control](https://kubernetes.io/docs/reference/access-authn-authz/rbac/) (RBAC)\nfor authorization so that the `kubelet` that is running on the Fargate\ninfrastructure can register with your Amazon EKS cluster so that it can appear\nin your cluster as a node. The pod execution role also provides IAM permissions\nto the Fargate infrastructure to allow read access to Amazon ECR image\nrepositories. For more information, see [Pod Execution Role](https://docs.aws.amazon.com/eks/latest/userguide/pod-execution-role.html)\nin the *Amazon EKS User Guide*.\n\nFargate profiles are immutable. However, you can create a new updated profile to\nreplace an existing profile and then delete the original after the updated\nprofile has finished creating.\n\nIf any Fargate profiles in a cluster are in the `DELETING` status, you must wait\nfor that Fargate profile to finish deleting before you can create any other\nprofiles in that cluster.\n\nFor more information, see [Fargate profile](https://docs.aws.amazon.com/eks/latest/userguide/fargate-profile.html)\nin the *Amazon EKS User Guide*.","ref":"AWS.EKS.html#create_fargate_profile/4","title":"AWS.EKS.create_fargate_profile/4","type":"function"},{"doc":"Creates a managed node group for an Amazon EKS cluster.\n\nYou can only create a node group for your cluster that is equal to the current\nKubernetes version for the cluster. All node groups are created with the latest\nAMI release version for the respective minor Kubernetes version of the cluster,\nunless you deploy a custom AMI using a launch template. For more information\nabout using launch templates, see [Launch template support](https://docs.aws.amazon.com/eks/latest/userguide/launch-templates.html).\n\nAn Amazon EKS managed node group is an Amazon EC2 Auto Scaling group and\nassociated Amazon EC2 instances that are managed by Amazon Web Services for an\nAmazon EKS cluster. For more information, see [Managed node groups](https://docs.aws.amazon.com/eks/latest/userguide/managed-node-groups.html)\nin the *Amazon EKS User Guide*.\n\nWindows AMI types are only supported for commercial Amazon Web Services Regions\nthat support Windows on Amazon EKS.","ref":"AWS.EKS.html#create_nodegroup/4","title":"AWS.EKS.create_nodegroup/4","type":"function"},{"doc":"Creates an EKS Pod Identity association between a service account in an Amazon\nEKS cluster and an IAM role with *EKS Pod Identity*.\n\nUse EKS Pod Identity to give temporary IAM credentials to pods and the\ncredentials are rotated automatically.\n\nAmazon EKS Pod Identity associations provide the ability to manage credentials\nfor your applications, similar to the way that Amazon EC2 instance profiles\nprovide credentials to Amazon EC2 instances.\n\nIf a pod uses a service account that has an association, Amazon EKS sets\nenvironment variables in the containers of the pod. The environment variables\nconfigure the Amazon Web Services SDKs, including the Command Line Interface, to\nuse the EKS Pod Identity credentials.\n\nPod Identity is a simpler method than *IAM roles for service accounts*, as this\nmethod doesn't use OIDC identity providers. Additionally, you can configure a\nrole for Pod Identity once, and reuse it across clusters.","ref":"AWS.EKS.html#create_pod_identity_association/4","title":"AWS.EKS.create_pod_identity_association/4","type":"function"},{"doc":"Deletes an access entry.\n\nDeleting an access entry of a type other than `Standard` can cause your cluster\nto function improperly. If you delete an access entry in error, you can recreate\nit.","ref":"AWS.EKS.html#delete_access_entry/5","title":"AWS.EKS.delete_access_entry/5","type":"function"},{"doc":"Deletes an Amazon EKS add-on.\n\nWhen you remove an add-on, it's deleted from the cluster. You can always\nmanually start an add-on on the cluster using the Kubernetes API.","ref":"AWS.EKS.html#delete_addon/5","title":"AWS.EKS.delete_addon/5","type":"function"},{"doc":"Deletes an Amazon EKS cluster control plane.\n\nIf you have active services in your cluster that are associated with a load\nbalancer, you must delete those services before deleting the cluster so that the\nload balancers are deleted properly. Otherwise, you can have orphaned resources\nin your VPC that prevent you from being able to delete the VPC. For more\ninformation, see [Deleting a cluster](https://docs.aws.amazon.com/eks/latest/userguide/delete-cluster.html)\nin the *Amazon EKS User Guide*.\n\nIf you have managed node groups or Fargate profiles attached to the cluster, you\nmust delete them first. For more information, see `DeleteNodgroup` and\n`DeleteFargateProfile`.","ref":"AWS.EKS.html#delete_cluster/4","title":"AWS.EKS.delete_cluster/4","type":"function"},{"doc":"Deletes an expired or inactive subscription.\n\nDeleting inactive subscriptions removes them from the Amazon Web Services\nManagement Console view and from list/describe API responses. Subscriptions can\nonly be cancelled within 7 days of creation and are cancelled by creating a\nticket in the Amazon Web Services Support Center.","ref":"AWS.EKS.html#delete_eks_anywhere_subscription/4","title":"AWS.EKS.delete_eks_anywhere_subscription/4","type":"function"},{"doc":"Deletes an Fargate profile.\n\nWhen you delete a Fargate profile, any `Pod` running on Fargate that was created\nwith the profile is deleted. If the `Pod` matches another Fargate profile, then\nit is scheduled on Fargate with that profile. If it no longer matches any\nFargate profiles, then it's not scheduled on Fargate and may remain in a pending\nstate.\n\nOnly one Fargate profile in a cluster can be in the `DELETING` status at a time.\nYou must wait for a Fargate profile to finish deleting before you can delete any\nother profiles in that cluster.","ref":"AWS.EKS.html#delete_fargate_profile/5","title":"AWS.EKS.delete_fargate_profile/5","type":"function"},{"doc":"Deletes a managed node group.","ref":"AWS.EKS.html#delete_nodegroup/5","title":"AWS.EKS.delete_nodegroup/5","type":"function"},{"doc":"Deletes a EKS Pod Identity association.\n\nThe temporary Amazon Web Services credentials from the previous IAM role session\nmight still be valid until the session expiry. If you need to immediately revoke\nthe temporary session credentials, then go to the role in the IAM console.","ref":"AWS.EKS.html#delete_pod_identity_association/5","title":"AWS.EKS.delete_pod_identity_association/5","type":"function"},{"doc":"Deregisters a connected cluster to remove it from the Amazon EKS control plane.\n\nA connected cluster is a Kubernetes cluster that you've connected to your\ncontrol plane using the [Amazon EKS Connector](https://docs.aws.amazon.com/eks/latest/userguide/eks-connector.html).","ref":"AWS.EKS.html#deregister_cluster/4","title":"AWS.EKS.deregister_cluster/4","type":"function"},{"doc":"Describes an access entry.","ref":"AWS.EKS.html#describe_access_entry/4","title":"AWS.EKS.describe_access_entry/4","type":"function"},{"doc":"Describes an Amazon EKS add-on.","ref":"AWS.EKS.html#describe_addon/4","title":"AWS.EKS.describe_addon/4","type":"function"},{"doc":"Returns configuration options.","ref":"AWS.EKS.html#describe_addon_configuration/4","title":"AWS.EKS.describe_addon_configuration/4","type":"function"},{"doc":"Describes the versions for an add-on.\n\nInformation such as the Kubernetes versions that you can use the add-on with,\nthe `owner`, `publisher`, and the `type` of the add-on are returned.","ref":"AWS.EKS.html#describe_addon_versions/9","title":"AWS.EKS.describe_addon_versions/9","type":"function"},{"doc":"Describes an Amazon EKS cluster.\n\nThe API server endpoint and certificate authority data returned by this\noperation are required for `kubelet` and `kubectl` to communicate with your\nKubernetes API server. For more information, see [Creating or updating a `kubeconfig` file for an Amazon EKS\ncluster](https://docs.aws.amazon.com/eks/latest/userguide/create-kubeconfig.html).\n\nThe API server endpoint and certificate authority data aren't available until\nthe cluster reaches the `ACTIVE` state.","ref":"AWS.EKS.html#describe_cluster/3","title":"AWS.EKS.describe_cluster/3","type":"function"},{"doc":"Returns descriptive information about a subscription.","ref":"AWS.EKS.html#describe_eks_anywhere_subscription/3","title":"AWS.EKS.describe_eks_anywhere_subscription/3","type":"function"},{"doc":"Describes an Fargate profile.","ref":"AWS.EKS.html#describe_fargate_profile/4","title":"AWS.EKS.describe_fargate_profile/4","type":"function"},{"doc":"Describes an identity provider configuration.","ref":"AWS.EKS.html#describe_identity_provider_config/4","title":"AWS.EKS.describe_identity_provider_config/4","type":"function"},{"doc":"Returns details about an insight that you specify using its ID.","ref":"AWS.EKS.html#describe_insight/4","title":"AWS.EKS.describe_insight/4","type":"function"},{"doc":"Describes a managed node group.","ref":"AWS.EKS.html#describe_nodegroup/4","title":"AWS.EKS.describe_nodegroup/4","type":"function"},{"doc":"Returns descriptive information about an EKS Pod Identity association.\n\nThis action requires the ID of the association. You can get the ID from the\nresponse to the `CreatePodIdentityAssocation` for newly created associations.\nOr, you can list the IDs for associations with `ListPodIdentityAssociations` and\nfilter the list by namespace or service account.","ref":"AWS.EKS.html#describe_pod_identity_association/4","title":"AWS.EKS.describe_pod_identity_association/4","type":"function"},{"doc":"Describes an update to an Amazon EKS resource.\n\nWhen the status of the update is `Succeeded`, the update is complete. If an\nupdate fails, the status is `Failed`, and an error detail explains the reason\nfor the failure.","ref":"AWS.EKS.html#describe_update/6","title":"AWS.EKS.describe_update/6","type":"function"},{"doc":"Disassociates an access policy from an access entry.","ref":"AWS.EKS.html#disassociate_access_policy/6","title":"AWS.EKS.disassociate_access_policy/6","type":"function"},{"doc":"Disassociates an identity provider configuration from a cluster.\n\nIf you disassociate an identity provider from your cluster, users included in\nthe provider can no longer access the cluster. However, you can still access the\ncluster with IAM principals.","ref":"AWS.EKS.html#disassociate_identity_provider_config/4","title":"AWS.EKS.disassociate_identity_provider_config/4","type":"function"},{"doc":"Lists the access entries for your cluster.","ref":"AWS.EKS.html#list_access_entries/6","title":"AWS.EKS.list_access_entries/6","type":"function"},{"doc":"Lists the available access policies.","ref":"AWS.EKS.html#list_access_policies/4","title":"AWS.EKS.list_access_policies/4","type":"function"},{"doc":"Lists the installed add-ons.","ref":"AWS.EKS.html#list_addons/5","title":"AWS.EKS.list_addons/5","type":"function"},{"doc":"Lists the access policies associated with an access entry.","ref":"AWS.EKS.html#list_associated_access_policies/6","title":"AWS.EKS.list_associated_access_policies/6","type":"function"},{"doc":"Lists the Amazon EKS clusters in your Amazon Web Services account in the\nspecified Amazon Web Services Region.","ref":"AWS.EKS.html#list_clusters/5","title":"AWS.EKS.list_clusters/5","type":"function"},{"doc":"Displays the full description of the subscription.","ref":"AWS.EKS.html#list_eks_anywhere_subscriptions/5","title":"AWS.EKS.list_eks_anywhere_subscriptions/5","type":"function"},{"doc":"Lists the Fargate profiles associated with the specified cluster in your Amazon\nWeb Services account in the specified Amazon Web Services Region.","ref":"AWS.EKS.html#list_fargate_profiles/5","title":"AWS.EKS.list_fargate_profiles/5","type":"function"},{"doc":"Lists the identity provider configurations for your cluster.","ref":"AWS.EKS.html#list_identity_provider_configs/5","title":"AWS.EKS.list_identity_provider_configs/5","type":"function"},{"doc":"Returns a list of all insights checked for against the specified cluster.\n\nYou can filter which insights are returned by category, associated Kubernetes\nversion, and status.","ref":"AWS.EKS.html#list_insights/4","title":"AWS.EKS.list_insights/4","type":"function"},{"doc":"Lists the managed node groups associated with the specified cluster in your\nAmazon Web Services account in the specified Amazon Web Services Region.\n\nSelf-managed node groups aren't listed.","ref":"AWS.EKS.html#list_nodegroups/5","title":"AWS.EKS.list_nodegroups/5","type":"function"},{"doc":"List the EKS Pod Identity associations in a cluster.\n\nYou can filter the list by the namespace that the association is in or the\nservice account that the association uses.","ref":"AWS.EKS.html#list_pod_identity_associations/7","title":"AWS.EKS.list_pod_identity_associations/7","type":"function"},{"doc":"List the tags for an Amazon EKS resource.","ref":"AWS.EKS.html#list_tags_for_resource/3","title":"AWS.EKS.list_tags_for_resource/3","type":"function"},{"doc":"Lists the updates associated with an Amazon EKS resource in your Amazon Web\nServices account, in the specified Amazon Web Services Region.","ref":"AWS.EKS.html#list_updates/7","title":"AWS.EKS.list_updates/7","type":"function"},{"doc":"","ref":"AWS.EKS.html#metadata/0","title":"AWS.EKS.metadata/0","type":"function"},{"doc":"Connects a Kubernetes cluster to the Amazon EKS control plane.\n\nAny Kubernetes cluster can be connected to the Amazon EKS control plane to view\ncurrent information about the cluster and its nodes.\n\nCluster connection requires two steps. First, send a ` `RegisterClusterRequest`\n` to add it to the Amazon EKS control plane.\n\nSecond, a\n[Manifest](https://amazon-eks.s3.us-west-2.amazonaws.com/eks-connector/manifests/eks-connector/latest/eks-connector.yaml)\ncontaining the `activationID` and `activationCode` must be applied to the\nKubernetes cluster through it's native provider to provide visibility.\n\nAfter the manifest is updated and applied, the connected cluster is visible to\nthe Amazon EKS control plane. If the manifest isn't applied within three days,\nthe connected cluster will no longer be visible and must be deregistered using\n`DeregisterCluster`.","ref":"AWS.EKS.html#register_cluster/3","title":"AWS.EKS.register_cluster/3","type":"function"},{"doc":"Associates the specified tags to an Amazon EKS resource with the specified\n`resourceArn`.\n\nIf existing tags on a resource are not specified in the request parameters, they\naren't changed. When a resource is deleted, the tags associated with that\nresource are also deleted. Tags that you create for Amazon EKS resources don't\npropagate to any other resources associated with the cluster. For example, if\nyou tag a cluster with this operation, that tag doesn't automatically propagate\nto the subnets and nodes associated with the cluster.","ref":"AWS.EKS.html#tag_resource/4","title":"AWS.EKS.tag_resource/4","type":"function"},{"doc":"Deletes specified tags from an Amazon EKS resource.","ref":"AWS.EKS.html#untag_resource/4","title":"AWS.EKS.untag_resource/4","type":"function"},{"doc":"Updates an access entry.","ref":"AWS.EKS.html#update_access_entry/5","title":"AWS.EKS.update_access_entry/5","type":"function"},{"doc":"Updates an Amazon EKS add-on.","ref":"AWS.EKS.html#update_addon/5","title":"AWS.EKS.update_addon/5","type":"function"},{"doc":"Updates an Amazon EKS cluster configuration.\n\nYour cluster continues to function during the update. The response output\nincludes an update ID that you can use to track the status of your cluster\nupdate with `DescribeUpdate`\"/>.\n\nYou can use this API operation to enable or disable exporting the Kubernetes\ncontrol plane logs for your cluster to CloudWatch Logs. By default, cluster\ncontrol plane logs aren't exported to CloudWatch Logs. For more information, see\n[Amazon EKS Cluster control plane logs](https://docs.aws.amazon.com/eks/latest/userguide/control-plane-logs.html)\nin the * *Amazon EKS User Guide* *.\n\nCloudWatch Logs ingestion, archive storage, and data scanning rates apply to\nexported control plane logs. For more information, see [CloudWatch Pricing](http://aws.amazon.com/cloudwatch/pricing/).\n\nYou can also use this API operation to enable or disable public and private\naccess to your cluster's Kubernetes API server endpoint. By default, public\naccess is enabled, and private access is disabled. For more information, see\n[Amazon EKS cluster endpoint access control](https://docs.aws.amazon.com/eks/latest/userguide/cluster-endpoint.html)\nin the * *Amazon EKS User Guide* *.\n\nYou can also use this API operation to choose different subnets and security\ngroups for the cluster. You must specify at least two subnets that are in\ndifferent Availability Zones. You can't change which VPC the subnets are from,\nthe subnets must be in the same VPC as the subnets that the cluster was created\nwith. For more information about the VPC requirements, see\n[https://docs.aws.amazon.com/eks/latest/userguide/network_reqs.html](https://docs.aws.amazon.com/eks/latest/userguide/network_reqs.html)\nin the * *Amazon EKS User Guide* *.\n\nCluster updates are asynchronous, and they should finish within a few minutes.\nDuring an update, the cluster status moves to `UPDATING` (this status transition\nis eventually consistent). When the update is complete (either `Failed` or\n`Successful`), the cluster status moves to `Active`.","ref":"AWS.EKS.html#update_cluster_config/4","title":"AWS.EKS.update_cluster_config/4","type":"function"},{"doc":"Updates an Amazon EKS cluster to the specified Kubernetes version.\n\nYour cluster continues to function during the update. The response output\nincludes an update ID that you can use to track the status of your cluster\nupdate with the `DescribeUpdate` API operation.\n\nCluster updates are asynchronous, and they should finish within a few minutes.\nDuring an update, the cluster status moves to `UPDATING` (this status transition\nis eventually consistent). When the update is complete (either `Failed` or\n`Successful`), the cluster status moves to `Active`.\n\nIf your cluster has managed node groups attached to it, all of your node groups’\nKubernetes versions must match the cluster’s Kubernetes version in order to\nupdate the cluster to a new Kubernetes version.","ref":"AWS.EKS.html#update_cluster_version/4","title":"AWS.EKS.update_cluster_version/4","type":"function"},{"doc":"Update an EKS Anywhere Subscription.\n\nOnly auto renewal and tags can be updated after subscription creation.","ref":"AWS.EKS.html#update_eks_anywhere_subscription/4","title":"AWS.EKS.update_eks_anywhere_subscription/4","type":"function"},{"doc":"Updates an Amazon EKS managed node group configuration.\n\nYour node group continues to function during the update. The response output\nincludes an update ID that you can use to track the status of your node group\nupdate with the `DescribeUpdate` API operation. Currently you can update the\nKubernetes labels for a node group or the scaling configuration.","ref":"AWS.EKS.html#update_nodegroup_config/5","title":"AWS.EKS.update_nodegroup_config/5","type":"function"},{"doc":"Updates the Kubernetes version or AMI version of an Amazon EKS managed node\ngroup.\n\nYou can update a node group using a launch template only if the node group was\noriginally deployed with a launch template. If you need to update a custom AMI\nin a node group that was deployed with a launch template, then update your\ncustom AMI, specify the new ID in a new version of the launch template, and then\nupdate the node group to the new version of the launch template.\n\nIf you update without a launch template, then you can update to the latest\navailable AMI version of a node group's current Kubernetes version by not\nspecifying a Kubernetes version in the request. You can update to the latest AMI\nversion of your cluster's current Kubernetes version by specifying your\ncluster's Kubernetes version in the request. For information about Linux\nversions, see [Amazon EKS optimized Amazon Linux AMI versions](https://docs.aws.amazon.com/eks/latest/userguide/eks-linux-ami-versions.html)\nin the *Amazon EKS User Guide*. For information about Windows versions, see\n[Amazon EKS optimized Windows AMI versions](https://docs.aws.amazon.com/eks/latest/userguide/eks-ami-versions-windows.html)\nin the *Amazon EKS User Guide*.\n\nYou cannot roll back a node group to an earlier Kubernetes version or AMI\nversion.\n\nWhen a node in a managed node group is terminated due to a scaling action or\nupdate, every `Pod` on that node is drained first. Amazon EKS attempts to drain\nthe nodes gracefully and will fail if it is unable to do so. You can `force` the\nupdate if Amazon EKS is unable to drain the nodes as a result of a `Pod`\ndisruption budget issue.","ref":"AWS.EKS.html#update_nodegroup_version/5","title":"AWS.EKS.update_nodegroup_version/5","type":"function"},{"doc":"Updates a EKS Pod Identity association.\n\nOnly the IAM role can be changed; an association can't be moved between\nclusters, namespaces, or service accounts. If you need to edit the namespace or\nservice account, you need to delete the association and then create a new\nassociation with your desired settings.","ref":"AWS.EKS.html#update_pod_identity_association/5","title":"AWS.EKS.update_pod_identity_association/5","type":"function"},{"doc":"The Amazon EKS Auth API and the `AssumeRoleForPodIdentity` action are only used\nby the EKS Pod Identity Agent.","ref":"AWS.EKSAuth.html","title":"AWS.EKSAuth","type":"module"},{"doc":"The Amazon EKS Auth API and the `AssumeRoleForPodIdentity` action are only used\nby the EKS Pod Identity Agent.\n\nWe recommend that applications use the Amazon Web Services SDKs to connect to\nAmazon Web Services services; if credentials from an EKS Pod Identity\nassociation are available in the pod, the latest versions of the SDKs use them\nautomatically.","ref":"AWS.EKSAuth.html#assume_role_for_pod_identity/4","title":"AWS.EKSAuth.assume_role_for_pod_identity/4","type":"function"},{"doc":"","ref":"AWS.EKSAuth.html#metadata/0","title":"AWS.EKSAuth.metadata/0","type":"function"},{"doc":"Amazon EMR is a web service that makes it easier to process large amounts of\ndata efficiently.\n\nAmazon EMR uses Hadoop processing combined with several Amazon Web Services\nservices to do tasks such as web indexing, data mining, log file analysis,\nmachine learning, scientific simulation, and data warehouse management.","ref":"AWS.EMR.html","title":"AWS.EMR","type":"module"},{"doc":"Adds an instance fleet to a running cluster.\n\nThe instance fleet configuration is available only in Amazon EMR releases 4.8.0\nand later, excluding 5.0.x.","ref":"AWS.EMR.html#add_instance_fleet/3","title":"AWS.EMR.add_instance_fleet/3","type":"function"},{"doc":"Adds one or more instance groups to a running cluster.","ref":"AWS.EMR.html#add_instance_groups/3","title":"AWS.EMR.add_instance_groups/3","type":"function"},{"doc":"AddJobFlowSteps adds new steps to a running cluster.\n\nA maximum of 256 steps are allowed in each job flow.\n\nIf your cluster is long-running (such as a Hive data warehouse) or complex, you\nmay require more than 256 steps to process your data. You can bypass the\n256-step limitation in various ways, including using SSH to connect to the\nmaster node and submitting queries directly to the software running on the\nmaster node, such as Hive and Hadoop.\n\nA step specifies the location of a JAR file stored either on the master node of\nthe cluster or in Amazon S3. Each step is performed by the main function of the\nmain class of the JAR file. The main class can be specified either in the\nmanifest of the JAR or by using the MainFunction parameter of the step.\n\nAmazon EMR executes each step in the order listed. For a step to be considered\ncomplete, the main function must exit with a zero exit code and all Hadoop jobs\nstarted while the step was running must have completed and run successfully.\n\nYou can only add steps to a cluster that is in one of the following states:\nSTARTING, BOOTSTRAPPING, RUNNING, or WAITING.\n\nThe string values passed into `HadoopJarStep` object cannot exceed a total of\n10240 characters.","ref":"AWS.EMR.html#add_job_flow_steps/3","title":"AWS.EMR.add_job_flow_steps/3","type":"function"},{"doc":"Adds tags to an Amazon EMR resource, such as a cluster or an Amazon EMR Studio.\n\nTags make it easier to associate resources in various ways, such as grouping\nclusters to track your Amazon EMR resource allocation costs. For more\ninformation, see [Tag Clusters](https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-plan-tags.html).","ref":"AWS.EMR.html#add_tags/3","title":"AWS.EMR.add_tags/3","type":"function"},{"doc":"Cancels a pending step or steps in a running cluster.\n\nAvailable only in Amazon EMR versions 4.8.0 and later, excluding version 5.0.0.\nA maximum of 256 steps are allowed in each CancelSteps request. CancelSteps is\nidempotent but asynchronous; it does not guarantee that a step will be canceled,\neven if the request is successfully submitted. When you use Amazon EMR releases\n5.28.0 and later, you can cancel steps that are in a `PENDING` or `RUNNING`\nstate. In earlier versions of Amazon EMR, you can only cancel steps that are in\na `PENDING` state.","ref":"AWS.EMR.html#cancel_steps/3","title":"AWS.EMR.cancel_steps/3","type":"function"},{"doc":"Creates a security configuration, which is stored in the service and can be\nspecified when a cluster is created.","ref":"AWS.EMR.html#create_security_configuration/3","title":"AWS.EMR.create_security_configuration/3","type":"function"},{"doc":"Creates a new Amazon EMR Studio.","ref":"AWS.EMR.html#create_studio/3","title":"AWS.EMR.create_studio/3","type":"function"},{"doc":"Maps a user or group to the Amazon EMR Studio specified by `StudioId`, and\napplies a session policy to refine Studio permissions for that user or group.\n\nUse `CreateStudioSessionMapping` to assign users to a Studio when you use IAM\nIdentity Center authentication. For instructions on how to assign users to a\nStudio when you use IAM authentication, see [Assign a user or group to your EMR Studio](https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-studio-manage-users.html#emr-studio-assign-users-groups).","ref":"AWS.EMR.html#create_studio_session_mapping/3","title":"AWS.EMR.create_studio_session_mapping/3","type":"function"},{"doc":"Deletes a security configuration.","ref":"AWS.EMR.html#delete_security_configuration/3","title":"AWS.EMR.delete_security_configuration/3","type":"function"},{"doc":"Removes an Amazon EMR Studio from the Studio metadata store.","ref":"AWS.EMR.html#delete_studio/3","title":"AWS.EMR.delete_studio/3","type":"function"},{"doc":"Removes a user or group from an Amazon EMR Studio.","ref":"AWS.EMR.html#delete_studio_session_mapping/3","title":"AWS.EMR.delete_studio_session_mapping/3","type":"function"},{"doc":"Provides cluster-level details including status, hardware and software\nconfiguration, VPC settings, and so on.","ref":"AWS.EMR.html#describe_cluster/3","title":"AWS.EMR.describe_cluster/3","type":"function"},{"doc":"This API is no longer supported and will eventually be removed.\n\nWe recommend you use `ListClusters`, `DescribeCluster`, `ListSteps`,\n`ListInstanceGroups` and `ListBootstrapActions` instead.\n\nDescribeJobFlows returns a list of job flows that match all of the supplied\nparameters. The parameters can include a list of job flow IDs, job flow states,\nand restrictions on job flow creation date and time.\n\nRegardless of supplied parameters, only job flows created within the last two\nmonths are returned.\n\nIf no parameters are supplied, then job flows matching either of the following\ncriteria are returned:\n\n  * Job flows created and completed in the last two weeks\n\n  * Job flows created within the last two months that are in one of\nthe following states: `RUNNING`, `WAITING`, `SHUTTING_DOWN`, `STARTING`\n\nAmazon EMR can return a maximum of 512 job flow descriptions.","ref":"AWS.EMR.html#describe_job_flows/3","title":"AWS.EMR.describe_job_flows/3","type":"function"},{"doc":"Provides details of a notebook execution.","ref":"AWS.EMR.html#describe_notebook_execution/3","title":"AWS.EMR.describe_notebook_execution/3","type":"function"},{"doc":"Provides Amazon EMR release label details, such as the releases available the\nRegion where the API request is run, and the available applications for a\nspecific Amazon EMR release label.\n\nCan also list Amazon EMR releases that support a specified version of Spark.","ref":"AWS.EMR.html#describe_release_label/3","title":"AWS.EMR.describe_release_label/3","type":"function"},{"doc":"Provides the details of a security configuration by returning the configuration\nJSON.","ref":"AWS.EMR.html#describe_security_configuration/3","title":"AWS.EMR.describe_security_configuration/3","type":"function"},{"doc":"Provides more detail about the cluster step.","ref":"AWS.EMR.html#describe_step/3","title":"AWS.EMR.describe_step/3","type":"function"},{"doc":"Returns details for the specified Amazon EMR Studio including ID, Name, VPC,\nStudio access URL, and so on.","ref":"AWS.EMR.html#describe_studio/3","title":"AWS.EMR.describe_studio/3","type":"function"},{"doc":"Returns the auto-termination policy for an Amazon EMR cluster.","ref":"AWS.EMR.html#get_auto_termination_policy/3","title":"AWS.EMR.get_auto_termination_policy/3","type":"function"},{"doc":"Returns the Amazon EMR block public access configuration for your Amazon Web\nServices account in the current Region.\n\nFor more information see [Configure Block Public Access for Amazon EMR](https://docs.aws.amazon.com/emr/latest/ManagementGuide/configure-block-public-access.html)\nin the *Amazon EMR Management Guide*.","ref":"AWS.EMR.html#get_block_public_access_configuration/3","title":"AWS.EMR.get_block_public_access_configuration/3","type":"function"},{"doc":"Provides temporary, HTTP basic credentials that are associated with a given\nruntime IAM role and used by a cluster with fine-grained access control\nactivated.\n\nYou can use these credentials to connect to cluster endpoints that support\nusername and password authentication.","ref":"AWS.EMR.html#get_cluster_session_credentials/3","title":"AWS.EMR.get_cluster_session_credentials/3","type":"function"},{"doc":"Fetches the attached managed scaling policy for an Amazon EMR cluster.","ref":"AWS.EMR.html#get_managed_scaling_policy/3","title":"AWS.EMR.get_managed_scaling_policy/3","type":"function"},{"doc":"Fetches mapping details for the specified Amazon EMR Studio and identity (user\nor group).","ref":"AWS.EMR.html#get_studio_session_mapping/3","title":"AWS.EMR.get_studio_session_mapping/3","type":"function"},{"doc":"Provides information about the bootstrap actions associated with a cluster.","ref":"AWS.EMR.html#list_bootstrap_actions/3","title":"AWS.EMR.list_bootstrap_actions/3","type":"function"},{"doc":"Provides the status of all clusters visible to this Amazon Web Services account.\n\nAllows you to filter the list of clusters based on certain criteria; for\nexample, filtering by cluster creation date and time or by status. This call\nreturns a maximum of 50 clusters in unsorted order per call, but returns a\nmarker to track the paging of the cluster list across multiple ListClusters\ncalls.","ref":"AWS.EMR.html#list_clusters/3","title":"AWS.EMR.list_clusters/3","type":"function"},{"doc":"Lists all available details about the instance fleets in a cluster.\n\nThe instance fleet configuration is available only in Amazon EMR releases 4.8.0\nand later, excluding 5.0.x versions.","ref":"AWS.EMR.html#list_instance_fleets/3","title":"AWS.EMR.list_instance_fleets/3","type":"function"},{"doc":"Provides all available details about the instance groups in a cluster.","ref":"AWS.EMR.html#list_instance_groups/3","title":"AWS.EMR.list_instance_groups/3","type":"function"},{"doc":"Provides information for all active Amazon EC2 instances and Amazon EC2\ninstances terminated in the last 30 days, up to a maximum of 2,000.\n\nAmazon EC2 instances in any of the following states are considered active:\nAWAITING_FULFILLMENT, PROVISIONING, BOOTSTRAPPING, RUNNING.","ref":"AWS.EMR.html#list_instances/3","title":"AWS.EMR.list_instances/3","type":"function"},{"doc":"Provides summaries of all notebook executions.\n\nYou can filter the list based on multiple criteria such as status, time range,\nand editor id. Returns a maximum of 50 notebook executions and a marker to track\nthe paging of a longer notebook execution list across multiple\n`ListNotebookExecutions` calls.","ref":"AWS.EMR.html#list_notebook_executions/3","title":"AWS.EMR.list_notebook_executions/3","type":"function"},{"doc":"Retrieves release labels of Amazon EMR services in the Region where the API is\ncalled.","ref":"AWS.EMR.html#list_release_labels/3","title":"AWS.EMR.list_release_labels/3","type":"function"},{"doc":"Lists all the security configurations visible to this account, providing their\ncreation dates and times, and their names.\n\nThis call returns a maximum of 50 clusters per call, but returns a marker to\ntrack the paging of the cluster list across multiple ListSecurityConfigurations\ncalls.","ref":"AWS.EMR.html#list_security_configurations/3","title":"AWS.EMR.list_security_configurations/3","type":"function"},{"doc":"Provides a list of steps for the cluster in reverse order unless you specify\n`stepIds` with the request or filter by `StepStates`.\n\nYou can specify a maximum of 10 `stepIDs`. The CLI automatically paginates\nresults to return a list greater than 50 steps. To return more than 50 steps\nusing the CLI, specify a `Marker`, which is a pagination token that indicates\nthe next set of steps to retrieve.","ref":"AWS.EMR.html#list_steps/3","title":"AWS.EMR.list_steps/3","type":"function"},{"doc":"Returns a list of all user or group session mappings for the Amazon EMR Studio\nspecified by `StudioId`.","ref":"AWS.EMR.html#list_studio_session_mappings/3","title":"AWS.EMR.list_studio_session_mappings/3","type":"function"},{"doc":"Returns a list of all Amazon EMR Studios associated with the Amazon Web Services\naccount.\n\nThe list includes details such as ID, Studio Access URL, and creation time for\neach Studio.","ref":"AWS.EMR.html#list_studios/3","title":"AWS.EMR.list_studios/3","type":"function"},{"doc":"A list of the instance types that Amazon EMR supports.\n\nYou can filter the list by Amazon Web Services Region and Amazon EMR release.","ref":"AWS.EMR.html#list_supported_instance_types/3","title":"AWS.EMR.list_supported_instance_types/3","type":"function"},{"doc":"","ref":"AWS.EMR.html#metadata/0","title":"AWS.EMR.metadata/0","type":"function"},{"doc":"Modifies the number of steps that can be executed concurrently for the cluster\nspecified using ClusterID.","ref":"AWS.EMR.html#modify_cluster/3","title":"AWS.EMR.modify_cluster/3","type":"function"},{"doc":"Modifies the target On-Demand and target Spot capacities for the instance fleet\nwith the specified InstanceFleetID within the cluster specified using ClusterID.\n\nThe call either succeeds or fails atomically.\n\nThe instance fleet configuration is available only in Amazon EMR releases 4.8.0\nand later, excluding 5.0.x versions.","ref":"AWS.EMR.html#modify_instance_fleet/3","title":"AWS.EMR.modify_instance_fleet/3","type":"function"},{"doc":"ModifyInstanceGroups modifies the number of nodes and configuration settings of\nan instance group.\n\nThe input parameters include the new target instance count for the group and the\ninstance group ID. The call will either succeed or fail atomically.","ref":"AWS.EMR.html#modify_instance_groups/3","title":"AWS.EMR.modify_instance_groups/3","type":"function"},{"doc":"Creates or updates an automatic scaling policy for a core instance group or task\ninstance group in an Amazon EMR cluster.\n\nThe automatic scaling policy defines how an instance group dynamically adds and\nterminates Amazon EC2 instances in response to the value of a CloudWatch metric.","ref":"AWS.EMR.html#put_auto_scaling_policy/3","title":"AWS.EMR.put_auto_scaling_policy/3","type":"function"},{"doc":"Auto-termination is supported in Amazon EMR releases 5.30.0 and 6.1.0 and later.\n\nFor more information, see [Using an auto-termination policy](https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-auto-termination-policy.html).\n\nCreates or updates an auto-termination policy for an Amazon EMR cluster. An\nauto-termination policy defines the amount of idle time in seconds after which a\ncluster automatically terminates. For alternative cluster termination options,\nsee [Control cluster termination](https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-plan-termination.html).","ref":"AWS.EMR.html#put_auto_termination_policy/3","title":"AWS.EMR.put_auto_termination_policy/3","type":"function"},{"doc":"Creates or updates an Amazon EMR block public access configuration for your\nAmazon Web Services account in the current Region.\n\nFor more information see [Configure Block Public Access for Amazon EMR](https://docs.aws.amazon.com/emr/latest/ManagementGuide/configure-block-public-access.html)\nin the *Amazon EMR Management Guide*.","ref":"AWS.EMR.html#put_block_public_access_configuration/3","title":"AWS.EMR.put_block_public_access_configuration/3","type":"function"},{"doc":"Creates or updates a managed scaling policy for an Amazon EMR cluster.\n\nThe managed scaling policy defines the limits for resources, such as Amazon EC2\ninstances that can be added or terminated from a cluster. The policy only\napplies to the core and task nodes. The master node cannot be scaled after\ninitial configuration.","ref":"AWS.EMR.html#put_managed_scaling_policy/3","title":"AWS.EMR.put_managed_scaling_policy/3","type":"function"},{"doc":"Removes an automatic scaling policy from a specified instance group within an\nAmazon EMR cluster.","ref":"AWS.EMR.html#remove_auto_scaling_policy/3","title":"AWS.EMR.remove_auto_scaling_policy/3","type":"function"},{"doc":"Removes an auto-termination policy from an Amazon EMR cluster.","ref":"AWS.EMR.html#remove_auto_termination_policy/3","title":"AWS.EMR.remove_auto_termination_policy/3","type":"function"},{"doc":"Removes a managed scaling policy from a specified Amazon EMR cluster.","ref":"AWS.EMR.html#remove_managed_scaling_policy/3","title":"AWS.EMR.remove_managed_scaling_policy/3","type":"function"},{"doc":"Removes tags from an Amazon EMR resource, such as a cluster or Amazon EMR\nStudio.\n\nTags make it easier to associate resources in various ways, such as grouping\nclusters to track your Amazon EMR resource allocation costs. For more\ninformation, see [Tag Clusters](https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-plan-tags.html).\n\nThe following example removes the stack tag with value Prod from a cluster:","ref":"AWS.EMR.html#remove_tags/3","title":"AWS.EMR.remove_tags/3","type":"function"},{"doc":"RunJobFlow creates and starts running a new cluster (job flow).\n\nThe cluster runs the steps specified. After the steps complete, the cluster\nstops and the HDFS partition is lost. To prevent loss of data, configure the\nlast step of the job flow to store results in Amazon S3. If the\n`JobFlowInstancesConfig` `KeepJobFlowAliveWhenNoSteps` parameter is set to\n`TRUE`, the cluster transitions to the WAITING state rather than shutting down\nafter the steps have completed.\n\nFor additional protection, you can set the `JobFlowInstancesConfig`\n`TerminationProtected` parameter to `TRUE` to lock the cluster and prevent it\nfrom being terminated by API call, user intervention, or in the event of a job\nflow error.\n\nA maximum of 256 steps are allowed in each job flow.\n\nIf your cluster is long-running (such as a Hive data warehouse) or complex, you\nmay require more than 256 steps to process your data. You can bypass the\n256-step limitation in various ways, including using the SSH shell to connect to\nthe master node and submitting queries directly to the software running on the\nmaster node, such as Hive and Hadoop.\n\nFor long-running clusters, we recommend that you periodically store your\nresults.\n\nThe instance fleets configuration is available only in Amazon EMR releases 4.8.0\nand later, excluding 5.0.x versions. The RunJobFlow request can contain\nInstanceFleets parameters or InstanceGroups parameters, but not both.","ref":"AWS.EMR.html#run_job_flow/3","title":"AWS.EMR.run_job_flow/3","type":"function"},{"doc":"You can use the `SetKeepJobFlowAliveWhenNoSteps` to configure a cluster (job\nflow) to terminate after the step execution, i.e., all your steps are executed.\n\nIf you want a transient cluster that shuts down after the last of the current\nexecuting steps are completed, you can configure\n`SetKeepJobFlowAliveWhenNoSteps` to false. If you want a long running cluster,\nconfigure `SetKeepJobFlowAliveWhenNoSteps` to true.\n\nFor more information, see [Managing Cluster Termination](https://docs.aws.amazon.com/emr/latest/ManagementGuide/UsingEMR_TerminationProtection.html)\nin the *Amazon EMR Management Guide*.","ref":"AWS.EMR.html#set_keep_job_flow_alive_when_no_steps/3","title":"AWS.EMR.set_keep_job_flow_alive_when_no_steps/3","type":"function"},{"doc":"SetTerminationProtection locks a cluster (job flow) so the Amazon EC2 instances\nin the cluster cannot be terminated by user intervention, an API call, or in the\nevent of a job-flow error.\n\nThe cluster still terminates upon successful completion of the job flow. Calling\n`SetTerminationProtection` on a cluster is similar to calling the Amazon EC2\n`DisableAPITermination` API on all Amazon EC2 instances in a cluster.\n\n`SetTerminationProtection` is used to prevent accidental termination of a\ncluster and to ensure that in the event of an error, the instances persist so\nthat you can recover any data stored in their ephemeral instance storage.\n\nTo terminate a cluster that has been locked by setting\n`SetTerminationProtection` to `true`, you must first unlock the job flow by a\nsubsequent call to `SetTerminationProtection` in which you set the value to\n`false`.\n\nFor more information, see[Managing Cluster Termination](https://docs.aws.amazon.com/emr/latest/ManagementGuide/UsingEMR_TerminationProtection.html)\nin the *Amazon EMR Management Guide*.","ref":"AWS.EMR.html#set_termination_protection/3","title":"AWS.EMR.set_termination_protection/3","type":"function"},{"doc":"The SetVisibleToAllUsers parameter is no longer supported.\n\nYour cluster may be visible to all users in your account. To restrict cluster\naccess using an IAM policy, see [Identity and Access Management for Amazon EMR](https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-plan-access-IAM.html).\n\nSets the `Cluster$VisibleToAllUsers` value for an Amazon EMR cluster. When\n`true`, IAM principals in the Amazon Web Services account can perform Amazon EMR\ncluster actions that their IAM policies allow. When `false`, only the IAM\nprincipal that created the cluster and the Amazon Web Services account root user\ncan perform Amazon EMR actions on the cluster, regardless of IAM permissions\npolicies attached to other IAM principals.\n\nThis action works on running clusters. When you create a cluster, use the\n`RunJobFlowInput$VisibleToAllUsers` parameter.\n\nFor more information, see [Understanding the Amazon EMR Cluster VisibleToAllUsers\nSetting](https://docs.aws.amazon.com/emr/latest/ManagementGuide/security_IAM_emr-with-IAM.html#security_set_visible_to_all_users)\nin the *Amazon EMR Management Guide*.","ref":"AWS.EMR.html#set_visible_to_all_users/3","title":"AWS.EMR.set_visible_to_all_users/3","type":"function"},{"doc":"Starts a notebook execution.","ref":"AWS.EMR.html#start_notebook_execution/3","title":"AWS.EMR.start_notebook_execution/3","type":"function"},{"doc":"Stops a notebook execution.","ref":"AWS.EMR.html#stop_notebook_execution/3","title":"AWS.EMR.stop_notebook_execution/3","type":"function"},{"doc":"TerminateJobFlows shuts a list of clusters (job flows) down.\n\nWhen a job flow is shut down, any step not yet completed is canceled and the\nAmazon EC2 instances on which the cluster is running are stopped. Any log files\nnot already saved are uploaded to Amazon S3 if a LogUri was specified when the\ncluster was created.\n\nThe maximum number of clusters allowed is 10. The call to `TerminateJobFlows` is\nasynchronous. Depending on the configuration of the cluster, it may take up to\n1-5 minutes for the cluster to completely terminate and release allocated\nresources, such as Amazon EC2 instances.","ref":"AWS.EMR.html#terminate_job_flows/3","title":"AWS.EMR.terminate_job_flows/3","type":"function"},{"doc":"Updates an Amazon EMR Studio configuration, including attributes such as name,\ndescription, and subnets.","ref":"AWS.EMR.html#update_studio/3","title":"AWS.EMR.update_studio/3","type":"function"},{"doc":"Updates the session policy attached to the user or group for the specified\nAmazon EMR Studio.","ref":"AWS.EMR.html#update_studio_session_mapping/3","title":"AWS.EMR.update_studio_session_mapping/3","type":"function"},{"doc":"Amazon EMR Serverless is a new deployment option for Amazon EMR.\n\nAmazon EMR Serverless provides a serverless runtime environment that simplifies\nrunning analytics applications using the latest open source frameworks such as\nApache Spark and Apache Hive. With Amazon EMR Serverless, you don’t have to\nconfigure, optimize, secure, or operate clusters to run applications with these\nframeworks.\n\nThe API reference to Amazon EMR Serverless is `emr-serverless`. The\n`emr-serverless` prefix is used in the following scenarios:\n\n  * It is the prefix in the CLI commands for Amazon EMR Serverless.\nFor example, `aws emr-serverless start-job-run`.\n\n  * It is the prefix before IAM policy actions for Amazon EMR\nServerless. For example, `\"Action\": [\"emr-serverless:StartJobRun\"]`. For more information, see [Policy actions for Amazon EMR\nServerless](https://docs.aws.amazon.com/emr/latest/EMR-Serverless-UserGuide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-actions).\n\n  * It is the prefix used in Amazon EMR Serverless service endpoints.\nFor example, `emr-serverless.us-east-2.amazonaws.com`.","ref":"AWS.EMRServerless.html","title":"AWS.EMRServerless","type":"module"},{"doc":"Cancels a job run.","ref":"AWS.EMRServerless.html#cancel_job_run/5","title":"AWS.EMRServerless.cancel_job_run/5","type":"function"},{"doc":"Creates an application.","ref":"AWS.EMRServerless.html#create_application/3","title":"AWS.EMRServerless.create_application/3","type":"function"},{"doc":"Deletes an application.\n\nAn application has to be in a stopped or created state in order to be deleted.","ref":"AWS.EMRServerless.html#delete_application/4","title":"AWS.EMRServerless.delete_application/4","type":"function"},{"doc":"Displays detailed information about a specified application.","ref":"AWS.EMRServerless.html#get_application/3","title":"AWS.EMRServerless.get_application/3","type":"function"},{"doc":"Creates and returns a URL that you can use to access the application UIs for a\njob run.\n\nFor jobs in a running state, the application UI is a live user interface such as\nthe Spark or Tez web UI. For completed jobs, the application UI is a persistent\napplication user interface such as the Spark History Server or persistent Tez\nUI.\n\nThe URL is valid for one hour after you generate it. To access the application\nUI after that hour elapses, you must invoke the API again to generate a new URL.","ref":"AWS.EMRServerless.html#get_dashboard_for_job_run/4","title":"AWS.EMRServerless.get_dashboard_for_job_run/4","type":"function"},{"doc":"Displays detailed information about a job run.","ref":"AWS.EMRServerless.html#get_job_run/4","title":"AWS.EMRServerless.get_job_run/4","type":"function"},{"doc":"Lists applications based on a set of parameters.","ref":"AWS.EMRServerless.html#list_applications/5","title":"AWS.EMRServerless.list_applications/5","type":"function"},{"doc":"Lists job runs based on a set of parameters.","ref":"AWS.EMRServerless.html#list_job_runs/8","title":"AWS.EMRServerless.list_job_runs/8","type":"function"},{"doc":"Lists the tags assigned to the resources.","ref":"AWS.EMRServerless.html#list_tags_for_resource/3","title":"AWS.EMRServerless.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.EMRServerless.html#metadata/0","title":"AWS.EMRServerless.metadata/0","type":"function"},{"doc":"Starts a specified application and initializes initial capacity if configured.","ref":"AWS.EMRServerless.html#start_application/4","title":"AWS.EMRServerless.start_application/4","type":"function"},{"doc":"Starts a job run.","ref":"AWS.EMRServerless.html#start_job_run/4","title":"AWS.EMRServerless.start_job_run/4","type":"function"},{"doc":"Stops a specified application and releases initial capacity if configured.\n\nAll scheduled and running jobs must be completed or cancelled before stopping an\napplication.","ref":"AWS.EMRServerless.html#stop_application/4","title":"AWS.EMRServerless.stop_application/4","type":"function"},{"doc":"Assigns tags to resources.\n\nA tag is a label that you assign to an Amazon Web Services resource. Each tag\nconsists of a key and an optional value, both of which you define. Tags enable\nyou to categorize your Amazon Web Services resources by attributes such as\npurpose, owner, or environment. When you have many resources of the same type,\nyou can quickly identify a specific resource based on the tags you've assigned\nto it.","ref":"AWS.EMRServerless.html#tag_resource/4","title":"AWS.EMRServerless.tag_resource/4","type":"function"},{"doc":"Removes tags from resources.","ref":"AWS.EMRServerless.html#untag_resource/4","title":"AWS.EMRServerless.untag_resource/4","type":"function"},{"doc":"Updates a specified application.\n\nAn application has to be in a stopped or created state in order to be updated.","ref":"AWS.EMRServerless.html#update_application/4","title":"AWS.EMRServerless.update_application/4","type":"function"},{"doc":"Amazon EMR on EKS provides a deployment option for Amazon EMR that allows you to\nrun open-source big data frameworks on Amazon Elastic Kubernetes Service (Amazon\nEKS).\n\nWith this deployment option, you can focus on running analytics workloads while\nAmazon EMR on EKS builds, configures, and manages containers for open-source\napplications. For more information about Amazon EMR on EKS concepts and tasks,\nsee [What is shared id=\"EMR-EKS\"/>](https://docs.aws.amazon.com/emr/latest/EMR-on-EKS-DevelopmentGuide/emr-eks.html).\n\n*Amazon EMR containers* is the API name for Amazon EMR on EKS. The\n`emr-containers` prefix is used in the following scenarios:\n\n  * It is the prefix in the CLI commands for Amazon EMR on EKS. For\nexample, `aws emr-containers start-job-run`.\n\n  * It is the prefix before IAM policy actions for Amazon EMR on EKS.\nFor example, `\"Action\": [ \"emr-containers:StartJobRun\"]`. For more information, see [Policy actions for Amazon EMR on\nEKS](https://docs.aws.amazon.com/emr/latest/EMR-on-EKS-DevelopmentGuide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-actions).\n\n  * It is the prefix used in Amazon EMR on EKS service endpoints. For\nexample, `emr-containers.us-east-2.amazonaws.com`. For more information, see\n[Amazon EMR on EKSService Endpoints](https://docs.aws.amazon.com/emr/latest/EMR-on-EKS-DevelopmentGuide/service-quotas.html#service-endpoints).","ref":"AWS.EMRcontainers.html","title":"AWS.EMRcontainers","type":"module"},{"doc":"Cancels a job run.\n\nA job run is a unit of work, such as a Spark jar, PySpark script, or SparkSQL\nquery, that you submit to Amazon EMR on EKS.","ref":"AWS.EMRcontainers.html#cancel_job_run/5","title":"AWS.EMRcontainers.cancel_job_run/5","type":"function"},{"doc":"Creates a job template.\n\nJob template stores values of StartJobRun API request in a template and can be\nused to start a job run. Job template allows two use cases: avoid repeating\nrecurring StartJobRun API request values, enforcing certain values in\nStartJobRun API request.","ref":"AWS.EMRcontainers.html#create_job_template/3","title":"AWS.EMRcontainers.create_job_template/3","type":"function"},{"doc":"Creates a managed endpoint.\n\nA managed endpoint is a gateway that connects Amazon EMR Studio to Amazon EMR on\nEKS so that Amazon EMR Studio can communicate with your virtual cluster.","ref":"AWS.EMRcontainers.html#create_managed_endpoint/4","title":"AWS.EMRcontainers.create_managed_endpoint/4","type":"function"},{"doc":"Creates a virtual cluster.\n\nVirtual cluster is a managed entity on Amazon EMR on EKS. You can create,\ndescribe, list and delete virtual clusters. They do not consume any additional\nresource in your system. A single virtual cluster maps to a single Kubernetes\nnamespace. Given this relationship, you can model virtual clusters the same way\nyou model Kubernetes namespaces to meet your requirements.","ref":"AWS.EMRcontainers.html#create_virtual_cluster/3","title":"AWS.EMRcontainers.create_virtual_cluster/3","type":"function"},{"doc":"Deletes a job template.\n\nJob template stores values of StartJobRun API request in a template and can be\nused to start a job run. Job template allows two use cases: avoid repeating\nrecurring StartJobRun API request values, enforcing certain values in\nStartJobRun API request.","ref":"AWS.EMRcontainers.html#delete_job_template/4","title":"AWS.EMRcontainers.delete_job_template/4","type":"function"},{"doc":"Deletes a managed endpoint.\n\nA managed endpoint is a gateway that connects Amazon EMR Studio to Amazon EMR on\nEKS so that Amazon EMR Studio can communicate with your virtual cluster.","ref":"AWS.EMRcontainers.html#delete_managed_endpoint/5","title":"AWS.EMRcontainers.delete_managed_endpoint/5","type":"function"},{"doc":"Deletes a virtual cluster.\n\nVirtual cluster is a managed entity on Amazon EMR on EKS. You can create,\ndescribe, list and delete virtual clusters. They do not consume any additional\nresource in your system. A single virtual cluster maps to a single Kubernetes\nnamespace. Given this relationship, you can model virtual clusters the same way\nyou model Kubernetes namespaces to meet your requirements.","ref":"AWS.EMRcontainers.html#delete_virtual_cluster/4","title":"AWS.EMRcontainers.delete_virtual_cluster/4","type":"function"},{"doc":"Displays detailed information about a job run.\n\nA job run is a unit of work, such as a Spark jar, PySpark script, or SparkSQL\nquery, that you submit to Amazon EMR on EKS.","ref":"AWS.EMRcontainers.html#describe_job_run/4","title":"AWS.EMRcontainers.describe_job_run/4","type":"function"},{"doc":"Displays detailed information about a specified job template.\n\nJob template stores values of StartJobRun API request in a template and can be\nused to start a job run. Job template allows two use cases: avoid repeating\nrecurring StartJobRun API request values, enforcing certain values in\nStartJobRun API request.","ref":"AWS.EMRcontainers.html#describe_job_template/3","title":"AWS.EMRcontainers.describe_job_template/3","type":"function"},{"doc":"Displays detailed information about a managed endpoint.\n\nA managed endpoint is a gateway that connects Amazon EMR Studio to Amazon EMR on\nEKS so that Amazon EMR Studio can communicate with your virtual cluster.","ref":"AWS.EMRcontainers.html#describe_managed_endpoint/4","title":"AWS.EMRcontainers.describe_managed_endpoint/4","type":"function"},{"doc":"Displays detailed information about a specified virtual cluster.\n\nVirtual cluster is a managed entity on Amazon EMR on EKS. You can create,\ndescribe, list and delete virtual clusters. They do not consume any additional\nresource in your system. A single virtual cluster maps to a single Kubernetes\nnamespace. Given this relationship, you can model virtual clusters the same way\nyou model Kubernetes namespaces to meet your requirements.","ref":"AWS.EMRcontainers.html#describe_virtual_cluster/3","title":"AWS.EMRcontainers.describe_virtual_cluster/3","type":"function"},{"doc":"Generate a session token to connect to a managed endpoint.","ref":"AWS.EMRcontainers.html#get_managed_endpoint_session_credentials/5","title":"AWS.EMRcontainers.get_managed_endpoint_session_credentials/5","type":"function"},{"doc":"Lists job runs based on a set of parameters.\n\nA job run is a unit of work, such as a Spark jar, PySpark script, or SparkSQL\nquery, that you submit to Amazon EMR on EKS.","ref":"AWS.EMRcontainers.html#list_job_runs/9","title":"AWS.EMRcontainers.list_job_runs/9","type":"function"},{"doc":"Lists job templates based on a set of parameters.\n\nJob template stores values of StartJobRun API request in a template and can be\nused to start a job run. Job template allows two use cases: avoid repeating\nrecurring StartJobRun API request values, enforcing certain values in\nStartJobRun API request.","ref":"AWS.EMRcontainers.html#list_job_templates/6","title":"AWS.EMRcontainers.list_job_templates/6","type":"function"},{"doc":"Lists managed endpoints based on a set of parameters.\n\nA managed endpoint is a gateway that connects Amazon EMR Studio to Amazon EMR on\nEKS so that Amazon EMR Studio can communicate with your virtual cluster.","ref":"AWS.EMRcontainers.html#list_managed_endpoints/9","title":"AWS.EMRcontainers.list_managed_endpoints/9","type":"function"},{"doc":"Lists the tags assigned to the resources.","ref":"AWS.EMRcontainers.html#list_tags_for_resource/3","title":"AWS.EMRcontainers.list_tags_for_resource/3","type":"function"},{"doc":"Lists information about the specified virtual cluster.\n\nVirtual cluster is a managed entity on Amazon EMR on EKS. You can create,\ndescribe, list and delete virtual clusters. They do not consume any additional\nresource in your system. A single virtual cluster maps to a single Kubernetes\nnamespace. Given this relationship, you can model virtual clusters the same way\nyou model Kubernetes namespaces to meet your requirements.","ref":"AWS.EMRcontainers.html#list_virtual_clusters/9","title":"AWS.EMRcontainers.list_virtual_clusters/9","type":"function"},{"doc":"","ref":"AWS.EMRcontainers.html#metadata/0","title":"AWS.EMRcontainers.metadata/0","type":"function"},{"doc":"Starts a job run.\n\nA job run is a unit of work, such as a Spark jar, PySpark script, or SparkSQL\nquery, that you submit to Amazon EMR on EKS.","ref":"AWS.EMRcontainers.html#start_job_run/4","title":"AWS.EMRcontainers.start_job_run/4","type":"function"},{"doc":"Assigns tags to resources.\n\nA tag is a label that you assign to an Amazon Web Services resource. Each tag\nconsists of a key and an optional value, both of which you define. Tags enable\nyou to categorize your Amazon Web Services resources by attributes such as\npurpose, owner, or environment. When you have many resources of the same type,\nyou can quickly identify a specific resource based on the tags you've assigned\nto it. For example, you can define a set of tags for your Amazon EMR on EKS\nclusters to help you track each cluster's owner and stack level. We recommend\nthat you devise a consistent set of tag keys for each resource type. You can\nthen search and filter the resources based on the tags that you add.","ref":"AWS.EMRcontainers.html#tag_resource/4","title":"AWS.EMRcontainers.tag_resource/4","type":"function"},{"doc":"Removes tags from resources.","ref":"AWS.EMRcontainers.html#untag_resource/4","title":"AWS.EMRcontainers.untag_resource/4","type":"function"},{"doc":"Amazon ElastiCache\n\nAmazon ElastiCache is a web service that makes it easier to set up, operate, and\nscale a distributed cache in the cloud.\n\nWith ElastiCache, customers get all of the benefits of a high-performance,\nin-memory cache with less of the administrative burden involved in launching and\nmanaging a distributed cache. The service makes setup, scaling, and cluster\nfailure handling much simpler than in a self-managed cache deployment.\n\nIn addition, through integration with Amazon CloudWatch, customers get enhanced\nvisibility into the key performance statistics associated with their cache and\ncan receive alarms if a part of their cache runs hot.","ref":"AWS.ElastiCache.html","title":"AWS.ElastiCache","type":"module"},{"doc":"A tag is a key-value pair where the key and value are case-sensitive.\n\nYou can use tags to categorize and track all your ElastiCache resources, with\nthe exception of global replication group. When you add or remove tags on\nreplication groups, those actions will be replicated to all nodes in the\nreplication group. For more information, see [Resource-level permissions](http://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/IAM.ResourceLevelPermissions.html).\n\nFor example, you can use cost-allocation tags to your ElastiCache resources,\nAmazon generates a cost allocation report as a comma-separated value (CSV) file\nwith your usage and costs aggregated by your tags. You can apply tags that\nrepresent business categories (such as cost centers, application names, or\nowners) to organize your costs across multiple services.\n\nFor more information, see [Using Cost Allocation Tags in Amazon ElastiCache](https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/Tagging.html)\nin the *ElastiCache User Guide*.","ref":"AWS.ElastiCache.html#add_tags_to_resource/3","title":"AWS.ElastiCache.add_tags_to_resource/3","type":"function"},{"doc":"Allows network ingress to a cache security group.\n\nApplications using ElastiCache must be running on Amazon EC2, and Amazon EC2\nsecurity groups are used as the authorization mechanism.\n\nYou cannot authorize ingress from an Amazon EC2 security group in one region to\nan ElastiCache cluster in another region.","ref":"AWS.ElastiCache.html#authorize_cache_security_group_ingress/3","title":"AWS.ElastiCache.authorize_cache_security_group_ingress/3","type":"function"},{"doc":"Apply the service update.\n\nFor more information on service updates and applying them, see [Applying Service Updates](https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/applying-updates.html).","ref":"AWS.ElastiCache.html#batch_apply_update_action/3","title":"AWS.ElastiCache.batch_apply_update_action/3","type":"function"},{"doc":"Stop the service update.\n\nFor more information on service updates and stopping them, see [Stopping Service Updates](https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/stopping-self-service-updates.html).","ref":"AWS.ElastiCache.html#batch_stop_update_action/3","title":"AWS.ElastiCache.batch_stop_update_action/3","type":"function"},{"doc":"Complete the migration of data.","ref":"AWS.ElastiCache.html#complete_migration/3","title":"AWS.ElastiCache.complete_migration/3","type":"function"},{"doc":"Creates a copy of an existing serverless cache’s snapshot.\n\nAvailable for Redis only.","ref":"AWS.ElastiCache.html#copy_serverless_cache_snapshot/3","title":"AWS.ElastiCache.copy_serverless_cache_snapshot/3","type":"function"},{"doc":"Makes a copy of an existing snapshot.\n\nThis operation is valid for Redis only.\n\nUsers or groups that have permissions to use the `CopySnapshot` operation can\ncreate their own Amazon S3 buckets and copy snapshots to it. To control access\nto your snapshots, use an IAM policy to control who has the ability to use the\n`CopySnapshot` operation. For more information about using IAM to control the\nuse of ElastiCache operations, see [Exporting Snapshots](https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/backups-exporting.html)\nand [Authentication & Access Control](https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/IAM.html).\n\nYou could receive the following error messages.","ref":"AWS.ElastiCache.html#copy_snapshot/3","title":"AWS.ElastiCache.copy_snapshot/3","type":"function"},{"doc":"* **Error Message:** The S3 bucket %s is outside of the region.\n\n**Solution:** Create an Amazon S3 bucket in the same region as your snapshot.\nFor more information, see [Step 1: Create an Amazon S3 Bucket](https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/backups-exporting.html#backups-exporting-create-s3-bucket)\nin the ElastiCache User Guide.\n\n  * **Error Message:** The S3 bucket %s does not exist.\n\n**Solution:** Create an Amazon S3 bucket in the same region as your snapshot.\nFor more information, see [Step 1: Create an Amazon S3 Bucket](https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/backups-exporting.html#backups-exporting-create-s3-bucket)\nin the ElastiCache User Guide.\n\n  * **Error Message:** The S3 bucket %s is not owned by the\nauthenticated user.\n\n**Solution:** Create an Amazon S3 bucket in the same region as your snapshot.\nFor more information, see [Step 1: Create an Amazon S3 Bucket](https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/backups-exporting.html#backups-exporting-create-s3-bucket)\nin the ElastiCache User Guide.\n\n  * **Error Message:** The authenticated user does not have sufficient\npermissions to perform the desired activity.\n\n**Solution:** Contact your system administrator to get the needed permissions.\n\n  * **Error Message:** The S3 bucket %s already contains an object\nwith key %s.\n\n**Solution:** Give the `TargetSnapshotName` a new and unique value. If exporting\na snapshot, you could alternatively create a new Amazon S3 bucket and use this\nsame value for `TargetSnapshotName`.\n\n  * **Error Message: ** ElastiCache has not been granted READ\npermissions %s on the S3 Bucket.\n\n**Solution:** Add List and Read permissions on the bucket. For more information,\nsee [Step 2: Grant ElastiCache Access to Your Amazon S3 Bucket](https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/backups-exporting.html#backups-exporting-grant-access)\nin the ElastiCache User Guide.\n\n  * **Error Message: ** ElastiCache has not been granted WRITE\npermissions %s on the S3 Bucket.\n\n**Solution:** Add Upload/Delete permissions on the bucket. For more information,\nsee [Step 2: Grant ElastiCache Access to Your Amazon S3 Bucket](https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/backups-exporting.html#backups-exporting-grant-access)\nin the ElastiCache User Guide.\n\n  * **Error Message: ** ElastiCache has not been granted READ_ACP\npermissions %s on the S3 Bucket.\n\n**Solution:** Add View Permissions on the bucket. For more information, see\n[Step 2: Grant ElastiCache Access to Your Amazon S3 Bucket](https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/backups-exporting.html#backups-exporting-grant-access)\nin the ElastiCache User Guide.","ref":"AWS.ElastiCache.html#copy_snapshot/3-error-messages","title":"Error Messages - AWS.ElastiCache.copy_snapshot/3","type":"function"},{"doc":"Creates a cluster.\n\nAll nodes in the cluster run the same protocol-compliant cache engine software,\neither Memcached or Redis.\n\nThis operation is not supported for Redis (cluster mode enabled) clusters.","ref":"AWS.ElastiCache.html#create_cache_cluster/3","title":"AWS.ElastiCache.create_cache_cluster/3","type":"function"},{"doc":"Creates a new Amazon ElastiCache cache parameter group.\n\nAn ElastiCache cache parameter group is a collection of parameters and their\nvalues that are applied to all of the nodes in any cluster or replication group\nusing the CacheParameterGroup.\n\nA newly created CacheParameterGroup is an exact duplicate of the default\nparameter group for the CacheParameterGroupFamily. To customize the newly\ncreated CacheParameterGroup you can change the values of specific parameters.\nFor more information, see:\n\n  *\n[ModifyCacheParameterGroup](https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_ModifyCacheParameterGroup.html) in the ElastiCache API Reference.\n\n  * [Parameters and Parameter\nGroups](https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/ParameterGroups.html)\nin the ElastiCache User Guide.","ref":"AWS.ElastiCache.html#create_cache_parameter_group/3","title":"AWS.ElastiCache.create_cache_parameter_group/3","type":"function"},{"doc":"Creates a new cache security group.\n\nUse a cache security group to control access to one or more clusters.\n\nCache security groups are only used when you are creating a cluster outside of\nan Amazon Virtual Private Cloud (Amazon VPC). If you are creating a cluster\ninside of a VPC, use a cache subnet group instead. For more information, see\n[CreateCacheSubnetGroup](https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_CreateCacheSubnetGroup.html).","ref":"AWS.ElastiCache.html#create_cache_security_group/3","title":"AWS.ElastiCache.create_cache_security_group/3","type":"function"},{"doc":"Creates a new cache subnet group.\n\nUse this parameter only when you are creating a cluster in an Amazon Virtual\nPrivate Cloud (Amazon VPC).","ref":"AWS.ElastiCache.html#create_cache_subnet_group/3","title":"AWS.ElastiCache.create_cache_subnet_group/3","type":"function"},{"doc":"Global Datastore for Redis offers fully managed, fast, reliable and secure\ncross-region replication.\n\nUsing Global Datastore for Redis, you can create cross-region read replica\nclusters for ElastiCache for Redis to enable low-latency reads and disaster\nrecovery across regions. For more information, see [Replication Across Regions Using Global\nDatastore](https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/Redis-Global-Datastore.html).\n\n  * The **GlobalReplicationGroupIdSuffix** is the name of the Global\ndatastore.\n\n  * The **PrimaryReplicationGroupId** represents the name of the\nprimary cluster that accepts writes and will replicate updates to the secondary\ncluster.","ref":"AWS.ElastiCache.html#create_global_replication_group/3","title":"AWS.ElastiCache.create_global_replication_group/3","type":"function"},{"doc":"Creates a Redis (cluster mode disabled) or a Redis (cluster mode enabled)\nreplication group.\n\nThis API can be used to create a standalone regional replication group or a\nsecondary replication group associated with a Global datastore.\n\nA Redis (cluster mode disabled) replication group is a collection of clusters,\nwhere one of the clusters is a read/write primary and the others are read-only\nreplicas. Writes to the primary are asynchronously propagated to the replicas.\n\nA Redis cluster-mode enabled cluster is comprised of from 1 to 90 shards\n(API/CLI: node groups). Each shard has a primary node and up to 5 read-only\nreplica nodes. The configuration can range from 90 shards and 0 replicas to 15\nshards and 5 replicas, which is the maximum number or replicas allowed.\n\nThe node or shard limit can be increased to a maximum of 500 per cluster if the\nRedis engine version is 5.0.6 or higher. For example, you can choose to\nconfigure a 500 node cluster that ranges between 83 shards (one primary and 5\nreplicas per shard) and 500 shards (single primary and no replicas). Make sure\nthere are enough available IP addresses to accommodate the increase. Common\npitfalls include the subnets in the subnet group have too small a CIDR range or\nthe subnets are shared and heavily used by other clusters. For more information,\nsee [Creating a Subnet Group](https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/SubnetGroups.Creating.html).\nFor versions below 5.0.6, the limit is 250 per cluster.\n\nTo request a limit increase, see [Amazon Service Limits](https://docs.aws.amazon.com/general/latest/gr/aws_service_limits.html)\nand choose the limit type **Nodes per cluster per instance type**.\n\nWhen a Redis (cluster mode disabled) replication group has been successfully\ncreated, you can add one or more read replicas to it, up to a total of 5 read\nreplicas. If you need to increase or decrease the number of node groups\n(console: shards), you can avail yourself of ElastiCache for Redis' scaling. For\nmore information, see [Scaling ElastiCache for Redis Clusters](https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/Scaling.html)\nin the *ElastiCache User Guide*.\n\nThis operation is valid for Redis only.","ref":"AWS.ElastiCache.html#create_replication_group/3","title":"AWS.ElastiCache.create_replication_group/3","type":"function"},{"doc":"Creates a serverless cache.","ref":"AWS.ElastiCache.html#create_serverless_cache/3","title":"AWS.ElastiCache.create_serverless_cache/3","type":"function"},{"doc":"This API creates a copy of an entire ServerlessCache at a specific moment in\ntime.\n\nAvailable for Redis only.","ref":"AWS.ElastiCache.html#create_serverless_cache_snapshot/3","title":"AWS.ElastiCache.create_serverless_cache_snapshot/3","type":"function"},{"doc":"Creates a copy of an entire cluster or replication group at a specific moment in\ntime.\n\nThis operation is valid for Redis only.","ref":"AWS.ElastiCache.html#create_snapshot/3","title":"AWS.ElastiCache.create_snapshot/3","type":"function"},{"doc":"For Redis engine version 6.0 onwards: Creates a Redis user.\n\nFor more information, see [Using Role Based Access Control (RBAC)](http://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/Clusters.RBAC.html).","ref":"AWS.ElastiCache.html#create_user/3","title":"AWS.ElastiCache.create_user/3","type":"function"},{"doc":"For Redis engine version 6.0 onwards: Creates a Redis user group.\n\nFor more information, see [Using Role Based Access Control (RBAC)](http://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/Clusters.RBAC.html)","ref":"AWS.ElastiCache.html#create_user_group/3","title":"AWS.ElastiCache.create_user_group/3","type":"function"},{"doc":"Decreases the number of node groups in a Global datastore","ref":"AWS.ElastiCache.html#decrease_node_groups_in_global_replication_group/3","title":"AWS.ElastiCache.decrease_node_groups_in_global_replication_group/3","type":"function"},{"doc":"Dynamically decreases the number of replicas in a Redis (cluster mode disabled)\nreplication group or the number of replica nodes in one or more node groups\n(shards) of a Redis (cluster mode enabled) replication group.\n\nThis operation is performed with no cluster down time.","ref":"AWS.ElastiCache.html#decrease_replica_count/3","title":"AWS.ElastiCache.decrease_replica_count/3","type":"function"},{"doc":"Deletes a previously provisioned cluster.\n\n`DeleteCacheCluster` deletes all associated cache nodes, node endpoints and the\ncluster itself. When you receive a successful response from this operation,\nAmazon ElastiCache immediately begins deleting the cluster; you cannot cancel or\nrevert this operation.\n\nThis operation is not valid for:\n\n  * Redis (cluster mode enabled) clusters\n\n  * Redis (cluster mode disabled) clusters\n\n  * A cluster that is the last read replica of a replication group\n\n  * A cluster that is the primary node of a replication group\n\n  * A node group (shard) that has Multi-AZ mode enabled\n\n  * A cluster from a Redis (cluster mode enabled) replication group\n\n  * A cluster that is not in the `available` state","ref":"AWS.ElastiCache.html#delete_cache_cluster/3","title":"AWS.ElastiCache.delete_cache_cluster/3","type":"function"},{"doc":"Deletes the specified cache parameter group.\n\nYou cannot delete a cache parameter group if it is associated with any cache\nclusters. You cannot delete the default cache parameter groups in your account.","ref":"AWS.ElastiCache.html#delete_cache_parameter_group/3","title":"AWS.ElastiCache.delete_cache_parameter_group/3","type":"function"},{"doc":"Deletes a cache security group.\n\nYou cannot delete a cache security group if it is associated with any clusters.","ref":"AWS.ElastiCache.html#delete_cache_security_group/3","title":"AWS.ElastiCache.delete_cache_security_group/3","type":"function"},{"doc":"Deletes a cache subnet group.\n\nYou cannot delete a default cache subnet group or one that is associated with\nany clusters.","ref":"AWS.ElastiCache.html#delete_cache_subnet_group/3","title":"AWS.ElastiCache.delete_cache_subnet_group/3","type":"function"},{"doc":"Deleting a Global datastore is a two-step process:\n\n  * First, you must `DisassociateGlobalReplicationGroup` to remove the\nsecondary clusters in the Global datastore.\n\n  * Once the Global datastore contains only the primary cluster, you\ncan use the `DeleteGlobalReplicationGroup` API to delete the Global datastore\nwhile retainining the primary cluster using\n`RetainPrimaryReplicationGroup=true`.\n\nSince the Global Datastore has only a primary cluster, you can delete the Global\nDatastore while retaining the primary by setting\n`RetainPrimaryReplicationGroup=true`. The primary cluster is never deleted when\ndeleting a Global Datastore. It can only be deleted when it no longer is\nassociated with any Global Datastore.\n\nWhen you receive a successful response from this operation, Amazon ElastiCache\nimmediately begins deleting the selected resources; you cannot cancel or revert\nthis operation.","ref":"AWS.ElastiCache.html#delete_global_replication_group/3","title":"AWS.ElastiCache.delete_global_replication_group/3","type":"function"},{"doc":"Deletes an existing replication group.\n\nBy default, this operation deletes the entire replication group, including the\nprimary/primaries and all of the read replicas. If the replication group has\nonly one primary, you can optionally delete only the read replicas, while\nretaining the primary by setting `RetainPrimaryCluster=true`.\n\nWhen you receive a successful response from this operation, Amazon ElastiCache\nimmediately begins deleting the selected resources; you cannot cancel or revert\nthis operation.\n\nThis operation is valid for Redis only.","ref":"AWS.ElastiCache.html#delete_replication_group/3","title":"AWS.ElastiCache.delete_replication_group/3","type":"function"},{"doc":"Deletes a specified existing serverless cache.","ref":"AWS.ElastiCache.html#delete_serverless_cache/3","title":"AWS.ElastiCache.delete_serverless_cache/3","type":"function"},{"doc":"Deletes an existing serverless cache snapshot.\n\nAvailable for Redis only.","ref":"AWS.ElastiCache.html#delete_serverless_cache_snapshot/3","title":"AWS.ElastiCache.delete_serverless_cache_snapshot/3","type":"function"},{"doc":"Deletes an existing snapshot.\n\nWhen you receive a successful response from this operation, ElastiCache\nimmediately begins deleting the snapshot; you cannot cancel or revert this\noperation.\n\nThis operation is valid for Redis only.","ref":"AWS.ElastiCache.html#delete_snapshot/3","title":"AWS.ElastiCache.delete_snapshot/3","type":"function"},{"doc":"For Redis engine version 6.0 onwards: Deletes a user.\n\nThe user will be removed from all user groups and in turn removed from all\nreplication groups. For more information, see [Using Role Based Access Control (RBAC)](http://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/Clusters.RBAC.html).","ref":"AWS.ElastiCache.html#delete_user/3","title":"AWS.ElastiCache.delete_user/3","type":"function"},{"doc":"For Redis engine version 6.0 onwards: Deletes a user group.\n\nThe user group must first be disassociated from the replication group before it\ncan be deleted. For more information, see [Using Role Based Access Control (RBAC)](http://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/Clusters.RBAC.html).","ref":"AWS.ElastiCache.html#delete_user_group/3","title":"AWS.ElastiCache.delete_user_group/3","type":"function"},{"doc":"Returns information about all provisioned clusters if no cluster identifier is\nspecified, or about a specific cache cluster if a cluster identifier is\nsupplied.\n\nBy default, abbreviated information about the clusters is returned. You can use\nthe optional *ShowCacheNodeInfo* flag to retrieve detailed information about the\ncache nodes associated with the clusters. These details include the DNS address\nand port for the cache node endpoint.\n\nIf the cluster is in the *creating* state, only cluster-level information is\ndisplayed until all of the nodes are successfully provisioned.\n\nIf the cluster is in the *deleting* state, only cluster-level information is\ndisplayed.\n\nIf cache nodes are currently being added to the cluster, node endpoint\ninformation and creation time for the additional nodes are not displayed until\nthey are completely provisioned. When the cluster state is *available*, the\ncluster is ready for use.\n\nIf cache nodes are currently being removed from the cluster, no endpoint\ninformation for the removed nodes is displayed.","ref":"AWS.ElastiCache.html#describe_cache_clusters/3","title":"AWS.ElastiCache.describe_cache_clusters/3","type":"function"},{"doc":"Returns a list of the available cache engines and their versions.","ref":"AWS.ElastiCache.html#describe_cache_engine_versions/3","title":"AWS.ElastiCache.describe_cache_engine_versions/3","type":"function"},{"doc":"Returns a list of cache parameter group descriptions.\n\nIf a cache parameter group name is specified, the list contains only the\ndescriptions for that group.","ref":"AWS.ElastiCache.html#describe_cache_parameter_groups/3","title":"AWS.ElastiCache.describe_cache_parameter_groups/3","type":"function"},{"doc":"Returns the detailed parameter list for a particular cache parameter group.","ref":"AWS.ElastiCache.html#describe_cache_parameters/3","title":"AWS.ElastiCache.describe_cache_parameters/3","type":"function"},{"doc":"Returns a list of cache security group descriptions.\n\nIf a cache security group name is specified, the list contains only the\ndescription of that group. This applicable only when you have ElastiCache in\nClassic setup","ref":"AWS.ElastiCache.html#describe_cache_security_groups/3","title":"AWS.ElastiCache.describe_cache_security_groups/3","type":"function"},{"doc":"Returns a list of cache subnet group descriptions.\n\nIf a subnet group name is specified, the list contains only the description of\nthat group. This is applicable only when you have ElastiCache in VPC setup. All\nElastiCache clusters now launch in VPC by default.","ref":"AWS.ElastiCache.html#describe_cache_subnet_groups/3","title":"AWS.ElastiCache.describe_cache_subnet_groups/3","type":"function"},{"doc":"Returns the default engine and system parameter information for the specified\ncache engine.","ref":"AWS.ElastiCache.html#describe_engine_default_parameters/3","title":"AWS.ElastiCache.describe_engine_default_parameters/3","type":"function"},{"doc":"Returns events related to clusters, cache security groups, and cache parameter\ngroups.\n\nYou can obtain events specific to a particular cluster, cache security group, or\ncache parameter group by providing the name as a parameter.\n\nBy default, only the events occurring within the last hour are returned;\nhowever, you can retrieve up to 14 days' worth of events if necessary.","ref":"AWS.ElastiCache.html#describe_events/3","title":"AWS.ElastiCache.describe_events/3","type":"function"},{"doc":"Returns information about a particular global replication group.\n\nIf no identifier is specified, returns information about all Global datastores.","ref":"AWS.ElastiCache.html#describe_global_replication_groups/3","title":"AWS.ElastiCache.describe_global_replication_groups/3","type":"function"},{"doc":"Returns information about a particular replication group.\n\nIf no identifier is specified, `DescribeReplicationGroups` returns information\nabout all replication groups.\n\nThis operation is valid for Redis only.","ref":"AWS.ElastiCache.html#describe_replication_groups/3","title":"AWS.ElastiCache.describe_replication_groups/3","type":"function"},{"doc":"Returns information about reserved cache nodes for this account, or about a\nspecified reserved cache node.","ref":"AWS.ElastiCache.html#describe_reserved_cache_nodes/3","title":"AWS.ElastiCache.describe_reserved_cache_nodes/3","type":"function"},{"doc":"Lists available reserved cache node offerings.","ref":"AWS.ElastiCache.html#describe_reserved_cache_nodes_offerings/3","title":"AWS.ElastiCache.describe_reserved_cache_nodes_offerings/3","type":"function"},{"doc":"Returns information about serverless cache snapshots.\n\nBy default, this API lists all of the customer’s serverless cache snapshots. It\ncan also describe a single serverless cache snapshot, or the snapshots\nassociated with a particular serverless cache. Available for Redis only.","ref":"AWS.ElastiCache.html#describe_serverless_cache_snapshots/3","title":"AWS.ElastiCache.describe_serverless_cache_snapshots/3","type":"function"},{"doc":"Returns information about a specific serverless cache.\n\nIf no identifier is specified, then the API returns information on all the\nserverless caches belonging to this Amazon Web Services account.","ref":"AWS.ElastiCache.html#describe_serverless_caches/3","title":"AWS.ElastiCache.describe_serverless_caches/3","type":"function"},{"doc":"Returns details of the service updates","ref":"AWS.ElastiCache.html#describe_service_updates/3","title":"AWS.ElastiCache.describe_service_updates/3","type":"function"},{"doc":"Returns information about cluster or replication group snapshots.\n\nBy default, `DescribeSnapshots` lists all of your snapshots; it can optionally\ndescribe a single snapshot, or just the snapshots associated with a particular\ncache cluster.\n\nThis operation is valid for Redis only.","ref":"AWS.ElastiCache.html#describe_snapshots/3","title":"AWS.ElastiCache.describe_snapshots/3","type":"function"},{"doc":"Returns details of the update actions","ref":"AWS.ElastiCache.html#describe_update_actions/3","title":"AWS.ElastiCache.describe_update_actions/3","type":"function"},{"doc":"Returns a list of user groups.","ref":"AWS.ElastiCache.html#describe_user_groups/3","title":"AWS.ElastiCache.describe_user_groups/3","type":"function"},{"doc":"Returns a list of users.","ref":"AWS.ElastiCache.html#describe_users/3","title":"AWS.ElastiCache.describe_users/3","type":"function"},{"doc":"Remove a secondary cluster from the Global datastore using the Global datastore\nname.\n\nThe secondary cluster will no longer receive updates from the primary cluster,\nbut will remain as a standalone cluster in that Amazon region.","ref":"AWS.ElastiCache.html#disassociate_global_replication_group/3","title":"AWS.ElastiCache.disassociate_global_replication_group/3","type":"function"},{"doc":"Provides the functionality to export the serverless cache snapshot data to\nAmazon S3.\n\nAvailable for Redis only.","ref":"AWS.ElastiCache.html#export_serverless_cache_snapshot/3","title":"AWS.ElastiCache.export_serverless_cache_snapshot/3","type":"function"},{"doc":"Used to failover the primary region to a secondary region.\n\nThe secondary region will become primary, and all other clusters will become\nsecondary.","ref":"AWS.ElastiCache.html#failover_global_replication_group/3","title":"AWS.ElastiCache.failover_global_replication_group/3","type":"function"},{"doc":"Increase the number of node groups in the Global datastore","ref":"AWS.ElastiCache.html#increase_node_groups_in_global_replication_group/3","title":"AWS.ElastiCache.increase_node_groups_in_global_replication_group/3","type":"function"},{"doc":"Dynamically increases the number of replicas in a Redis (cluster mode disabled)\nreplication group or the number of replica nodes in one or more node groups\n(shards) of a Redis (cluster mode enabled) replication group.\n\nThis operation is performed with no cluster down time.","ref":"AWS.ElastiCache.html#increase_replica_count/3","title":"AWS.ElastiCache.increase_replica_count/3","type":"function"},{"doc":"Lists all available node types that you can scale your Redis cluster's or\nreplication group's current node type.\n\nWhen you use the `ModifyCacheCluster` or `ModifyReplicationGroup` operations to\nscale your cluster or replication group, the value of the `CacheNodeType`\nparameter must be one of the node types returned by this operation.","ref":"AWS.ElastiCache.html#list_allowed_node_type_modifications/3","title":"AWS.ElastiCache.list_allowed_node_type_modifications/3","type":"function"},{"doc":"Lists all tags currently on a named resource.\n\nA tag is a key-value pair where the key and value are case-sensitive. You can\nuse tags to categorize and track all your ElastiCache resources, with the\nexception of global replication group. When you add or remove tags on\nreplication groups, those actions will be replicated to all nodes in the\nreplication group. For more information, see [Resource-level permissions](http://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/IAM.ResourceLevelPermissions.html).\n\nIf the cluster is not in the *available* state, `ListTagsForResource` returns an\nerror.","ref":"AWS.ElastiCache.html#list_tags_for_resource/3","title":"AWS.ElastiCache.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.ElastiCache.html#metadata/0","title":"AWS.ElastiCache.metadata/0","type":"function"},{"doc":"Modifies the settings for a cluster.\n\nYou can use this operation to change one or more cluster configuration\nparameters by specifying the parameters and the new values.","ref":"AWS.ElastiCache.html#modify_cache_cluster/3","title":"AWS.ElastiCache.modify_cache_cluster/3","type":"function"},{"doc":"Modifies the parameters of a cache parameter group.\n\nYou can modify up to 20 parameters in a single request by submitting a list\nparameter name and value pairs.","ref":"AWS.ElastiCache.html#modify_cache_parameter_group/3","title":"AWS.ElastiCache.modify_cache_parameter_group/3","type":"function"},{"doc":"Modifies an existing cache subnet group.","ref":"AWS.ElastiCache.html#modify_cache_subnet_group/3","title":"AWS.ElastiCache.modify_cache_subnet_group/3","type":"function"},{"doc":"Modifies the settings for a Global datastore.","ref":"AWS.ElastiCache.html#modify_global_replication_group/3","title":"AWS.ElastiCache.modify_global_replication_group/3","type":"function"},{"doc":"Modifies the settings for a replication group.\n\nThis is limited to Redis 7 and newer.\n\n  * [Scaling for Amazon ElastiCache for Redis (cluster mode enabled)](https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/scaling-redis-cluster-mode-enabled.html)\nin the ElastiCache User Guide\n\n  *\n[ModifyReplicationGroupShardConfiguration](https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_ModifyReplicationGroupShardConfiguration.html)\nin the ElastiCache API Reference\n\nThis operation is valid for Redis only.","ref":"AWS.ElastiCache.html#modify_replication_group/3","title":"AWS.ElastiCache.modify_replication_group/3","type":"function"},{"doc":"Modifies a replication group's shards (node groups) by allowing you to add\nshards, remove shards, or rebalance the keyspaces among existing shards.","ref":"AWS.ElastiCache.html#modify_replication_group_shard_configuration/3","title":"AWS.ElastiCache.modify_replication_group_shard_configuration/3","type":"function"},{"doc":"This API modifies the attributes of a serverless cache.","ref":"AWS.ElastiCache.html#modify_serverless_cache/3","title":"AWS.ElastiCache.modify_serverless_cache/3","type":"function"},{"doc":"Changes user password(s) and/or access string.","ref":"AWS.ElastiCache.html#modify_user/3","title":"AWS.ElastiCache.modify_user/3","type":"function"},{"doc":"Changes the list of users that belong to the user group.","ref":"AWS.ElastiCache.html#modify_user_group/3","title":"AWS.ElastiCache.modify_user_group/3","type":"function"},{"doc":"Allows you to purchase a reserved cache node offering.\n\nReserved nodes are not eligible for cancellation and are non-refundable. For\nmore information, see [Managing Costs with Reserved Nodes](https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/reserved-nodes.html)\nfor Redis or [Managing Costs with Reserved Nodes](https://docs.aws.amazon.com/AmazonElastiCache/latest/mem-ug/reserved-nodes.html)\nfor Memcached.","ref":"AWS.ElastiCache.html#purchase_reserved_cache_nodes_offering/3","title":"AWS.ElastiCache.purchase_reserved_cache_nodes_offering/3","type":"function"},{"doc":"Redistribute slots to ensure uniform distribution across existing shards in the\ncluster.","ref":"AWS.ElastiCache.html#rebalance_slots_in_global_replication_group/3","title":"AWS.ElastiCache.rebalance_slots_in_global_replication_group/3","type":"function"},{"doc":"Reboots some, or all, of the cache nodes within a provisioned cluster.\n\nThis operation applies any modified cache parameter groups to the cluster. The\nreboot operation takes place as soon as possible, and results in a momentary\noutage to the cluster. During the reboot, the cluster status is set to\nREBOOTING.\n\nThe reboot causes the contents of the cache (for each cache node being rebooted)\nto be lost.\n\nWhen the reboot is complete, a cluster event is created.\n\nRebooting a cluster is currently supported on Memcached and Redis (cluster mode\ndisabled) clusters. Rebooting is not supported on Redis (cluster mode enabled)\nclusters.\n\nIf you make changes to parameters that require a Redis (cluster mode enabled)\ncluster reboot for the changes to be applied, see [Rebooting a Cluster](http://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/nodes.rebooting.html)\nfor an alternate process.","ref":"AWS.ElastiCache.html#reboot_cache_cluster/3","title":"AWS.ElastiCache.reboot_cache_cluster/3","type":"function"},{"doc":"Removes the tags identified by the `TagKeys` list from the named resource.\n\nA tag is a key-value pair where the key and value are case-sensitive. You can\nuse tags to categorize and track all your ElastiCache resources, with the\nexception of global replication group. When you add or remove tags on\nreplication groups, those actions will be replicated to all nodes in the\nreplication group. For more information, see [Resource-level permissions](http://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/IAM.ResourceLevelPermissions.html).","ref":"AWS.ElastiCache.html#remove_tags_from_resource/3","title":"AWS.ElastiCache.remove_tags_from_resource/3","type":"function"},{"doc":"Modifies the parameters of a cache parameter group to the engine or system\ndefault value.\n\nYou can reset specific parameters by submitting a list of parameter names. To\nreset the entire cache parameter group, specify the `ResetAllParameters` and\n`CacheParameterGroupName` parameters.","ref":"AWS.ElastiCache.html#reset_cache_parameter_group/3","title":"AWS.ElastiCache.reset_cache_parameter_group/3","type":"function"},{"doc":"Revokes ingress from a cache security group.\n\nUse this operation to disallow access from an Amazon EC2 security group that had\nbeen previously authorized.","ref":"AWS.ElastiCache.html#revoke_cache_security_group_ingress/3","title":"AWS.ElastiCache.revoke_cache_security_group_ingress/3","type":"function"},{"doc":"Start the migration of data.","ref":"AWS.ElastiCache.html#start_migration/3","title":"AWS.ElastiCache.start_migration/3","type":"function"},{"doc":"Represents the input of a `TestFailover` operation which test automatic failover\non a specified node group (called shard in the console) in a replication group\n(called cluster in the console).\n\nThis API is designed for testing the behavior of your application in case of\nElastiCache failover. It is not designed to be an operational tool for\ninitiating a failover to overcome a problem you may have with the cluster.\nMoreover, in certain conditions such as large-scale operational events, Amazon\nmay block this API.","ref":"AWS.ElastiCache.html#test_failover/3","title":"AWS.ElastiCache.test_failover/3","type":"function"},{"doc":"* A customer can use this operation to test automatic failover on up\nto 5 shards (called node groups in the ElastiCache API and Amazon CLI) in any\nrolling 24-hour period.\n\n  * If calling this operation on shards in different clusters (called\nreplication groups in the API and CLI), the calls can be made concurrently.\n\n  * If calling this operation multiple times on different shards in\nthe same Redis (cluster mode enabled) replication group, the first node\nreplacement must complete before a subsequent call can be made.\n\n  * To determine whether the node replacement is complete you can\ncheck Events using the Amazon ElastiCache console, the Amazon CLI, or the\nElastiCache API. Look for the following automatic failover related events,\nlisted here in order of occurrance:\n\n    1. Replication group message: `Test Failover API called\nfor node group  `\n\n    2. Cache cluster message: `Failover from primary node\n  to replica node   completed`\n\n    3. Replication group message: `Failover from primary\nnode   to replica node   completed`\n\n    4. Cache cluster message: `Recovering cache nodes\n `\n\n    5. Cache cluster message: `Finished recovery for cache\nnodes  `\n\nFor more information see:\n\n    * [Viewing ElastiCache Events](https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/ECEvents.Viewing.html)\nin the *ElastiCache User Guide*\n\n    *\n[DescribeEvents](https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DescribeEvents.html) in the ElastiCache API Reference\n\nAlso see, [Testing Multi-AZ\n](https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/AutoFailover.html#auto-failover-test)\nin the *ElastiCache User Guide*.","ref":"AWS.ElastiCache.html#test_failover/3-note-the-following","title":"Note the following - AWS.ElastiCache.test_failover/3","type":"function"},{"doc":"Async API to test connection between source and target replication group.","ref":"AWS.ElastiCache.html#test_migration/3","title":"AWS.ElastiCache.test_migration/3","type":"function"},{"doc":"AWS Elastic Beanstalk\n\nAWS Elastic Beanstalk makes it easy for you to create, deploy, and manage\nscalable, fault-tolerant applications running on the Amazon Web Services cloud.\n\nFor more information about this product, go to the [AWS Elastic Beanstalk](http://aws.amazon.com/elasticbeanstalk/) details page. The location\nof the latest AWS Elastic Beanstalk WSDL is\n[https://elasticbeanstalk.s3.amazonaws.com/doc/2010-12-01/AWSElasticBeanstalk.wsdl](https://elasticbeanstalk.s3.amazonaws.com/doc/2010-12-01/AWSElasticBeanstalk.wsdl). To install the Software Development Kits (SDKs), Integrated Development\nEnvironment (IDE) Toolkits, and command line tools that enable you to access the\nAPI, go to [Tools for Amazon Web Services](http://aws.amazon.com/tools/).","ref":"AWS.ElasticBeanstalk.html","title":"AWS.ElasticBeanstalk","type":"module"},{"doc":"For a list of region-specific endpoints that AWS Elastic Beanstalk supports, go\nto [Regions and Endpoints](https://docs.aws.amazon.com/general/latest/gr/rande.html#elasticbeanstalk_region)\nin the *Amazon Web Services Glossary*.","ref":"AWS.ElasticBeanstalk.html#module-endpoints","title":"Endpoints - AWS.ElasticBeanstalk","type":"module"},{"doc":"Cancels in-progress environment configuration update or application version\ndeployment.","ref":"AWS.ElasticBeanstalk.html#abort_environment_update/3","title":"AWS.ElasticBeanstalk.abort_environment_update/3","type":"function"},{"doc":"Applies a scheduled managed action immediately.\n\nA managed action can be applied only if its status is `Scheduled`. Get the\nstatus and action ID of a managed action with\n`DescribeEnvironmentManagedActions`.","ref":"AWS.ElasticBeanstalk.html#apply_environment_managed_action/3","title":"AWS.ElasticBeanstalk.apply_environment_managed_action/3","type":"function"},{"doc":"Add or change the operations role used by an environment.\n\nAfter this call is made, Elastic Beanstalk uses the associated operations role\nfor permissions to downstream services during subsequent calls acting on this\nenvironment. For more information, see [Operations roles](https://docs.aws.amazon.com/elasticbeanstalk/latest/dg/iam-operationsrole.html)\nin the *AWS Elastic Beanstalk Developer Guide*.","ref":"AWS.ElasticBeanstalk.html#associate_environment_operations_role/3","title":"AWS.ElasticBeanstalk.associate_environment_operations_role/3","type":"function"},{"doc":"Checks if the specified CNAME is available.","ref":"AWS.ElasticBeanstalk.html#check_dns_availability/3","title":"AWS.ElasticBeanstalk.check_dns_availability/3","type":"function"},{"doc":"Create or update a group of environments that each run a separate component of a\nsingle application.\n\nTakes a list of version labels that specify application source bundles for each\nof the environments to create or update. The name of each environment and other\nrequired information must be included in the source bundles in an environment\nmanifest named `env.yaml`. See [Compose Environments](https://docs.aws.amazon.com/elasticbeanstalk/latest/dg/environment-mgmt-compose.html)\nfor details.","ref":"AWS.ElasticBeanstalk.html#compose_environments/3","title":"AWS.ElasticBeanstalk.compose_environments/3","type":"function"},{"doc":"Creates an application that has one configuration template named `default` and\nno application versions.","ref":"AWS.ElasticBeanstalk.html#create_application/3","title":"AWS.ElasticBeanstalk.create_application/3","type":"function"},{"doc":"Creates an application version for the specified application.\n\nYou can create an application version from a source bundle in Amazon S3, a\ncommit in AWS CodeCommit, or the output of an AWS CodeBuild build as follows:\n\nSpecify a commit in an AWS CodeCommit repository with `SourceBuildInformation`.\n\nSpecify a build in an AWS CodeBuild with `SourceBuildInformation` and\n`BuildConfiguration`.\n\nSpecify a source bundle in S3 with `SourceBundle`\n\nOmit both `SourceBuildInformation` and `SourceBundle` to use the default sample\napplication.\n\nAfter you create an application version with a specified Amazon S3 bucket and\nkey location, you can't change that Amazon S3 location. If you change the Amazon\nS3 location, you receive an exception when you attempt to launch an environment\nfrom the application version.","ref":"AWS.ElasticBeanstalk.html#create_application_version/3","title":"AWS.ElasticBeanstalk.create_application_version/3","type":"function"},{"doc":"Creates an AWS Elastic Beanstalk configuration template, associated with a\nspecific Elastic Beanstalk application.\n\nYou define application configuration settings in a configuration template. You\ncan then use the configuration template to deploy different versions of the\napplication with the same configuration settings.\n\nTemplates aren't associated with any environment. The `EnvironmentName` response\nelement is always `null`.\n\nRelated Topics\n\n  * `DescribeConfigurationOptions`\n\n  * `DescribeConfigurationSettings`\n\n  * `ListAvailableSolutionStacks`","ref":"AWS.ElasticBeanstalk.html#create_configuration_template/3","title":"AWS.ElasticBeanstalk.create_configuration_template/3","type":"function"},{"doc":"Launches an AWS Elastic Beanstalk environment for the specified application\nusing the specified configuration.","ref":"AWS.ElasticBeanstalk.html#create_environment/3","title":"AWS.ElasticBeanstalk.create_environment/3","type":"function"},{"doc":"Create a new version of your custom platform.","ref":"AWS.ElasticBeanstalk.html#create_platform_version/3","title":"AWS.ElasticBeanstalk.create_platform_version/3","type":"function"},{"doc":"Creates a bucket in Amazon S3 to store application versions, logs, and other\nfiles used by Elastic Beanstalk environments.\n\nThe Elastic Beanstalk console and EB CLI call this API the first time you create\nan environment in a region. If the storage location already exists,\n`CreateStorageLocation` still returns the bucket name but does not create a new\nbucket.","ref":"AWS.ElasticBeanstalk.html#create_storage_location/3","title":"AWS.ElasticBeanstalk.create_storage_location/3","type":"function"},{"doc":"Deletes the specified application along with all associated versions and\nconfigurations.\n\nThe application versions will not be deleted from your Amazon S3 bucket.\n\nYou cannot delete an application that has a running environment.","ref":"AWS.ElasticBeanstalk.html#delete_application/3","title":"AWS.ElasticBeanstalk.delete_application/3","type":"function"},{"doc":"Deletes the specified version from the specified application.\n\nYou cannot delete an application version that is associated with a running\nenvironment.","ref":"AWS.ElasticBeanstalk.html#delete_application_version/3","title":"AWS.ElasticBeanstalk.delete_application_version/3","type":"function"},{"doc":"Deletes the specified configuration template.\n\nWhen you launch an environment using a configuration template, the environment\ngets a copy of the template. You can delete or modify the environment's copy of\nthe template without affecting the running environment.","ref":"AWS.ElasticBeanstalk.html#delete_configuration_template/3","title":"AWS.ElasticBeanstalk.delete_configuration_template/3","type":"function"},{"doc":"Deletes the draft configuration associated with the running environment.\n\nUpdating a running environment with any configuration changes creates a draft\nconfiguration set. You can get the draft configuration using\n`DescribeConfigurationSettings` while the update is in progress or if the update\nfails. The `DeploymentStatus` for the draft configuration indicates whether the\ndeployment is in process or has failed. The draft configuration remains in\nexistence until it is deleted with this action.","ref":"AWS.ElasticBeanstalk.html#delete_environment_configuration/3","title":"AWS.ElasticBeanstalk.delete_environment_configuration/3","type":"function"},{"doc":"Deletes the specified version of a custom platform.","ref":"AWS.ElasticBeanstalk.html#delete_platform_version/3","title":"AWS.ElasticBeanstalk.delete_platform_version/3","type":"function"},{"doc":"Returns attributes related to AWS Elastic Beanstalk that are associated with the\ncalling AWS account.\n\nThe result currently has one set of attributes—resource quotas.","ref":"AWS.ElasticBeanstalk.html#describe_account_attributes/3","title":"AWS.ElasticBeanstalk.describe_account_attributes/3","type":"function"},{"doc":"Retrieve a list of application versions.","ref":"AWS.ElasticBeanstalk.html#describe_application_versions/3","title":"AWS.ElasticBeanstalk.describe_application_versions/3","type":"function"},{"doc":"Returns the descriptions of existing applications.","ref":"AWS.ElasticBeanstalk.html#describe_applications/3","title":"AWS.ElasticBeanstalk.describe_applications/3","type":"function"},{"doc":"Describes the configuration options that are used in a particular configuration\ntemplate or environment, or that a specified solution stack defines.\n\nThe description includes the values the options, their default values, and an\nindication of the required action on a running environment if an option value is\nchanged.","ref":"AWS.ElasticBeanstalk.html#describe_configuration_options/3","title":"AWS.ElasticBeanstalk.describe_configuration_options/3","type":"function"},{"doc":"Returns a description of the settings for the specified configuration set, that\nis, either a configuration template or the configuration set associated with a\nrunning environment.\n\nWhen describing the settings for the configuration set associated with a running\nenvironment, it is possible to receive two sets of setting descriptions. One is\nthe deployed configuration set, and the other is a draft configuration of an\nenvironment that is either in the process of deployment or that failed to\ndeploy.\n\nRelated Topics\n\n  * `DeleteEnvironmentConfiguration`","ref":"AWS.ElasticBeanstalk.html#describe_configuration_settings/3","title":"AWS.ElasticBeanstalk.describe_configuration_settings/3","type":"function"},{"doc":"Returns information about the overall health of the specified environment.\n\nThe **DescribeEnvironmentHealth** operation is only available with AWS Elastic\nBeanstalk Enhanced Health.","ref":"AWS.ElasticBeanstalk.html#describe_environment_health/3","title":"AWS.ElasticBeanstalk.describe_environment_health/3","type":"function"},{"doc":"Lists an environment's completed and failed managed actions.","ref":"AWS.ElasticBeanstalk.html#describe_environment_managed_action_history/3","title":"AWS.ElasticBeanstalk.describe_environment_managed_action_history/3","type":"function"},{"doc":"Lists an environment's upcoming and in-progress managed actions.","ref":"AWS.ElasticBeanstalk.html#describe_environment_managed_actions/3","title":"AWS.ElasticBeanstalk.describe_environment_managed_actions/3","type":"function"},{"doc":"Returns AWS resources for this environment.","ref":"AWS.ElasticBeanstalk.html#describe_environment_resources/3","title":"AWS.ElasticBeanstalk.describe_environment_resources/3","type":"function"},{"doc":"Returns descriptions for existing environments.","ref":"AWS.ElasticBeanstalk.html#describe_environments/3","title":"AWS.ElasticBeanstalk.describe_environments/3","type":"function"},{"doc":"Returns list of event descriptions matching criteria up to the last 6 weeks.\n\nThis action returns the most recent 1,000 events from the specified `NextToken`.","ref":"AWS.ElasticBeanstalk.html#describe_events/3","title":"AWS.ElasticBeanstalk.describe_events/3","type":"function"},{"doc":"Retrieves detailed information about the health of instances in your AWS Elastic\nBeanstalk.\n\nThis operation requires [enhanced health reporting](https://docs.aws.amazon.com/elasticbeanstalk/latest/dg/health-enhanced.html).","ref":"AWS.ElasticBeanstalk.html#describe_instances_health/3","title":"AWS.ElasticBeanstalk.describe_instances_health/3","type":"function"},{"doc":"Describes a platform version.\n\nProvides full details. Compare to `ListPlatformVersions`, which provides summary\ninformation about a list of platform versions.\n\nFor definitions of platform version and other platform-related terms, see [AWS Elastic Beanstalk Platforms\nGlossary](https://docs.aws.amazon.com/elasticbeanstalk/latest/dg/platforms-glossary.html).","ref":"AWS.ElasticBeanstalk.html#describe_platform_version/3","title":"AWS.ElasticBeanstalk.describe_platform_version/3","type":"function"},{"doc":"Disassociate the operations role from an environment.\n\nAfter this call is made, Elastic Beanstalk uses the caller's permissions for\npermissions to downstream services during subsequent calls acting on this\nenvironment. For more information, see [Operations roles](https://docs.aws.amazon.com/elasticbeanstalk/latest/dg/iam-operationsrole.html)\nin the *AWS Elastic Beanstalk Developer Guide*.","ref":"AWS.ElasticBeanstalk.html#disassociate_environment_operations_role/3","title":"AWS.ElasticBeanstalk.disassociate_environment_operations_role/3","type":"function"},{"doc":"Returns a list of the available solution stack names, with the public version\nfirst and then in reverse chronological order.","ref":"AWS.ElasticBeanstalk.html#list_available_solution_stacks/3","title":"AWS.ElasticBeanstalk.list_available_solution_stacks/3","type":"function"},{"doc":"Lists the platform branches available for your account in an AWS Region.\n\nProvides summary information about each platform branch.\n\nFor definitions of platform branch and other platform-related terms, see [AWS Elastic Beanstalk Platforms\nGlossary](https://docs.aws.amazon.com/elasticbeanstalk/latest/dg/platforms-glossary.html).","ref":"AWS.ElasticBeanstalk.html#list_platform_branches/3","title":"AWS.ElasticBeanstalk.list_platform_branches/3","type":"function"},{"doc":"Lists the platform versions available for your account in an AWS Region.\n\nProvides summary information about each platform version. Compare to\n`DescribePlatformVersion`, which provides full details about a single platform\nversion.\n\nFor definitions of platform version and other platform-related terms, see [AWS Elastic Beanstalk Platforms\nGlossary](https://docs.aws.amazon.com/elasticbeanstalk/latest/dg/platforms-glossary.html).","ref":"AWS.ElasticBeanstalk.html#list_platform_versions/3","title":"AWS.ElasticBeanstalk.list_platform_versions/3","type":"function"},{"doc":"Return the tags applied to an AWS Elastic Beanstalk resource.\n\nThe response contains a list of tag key-value pairs.\n\nElastic Beanstalk supports tagging of all of its resources. For details about\nresource tagging, see [Tagging Application Resources](https://docs.aws.amazon.com/elasticbeanstalk/latest/dg/applications-tagging-resources.html).","ref":"AWS.ElasticBeanstalk.html#list_tags_for_resource/3","title":"AWS.ElasticBeanstalk.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.ElasticBeanstalk.html#metadata/0","title":"AWS.ElasticBeanstalk.metadata/0","type":"function"},{"doc":"Deletes and recreates all of the AWS resources (for example: the Auto Scaling\ngroup, load balancer, etc.) for a specified environment and forces a restart.","ref":"AWS.ElasticBeanstalk.html#rebuild_environment/3","title":"AWS.ElasticBeanstalk.rebuild_environment/3","type":"function"},{"doc":"Initiates a request to compile the specified type of information of the deployed\nenvironment.\n\nSetting the `InfoType` to `tail` compiles the last lines from the application\nserver log files of every Amazon EC2 instance in your environment.\n\nSetting the `InfoType` to `bundle` compresses the application server log files\nfor every Amazon EC2 instance into a `.zip` file. Legacy and .NET containers do\nnot support bundle logs.\n\nUse `RetrieveEnvironmentInfo` to obtain the set of logs.\n\nRelated Topics\n\n  * `RetrieveEnvironmentInfo`","ref":"AWS.ElasticBeanstalk.html#request_environment_info/3","title":"AWS.ElasticBeanstalk.request_environment_info/3","type":"function"},{"doc":"Causes the environment to restart the application container server running on\neach Amazon EC2 instance.","ref":"AWS.ElasticBeanstalk.html#restart_app_server/3","title":"AWS.ElasticBeanstalk.restart_app_server/3","type":"function"},{"doc":"Retrieves the compiled information from a `RequestEnvironmentInfo` request.\n\nRelated Topics\n\n  * `RequestEnvironmentInfo`","ref":"AWS.ElasticBeanstalk.html#retrieve_environment_info/3","title":"AWS.ElasticBeanstalk.retrieve_environment_info/3","type":"function"},{"doc":"Swaps the CNAMEs of two environments.","ref":"AWS.ElasticBeanstalk.html#swap_environment_cnames/3","title":"AWS.ElasticBeanstalk.swap_environment_cnames/3","type":"function"},{"doc":"Terminates the specified environment.","ref":"AWS.ElasticBeanstalk.html#terminate_environment/3","title":"AWS.ElasticBeanstalk.terminate_environment/3","type":"function"},{"doc":"Updates the specified application to have the specified properties.\n\nIf a property (for example, `description`) is not provided, the value remains\nunchanged. To clear these properties, specify an empty string.","ref":"AWS.ElasticBeanstalk.html#update_application/3","title":"AWS.ElasticBeanstalk.update_application/3","type":"function"},{"doc":"Modifies lifecycle settings for an application.","ref":"AWS.ElasticBeanstalk.html#update_application_resource_lifecycle/3","title":"AWS.ElasticBeanstalk.update_application_resource_lifecycle/3","type":"function"},{"doc":"Updates the specified application version to have the specified properties.\n\nIf a property (for example, `description`) is not provided, the value remains\nunchanged. To clear properties, specify an empty string.","ref":"AWS.ElasticBeanstalk.html#update_application_version/3","title":"AWS.ElasticBeanstalk.update_application_version/3","type":"function"},{"doc":"Updates the specified configuration template to have the specified properties or\nconfiguration option values.\n\nIf a property (for example, `ApplicationName`) is not provided, its value\nremains unchanged. To clear such properties, specify an empty string.\n\nRelated Topics\n\n  * `DescribeConfigurationOptions`","ref":"AWS.ElasticBeanstalk.html#update_configuration_template/3","title":"AWS.ElasticBeanstalk.update_configuration_template/3","type":"function"},{"doc":"Updates the environment description, deploys a new application version, updates\nthe configuration settings to an entirely new configuration template, or updates\nselect configuration option values in the running environment.\n\nAttempting to update both the release and configuration is not allowed and AWS\nElastic Beanstalk returns an `InvalidParameterCombination` error.\n\nWhen updating the configuration settings to a new template or individual\nsettings, a draft configuration is created and `DescribeConfigurationSettings`\nfor this environment returns two setting descriptions with different\n`DeploymentStatus` values.","ref":"AWS.ElasticBeanstalk.html#update_environment/3","title":"AWS.ElasticBeanstalk.update_environment/3","type":"function"},{"doc":"Update the list of tags applied to an AWS Elastic Beanstalk resource.\n\nTwo lists can be passed: `TagsToAdd` for tags to add or update, and\n`TagsToRemove`.\n\nElastic Beanstalk supports tagging of all of its resources. For details about\nresource tagging, see [Tagging Application Resources](https://docs.aws.amazon.com/elasticbeanstalk/latest/dg/applications-tagging-resources.html).\n\nIf you create a custom IAM user policy to control permission to this operation,\nspecify one of the following two virtual actions (or both) instead of the API\noperation name:","ref":"AWS.ElasticBeanstalk.html#update_tags_for_resource/3","title":"AWS.ElasticBeanstalk.update_tags_for_resource/3","type":"function"},{"doc":"#","ref":"AWS.ElasticBeanstalk.html#update_tags_for_resource/3-definitions","title":"Definitions - AWS.ElasticBeanstalk.update_tags_for_resource/3","type":"function"},{"doc":"Controls permission to call `UpdateTagsForResource` and pass a list of tags to\nadd in the `TagsToAdd` parameter.\n\n#","ref":"AWS.ElasticBeanstalk.html#update_tags_for_resource/3-elasticbeanstalk-addtags","title":"elasticbeanstalk:AddTags - AWS.ElasticBeanstalk.update_tags_for_resource/3","type":"function"},{"doc":"Controls permission to call `UpdateTagsForResource` and pass a list of tag keys\nto remove in the `TagsToRemove` parameter.\n\nFor details about creating a custom user policy, see [Creating a Custom User Policy](https://docs.aws.amazon.com/elasticbeanstalk/latest/dg/AWSHowTo.iam.managed-policies.html#AWSHowTo.iam.policies).","ref":"AWS.ElasticBeanstalk.html#update_tags_for_resource/3-elasticbeanstalk-removetags","title":"elasticbeanstalk:RemoveTags - AWS.ElasticBeanstalk.update_tags_for_resource/3","type":"function"},{"doc":"Takes a set of configuration settings and either a configuration template or\nenvironment, and determines whether those values are valid.\n\nThis action returns a list of messages indicating any errors or warnings\nassociated with the selection of option values.","ref":"AWS.ElasticBeanstalk.html#validate_configuration_settings/3","title":"AWS.ElasticBeanstalk.validate_configuration_settings/3","type":"function"},{"doc":"Elastic Inference public APIs.\n\nFebruary 15, 2023: Starting April 15, 2023, AWS will not onboard new customers\nto Amazon Elastic Inference (EI), and will help current customers migrate their\nworkloads to options that offer better price and performance. After April 15,\n2023, new customers will not be able to launch instances with Amazon EI\naccelerators in Amazon SageMaker, Amazon ECS, or Amazon EC2. However, customers\nwho have used Amazon EI at least once during the past 30-day period are\nconsidered current customers and will be able to continue using the service.","ref":"AWS.ElasticInference.html","title":"AWS.ElasticInference","type":"module"},{"doc":"Describes the locations in which a given accelerator type or set of types is\npresent in a given region.\n\nFebruary 15, 2023: Starting April 15, 2023, AWS will not onboard new customers\nto Amazon Elastic Inference (EI), and will help current customers migrate their\nworkloads to options that offer better price and performance. After April 15,\n2023, new customers will not be able to launch instances with Amazon EI\naccelerators in Amazon SageMaker, Amazon ECS, or Amazon EC2. However, customers\nwho have used Amazon EI at least once during the past 30-day period are\nconsidered current customers and will be able to continue using the service.","ref":"AWS.ElasticInference.html#describe_accelerator_offerings/3","title":"AWS.ElasticInference.describe_accelerator_offerings/3","type":"function"},{"doc":"Describes the accelerator types available in a given region, as well as their\ncharacteristics, such as memory and throughput.\n\nFebruary 15, 2023: Starting April 15, 2023, AWS will not onboard new customers\nto Amazon Elastic Inference (EI), and will help current customers migrate their\nworkloads to options that offer better price and performance. After April 15,\n2023, new customers will not be able to launch instances with Amazon EI\naccelerators in Amazon SageMaker, Amazon ECS, or Amazon EC2. However, customers\nwho have used Amazon EI at least once during the past 30-day period are\nconsidered current customers and will be able to continue using the service.","ref":"AWS.ElasticInference.html#describe_accelerator_types/2","title":"AWS.ElasticInference.describe_accelerator_types/2","type":"function"},{"doc":"Describes information over a provided set of accelerators belonging to an\naccount.\n\nFebruary 15, 2023: Starting April 15, 2023, AWS will not onboard new customers\nto Amazon Elastic Inference (EI), and will help current customers migrate their\nworkloads to options that offer better price and performance. After April 15,\n2023, new customers will not be able to launch instances with Amazon EI\naccelerators in Amazon SageMaker, Amazon ECS, or Amazon EC2. However, customers\nwho have used Amazon EI at least once during the past 30-day period are\nconsidered current customers and will be able to continue using the service.","ref":"AWS.ElasticInference.html#describe_accelerators/3","title":"AWS.ElasticInference.describe_accelerators/3","type":"function"},{"doc":"Returns all tags of an Elastic Inference Accelerator.\n\nFebruary 15, 2023: Starting April 15, 2023, AWS will not onboard new customers\nto Amazon Elastic Inference (EI), and will help current customers migrate their\nworkloads to options that offer better price and performance. After April 15,\n2023, new customers will not be able to launch instances with Amazon EI\naccelerators in Amazon SageMaker, Amazon ECS, or Amazon EC2. However, customers\nwho have used Amazon EI at least once during the past 30-day period are\nconsidered current customers and will be able to continue using the service.","ref":"AWS.ElasticInference.html#list_tags_for_resource/3","title":"AWS.ElasticInference.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.ElasticInference.html#metadata/0","title":"AWS.ElasticInference.metadata/0","type":"function"},{"doc":"Adds the specified tags to an Elastic Inference Accelerator.\n\nFebruary 15, 2023: Starting April 15, 2023, AWS will not onboard new customers\nto Amazon Elastic Inference (EI), and will help current customers migrate their\nworkloads to options that offer better price and performance. After April 15,\n2023, new customers will not be able to launch instances with Amazon EI\naccelerators in Amazon SageMaker, Amazon ECS, or Amazon EC2. However, customers\nwho have used Amazon EI at least once during the past 30-day period are\nconsidered current customers and will be able to continue using the service.","ref":"AWS.ElasticInference.html#tag_resource/4","title":"AWS.ElasticInference.tag_resource/4","type":"function"},{"doc":"Removes the specified tags from an Elastic Inference Accelerator.\n\nFebruary 15, 2023: Starting April 15, 2023, AWS will not onboard new customers\nto Amazon Elastic Inference (EI), and will help current customers migrate their\nworkloads to options that offer better price and performance. After April 15,\n2023, new customers will not be able to launch instances with Amazon EI\naccelerators in Amazon SageMaker, Amazon ECS, or Amazon EC2. However, customers\nwho have used Amazon EI at least once during the past 30-day period are\nconsidered current customers and will be able to continue using the service.","ref":"AWS.ElasticInference.html#untag_resource/4","title":"AWS.ElasticInference.untag_resource/4","type":"function"},{"doc":"Elastic Load Balancing\n\nA load balancer can distribute incoming traffic across your EC2 instances.\n\nThis enables you to increase the availability of your application. The load\nbalancer also monitors the health of its registered instances and ensures that\nit routes traffic only to healthy instances. You configure your load balancer to\naccept incoming traffic by specifying one or more listeners, which are\nconfigured with a protocol and port number for connections from clients to the\nload balancer and a protocol and port number for connections from the load\nbalancer to the instances.\n\nElastic Load Balancing supports three types of load balancers: Application Load\nBalancers, Network Load Balancers, and Classic Load Balancers. You can select a\nload balancer based on your application needs. For more information, see the\n[Elastic Load Balancing User Guide](https://docs.aws.amazon.com/elasticloadbalancing/latest/userguide/).\n\nThis reference covers the 2012-06-01 API, which supports Classic Load Balancers.\nThe 2015-12-01 API supports Application Load Balancers and Network Load\nBalancers.\n\nTo get started, create a load balancer with one or more listeners using\n`CreateLoadBalancer`. Register your instances with the load balancer using\n`RegisterInstancesWithLoadBalancer`.\n\nAll Elastic Load Balancing operations are *idempotent*, which means that they\ncomplete at most one time. If you repeat an operation, it succeeds with a 200 OK\nresponse code.","ref":"AWS.ElasticLoadBalancing.html","title":"AWS.ElasticLoadBalancing","type":"module"},{"doc":"Adds the specified tags to the specified load balancer.\n\nEach load balancer can have a maximum of 10 tags.\n\nEach tag consists of a key and an optional value. If a tag with the same key is\nalready associated with the load balancer, `AddTags` updates its value.\n\nFor more information, see [Tag Your Classic Load Balancer](https://docs.aws.amazon.com/elasticloadbalancing/latest/classic/add-remove-tags.html)\nin the *Classic Load Balancers Guide*.","ref":"AWS.ElasticLoadBalancing.html#add_tags/3","title":"AWS.ElasticLoadBalancing.add_tags/3","type":"function"},{"doc":"Associates one or more security groups with your load balancer in a virtual\nprivate cloud (VPC).\n\nThe specified security groups override the previously associated security\ngroups.\n\nFor more information, see [Security Groups for Load Balancers in a VPC](https://docs.aws.amazon.com/elasticloadbalancing/latest/classic/elb-security-groups.html#elb-vpc-security-groups)\nin the *Classic Load Balancers Guide*.","ref":"AWS.ElasticLoadBalancing.html#apply_security_groups_to_load_balancer/3","title":"AWS.ElasticLoadBalancing.apply_security_groups_to_load_balancer/3","type":"function"},{"doc":"Adds one or more subnets to the set of configured subnets for the specified load\nbalancer.\n\nThe load balancer evenly distributes requests across all registered subnets. For\nmore information, see [Add or Remove Subnets for Your Load Balancer in a VPC](https://docs.aws.amazon.com/elasticloadbalancing/latest/classic/elb-manage-subnets.html)\nin the *Classic Load Balancers Guide*.","ref":"AWS.ElasticLoadBalancing.html#attach_load_balancer_to_subnets/3","title":"AWS.ElasticLoadBalancing.attach_load_balancer_to_subnets/3","type":"function"},{"doc":"Specifies the health check settings to use when evaluating the health state of\nyour EC2 instances.\n\nFor more information, see [Configure Health Checks for Your Load Balancer](https://docs.aws.amazon.com/elasticloadbalancing/latest/classic/elb-healthchecks.html)\nin the *Classic Load Balancers Guide*.","ref":"AWS.ElasticLoadBalancing.html#configure_health_check/3","title":"AWS.ElasticLoadBalancing.configure_health_check/3","type":"function"},{"doc":"Generates a stickiness policy with sticky session lifetimes that follow that of\nan application-generated cookie.\n\nThis policy can be associated only with HTTP/HTTPS listeners.\n\nThis policy is similar to the policy created by\n`CreateLBCookieStickinessPolicy`, except that the lifetime of the special\nElastic Load Balancing cookie, `AWSELB`, follows the lifetime of the\napplication-generated cookie specified in the policy configuration. The load\nbalancer only inserts a new stickiness cookie when the application response\nincludes a new application cookie.\n\nIf the application cookie is explicitly removed or expires, the session stops\nbeing sticky until a new application cookie is issued.\n\nFor more information, see [Application-Controlled Session Stickiness](https://docs.aws.amazon.com/elasticloadbalancing/latest/classic/elb-sticky-sessions.html#enable-sticky-sessions-application)\nin the *Classic Load Balancers Guide*.","ref":"AWS.ElasticLoadBalancing.html#create_app_cookie_stickiness_policy/3","title":"AWS.ElasticLoadBalancing.create_app_cookie_stickiness_policy/3","type":"function"},{"doc":"Generates a stickiness policy with sticky session lifetimes controlled by the\nlifetime of the browser (user-agent) or a specified expiration period.\n\nThis policy can be associated only with HTTP/HTTPS listeners.\n\nWhen a load balancer implements this policy, the load balancer uses a special\ncookie to track the instance for each request. When the load balancer receives a\nrequest, it first checks to see if this cookie is present in the request. If so,\nthe load balancer sends the request to the application server specified in the\ncookie. If not, the load balancer sends the request to a server that is chosen\nbased on the existing load-balancing algorithm.\n\nA cookie is inserted into the response for binding subsequent requests from the\nsame user to that server. The validity of the cookie is based on the cookie\nexpiration time, which is specified in the policy configuration.\n\nFor more information, see [Duration-Based Session Stickiness](https://docs.aws.amazon.com/elasticloadbalancing/latest/classic/elb-sticky-sessions.html#enable-sticky-sessions-duration)\nin the *Classic Load Balancers Guide*.","ref":"AWS.ElasticLoadBalancing.html#create_lb_cookie_stickiness_policy/3","title":"AWS.ElasticLoadBalancing.create_lb_cookie_stickiness_policy/3","type":"function"},{"doc":"Creates a Classic Load Balancer.\n\nYou can add listeners, security groups, subnets, and tags when you create your\nload balancer, or you can add them later using `CreateLoadBalancerListeners`,\n`ApplySecurityGroupsToLoadBalancer`, `AttachLoadBalancerToSubnets`, and\n`AddTags`.\n\nTo describe your current load balancers, see `DescribeLoadBalancers`. When you\nare finished with a load balancer, you can delete it using `DeleteLoadBalancer`.\n\nYou can create up to 20 load balancers per region per account. You can request\nan increase for the number of load balancers for your account. For more\ninformation, see [Limits for Your Classic Load Balancer](https://docs.aws.amazon.com/elasticloadbalancing/latest/classic/elb-limits.html)\nin the *Classic Load Balancers Guide*.","ref":"AWS.ElasticLoadBalancing.html#create_load_balancer/3","title":"AWS.ElasticLoadBalancing.create_load_balancer/3","type":"function"},{"doc":"Creates one or more listeners for the specified load balancer.\n\nIf a listener with the specified port does not already exist, it is created;\notherwise, the properties of the new listener must match the properties of the\nexisting listener.\n\nFor more information, see [Listeners for Your Classic Load Balancer](https://docs.aws.amazon.com/elasticloadbalancing/latest/classic/elb-listener-config.html)\nin the *Classic Load Balancers Guide*.","ref":"AWS.ElasticLoadBalancing.html#create_load_balancer_listeners/3","title":"AWS.ElasticLoadBalancing.create_load_balancer_listeners/3","type":"function"},{"doc":"Creates a policy with the specified attributes for the specified load balancer.\n\nPolicies are settings that are saved for your load balancer and that can be\napplied to the listener or the application server, depending on the policy type.","ref":"AWS.ElasticLoadBalancing.html#create_load_balancer_policy/3","title":"AWS.ElasticLoadBalancing.create_load_balancer_policy/3","type":"function"},{"doc":"Deletes the specified load balancer.\n\nIf you are attempting to recreate a load balancer, you must reconfigure all\nsettings. The DNS name associated with a deleted load balancer are no longer\nusable. The name and associated DNS record of the deleted load balancer no\nlonger exist and traffic sent to any of its IP addresses is no longer delivered\nto your instances.\n\nIf the load balancer does not exist or has already been deleted, the call to\n`DeleteLoadBalancer` still succeeds.","ref":"AWS.ElasticLoadBalancing.html#delete_load_balancer/3","title":"AWS.ElasticLoadBalancing.delete_load_balancer/3","type":"function"},{"doc":"Deletes the specified listeners from the specified load balancer.","ref":"AWS.ElasticLoadBalancing.html#delete_load_balancer_listeners/3","title":"AWS.ElasticLoadBalancing.delete_load_balancer_listeners/3","type":"function"},{"doc":"Deletes the specified policy from the specified load balancer.\n\nThis policy must not be enabled for any listeners.","ref":"AWS.ElasticLoadBalancing.html#delete_load_balancer_policy/3","title":"AWS.ElasticLoadBalancing.delete_load_balancer_policy/3","type":"function"},{"doc":"Deregisters the specified instances from the specified load balancer.\n\nAfter the instance is deregistered, it no longer receives traffic from the load\nbalancer.\n\nYou can use `DescribeLoadBalancers` to verify that the instance is deregistered\nfrom the load balancer.\n\nFor more information, see [Register or De-Register EC2 Instances](https://docs.aws.amazon.com/elasticloadbalancing/latest/classic/elb-deregister-register-instances.html)\nin the *Classic Load Balancers Guide*.","ref":"AWS.ElasticLoadBalancing.html#deregister_instances_from_load_balancer/3","title":"AWS.ElasticLoadBalancing.deregister_instances_from_load_balancer/3","type":"function"},{"doc":"Describes the current Elastic Load Balancing resource limits for your AWS\naccount.\n\nFor more information, see [Limits for Your Classic Load Balancer](https://docs.aws.amazon.com/elasticloadbalancing/latest/classic/elb-limits.html)\nin the *Classic Load Balancers Guide*.","ref":"AWS.ElasticLoadBalancing.html#describe_account_limits/3","title":"AWS.ElasticLoadBalancing.describe_account_limits/3","type":"function"},{"doc":"Describes the state of the specified instances with respect to the specified\nload balancer.\n\nIf no instances are specified, the call describes the state of all instances\nthat are currently registered with the load balancer. If instances are\nspecified, their state is returned even if they are no longer registered with\nthe load balancer. The state of terminated instances is not returned.","ref":"AWS.ElasticLoadBalancing.html#describe_instance_health/3","title":"AWS.ElasticLoadBalancing.describe_instance_health/3","type":"function"},{"doc":"Describes the attributes for the specified load balancer.","ref":"AWS.ElasticLoadBalancing.html#describe_load_balancer_attributes/3","title":"AWS.ElasticLoadBalancing.describe_load_balancer_attributes/3","type":"function"},{"doc":"Describes the specified policies.\n\nIf you specify a load balancer name, the action returns the descriptions of all\npolicies created for the load balancer. If you specify a policy name associated\nwith your load balancer, the action returns the description of that policy. If\nyou don't specify a load balancer name, the action returns descriptions of the\nspecified sample policies, or descriptions of all sample policies. The names of\nthe sample policies have the `ELBSample-` prefix.","ref":"AWS.ElasticLoadBalancing.html#describe_load_balancer_policies/3","title":"AWS.ElasticLoadBalancing.describe_load_balancer_policies/3","type":"function"},{"doc":"Describes the specified load balancer policy types or all load balancer policy\ntypes.\n\nThe description of each type indicates how it can be used. For example, some\npolicies can be used only with layer 7 listeners, some policies can be used only\nwith layer 4 listeners, and some policies can be used only with your EC2\ninstances.\n\nYou can use `CreateLoadBalancerPolicy` to create a policy configuration for any\nof these policy types. Then, depending on the policy type, use either\n`SetLoadBalancerPoliciesOfListener` or `SetLoadBalancerPoliciesForBackendServer`\nto set the policy.","ref":"AWS.ElasticLoadBalancing.html#describe_load_balancer_policy_types/3","title":"AWS.ElasticLoadBalancing.describe_load_balancer_policy_types/3","type":"function"},{"doc":"Describes the specified the load balancers.\n\nIf no load balancers are specified, the call describes all of your load\nbalancers.","ref":"AWS.ElasticLoadBalancing.html#describe_load_balancers/3","title":"AWS.ElasticLoadBalancing.describe_load_balancers/3","type":"function"},{"doc":"Describes the tags associated with the specified load balancers.","ref":"AWS.ElasticLoadBalancing.html#describe_tags/3","title":"AWS.ElasticLoadBalancing.describe_tags/3","type":"function"},{"doc":"Removes the specified subnets from the set of configured subnets for the load\nbalancer.\n\nAfter a subnet is removed, all EC2 instances registered with the load balancer\nin the removed subnet go into the `OutOfService` state. Then, the load balancer\nbalances the traffic among the remaining routable subnets.","ref":"AWS.ElasticLoadBalancing.html#detach_load_balancer_from_subnets/3","title":"AWS.ElasticLoadBalancing.detach_load_balancer_from_subnets/3","type":"function"},{"doc":"Removes the specified Availability Zones from the set of Availability Zones for\nthe specified load balancer in EC2-Classic or a default VPC.\n\nFor load balancers in a non-default VPC, use `DetachLoadBalancerFromSubnets`.\n\nThere must be at least one Availability Zone registered with a load balancer at\nall times. After an Availability Zone is removed, all instances registered with\nthe load balancer that are in the removed Availability Zone go into the\n`OutOfService` state. Then, the load balancer attempts to equally balance the\ntraffic among its remaining Availability Zones.\n\nFor more information, see [Add or Remove Availability Zones](https://docs.aws.amazon.com/elasticloadbalancing/latest/classic/enable-disable-az.html)\nin the *Classic Load Balancers Guide*.","ref":"AWS.ElasticLoadBalancing.html#disable_availability_zones_for_load_balancer/3","title":"AWS.ElasticLoadBalancing.disable_availability_zones_for_load_balancer/3","type":"function"},{"doc":"Adds the specified Availability Zones to the set of Availability Zones for the\nspecified load balancer in EC2-Classic or a default VPC.\n\nFor load balancers in a non-default VPC, use `AttachLoadBalancerToSubnets`.\n\nThe load balancer evenly distributes requests across all its registered\nAvailability Zones that contain instances. For more information, see [Add or Remove Availability\nZones](https://docs.aws.amazon.com/elasticloadbalancing/latest/classic/enable-disable-az.html)\nin the *Classic Load Balancers Guide*.","ref":"AWS.ElasticLoadBalancing.html#enable_availability_zones_for_load_balancer/3","title":"AWS.ElasticLoadBalancing.enable_availability_zones_for_load_balancer/3","type":"function"},{"doc":"","ref":"AWS.ElasticLoadBalancing.html#metadata/0","title":"AWS.ElasticLoadBalancing.metadata/0","type":"function"},{"doc":"Modifies the attributes of the specified load balancer.\n\nYou can modify the load balancer attributes, such as `AccessLogs`,\n`ConnectionDraining`, and `CrossZoneLoadBalancing` by either enabling or\ndisabling them. Or, you can modify the load balancer attribute\n`ConnectionSettings` by specifying an idle connection timeout value for your\nload balancer.\n\nFor more information, see the following in the *Classic Load Balancers Guide*:\n\n  * [Cross-Zone Load Balancing](https://docs.aws.amazon.com/elasticloadbalancing/latest/classic/enable-disable-crosszone-lb.html)\n\n  * [Connection Draining](https://docs.aws.amazon.com/elasticloadbalancing/latest/classic/config-conn-drain.html)\n\n  * [Access Logs](https://docs.aws.amazon.com/elasticloadbalancing/latest/classic/access-log-collection.html)\n\n  * [Idle Connection Timeout](https://docs.aws.amazon.com/elasticloadbalancing/latest/classic/config-idle-timeout.html)","ref":"AWS.ElasticLoadBalancing.html#modify_load_balancer_attributes/3","title":"AWS.ElasticLoadBalancing.modify_load_balancer_attributes/3","type":"function"},{"doc":"Adds the specified instances to the specified load balancer.\n\nThe instance must be a running instance in the same network as the load balancer\n(EC2-Classic or the same VPC). If you have EC2-Classic instances and a load\nbalancer in a VPC with ClassicLink enabled, you can link the EC2-Classic\ninstances to that VPC and then register the linked EC2-Classic instances with\nthe load balancer in the VPC.\n\nNote that `RegisterInstanceWithLoadBalancer` completes when the request has been\nregistered. Instance registration takes a little time to complete. To check the\nstate of the registered instances, use `DescribeLoadBalancers` or\n`DescribeInstanceHealth`.\n\nAfter the instance is registered, it starts receiving traffic and requests from\nthe load balancer. Any instance that is not in one of the Availability Zones\nregistered for the load balancer is moved to the `OutOfService` state. If an\nAvailability Zone is added to the load balancer later, any instances registered\nwith the load balancer move to the `InService` state.\n\nTo deregister instances from a load balancer, use\n`DeregisterInstancesFromLoadBalancer`.\n\nFor more information, see [Register or De-Register EC2 Instances](https://docs.aws.amazon.com/elasticloadbalancing/latest/classic/elb-deregister-register-instances.html)\nin the *Classic Load Balancers Guide*.","ref":"AWS.ElasticLoadBalancing.html#register_instances_with_load_balancer/3","title":"AWS.ElasticLoadBalancing.register_instances_with_load_balancer/3","type":"function"},{"doc":"Removes one or more tags from the specified load balancer.","ref":"AWS.ElasticLoadBalancing.html#remove_tags/3","title":"AWS.ElasticLoadBalancing.remove_tags/3","type":"function"},{"doc":"Sets the certificate that terminates the specified listener's SSL connections.\n\nThe specified certificate replaces any prior certificate that was used on the\nsame load balancer and port.\n\nFor more information about updating your SSL certificate, see [Replace the SSL Certificate for Your Load\nBalancer](https://docs.aws.amazon.com/elasticloadbalancing/latest/classic/elb-update-ssl-cert.html)\nin the *Classic Load Balancers Guide*.","ref":"AWS.ElasticLoadBalancing.html#set_load_balancer_listener_ssl_certificate/3","title":"AWS.ElasticLoadBalancing.set_load_balancer_listener_ssl_certificate/3","type":"function"},{"doc":"Replaces the set of policies associated with the specified port on which the EC2\ninstance is listening with a new set of policies.\n\nAt this time, only the back-end server authentication policy type can be applied\nto the instance ports; this policy type is composed of multiple public key\npolicies.\n\nEach time you use `SetLoadBalancerPoliciesForBackendServer` to enable the\npolicies, use the `PolicyNames` parameter to list the policies that you want to\nenable.\n\nYou can use `DescribeLoadBalancers` or `DescribeLoadBalancerPolicies` to verify\nthat the policy is associated with the EC2 instance.\n\nFor more information about enabling back-end instance authentication, see\n[Configure Back-end Instance Authentication](https://docs.aws.amazon.com/elasticloadbalancing/latest/classic/elb-create-https-ssl-load-balancer.html#configure_backendauth_clt)\nin the *Classic Load Balancers Guide*. For more information about Proxy\nProtocol, see [Configure Proxy Protocol Support](https://docs.aws.amazon.com/elasticloadbalancing/latest/classic/enable-proxy-protocol.html)\nin the *Classic Load Balancers Guide*.","ref":"AWS.ElasticLoadBalancing.html#set_load_balancer_policies_for_backend_server/3","title":"AWS.ElasticLoadBalancing.set_load_balancer_policies_for_backend_server/3","type":"function"},{"doc":"Replaces the current set of policies for the specified load balancer port with\nthe specified set of policies.\n\nTo enable back-end server authentication, use\n`SetLoadBalancerPoliciesForBackendServer`.\n\nFor more information about setting policies, see [Update the SSL Negotiation Configuration](https://docs.aws.amazon.com/elasticloadbalancing/latest/classic/ssl-config-update.html),\n[Duration-Based Session Stickiness](https://docs.aws.amazon.com/elasticloadbalancing/latest/classic/elb-sticky-sessions.html#enable-sticky-sessions-duration),\nand [Application-Controlled Session Stickiness](https://docs.aws.amazon.com/elasticloadbalancing/latest/classic/elb-sticky-sessions.html#enable-sticky-sessions-application)\nin the *Classic Load Balancers Guide*.","ref":"AWS.ElasticLoadBalancing.html#set_load_balancer_policies_of_listener/3","title":"AWS.ElasticLoadBalancing.set_load_balancer_policies_of_listener/3","type":"function"},{"doc":"Elastic Load Balancing\n\nA load balancer distributes incoming traffic across targets, such as your EC2\ninstances.\n\nThis enables you to increase the availability of your application. The load\nbalancer also monitors the health of its registered targets and ensures that it\nroutes traffic only to healthy targets. You configure your load balancer to\naccept incoming traffic by specifying one or more listeners, which are\nconfigured with a protocol and port number for connections from clients to the\nload balancer. You configure a target group with a protocol and port number for\nconnections from the load balancer to the targets, and with health check\nsettings to be used when checking the health status of the targets.\n\nElastic Load Balancing supports the following types of load balancers:\nApplication Load Balancers, Network Load Balancers, Gateway Load Balancers, and\nClassic Load Balancers. This reference covers the following load balancer types:\n\n  * Application Load Balancer - Operates at the application layer\n(layer 7) and supports HTTP and HTTPS.\n\n  * Network Load Balancer - Operates at the transport layer (layer 4)\nand supports TCP, TLS, and UDP.\n\n  * Gateway Load Balancer - Operates at the network layer (layer 3).\n\nFor more information, see the [Elastic Load Balancing User Guide](https://docs.aws.amazon.com/elasticloadbalancing/latest/userguide/).\n\nAll Elastic Load Balancing operations are idempotent, which means that they\ncomplete at most one time. If you repeat an operation, it succeeds.","ref":"AWS.ElasticLoadBalancingv2.html","title":"AWS.ElasticLoadBalancingv2","type":"module"},{"doc":"Adds the specified SSL server certificate to the certificate list for the\nspecified HTTPS or TLS listener.\n\nIf the certificate in already in the certificate list, the call is successful\nbut the certificate is not added again.\n\nFor more information, see [HTTPS listeners](https://docs.aws.amazon.com/elasticloadbalancing/latest/application/create-https-listener.html)\nin the *Application Load Balancers Guide* or [TLS listeners](https://docs.aws.amazon.com/elasticloadbalancing/latest/network/create-tls-listener.html)\nin the *Network Load Balancers Guide*.","ref":"AWS.ElasticLoadBalancingv2.html#add_listener_certificates/3","title":"AWS.ElasticLoadBalancingv2.add_listener_certificates/3","type":"function"},{"doc":"Adds the specified tags to the specified Elastic Load Balancing resource.\n\nYou can tag your Application Load Balancers, Network Load Balancers, Gateway\nLoad Balancers, target groups, trust stores, listeners, and rules.\n\nEach tag consists of a key and an optional value. If a resource already has a\ntag with the same key, `AddTags` updates its value.","ref":"AWS.ElasticLoadBalancingv2.html#add_tags/3","title":"AWS.ElasticLoadBalancingv2.add_tags/3","type":"function"},{"doc":"Adds the specified revocation file to the specified trust store.","ref":"AWS.ElasticLoadBalancingv2.html#add_trust_store_revocations/3","title":"AWS.ElasticLoadBalancingv2.add_trust_store_revocations/3","type":"function"},{"doc":"Creates a listener for the specified Application Load Balancer, Network Load\nBalancer, or Gateway Load Balancer.\n\nFor more information, see the following:\n\n  * [Listeners for your Application Load Balancers](https://docs.aws.amazon.com/elasticloadbalancing/latest/application/load-balancer-listeners.html)\n\n  * [Listeners for your Network Load Balancers](https://docs.aws.amazon.com/elasticloadbalancing/latest/network/load-balancer-listeners.html)\n\n  * [Listeners for your Gateway Load Balancers](https://docs.aws.amazon.com/elasticloadbalancing/latest/gateway/gateway-listeners.html)\n\nThis operation is idempotent, which means that it completes at most one time. If\nyou attempt to create multiple listeners with the same settings, each call\nsucceeds.","ref":"AWS.ElasticLoadBalancingv2.html#create_listener/3","title":"AWS.ElasticLoadBalancingv2.create_listener/3","type":"function"},{"doc":"Creates an Application Load Balancer, Network Load Balancer, or Gateway Load\nBalancer.\n\nFor more information, see the following:\n\n  * [Application Load Balancers](https://docs.aws.amazon.com/elasticloadbalancing/latest/application/application-load-balancers.html)\n\n  * [Network Load Balancers](https://docs.aws.amazon.com/elasticloadbalancing/latest/network/network-load-balancers.html)\n\n  * [Gateway Load Balancers](https://docs.aws.amazon.com/elasticloadbalancing/latest/gateway/gateway-load-balancers.html)\n\nThis operation is idempotent, which means that it completes at most one time. If\nyou attempt to create multiple load balancers with the same settings, each call\nsucceeds.","ref":"AWS.ElasticLoadBalancingv2.html#create_load_balancer/3","title":"AWS.ElasticLoadBalancingv2.create_load_balancer/3","type":"function"},{"doc":"Creates a rule for the specified listener.\n\nThe listener must be associated with an Application Load Balancer.\n\nEach rule consists of a priority, one or more actions, and one or more\nconditions. Rules are evaluated in priority order, from the lowest value to the\nhighest value. When the conditions for a rule are met, its actions are\nperformed. If the conditions for no rules are met, the actions for the default\nrule are performed. For more information, see [Listener rules](https://docs.aws.amazon.com/elasticloadbalancing/latest/application/load-balancer-listeners.html#listener-rules)\nin the *Application Load Balancers Guide*.","ref":"AWS.ElasticLoadBalancingv2.html#create_rule/3","title":"AWS.ElasticLoadBalancingv2.create_rule/3","type":"function"},{"doc":"Creates a target group.\n\nFor more information, see the following:\n\n  * [Target groups for your Application Load Balancers](https://docs.aws.amazon.com/elasticloadbalancing/latest/application/load-balancer-target-groups.html)\n\n  * [Target groups for your Network Load Balancers](https://docs.aws.amazon.com/elasticloadbalancing/latest/network/load-balancer-target-groups.html)\n\n  * [Target groups for your Gateway Load Balancers](https://docs.aws.amazon.com/elasticloadbalancing/latest/gateway/target-groups.html)\n\nThis operation is idempotent, which means that it completes at most one time. If\nyou attempt to create multiple target groups with the same settings, each call\nsucceeds.","ref":"AWS.ElasticLoadBalancingv2.html#create_target_group/3","title":"AWS.ElasticLoadBalancingv2.create_target_group/3","type":"function"},{"doc":"Creates a trust store.","ref":"AWS.ElasticLoadBalancingv2.html#create_trust_store/3","title":"AWS.ElasticLoadBalancingv2.create_trust_store/3","type":"function"},{"doc":"Deletes the specified listener.\n\nAlternatively, your listener is deleted when you delete the load balancer to\nwhich it is attached.","ref":"AWS.ElasticLoadBalancingv2.html#delete_listener/3","title":"AWS.ElasticLoadBalancingv2.delete_listener/3","type":"function"},{"doc":"Deletes the specified Application Load Balancer, Network Load Balancer, or\nGateway Load Balancer.\n\nDeleting a load balancer also deletes its listeners.\n\nYou can't delete a load balancer if deletion protection is enabled. If the load\nbalancer does not exist or has already been deleted, the call succeeds.\n\nDeleting a load balancer does not affect its registered targets. For example,\nyour EC2 instances continue to run and are still registered to their target\ngroups. If you no longer need these EC2 instances, you can stop or terminate\nthem.","ref":"AWS.ElasticLoadBalancingv2.html#delete_load_balancer/3","title":"AWS.ElasticLoadBalancingv2.delete_load_balancer/3","type":"function"},{"doc":"Deletes the specified rule.\n\nYou can't delete the default rule.","ref":"AWS.ElasticLoadBalancingv2.html#delete_rule/3","title":"AWS.ElasticLoadBalancingv2.delete_rule/3","type":"function"},{"doc":"Deletes the specified target group.\n\nYou can delete a target group if it is not referenced by any actions. Deleting a\ntarget group also deletes any associated health checks. Deleting a target group\ndoes not affect its registered targets. For example, any EC2 instances continue\nto run until you stop or terminate them.","ref":"AWS.ElasticLoadBalancingv2.html#delete_target_group/3","title":"AWS.ElasticLoadBalancingv2.delete_target_group/3","type":"function"},{"doc":"Deletes a trust store.","ref":"AWS.ElasticLoadBalancingv2.html#delete_trust_store/3","title":"AWS.ElasticLoadBalancingv2.delete_trust_store/3","type":"function"},{"doc":"Deregisters the specified targets from the specified target group.\n\nAfter the targets are deregistered, they no longer receive traffic from the load\nbalancer.\n\nThe load balancer stops sending requests to targets that are deregistering, but\nuses connection draining to ensure that in-flight traffic completes on the\nexisting connections. This deregistration delay is configured by default but can\nbe updated for each target group.\n\nFor more information, see the following:\n\n  * [ Deregistration delay](https://docs.aws.amazon.com/elasticloadbalancing/latest/application/load-balancer-target-groups.html#deregistration-delay)\nin the *Application Load Balancers User Guide*\n\n  * [ Deregistration delay](https://docs.aws.amazon.com/elasticloadbalancing/latest/network/load-balancer-target-groups.html#deregistration-delay)\nin the *Network Load Balancers User Guide*\n\n  * [ Deregistration delay](https://docs.aws.amazon.com/elasticloadbalancing/latest/gateway/target-groups.html#deregistration-delay)\nin the *Gateway Load Balancers User Guide*\n\nNote: If the specified target does not exist, the action returns successfully.","ref":"AWS.ElasticLoadBalancingv2.html#deregister_targets/3","title":"AWS.ElasticLoadBalancingv2.deregister_targets/3","type":"function"},{"doc":"Describes the current Elastic Load Balancing resource limits for your Amazon Web\nServices account.\n\nFor more information, see the following:\n\n  * [Quotas for your Application Load Balancers](https://docs.aws.amazon.com/elasticloadbalancing/latest/application/load-balancer-limits.html)\n\n  * [Quotas for your Network Load Balancers](https://docs.aws.amazon.com/elasticloadbalancing/latest/network/load-balancer-limits.html)\n\n  * [Quotas for your Gateway Load Balancers](https://docs.aws.amazon.com/elasticloadbalancing/latest/gateway/quotas-limits.html)","ref":"AWS.ElasticLoadBalancingv2.html#describe_account_limits/3","title":"AWS.ElasticLoadBalancingv2.describe_account_limits/3","type":"function"},{"doc":"Describes the default certificate and the certificate list for the specified\nHTTPS or TLS listener.\n\nIf the default certificate is also in the certificate list, it appears twice in\nthe results (once with `IsDefault` set to true and once with `IsDefault` set to\nfalse).\n\nFor more information, see [SSL certificates](https://docs.aws.amazon.com/elasticloadbalancing/latest/application/create-https-listener.html#https-listener-certificates)\nin the *Application Load Balancers Guide* or [Server certificates](https://docs.aws.amazon.com/elasticloadbalancing/latest/network/create-tls-listener.html#tls-listener-certificate)\nin the *Network Load Balancers Guide*.","ref":"AWS.ElasticLoadBalancingv2.html#describe_listener_certificates/3","title":"AWS.ElasticLoadBalancingv2.describe_listener_certificates/3","type":"function"},{"doc":"Describes the specified listeners or the listeners for the specified Application\nLoad Balancer, Network Load Balancer, or Gateway Load Balancer.\n\nYou must specify either a load balancer or one or more listeners.","ref":"AWS.ElasticLoadBalancingv2.html#describe_listeners/3","title":"AWS.ElasticLoadBalancingv2.describe_listeners/3","type":"function"},{"doc":"Describes the attributes for the specified Application Load Balancer, Network\nLoad Balancer, or Gateway Load Balancer.\n\nFor more information, see the following:\n\n  * [Load balancer attributes](https://docs.aws.amazon.com/elasticloadbalancing/latest/application/application-load-balancers.html#load-balancer-attributes)\nin the *Application Load Balancers Guide*\n\n  * [Load balancer attributes](https://docs.aws.amazon.com/elasticloadbalancing/latest/network/network-load-balancers.html#load-balancer-attributes)\nin the *Network Load Balancers Guide*\n\n  * [Load balancer attributes](https://docs.aws.amazon.com/elasticloadbalancing/latest/gateway/gateway-load-balancers.html#load-balancer-attributes)\nin the *Gateway Load Balancers Guide*","ref":"AWS.ElasticLoadBalancingv2.html#describe_load_balancer_attributes/3","title":"AWS.ElasticLoadBalancingv2.describe_load_balancer_attributes/3","type":"function"},{"doc":"Describes the specified load balancers or all of your load balancers.","ref":"AWS.ElasticLoadBalancingv2.html#describe_load_balancers/3","title":"AWS.ElasticLoadBalancingv2.describe_load_balancers/3","type":"function"},{"doc":"Describes the specified rules or the rules for the specified listener.\n\nYou must specify either a listener or one or more rules.","ref":"AWS.ElasticLoadBalancingv2.html#describe_rules/3","title":"AWS.ElasticLoadBalancingv2.describe_rules/3","type":"function"},{"doc":"Describes the specified policies or all policies used for SSL negotiation.\n\nFor more information, see [Security policies](https://docs.aws.amazon.com/elasticloadbalancing/latest/application/create-https-listener.html#describe-ssl-policies)\nin the *Application Load Balancers Guide* or [Security policies](https://docs.aws.amazon.com/elasticloadbalancing/latest/network/create-tls-listener.html#describe-ssl-policies)\nin the *Network Load Balancers Guide*.","ref":"AWS.ElasticLoadBalancingv2.html#describe_ssl_policies/3","title":"AWS.ElasticLoadBalancingv2.describe_ssl_policies/3","type":"function"},{"doc":"Describes the tags for the specified Elastic Load Balancing resources.\n\nYou can describe the tags for one or more Application Load Balancers, Network\nLoad Balancers, Gateway Load Balancers, target groups, listeners, or rules.","ref":"AWS.ElasticLoadBalancingv2.html#describe_tags/3","title":"AWS.ElasticLoadBalancingv2.describe_tags/3","type":"function"},{"doc":"Describes the attributes for the specified target group.\n\nFor more information, see the following:\n\n  * [Target group attributes](https://docs.aws.amazon.com/elasticloadbalancing/latest/application/load-balancer-target-groups.html#target-group-attributes)\nin the *Application Load Balancers Guide*\n\n  * [Target group attributes](https://docs.aws.amazon.com/elasticloadbalancing/latest/network/load-balancer-target-groups.html#target-group-attributes)\nin the *Network Load Balancers Guide*\n\n  * [Target group attributes](https://docs.aws.amazon.com/elasticloadbalancing/latest/gateway/target-groups.html#target-group-attributes)\nin the *Gateway Load Balancers Guide*","ref":"AWS.ElasticLoadBalancingv2.html#describe_target_group_attributes/3","title":"AWS.ElasticLoadBalancingv2.describe_target_group_attributes/3","type":"function"},{"doc":"Describes the specified target groups or all of your target groups.\n\nBy default, all target groups are described. Alternatively, you can specify one\nof the following to filter the results: the ARN of the load balancer, the names\nof one or more target groups, or the ARNs of one or more target groups.","ref":"AWS.ElasticLoadBalancingv2.html#describe_target_groups/3","title":"AWS.ElasticLoadBalancingv2.describe_target_groups/3","type":"function"},{"doc":"Describes the health of the specified targets or all of your targets.","ref":"AWS.ElasticLoadBalancingv2.html#describe_target_health/3","title":"AWS.ElasticLoadBalancingv2.describe_target_health/3","type":"function"},{"doc":"Describes all resources associated with the specified trust store.","ref":"AWS.ElasticLoadBalancingv2.html#describe_trust_store_associations/3","title":"AWS.ElasticLoadBalancingv2.describe_trust_store_associations/3","type":"function"},{"doc":"Describes the revocation files in use by the specified trust store arn, or\nrevocation ID.","ref":"AWS.ElasticLoadBalancingv2.html#describe_trust_store_revocations/3","title":"AWS.ElasticLoadBalancingv2.describe_trust_store_revocations/3","type":"function"},{"doc":"Describes all trust stores for a given account by trust store arn’s or name.","ref":"AWS.ElasticLoadBalancingv2.html#describe_trust_stores/3","title":"AWS.ElasticLoadBalancingv2.describe_trust_stores/3","type":"function"},{"doc":"Retrieves the ca certificate bundle.\n\nThis action returns a pre-signed S3 URI which is active for ten minutes.","ref":"AWS.ElasticLoadBalancingv2.html#get_trust_store_ca_certificates_bundle/3","title":"AWS.ElasticLoadBalancingv2.get_trust_store_ca_certificates_bundle/3","type":"function"},{"doc":"Retrieves the specified revocation file.\n\nThis action returns a pre-signed S3 URI which is active for ten minutes.","ref":"AWS.ElasticLoadBalancingv2.html#get_trust_store_revocation_content/3","title":"AWS.ElasticLoadBalancingv2.get_trust_store_revocation_content/3","type":"function"},{"doc":"","ref":"AWS.ElasticLoadBalancingv2.html#metadata/0","title":"AWS.ElasticLoadBalancingv2.metadata/0","type":"function"},{"doc":"Replaces the specified properties of the specified listener.\n\nAny properties that you do not specify remain unchanged.\n\nChanging the protocol from HTTPS to HTTP, or from TLS to TCP, removes the\nsecurity policy and default certificate properties. If you change the protocol\nfrom HTTP to HTTPS, or from TCP to TLS, you must add the security policy and\ndefault certificate properties.\n\nTo add an item to a list, remove an item from a list, or update an item in a\nlist, you must provide the entire list. For example, to add an action, specify a\nlist with the current actions plus the new action.","ref":"AWS.ElasticLoadBalancingv2.html#modify_listener/3","title":"AWS.ElasticLoadBalancingv2.modify_listener/3","type":"function"},{"doc":"Modifies the specified attributes of the specified Application Load Balancer,\nNetwork Load Balancer, or Gateway Load Balancer.\n\nIf any of the specified attributes can't be modified as requested, the call\nfails. Any existing attributes that you do not modify retain their current\nvalues.","ref":"AWS.ElasticLoadBalancingv2.html#modify_load_balancer_attributes/3","title":"AWS.ElasticLoadBalancingv2.modify_load_balancer_attributes/3","type":"function"},{"doc":"Replaces the specified properties of the specified rule.\n\nAny properties that you do not specify are unchanged.\n\nTo add an item to a list, remove an item from a list, or update an item in a\nlist, you must provide the entire list. For example, to add an action, specify a\nlist with the current actions plus the new action.","ref":"AWS.ElasticLoadBalancingv2.html#modify_rule/3","title":"AWS.ElasticLoadBalancingv2.modify_rule/3","type":"function"},{"doc":"Modifies the health checks used when evaluating the health state of the targets\nin the specified target group.","ref":"AWS.ElasticLoadBalancingv2.html#modify_target_group/3","title":"AWS.ElasticLoadBalancingv2.modify_target_group/3","type":"function"},{"doc":"Modifies the specified attributes of the specified target group.","ref":"AWS.ElasticLoadBalancingv2.html#modify_target_group_attributes/3","title":"AWS.ElasticLoadBalancingv2.modify_target_group_attributes/3","type":"function"},{"doc":"Update the ca certificate bundle for a given trust store.","ref":"AWS.ElasticLoadBalancingv2.html#modify_trust_store/3","title":"AWS.ElasticLoadBalancingv2.modify_trust_store/3","type":"function"},{"doc":"Registers the specified targets with the specified target group.\n\nIf the target is an EC2 instance, it must be in the `running` state when you\nregister it.\n\nBy default, the load balancer routes requests to registered targets using the\nprotocol and port for the target group. Alternatively, you can override the port\nfor a target when you register it. You can register each EC2 instance or IP\naddress with the same target group multiple times using different ports.\n\nWith a Network Load Balancer, you cannot register instances by instance ID if\nthey have the following instance types: C1, CC1, CC2, CG1, CG2, CR1, CS1, G1,\nG2, HI1, HS1, M1, M2, M3, and T1. You can register instances of these types by\nIP address.","ref":"AWS.ElasticLoadBalancingv2.html#register_targets/3","title":"AWS.ElasticLoadBalancingv2.register_targets/3","type":"function"},{"doc":"Removes the specified certificate from the certificate list for the specified\nHTTPS or TLS listener.","ref":"AWS.ElasticLoadBalancingv2.html#remove_listener_certificates/3","title":"AWS.ElasticLoadBalancingv2.remove_listener_certificates/3","type":"function"},{"doc":"Removes the specified tags from the specified Elastic Load Balancing resources.\n\nYou can remove the tags for one or more Application Load Balancers, Network Load\nBalancers, Gateway Load Balancers, target groups, listeners, or rules.","ref":"AWS.ElasticLoadBalancingv2.html#remove_tags/3","title":"AWS.ElasticLoadBalancingv2.remove_tags/3","type":"function"},{"doc":"Removes the specified revocation file from the specified trust store.","ref":"AWS.ElasticLoadBalancingv2.html#remove_trust_store_revocations/3","title":"AWS.ElasticLoadBalancingv2.remove_trust_store_revocations/3","type":"function"},{"doc":"Sets the type of IP addresses used by the subnets of the specified load\nbalancer.","ref":"AWS.ElasticLoadBalancingv2.html#set_ip_address_type/3","title":"AWS.ElasticLoadBalancingv2.set_ip_address_type/3","type":"function"},{"doc":"Sets the priorities of the specified rules.\n\nYou can reorder the rules as long as there are no priority conflicts in the new\norder. Any existing rules that you do not specify retain their current priority.","ref":"AWS.ElasticLoadBalancingv2.html#set_rule_priorities/3","title":"AWS.ElasticLoadBalancingv2.set_rule_priorities/3","type":"function"},{"doc":"Associates the specified security groups with the specified Application Load\nBalancer or Network Load Balancer.\n\nThe specified security groups override the previously associated security\ngroups.\n\nYou can't perform this operation on a Network Load Balancer unless you specified\na security group for the load balancer when you created it.\n\nYou can't associate a security group with a Gateway Load Balancer.","ref":"AWS.ElasticLoadBalancingv2.html#set_security_groups/3","title":"AWS.ElasticLoadBalancingv2.set_security_groups/3","type":"function"},{"doc":"Enables the Availability Zones for the specified public subnets for the\nspecified Application Load Balancer, Network Load Balancer or Gateway Load\nBalancer.\n\nThe specified subnets replace the previously enabled subnets.\n\nWhen you specify subnets for a Network Load Balancer, or Gateway Load Balancer\nyou must include all subnets that were enabled previously, with their existing\nconfigurations, plus any additional subnets.","ref":"AWS.ElasticLoadBalancingv2.html#set_subnets/3","title":"AWS.ElasticLoadBalancingv2.set_subnets/3","type":"function"},{"doc":"AWS Elastic Transcoder Service\n\nThe AWS Elastic Transcoder Service.","ref":"AWS.ElasticTranscoder.html","title":"AWS.ElasticTranscoder","type":"module"},{"doc":"The CancelJob operation cancels an unfinished job.\n\nYou can only cancel a job that has a status of `Submitted`. To prevent a\npipeline from starting to process a job while you're getting the job identifier,\nuse `UpdatePipelineStatus` to temporarily pause the pipeline.","ref":"AWS.ElasticTranscoder.html#cancel_job/4","title":"AWS.ElasticTranscoder.cancel_job/4","type":"function"},{"doc":"When you create a job, Elastic Transcoder returns JSON data that includes the\nvalues that you specified plus information about the job that is created.\n\nIf you have specified more than one output for your jobs (for example, one\noutput for the Kindle Fire and another output for the Apple iPhone 4s), you\ncurrently must use the Elastic Transcoder API to list the jobs (as opposed to\nthe AWS Console).","ref":"AWS.ElasticTranscoder.html#create_job/3","title":"AWS.ElasticTranscoder.create_job/3","type":"function"},{"doc":"The CreatePipeline operation creates a pipeline with settings that you specify.","ref":"AWS.ElasticTranscoder.html#create_pipeline/3","title":"AWS.ElasticTranscoder.create_pipeline/3","type":"function"},{"doc":"The CreatePreset operation creates a preset with settings that you specify.\n\nElastic Transcoder checks the CreatePreset settings to ensure that they meet\nElastic Transcoder requirements and to determine whether they comply with H.264\nstandards. If your settings are not valid for Elastic Transcoder, Elastic\nTranscoder returns an HTTP 400 response (`ValidationException`) and does not\ncreate the preset. If the settings are valid for Elastic Transcoder but aren't\nstrictly compliant with the H.264 standard, Elastic Transcoder creates the\npreset and returns a warning message in the response. This helps you determine\nwhether your settings comply with the H.264 standard while giving you greater\nflexibility with respect to the video that Elastic Transcoder produces.\n\nElastic Transcoder uses the H.264 video-compression format. For more\ninformation, see the International Telecommunication Union publication\n*Recommendation ITU-T H.264: Advanced video coding for generic audiovisual\nservices*.","ref":"AWS.ElasticTranscoder.html#create_preset/3","title":"AWS.ElasticTranscoder.create_preset/3","type":"function"},{"doc":"The DeletePipeline operation removes a pipeline.\n\nYou can only delete a pipeline that has never been used or that is not currently\nin use (doesn't contain any active jobs). If the pipeline is currently in use,\n`DeletePipeline` returns an error.","ref":"AWS.ElasticTranscoder.html#delete_pipeline/4","title":"AWS.ElasticTranscoder.delete_pipeline/4","type":"function"},{"doc":"The DeletePreset operation removes a preset that you've added in an AWS region.\n\nYou can't delete the default presets that are included with Elastic Transcoder.","ref":"AWS.ElasticTranscoder.html#delete_preset/4","title":"AWS.ElasticTranscoder.delete_preset/4","type":"function"},{"doc":"The ListJobsByPipeline operation gets a list of the jobs currently in a\npipeline.\n\nElastic Transcoder returns all of the jobs currently in the specified pipeline.\nThe response body contains one element for each job that satisfies the search\ncriteria.","ref":"AWS.ElasticTranscoder.html#list_jobs_by_pipeline/5","title":"AWS.ElasticTranscoder.list_jobs_by_pipeline/5","type":"function"},{"doc":"The ListJobsByStatus operation gets a list of jobs that have a specified status.\n\nThe response body contains one element for each job that satisfies the search\ncriteria.","ref":"AWS.ElasticTranscoder.html#list_jobs_by_status/5","title":"AWS.ElasticTranscoder.list_jobs_by_status/5","type":"function"},{"doc":"The ListPipelines operation gets a list of the pipelines associated with the\ncurrent AWS account.","ref":"AWS.ElasticTranscoder.html#list_pipelines/4","title":"AWS.ElasticTranscoder.list_pipelines/4","type":"function"},{"doc":"The ListPresets operation gets a list of the default presets included with\nElastic Transcoder and the presets that you've added in an AWS region.","ref":"AWS.ElasticTranscoder.html#list_presets/4","title":"AWS.ElasticTranscoder.list_presets/4","type":"function"},{"doc":"","ref":"AWS.ElasticTranscoder.html#metadata/0","title":"AWS.ElasticTranscoder.metadata/0","type":"function"},{"doc":"The ReadJob operation returns detailed information about a job.","ref":"AWS.ElasticTranscoder.html#read_job/3","title":"AWS.ElasticTranscoder.read_job/3","type":"function"},{"doc":"The ReadPipeline operation gets detailed information about a pipeline.","ref":"AWS.ElasticTranscoder.html#read_pipeline/3","title":"AWS.ElasticTranscoder.read_pipeline/3","type":"function"},{"doc":"The ReadPreset operation gets detailed information about a preset.","ref":"AWS.ElasticTranscoder.html#read_preset/3","title":"AWS.ElasticTranscoder.read_preset/3","type":"function"},{"doc":"The TestRole operation tests the IAM role used to create the pipeline.\n\nThe `TestRole` action lets you determine whether the IAM role you are using has\nsufficient permissions to let Elastic Transcoder perform tasks associated with\nthe transcoding process. The action attempts to assume the specified IAM role,\nchecks read access to the input and output buckets, and tries to send a test\nnotification to Amazon SNS topics that you specify.","ref":"AWS.ElasticTranscoder.html#test_role/3","title":"AWS.ElasticTranscoder.test_role/3","type":"function"},{"doc":"Use the `UpdatePipeline` operation to update settings for a pipeline.\n\nWhen you change pipeline settings, your changes take effect immediately. Jobs\nthat you have already submitted and that Elastic Transcoder has not started to\nprocess are affected in addition to jobs that you submit after you change\nsettings.","ref":"AWS.ElasticTranscoder.html#update_pipeline/4","title":"AWS.ElasticTranscoder.update_pipeline/4","type":"function"},{"doc":"With the UpdatePipelineNotifications operation, you can update Amazon Simple\nNotification Service (Amazon SNS) notifications for a pipeline.\n\nWhen you update notifications for a pipeline, Elastic Transcoder returns the\nvalues that you specified in the request.","ref":"AWS.ElasticTranscoder.html#update_pipeline_notifications/4","title":"AWS.ElasticTranscoder.update_pipeline_notifications/4","type":"function"},{"doc":"The UpdatePipelineStatus operation pauses or reactivates a pipeline, so that the\npipeline stops or restarts the processing of jobs.\n\nChanging the pipeline status is useful if you want to cancel one or more jobs.\nYou can't cancel jobs after Elastic Transcoder has started processing them; if\nyou pause the pipeline to which you submitted the jobs, you have more time to\nget the job IDs for the jobs that you want to cancel, and to send a `CancelJob`\nrequest.","ref":"AWS.ElasticTranscoder.html#update_pipeline_status/4","title":"AWS.ElasticTranscoder.update_pipeline_status/4","type":"function"},{"doc":"Amazon Elasticsearch Configuration Service\n\nUse the Amazon Elasticsearch Configuration API to create, configure, and manage\nElasticsearch domains.\n\nFor sample code that uses the Configuration API, see the [Amazon Elasticsearch Service Developer\nGuide](https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-configuration-samples.html).\nThe guide also contains [sample code for sending signed HTTP requests to the Elasticsearch\nAPIs](https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-request-signing.html).\n\nThe endpoint for configuration service requests is region-specific:\nes.*region*.amazonaws.com. For example, es.us-east-1.amazonaws.com. For a\ncurrent list of supported regions and endpoints, see [Regions and Endpoints](http://docs.aws.amazon.com/general/latest/gr/rande.html#elasticsearch-service-regions).","ref":"AWS.Elasticsearch.html","title":"AWS.Elasticsearch","type":"module"},{"doc":"Allows the destination domain owner to accept an inbound cross-cluster search\nconnection request.","ref":"AWS.Elasticsearch.html#accept_inbound_cross_cluster_search_connection/4","title":"AWS.Elasticsearch.accept_inbound_cross_cluster_search_connection/4","type":"function"},{"doc":"Attaches tags to an existing Elasticsearch domain.\n\nTags are a set of case-sensitive key value pairs. An Elasticsearch domain may\nhave up to 10 tags. See [ Tagging Amazon Elasticsearch Service Domains for more information.](http://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-managedomains.html#es-managedomains-awsresorcetagging)","ref":"AWS.Elasticsearch.html#add_tags/3","title":"AWS.Elasticsearch.add_tags/3","type":"function"},{"doc":"Associates a package with an Amazon ES domain.","ref":"AWS.Elasticsearch.html#associate_package/5","title":"AWS.Elasticsearch.associate_package/5","type":"function"},{"doc":"Provides access to an Amazon OpenSearch Service domain through the use of an\ninterface VPC endpoint.","ref":"AWS.Elasticsearch.html#authorize_vpc_endpoint_access/4","title":"AWS.Elasticsearch.authorize_vpc_endpoint_access/4","type":"function"},{"doc":"Cancels a pending configuration change on an Amazon OpenSearch Service domain.","ref":"AWS.Elasticsearch.html#cancel_domain_config_change/4","title":"AWS.Elasticsearch.cancel_domain_config_change/4","type":"function"},{"doc":"Cancels a scheduled service software update for an Amazon ES domain.\n\nYou can only perform this operation before the `AutomatedUpdateDate` and when\nthe `UpdateStatus` is in the `PENDING_UPDATE` state.","ref":"AWS.Elasticsearch.html#cancel_elasticsearch_service_software_update/3","title":"AWS.Elasticsearch.cancel_elasticsearch_service_software_update/3","type":"function"},{"doc":"Creates a new Elasticsearch domain.\n\nFor more information, see [Creating Elasticsearch Domains](http://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-createupdatedomains.html#es-createdomains)\nin the *Amazon Elasticsearch Service Developer Guide*.","ref":"AWS.Elasticsearch.html#create_elasticsearch_domain/3","title":"AWS.Elasticsearch.create_elasticsearch_domain/3","type":"function"},{"doc":"Creates a new cross-cluster search connection from a source domain to a\ndestination domain.","ref":"AWS.Elasticsearch.html#create_outbound_cross_cluster_search_connection/3","title":"AWS.Elasticsearch.create_outbound_cross_cluster_search_connection/3","type":"function"},{"doc":"Create a package for use with Amazon ES domains.","ref":"AWS.Elasticsearch.html#create_package/3","title":"AWS.Elasticsearch.create_package/3","type":"function"},{"doc":"Creates an Amazon OpenSearch Service-managed VPC endpoint.","ref":"AWS.Elasticsearch.html#create_vpc_endpoint/3","title":"AWS.Elasticsearch.create_vpc_endpoint/3","type":"function"},{"doc":"Permanently deletes the specified Elasticsearch domain and all of its data.\n\nOnce a domain is deleted, it cannot be recovered.","ref":"AWS.Elasticsearch.html#delete_elasticsearch_domain/4","title":"AWS.Elasticsearch.delete_elasticsearch_domain/4","type":"function"},{"doc":"Deletes the service-linked role that Elasticsearch Service uses to manage and\nmaintain VPC domains.\n\nRole deletion will fail if any existing VPC domains use the role. You must\ndelete any such Elasticsearch domains before deleting the role. See [Deleting Elasticsearch Service\nRole](http://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-vpc.html#es-enabling-slr)\nin *VPC Endpoints for Amazon Elasticsearch Service Domains*.","ref":"AWS.Elasticsearch.html#delete_elasticsearch_service_role/3","title":"AWS.Elasticsearch.delete_elasticsearch_service_role/3","type":"function"},{"doc":"Allows the destination domain owner to delete an existing inbound cross-cluster\nsearch connection.","ref":"AWS.Elasticsearch.html#delete_inbound_cross_cluster_search_connection/4","title":"AWS.Elasticsearch.delete_inbound_cross_cluster_search_connection/4","type":"function"},{"doc":"Allows the source domain owner to delete an existing outbound cross-cluster\nsearch connection.","ref":"AWS.Elasticsearch.html#delete_outbound_cross_cluster_search_connection/4","title":"AWS.Elasticsearch.delete_outbound_cross_cluster_search_connection/4","type":"function"},{"doc":"Delete the package.","ref":"AWS.Elasticsearch.html#delete_package/4","title":"AWS.Elasticsearch.delete_package/4","type":"function"},{"doc":"Deletes an Amazon OpenSearch Service-managed interface VPC endpoint.","ref":"AWS.Elasticsearch.html#delete_vpc_endpoint/4","title":"AWS.Elasticsearch.delete_vpc_endpoint/4","type":"function"},{"doc":"Provides scheduled Auto-Tune action details for the Elasticsearch domain, such\nas Auto-Tune action type, description, severity, and scheduled date.","ref":"AWS.Elasticsearch.html#describe_domain_auto_tunes/3","title":"AWS.Elasticsearch.describe_domain_auto_tunes/3","type":"function"},{"doc":"Returns information about the current blue/green deployment happening on a\ndomain, including a change ID, status, and progress stages.","ref":"AWS.Elasticsearch.html#describe_domain_change_progress/4","title":"AWS.Elasticsearch.describe_domain_change_progress/4","type":"function"},{"doc":"Returns domain configuration information about the specified Elasticsearch\ndomain, including the domain ID, domain endpoint, and domain ARN.","ref":"AWS.Elasticsearch.html#describe_elasticsearch_domain/3","title":"AWS.Elasticsearch.describe_elasticsearch_domain/3","type":"function"},{"doc":"Provides cluster configuration information about the specified Elasticsearch\ndomain, such as the state, creation date, update version, and update date for\ncluster options.","ref":"AWS.Elasticsearch.html#describe_elasticsearch_domain_config/3","title":"AWS.Elasticsearch.describe_elasticsearch_domain_config/3","type":"function"},{"doc":"Returns domain configuration information about the specified Elasticsearch\ndomains, including the domain ID, domain endpoint, and domain ARN.","ref":"AWS.Elasticsearch.html#describe_elasticsearch_domains/3","title":"AWS.Elasticsearch.describe_elasticsearch_domains/3","type":"function"},{"doc":"Describe Elasticsearch Limits for a given InstanceType and ElasticsearchVersion.\n\nWhen modifying existing Domain, specify the ` `DomainName` ` to know what Limits\nare supported for modifying.","ref":"AWS.Elasticsearch.html#describe_elasticsearch_instance_type_limits/5","title":"AWS.Elasticsearch.describe_elasticsearch_instance_type_limits/5","type":"function"},{"doc":"Lists all the inbound cross-cluster search connections for a destination domain.","ref":"AWS.Elasticsearch.html#describe_inbound_cross_cluster_search_connections/3","title":"AWS.Elasticsearch.describe_inbound_cross_cluster_search_connections/3","type":"function"},{"doc":"Lists all the outbound cross-cluster search connections for a source domain.","ref":"AWS.Elasticsearch.html#describe_outbound_cross_cluster_search_connections/3","title":"AWS.Elasticsearch.describe_outbound_cross_cluster_search_connections/3","type":"function"},{"doc":"Describes all packages available to Amazon ES.\n\nIncludes options for filtering, limiting the number of results, and pagination.","ref":"AWS.Elasticsearch.html#describe_packages/3","title":"AWS.Elasticsearch.describe_packages/3","type":"function"},{"doc":"Lists available reserved Elasticsearch instance offerings.","ref":"AWS.Elasticsearch.html#describe_reserved_elasticsearch_instance_offerings/5","title":"AWS.Elasticsearch.describe_reserved_elasticsearch_instance_offerings/5","type":"function"},{"doc":"Returns information about reserved Elasticsearch instances for this account.","ref":"AWS.Elasticsearch.html#describe_reserved_elasticsearch_instances/5","title":"AWS.Elasticsearch.describe_reserved_elasticsearch_instances/5","type":"function"},{"doc":"Describes one or more Amazon OpenSearch Service-managed VPC endpoints.","ref":"AWS.Elasticsearch.html#describe_vpc_endpoints/3","title":"AWS.Elasticsearch.describe_vpc_endpoints/3","type":"function"},{"doc":"Dissociates a package from the Amazon ES domain.","ref":"AWS.Elasticsearch.html#dissociate_package/5","title":"AWS.Elasticsearch.dissociate_package/5","type":"function"},{"doc":"Returns a list of upgrade compatible Elastisearch versions.\n\nYou can optionally pass a ` `DomainName` ` to get all upgrade compatible\nElasticsearch versions for that specific domain.","ref":"AWS.Elasticsearch.html#get_compatible_elasticsearch_versions/3","title":"AWS.Elasticsearch.get_compatible_elasticsearch_versions/3","type":"function"},{"doc":"Returns a list of versions of the package, along with their creation time and\ncommit message.","ref":"AWS.Elasticsearch.html#get_package_version_history/5","title":"AWS.Elasticsearch.get_package_version_history/5","type":"function"},{"doc":"Retrieves the complete history of the last 10 upgrades that were performed on\nthe domain.","ref":"AWS.Elasticsearch.html#get_upgrade_history/5","title":"AWS.Elasticsearch.get_upgrade_history/5","type":"function"},{"doc":"Retrieves the latest status of the last upgrade or upgrade eligibility check\nthat was performed on the domain.","ref":"AWS.Elasticsearch.html#get_upgrade_status/3","title":"AWS.Elasticsearch.get_upgrade_status/3","type":"function"},{"doc":"Returns the name of all Elasticsearch domains owned by the current user's\naccount.","ref":"AWS.Elasticsearch.html#list_domain_names/3","title":"AWS.Elasticsearch.list_domain_names/3","type":"function"},{"doc":"Lists all Amazon ES domains associated with the package.","ref":"AWS.Elasticsearch.html#list_domains_for_package/5","title":"AWS.Elasticsearch.list_domains_for_package/5","type":"function"},{"doc":"List all Elasticsearch instance types that are supported for given\nElasticsearchVersion","ref":"AWS.Elasticsearch.html#list_elasticsearch_instance_types/6","title":"AWS.Elasticsearch.list_elasticsearch_instance_types/6","type":"function"},{"doc":"List all supported Elasticsearch versions","ref":"AWS.Elasticsearch.html#list_elasticsearch_versions/4","title":"AWS.Elasticsearch.list_elasticsearch_versions/4","type":"function"},{"doc":"Lists all packages associated with the Amazon ES domain.","ref":"AWS.Elasticsearch.html#list_packages_for_domain/5","title":"AWS.Elasticsearch.list_packages_for_domain/5","type":"function"},{"doc":"Returns all tags for the given Elasticsearch domain.","ref":"AWS.Elasticsearch.html#list_tags/3","title":"AWS.Elasticsearch.list_tags/3","type":"function"},{"doc":"Retrieves information about each principal that is allowed to access a given\nAmazon OpenSearch Service domain through the use of an interface VPC endpoint.","ref":"AWS.Elasticsearch.html#list_vpc_endpoint_access/4","title":"AWS.Elasticsearch.list_vpc_endpoint_access/4","type":"function"},{"doc":"Retrieves all Amazon OpenSearch Service-managed VPC endpoints in the current\naccount and Region.","ref":"AWS.Elasticsearch.html#list_vpc_endpoints/3","title":"AWS.Elasticsearch.list_vpc_endpoints/3","type":"function"},{"doc":"Retrieves all Amazon OpenSearch Service-managed VPC endpoints associated with a\nparticular domain.","ref":"AWS.Elasticsearch.html#list_vpc_endpoints_for_domain/4","title":"AWS.Elasticsearch.list_vpc_endpoints_for_domain/4","type":"function"},{"doc":"","ref":"AWS.Elasticsearch.html#metadata/0","title":"AWS.Elasticsearch.metadata/0","type":"function"},{"doc":"Allows you to purchase reserved Elasticsearch instances.","ref":"AWS.Elasticsearch.html#purchase_reserved_elasticsearch_instance_offering/3","title":"AWS.Elasticsearch.purchase_reserved_elasticsearch_instance_offering/3","type":"function"},{"doc":"Allows the destination domain owner to reject an inbound cross-cluster search\nconnection request.","ref":"AWS.Elasticsearch.html#reject_inbound_cross_cluster_search_connection/4","title":"AWS.Elasticsearch.reject_inbound_cross_cluster_search_connection/4","type":"function"},{"doc":"Removes the specified set of tags from the specified Elasticsearch domain.","ref":"AWS.Elasticsearch.html#remove_tags/3","title":"AWS.Elasticsearch.remove_tags/3","type":"function"},{"doc":"Revokes access to an Amazon OpenSearch Service domain that was provided through\nan interface VPC endpoint.","ref":"AWS.Elasticsearch.html#revoke_vpc_endpoint_access/4","title":"AWS.Elasticsearch.revoke_vpc_endpoint_access/4","type":"function"},{"doc":"Schedules a service software update for an Amazon ES domain.","ref":"AWS.Elasticsearch.html#start_elasticsearch_service_software_update/3","title":"AWS.Elasticsearch.start_elasticsearch_service_software_update/3","type":"function"},{"doc":"Modifies the cluster configuration of the specified Elasticsearch domain,\nsetting as setting the instance type and the number of instances.","ref":"AWS.Elasticsearch.html#update_elasticsearch_domain_config/4","title":"AWS.Elasticsearch.update_elasticsearch_domain_config/4","type":"function"},{"doc":"Updates a package for use with Amazon ES domains.","ref":"AWS.Elasticsearch.html#update_package/3","title":"AWS.Elasticsearch.update_package/3","type":"function"},{"doc":"Modifies an Amazon OpenSearch Service-managed interface VPC endpoint.","ref":"AWS.Elasticsearch.html#update_vpc_endpoint/3","title":"AWS.Elasticsearch.update_vpc_endpoint/3","type":"function"},{"doc":"Allows you to either upgrade your domain or perform an Upgrade eligibility check\nto a compatible Elasticsearch version.","ref":"AWS.Elasticsearch.html#upgrade_elasticsearch_domain/3","title":"AWS.Elasticsearch.upgrade_elasticsearch_domain/3","type":"function"},{"doc":"Welcome to the *Entity Resolution API Reference*.\n\nEntity Resolution is an Amazon Web Services service that provides pre-configured\nentity resolution capabilities that enable developers and analysts at\nadvertising and marketing companies to build an accurate and complete view of\ntheir consumers.\n\nWith Entity Resolution, you can match source records containing consumer\nidentifiers, such as name, email address, and phone number. This is true even\nwhen these records have incomplete or conflicting identifiers. For example,\nEntity Resolution can effectively match a source record from a customer\nrelationship management (CRM) system with a source record from a marketing\nsystem containing campaign information.\n\nTo learn more about Entity Resolution concepts, procedures, and best practices,\nsee the [Entity Resolution User Guide](https://docs.aws.amazon.com/entityresolution/latest/userguide/what-is-service.html).","ref":"AWS.EntityResolution.html","title":"AWS.EntityResolution","type":"module"},{"doc":"Creates an `IdMappingWorkflow` object which stores the configuration of the data\nprocessing job to be run.\n\nEach `IdMappingWorkflow` must have a unique workflow name. To modify an existing\nworkflow, use the `UpdateIdMappingWorkflow` API.","ref":"AWS.EntityResolution.html#create_id_mapping_workflow/3","title":"AWS.EntityResolution.create_id_mapping_workflow/3","type":"function"},{"doc":"Creates a `MatchingWorkflow` object which stores the configuration of the data\nprocessing job to be run.\n\nIt is important to note that there should not be a pre-existing\n`MatchingWorkflow` with the same name. To modify an existing workflow, utilize\nthe `UpdateMatchingWorkflow` API.","ref":"AWS.EntityResolution.html#create_matching_workflow/3","title":"AWS.EntityResolution.create_matching_workflow/3","type":"function"},{"doc":"Creates a schema mapping, which defines the schema of the input customer records\ntable.\n\nThe `SchemaMapping` also provides Entity Resolution with some metadata about the\ntable, such as the attribute types of the columns and which columns to match on.","ref":"AWS.EntityResolution.html#create_schema_mapping/3","title":"AWS.EntityResolution.create_schema_mapping/3","type":"function"},{"doc":"Deletes the `IdMappingWorkflow` with a given name.\n\nThis operation will succeed even if a workflow with the given name does not\nexist.","ref":"AWS.EntityResolution.html#delete_id_mapping_workflow/4","title":"AWS.EntityResolution.delete_id_mapping_workflow/4","type":"function"},{"doc":"Deletes the `MatchingWorkflow` with a given name.\n\nThis operation will succeed even if a workflow with the given name does not\nexist.","ref":"AWS.EntityResolution.html#delete_matching_workflow/4","title":"AWS.EntityResolution.delete_matching_workflow/4","type":"function"},{"doc":"Deletes the `SchemaMapping` with a given name.\n\nThis operation will succeed even if a schema with the given name does not exist.\nThis operation will fail if there is a `MatchingWorkflow` object that references\nthe `SchemaMapping` in the workflow's `InputSourceConfig`.","ref":"AWS.EntityResolution.html#delete_schema_mapping/4","title":"AWS.EntityResolution.delete_schema_mapping/4","type":"function"},{"doc":"Gets the status, metrics, and errors (if there are any) that are associated with\na job.","ref":"AWS.EntityResolution.html#get_id_mapping_job/4","title":"AWS.EntityResolution.get_id_mapping_job/4","type":"function"},{"doc":"Returns the `IdMappingWorkflow` with a given name, if it exists.","ref":"AWS.EntityResolution.html#get_id_mapping_workflow/3","title":"AWS.EntityResolution.get_id_mapping_workflow/3","type":"function"},{"doc":"Returns the corresponding Match ID of a customer record if the record has been\nprocessed.","ref":"AWS.EntityResolution.html#get_match_id/4","title":"AWS.EntityResolution.get_match_id/4","type":"function"},{"doc":"Gets the status, metrics, and errors (if there are any) that are associated with\na job.","ref":"AWS.EntityResolution.html#get_matching_job/4","title":"AWS.EntityResolution.get_matching_job/4","type":"function"},{"doc":"Returns the `MatchingWorkflow` with a given name, if it exists.","ref":"AWS.EntityResolution.html#get_matching_workflow/3","title":"AWS.EntityResolution.get_matching_workflow/3","type":"function"},{"doc":"Returns the SchemaMapping of a given name.","ref":"AWS.EntityResolution.html#get_schema_mapping/3","title":"AWS.EntityResolution.get_schema_mapping/3","type":"function"},{"doc":"Lists all ID mapping jobs for a given workflow.","ref":"AWS.EntityResolution.html#list_id_mapping_jobs/5","title":"AWS.EntityResolution.list_id_mapping_jobs/5","type":"function"},{"doc":"Returns a list of all the `IdMappingWorkflows` that have been created for an\nAmazon Web Services account.","ref":"AWS.EntityResolution.html#list_id_mapping_workflows/4","title":"AWS.EntityResolution.list_id_mapping_workflows/4","type":"function"},{"doc":"Lists all jobs for a given workflow.","ref":"AWS.EntityResolution.html#list_matching_jobs/5","title":"AWS.EntityResolution.list_matching_jobs/5","type":"function"},{"doc":"Returns a list of all the `MatchingWorkflows` that have been created for an\nAmazon Web Services account.","ref":"AWS.EntityResolution.html#list_matching_workflows/4","title":"AWS.EntityResolution.list_matching_workflows/4","type":"function"},{"doc":"Returns a list of all the `ProviderServices` that are available in this Amazon\nWeb Services Region.","ref":"AWS.EntityResolution.html#list_provider_services/5","title":"AWS.EntityResolution.list_provider_services/5","type":"function"},{"doc":"Returns a list of all the `SchemaMappings` that have been created for an Amazon\nWeb Services account.","ref":"AWS.EntityResolution.html#list_schema_mappings/4","title":"AWS.EntityResolution.list_schema_mappings/4","type":"function"},{"doc":"Displays the tags associated with an Entity Resolution resource.\n\nIn Entity Resolution, `SchemaMapping`, and `MatchingWorkflow` can be tagged.","ref":"AWS.EntityResolution.html#list_tags_for_resource/3","title":"AWS.EntityResolution.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.EntityResolution.html#metadata/0","title":"AWS.EntityResolution.metadata/0","type":"function"},{"doc":"Starts the `IdMappingJob` of a workflow.\n\nThe workflow must have previously been created using the\n`CreateIdMappingWorkflow` endpoint.","ref":"AWS.EntityResolution.html#start_id_mapping_job/4","title":"AWS.EntityResolution.start_id_mapping_job/4","type":"function"},{"doc":"Starts the `MatchingJob` of a workflow.\n\nThe workflow must have previously been created using the\n`CreateMatchingWorkflow` endpoint.","ref":"AWS.EntityResolution.html#start_matching_job/4","title":"AWS.EntityResolution.start_matching_job/4","type":"function"},{"doc":"Assigns one or more tags (key-value pairs) to the specified Entity Resolution\nresource.\n\nTags can help you organize and categorize your resources. You can also use them\nto scope user permissions by granting a user permission to access or change only\nresources with certain tag values. In Entity Resolution, `SchemaMapping` and\n`MatchingWorkflow` can be tagged. Tags don't have any semantic meaning to Amazon\nWeb Services and are interpreted strictly as strings of characters. You can use\nthe `TagResource` action with a resource that already has tags. If you specify a\nnew tag key, this tag is appended to the list of tags associated with the\nresource. If you specify a tag key that is already associated with the resource,\nthe new tag value that you specify replaces the previous value for that tag.","ref":"AWS.EntityResolution.html#tag_resource/4","title":"AWS.EntityResolution.tag_resource/4","type":"function"},{"doc":"Removes one or more tags from the specified Entity Resolution resource.\n\nIn Entity Resolution, `SchemaMapping`, and `MatchingWorkflow` can be tagged.","ref":"AWS.EntityResolution.html#untag_resource/4","title":"AWS.EntityResolution.untag_resource/4","type":"function"},{"doc":"Updates an existing `IdMappingWorkflow`.\n\nThis method is identical to `CreateIdMappingWorkflow`, except it uses an HTTP\n`PUT` request instead of a `POST` request, and the `IdMappingWorkflow` must\nalready exist for the method to succeed.","ref":"AWS.EntityResolution.html#update_id_mapping_workflow/4","title":"AWS.EntityResolution.update_id_mapping_workflow/4","type":"function"},{"doc":"Updates an existing `MatchingWorkflow`.\n\nThis method is identical to `CreateMatchingWorkflow`, except it uses an HTTP\n`PUT` request instead of a `POST` request, and the `MatchingWorkflow` must\nalready exist for the method to succeed.","ref":"AWS.EntityResolution.html#update_matching_workflow/4","title":"AWS.EntityResolution.update_matching_workflow/4","type":"function"},{"doc":"Updates a schema mapping.\n\nA schema is immutable if it is being used by a workflow. Therefore, you can't\nupdate a schema mapping if it's associated with a workflow.","ref":"AWS.EntityResolution.html#update_schema_mapping/4","title":"AWS.EntityResolution.update_schema_mapping/4","type":"function"},{"doc":"Amazon EventBridge helps you to respond to state changes in your Amazon Web\nServices resources.\n\nWhen your resources change state, they automatically send events to an event\nstream. You can create rules that match selected events in the stream and route\nthem to targets to take action. You can also use rules to take action on a\npredetermined schedule. For example, you can configure rules to:\n\n  * Automatically invoke an Lambda function to update DNS entries when\nan event notifies you that Amazon EC2 instance enters the running state.\n\n  * Direct specific API records from CloudTrail to an Amazon Kinesis\ndata stream for detailed analysis of potential security or availability risks.\n\n  * Periodically invoke a built-in target to create a snapshot of an\nAmazon EBS volume.\n\nFor more information about the features of Amazon EventBridge, see the [Amazon EventBridge User\nGuide](https://docs.aws.amazon.com/eventbridge/latest/userguide).","ref":"AWS.EventBridge.html","title":"AWS.EventBridge","type":"module"},{"doc":"Activates a partner event source that has been deactivated.\n\nOnce activated, your matching event bus will start receiving events from the\nevent source.","ref":"AWS.EventBridge.html#activate_event_source/3","title":"AWS.EventBridge.activate_event_source/3","type":"function"},{"doc":"Cancels the specified replay.","ref":"AWS.EventBridge.html#cancel_replay/3","title":"AWS.EventBridge.cancel_replay/3","type":"function"},{"doc":"Creates an API destination, which is an HTTP invocation endpoint configured as a\ntarget for events.\n\nAPI destinations do not support private destinations, such as interface VPC\nendpoints.\n\nFor more information, see [API destinations](https://docs.aws.amazon.com/eventbridge/latest/userguide/eb-api-destinations.html)\nin the *EventBridge User Guide*.","ref":"AWS.EventBridge.html#create_api_destination/3","title":"AWS.EventBridge.create_api_destination/3","type":"function"},{"doc":"Creates an archive of events with the specified settings.\n\nWhen you create an archive, incoming events might not immediately start being\nsent to the archive. Allow a short period of time for changes to take effect. If\nyou do not specify a pattern to filter events sent to the archive, all events\nare sent to the archive except replayed events. Replayed events are not sent to\nan archive.","ref":"AWS.EventBridge.html#create_archive/3","title":"AWS.EventBridge.create_archive/3","type":"function"},{"doc":"Creates a connection.\n\nA connection defines the authorization type and credentials to use for\nauthorization with an API destination HTTP endpoint.","ref":"AWS.EventBridge.html#create_connection/3","title":"AWS.EventBridge.create_connection/3","type":"function"},{"doc":"Creates a global endpoint.\n\nGlobal endpoints improve your application's availability by making it\nregional-fault tolerant. To do this, you define a primary and secondary Region\nwith event buses in each Region. You also create a Amazon Route 53 health check\nthat will tell EventBridge to route events to the secondary Region when an\n\"unhealthy\" state is encountered and events will be routed back to the primary\nRegion when the health check reports a \"healthy\" state.","ref":"AWS.EventBridge.html#create_endpoint/3","title":"AWS.EventBridge.create_endpoint/3","type":"function"},{"doc":"Creates a new event bus within your account.\n\nThis can be a custom event bus which you can use to receive events from your\ncustom applications and services, or it can be a partner event bus which can be\nmatched to a partner event source.","ref":"AWS.EventBridge.html#create_event_bus/3","title":"AWS.EventBridge.create_event_bus/3","type":"function"},{"doc":"Called by an SaaS partner to create a partner event source.\n\nThis operation is not used by Amazon Web Services customers.\n\nEach partner event source can be used by one Amazon Web Services account to\ncreate a matching partner event bus in that Amazon Web Services account. A SaaS\npartner must create one partner event source for each Amazon Web Services\naccount that wants to receive those event types.\n\nA partner event source creates events based on resources within the SaaS\npartner's service or application.\n\nAn Amazon Web Services account that creates a partner event bus that matches the\npartner event source can use that event bus to receive events from the partner,\nand then process them using Amazon Web Services Events rules and targets.\n\nPartner event source names follow this format:\n\n` *partner_name*/*event_namespace*/*event_name* `\n\n  * *partner_name* is determined during partner registration, and\nidentifies the partner to Amazon Web Services customers.\n\n  * *event_namespace* is determined by the partner, and is a way for\nthe partner to categorize their events.\n\n  * *event_name* is determined by the partner, and should uniquely\nidentify an event-generating resource within the partner system.\n\nThe *event_name* must be unique across all Amazon Web Services customers. This\nis because the event source is a shared resource between the partner and\ncustomer accounts, and each partner event source unique in the partner account.\n\nThe combination of *event_namespace* and *event_name* should help Amazon Web\nServices customers decide whether to create an event bus to receive these\nevents.","ref":"AWS.EventBridge.html#create_partner_event_source/3","title":"AWS.EventBridge.create_partner_event_source/3","type":"function"},{"doc":"You can use this operation to temporarily stop receiving events from the\nspecified partner event source.\n\nThe matching event bus is not deleted.\n\nWhen you deactivate a partner event source, the source goes into PENDING state.\nIf it remains in PENDING state for more than two weeks, it is deleted.\n\nTo activate a deactivated partner event source, use\n[ActivateEventSource](https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_ActivateEventSource.html).","ref":"AWS.EventBridge.html#deactivate_event_source/3","title":"AWS.EventBridge.deactivate_event_source/3","type":"function"},{"doc":"Removes all authorization parameters from the connection.\n\nThis lets you remove the secret from the connection so you can reuse it without\nhaving to create a new connection.","ref":"AWS.EventBridge.html#deauthorize_connection/3","title":"AWS.EventBridge.deauthorize_connection/3","type":"function"},{"doc":"Deletes the specified API destination.","ref":"AWS.EventBridge.html#delete_api_destination/3","title":"AWS.EventBridge.delete_api_destination/3","type":"function"},{"doc":"Deletes the specified archive.","ref":"AWS.EventBridge.html#delete_archive/3","title":"AWS.EventBridge.delete_archive/3","type":"function"},{"doc":"Deletes a connection.","ref":"AWS.EventBridge.html#delete_connection/3","title":"AWS.EventBridge.delete_connection/3","type":"function"},{"doc":"Delete an existing global endpoint.\n\nFor more information about global endpoints, see [Making applications Regional-fault tolerant with global endpoints and event\nreplication](https://docs.aws.amazon.com/eventbridge/latest/userguide/eb-global-endpoints.html)\nin the *Amazon EventBridge User Guide*.","ref":"AWS.EventBridge.html#delete_endpoint/3","title":"AWS.EventBridge.delete_endpoint/3","type":"function"},{"doc":"Deletes the specified custom event bus or partner event bus.\n\nAll rules associated with this event bus need to be deleted. You can't delete\nyour account's default event bus.","ref":"AWS.EventBridge.html#delete_event_bus/3","title":"AWS.EventBridge.delete_event_bus/3","type":"function"},{"doc":"This operation is used by SaaS partners to delete a partner event source.\n\nThis operation is not used by Amazon Web Services customers.\n\nWhen you delete an event source, the status of the corresponding partner event\nbus in the Amazon Web Services customer account becomes DELETED.","ref":"AWS.EventBridge.html#delete_partner_event_source/3","title":"AWS.EventBridge.delete_partner_event_source/3","type":"function"},{"doc":"Deletes the specified rule.\n\nBefore you can delete the rule, you must remove all targets, using\n[RemoveTargets](https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_RemoveTargets.html).\n\nWhen you delete a rule, incoming events might continue to match to the deleted\nrule. Allow a short period of time for changes to take effect.\n\nIf you call delete rule multiple times for the same rule, all calls will\nsucceed. When you call delete rule for a non-existent custom eventbus,\n`ResourceNotFoundException` is returned.\n\nManaged rules are rules created and managed by another Amazon Web Services\nservice on your behalf. These rules are created by those other Amazon Web\nServices services to support functionality in those services. You can delete\nthese rules using the `Force` option, but you should do so only if you are sure\nthe other service is not still using that rule.","ref":"AWS.EventBridge.html#delete_rule/3","title":"AWS.EventBridge.delete_rule/3","type":"function"},{"doc":"Retrieves details about an API destination.","ref":"AWS.EventBridge.html#describe_api_destination/3","title":"AWS.EventBridge.describe_api_destination/3","type":"function"},{"doc":"Retrieves details about an archive.","ref":"AWS.EventBridge.html#describe_archive/3","title":"AWS.EventBridge.describe_archive/3","type":"function"},{"doc":"Retrieves details about a connection.","ref":"AWS.EventBridge.html#describe_connection/3","title":"AWS.EventBridge.describe_connection/3","type":"function"},{"doc":"Get the information about an existing global endpoint.\n\nFor more information about global endpoints, see [Making applications Regional-fault tolerant with global endpoints and event\nreplication](https://docs.aws.amazon.com/eventbridge/latest/userguide/eb-global-endpoints.html)\nin the *Amazon EventBridge User Guide*.","ref":"AWS.EventBridge.html#describe_endpoint/3","title":"AWS.EventBridge.describe_endpoint/3","type":"function"},{"doc":"Displays details about an event bus in your account.\n\nThis can include the external Amazon Web Services accounts that are permitted to\nwrite events to your default event bus, and the associated policy. For custom\nevent buses and partner event buses, it displays the name, ARN, policy, state,\nand creation time.\n\nTo enable your account to receive events from other accounts on its default\nevent bus, use\n[PutPermission](https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_PutPermission.html).  For more information about partner event buses, see\n[CreateEventBus](https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_CreateEventBus.html).","ref":"AWS.EventBridge.html#describe_event_bus/3","title":"AWS.EventBridge.describe_event_bus/3","type":"function"},{"doc":"This operation lists details about a partner event source that is shared with\nyour account.","ref":"AWS.EventBridge.html#describe_event_source/3","title":"AWS.EventBridge.describe_event_source/3","type":"function"},{"doc":"An SaaS partner can use this operation to list details about a partner event\nsource that they have created.\n\nAmazon Web Services customers do not use this operation. Instead, Amazon Web\nServices customers can use\n[DescribeEventSource](https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_DescribeEventSource.html)\nto see details about a partner event source that is shared with them.","ref":"AWS.EventBridge.html#describe_partner_event_source/3","title":"AWS.EventBridge.describe_partner_event_source/3","type":"function"},{"doc":"Retrieves details about a replay.\n\nUse `DescribeReplay` to determine the progress of a running replay. A replay\nprocesses events to replay based on the time in the event, and replays them\nusing 1 minute intervals. If you use `StartReplay` and specify an\n`EventStartTime` and an `EventEndTime` that covers a 20 minute time range, the\nevents are replayed from the first minute of that 20 minute range first. Then\nthe events from the second minute are replayed. You can use `DescribeReplay` to\ndetermine the progress of a replay. The value returned for\n`EventLastReplayedTime` indicates the time within the specified time range\nassociated with the last event replayed.","ref":"AWS.EventBridge.html#describe_replay/3","title":"AWS.EventBridge.describe_replay/3","type":"function"},{"doc":"Describes the specified rule.\n\nDescribeRule does not list the targets of a rule. To see the targets associated\nwith a rule, use\n[ListTargetsByRule](https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_ListTargetsByRule.html).","ref":"AWS.EventBridge.html#describe_rule/3","title":"AWS.EventBridge.describe_rule/3","type":"function"},{"doc":"Disables the specified rule.\n\nA disabled rule won't match any events, and won't self-trigger if it has a\nschedule expression.\n\nWhen you disable a rule, incoming events might continue to match to the disabled\nrule. Allow a short period of time for changes to take effect.","ref":"AWS.EventBridge.html#disable_rule/3","title":"AWS.EventBridge.disable_rule/3","type":"function"},{"doc":"Enables the specified rule.\n\nIf the rule does not exist, the operation fails.\n\nWhen you enable a rule, incoming events might not immediately start matching to\na newly enabled rule. Allow a short period of time for changes to take effect.","ref":"AWS.EventBridge.html#enable_rule/3","title":"AWS.EventBridge.enable_rule/3","type":"function"},{"doc":"Retrieves a list of API destination in the account in the current Region.","ref":"AWS.EventBridge.html#list_api_destinations/3","title":"AWS.EventBridge.list_api_destinations/3","type":"function"},{"doc":"Lists your archives.\n\nYou can either list all the archives or you can provide a prefix to match to the\narchive names. Filter parameters are exclusive.","ref":"AWS.EventBridge.html#list_archives/3","title":"AWS.EventBridge.list_archives/3","type":"function"},{"doc":"Retrieves a list of connections from the account.","ref":"AWS.EventBridge.html#list_connections/3","title":"AWS.EventBridge.list_connections/3","type":"function"},{"doc":"List the global endpoints associated with this account.\n\nFor more information about global endpoints, see [Making applications Regional-fault tolerant with global endpoints and event\nreplication](https://docs.aws.amazon.com/eventbridge/latest/userguide/eb-global-endpoints.html)\nin the *Amazon EventBridge User Guide*.","ref":"AWS.EventBridge.html#list_endpoints/3","title":"AWS.EventBridge.list_endpoints/3","type":"function"},{"doc":"Lists all the event buses in your account, including the default event bus,\ncustom event buses, and partner event buses.","ref":"AWS.EventBridge.html#list_event_buses/3","title":"AWS.EventBridge.list_event_buses/3","type":"function"},{"doc":"You can use this to see all the partner event sources that have been shared with\nyour Amazon Web Services account.\n\nFor more information about partner event sources, see\n[CreateEventBus](https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_CreateEventBus.html).","ref":"AWS.EventBridge.html#list_event_sources/3","title":"AWS.EventBridge.list_event_sources/3","type":"function"},{"doc":"An SaaS partner can use this operation to display the Amazon Web Services\naccount ID that a particular partner event source name is associated with.\n\nThis operation is not used by Amazon Web Services customers.","ref":"AWS.EventBridge.html#list_partner_event_source_accounts/3","title":"AWS.EventBridge.list_partner_event_source_accounts/3","type":"function"},{"doc":"An SaaS partner can use this operation to list all the partner event source\nnames that they have created.\n\nThis operation is not used by Amazon Web Services customers.","ref":"AWS.EventBridge.html#list_partner_event_sources/3","title":"AWS.EventBridge.list_partner_event_sources/3","type":"function"},{"doc":"Lists your replays.\n\nYou can either list all the replays or you can provide a prefix to match to the\nreplay names. Filter parameters are exclusive.","ref":"AWS.EventBridge.html#list_replays/3","title":"AWS.EventBridge.list_replays/3","type":"function"},{"doc":"Lists the rules for the specified target.\n\nYou can see which of the rules in Amazon EventBridge can invoke a specific\ntarget in your account.\n\nThe maximum number of results per page for requests is 100.","ref":"AWS.EventBridge.html#list_rule_names_by_target/3","title":"AWS.EventBridge.list_rule_names_by_target/3","type":"function"},{"doc":"Lists your Amazon EventBridge rules.\n\nYou can either list all the rules or you can provide a prefix to match to the\nrule names.\n\nThe maximum number of results per page for requests is 100.\n\nListRules does not list the targets of a rule. To see the targets associated\nwith a rule, use\n[ListTargetsByRule](https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_ListTargetsByRule.html).","ref":"AWS.EventBridge.html#list_rules/3","title":"AWS.EventBridge.list_rules/3","type":"function"},{"doc":"Displays the tags associated with an EventBridge resource.\n\nIn EventBridge, rules and event buses can be tagged.","ref":"AWS.EventBridge.html#list_tags_for_resource/3","title":"AWS.EventBridge.list_tags_for_resource/3","type":"function"},{"doc":"Lists the targets assigned to the specified rule.\n\nThe maximum number of results per page for requests is 100.","ref":"AWS.EventBridge.html#list_targets_by_rule/3","title":"AWS.EventBridge.list_targets_by_rule/3","type":"function"},{"doc":"","ref":"AWS.EventBridge.html#metadata/0","title":"AWS.EventBridge.metadata/0","type":"function"},{"doc":"Sends custom events to Amazon EventBridge so that they can be matched to rules.\n\nThe maximum size for a PutEvents event entry is 256 KB. Entry size is calculated\nincluding the event and any necessary characters and keys of the JSON\nrepresentation of the event. To learn more, see [Calculating PutEvents event entry\nsize](https://docs.aws.amazon.com/eventbridge/latest/userguide/eb-putevent-size.html)\nin the *Amazon EventBridge User Guide*\n\nPutEvents accepts the data in JSON format. For the JSON number (integer) data\ntype, the constraints are: a minimum value of -9,223,372,036,854,775,808 and a\nmaximum value of 9,223,372,036,854,775,807.\n\nPutEvents will only process nested JSON up to 1100 levels deep.","ref":"AWS.EventBridge.html#put_events/3","title":"AWS.EventBridge.put_events/3","type":"function"},{"doc":"This is used by SaaS partners to write events to a customer's partner event bus.\n\nAmazon Web Services customers do not use this operation.\n\nFor information on calculating event batch size, see [Calculating EventBridge PutEvents event entry\nsize](https://docs.aws.amazon.com/eventbridge/latest/userguide/eb-putevent-size.html)\nin the *EventBridge User Guide*.","ref":"AWS.EventBridge.html#put_partner_events/3","title":"AWS.EventBridge.put_partner_events/3","type":"function"},{"doc":"Running `PutPermission` permits the specified Amazon Web Services account or\nAmazon Web Services organization to put events to the specified *event bus*.\n\nAmazon EventBridge (CloudWatch Events) rules in your account are triggered by\nthese events arriving to an event bus in your account.\n\nFor another account to send events to your account, that external account must\nhave an EventBridge rule with your account's event bus as a target.\n\nTo enable multiple Amazon Web Services accounts to put events to your event bus,\nrun `PutPermission` once for each of these accounts. Or, if all the accounts are\nmembers of the same Amazon Web Services organization, you can run\n`PutPermission` once specifying `Principal` as \"*\" and specifying the Amazon Web\nServices organization ID in `Condition`, to grant permissions to all accounts in\nthat organization.\n\nIf you grant permissions using an organization, then accounts in that\norganization must specify a `RoleArn` with proper permissions when they use\n`PutTarget` to add your account's event bus as a target. For more information,\nsee [Sending and Receiving Events Between Amazon Web Services Accounts](https://docs.aws.amazon.com/eventbridge/latest/userguide/eventbridge-cross-account-event-delivery.html)\nin the *Amazon EventBridge User Guide*.\n\nThe permission policy on the event bus cannot exceed 10 KB in size.","ref":"AWS.EventBridge.html#put_permission/3","title":"AWS.EventBridge.put_permission/3","type":"function"},{"doc":"Creates or updates the specified rule.\n\nRules are enabled by default, or based on value of the state. You can disable a\nrule using\n[DisableRule](https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_DisableRule.html).  A single rule watches for events from a single event bus. Events generated by\nAmazon Web Services services go to your account's default event bus. Events\ngenerated by SaaS partner services or applications go to the matching partner\nevent bus. If you have custom applications or services, you can specify whether\ntheir events go to your default event bus or a custom event bus that you have\ncreated. For more information, see\n[CreateEventBus](https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_CreateEventBus.html).\n\nIf you are updating an existing rule, the rule is replaced with what you specify\nin this `PutRule` command. If you omit arguments in `PutRule`, the old values\nfor those arguments are not kept. Instead, they are replaced with null values.\n\nWhen you create or update a rule, incoming events might not immediately start\nmatching to new or updated rules. Allow a short period of time for changes to\ntake effect.\n\nA rule must contain at least an EventPattern or ScheduleExpression. Rules with\nEventPatterns are triggered when a matching event is observed. Rules with\nScheduleExpressions self-trigger based on the given schedule. A rule can have\nboth an EventPattern and a ScheduleExpression, in which case the rule triggers\non matching events as well as on a schedule.\n\nWhen you initially create a rule, you can optionally assign one or more tags to\nthe rule. Tags can help you organize and categorize your resources. You can also\nuse them to scope user permissions, by granting a user permission to access or\nchange only rules with certain tag values. To use the `PutRule` operation and\nassign tags, you must have both the `events:PutRule` and `events:TagResource`\npermissions.\n\nIf you are updating an existing rule, any tags you specify in the `PutRule`\noperation are ignored. To update the tags of an existing rule, use\n[TagResource](https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_TagResource.html) and\n[UntagResource](https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_UntagResource.html).\n\nMost services in Amazon Web Services treat : or / as the same character in\nAmazon Resource Names (ARNs). However, EventBridge uses an exact match in event\npatterns and rules. Be sure to use the correct ARN characters when creating\nevent patterns so that they match the ARN syntax in the event you want to match.\n\nIn EventBridge, it is possible to create rules that lead to infinite loops,\nwhere a rule is fired repeatedly. For example, a rule might detect that ACLs\nhave changed on an S3 bucket, and trigger software to change them to the desired\nstate. If the rule is not written carefully, the subsequent change to the ACLs\nfires the rule again, creating an infinite loop.\n\nTo prevent this, write the rules so that the triggered actions do not re-fire\nthe same rule. For example, your rule could fire only if ACLs are found to be in\na bad state, instead of after any change.\n\nAn infinite loop can quickly cause higher than expected charges. We recommend\nthat you use budgeting, which alerts you when charges exceed your specified\nlimit. For more information, see [Managing Your Costs with Budgets](https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/budgets-managing-costs.html).","ref":"AWS.EventBridge.html#put_rule/3","title":"AWS.EventBridge.put_rule/3","type":"function"},{"doc":"Adds the specified targets to the specified rule, or updates the targets if they\nare already associated with the rule.\n\nTargets are the resources that are invoked when a rule is triggered.\n\nThe maximum number of entries per request is 10.\n\nEach rule can have up to five (5) targets associated with it at one time.\n\nFor a list of services you can configure as targets for events, see [EventBridge targets](https://docs.aws.amazon.com/eventbridge/latest/userguide/eb-targets.html)\nin the *Amazon EventBridge User Guide*.\n\nCreating rules with built-in targets is supported only in the Amazon Web\nServices Management Console. The built-in targets are:\n\n  * `Amazon EBS CreateSnapshot API call`\n\n  * `Amazon EC2 RebootInstances API call`\n\n  * `Amazon EC2 StopInstances API call`\n\n  * `Amazon EC2 TerminateInstances API call`\n\nFor some target types, `PutTargets` provides target-specific parameters. If the\ntarget is a Kinesis data stream, you can optionally specify which shard the\nevent goes to by using the `KinesisParameters` argument. To invoke a command on\nmultiple EC2 instances with one rule, you can use the `RunCommandParameters`\nfield.\n\nTo be able to make API calls against the resources that you own, Amazon\nEventBridge needs the appropriate permissions:\n\n  * For Lambda and Amazon SNS resources, EventBridge relies on\nresource-based policies.\n\n  * For EC2 instances, Kinesis Data Streams, Step Functions state\nmachines and API Gateway APIs, EventBridge relies on IAM roles that you specify\nin the `RoleARN` argument in `PutTargets`.\n\nFor more information, see [Authentication and Access Control](https://docs.aws.amazon.com/eventbridge/latest/userguide/auth-and-access-control-eventbridge.html)\nin the *Amazon EventBridge User Guide*.\n\nIf another Amazon Web Services account is in the same region and has granted you\npermission (using `PutPermission`), you can send events to that account. Set\nthat account's event bus as a target of the rules in your account. To send the\nmatched events to the other account, specify that account's event bus as the\n`Arn` value when you run `PutTargets`. If your account sends events to another\naccount, your account is charged for each sent event. Each event sent to another\naccount is charged as a custom event. The account receiving the event is not\ncharged. For more information, see [Amazon EventBridge Pricing](http://aws.amazon.com/eventbridge/pricing/).\n\n`Input`, `InputPath`, and `InputTransformer` are not available with `PutTarget`\nif the target is an event bus of a different Amazon Web Services account.\n\nIf you are setting the event bus of another account as the target, and that\naccount granted permission to your account through an organization instead of\ndirectly by the account ID, then you must specify a `RoleArn` with proper\npermissions in the `Target` structure. For more information, see [Sending and Receiving Events Between Amazon Web Services\nAccounts](https://docs.aws.amazon.com/eventbridge/latest/userguide/eventbridge-cross-account-event-delivery.html)\nin the *Amazon EventBridge User Guide*.\n\nIf you have an IAM role on a cross-account event bus target, a `PutTargets` call\nwithout a role on the same target (same `Id` and `Arn`) will not remove the\nrole.\n\nFor more information about enabling cross-account events, see\n[PutPermission](https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_PutPermission.html).\n\n**Input**, **InputPath**, and **InputTransformer** are mutually exclusive and\noptional parameters of a target. When a rule is triggered due to a matched\nevent:\n\n  * If none of the following arguments are specified for a target,\nthen the entire event is passed to the target in JSON format (unless the target\nis Amazon EC2 Run Command or Amazon ECS task, in which case nothing from the\nevent is passed to the target).\n\n  * If **Input** is specified in the form of valid JSON, then the\nmatched event is overridden with this constant.\n\n  * If **InputPath** is specified in the form of JSONPath (for\nexample, `$.detail`), then only the part of the event specified in the path is\npassed to the target (for example, only the detail part of the event is passed).\n\n  * If **InputTransformer** is specified, then one or more specified\nJSONPaths are extracted from the event and used as values in a template that you\nspecify as the input to the target.\n\nWhen you specify `InputPath` or `InputTransformer`, you must use JSON dot\nnotation, not bracket notation.\n\nWhen you add targets to a rule and the associated rule triggers soon after, new\nor updated targets might not be immediately invoked. Allow a short period of\ntime for changes to take effect.\n\nThis action can partially fail if too many requests are made at the same time.\nIf that happens, `FailedEntryCount` is non-zero in the response and each entry\nin `FailedEntries` provides the ID of the failed target and the error code.","ref":"AWS.EventBridge.html#put_targets/3","title":"AWS.EventBridge.put_targets/3","type":"function"},{"doc":"Revokes the permission of another Amazon Web Services account to be able to put\nevents to the specified event bus.\n\nSpecify the account to revoke by the `StatementId` value that you associated\nwith the account when you granted it permission with `PutPermission`. You can\nfind the `StatementId` by using\n[DescribeEventBus](https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_DescribeEventBus.html).","ref":"AWS.EventBridge.html#remove_permission/3","title":"AWS.EventBridge.remove_permission/3","type":"function"},{"doc":"Removes the specified targets from the specified rule.\n\nWhen the rule is triggered, those targets are no longer be invoked.\n\nA successful execution of `RemoveTargets` doesn't guarantee all targets are\nremoved from the rule, it means that the target(s) listed in the request are\nremoved.\n\nWhen you remove a target, when the associated rule triggers, removed targets\nmight continue to be invoked. Allow a short period of time for changes to take\neffect.\n\nThis action can partially fail if too many requests are made at the same time.\nIf that happens, `FailedEntryCount` is non-zero in the response and each entry\nin `FailedEntries` provides the ID of the failed target and the error code.\n\nThe maximum number of entries per request is 10.","ref":"AWS.EventBridge.html#remove_targets/3","title":"AWS.EventBridge.remove_targets/3","type":"function"},{"doc":"Starts the specified replay.\n\nEvents are not necessarily replayed in the exact same order that they were added\nto the archive. A replay processes events to replay based on the time in the\nevent, and replays them using 1 minute intervals. If you specify an\n`EventStartTime` and an `EventEndTime` that covers a 20 minute time range, the\nevents are replayed from the first minute of that 20 minute range first. Then\nthe events from the second minute are replayed. You can use `DescribeReplay` to\ndetermine the progress of a replay. The value returned for\n`EventLastReplayedTime` indicates the time within the specified time range\nassociated with the last event replayed.","ref":"AWS.EventBridge.html#start_replay/3","title":"AWS.EventBridge.start_replay/3","type":"function"},{"doc":"Assigns one or more tags (key-value pairs) to the specified EventBridge\nresource.\n\nTags can help you organize and categorize your resources. You can also use them\nto scope user permissions by granting a user permission to access or change only\nresources with certain tag values. In EventBridge, rules and event buses can be\ntagged.\n\nTags don't have any semantic meaning to Amazon Web Services and are interpreted\nstrictly as strings of characters.\n\nYou can use the `TagResource` action with a resource that already has tags. If\nyou specify a new tag key, this tag is appended to the list of tags associated\nwith the resource. If you specify a tag key that is already associated with the\nresource, the new tag value that you specify replaces the previous value for\nthat tag.\n\nYou can associate as many as 50 tags with a resource.","ref":"AWS.EventBridge.html#tag_resource/3","title":"AWS.EventBridge.tag_resource/3","type":"function"},{"doc":"Tests whether the specified event pattern matches the provided event.\n\nMost services in Amazon Web Services treat : or / as the same character in\nAmazon Resource Names (ARNs). However, EventBridge uses an exact match in event\npatterns and rules. Be sure to use the correct ARN characters when creating\nevent patterns so that they match the ARN syntax in the event you want to match.","ref":"AWS.EventBridge.html#test_event_pattern/3","title":"AWS.EventBridge.test_event_pattern/3","type":"function"},{"doc":"Removes one or more tags from the specified EventBridge resource.\n\nIn Amazon EventBridge (CloudWatch Events), rules and event buses can be tagged.","ref":"AWS.EventBridge.html#untag_resource/3","title":"AWS.EventBridge.untag_resource/3","type":"function"},{"doc":"Updates an API destination.","ref":"AWS.EventBridge.html#update_api_destination/3","title":"AWS.EventBridge.update_api_destination/3","type":"function"},{"doc":"Updates the specified archive.","ref":"AWS.EventBridge.html#update_archive/3","title":"AWS.EventBridge.update_archive/3","type":"function"},{"doc":"Updates settings for a connection.","ref":"AWS.EventBridge.html#update_connection/3","title":"AWS.EventBridge.update_connection/3","type":"function"},{"doc":"Update an existing endpoint.\n\nFor more information about global endpoints, see [Making applications Regional-fault tolerant with global endpoints and event\nreplication](https://docs.aws.amazon.com/eventbridge/latest/userguide/eb-global-endpoints.html)\nin the *Amazon EventBridge User Guide*.","ref":"AWS.EventBridge.html#update_endpoint/3","title":"AWS.EventBridge.update_endpoint/3","type":"function"},{"doc":"You can use Amazon CloudWatch Evidently to safely validate new features by\nserving them to a specified percentage of your users while you roll out the\nfeature.\n\nYou can monitor the performance of the new feature to help you decide when to\nramp up traffic to your users. This helps you reduce risk and identify\nunintended consequences before you fully launch the feature.\n\nYou can also conduct A/B experiments to make feature design decisions based on\nevidence and data. An experiment can test as many as five variations at once.\nEvidently collects experiment data and analyzes it using statistical methods. It\nalso provides clear recommendations about which variations perform better. You\ncan test both user-facing features and backend features.","ref":"AWS.Evidently.html","title":"AWS.Evidently","type":"module"},{"doc":"This operation assigns feature variation to user sessions.\n\nFor each user session, you pass in an `entityID` that represents the user.\nEvidently then checks the evaluation rules and assigns the variation.\n\nThe first rules that are evaluated are the override rules. If the user's\n`entityID` matches an override rule, the user is served the variation specified\nby that rule.\n\nNext, if there is a launch of the feature, the user might be assigned to a\nvariation in the launch. The chance of this depends on the percentage of users\nthat are allocated to that launch. If the user is enrolled in the launch, the\nvariation they are served depends on the allocation of the various feature\nvariations used for the launch.\n\nIf the user is not assigned to a launch, and there is an ongoing experiment for\nthis feature, the user might be assigned to a variation in the experiment. The\nchance of this depends on the percentage of users that are allocated to that\nexperiment. If the user is enrolled in the experiment, the variation they are\nserved depends on the allocation of the various feature variations used for the\nexperiment.\n\nIf the user is not assigned to a launch or experiment, they are served the\ndefault variation.","ref":"AWS.Evidently.html#batch_evaluate_feature/4","title":"AWS.Evidently.batch_evaluate_feature/4","type":"function"},{"doc":"Creates an Evidently *experiment*.\n\nBefore you create an experiment, you must create the feature to use for the\nexperiment.\n\nAn experiment helps you make feature design decisions based on evidence and\ndata. An experiment can test as many as five variations at once. Evidently\ncollects experiment data and analyzes it by statistical methods, and provides\nclear recommendations about which variations perform better.\n\nYou can optionally specify a `segment` to have the experiment consider only\ncertain audience types in the experiment, such as using only user sessions from\na certain location or who use a certain internet browser.\n\nDon't use this operation to update an existing experiment. Instead, use\n[UpdateExperiment](https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_UpdateExperiment.html).","ref":"AWS.Evidently.html#create_experiment/4","title":"AWS.Evidently.create_experiment/4","type":"function"},{"doc":"Creates an Evidently *feature* that you want to launch or test.\n\nYou can define up to five variations of a feature, and use these variations in\nyour launches and experiments. A feature must be created in a project. For\ninformation about creating a project, see\n[CreateProject](https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_CreateProject.html).  Don't use this operation to update an existing feature. Instead, use\n[UpdateFeature](https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_UpdateFeature.html).","ref":"AWS.Evidently.html#create_feature/4","title":"AWS.Evidently.create_feature/4","type":"function"},{"doc":"Creates a *launch* of a given feature.\n\nBefore you create a launch, you must create the feature to use for the launch.\n\nYou can use a launch to safely validate new features by serving them to a\nspecified percentage of your users while you roll out the feature. You can\nmonitor the performance of the new feature to help you decide when to ramp up\ntraffic to more users. This helps you reduce risk and identify unintended\nconsequences before you fully launch the feature.\n\nDon't use this operation to update an existing launch. Instead, use\n[UpdateLaunch](https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_UpdateLaunch.html).","ref":"AWS.Evidently.html#create_launch/4","title":"AWS.Evidently.create_launch/4","type":"function"},{"doc":"Creates a project, which is the logical object in Evidently that can contain\nfeatures, launches, and experiments.\n\nUse projects to group similar features together.\n\nTo update an existing project, use\n[UpdateProject](https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_UpdateProject.html).","ref":"AWS.Evidently.html#create_project/3","title":"AWS.Evidently.create_project/3","type":"function"},{"doc":"Use this operation to define a *segment* of your audience.\n\nA segment is a portion of your audience that share one or more characteristics.\nExamples could be Chrome browser users, users in Europe, or Firefox browser\nusers in Europe who also fit other criteria that your application collects, such\nas age.\n\nUsing a segment in an experiment limits that experiment to evaluate only the\nusers who match the segment criteria. Using one or more segments in a launch\nallows you to define different traffic splits for the different audience\nsegments.\n\nFor more information about segment pattern syntax, see [ Segment rule pattern syntax](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch-Evidently-segments.html#CloudWatch-Evidently-segments-syntax.html).\n\nThe pattern that you define for a segment is matched against the value of\n`evaluationContext`, which is passed into Evidently in the\n[EvaluateFeature](https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_EvaluateFeature.html)\noperation, when Evidently assigns a feature variation to a user.","ref":"AWS.Evidently.html#create_segment/3","title":"AWS.Evidently.create_segment/3","type":"function"},{"doc":"Deletes an Evidently experiment.\n\nThe feature used for the experiment is not deleted.\n\nTo stop an experiment without deleting it, use\n[StopExperiment](https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_StopExperiment.html).","ref":"AWS.Evidently.html#delete_experiment/5","title":"AWS.Evidently.delete_experiment/5","type":"function"},{"doc":"Deletes an Evidently feature.","ref":"AWS.Evidently.html#delete_feature/5","title":"AWS.Evidently.delete_feature/5","type":"function"},{"doc":"Deletes an Evidently launch.\n\nThe feature used for the launch is not deleted.\n\nTo stop a launch without deleting it, use\n[StopLaunch](https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_StopLaunch.html).","ref":"AWS.Evidently.html#delete_launch/5","title":"AWS.Evidently.delete_launch/5","type":"function"},{"doc":"Deletes an Evidently project.\n\nBefore you can delete a project, you must delete all the features that the\nproject contains. To delete a feature, use\n[DeleteFeature](https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_DeleteFeature.html).","ref":"AWS.Evidently.html#delete_project/4","title":"AWS.Evidently.delete_project/4","type":"function"},{"doc":"Deletes a segment.\n\nYou can't delete a segment that is being used in a launch or experiment, even if\nthat launch or experiment is not currently running.","ref":"AWS.Evidently.html#delete_segment/4","title":"AWS.Evidently.delete_segment/4","type":"function"},{"doc":"This operation assigns a feature variation to one given user session.\n\nYou pass in an `entityID` that represents the user. Evidently then checks the\nevaluation rules and assigns the variation.\n\nThe first rules that are evaluated are the override rules. If the user's\n`entityID` matches an override rule, the user is served the variation specified\nby that rule.\n\nIf there is a current launch with this feature that uses segment overrides, and\nif the user session's `evaluationContext` matches a segment rule defined in a\nsegment override, the configuration in the segment overrides is used. For more\ninformation about segments, see\n[CreateSegment](https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_CreateSegment.html) and [Use segments to focus your\naudience](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch-Evidently-segments.html).\n\nIf there is a launch with no segment overrides, the user might be assigned to a\nvariation in the launch. The chance of this depends on the percentage of users\nthat are allocated to that launch. If the user is enrolled in the launch, the\nvariation they are served depends on the allocation of the various feature\nvariations used for the launch.\n\nIf the user is not assigned to a launch, and there is an ongoing experiment for\nthis feature, the user might be assigned to a variation in the experiment. The\nchance of this depends on the percentage of users that are allocated to that\nexperiment.\n\nIf the experiment uses a segment, then only user sessions with\n`evaluationContext` values that match the segment rule are used in the\nexperiment.\n\nIf the user is enrolled in the experiment, the variation they are served depends\non the allocation of the various feature variations used for the experiment.\n\nIf the user is not assigned to a launch or experiment, they are served the\ndefault variation.","ref":"AWS.Evidently.html#evaluate_feature/5","title":"AWS.Evidently.evaluate_feature/5","type":"function"},{"doc":"Returns the details about one experiment.\n\nYou must already know the experiment name. To retrieve a list of experiments in\nyour account, use\n[ListExperiments](https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_ListExperiments.html).","ref":"AWS.Evidently.html#get_experiment/4","title":"AWS.Evidently.get_experiment/4","type":"function"},{"doc":"Retrieves the results of a running or completed experiment.\n\nNo results are available until there have been 100 events for each variation and\nat least 10 minutes have passed since the start of the experiment. To increase\nthe statistical power, Evidently performs an additional offline p-value analysis\nat the end of the experiment. Offline p-value analysis can detect statistical\nsignificance in some cases where the anytime p-values used during the experiment\ndo not find statistical significance.\n\nExperiment results are available up to 63 days after the start of the\nexperiment. They are not available after that because of CloudWatch data\nretention policies.","ref":"AWS.Evidently.html#get_experiment_results/5","title":"AWS.Evidently.get_experiment_results/5","type":"function"},{"doc":"Returns the details about one feature.\n\nYou must already know the feature name. To retrieve a list of features in your\naccount, use\n[ListFeatures](https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_ListFeatures.html).","ref":"AWS.Evidently.html#get_feature/4","title":"AWS.Evidently.get_feature/4","type":"function"},{"doc":"Returns the details about one launch.\n\nYou must already know the launch name. To retrieve a list of launches in your\naccount, use\n[ListLaunches](https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_ListLaunches.html).","ref":"AWS.Evidently.html#get_launch/4","title":"AWS.Evidently.get_launch/4","type":"function"},{"doc":"Returns the details about one launch.\n\nYou must already know the project name. To retrieve a list of projects in your\naccount, use\n[ListProjects](https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_ListProjects.html).","ref":"AWS.Evidently.html#get_project/3","title":"AWS.Evidently.get_project/3","type":"function"},{"doc":"Returns information about the specified segment.\n\nSpecify the segment you want to view by specifying its ARN.","ref":"AWS.Evidently.html#get_segment/3","title":"AWS.Evidently.get_segment/3","type":"function"},{"doc":"Returns configuration details about all the experiments in the specified\nproject.","ref":"AWS.Evidently.html#list_experiments/6","title":"AWS.Evidently.list_experiments/6","type":"function"},{"doc":"Returns configuration details about all the features in the specified project.","ref":"AWS.Evidently.html#list_features/5","title":"AWS.Evidently.list_features/5","type":"function"},{"doc":"Returns configuration details about all the launches in the specified project.","ref":"AWS.Evidently.html#list_launches/6","title":"AWS.Evidently.list_launches/6","type":"function"},{"doc":"Returns configuration details about all the projects in the current Region in\nyour account.","ref":"AWS.Evidently.html#list_projects/4","title":"AWS.Evidently.list_projects/4","type":"function"},{"doc":"Use this operation to find which experiments or launches are using a specified\nsegment.","ref":"AWS.Evidently.html#list_segment_references/6","title":"AWS.Evidently.list_segment_references/6","type":"function"},{"doc":"Returns a list of audience segments that you have created in your account in\nthis Region.","ref":"AWS.Evidently.html#list_segments/4","title":"AWS.Evidently.list_segments/4","type":"function"},{"doc":"Displays the tags associated with an Evidently resource.","ref":"AWS.Evidently.html#list_tags_for_resource/3","title":"AWS.Evidently.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.Evidently.html#metadata/0","title":"AWS.Evidently.metadata/0","type":"function"},{"doc":"Sends performance events to Evidently.\n\nThese events can be used to evaluate a launch or an experiment.","ref":"AWS.Evidently.html#put_project_events/4","title":"AWS.Evidently.put_project_events/4","type":"function"},{"doc":"Starts an existing experiment.\n\nTo create an experiment, use\n[CreateExperiment](https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_CreateExperiment.html).","ref":"AWS.Evidently.html#start_experiment/5","title":"AWS.Evidently.start_experiment/5","type":"function"},{"doc":"Starts an existing launch.\n\nTo create a launch, use\n[CreateLaunch](https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_CreateLaunch.html).","ref":"AWS.Evidently.html#start_launch/5","title":"AWS.Evidently.start_launch/5","type":"function"},{"doc":"Stops an experiment that is currently running.\n\nIf you stop an experiment, you can't resume it or restart it.","ref":"AWS.Evidently.html#stop_experiment/5","title":"AWS.Evidently.stop_experiment/5","type":"function"},{"doc":"Stops a launch that is currently running.\n\nAfter you stop a launch, you will not be able to resume it or restart it. Also,\nit will not be evaluated as a rule for traffic allocation, and the traffic that\nwas allocated to the launch will instead be available to the feature's\nexperiment, if there is one. Otherwise, all traffic will be served the default\nvariation after the launch is stopped.","ref":"AWS.Evidently.html#stop_launch/5","title":"AWS.Evidently.stop_launch/5","type":"function"},{"doc":"Assigns one or more tags (key-value pairs) to the specified CloudWatch Evidently\nresource.\n\nProjects, features, launches, and experiments can be tagged.\n\nTags can help you organize and categorize your resources. You can also use them\nto scope user permissions by granting a user permission to access or change only\nresources with certain tag values.\n\nTags don't have any semantic meaning to Amazon Web Services and are interpreted\nstrictly as strings of characters.\n\nYou can use the `TagResource` action with a resource that already has tags. If\nyou specify a new tag key for the resource, this tag is appended to the list of\ntags associated with the alarm. If you specify a tag key that is already\nassociated with the resource, the new tag value that you specify replaces the\nprevious value for that tag.\n\nYou can associate as many as 50 tags with a resource.\n\nFor more information, see [Tagging Amazon Web Services resources](https://docs.aws.amazon.com/general/latest/gr/aws_tagging.html).","ref":"AWS.Evidently.html#tag_resource/4","title":"AWS.Evidently.tag_resource/4","type":"function"},{"doc":"Use this operation to test a rules pattern that you plan to use to create an\naudience segment.\n\nFor more information about segments, see\n[CreateSegment](https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_CreateSegment.html).","ref":"AWS.Evidently.html#test_segment_pattern/3","title":"AWS.Evidently.test_segment_pattern/3","type":"function"},{"doc":"Removes one or more tags from the specified resource.","ref":"AWS.Evidently.html#untag_resource/4","title":"AWS.Evidently.untag_resource/4","type":"function"},{"doc":"Updates an Evidently experiment.\n\nDon't use this operation to update an experiment's tag. Instead, use\n[TagResource](https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_TagResource.html).","ref":"AWS.Evidently.html#update_experiment/5","title":"AWS.Evidently.update_experiment/5","type":"function"},{"doc":"Updates an existing feature.\n\nYou can't use this operation to update the tags of an existing feature. Instead,\nuse\n[TagResource](https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_TagResource.html).","ref":"AWS.Evidently.html#update_feature/5","title":"AWS.Evidently.update_feature/5","type":"function"},{"doc":"Updates a launch of a given feature.\n\nDon't use this operation to update the tags of an existing launch. Instead, use\n[TagResource](https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_TagResource.html).","ref":"AWS.Evidently.html#update_launch/5","title":"AWS.Evidently.update_launch/5","type":"function"},{"doc":"Updates the description of an existing project.\n\nTo create a new project, use\n[CreateProject](https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_CreateProject.html).  Don't use this operation to update the data storage options of a project.\nInstead, use\n[UpdateProjectDataDelivery](https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_UpdateProjectDataDelivery.html).\n\nDon't use this operation to update the tags of a project. Instead, use\n[TagResource](https://docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_TagResource.html).","ref":"AWS.Evidently.html#update_project/4","title":"AWS.Evidently.update_project/4","type":"function"},{"doc":"Updates the data storage options for this project.\n\nIf you store evaluation events, you an keep them and analyze them on your own.\nIf you choose not to store evaluation events, Evidently deletes them after using\nthem to produce metrics and other experiment results that you can view.\n\nYou can't specify both `cloudWatchLogs` and `s3Destination` in the same\noperation.","ref":"AWS.Evidently.html#update_project_data_delivery/4","title":"AWS.Evidently.update_project_data_delivery/4","type":"function"},{"doc":"This is the *Firewall Manager API Reference*.\n\nThis guide is for developers who need detailed information about the Firewall\nManager API actions, data types, and errors. For detailed information about\nFirewall Manager features, see the [Firewall Manager Developer Guide](https://docs.aws.amazon.com/waf/latest/developerguide/fms-chapter.html).\n\nSome API actions require explicit resource permissions. For information, see the\ndeveloper guide topic [Service roles for Firewall Manager](https://docs.aws.amazon.com/waf/latest/developerguide/fms-security_iam_service-with-iam.html#fms-security_iam_service-with-iam-roles-service).","ref":"AWS.FMS.html","title":"AWS.FMS","type":"module"},{"doc":"Sets a Firewall Manager default administrator account.\n\nThe Firewall Manager default administrator account can manage third-party\nfirewalls and has full administrative scope that allows administration of all\npolicy types, accounts, organizational units, and Regions. This account must be\na member account of the organization in Organizations whose resources you want\nto protect.\n\nFor information about working with Firewall Manager administrator accounts, see\n[Managing Firewall Manager administrators](https://docs.aws.amazon.com/organizations/latest/userguide/fms-administrators.html)\nin the *Firewall Manager Developer Guide*.","ref":"AWS.FMS.html#associate_admin_account/3","title":"AWS.FMS.associate_admin_account/3","type":"function"},{"doc":"Sets the Firewall Manager policy administrator as a tenant administrator of a\nthird-party firewall service.\n\nA tenant is an instance of the third-party firewall service that's associated\nwith your Amazon Web Services customer account.","ref":"AWS.FMS.html#associate_third_party_firewall/3","title":"AWS.FMS.associate_third_party_firewall/3","type":"function"},{"doc":"Associate resources to a Firewall Manager resource set.","ref":"AWS.FMS.html#batch_associate_resource/3","title":"AWS.FMS.batch_associate_resource/3","type":"function"},{"doc":"Disassociates resources from a Firewall Manager resource set.","ref":"AWS.FMS.html#batch_disassociate_resource/3","title":"AWS.FMS.batch_disassociate_resource/3","type":"function"},{"doc":"Permanently deletes an Firewall Manager applications list.","ref":"AWS.FMS.html#delete_apps_list/3","title":"AWS.FMS.delete_apps_list/3","type":"function"},{"doc":"Deletes an Firewall Manager association with the IAM role and the Amazon Simple\nNotification Service (SNS) topic that is used to record Firewall Manager SNS\nlogs.","ref":"AWS.FMS.html#delete_notification_channel/3","title":"AWS.FMS.delete_notification_channel/3","type":"function"},{"doc":"Permanently deletes an Firewall Manager policy.","ref":"AWS.FMS.html#delete_policy/3","title":"AWS.FMS.delete_policy/3","type":"function"},{"doc":"Permanently deletes an Firewall Manager protocols list.","ref":"AWS.FMS.html#delete_protocols_list/3","title":"AWS.FMS.delete_protocols_list/3","type":"function"},{"doc":"Deletes the specified `ResourceSet`.","ref":"AWS.FMS.html#delete_resource_set/3","title":"AWS.FMS.delete_resource_set/3","type":"function"},{"doc":"Disassociates an Firewall Manager administrator account.\n\nTo set a different account as an Firewall Manager administrator, submit a\n`PutAdminAccount` request. To set an account as a default administrator account,\nyou must submit an `AssociateAdminAccount` request.\n\nDisassociation of the default administrator account follows the first in, last\nout principle. If you are the default administrator, all Firewall Manager\nadministrators within the organization must first disassociate their accounts\nbefore you can disassociate your account.","ref":"AWS.FMS.html#disassociate_admin_account/3","title":"AWS.FMS.disassociate_admin_account/3","type":"function"},{"doc":"Disassociates a Firewall Manager policy administrator from a third-party\nfirewall tenant.\n\nWhen you call `DisassociateThirdPartyFirewall`, the third-party firewall vendor\ndeletes all of the firewalls that are associated with the account.","ref":"AWS.FMS.html#disassociate_third_party_firewall/3","title":"AWS.FMS.disassociate_third_party_firewall/3","type":"function"},{"doc":"Returns the Organizations account that is associated with Firewall Manager as\nthe Firewall Manager default administrator.","ref":"AWS.FMS.html#get_admin_account/3","title":"AWS.FMS.get_admin_account/3","type":"function"},{"doc":"Returns information about the specified account's administrative scope.\n\nThe admistrative scope defines the resources that an Firewall Manager\nadministrator can manage.","ref":"AWS.FMS.html#get_admin_scope/3","title":"AWS.FMS.get_admin_scope/3","type":"function"},{"doc":"Returns information about the specified Firewall Manager applications list.","ref":"AWS.FMS.html#get_apps_list/3","title":"AWS.FMS.get_apps_list/3","type":"function"},{"doc":"Returns detailed compliance information about the specified member account.\n\nDetails include resources that are in and out of compliance with the specified\npolicy.\n\n  * Resources are considered noncompliant for WAF and Shield Advanced\npolicies if the specified policy has not been applied to them.\n\n  * Resources are considered noncompliant for security group policies\nif they are in scope of the policy, they violate one or more of the policy\nrules, and remediation is disabled or not possible.\n\n  * Resources are considered noncompliant for Network Firewall\npolicies if a firewall is missing in the VPC, if the firewall endpoint isn't set\nup in an expected Availability Zone and subnet, if a subnet created by the\nFirewall Manager doesn't have the expected route table, and for modifications to\na firewall policy that violate the Firewall Manager policy's rules.\n\n  * Resources are considered noncompliant for DNS Firewall policies if\na DNS Firewall rule group is missing from the rule group associations for the\nVPC.","ref":"AWS.FMS.html#get_compliance_detail/3","title":"AWS.FMS.get_compliance_detail/3","type":"function"},{"doc":"Information about the Amazon Simple Notification Service (SNS) topic that is\nused to record Firewall Manager SNS logs.","ref":"AWS.FMS.html#get_notification_channel/3","title":"AWS.FMS.get_notification_channel/3","type":"function"},{"doc":"Returns information about the specified Firewall Manager policy.","ref":"AWS.FMS.html#get_policy/3","title":"AWS.FMS.get_policy/3","type":"function"},{"doc":"If you created a Shield Advanced policy, returns policy-level attack summary\ninformation in the event of a potential DDoS attack.\n\nOther policy types are currently unsupported.","ref":"AWS.FMS.html#get_protection_status/3","title":"AWS.FMS.get_protection_status/3","type":"function"},{"doc":"Returns information about the specified Firewall Manager protocols list.","ref":"AWS.FMS.html#get_protocols_list/3","title":"AWS.FMS.get_protocols_list/3","type":"function"},{"doc":"Gets information about a specific resource set.","ref":"AWS.FMS.html#get_resource_set/3","title":"AWS.FMS.get_resource_set/3","type":"function"},{"doc":"The onboarding status of a Firewall Manager admin account to third-party\nfirewall vendor tenant.","ref":"AWS.FMS.html#get_third_party_firewall_association_status/3","title":"AWS.FMS.get_third_party_firewall_association_status/3","type":"function"},{"doc":"Retrieves violations for a resource based on the specified Firewall Manager\npolicy and Amazon Web Services account.","ref":"AWS.FMS.html#get_violation_details/3","title":"AWS.FMS.get_violation_details/3","type":"function"},{"doc":"Returns a `AdminAccounts` object that lists the Firewall Manager administrators\nwithin the organization that are onboarded to Firewall Manager by\n`AssociateAdminAccount`.\n\nThis operation can be called only from the organization's management account.","ref":"AWS.FMS.html#list_admin_accounts_for_organization/3","title":"AWS.FMS.list_admin_accounts_for_organization/3","type":"function"},{"doc":"Lists the accounts that are managing the specified Organizations member account.\n\nThis is useful for any member account so that they can view the accounts who are\nmanaging their account. This operation only returns the managing administrators\nthat have the requested account within their `AdminScope`.","ref":"AWS.FMS.html#list_admins_managing_account/3","title":"AWS.FMS.list_admins_managing_account/3","type":"function"},{"doc":"Returns an array of `AppsListDataSummary` objects.","ref":"AWS.FMS.html#list_apps_lists/3","title":"AWS.FMS.list_apps_lists/3","type":"function"},{"doc":"Returns an array of `PolicyComplianceStatus` objects.\n\nUse `PolicyComplianceStatus` to get a summary of which member accounts are\nprotected by the specified policy.","ref":"AWS.FMS.html#list_compliance_status/3","title":"AWS.FMS.list_compliance_status/3","type":"function"},{"doc":"Returns an array of resources in the organization's accounts that are available\nto be associated with a resource set.","ref":"AWS.FMS.html#list_discovered_resources/3","title":"AWS.FMS.list_discovered_resources/3","type":"function"},{"doc":"Returns a `MemberAccounts` object that lists the member accounts in the\nadministrator's Amazon Web Services organization.\n\nEither an Firewall Manager administrator or the organization's management\naccount can make this request.","ref":"AWS.FMS.html#list_member_accounts/3","title":"AWS.FMS.list_member_accounts/3","type":"function"},{"doc":"Returns an array of `PolicySummary` objects.","ref":"AWS.FMS.html#list_policies/3","title":"AWS.FMS.list_policies/3","type":"function"},{"doc":"Returns an array of `ProtocolsListDataSummary` objects.","ref":"AWS.FMS.html#list_protocols_lists/3","title":"AWS.FMS.list_protocols_lists/3","type":"function"},{"doc":"Returns an array of resources that are currently associated to a resource set.","ref":"AWS.FMS.html#list_resource_set_resources/3","title":"AWS.FMS.list_resource_set_resources/3","type":"function"},{"doc":"Returns an array of `ResourceSetSummary` objects.","ref":"AWS.FMS.html#list_resource_sets/3","title":"AWS.FMS.list_resource_sets/3","type":"function"},{"doc":"Retrieves the list of tags for the specified Amazon Web Services resource.","ref":"AWS.FMS.html#list_tags_for_resource/3","title":"AWS.FMS.list_tags_for_resource/3","type":"function"},{"doc":"Retrieves a list of all of the third-party firewall policies that are associated\nwith the third-party firewall administrator's account.","ref":"AWS.FMS.html#list_third_party_firewall_firewall_policies/3","title":"AWS.FMS.list_third_party_firewall_firewall_policies/3","type":"function"},{"doc":"","ref":"AWS.FMS.html#metadata/0","title":"AWS.FMS.metadata/0","type":"function"},{"doc":"Creates or updates an Firewall Manager administrator account.\n\nThe account must be a member of the organization that was onboarded to Firewall\nManager by `AssociateAdminAccount`. Only the organization's management account\ncan create an Firewall Manager administrator account. When you create an\nFirewall Manager administrator account, the service checks to see if the account\nis already a delegated administrator within Organizations. If the account isn't\na delegated administrator, Firewall Manager calls Organizations to delegate the\naccount within Organizations. For more information about administrator accounts\nwithin Organizations, see [Managing the Amazon Web Services Accounts in Your Organization](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_accounts.html).","ref":"AWS.FMS.html#put_admin_account/3","title":"AWS.FMS.put_admin_account/3","type":"function"},{"doc":"Creates an Firewall Manager applications list.","ref":"AWS.FMS.html#put_apps_list/3","title":"AWS.FMS.put_apps_list/3","type":"function"},{"doc":"Designates the IAM role and Amazon Simple Notification Service (SNS) topic that\nFirewall Manager uses to record SNS logs.\n\nTo perform this action outside of the console, you must first configure the SNS\ntopic's access policy to allow the `SnsRoleName` to publish SNS logs. If the\n`SnsRoleName` provided is a role other than the `AWSServiceRoleForFMS`\nservice-linked role, this role must have a trust relationship configured to\nallow the Firewall Manager service principal `fms.amazonaws.com` to assume this\nrole. For information about configuring an SNS access policy, see [Service roles for Firewall\nManager](https://docs.aws.amazon.com/waf/latest/developerguide/fms-security_iam_service-with-iam.html#fms-security_iam_service-with-iam-roles-service)\nin the *Firewall Manager Developer Guide*.","ref":"AWS.FMS.html#put_notification_channel/3","title":"AWS.FMS.put_notification_channel/3","type":"function"},{"doc":"Creates an Firewall Manager policy.\n\nA Firewall Manager policy is specific to the individual policy type. If you want\nto enforce multiple policy types across accounts, you can create multiple\npolicies. You can create more than one policy for each type.\n\nIf you add a new account to an organization that you created with Organizations,\nFirewall Manager automatically applies the policy to the resources in that\naccount that are within scope of the policy.\n\nFirewall Manager provides the following types of policies:\n\n  * **Shield Advanced policy** - This policy applies Shield Advanced\nprotection to specified accounts and resources.\n\n  * **Security Groups policy** - This type of policy gives you control\nover security groups that are in use throughout your organization in\nOrganizations and lets you enforce a baseline set of rules across your\norganization.\n\n  * **Network Firewall policy** - This policy applies Network Firewall\nprotection to your organization's VPCs.\n\n  * **DNS Firewall policy** - This policy applies Amazon Route 53\nResolver DNS Firewall protections to your organization's VPCs.\n\n  * **Third-party firewall policy** - This policy applies third-party\nfirewall protections. Third-party firewalls are available by subscription\nthrough the Amazon Web Services Marketplace console at [Amazon Web Services Marketplace](https://aws.amazon.com/marketplace).\n\n    * **Palo Alto Networks Cloud NGFW policy** - This policy\napplies Palo Alto Networks Cloud Next Generation Firewall (NGFW) protections and\nPalo Alto Networks Cloud NGFW rulestacks to your organization's VPCs.\n\n    * **Fortigate CNF policy** - This policy applies\nFortigate Cloud Native Firewall (CNF) protections. Fortigate CNF is a\ncloud-centered solution that blocks Zero-Day threats and secures cloud\ninfrastructures with industry-leading advanced threat prevention, smart web\napplication firewalls (WAF), and API protection.","ref":"AWS.FMS.html#put_policy/3","title":"AWS.FMS.put_policy/3","type":"function"},{"doc":"Creates an Firewall Manager protocols list.","ref":"AWS.FMS.html#put_protocols_list/3","title":"AWS.FMS.put_protocols_list/3","type":"function"},{"doc":"Creates the resource set.\n\nAn Firewall Manager resource set defines the resources to import into an\nFirewall Manager policy from another Amazon Web Services service.","ref":"AWS.FMS.html#put_resource_set/3","title":"AWS.FMS.put_resource_set/3","type":"function"},{"doc":"Adds one or more tags to an Amazon Web Services resource.","ref":"AWS.FMS.html#tag_resource/3","title":"AWS.FMS.tag_resource/3","type":"function"},{"doc":"Removes one or more tags from an Amazon Web Services resource.","ref":"AWS.FMS.html#untag_resource/3","title":"AWS.FMS.untag_resource/3","type":"function"},{"doc":"Amazon FSx is a fully managed service that makes it easy for storage and\napplication administrators to launch and use shared file storage.","ref":"AWS.FSx.html","title":"AWS.FSx","type":"module"},{"doc":"Use this action to associate one or more Domain Name Server (DNS) aliases with\nan existing Amazon FSx for Windows File Server file system.\n\nA file system can have a maximum of 50 DNS aliases associated with it at any one\ntime. If you try to associate a DNS alias that is already associated with the\nfile system, FSx takes no action on that alias in the request. For more\ninformation, see [Working with DNS Aliases](https://docs.aws.amazon.com/fsx/latest/WindowsGuide/managing-dns-aliases.html)\nand [Walkthrough 5: Using DNS aliases to access your file system](https://docs.aws.amazon.com/fsx/latest/WindowsGuide/walkthrough05-file-system-custom-CNAME.html),\nincluding additional steps you must take to be able to access your file system\nusing a DNS alias.\n\nThe system response shows the DNS aliases that Amazon FSx is attempting to\nassociate with the file system. Use the API operation to monitor the status of\nthe aliases Amazon FSx is associating with the file system.","ref":"AWS.FSx.html#associate_file_system_aliases/3","title":"AWS.FSx.associate_file_system_aliases/3","type":"function"},{"doc":"Cancels an existing Amazon FSx for Lustre data repository task if that task is\nin either the `PENDING` or `EXECUTING` state.\n\nWhen you cancel am export task, Amazon FSx does the following.\n\n  * Any files that FSx has already exported are not reverted.\n\n  * FSx continues to export any files that are in-flight when the\ncancel operation is received.\n\n  * FSx does not export any files that have not yet been exported.\n\nFor a release task, Amazon FSx will stop releasing files upon cancellation. Any\nfiles that have already been released will remain in the released state.","ref":"AWS.FSx.html#cancel_data_repository_task/3","title":"AWS.FSx.cancel_data_repository_task/3","type":"function"},{"doc":"Copies an existing backup within the same Amazon Web Services account to another\nAmazon Web Services Region (cross-Region copy) or within the same Amazon Web\nServices Region (in-Region copy).\n\nYou can have up to five backup copy requests in progress to a single destination\nRegion per account.\n\nYou can use cross-Region backup copies for cross-Region disaster recovery. You\ncan periodically take backups and copy them to another Region so that in the\nevent of a disaster in the primary Region, you can restore from backup and\nrecover availability quickly in the other Region. You can make cross-Region\ncopies only within your Amazon Web Services partition. A partition is a grouping\nof Regions. Amazon Web Services currently has three partitions: `aws` (Standard\nRegions), `aws-cn` (China Regions), and `aws-us-gov` (Amazon Web Services\nGovCloud [US] Regions).  You can also use backup copies to clone your file dataset to another Region or\nwithin the same Region.\n\nYou can use the `SourceRegion` parameter to specify the Amazon Web Services\nRegion from which the backup will be copied. For example, if you make the call\nfrom the `us-west-1` Region and want to copy a backup from the `us-east-2`\nRegion, you specify `us-east-2` in the `SourceRegion` parameter to make a\ncross-Region copy. If you don't specify a Region, the backup copy is created in\nthe same Region where the request is sent from (in-Region copy).\n\nFor more information about creating backup copies, see [ Copying\nbackups](https://docs.aws.amazon.com/fsx/latest/WindowsGuide/using-backups.html#copy-backups)\nin the *Amazon FSx for Windows User Guide*, [Copying backups](https://docs.aws.amazon.com/fsx/latest/LustreGuide/using-backups-fsx.html#copy-backups)\nin the *Amazon FSx for Lustre User Guide*, and [Copying backups](https://docs.aws.amazon.com/fsx/latest/OpenZFSGuide/using-backups.html#copy-backups)\nin the *Amazon FSx for OpenZFS User Guide*.","ref":"AWS.FSx.html#copy_backup/3","title":"AWS.FSx.copy_backup/3","type":"function"},{"doc":"Updates an existing volume by using a snapshot from another Amazon FSx for\nOpenZFS file system.\n\nFor more information, see [on-demand data replication](https://docs.aws.amazon.com/fsx/latest/OpenZFSGuide/on-demand-replication.html)\nin the Amazon FSx for OpenZFS User Guide.","ref":"AWS.FSx.html#copy_snapshot_and_update_volume/3","title":"AWS.FSx.copy_snapshot_and_update_volume/3","type":"function"},{"doc":"Creates a backup of an existing Amazon FSx for Windows File Server file system,\nAmazon FSx for Lustre file system, Amazon FSx for NetApp ONTAP volume, or Amazon\nFSx for OpenZFS file system.\n\nWe recommend creating regular backups so that you can restore a file system or\nvolume from a backup if an issue arises with the original file system or volume.\n\nFor Amazon FSx for Lustre file systems, you can create a backup only for file\nsystems that have the following configuration:\n\n  * A Persistent deployment type\n\n  * Are *not* linked to a data repository\n\nFor more information about backups, see the following:\n\n  * For Amazon FSx for Lustre, see [Working with FSx for Lustre backups](https://docs.aws.amazon.com/fsx/latest/LustreGuide/using-backups-fsx.html).\n\n  * For Amazon FSx for Windows, see [Working with FSx for Windows backups](https://docs.aws.amazon.com/fsx/latest/WindowsGuide/using-backups.html).\n\n  * For Amazon FSx for NetApp ONTAP, see [Working with FSx for NetApp ONTAP\nbackups](https://docs.aws.amazon.com/fsx/latest/ONTAPGuide/using-backups.html).\n\n  * For Amazon FSx for OpenZFS, see [Working with FSx for OpenZFS backups](https://docs.aws.amazon.com/fsx/latest/OpenZFSGuide/using-backups.html).\n\nIf a backup with the specified client request token exists and the parameters\nmatch, this operation returns the description of the existing backup. If a\nbackup with the specified client request token exists and the parameters don't\nmatch, this operation returns `IncompatibleParameterError`. If a backup with the\nspecified client request token doesn't exist, `CreateBackup` does the following:\n\n  * Creates a new Amazon FSx backup with an assigned ID, and an\ninitial lifecycle state of `CREATING`.\n\n  * Returns the description of the backup.\n\nBy using the idempotent operation, you can retry a `CreateBackup` operation\nwithout the risk of creating an extra backup. This approach can be useful when\nan initial call fails in a way that makes it unclear whether a backup was\ncreated. If you use the same client request token and the initial call created a\nbackup, the operation returns a successful result because all the parameters are\nthe same.\n\nThe `CreateBackup` operation returns while the backup's lifecycle state is still\n`CREATING`. You can check the backup creation status by calling the\n[DescribeBackups](https://docs.aws.amazon.com/fsx/latest/APIReference/API_DescribeBackups.html)\noperation, which returns the backup state along with other information.","ref":"AWS.FSx.html#create_backup/3","title":"AWS.FSx.create_backup/3","type":"function"},{"doc":"Creates an Amazon FSx for Lustre data repository association (DRA).\n\nA data repository association is a link between a directory on the file system\nand an Amazon S3 bucket or prefix. You can have a maximum of 8 data repository\nassociations on a file system. Data repository associations are supported on all\nFSx for Lustre 2.12 and 2.15 file systems, excluding `scratch_1` deployment\ntype.\n\nEach data repository association must have a unique Amazon FSx file system\ndirectory and a unique S3 bucket or prefix associated with it. You can configure\na data repository association for automatic import only, for automatic export\nonly, or for both. To learn more about linking a data repository to your file\nsystem, see [Linking your file system to an S3 bucket](https://docs.aws.amazon.com/fsx/latest/LustreGuide/create-dra-linked-data-repo.html).\n\n`CreateDataRepositoryAssociation` isn't supported on Amazon File Cache\nresources. To create a DRA on Amazon File Cache, use the `CreateFileCache`\noperation.","ref":"AWS.FSx.html#create_data_repository_association/3","title":"AWS.FSx.create_data_repository_association/3","type":"function"},{"doc":"Creates an Amazon FSx for Lustre data repository task.\n\nA `CreateDataRepositoryTask` operation will fail if a data repository is not\nlinked to the FSx file system.\n\nYou use import and export data repository tasks to perform bulk operations\nbetween your FSx for Lustre file system and its linked data repositories. An\nexample of a data repository task is exporting any data and metadata changes,\nincluding POSIX metadata, to files, directories, and symbolic links (symlinks)\nfrom your FSx file system to a linked data repository.\n\nYou use release data repository tasks to release data from your file system for\nfiles that are exported to S3. The metadata of released files remains on the\nfile system so users or applications can still access released files by reading\nthe files again, which will restore data from Amazon S3 to the FSx for Lustre\nfile system.\n\nTo learn more about data repository tasks, see [Data Repository Tasks](https://docs.aws.amazon.com/fsx/latest/LustreGuide/data-repository-tasks.html).\nTo learn more about linking a data repository to your file system, see [Linking your file system to an S3\nbucket](https://docs.aws.amazon.com/fsx/latest/LustreGuide/create-dra-linked-data-repo.html).","ref":"AWS.FSx.html#create_data_repository_task/3","title":"AWS.FSx.create_data_repository_task/3","type":"function"},{"doc":"Creates a new Amazon File Cache resource.\n\nYou can use this operation with a client request token in the request that\nAmazon File Cache uses to ensure idempotent creation. If a cache with the\nspecified client request token exists and the parameters match,\n`CreateFileCache` returns the description of the existing cache. If a cache with\nthe specified client request token exists and the parameters don't match, this\ncall returns `IncompatibleParameterError`. If a file cache with the specified\nclient request token doesn't exist, `CreateFileCache` does the following:\n\n  * Creates a new, empty Amazon File Cache resourcewith an assigned\nID, and an initial lifecycle state of `CREATING`.\n\n  * Returns the description of the cache in JSON format.\n\nThe `CreateFileCache` call returns while the cache's lifecycle state is still\n`CREATING`. You can check the cache creation status by calling the\n[DescribeFileCaches](https://docs.aws.amazon.com/fsx/latest/APIReference/API_DescribeFileCaches.html)\noperation, which returns the cache state along with other information.","ref":"AWS.FSx.html#create_file_cache/3","title":"AWS.FSx.create_file_cache/3","type":"function"},{"doc":"Creates a new, empty Amazon FSx file system.\n\nYou can create the following supported Amazon FSx file systems using the\n`CreateFileSystem` API operation:\n\n  * Amazon FSx for Lustre\n\n  * Amazon FSx for NetApp ONTAP\n\n  * Amazon FSx for OpenZFS\n\n  * Amazon FSx for Windows File Server\n\nThis operation requires a client request token in the request that Amazon FSx\nuses to ensure idempotent creation. This means that calling the operation\nmultiple times with the same client request token has no effect. By using the\nidempotent operation, you can retry a `CreateFileSystem` operation without the\nrisk of creating an extra file system. This approach can be useful when an\ninitial call fails in a way that makes it unclear whether a file system was\ncreated. Examples are if a transport level timeout occurred, or your connection\nwas reset. If you use the same client request token and the initial call created\na file system, the client receives success as long as the parameters are the\nsame.\n\nIf a file system with the specified client request token exists and the\nparameters match, `CreateFileSystem` returns the description of the existing\nfile system. If a file system with the specified client request token exists and\nthe parameters don't match, this call returns `IncompatibleParameterError`. If a\nfile system with the specified client request token doesn't exist,\n`CreateFileSystem` does the following:\n\n  * Creates a new, empty Amazon FSx file system with an assigned ID,\nand an initial lifecycle state of `CREATING`.\n\n  * Returns the description of the file system in JSON format.\n\nThe `CreateFileSystem` call returns while the file system's lifecycle state is\nstill `CREATING`. You can check the file-system creation status by calling the\n[DescribeFileSystems](https://docs.aws.amazon.com/fsx/latest/APIReference/API_DescribeFileSystems.html)\noperation, which returns the file system state along with other information.","ref":"AWS.FSx.html#create_file_system/3","title":"AWS.FSx.create_file_system/3","type":"function"},{"doc":"Creates a new Amazon FSx for Lustre, Amazon FSx for Windows File Server, or\nAmazon FSx for OpenZFS file system from an existing Amazon FSx backup.\n\nIf a file system with the specified client request token exists and the\nparameters match, this operation returns the description of the file system. If\na file system with the specified client request token exists but the parameters\ndon't match, this call returns `IncompatibleParameterError`. If a file system\nwith the specified client request token doesn't exist, this operation does the\nfollowing:\n\n  * Creates a new Amazon FSx file system from backup with an assigned\nID, and an initial lifecycle state of `CREATING`.\n\n  * Returns the description of the file system.\n\nParameters like the Active Directory, default share name, automatic backup, and\nbackup settings default to the parameters of the file system that was backed up,\nunless overridden. You can explicitly supply other settings.\n\nBy using the idempotent operation, you can retry a `CreateFileSystemFromBackup`\ncall without the risk of creating an extra file system. This approach can be\nuseful when an initial call fails in a way that makes it unclear whether a file\nsystem was created. Examples are if a transport level timeout occurred, or your\nconnection was reset. If you use the same client request token and the initial\ncall created a file system, the client receives a success message as long as the\nparameters are the same.\n\nThe `CreateFileSystemFromBackup` call returns while the file system's lifecycle\nstate is still `CREATING`. You can check the file-system creation status by\ncalling the [\nDescribeFileSystems](https://docs.aws.amazon.com/fsx/latest/APIReference/API_DescribeFileSystems.html)\noperation, which returns the file system state along with other information.","ref":"AWS.FSx.html#create_file_system_from_backup/3","title":"AWS.FSx.create_file_system_from_backup/3","type":"function"},{"doc":"Creates a snapshot of an existing Amazon FSx for OpenZFS volume.\n\nWith snapshots, you can easily undo file changes and compare file versions by\nrestoring the volume to a previous version.\n\nIf a snapshot with the specified client request token exists, and the parameters\nmatch, this operation returns the description of the existing snapshot. If a\nsnapshot with the specified client request token exists, and the parameters\ndon't match, this operation returns `IncompatibleParameterError`. If a snapshot\nwith the specified client request token doesn't exist, `CreateSnapshot` does the\nfollowing:\n\n  * Creates a new OpenZFS snapshot with an assigned ID, and an initial\nlifecycle state of `CREATING`.\n\n  * Returns the description of the snapshot.\n\nBy using the idempotent operation, you can retry a `CreateSnapshot` operation\nwithout the risk of creating an extra snapshot. This approach can be useful when\nan initial call fails in a way that makes it unclear whether a snapshot was\ncreated. If you use the same client request token and the initial call created a\nsnapshot, the operation returns a successful result because all the parameters\nare the same.\n\nThe `CreateSnapshot` operation returns while the snapshot's lifecycle state is\nstill `CREATING`. You can check the snapshot creation status by calling the\n[DescribeSnapshots](https://docs.aws.amazon.com/fsx/latest/APIReference/API_DescribeSnapshots.html)\noperation, which returns the snapshot state along with other information.","ref":"AWS.FSx.html#create_snapshot/3","title":"AWS.FSx.create_snapshot/3","type":"function"},{"doc":"Creates a storage virtual machine (SVM) for an Amazon FSx for ONTAP file system.","ref":"AWS.FSx.html#create_storage_virtual_machine/3","title":"AWS.FSx.create_storage_virtual_machine/3","type":"function"},{"doc":"Creates an FSx for ONTAP or Amazon FSx for OpenZFS storage volume.","ref":"AWS.FSx.html#create_volume/3","title":"AWS.FSx.create_volume/3","type":"function"},{"doc":"Creates a new Amazon FSx for NetApp ONTAP volume from an existing Amazon FSx\nvolume backup.","ref":"AWS.FSx.html#create_volume_from_backup/3","title":"AWS.FSx.create_volume_from_backup/3","type":"function"},{"doc":"Deletes an Amazon FSx backup.\n\nAfter deletion, the backup no longer exists, and its data is gone.\n\nThe `DeleteBackup` call returns instantly. The backup won't show up in later\n`DescribeBackups` calls.\n\nThe data in a deleted backup is also deleted and can't be recovered by any\nmeans.","ref":"AWS.FSx.html#delete_backup/3","title":"AWS.FSx.delete_backup/3","type":"function"},{"doc":"Deletes a data repository association on an Amazon FSx for Lustre file system.\n\nDeleting the data repository association unlinks the file system from the Amazon\nS3 bucket. When deleting a data repository association, you have the option of\ndeleting the data in the file system that corresponds to the data repository\nassociation. Data repository associations are supported on all FSx for Lustre\n2.12 and 2.15 file systems, excluding `scratch_1` deployment type.","ref":"AWS.FSx.html#delete_data_repository_association/3","title":"AWS.FSx.delete_data_repository_association/3","type":"function"},{"doc":"Deletes an Amazon File Cache resource.\n\nAfter deletion, the cache no longer exists, and its data is gone.\n\nThe `DeleteFileCache` operation returns while the cache has the `DELETING`\nstatus. You can check the cache deletion status by calling the\n[DescribeFileCaches](https://docs.aws.amazon.com/fsx/latest/APIReference/API_DescribeFileCaches.html)\noperation, which returns a list of caches in your account. If you pass the cache\nID for a deleted cache, the `DescribeFileCaches` operation returns a\n`FileCacheNotFound` error.\n\nThe data in a deleted cache is also deleted and can't be recovered by any means.","ref":"AWS.FSx.html#delete_file_cache/3","title":"AWS.FSx.delete_file_cache/3","type":"function"},{"doc":"Deletes a file system.\n\nAfter deletion, the file system no longer exists, and its data is gone. Any\nexisting automatic backups and snapshots are also deleted.\n\nTo delete an Amazon FSx for NetApp ONTAP file system, first delete all the\nvolumes and storage virtual machines (SVMs) on the file system. Then provide a\n`FileSystemId` value to the `DeleFileSystem` operation.\n\nBy default, when you delete an Amazon FSx for Windows File Server file system, a\nfinal backup is created upon deletion. This final backup isn't subject to the\nfile system's retention policy, and must be manually deleted.\n\nTo delete an Amazon FSx for Lustre file system, first\n[unmount](https://docs.aws.amazon.com/fsx/latest/LustreGuide/unmounting-fs.html) it from every connected Amazon EC2 instance, then provide a `FileSystemId` value\nto the `DeleFileSystem` operation. By default, Amazon FSx will not take a final\nbackup when the `DeleteFileSystem` operation is invoked. On file systems not\nlinked to an Amazon S3 bucket, set `SkipFinalBackup` to `false` to take a final\nbackup of the file system you are deleting. Backups cannot be enabled on\nS3-linked file systems. To ensure all of your data is written back to S3 before\ndeleting your file system, you can either monitor for the\n[AgeOfOldestQueuedMessage](https://docs.aws.amazon.com/fsx/latest/LustreGuide/monitoring-cloudwatch.html#auto-import-export-metrics)\nmetric to be zero (if using automatic export) or you can run an [export data repository\ntask](https://docs.aws.amazon.com/fsx/latest/LustreGuide/export-data-repo-task-dra.html).\nIf you have automatic export enabled and want to use an export data repository\ntask, you have to disable automatic export before executing the export data\nrepository task.\n\nThe `DeleteFileSystem` operation returns while the file system has the\n`DELETING` status. You can check the file system deletion status by calling the\n[DescribeFileSystems](https://docs.aws.amazon.com/fsx/latest/APIReference/API_DescribeFileSystems.html)\noperation, which returns a list of file systems in your account. If you pass the\nfile system ID for a deleted file system, the `DescribeFileSystems` operation\nreturns a `FileSystemNotFound` error.\n\nIf a data repository task is in a `PENDING` or `EXECUTING` state, deleting an\nAmazon FSx for Lustre file system will fail with an HTTP status code 400 (Bad\nRequest).\n\nThe data in a deleted file system is also deleted and can't be recovered by any\nmeans.","ref":"AWS.FSx.html#delete_file_system/3","title":"AWS.FSx.delete_file_system/3","type":"function"},{"doc":"Deletes an Amazon FSx for OpenZFS snapshot.\n\nAfter deletion, the snapshot no longer exists, and its data is gone. Deleting a\nsnapshot doesn't affect snapshots stored in a file system backup.\n\nThe `DeleteSnapshot` operation returns instantly. The snapshot appears with the\nlifecycle status of `DELETING` until the deletion is complete.","ref":"AWS.FSx.html#delete_snapshot/3","title":"AWS.FSx.delete_snapshot/3","type":"function"},{"doc":"Deletes an existing Amazon FSx for ONTAP storage virtual machine (SVM).\n\nPrior to deleting an SVM, you must delete all non-root volumes in the SVM,\notherwise the operation will fail.","ref":"AWS.FSx.html#delete_storage_virtual_machine/3","title":"AWS.FSx.delete_storage_virtual_machine/3","type":"function"},{"doc":"Deletes an Amazon FSx for NetApp ONTAP or Amazon FSx for OpenZFS volume.","ref":"AWS.FSx.html#delete_volume/3","title":"AWS.FSx.delete_volume/3","type":"function"},{"doc":"Returns the description of a specific Amazon FSx backup, if a `BackupIds` value\nis provided for that backup.\n\nOtherwise, it returns all backups owned by your Amazon Web Services account in\nthe Amazon Web Services Region of the endpoint that you're calling.\n\nWhen retrieving all backups, you can optionally specify the `MaxResults`\nparameter to limit the number of backups in a response. If more backups remain,\nAmazon FSx returns a `NextToken` value in the response. In this case, send a\nlater request with the `NextToken` request parameter set to the value of the\n`NextToken` value from the last response.\n\nThis operation is used in an iterative process to retrieve a list of your\nbackups. `DescribeBackups` is called first without a `NextToken` value. Then the\noperation continues to be called with the `NextToken` parameter set to the value\nof the last `NextToken` value until a response has no `NextToken` value.\n\nWhen using this operation, keep the following in mind:\n\n  * The operation might return fewer than the `MaxResults` value of\nbackup descriptions while still including a `NextToken` value.\n\n  * The order of the backups returned in the response of one\n`DescribeBackups` call and the order of the backups returned across the\nresponses of a multi-call iteration is unspecified.","ref":"AWS.FSx.html#describe_backups/3","title":"AWS.FSx.describe_backups/3","type":"function"},{"doc":"Returns the description of specific Amazon FSx for Lustre or Amazon File Cache\ndata repository associations, if one or more `AssociationIds` values are\nprovided in the request, or if filters are used in the request.\n\nData repository associations are supported on Amazon File Cache resources and\nall FSx for Lustre 2.12 and 2,15 file systems, excluding `scratch_1` deployment\ntype.\n\nYou can use filters to narrow the response to include just data repository\nassociations for specific file systems (use the `file-system-id` filter with the\nID of the file system) or caches (use the `file-cache-id` filter with the ID of\nthe cache), or data repository associations for a specific repository type (use\nthe `data-repository-type` filter with a value of `S3` or `NFS`). If you don't\nuse filters, the response returns all data repository associations owned by your\nAmazon Web Services account in the Amazon Web Services Region of the endpoint\nthat you're calling.\n\nWhen retrieving all data repository associations, you can paginate the response\nby using the optional `MaxResults` parameter to limit the number of data\nrepository associations returned in a response. If more data repository\nassociations remain, a `NextToken` value is returned in the response. In this\ncase, send a later request with the `NextToken` request parameter set to the\nvalue of `NextToken` from the last response.","ref":"AWS.FSx.html#describe_data_repository_associations/3","title":"AWS.FSx.describe_data_repository_associations/3","type":"function"},{"doc":"Returns the description of specific Amazon FSx for Lustre or Amazon File Cache\ndata repository tasks, if one or more `TaskIds` values are provided in the\nrequest, or if filters are used in the request.\n\nYou can use filters to narrow the response to include just tasks for specific\nfile systems or caches, or tasks in a specific lifecycle state. Otherwise, it\nreturns all data repository tasks owned by your Amazon Web Services account in\nthe Amazon Web Services Region of the endpoint that you're calling.\n\nWhen retrieving all tasks, you can paginate the response by using the optional\n`MaxResults` parameter to limit the number of tasks returned in a response. If\nmore tasks remain, a `NextToken` value is returned in the response. In this\ncase, send a later request with the `NextToken` request parameter set to the\nvalue of `NextToken` from the last response.","ref":"AWS.FSx.html#describe_data_repository_tasks/3","title":"AWS.FSx.describe_data_repository_tasks/3","type":"function"},{"doc":"Returns the description of a specific Amazon File Cache resource, if a\n`FileCacheIds` value is provided for that cache.\n\nOtherwise, it returns descriptions of all caches owned by your Amazon Web\nServices account in the Amazon Web Services Region of the endpoint that you're\ncalling.\n\nWhen retrieving all cache descriptions, you can optionally specify the\n`MaxResults` parameter to limit the number of descriptions in a response. If\nmore cache descriptions remain, the operation returns a `NextToken` value in the\nresponse. In this case, send a later request with the `NextToken` request\nparameter set to the value of `NextToken` from the last response.\n\nThis operation is used in an iterative process to retrieve a list of your cache\ndescriptions. `DescribeFileCaches` is called first without a `NextToken`value.\nThen the operation continues to be called with the `NextToken` parameter set to\nthe value of the last `NextToken` value until a response has no `NextToken`.\n\nWhen using this operation, keep the following in mind:\n\n  * The implementation might return fewer than `MaxResults` cache\ndescriptions while still including a `NextToken` value.\n\n  * The order of caches returned in the response of one\n`DescribeFileCaches` call and the order of caches returned across the responses\nof a multicall iteration is unspecified.","ref":"AWS.FSx.html#describe_file_caches/3","title":"AWS.FSx.describe_file_caches/3","type":"function"},{"doc":"Returns the DNS aliases that are associated with the specified Amazon FSx for\nWindows File Server file system.\n\nA history of all DNS aliases that have been associated with and disassociated\nfrom the file system is available in the list of `AdministrativeAction` provided\nin the `DescribeFileSystems` operation response.","ref":"AWS.FSx.html#describe_file_system_aliases/3","title":"AWS.FSx.describe_file_system_aliases/3","type":"function"},{"doc":"Returns the description of specific Amazon FSx file systems, if a\n`FileSystemIds` value is provided for that file system.\n\nOtherwise, it returns descriptions of all file systems owned by your Amazon Web\nServices account in the Amazon Web Services Region of the endpoint that you're\ncalling.\n\nWhen retrieving all file system descriptions, you can optionally specify the\n`MaxResults` parameter to limit the number of descriptions in a response. If\nmore file system descriptions remain, Amazon FSx returns a `NextToken` value in\nthe response. In this case, send a later request with the `NextToken` request\nparameter set to the value of `NextToken` from the last response.\n\nThis operation is used in an iterative process to retrieve a list of your file\nsystem descriptions. `DescribeFileSystems` is called first without a\n`NextToken`value. Then the operation continues to be called with the `NextToken`\nparameter set to the value of the last `NextToken` value until a response has no\n`NextToken`.\n\nWhen using this operation, keep the following in mind:\n\n  * The implementation might return fewer than `MaxResults` file\nsystem descriptions while still including a `NextToken` value.\n\n  * The order of file systems returned in the response of one\n`DescribeFileSystems` call and the order of file systems returned across the\nresponses of a multicall iteration is unspecified.","ref":"AWS.FSx.html#describe_file_systems/3","title":"AWS.FSx.describe_file_systems/3","type":"function"},{"doc":"Indicates whether participant accounts in your organization can create Amazon\nFSx for NetApp ONTAP Multi-AZ file systems in subnets that are shared by a\nvirtual private cloud (VPC) owner.\n\nFor more information, see the [Amazon FSx for NetApp ONTAP User Guide](https://docs.aws.amazon.com/fsx/latest/ONTAPGuide/maz-shared-vpc.html).","ref":"AWS.FSx.html#describe_shared_vpc_configuration/3","title":"AWS.FSx.describe_shared_vpc_configuration/3","type":"function"},{"doc":"Returns the description of specific Amazon FSx for OpenZFS snapshots, if a\n`SnapshotIds` value is provided.\n\nOtherwise, this operation returns all snapshots owned by your Amazon Web\nServices account in the Amazon Web Services Region of the endpoint that you're\ncalling.\n\nWhen retrieving all snapshots, you can optionally specify the `MaxResults`\nparameter to limit the number of snapshots in a response. If more backups\nremain, Amazon FSx returns a `NextToken` value in the response. In this case,\nsend a later request with the `NextToken` request parameter set to the value of\n`NextToken` from the last response.\n\nUse this operation in an iterative process to retrieve a list of your snapshots.\n`DescribeSnapshots` is called first without a `NextToken` value. Then the\noperation continues to be called with the `NextToken` parameter set to the value\nof the last `NextToken` value until a response has no `NextToken` value.\n\nWhen using this operation, keep the following in mind:\n\n  * The operation might return fewer than the `MaxResults` value of\nsnapshot descriptions while still including a `NextToken` value.\n\n  * The order of snapshots returned in the response of one\n`DescribeSnapshots` call and the order of backups returned across the responses\nof a multi-call iteration is unspecified.","ref":"AWS.FSx.html#describe_snapshots/3","title":"AWS.FSx.describe_snapshots/3","type":"function"},{"doc":"Describes one or more Amazon FSx for NetApp ONTAP storage virtual machines\n(SVMs).","ref":"AWS.FSx.html#describe_storage_virtual_machines/3","title":"AWS.FSx.describe_storage_virtual_machines/3","type":"function"},{"doc":"Describes one or more Amazon FSx for NetApp ONTAP or Amazon FSx for OpenZFS\nvolumes.","ref":"AWS.FSx.html#describe_volumes/3","title":"AWS.FSx.describe_volumes/3","type":"function"},{"doc":"Use this action to disassociate, or remove, one or more Domain Name Service\n(DNS) aliases from an Amazon FSx for Windows File Server file system.\n\nIf you attempt to disassociate a DNS alias that is not associated with the file\nsystem, Amazon FSx responds with an HTTP status code 400 (Bad Request). For more\ninformation, see [Working with DNS Aliases](https://docs.aws.amazon.com/fsx/latest/WindowsGuide/managing-dns-aliases.html).\n\nThe system generated response showing the DNS aliases that Amazon FSx is\nattempting to disassociate from the file system. Use the API operation to\nmonitor the status of the aliases Amazon FSx is disassociating with the file\nsystem.","ref":"AWS.FSx.html#disassociate_file_system_aliases/3","title":"AWS.FSx.disassociate_file_system_aliases/3","type":"function"},{"doc":"Lists tags for Amazon FSx resources.\n\nWhen retrieving all tags, you can optionally specify the `MaxResults` parameter\nto limit the number of tags in a response. If more tags remain, Amazon FSx\nreturns a `NextToken` value in the response. In this case, send a later request\nwith the `NextToken` request parameter set to the value of `NextToken` from the\nlast response.\n\nThis action is used in an iterative process to retrieve a list of your tags.\n`ListTagsForResource` is called first without a `NextToken`value. Then the\naction continues to be called with the `NextToken` parameter set to the value of\nthe last `NextToken` value until a response has no `NextToken`.\n\nWhen using this action, keep the following in mind:\n\n  * The implementation might return fewer than `MaxResults` file\nsystem descriptions while still including a `NextToken` value.\n\n  * The order of tags returned in the response of one\n`ListTagsForResource` call and the order of tags returned across the responses\nof a multi-call iteration is unspecified.","ref":"AWS.FSx.html#list_tags_for_resource/3","title":"AWS.FSx.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.FSx.html#metadata/0","title":"AWS.FSx.metadata/0","type":"function"},{"doc":"Releases the file system lock from an Amazon FSx for OpenZFS file system.","ref":"AWS.FSx.html#release_file_system_nfs_v3_locks/3","title":"AWS.FSx.release_file_system_nfs_v3_locks/3","type":"function"},{"doc":"Returns an Amazon FSx for OpenZFS volume to the state saved by the specified\nsnapshot.","ref":"AWS.FSx.html#restore_volume_from_snapshot/3","title":"AWS.FSx.restore_volume_from_snapshot/3","type":"function"},{"doc":"After performing steps to repair the Active Directory configuration of an FSx\nfor Windows File Server file system, use this action to initiate the process of\nAmazon FSx attempting to reconnect to the file system.","ref":"AWS.FSx.html#start_misconfigured_state_recovery/3","title":"AWS.FSx.start_misconfigured_state_recovery/3","type":"function"},{"doc":"Tags an Amazon FSx resource.","ref":"AWS.FSx.html#tag_resource/3","title":"AWS.FSx.tag_resource/3","type":"function"},{"doc":"This action removes a tag from an Amazon FSx resource.","ref":"AWS.FSx.html#untag_resource/3","title":"AWS.FSx.untag_resource/3","type":"function"},{"doc":"Updates the configuration of an existing data repository association on an\nAmazon FSx for Lustre file system.\n\nData repository associations are supported on all FSx for Lustre 2.12 and 2.15\nfile systems, excluding `scratch_1` deployment type.","ref":"AWS.FSx.html#update_data_repository_association/3","title":"AWS.FSx.update_data_repository_association/3","type":"function"},{"doc":"Updates the configuration of an existing Amazon File Cache resource.\n\nYou can update multiple properties in a single request.","ref":"AWS.FSx.html#update_file_cache/3","title":"AWS.FSx.update_file_cache/3","type":"function"},{"doc":"Use this operation to update the configuration of an existing Amazon FSx file\nsystem.\n\nYou can update multiple properties in a single request.\n\nFor FSx for Windows File Server file systems, you can update the following\nproperties:\n\n  * `AuditLogConfiguration`\n\n  * `AutomaticBackupRetentionDays`\n\n  * `DailyAutomaticBackupStartTime`\n\n  * `SelfManagedActiveDirectoryConfiguration`\n\n  * `StorageCapacity`\n\n  * `StorageType`\n\n  * `ThroughputCapacity`\n\n  * `DiskIopsConfiguration`\n\n  * `WeeklyMaintenanceStartTime`\n\nFor FSx for Lustre file systems, you can update the following properties:\n\n  * `AutoImportPolicy`\n\n  * `AutomaticBackupRetentionDays`\n\n  * `DailyAutomaticBackupStartTime`\n\n  * `DataCompressionType`\n\n  * `LogConfiguration`\n\n  * `LustreRootSquashConfiguration`\n\n  * `PerUnitStorageThroughput`\n\n  * `StorageCapacity`\n\n  * `WeeklyMaintenanceStartTime`\n\nFor FSx for ONTAP file systems, you can update the following properties:\n\n  * `AddRouteTableIds`\n\n  * `AutomaticBackupRetentionDays`\n\n  * `DailyAutomaticBackupStartTime`\n\n  * `DiskIopsConfiguration`\n\n  * `FsxAdminPassword`\n\n  * `HAPairs`\n\n  * `RemoveRouteTableIds`\n\n  * `StorageCapacity`\n\n  * `ThroughputCapacity`\n\n  * `ThroughputCapacityPerHAPair`\n\n  * `WeeklyMaintenanceStartTime`\n\nFor FSx for OpenZFS file systems, you can update the following properties:\n\n  * `AddRouteTableIds`\n\n  * `AutomaticBackupRetentionDays`\n\n  * `CopyTagsToBackups`\n\n  * `CopyTagsToVolumes`\n\n  * `DailyAutomaticBackupStartTime`\n\n  * `DiskIopsConfiguration`\n\n  * `RemoveRouteTableIds`\n\n  * `StorageCapacity`\n\n  * `ThroughputCapacity`\n\n  * `WeeklyMaintenanceStartTime`","ref":"AWS.FSx.html#update_file_system/3","title":"AWS.FSx.update_file_system/3","type":"function"},{"doc":"Configures whether participant accounts in your organization can create Amazon\nFSx for NetApp ONTAP Multi-AZ file systems in subnets that are shared by a\nvirtual private cloud (VPC) owner.\n\nFor more information, see the [Amazon FSx for NetApp ONTAP User Guide](https://docs.aws.amazon.com/fsx/latest/ONTAPGuide/maz-shared-vpc.html).\n\nWe strongly recommend that participant-created Multi-AZ file systems in the\nshared VPC are deleted before you disable this feature. Once the feature is\ndisabled, these file systems will enter a `MISCONFIGURED` state and behave like\nSingle-AZ file systems. For more information, see [Important considerations before disabling shared VPC support for Multi-AZ file\nsystems](https://docs.aws.amazon.com/fsx/latest/ONTAPGuide/maz-shared-vpc.html#disabling-maz-vpc-sharing).","ref":"AWS.FSx.html#update_shared_vpc_configuration/3","title":"AWS.FSx.update_shared_vpc_configuration/3","type":"function"},{"doc":"Updates the name of an Amazon FSx for OpenZFS snapshot.","ref":"AWS.FSx.html#update_snapshot/3","title":"AWS.FSx.update_snapshot/3","type":"function"},{"doc":"Updates an FSx for ONTAP storage virtual machine (SVM).","ref":"AWS.FSx.html#update_storage_virtual_machine/3","title":"AWS.FSx.update_storage_virtual_machine/3","type":"function"},{"doc":"Updates the configuration of an Amazon FSx for NetApp ONTAP or Amazon FSx for\nOpenZFS volume.","ref":"AWS.FSx.html#update_volume/3","title":"AWS.FSx.update_volume/3","type":"function"},{"doc":"The FinSpace management service provides the APIs for managing FinSpace\nenvironments.","ref":"AWS.Finspace.html","title":"AWS.Finspace","type":"module"},{"doc":"Create a new FinSpace environment.","ref":"AWS.Finspace.html#create_environment/3","title":"AWS.Finspace.create_environment/3","type":"function"},{"doc":"Creates a changeset for a kdb database.\n\nA changeset allows you to add and delete existing files by using an ordered list\nof change requests.","ref":"AWS.Finspace.html#create_kx_changeset/5","title":"AWS.Finspace.create_kx_changeset/5","type":"function"},{"doc":"Creates a new kdb cluster.","ref":"AWS.Finspace.html#create_kx_cluster/4","title":"AWS.Finspace.create_kx_cluster/4","type":"function"},{"doc":"Creates a new kdb database in the environment.","ref":"AWS.Finspace.html#create_kx_database/4","title":"AWS.Finspace.create_kx_database/4","type":"function"},{"doc":"Creates a snapshot of kdb database with tiered storage capabilities and a\npre-warmed cache, ready for mounting on kdb clusters.\n\nDataviews are only available for clusters running on a scaling group. They are\nnot supported on dedicated clusters.","ref":"AWS.Finspace.html#create_kx_dataview/5","title":"AWS.Finspace.create_kx_dataview/5","type":"function"},{"doc":"Creates a managed kdb environment for the account.","ref":"AWS.Finspace.html#create_kx_environment/3","title":"AWS.Finspace.create_kx_environment/3","type":"function"},{"doc":"Creates a new scaling group.","ref":"AWS.Finspace.html#create_kx_scaling_group/4","title":"AWS.Finspace.create_kx_scaling_group/4","type":"function"},{"doc":"Creates a user in FinSpace kdb environment with an associated IAM role.","ref":"AWS.Finspace.html#create_kx_user/4","title":"AWS.Finspace.create_kx_user/4","type":"function"},{"doc":"Creates a new volume with a specific amount of throughput and storage capacity.","ref":"AWS.Finspace.html#create_kx_volume/4","title":"AWS.Finspace.create_kx_volume/4","type":"function"},{"doc":"Delete an FinSpace environment.","ref":"AWS.Finspace.html#delete_environment/4","title":"AWS.Finspace.delete_environment/4","type":"function"},{"doc":"Deletes a kdb cluster.","ref":"AWS.Finspace.html#delete_kx_cluster/5","title":"AWS.Finspace.delete_kx_cluster/5","type":"function"},{"doc":"Deletes the specified database and all of its associated data.\n\nThis action is irreversible. You must copy any data out of the database before\ndeleting it if the data is to be retained.","ref":"AWS.Finspace.html#delete_kx_database/5","title":"AWS.Finspace.delete_kx_database/5","type":"function"},{"doc":"Deletes the specified dataview.\n\nBefore deleting a dataview, make sure that it is not in use by any cluster.","ref":"AWS.Finspace.html#delete_kx_dataview/6","title":"AWS.Finspace.delete_kx_dataview/6","type":"function"},{"doc":"Deletes the kdb environment.\n\nThis action is irreversible. Deleting a kdb environment will remove all the\nassociated data and any services running in it.","ref":"AWS.Finspace.html#delete_kx_environment/4","title":"AWS.Finspace.delete_kx_environment/4","type":"function"},{"doc":"Deletes the specified scaling group.\n\nThis action is irreversible. You cannot delete a scaling group until all the\nclusters running on it have been deleted.","ref":"AWS.Finspace.html#delete_kx_scaling_group/5","title":"AWS.Finspace.delete_kx_scaling_group/5","type":"function"},{"doc":"Deletes a user in the specified kdb environment.","ref":"AWS.Finspace.html#delete_kx_user/5","title":"AWS.Finspace.delete_kx_user/5","type":"function"},{"doc":"Deletes a volume.\n\nYou can only delete a volume if it's not attached to a cluster or a dataview.\nWhen a volume is deleted, any data on the volume is lost. This action is\nirreversible.","ref":"AWS.Finspace.html#delete_kx_volume/5","title":"AWS.Finspace.delete_kx_volume/5","type":"function"},{"doc":"Returns the FinSpace environment object.","ref":"AWS.Finspace.html#get_environment/3","title":"AWS.Finspace.get_environment/3","type":"function"},{"doc":"Returns information about a kdb changeset.","ref":"AWS.Finspace.html#get_kx_changeset/5","title":"AWS.Finspace.get_kx_changeset/5","type":"function"},{"doc":"Retrieves information about a kdb cluster.","ref":"AWS.Finspace.html#get_kx_cluster/4","title":"AWS.Finspace.get_kx_cluster/4","type":"function"},{"doc":"Retrieves a connection string for a user to connect to a kdb cluster.\n\nYou must call this API using the same role that you have defined while creating\na user.","ref":"AWS.Finspace.html#get_kx_connection_string/5","title":"AWS.Finspace.get_kx_connection_string/5","type":"function"},{"doc":"Returns database information for the specified environment ID.","ref":"AWS.Finspace.html#get_kx_database/4","title":"AWS.Finspace.get_kx_database/4","type":"function"},{"doc":"Retrieves details of the dataview.","ref":"AWS.Finspace.html#get_kx_dataview/5","title":"AWS.Finspace.get_kx_dataview/5","type":"function"},{"doc":"Retrieves all the information for the specified kdb environment.","ref":"AWS.Finspace.html#get_kx_environment/3","title":"AWS.Finspace.get_kx_environment/3","type":"function"},{"doc":"Retrieves details of a scaling group.","ref":"AWS.Finspace.html#get_kx_scaling_group/4","title":"AWS.Finspace.get_kx_scaling_group/4","type":"function"},{"doc":"Retrieves information about the specified kdb user.","ref":"AWS.Finspace.html#get_kx_user/4","title":"AWS.Finspace.get_kx_user/4","type":"function"},{"doc":"Retrieves the information about the volume.","ref":"AWS.Finspace.html#get_kx_volume/4","title":"AWS.Finspace.get_kx_volume/4","type":"function"},{"doc":"A list of all of your FinSpace environments.","ref":"AWS.Finspace.html#list_environments/4","title":"AWS.Finspace.list_environments/4","type":"function"},{"doc":"Returns a list of all the changesets for a database.","ref":"AWS.Finspace.html#list_kx_changesets/6","title":"AWS.Finspace.list_kx_changesets/6","type":"function"},{"doc":"Lists all the nodes in a kdb cluster.","ref":"AWS.Finspace.html#list_kx_cluster_nodes/6","title":"AWS.Finspace.list_kx_cluster_nodes/6","type":"function"},{"doc":"Returns a list of clusters.","ref":"AWS.Finspace.html#list_kx_clusters/6","title":"AWS.Finspace.list_kx_clusters/6","type":"function"},{"doc":"Returns a list of all the databases in the kdb environment.","ref":"AWS.Finspace.html#list_kx_databases/5","title":"AWS.Finspace.list_kx_databases/5","type":"function"},{"doc":"Returns a list of all the dataviews in the database.","ref":"AWS.Finspace.html#list_kx_dataviews/6","title":"AWS.Finspace.list_kx_dataviews/6","type":"function"},{"doc":"Returns a list of kdb environments created in an account.","ref":"AWS.Finspace.html#list_kx_environments/4","title":"AWS.Finspace.list_kx_environments/4","type":"function"},{"doc":"Returns a list of scaling groups in a kdb environment.","ref":"AWS.Finspace.html#list_kx_scaling_groups/5","title":"AWS.Finspace.list_kx_scaling_groups/5","type":"function"},{"doc":"Lists all the users in a kdb environment.","ref":"AWS.Finspace.html#list_kx_users/5","title":"AWS.Finspace.list_kx_users/5","type":"function"},{"doc":"Lists all the volumes in a kdb environment.","ref":"AWS.Finspace.html#list_kx_volumes/6","title":"AWS.Finspace.list_kx_volumes/6","type":"function"},{"doc":"A list of all tags for a resource.","ref":"AWS.Finspace.html#list_tags_for_resource/3","title":"AWS.Finspace.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.Finspace.html#metadata/0","title":"AWS.Finspace.metadata/0","type":"function"},{"doc":"Adds metadata tags to a FinSpace resource.","ref":"AWS.Finspace.html#tag_resource/4","title":"AWS.Finspace.tag_resource/4","type":"function"},{"doc":"Removes metadata tags from a FinSpace resource.","ref":"AWS.Finspace.html#untag_resource/4","title":"AWS.Finspace.untag_resource/4","type":"function"},{"doc":"Update your FinSpace environment.","ref":"AWS.Finspace.html#update_environment/4","title":"AWS.Finspace.update_environment/4","type":"function"},{"doc":"Allows you to update code configuration on a running cluster.\n\nBy using this API you can update the code, the initialization script path, and\nthe command line arguments for a specific cluster. The configuration that you\nwant to update will override any existing configurations on the cluster.","ref":"AWS.Finspace.html#update_kx_cluster_code_configuration/5","title":"AWS.Finspace.update_kx_cluster_code_configuration/5","type":"function"},{"doc":"Updates the databases mounted on a kdb cluster, which includes the `changesetId`\nand all the dbPaths to be cached.\n\nThis API does not allow you to change a database name or add a database if you\ncreated a cluster without one.\n\nUsing this API you can point a cluster to a different changeset and modify a\nlist of partitions being cached.","ref":"AWS.Finspace.html#update_kx_cluster_databases/5","title":"AWS.Finspace.update_kx_cluster_databases/5","type":"function"},{"doc":"Updates information for the given kdb database.","ref":"AWS.Finspace.html#update_kx_database/5","title":"AWS.Finspace.update_kx_database/5","type":"function"},{"doc":"Updates the specified dataview.\n\nThe dataviews get automatically updated when any new changesets are ingested.\nEach update of the dataview creates a new version, including changeset details\nand cache configurations","ref":"AWS.Finspace.html#update_kx_dataview/6","title":"AWS.Finspace.update_kx_dataview/6","type":"function"},{"doc":"Updates information for the given kdb environment.","ref":"AWS.Finspace.html#update_kx_environment/4","title":"AWS.Finspace.update_kx_environment/4","type":"function"},{"doc":"Updates environment network to connect to your internal network by using a\ntransit gateway.\n\nThis API supports request to create a transit gateway attachment from FinSpace\nVPC to your transit gateway ID and create a custom Route-53 outbound resolvers.\n\nOnce you send a request to update a network, you cannot change it again. Network\nupdate might require termination of any clusters that are running in the\nexisting network.","ref":"AWS.Finspace.html#update_kx_environment_network/4","title":"AWS.Finspace.update_kx_environment_network/4","type":"function"},{"doc":"Updates the user details.\n\nYou can only update the IAM role associated with a user.","ref":"AWS.Finspace.html#update_kx_user/5","title":"AWS.Finspace.update_kx_user/5","type":"function"},{"doc":"Updates the throughput or capacity of a volume.\n\nDuring the update process, the filesystem might be unavailable for a few\nminutes. You can retry any operations after the update is complete.","ref":"AWS.Finspace.html#update_kx_volume/5","title":"AWS.Finspace.update_kx_volume/5","type":"function"},{"doc":"The FinSpace APIs let you take actions inside the FinSpace.","ref":"AWS.Finspacedata.html","title":"AWS.Finspacedata","type":"module"},{"doc":"Adds a user to a permission group to grant permissions for actions a user can\nperform in FinSpace.","ref":"AWS.Finspacedata.html#associate_user_to_permission_group/5","title":"AWS.Finspacedata.associate_user_to_permission_group/5","type":"function"},{"doc":"Creates a new Changeset in a FinSpace Dataset.","ref":"AWS.Finspacedata.html#create_changeset/4","title":"AWS.Finspacedata.create_changeset/4","type":"function"},{"doc":"Creates a Dataview for a Dataset.","ref":"AWS.Finspacedata.html#create_data_view/4","title":"AWS.Finspacedata.create_data_view/4","type":"function"},{"doc":"Creates a new FinSpace Dataset.","ref":"AWS.Finspacedata.html#create_dataset/3","title":"AWS.Finspacedata.create_dataset/3","type":"function"},{"doc":"Creates a group of permissions for various actions that a user can perform in\nFinSpace.","ref":"AWS.Finspacedata.html#create_permission_group/3","title":"AWS.Finspacedata.create_permission_group/3","type":"function"},{"doc":"Creates a new user in FinSpace.","ref":"AWS.Finspacedata.html#create_user/3","title":"AWS.Finspacedata.create_user/3","type":"function"},{"doc":"Deletes a FinSpace Dataset.","ref":"AWS.Finspacedata.html#delete_dataset/4","title":"AWS.Finspacedata.delete_dataset/4","type":"function"},{"doc":"Deletes a permission group.\n\nThis action is irreversible.","ref":"AWS.Finspacedata.html#delete_permission_group/4","title":"AWS.Finspacedata.delete_permission_group/4","type":"function"},{"doc":"Denies access to the FinSpace web application and API for the specified user.","ref":"AWS.Finspacedata.html#disable_user/4","title":"AWS.Finspacedata.disable_user/4","type":"function"},{"doc":"Removes a user from a permission group.","ref":"AWS.Finspacedata.html#disassociate_user_from_permission_group/5","title":"AWS.Finspacedata.disassociate_user_from_permission_group/5","type":"function"},{"doc":"Allows the specified user to access the FinSpace web application and API.","ref":"AWS.Finspacedata.html#enable_user/4","title":"AWS.Finspacedata.enable_user/4","type":"function"},{"doc":"Get information about a Changeset.","ref":"AWS.Finspacedata.html#get_changeset/4","title":"AWS.Finspacedata.get_changeset/4","type":"function"},{"doc":"Gets information about a Dataview.","ref":"AWS.Finspacedata.html#get_data_view/4","title":"AWS.Finspacedata.get_data_view/4","type":"function"},{"doc":"Returns information about a Dataset.","ref":"AWS.Finspacedata.html#get_dataset/3","title":"AWS.Finspacedata.get_dataset/3","type":"function"},{"doc":"Returns the credentials to access the external Dataview from an S3 location.\n\nTo call this API:\n\n  * You must retrieve the programmatic credentials.\n\n  * You must be a member of a FinSpace user group, where the dataset\nthat you want to access has `Read Dataset Data` permissions.","ref":"AWS.Finspacedata.html#get_external_data_view_access_details/5","title":"AWS.Finspacedata.get_external_data_view_access_details/5","type":"function"},{"doc":"Retrieves the details of a specific permission group.","ref":"AWS.Finspacedata.html#get_permission_group/3","title":"AWS.Finspacedata.get_permission_group/3","type":"function"},{"doc":"Request programmatic credentials to use with FinSpace SDK.\n\nFor more information, see [Step 2. Access credentials programmatically using IAM access key id and secret access\nkey](https://docs.aws.amazon.com/finspace/latest/data-api/fs-using-the-finspace-api.html#accessing-credentials).","ref":"AWS.Finspacedata.html#get_programmatic_access_credentials/4","title":"AWS.Finspacedata.get_programmatic_access_credentials/4","type":"function"},{"doc":"Retrieves details for a specific user.","ref":"AWS.Finspacedata.html#get_user/3","title":"AWS.Finspacedata.get_user/3","type":"function"},{"doc":"A temporary Amazon S3 location, where you can copy your files from a source\nlocation to stage or use as a scratch space in FinSpace notebook.","ref":"AWS.Finspacedata.html#get_working_location/3","title":"AWS.Finspacedata.get_working_location/3","type":"function"},{"doc":"Lists the FinSpace Changesets for a Dataset.","ref":"AWS.Finspacedata.html#list_changesets/5","title":"AWS.Finspacedata.list_changesets/5","type":"function"},{"doc":"Lists all available Dataviews for a Dataset.","ref":"AWS.Finspacedata.html#list_data_views/5","title":"AWS.Finspacedata.list_data_views/5","type":"function"},{"doc":"Lists all of the active Datasets that a user has access to.","ref":"AWS.Finspacedata.html#list_datasets/4","title":"AWS.Finspacedata.list_datasets/4","type":"function"},{"doc":"Lists all available permission groups in FinSpace.","ref":"AWS.Finspacedata.html#list_permission_groups/4","title":"AWS.Finspacedata.list_permission_groups/4","type":"function"},{"doc":"Lists all the permission groups that are associated with a specific user.","ref":"AWS.Finspacedata.html#list_permission_groups_by_user/5","title":"AWS.Finspacedata.list_permission_groups_by_user/5","type":"function"},{"doc":"Lists all available users in FinSpace.","ref":"AWS.Finspacedata.html#list_users/4","title":"AWS.Finspacedata.list_users/4","type":"function"},{"doc":"Lists details of all the users in a specific permission group.","ref":"AWS.Finspacedata.html#list_users_by_permission_group/5","title":"AWS.Finspacedata.list_users_by_permission_group/5","type":"function"},{"doc":"","ref":"AWS.Finspacedata.html#metadata/0","title":"AWS.Finspacedata.metadata/0","type":"function"},{"doc":"Resets the password for a specified user ID and generates a temporary one.\n\nOnly a superuser can reset password for other users. Resetting the password\nimmediately invalidates the previous password associated with the user.","ref":"AWS.Finspacedata.html#reset_user_password/4","title":"AWS.Finspacedata.reset_user_password/4","type":"function"},{"doc":"Updates a FinSpace Changeset.","ref":"AWS.Finspacedata.html#update_changeset/5","title":"AWS.Finspacedata.update_changeset/5","type":"function"},{"doc":"Updates a FinSpace Dataset.","ref":"AWS.Finspacedata.html#update_dataset/4","title":"AWS.Finspacedata.update_dataset/4","type":"function"},{"doc":"Modifies the details of a permission group.\n\nYou cannot modify a `permissionGroupID`.","ref":"AWS.Finspacedata.html#update_permission_group/4","title":"AWS.Finspacedata.update_permission_group/4","type":"function"},{"doc":"Modifies the details of the specified user.\n\nYou cannot update the `userId` for a user.","ref":"AWS.Finspacedata.html#update_user/4","title":"AWS.Finspacedata.update_user/4","type":"function"},{"doc":"Amazon Kinesis Data Firehose API Reference\n\nAmazon Kinesis Data Firehose is a fully managed service that delivers real-time\nstreaming data to destinations such as Amazon Simple Storage Service (Amazon\nS3), Amazon OpenSearch Service, Amazon Redshift, Splunk, and various other\nsupportd destinations.","ref":"AWS.Firehose.html","title":"AWS.Firehose","type":"module"},{"doc":"Creates a Kinesis Data Firehose delivery stream.\n\nBy default, you can create up to 50 delivery streams per Amazon Web Services\nRegion.\n\nThis is an asynchronous operation that immediately returns. The initial status\nof the delivery stream is `CREATING`. After the delivery stream is created, its\nstatus is `ACTIVE` and it now accepts data. If the delivery stream creation\nfails, the status transitions to `CREATING_FAILED`. Attempts to send data to a\ndelivery stream that is not in the `ACTIVE` state cause an exception. To check\nthe state of a delivery stream, use `DescribeDeliveryStream`.\n\nIf the status of a delivery stream is `CREATING_FAILED`, this status doesn't\nchange, and you can't invoke `CreateDeliveryStream` again on it. However, you\ncan invoke the `DeleteDeliveryStream` operation to delete it.\n\nA Kinesis Data Firehose delivery stream can be configured to receive records\ndirectly from providers using `PutRecord` or `PutRecordBatch`, or it can be\nconfigured to use an existing Kinesis stream as its source. To specify a Kinesis\ndata stream as input, set the `DeliveryStreamType` parameter to\n`KinesisStreamAsSource`, and provide the Kinesis stream Amazon Resource Name\n(ARN) and role ARN in the `KinesisStreamSourceConfiguration` parameter.\n\nTo create a delivery stream with server-side encryption (SSE) enabled, include\n`DeliveryStreamEncryptionConfigurationInput` in your request. This is optional.\nYou can also invoke `StartDeliveryStreamEncryption` to turn on SSE for an\nexisting delivery stream that doesn't have SSE enabled.\n\nA delivery stream is configured with a single destination, such as Amazon Simple\nStorage Service (Amazon S3), Amazon Redshift, Amazon OpenSearch Service, Amazon\nOpenSearch Serverless, Splunk, and any custom HTTP endpoint or HTTP endpoints\nowned by or supported by third-party service providers, including Datadog,\nDynatrace, LogicMonitor, MongoDB, New Relic, and Sumo Logic. You must specify\nonly one of the following destination configuration parameters:\n`ExtendedS3DestinationConfiguration`, `S3DestinationConfiguration`,\n`ElasticsearchDestinationConfiguration`, `RedshiftDestinationConfiguration`, or\n`SplunkDestinationConfiguration`.\n\nWhen you specify `S3DestinationConfiguration`, you can also provide the\nfollowing optional values: BufferingHints, `EncryptionConfiguration`, and\n`CompressionFormat`. By default, if no `BufferingHints` value is provided,\nKinesis Data Firehose buffers data up to 5 MB or for 5 minutes, whichever\ncondition is satisfied first. `BufferingHints` is a hint, so there are some\ncases where the service cannot adhere to these conditions strictly. For example,\nrecord boundaries might be such that the size is a little over or under the\nconfigured buffering size. By default, no encryption is performed. We strongly\nrecommend that you enable encryption to ensure secure data storage in Amazon S3.\n\nA few notes about Amazon Redshift as a destination:\n\n  * An Amazon Redshift destination requires an S3 bucket as\nintermediate location. Kinesis Data Firehose first delivers data to Amazon S3\nand then uses `COPY` syntax to load data into an Amazon Redshift table. This is\nspecified in the `RedshiftDestinationConfiguration.S3Configuration` parameter.\n\n  * The compression formats `SNAPPY` or `ZIP` cannot be specified in\n`RedshiftDestinationConfiguration.S3Configuration` because the Amazon Redshift\n`COPY` operation that reads from the S3 bucket doesn't support these compression\nformats.\n\n  * We strongly recommend that you use the user name and password you\nprovide exclusively with Kinesis Data Firehose, and that the permissions for the\naccount are restricted for Amazon Redshift `INSERT` permissions.\n\nKinesis Data Firehose assumes the IAM role that is configured as part of the\ndestination. The role should allow the Kinesis Data Firehose principal to assume\nthe role, and the role should have permissions that allow the service to deliver\nthe data. For more information, see [Grant Kinesis Data Firehose Access to an Amazon S3\nDestination](https://docs.aws.amazon.com/firehose/latest/dev/controlling-access.html#using-iam-s3)\nin the *Amazon Kinesis Data Firehose Developer Guide*.","ref":"AWS.Firehose.html#create_delivery_stream/3","title":"AWS.Firehose.create_delivery_stream/3","type":"function"},{"doc":"Deletes a delivery stream and its data.\n\nTo check the state of a delivery stream, use `DescribeDeliveryStream`. You can\ndelete a delivery stream only if it is in one of the following states: `ACTIVE`,\n`DELETING`, `CREATING_FAILED`, or `DELETING_FAILED`. You can't delete a delivery\nstream that is in the `CREATING` state. While the deletion request is in\nprocess, the delivery stream is in the `DELETING` state.\n\nWhile the delivery stream is in the `DELETING` state, the service might continue\nto accept records, but it doesn't make any guarantees with respect to delivering\nthe data. Therefore, as a best practice, first stop any applications that are\nsending records before you delete a delivery stream.","ref":"AWS.Firehose.html#delete_delivery_stream/3","title":"AWS.Firehose.delete_delivery_stream/3","type":"function"},{"doc":"Describes the specified delivery stream and its status.\n\nFor example, after your delivery stream is created, call\n`DescribeDeliveryStream` to see whether the delivery stream is `ACTIVE` and\ntherefore ready for data to be sent to it.\n\nIf the status of a delivery stream is `CREATING_FAILED`, this status doesn't\nchange, and you can't invoke `CreateDeliveryStream` again on it. However, you\ncan invoke the `DeleteDeliveryStream` operation to delete it. If the status is\n`DELETING_FAILED`, you can force deletion by invoking `DeleteDeliveryStream`\nagain but with `DeleteDeliveryStreamInput$AllowForceDelete` set to true.","ref":"AWS.Firehose.html#describe_delivery_stream/3","title":"AWS.Firehose.describe_delivery_stream/3","type":"function"},{"doc":"Lists your delivery streams in alphabetical order of their names.\n\nThe number of delivery streams might be too large to return using a single call\nto `ListDeliveryStreams`. You can limit the number of delivery streams returned,\nusing the `Limit` parameter. To determine whether there are more delivery\nstreams to list, check the value of `HasMoreDeliveryStreams` in the output. If\nthere are more delivery streams to list, you can request them by calling this\noperation again and setting the `ExclusiveStartDeliveryStreamName` parameter to\nthe name of the last delivery stream returned in the last call.","ref":"AWS.Firehose.html#list_delivery_streams/3","title":"AWS.Firehose.list_delivery_streams/3","type":"function"},{"doc":"Lists the tags for the specified delivery stream.\n\nThis operation has a limit of five transactions per second per account.","ref":"AWS.Firehose.html#list_tags_for_delivery_stream/3","title":"AWS.Firehose.list_tags_for_delivery_stream/3","type":"function"},{"doc":"","ref":"AWS.Firehose.html#metadata/0","title":"AWS.Firehose.metadata/0","type":"function"},{"doc":"Writes a single data record into an Amazon Kinesis Data Firehose delivery\nstream.\n\nTo write multiple data records into a delivery stream, use `PutRecordBatch`.\nApplications using these operations are referred to as producers.\n\nBy default, each delivery stream can take in up to 2,000 transactions per\nsecond, 5,000 records per second, or 5 MB per second. If you use `PutRecord` and\n`PutRecordBatch`, the limits are an aggregate across these two operations for\neach delivery stream. For more information about limits and how to request an\nincrease, see [Amazon Kinesis Data Firehose Limits](https://docs.aws.amazon.com/firehose/latest/dev/limits.html).\n\nKinesis Data Firehose accumulates and publishes a particular metric for a\ncustomer account in one minute intervals. It is possible that the bursts of\nincoming bytes/records ingested to a delivery stream last only for a few\nseconds. Due to this, the actual spikes in the traffic might not be fully\nvisible in the customer's 1 minute CloudWatch metrics.\n\nYou must specify the name of the delivery stream and the data record when using\n`PutRecord`. The data record consists of a data blob that can be up to 1,000 KiB\nin size, and any kind of data. For example, it can be a segment from a log file,\ngeographic location data, website clickstream data, and so on.\n\nKinesis Data Firehose buffers records before delivering them to the destination.\nTo disambiguate the data blobs at the destination, a common solution is to use\ndelimiters in the data, such as a newline (`\n`) or some other character unique\nwithin the data. This allows the consumer application to parse individual data\nitems when reading the data from the destination.\n\nThe `PutRecord` operation returns a `RecordId`, which is a unique string\nassigned to each record. Producer applications can use this ID for purposes such\nas auditability and investigation.\n\nIf the `PutRecord` operation throws a `ServiceUnavailableException`, the API is\nautomatically reinvoked (retried) 3 times. If the exception persists, it is\npossible that the throughput limits have been exceeded for the delivery stream.\n\nRe-invoking the Put API operations (for example, PutRecord and PutRecordBatch)\ncan result in data duplicates. For larger data assets, allow for a longer time\nout before retrying Put API operations.\n\nData records sent to Kinesis Data Firehose are stored for 24 hours from the time\nthey are added to a delivery stream as it tries to send the records to the\ndestination. If the destination is unreachable for more than 24 hours, the data\nis no longer available.\n\nDon't concatenate two or more base64 strings to form the data fields of your\nrecords. Instead, concatenate the raw data, then perform base64 encoding.","ref":"AWS.Firehose.html#put_record/3","title":"AWS.Firehose.put_record/3","type":"function"},{"doc":"Writes multiple data records into a delivery stream in a single call, which can\nachieve higher throughput per producer than when writing single records.\n\nTo write single data records into a delivery stream, use `PutRecord`.\nApplications using these operations are referred to as producers.\n\nKinesis Data Firehose accumulates and publishes a particular metric for a\ncustomer account in one minute intervals. It is possible that the bursts of\nincoming bytes/records ingested to a delivery stream last only for a few\nseconds. Due to this, the actual spikes in the traffic might not be fully\nvisible in the customer's 1 minute CloudWatch metrics.\n\nFor information about service quota, see [Amazon Kinesis Data Firehose Quota](https://docs.aws.amazon.com/firehose/latest/dev/limits.html).\n\nEach `PutRecordBatch` request supports up to 500 records. Each record in the\nrequest can be as large as 1,000 KB (before base64 encoding), up to a limit of 4\nMB for the entire request. These limits cannot be changed.\n\nYou must specify the name of the delivery stream and the data record when using\n`PutRecord`. The data record consists of a data blob that can be up to 1,000 KB\nin size, and any kind of data. For example, it could be a segment from a log\nfile, geographic location data, website clickstream data, and so on.\n\nKinesis Data Firehose buffers records before delivering them to the destination.\nTo disambiguate the data blobs at the destination, a common solution is to use\ndelimiters in the data, such as a newline (`\n`) or some other character unique\nwithin the data. This allows the consumer application to parse individual data\nitems when reading the data from the destination.\n\nThe `PutRecordBatch` response includes a count of failed records,\n`FailedPutCount`, and an array of responses, `RequestResponses`. Even if the\n`PutRecordBatch` call succeeds, the value of `FailedPutCount` may be greater\nthan 0, indicating that there are records for which the operation didn't\nsucceed. Each entry in the `RequestResponses` array provides additional\ninformation about the processed record. It directly correlates with a record in\nthe request array using the same ordering, from the top to the bottom. The\nresponse array always includes the same number of records as the request array.\n`RequestResponses` includes both successfully and unsuccessfully processed\nrecords. Kinesis Data Firehose tries to process all records in each\n`PutRecordBatch` request. A single record failure does not stop the processing\nof subsequent records.\n\nA successfully processed record includes a `RecordId` value, which is unique for\nthe record. An unsuccessfully processed record includes `ErrorCode` and\n`ErrorMessage` values. `ErrorCode` reflects the type of error, and is one of the\nfollowing values: `ServiceUnavailableException` or `InternalFailure`.\n`ErrorMessage` provides more detailed information about the error.\n\nIf there is an internal server error or a timeout, the write might have\ncompleted or it might have failed. If `FailedPutCount` is greater than 0, retry\nthe request, resending only those records that might have failed processing.\nThis minimizes the possible duplicate records and also reduces the total bytes\nsent (and corresponding charges). We recommend that you handle any duplicates at\nthe destination.\n\nIf `PutRecordBatch` throws `ServiceUnavailableException`, the API is\nautomatically reinvoked (retried) 3 times. If the exception persists, it is\npossible that the throughput limits have been exceeded for the delivery stream.\n\nRe-invoking the Put API operations (for example, PutRecord and PutRecordBatch)\ncan result in data duplicates. For larger data assets, allow for a longer time\nout before retrying Put API operations.\n\nData records sent to Kinesis Data Firehose are stored for 24 hours from the time\nthey are added to a delivery stream as it attempts to send the records to the\ndestination. If the destination is unreachable for more than 24 hours, the data\nis no longer available.\n\nDon't concatenate two or more base64 strings to form the data fields of your\nrecords. Instead, concatenate the raw data, then perform base64 encoding.","ref":"AWS.Firehose.html#put_record_batch/3","title":"AWS.Firehose.put_record_batch/3","type":"function"},{"doc":"Enables server-side encryption (SSE) for the delivery stream.\n\nThis operation is asynchronous. It returns immediately. When you invoke it,\nKinesis Data Firehose first sets the encryption status of the stream to\n`ENABLING`, and then to `ENABLED`. The encryption status of a delivery stream is\nthe `Status` property in `DeliveryStreamEncryptionConfiguration`. If the\noperation fails, the encryption status changes to `ENABLING_FAILED`. You can\ncontinue to read and write data to your delivery stream while the encryption\nstatus is `ENABLING`, but the data is not encrypted. It can take up to 5 seconds\nafter the encryption status changes to `ENABLED` before all records written to\nthe delivery stream are encrypted. To find out whether a record or a batch of\nrecords was encrypted, check the response elements `PutRecordOutput$Encrypted`\nand `PutRecordBatchOutput$Encrypted`, respectively.\n\nTo check the encryption status of a delivery stream, use\n`DescribeDeliveryStream`.\n\nEven if encryption is currently enabled for a delivery stream, you can still\ninvoke this operation on it to change the ARN of the CMK or both its type and\nARN. If you invoke this method to change the CMK, and the old CMK is of type\n`CUSTOMER_MANAGED_CMK`, Kinesis Data Firehose schedules the grant it had on the\nold CMK for retirement. If the new CMK is of type `CUSTOMER_MANAGED_CMK`,\nKinesis Data Firehose creates a grant that enables it to use the new CMK to\nencrypt and decrypt data and to manage the grant.\n\nFor the KMS grant creation to be successful, Kinesis Data Firehose APIs\n`StartDeliveryStreamEncryption` and `CreateDeliveryStream` should not be called\nwith session credentials that are more than 6 hours old.\n\nIf a delivery stream already has encryption enabled and then you invoke this\noperation to change the ARN of the CMK or both its type and ARN and you get\n`ENABLING_FAILED`, this only means that the attempt to change the CMK failed. In\nthis case, encryption remains enabled with the old CMK.\n\nIf the encryption status of your delivery stream is `ENABLING_FAILED`, you can\ninvoke this operation again with a valid CMK. The CMK must be enabled and the\nkey policy mustn't explicitly deny the permission for Kinesis Data Firehose to\ninvoke KMS encrypt and decrypt operations.\n\nYou can enable SSE for a delivery stream only if it's a delivery stream that\nuses `DirectPut` as its source.\n\nThe `StartDeliveryStreamEncryption` and `StopDeliveryStreamEncryption`\noperations have a combined limit of 25 calls per delivery stream per 24 hours.\nFor example, you reach the limit if you call `StartDeliveryStreamEncryption` 13\ntimes and `StopDeliveryStreamEncryption` 12 times for the same delivery stream\nin a 24-hour period.","ref":"AWS.Firehose.html#start_delivery_stream_encryption/3","title":"AWS.Firehose.start_delivery_stream_encryption/3","type":"function"},{"doc":"Disables server-side encryption (SSE) for the delivery stream.\n\nThis operation is asynchronous. It returns immediately. When you invoke it,\nKinesis Data Firehose first sets the encryption status of the stream to\n`DISABLING`, and then to `DISABLED`. You can continue to read and write data to\nyour stream while its status is `DISABLING`. It can take up to 5 seconds after\nthe encryption status changes to `DISABLED` before all records written to the\ndelivery stream are no longer subject to encryption. To find out whether a\nrecord or a batch of records was encrypted, check the response elements\n`PutRecordOutput$Encrypted` and `PutRecordBatchOutput$Encrypted`, respectively.\n\nTo check the encryption state of a delivery stream, use\n`DescribeDeliveryStream`.\n\nIf SSE is enabled using a customer managed CMK and then you invoke\n`StopDeliveryStreamEncryption`, Kinesis Data Firehose schedules the related KMS\ngrant for retirement and then retires it after it ensures that it is finished\ndelivering records to the destination.\n\nThe `StartDeliveryStreamEncryption` and `StopDeliveryStreamEncryption`\noperations have a combined limit of 25 calls per delivery stream per 24 hours.\nFor example, you reach the limit if you call `StartDeliveryStreamEncryption` 13\ntimes and `StopDeliveryStreamEncryption` 12 times for the same delivery stream\nin a 24-hour period.","ref":"AWS.Firehose.html#stop_delivery_stream_encryption/3","title":"AWS.Firehose.stop_delivery_stream_encryption/3","type":"function"},{"doc":"Adds or updates tags for the specified delivery stream.\n\nA tag is a key-value pair that you can define and assign to Amazon Web Services\nresources. If you specify a tag that already exists, the tag value is replaced\nwith the value that you specify in the request. Tags are metadata. For example,\nyou can add friendly names and descriptions or other types of information that\ncan help you distinguish the delivery stream. For more information about tags,\nsee [Using Cost Allocation Tags](https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/cost-alloc-tags.html)\nin the *Amazon Web Services Billing and Cost Management User Guide*.\n\nEach delivery stream can have up to 50 tags.\n\nThis operation has a limit of five transactions per second per account.","ref":"AWS.Firehose.html#tag_delivery_stream/3","title":"AWS.Firehose.tag_delivery_stream/3","type":"function"},{"doc":"Removes tags from the specified delivery stream.\n\nRemoved tags are deleted, and you can't recover them after this operation\nsuccessfully completes.\n\nIf you specify a tag that doesn't exist, the operation ignores it.\n\nThis operation has a limit of five transactions per second per account.","ref":"AWS.Firehose.html#untag_delivery_stream/3","title":"AWS.Firehose.untag_delivery_stream/3","type":"function"},{"doc":"Updates the specified destination of the specified delivery stream.\n\nUse this operation to change the destination type (for example, to replace the\nAmazon S3 destination with Amazon Redshift) or change the parameters associated\nwith a destination (for example, to change the bucket name of the Amazon S3\ndestination). The update might not occur immediately. The target delivery stream\nremains active while the configurations are updated, so data writes to the\ndelivery stream can continue during this process. The updated configurations are\nusually effective within a few minutes.\n\nSwitching between Amazon OpenSearch Service and other services is not supported.\nFor an Amazon OpenSearch Service destination, you can only update to another\nAmazon OpenSearch Service destination.\n\nIf the destination type is the same, Kinesis Data Firehose merges the\nconfiguration parameters specified with the destination configuration that\nalready exists on the delivery stream. If any of the parameters are not\nspecified in the call, the existing values are retained. For example, in the\nAmazon S3 destination, if `EncryptionConfiguration` is not specified, then the\nexisting `EncryptionConfiguration` is maintained on the destination.\n\nIf the destination type is not the same, for example, changing the destination\nfrom Amazon S3 to Amazon Redshift, Kinesis Data Firehose does not merge any\nparameters. In this case, all parameters must be specified.\n\nKinesis Data Firehose uses `CurrentDeliveryStreamVersionId` to avoid race\nconditions and conflicting merges. This is a required field, and the service\nupdates the configuration only if the existing configuration has a version ID\nthat matches. After the update is applied successfully, the version ID is\nupdated, and can be retrieved using `DescribeDeliveryStream`. Use the new\nversion ID to set `CurrentDeliveryStreamVersionId` in the next call.","ref":"AWS.Firehose.html#update_destination/3","title":"AWS.Firehose.update_destination/3","type":"function"},{"doc":"Fault Injection Simulator is a managed service that enables you to perform fault\ninjection experiments on your Amazon Web Services workloads.\n\nFor more information, see the [Fault Injection Simulator User Guide](https://docs.aws.amazon.com/fis/latest/userguide/).","ref":"AWS.Fis.html","title":"AWS.Fis","type":"module"},{"doc":"Creates an experiment template.\n\nAn experiment template includes the following components:\n\n  * **Targets**: A target can be a specific resource in your Amazon\nWeb Services environment, or one or more resources that match criteria that you\nspecify, for example, resources that have specific tags.\n\n  * **Actions**: The actions to carry out on the target. You can\nspecify multiple actions, the duration of each action, and when to start each\naction during an experiment.\n\n  * **Stop conditions**: If a stop condition is triggered while an\nexperiment is running, the experiment is automatically stopped. You can define a\nstop condition as a CloudWatch alarm.\n\nFor more information, see [experiment templates](https://docs.aws.amazon.com/fis/latest/userguide/experiment-templates.html)\nin the *Fault Injection Simulator User Guide*.","ref":"AWS.Fis.html#create_experiment_template/3","title":"AWS.Fis.create_experiment_template/3","type":"function"},{"doc":"Creates a target account configuration for the experiment template.\n\nA target account configuration is required when `accountTargeting` of\n`experimentOptions` is set to `multi-account`. For more information, see\n[experiment options](https://docs.aws.amazon.com/fis/latest/userguide/experiment-options.html)\nin the *Fault Injection Simulator User Guide*.","ref":"AWS.Fis.html#create_target_account_configuration/5","title":"AWS.Fis.create_target_account_configuration/5","type":"function"},{"doc":"Deletes the specified experiment template.","ref":"AWS.Fis.html#delete_experiment_template/4","title":"AWS.Fis.delete_experiment_template/4","type":"function"},{"doc":"Deletes the specified target account configuration of the experiment template.","ref":"AWS.Fis.html#delete_target_account_configuration/5","title":"AWS.Fis.delete_target_account_configuration/5","type":"function"},{"doc":"Gets information about the specified FIS action.","ref":"AWS.Fis.html#get_action/3","title":"AWS.Fis.get_action/3","type":"function"},{"doc":"Gets information about the specified experiment.","ref":"AWS.Fis.html#get_experiment/3","title":"AWS.Fis.get_experiment/3","type":"function"},{"doc":"Gets information about the specified target account configuration of the\nexperiment.","ref":"AWS.Fis.html#get_experiment_target_account_configuration/4","title":"AWS.Fis.get_experiment_target_account_configuration/4","type":"function"},{"doc":"Gets information about the specified experiment template.","ref":"AWS.Fis.html#get_experiment_template/3","title":"AWS.Fis.get_experiment_template/3","type":"function"},{"doc":"Gets information about the specified target account configuration of the\nexperiment template.","ref":"AWS.Fis.html#get_target_account_configuration/4","title":"AWS.Fis.get_target_account_configuration/4","type":"function"},{"doc":"Gets information about the specified resource type.","ref":"AWS.Fis.html#get_target_resource_type/3","title":"AWS.Fis.get_target_resource_type/3","type":"function"},{"doc":"Lists the available FIS actions.","ref":"AWS.Fis.html#list_actions/4","title":"AWS.Fis.list_actions/4","type":"function"},{"doc":"Lists the resolved targets information of the specified experiment.","ref":"AWS.Fis.html#list_experiment_resolved_targets/6","title":"AWS.Fis.list_experiment_resolved_targets/6","type":"function"},{"doc":"Lists the target account configurations of the specified experiment.","ref":"AWS.Fis.html#list_experiment_target_account_configurations/4","title":"AWS.Fis.list_experiment_target_account_configurations/4","type":"function"},{"doc":"Lists your experiment templates.","ref":"AWS.Fis.html#list_experiment_templates/4","title":"AWS.Fis.list_experiment_templates/4","type":"function"},{"doc":"Lists your experiments.","ref":"AWS.Fis.html#list_experiments/4","title":"AWS.Fis.list_experiments/4","type":"function"},{"doc":"Lists the tags for the specified resource.","ref":"AWS.Fis.html#list_tags_for_resource/3","title":"AWS.Fis.list_tags_for_resource/3","type":"function"},{"doc":"Lists the target account configurations of the specified experiment template.","ref":"AWS.Fis.html#list_target_account_configurations/5","title":"AWS.Fis.list_target_account_configurations/5","type":"function"},{"doc":"Lists the target resource types.","ref":"AWS.Fis.html#list_target_resource_types/4","title":"AWS.Fis.list_target_resource_types/4","type":"function"},{"doc":"","ref":"AWS.Fis.html#metadata/0","title":"AWS.Fis.metadata/0","type":"function"},{"doc":"Starts running an experiment from the specified experiment template.","ref":"AWS.Fis.html#start_experiment/3","title":"AWS.Fis.start_experiment/3","type":"function"},{"doc":"Stops the specified experiment.","ref":"AWS.Fis.html#stop_experiment/4","title":"AWS.Fis.stop_experiment/4","type":"function"},{"doc":"Applies the specified tags to the specified resource.","ref":"AWS.Fis.html#tag_resource/4","title":"AWS.Fis.tag_resource/4","type":"function"},{"doc":"Removes the specified tags from the specified resource.","ref":"AWS.Fis.html#untag_resource/4","title":"AWS.Fis.untag_resource/4","type":"function"},{"doc":"Updates the specified experiment template.","ref":"AWS.Fis.html#update_experiment_template/4","title":"AWS.Fis.update_experiment_template/4","type":"function"},{"doc":"Updates the target account configuration for the specified experiment template.","ref":"AWS.Fis.html#update_target_account_configuration/5","title":"AWS.Fis.update_target_account_configuration/5","type":"function"},{"doc":"Provides APIs for creating and managing Amazon Forecast resources.","ref":"AWS.Forecast.html","title":"AWS.Forecast","type":"module"},{"doc":"Creates an Amazon Forecast predictor.\n\nAmazon Forecast creates predictors with AutoPredictor, which involves applying\nthe optimal combination of algorithms to each time series in your datasets. You\ncan use `CreateAutoPredictor` to create new predictors or upgrade/retrain\nexisting predictors.","ref":"AWS.Forecast.html#create_auto_predictor/3","title":"AWS.Forecast.create_auto_predictor/3","type":"function"},{"doc":"The following parameters are required when creating a new predictor:\n\n  * `PredictorName` - A unique name for the predictor.\n\n  * `DatasetGroupArn` - The ARN of the dataset group used to train the\npredictor.\n\n  * `ForecastFrequency` - The granularity of your forecasts (hourly,\ndaily, weekly, etc).\n\n  * `ForecastHorizon` - The number of time-steps that the model\npredicts. The forecast horizon is also called the prediction length.\n\nWhen creating a new predictor, do not specify a value for\n`ReferencePredictorArn`.","ref":"AWS.Forecast.html#create_auto_predictor/3-creating-new-predictors","title":"Creating new predictors - AWS.Forecast.create_auto_predictor/3","type":"function"},{"doc":"The following parameters are required when retraining or upgrading a predictor:\n\n  * `PredictorName` - A unique name for the predictor.\n\n  * `ReferencePredictorArn` - The ARN of the predictor to retrain or\nupgrade.\n\nWhen upgrading or retraining a predictor, only specify values for the\n`ReferencePredictorArn` and `PredictorName`.","ref":"AWS.Forecast.html#create_auto_predictor/3-upgrading-and-retraining-predictors","title":"Upgrading and retraining predictors - AWS.Forecast.create_auto_predictor/3","type":"function"},{"doc":"Creates an Amazon Forecast dataset.\n\nThe information about the dataset that you provide helps Forecast understand how\nto consume the data for model training. This includes the following:\n\n  * * `DataFrequency` * - How frequently your historical time-series\ndata is collected.\n\n  * * `Domain` * and * `DatasetType` * - Each dataset has an\nassociated dataset domain and a type within the domain. Amazon Forecast provides\na list of predefined domains and types within each domain. For each unique\ndataset domain and type within the domain, Amazon Forecast requires your data to\ninclude a minimum set of predefined fields.\n\n  * * `Schema` * - A schema specifies the fields in the dataset,\nincluding the field name and data type.\n\nAfter creating a dataset, you import your training data into it and add the\ndataset to a dataset group. You use the dataset group to create a predictor. For\nmore information, see [Importing datasets](https://docs.aws.amazon.com/forecast/latest/dg/howitworks-datasets-groups.html).\n\nTo get a list of all your datasets, use the\n[ListDatasets](https://docs.aws.amazon.com/forecast/latest/dg/API_ListDatasets.html) operation.\n\nFor example Forecast datasets, see the [Amazon Forecast Sample GitHub\nrepository](https://github.com/aws-samples/amazon-forecast-samples).\n\nThe `Status` of a dataset must be `ACTIVE` before you can import training data.\nUse the\n[DescribeDataset](https://docs.aws.amazon.com/forecast/latest/dg/API_DescribeDataset.html)\noperation to get the status.","ref":"AWS.Forecast.html#create_dataset/3","title":"AWS.Forecast.create_dataset/3","type":"function"},{"doc":"Creates a dataset group, which holds a collection of related datasets.\n\nYou can add datasets to the dataset group when you create the dataset group, or\nlater by using the\n[UpdateDatasetGroup](https://docs.aws.amazon.com/forecast/latest/dg/API_UpdateDatasetGroup.html) operation.\n\nAfter creating a dataset group and adding datasets, you use the dataset group\nwhen you create a predictor. For more information, see [Dataset\ngroups](https://docs.aws.amazon.com/forecast/latest/dg/howitworks-datasets-groups.html).\n\nTo get a list of all your datasets groups, use the\n[ListDatasetGroups](https://docs.aws.amazon.com/forecast/latest/dg/API_ListDatasetGroups.html) operation.\n\nThe `Status` of a dataset group must be `ACTIVE` before you can use the dataset\ngroup to create a predictor. To get the status, use the\n[DescribeDatasetGroup](https://docs.aws.amazon.com/forecast/latest/dg/API_DescribeDatasetGroup.html)\noperation.","ref":"AWS.Forecast.html#create_dataset_group/3","title":"AWS.Forecast.create_dataset_group/3","type":"function"},{"doc":"Imports your training data to an Amazon Forecast dataset.\n\nYou provide the location of your training data in an Amazon Simple Storage\nService (Amazon S3) bucket and the Amazon Resource Name (ARN) of the dataset\nthat you want to import the data to.\n\nYou must specify a\n[DataSource](https://docs.aws.amazon.com/forecast/latest/dg/API_DataSource.html) object that includes an Identity and Access Management (IAM) role that Amazon\nForecast can assume to access the data, as Amazon Forecast makes a copy of your\ndata and processes it in an internal Amazon Web Services system. For more\ninformation, see [Set up\npermissions](https://docs.aws.amazon.com/forecast/latest/dg/aws-forecast-iam-roles.html).\n\nThe training data must be in CSV or Parquet format. The delimiter must be a\ncomma (,).\n\nYou can specify the path to a specific file, the S3 bucket, or to a folder in\nthe S3 bucket. For the latter two cases, Amazon Forecast imports all files up to\nthe limit of 10,000 files.\n\nBecause dataset imports are not aggregated, your most recent dataset import is\nthe one that is used when training a predictor or generating a forecast. Make\nsure that your most recent dataset import contains all of the data you want to\nmodel off of, and not just the new data collected since the previous import.\n\nTo get a list of all your dataset import jobs, filtered by specified criteria,\nuse the\n[ListDatasetImportJobs](https://docs.aws.amazon.com/forecast/latest/dg/API_ListDatasetImportJobs.html)\noperation.","ref":"AWS.Forecast.html#create_dataset_import_job/3","title":"AWS.Forecast.create_dataset_import_job/3","type":"function"},{"doc":"Explainability is only available for Forecasts and Predictors generated from an\nAutoPredictor (`CreateAutoPredictor`)\n\nCreates an Amazon Forecast Explainability.\n\nExplainability helps you better understand how the attributes in your datasets\nimpact forecast. Amazon Forecast uses a metric called Impact scores to quantify\nthe relative impact of each attribute and determine whether they increase or\ndecrease forecast values.\n\nTo enable Forecast Explainability, your predictor must include at least one of\nthe following: related time series, item metadata, or additional datasets like\nHolidays and the Weather Index.\n\nCreateExplainability accepts either a Predictor ARN or Forecast ARN. To receive\naggregated Impact scores for all time series and time points in your datasets,\nprovide a Predictor ARN. To receive Impact scores for specific time series and\ntime points, provide a Forecast ARN.","ref":"AWS.Forecast.html#create_explainability/3","title":"AWS.Forecast.create_explainability/3","type":"function"},{"doc":"You can only have one Explainability resource per predictor. If you already\nenabled `ExplainPredictor` in `CreateAutoPredictor`, that predictor already has\nan Explainability resource.\n\nThe following parameters are required when providing a Predictor ARN:\n\n  * `ExplainabilityName` - A unique name for the Explainability.\n\n  * `ResourceArn` - The Arn of the predictor.\n\n  * `TimePointGranularity` - Must be set to “ALL”.\n\n  * `TimeSeriesGranularity` - Must be set to “ALL”.\n\nDo not specify a value for the following parameters:\n\n  * `DataSource` - Only valid when TimeSeriesGranularity is\n“SPECIFIC”.\n\n  * `Schema` - Only valid when TimeSeriesGranularity is “SPECIFIC”.\n\n  * `StartDateTime` - Only valid when TimePointGranularity is\n“SPECIFIC”.\n\n  * `EndDateTime` - Only valid when TimePointGranularity is\n“SPECIFIC”.","ref":"AWS.Forecast.html#create_explainability/3-createexplainability-with-a-predictor-arn","title":"CreateExplainability with a Predictor ARN - AWS.Forecast.create_explainability/3","type":"function"},{"doc":"You can specify a maximum of 50 time series and 500 time points.\n\nThe following parameters are required when providing a Predictor ARN:\n\n  * `ExplainabilityName` - A unique name for the Explainability.\n\n  * `ResourceArn` - The Arn of the forecast.\n\n  * `TimePointGranularity` - Either “ALL” or “SPECIFIC”.\n\n  * `TimeSeriesGranularity` - Either “ALL” or “SPECIFIC”.\n\nIf you set TimeSeriesGranularity to “SPECIFIC”, you must also provide the\nfollowing:\n\n  * `DataSource` - The S3 location of the CSV file specifying your\ntime series.\n\n  * `Schema` - The Schema defines the attributes and attribute types\nlisted in the Data Source.\n\nIf you set TimePointGranularity to “SPECIFIC”, you must also provide the\nfollowing:\n\n  * `StartDateTime` - The first timestamp in the range of time points.\n\n  * `EndDateTime` - The last timestamp in the range of time points.","ref":"AWS.Forecast.html#create_explainability/3-createexplainability-with-a-forecast-arn","title":"CreateExplainability with a Forecast ARN - AWS.Forecast.create_explainability/3","type":"function"},{"doc":"Exports an Explainability resource created by the `CreateExplainability`\noperation.\n\nExported files are exported to an Amazon Simple Storage Service (Amazon S3)\nbucket.\n\nYou must specify a `DataDestination` object that includes an Amazon S3 bucket\nand an Identity and Access Management (IAM) role that Amazon Forecast can assume\nto access the Amazon S3 bucket. For more information, see\n`aws-forecast-iam-roles`.\n\nThe `Status` of the export job must be `ACTIVE` before you can access the export\nin your Amazon S3 bucket. To get the status, use the\n`DescribeExplainabilityExport` operation.","ref":"AWS.Forecast.html#create_explainability_export/3","title":"AWS.Forecast.create_explainability_export/3","type":"function"},{"doc":"Creates a forecast for each item in the `TARGET_TIME_SERIES` dataset that was\nused to train the predictor.\n\nThis is known as inference. To retrieve the forecast for a single item at low\nlatency, use the operation. To export the complete forecast into your Amazon\nSimple Storage Service (Amazon S3) bucket, use the `CreateForecastExportJob`\noperation.\n\nThe range of the forecast is determined by the `ForecastHorizon` value, which\nyou specify in the `CreatePredictor` request. When you query a forecast, you can\nrequest a specific date range within the forecast.\n\nTo get a list of all your forecasts, use the `ListForecasts` operation.\n\nThe forecasts generated by Amazon Forecast are in the same time zone as the\ndataset that was used to create the predictor.\n\nFor more information, see `howitworks-forecast`.\n\nThe `Status` of the forecast must be `ACTIVE` before you can query or export the\nforecast. Use the `DescribeForecast` operation to get the status.\n\nBy default, a forecast includes predictions for every item (`item_id`) in the\ndataset group that was used to train the predictor. However, you can use the\n`TimeSeriesSelector` object to generate a forecast on a subset of time series.\nForecast creation is skipped for any time series that you specify that are not\nin the input dataset. The forecast export file will not contain these time\nseries or their forecasted values.","ref":"AWS.Forecast.html#create_forecast/3","title":"AWS.Forecast.create_forecast/3","type":"function"},{"doc":"Exports a forecast created by the `CreateForecast` operation to your Amazon\nSimple Storage Service (Amazon S3) bucket.\n\nThe forecast file name will match the following conventions:\n\n _ _ \n\nwhere the   component is in Java SimpleDateFormat\n(yyyy-MM-ddTHH-mm-ssZ).\n\nYou must specify a `DataDestination` object that includes an Identity and Access\nManagement (IAM) role that Amazon Forecast can assume to access the Amazon S3\nbucket. For more information, see `aws-forecast-iam-roles`.\n\nFor more information, see `howitworks-forecast`.\n\nTo get a list of all your forecast export jobs, use the `ListForecastExportJobs`\noperation.\n\nThe `Status` of the forecast export job must be `ACTIVE` before you can access\nthe forecast in your Amazon S3 bucket. To get the status, use the\n`DescribeForecastExportJob` operation.","ref":"AWS.Forecast.html#create_forecast_export_job/3","title":"AWS.Forecast.create_forecast_export_job/3","type":"function"},{"doc":"Creates a predictor monitor resource for an existing auto predictor.\n\nPredictor monitoring allows you to see how your predictor's performance changes\nover time. For more information, see [Predictor Monitoring](https://docs.aws.amazon.com/forecast/latest/dg/predictor-monitoring.html).","ref":"AWS.Forecast.html#create_monitor/3","title":"AWS.Forecast.create_monitor/3","type":"function"},{"doc":"This operation creates a legacy predictor that does not include all the\npredictor functionalities provided by Amazon Forecast.\n\nTo create a predictor that is compatible with all aspects of Forecast, use\n`CreateAutoPredictor`.\n\nCreates an Amazon Forecast predictor.\n\nIn the request, provide a dataset group and either specify an algorithm or let\nAmazon Forecast choose an algorithm for you using AutoML. If you specify an\nalgorithm, you also can override algorithm-specific hyperparameters.\n\nAmazon Forecast uses the algorithm to train a predictor using the latest version\nof the datasets in the specified dataset group. You can then generate a forecast\nusing the `CreateForecast` operation.\n\nTo see the evaluation metrics, use the `GetAccuracyMetrics` operation.\n\nYou can specify a featurization configuration to fill and aggregate the data\nfields in the `TARGET_TIME_SERIES` dataset to improve model training. For more\ninformation, see `FeaturizationConfig`.\n\nFor RELATED_TIME_SERIES datasets, `CreatePredictor` verifies that the\n`DataFrequency` specified when the dataset was created matches the\n`ForecastFrequency`. TARGET_TIME_SERIES datasets don't have this restriction.\nAmazon Forecast also verifies the delimiter and timestamp format. For more\ninformation, see `howitworks-datasets-groups`.\n\nBy default, predictors are trained and evaluated at the 0.1 (P10), 0.5 (P50),\nand 0.9 (P90) quantiles. You can choose custom forecast types to train and\nevaluate your predictor by setting the `ForecastTypes`.","ref":"AWS.Forecast.html#create_predictor/3","title":"AWS.Forecast.create_predictor/3","type":"function"},{"doc":"If you want Amazon Forecast to evaluate each algorithm and choose the one that\nminimizes the `objective function`, set `PerformAutoML` to `true`. The\n`objective function` is defined as the mean of the weighted losses over the\nforecast types. By default, these are the p10, p50, and p90 quantile losses. For\nmore information, see `EvaluationResult`.\n\nWhen AutoML is enabled, the following properties are disallowed:\n\n  * `AlgorithmArn`\n\n  * `HPOConfig`\n\n  * `PerformHPO`\n\n  * `TrainingParameters`\n\nTo get a list of all of your predictors, use the `ListPredictors` operation.\n\nBefore you can use the predictor to create a forecast, the `Status` of the\npredictor must be `ACTIVE`, signifying that training has completed. To get the\nstatus, use the `DescribePredictor` operation.","ref":"AWS.Forecast.html#create_predictor/3-automl","title":"AutoML - AWS.Forecast.create_predictor/3","type":"function"},{"doc":"Exports backtest forecasts and accuracy metrics generated by the\n`CreateAutoPredictor` or `CreatePredictor` operations.\n\nTwo folders containing CSV or Parquet files are exported to your specified S3\nbucket.\n\nThe export file names will match the following conventions:\n\n` _ _ .csv`\n\nThe   component is in Java SimpleDate format\n(yyyy-MM-ddTHH-mm-ssZ).\n\nYou must specify a `DataDestination` object that includes an Amazon S3 bucket\nand an Identity and Access Management (IAM) role that Amazon Forecast can assume\nto access the Amazon S3 bucket. For more information, see\n`aws-forecast-iam-roles`.\n\nThe `Status` of the export job must be `ACTIVE` before you can access the export\nin your Amazon S3 bucket. To get the status, use the\n`DescribePredictorBacktestExportJob` operation.","ref":"AWS.Forecast.html#create_predictor_backtest_export_job/3","title":"AWS.Forecast.create_predictor_backtest_export_job/3","type":"function"},{"doc":"What-if analysis is a scenario modeling technique where you make a hypothetical\nchange to a time series and compare the forecasts generated by these changes\nagainst the baseline, unchanged time series.\n\nIt is important to remember that the purpose of a what-if analysis is to\nunderstand how a forecast can change given different modifications to the\nbaseline time series.\n\nFor example, imagine you are a clothing retailer who is considering an end of\nseason sale to clear space for new styles. After creating a baseline forecast,\nyou can use a what-if analysis to investigate how different sales tactics might\naffect your goals.\n\nYou could create a scenario where everything is given a 25% markdown, and\nanother where everything is given a fixed dollar markdown. You could create a\nscenario where the sale lasts for one week and another where the sale lasts for\none month. With a what-if analysis, you can compare many different scenarios\nagainst each other.\n\nNote that a what-if analysis is meant to display what the forecasting model has\nlearned and how it will behave in the scenarios that you are evaluating. Do not\nblindly use the results of the what-if analysis to make business decisions. For\ninstance, forecasts might not be accurate for novel scenarios where there is no\nreference available to determine whether a forecast is good.\n\nThe `TimeSeriesSelector` object defines the items that you want in the what-if\nanalysis.","ref":"AWS.Forecast.html#create_what_if_analysis/3","title":"AWS.Forecast.create_what_if_analysis/3","type":"function"},{"doc":"A what-if forecast is a forecast that is created from a modified version of the\nbaseline forecast.\n\nEach what-if forecast incorporates either a replacement dataset or a set of\ntransformations to the original dataset.","ref":"AWS.Forecast.html#create_what_if_forecast/3","title":"AWS.Forecast.create_what_if_forecast/3","type":"function"},{"doc":"Exports a forecast created by the `CreateWhatIfForecast` operation to your\nAmazon Simple Storage Service (Amazon S3) bucket.\n\nThe forecast file name will match the following conventions:\n\n`≈ _ _ `\n\nThe   component is in Java SimpleDateFormat\n(yyyy-MM-ddTHH-mm-ssZ).\n\nYou must specify a `DataDestination` object that includes an Identity and Access\nManagement (IAM) role that Amazon Forecast can assume to access the Amazon S3\nbucket. For more information, see `aws-forecast-iam-roles`.\n\nFor more information, see `howitworks-forecast`.\n\nTo get a list of all your what-if forecast export jobs, use the\n`ListWhatIfForecastExports` operation.\n\nThe `Status` of the forecast export job must be `ACTIVE` before you can access\nthe forecast in your Amazon S3 bucket. To get the status, use the\n`DescribeWhatIfForecastExport` operation.","ref":"AWS.Forecast.html#create_what_if_forecast_export/3","title":"AWS.Forecast.create_what_if_forecast_export/3","type":"function"},{"doc":"Deletes an Amazon Forecast dataset that was created using the\n[CreateDataset](https://docs.aws.amazon.com/forecast/latest/dg/API_CreateDataset.html) operation.\n\nYou can only delete datasets that have a status of `ACTIVE` or `CREATE_FAILED`.\nTo get the status use the\n[DescribeDataset](https://docs.aws.amazon.com/forecast/latest/dg/API_DescribeDataset.html)\noperation.\n\nForecast does not automatically update any dataset groups that contain the\ndeleted dataset. In order to update the dataset group, use the\n[UpdateDatasetGroup](https://docs.aws.amazon.com/forecast/latest/dg/API_UpdateDatasetGroup.html)\noperation, omitting the deleted dataset's ARN.","ref":"AWS.Forecast.html#delete_dataset/3","title":"AWS.Forecast.delete_dataset/3","type":"function"},{"doc":"Deletes a dataset group created using the\n[CreateDatasetGroup](https://docs.aws.amazon.com/forecast/latest/dg/API_CreateDatasetGroup.html) operation.\n\nYou can only delete dataset groups that have a status of `ACTIVE`,\n`CREATE_FAILED`, or `UPDATE_FAILED`. To get the status, use the\n[DescribeDatasetGroup](https://docs.aws.amazon.com/forecast/latest/dg/API_DescribeDatasetGroup.html)\noperation.\n\nThis operation deletes only the dataset group, not the datasets in the group.","ref":"AWS.Forecast.html#delete_dataset_group/3","title":"AWS.Forecast.delete_dataset_group/3","type":"function"},{"doc":"Deletes a dataset import job created using the\n[CreateDatasetImportJob](https://docs.aws.amazon.com/forecast/latest/dg/API_CreateDatasetImportJob.html) operation.\n\nYou can delete only dataset import jobs that have a status of `ACTIVE` or\n`CREATE_FAILED`. To get the status, use the\n[DescribeDatasetImportJob](https://docs.aws.amazon.com/forecast/latest/dg/API_DescribeDatasetImportJob.html)\noperation.","ref":"AWS.Forecast.html#delete_dataset_import_job/3","title":"AWS.Forecast.delete_dataset_import_job/3","type":"function"},{"doc":"Deletes an Explainability resource.\n\nYou can delete only predictor that have a status of `ACTIVE` or `CREATE_FAILED`.\nTo get the status, use the `DescribeExplainability` operation.","ref":"AWS.Forecast.html#delete_explainability/3","title":"AWS.Forecast.delete_explainability/3","type":"function"},{"doc":"Deletes an Explainability export.","ref":"AWS.Forecast.html#delete_explainability_export/3","title":"AWS.Forecast.delete_explainability_export/3","type":"function"},{"doc":"Deletes a forecast created using the `CreateForecast` operation.\n\nYou can delete only forecasts that have a status of `ACTIVE` or `CREATE_FAILED`.\nTo get the status, use the `DescribeForecast` operation.\n\nYou can't delete a forecast while it is being exported. After a forecast is\ndeleted, you can no longer query the forecast.","ref":"AWS.Forecast.html#delete_forecast/3","title":"AWS.Forecast.delete_forecast/3","type":"function"},{"doc":"Deletes a forecast export job created using the `CreateForecastExportJob`\noperation.\n\nYou can delete only export jobs that have a status of `ACTIVE` or\n`CREATE_FAILED`. To get the status, use the `DescribeForecastExportJob`\noperation.","ref":"AWS.Forecast.html#delete_forecast_export_job/3","title":"AWS.Forecast.delete_forecast_export_job/3","type":"function"},{"doc":"Deletes a monitor resource.\n\nYou can only delete a monitor resource with a status of `ACTIVE`,\n`ACTIVE_STOPPED`, `CREATE_FAILED`, or `CREATE_STOPPED`.","ref":"AWS.Forecast.html#delete_monitor/3","title":"AWS.Forecast.delete_monitor/3","type":"function"},{"doc":"Deletes a predictor created using the `DescribePredictor` or `CreatePredictor`\noperations.\n\nYou can delete only predictor that have a status of `ACTIVE` or `CREATE_FAILED`.\nTo get the status, use the `DescribePredictor` operation.","ref":"AWS.Forecast.html#delete_predictor/3","title":"AWS.Forecast.delete_predictor/3","type":"function"},{"doc":"Deletes a predictor backtest export job.","ref":"AWS.Forecast.html#delete_predictor_backtest_export_job/3","title":"AWS.Forecast.delete_predictor_backtest_export_job/3","type":"function"},{"doc":"Deletes an entire resource tree.\n\nThis operation will delete the parent resource and its child resources.\n\nChild resources are resources that were created from another resource. For\nexample, when a forecast is generated from a predictor, the forecast is the\nchild resource and the predictor is the parent resource.\n\nAmazon Forecast resources possess the following parent-child resource\nhierarchies:\n\n  * **Dataset**: dataset import jobs\n\n  * **Dataset Group**: predictors, predictor backtest export jobs,\nforecasts, forecast export jobs\n\n  * **Predictor**: predictor backtest export jobs, forecasts, forecast\nexport jobs\n\n  * **Forecast**: forecast export jobs\n\n`DeleteResourceTree` will only delete Amazon Forecast resources, and will not\ndelete datasets or exported files stored in Amazon S3.","ref":"AWS.Forecast.html#delete_resource_tree/3","title":"AWS.Forecast.delete_resource_tree/3","type":"function"},{"doc":"Deletes a what-if analysis created using the `CreateWhatIfAnalysis` operation.\n\nYou can delete only what-if analyses that have a status of `ACTIVE` or\n`CREATE_FAILED`. To get the status, use the `DescribeWhatIfAnalysis` operation.\n\nYou can't delete a what-if analysis while any of its forecasts are being\nexported.","ref":"AWS.Forecast.html#delete_what_if_analysis/3","title":"AWS.Forecast.delete_what_if_analysis/3","type":"function"},{"doc":"Deletes a what-if forecast created using the `CreateWhatIfForecast` operation.\n\nYou can delete only what-if forecasts that have a status of `ACTIVE` or\n`CREATE_FAILED`. To get the status, use the `DescribeWhatIfForecast` operation.\n\nYou can't delete a what-if forecast while it is being exported. After a what-if\nforecast is deleted, you can no longer query the what-if analysis.","ref":"AWS.Forecast.html#delete_what_if_forecast/3","title":"AWS.Forecast.delete_what_if_forecast/3","type":"function"},{"doc":"Deletes a what-if forecast export created using the `CreateWhatIfForecastExport`\noperation.\n\nYou can delete only what-if forecast exports that have a status of `ACTIVE` or\n`CREATE_FAILED`. To get the status, use the `DescribeWhatIfForecastExport`\noperation.","ref":"AWS.Forecast.html#delete_what_if_forecast_export/3","title":"AWS.Forecast.delete_what_if_forecast_export/3","type":"function"},{"doc":"Describes a predictor created using the CreateAutoPredictor operation.","ref":"AWS.Forecast.html#describe_auto_predictor/3","title":"AWS.Forecast.describe_auto_predictor/3","type":"function"},{"doc":"Describes an Amazon Forecast dataset created using the\n[CreateDataset](https://docs.aws.amazon.com/forecast/latest/dg/API_CreateDataset.html)\noperation.\n\nIn addition to listing the parameters specified in the `CreateDataset` request,\nthis operation includes the following dataset properties:\n\n  * `CreationTime`\n\n  * `LastModificationTime`\n\n  * `Status`","ref":"AWS.Forecast.html#describe_dataset/3","title":"AWS.Forecast.describe_dataset/3","type":"function"},{"doc":"Describes a dataset group created using the\n[CreateDatasetGroup](https://docs.aws.amazon.com/forecast/latest/dg/API_CreateDatasetGroup.html)\noperation.\n\nIn addition to listing the parameters provided in the `CreateDatasetGroup`\nrequest, this operation includes the following properties:\n\n  * `DatasetArns` - The datasets belonging to the group.\n\n  * `CreationTime`\n\n  * `LastModificationTime`\n\n  * `Status`","ref":"AWS.Forecast.html#describe_dataset_group/3","title":"AWS.Forecast.describe_dataset_group/3","type":"function"},{"doc":"Describes a dataset import job created using the\n[CreateDatasetImportJob](https://docs.aws.amazon.com/forecast/latest/dg/API_CreateDatasetImportJob.html)\noperation.\n\nIn addition to listing the parameters provided in the `CreateDatasetImportJob`\nrequest, this operation includes the following properties:\n\n  * `CreationTime`\n\n  * `LastModificationTime`\n\n  * `DataSize`\n\n  * `FieldStatistics`\n\n  * `Status`\n\n  * `Message` - If an error occurred, information about the error.","ref":"AWS.Forecast.html#describe_dataset_import_job/3","title":"AWS.Forecast.describe_dataset_import_job/3","type":"function"},{"doc":"Describes an Explainability resource created using the `CreateExplainability`\noperation.","ref":"AWS.Forecast.html#describe_explainability/3","title":"AWS.Forecast.describe_explainability/3","type":"function"},{"doc":"Describes an Explainability export created using the\n`CreateExplainabilityExport` operation.","ref":"AWS.Forecast.html#describe_explainability_export/3","title":"AWS.Forecast.describe_explainability_export/3","type":"function"},{"doc":"Describes a forecast created using the `CreateForecast` operation.\n\nIn addition to listing the properties provided in the `CreateForecast` request,\nthis operation lists the following properties:\n\n  * `DatasetGroupArn` - The dataset group that provided the training\ndata.\n\n  * `CreationTime`\n\n  * `LastModificationTime`\n\n  * `Status`\n\n  * `Message` - If an error occurred, information about the error.","ref":"AWS.Forecast.html#describe_forecast/3","title":"AWS.Forecast.describe_forecast/3","type":"function"},{"doc":"Describes a forecast export job created using the `CreateForecastExportJob`\noperation.\n\nIn addition to listing the properties provided by the user in the\n`CreateForecastExportJob` request, this operation lists the following\nproperties:\n\n  * `CreationTime`\n\n  * `LastModificationTime`\n\n  * `Status`\n\n  * `Message` - If an error occurred, information about the error.","ref":"AWS.Forecast.html#describe_forecast_export_job/3","title":"AWS.Forecast.describe_forecast_export_job/3","type":"function"},{"doc":"Describes a monitor resource.\n\nIn addition to listing the properties provided in the `CreateMonitor` request,\nthis operation lists the following properties:\n\n  * `Baseline`\n\n  * `CreationTime`\n\n  * `LastEvaluationTime`\n\n  * `LastEvaluationState`\n\n  * `LastModificationTime`\n\n  * `Message`\n\n  * `Status`","ref":"AWS.Forecast.html#describe_monitor/3","title":"AWS.Forecast.describe_monitor/3","type":"function"},{"doc":"This operation is only valid for legacy predictors created with CreatePredictor.\n\nIf you are not using a legacy predictor, use `DescribeAutoPredictor`.\n\nDescribes a predictor created using the `CreatePredictor` operation.\n\nIn addition to listing the properties provided in the `CreatePredictor` request,\nthis operation lists the following properties:\n\n  * `DatasetImportJobArns` - The dataset import jobs used to import\ntraining data.\n\n  * `AutoMLAlgorithmArns` - If AutoML is performed, the algorithms\nthat were evaluated.\n\n  * `CreationTime`\n\n  * `LastModificationTime`\n\n  * `Status`\n\n  * `Message` - If an error occurred, information about the error.","ref":"AWS.Forecast.html#describe_predictor/3","title":"AWS.Forecast.describe_predictor/3","type":"function"},{"doc":"Describes a predictor backtest export job created using the\n`CreatePredictorBacktestExportJob` operation.\n\nIn addition to listing the properties provided by the user in the\n`CreatePredictorBacktestExportJob` request, this operation lists the following\nproperties:\n\n  * `CreationTime`\n\n  * `LastModificationTime`\n\n  * `Status`\n\n  * `Message` (if an error occurred)","ref":"AWS.Forecast.html#describe_predictor_backtest_export_job/3","title":"AWS.Forecast.describe_predictor_backtest_export_job/3","type":"function"},{"doc":"Describes the what-if analysis created using the `CreateWhatIfAnalysis`\noperation.\n\nIn addition to listing the properties provided in the `CreateWhatIfAnalysis`\nrequest, this operation lists the following properties:\n\n  * `CreationTime`\n\n  * `LastModificationTime`\n\n  * `Message` - If an error occurred, information about the error.\n\n  * `Status`","ref":"AWS.Forecast.html#describe_what_if_analysis/3","title":"AWS.Forecast.describe_what_if_analysis/3","type":"function"},{"doc":"Describes the what-if forecast created using the `CreateWhatIfForecast`\noperation.\n\nIn addition to listing the properties provided in the `CreateWhatIfForecast`\nrequest, this operation lists the following properties:\n\n  * `CreationTime`\n\n  * `LastModificationTime`\n\n  * `Message` - If an error occurred, information about the error.\n\n  * `Status`","ref":"AWS.Forecast.html#describe_what_if_forecast/3","title":"AWS.Forecast.describe_what_if_forecast/3","type":"function"},{"doc":"Describes the what-if forecast export created using the\n`CreateWhatIfForecastExport` operation.\n\nIn addition to listing the properties provided in the\n`CreateWhatIfForecastExport` request, this operation lists the following\nproperties:\n\n  * `CreationTime`\n\n  * `LastModificationTime`\n\n  * `Message` - If an error occurred, information about the error.\n\n  * `Status`","ref":"AWS.Forecast.html#describe_what_if_forecast_export/3","title":"AWS.Forecast.describe_what_if_forecast_export/3","type":"function"},{"doc":"Provides metrics on the accuracy of the models that were trained by the\n`CreatePredictor` operation.\n\nUse metrics to see how well the model performed and to decide whether to use the\npredictor to generate a forecast. For more information, see [Predictor Metrics](https://docs.aws.amazon.com/forecast/latest/dg/metrics.html).\n\nThis operation generates metrics for each backtest window that was evaluated.\nThe number of backtest windows (`NumberOfBacktestWindows`) is specified using\nthe `EvaluationParameters` object, which is optionally included in the\n`CreatePredictor` request. If `NumberOfBacktestWindows` isn't specified, the\nnumber defaults to one.\n\nThe parameters of the `filling` method determine which items contribute to the\nmetrics. If you want all items to contribute, specify `zero`. If you want only\nthose items that have complete data in the range being evaluated to contribute,\nspecify `nan`. For more information, see `FeaturizationMethod`.\n\nBefore you can get accuracy metrics, the `Status` of the predictor must be\n`ACTIVE`, signifying that training has completed. To get the status, use the\n`DescribePredictor` operation.","ref":"AWS.Forecast.html#get_accuracy_metrics/3","title":"AWS.Forecast.get_accuracy_metrics/3","type":"function"},{"doc":"Returns a list of dataset groups created using the\n[CreateDatasetGroup](https://docs.aws.amazon.com/forecast/latest/dg/API_CreateDatasetGroup.html) operation.\n\nFor each dataset group, this operation returns a summary of its properties,\nincluding its Amazon Resource Name (ARN). You can retrieve the complete set of\nproperties by using the dataset group ARN with the\n[DescribeDatasetGroup](https://docs.aws.amazon.com/forecast/latest/dg/API_DescribeDatasetGroup.html)\noperation.","ref":"AWS.Forecast.html#list_dataset_groups/3","title":"AWS.Forecast.list_dataset_groups/3","type":"function"},{"doc":"Returns a list of dataset import jobs created using the\n[CreateDatasetImportJob](https://docs.aws.amazon.com/forecast/latest/dg/API_CreateDatasetImportJob.html) operation.\n\nFor each import job, this operation returns a summary of its properties,\nincluding its Amazon Resource Name (ARN). You can retrieve the complete set of\nproperties by using the ARN with the\n[DescribeDatasetImportJob](https://docs.aws.amazon.com/forecast/latest/dg/API_DescribeDatasetImportJob.html)\noperation. You can filter the list by providing an array of\n[Filter](https://docs.aws.amazon.com/forecast/latest/dg/API_Filter.html)\nobjects.","ref":"AWS.Forecast.html#list_dataset_import_jobs/3","title":"AWS.Forecast.list_dataset_import_jobs/3","type":"function"},{"doc":"Returns a list of datasets created using the\n[CreateDataset](https://docs.aws.amazon.com/forecast/latest/dg/API_CreateDataset.html) operation.\n\nFor each dataset, a summary of its properties, including its Amazon Resource\nName (ARN), is returned. To retrieve the complete set of properties, use the ARN\nwith the\n[DescribeDataset](https://docs.aws.amazon.com/forecast/latest/dg/API_DescribeDataset.html)\noperation.","ref":"AWS.Forecast.html#list_datasets/3","title":"AWS.Forecast.list_datasets/3","type":"function"},{"doc":"Returns a list of Explainability resources created using the\n`CreateExplainability` operation.\n\nThis operation returns a summary for each Explainability. You can filter the\nlist using an array of `Filter` objects.\n\nTo retrieve the complete set of properties for a particular Explainability\nresource, use the ARN with the `DescribeExplainability` operation.","ref":"AWS.Forecast.html#list_explainabilities/3","title":"AWS.Forecast.list_explainabilities/3","type":"function"},{"doc":"Returns a list of Explainability exports created using the\n`CreateExplainabilityExport` operation.\n\nThis operation returns a summary for each Explainability export. You can filter\nthe list using an array of `Filter` objects.\n\nTo retrieve the complete set of properties for a particular Explainability\nexport, use the ARN with the `DescribeExplainability` operation.","ref":"AWS.Forecast.html#list_explainability_exports/3","title":"AWS.Forecast.list_explainability_exports/3","type":"function"},{"doc":"Returns a list of forecast export jobs created using the\n`CreateForecastExportJob` operation.\n\nFor each forecast export job, this operation returns a summary of its\nproperties, including its Amazon Resource Name (ARN). To retrieve the complete\nset of properties, use the ARN with the `DescribeForecastExportJob` operation.\nYou can filter the list using an array of `Filter` objects.","ref":"AWS.Forecast.html#list_forecast_export_jobs/3","title":"AWS.Forecast.list_forecast_export_jobs/3","type":"function"},{"doc":"Returns a list of forecasts created using the `CreateForecast` operation.\n\nFor each forecast, this operation returns a summary of its properties, including\nits Amazon Resource Name (ARN). To retrieve the complete set of properties,\nspecify the ARN with the `DescribeForecast` operation. You can filter the list\nusing an array of `Filter` objects.","ref":"AWS.Forecast.html#list_forecasts/3","title":"AWS.Forecast.list_forecasts/3","type":"function"},{"doc":"Returns a list of the monitoring evaluation results and predictor events\ncollected by the monitor resource during different windows of time.\n\nFor information about monitoring see `predictor-monitoring`. For more\ninformation about retrieving monitoring results see [Viewing Monitoring Results](https://docs.aws.amazon.com/forecast/latest/dg/predictor-monitoring-results.html).","ref":"AWS.Forecast.html#list_monitor_evaluations/3","title":"AWS.Forecast.list_monitor_evaluations/3","type":"function"},{"doc":"Returns a list of monitors created with the `CreateMonitor` operation and\n`CreateAutoPredictor` operation.\n\nFor each monitor resource, this operation returns of a summary of its\nproperties, including its Amazon Resource Name (ARN). You can retrieve a\ncomplete set of properties of a monitor resource by specify the monitor's ARN in\nthe `DescribeMonitor` operation.","ref":"AWS.Forecast.html#list_monitors/3","title":"AWS.Forecast.list_monitors/3","type":"function"},{"doc":"Returns a list of predictor backtest export jobs created using the\n`CreatePredictorBacktestExportJob` operation.\n\nThis operation returns a summary for each backtest export job. You can filter\nthe list using an array of `Filter` objects.\n\nTo retrieve the complete set of properties for a particular backtest export job,\nuse the ARN with the `DescribePredictorBacktestExportJob` operation.","ref":"AWS.Forecast.html#list_predictor_backtest_export_jobs/3","title":"AWS.Forecast.list_predictor_backtest_export_jobs/3","type":"function"},{"doc":"Returns a list of predictors created using the `CreateAutoPredictor` or\n`CreatePredictor` operations.\n\nFor each predictor, this operation returns a summary of its properties,\nincluding its Amazon Resource Name (ARN).\n\nYou can retrieve the complete set of properties by using the ARN with the\n`DescribeAutoPredictor` and `DescribePredictor` operations. You can filter the\nlist using an array of `Filter` objects.","ref":"AWS.Forecast.html#list_predictors/3","title":"AWS.Forecast.list_predictors/3","type":"function"},{"doc":"Lists the tags for an Amazon Forecast resource.","ref":"AWS.Forecast.html#list_tags_for_resource/3","title":"AWS.Forecast.list_tags_for_resource/3","type":"function"},{"doc":"Returns a list of what-if analyses created using the `CreateWhatIfAnalysis`\noperation.\n\nFor each what-if analysis, this operation returns a summary of its properties,\nincluding its Amazon Resource Name (ARN). You can retrieve the complete set of\nproperties by using the what-if analysis ARN with the `DescribeWhatIfAnalysis`\noperation.","ref":"AWS.Forecast.html#list_what_if_analyses/3","title":"AWS.Forecast.list_what_if_analyses/3","type":"function"},{"doc":"Returns a list of what-if forecast exports created using the\n`CreateWhatIfForecastExport` operation.\n\nFor each what-if forecast export, this operation returns a summary of its\nproperties, including its Amazon Resource Name (ARN). You can retrieve the\ncomplete set of properties by using the what-if forecast export ARN with the\n`DescribeWhatIfForecastExport` operation.","ref":"AWS.Forecast.html#list_what_if_forecast_exports/3","title":"AWS.Forecast.list_what_if_forecast_exports/3","type":"function"},{"doc":"Returns a list of what-if forecasts created using the `CreateWhatIfForecast`\noperation.\n\nFor each what-if forecast, this operation returns a summary of its properties,\nincluding its Amazon Resource Name (ARN). You can retrieve the complete set of\nproperties by using the what-if forecast ARN with the `DescribeWhatIfForecast`\noperation.","ref":"AWS.Forecast.html#list_what_if_forecasts/3","title":"AWS.Forecast.list_what_if_forecasts/3","type":"function"},{"doc":"","ref":"AWS.Forecast.html#metadata/0","title":"AWS.Forecast.metadata/0","type":"function"},{"doc":"Resumes a stopped monitor resource.","ref":"AWS.Forecast.html#resume_resource/3","title":"AWS.Forecast.resume_resource/3","type":"function"},{"doc":"Stops a resource.\n\nThe resource undergoes the following states: `CREATE_STOPPING` and\n`CREATE_STOPPED`. You cannot resume a resource once it has been stopped.\n\nThis operation can be applied to the following resources (and their\ncorresponding child resources):\n\n  * Dataset Import Job\n\n  * Predictor Job\n\n  * Forecast Job\n\n  * Forecast Export Job\n\n  * Predictor Backtest Export Job\n\n  * Explainability Job\n\n  * Explainability Export Job","ref":"AWS.Forecast.html#stop_resource/3","title":"AWS.Forecast.stop_resource/3","type":"function"},{"doc":"Associates the specified tags to a resource with the specified `resourceArn`.\n\nIf existing tags on a resource are not specified in the request parameters, they\nare not changed. When a resource is deleted, the tags associated with that\nresource are also deleted.","ref":"AWS.Forecast.html#tag_resource/3","title":"AWS.Forecast.tag_resource/3","type":"function"},{"doc":"Deletes the specified tags from a resource.","ref":"AWS.Forecast.html#untag_resource/3","title":"AWS.Forecast.untag_resource/3","type":"function"},{"doc":"Replaces the datasets in a dataset group with the specified datasets.\n\nThe `Status` of the dataset group must be `ACTIVE` before you can use the\ndataset group to create a predictor. Use the\n[DescribeDatasetGroup](https://docs.aws.amazon.com/forecast/latest/dg/API_DescribeDatasetGroup.html)\noperation to get the status.","ref":"AWS.Forecast.html#update_dataset_group/3","title":"AWS.Forecast.update_dataset_group/3","type":"function"},{"doc":"Provides APIs for creating and managing Amazon Forecast resources.","ref":"AWS.Forecastquery.html","title":"AWS.Forecastquery","type":"module"},{"doc":"","ref":"AWS.Forecastquery.html#metadata/0","title":"AWS.Forecastquery.metadata/0","type":"function"},{"doc":"Retrieves a forecast for a single item, filtered by the supplied criteria.\n\nThe criteria is a key-value pair. The key is either `item_id` (or the equivalent\nnon-timestamp, non-target field) from the `TARGET_TIME_SERIES` dataset, or one\nof the forecast dimensions specified as part of the `FeaturizationConfig`\nobject.\n\nBy default, `QueryForecast` returns the complete date range for the filtered\nforecast. You can request a specific date range.\n\nTo get the full forecast, use the\n[CreateForecastExportJob](https://docs.aws.amazon.com/en_us/forecast/latest/dg/API_CreateForecastExportJob.html)\noperation.\n\nThe forecasts generated by Amazon Forecast are in the same timezone as the\ndataset that was used to create the predictor.","ref":"AWS.Forecastquery.html#query_forecast/3","title":"AWS.Forecastquery.query_forecast/3","type":"function"},{"doc":"Retrieves a what-if forecast.","ref":"AWS.Forecastquery.html#query_what_if_forecast/3","title":"AWS.Forecastquery.query_what_if_forecast/3","type":"function"},{"doc":"This is the Amazon Fraud Detector API Reference.\n\nThis guide is for developers who need detailed information about Amazon Fraud\nDetector API actions, data types, and errors. For more information about Amazon\nFraud Detector features, see the [Amazon Fraud Detector User Guide](https://docs.aws.amazon.com/frauddetector/latest/ug/).\n\nWe provide the Query API as well as AWS software development kits (SDK) for\nAmazon Fraud Detector in Java and Python programming languages.\n\nThe Amazon Fraud Detector Query API provides HTTPS requests that use the HTTP\nverb GET or POST and a Query parameter `Action`. AWS SDK provides libraries,\nsample code, tutorials, and other resources for software developers who prefer\nto build applications using language-specific APIs instead of submitting a\nrequest over HTTP or HTTPS. These libraries provide basic functions that\nautomatically take care of tasks such as cryptographically signing your\nrequests, retrying requests, and handling error responses, so that it is easier\nfor you to get started. For more information about the AWS SDKs, go to [Tools to build on AWS](https://aws.amazon.com/developer/tools/) page, scroll down to the\n**SDK** section, and choose plus (+) sign to expand the section.","ref":"AWS.FraudDetector.html","title":"AWS.FraudDetector","type":"module"},{"doc":"Creates a batch of variables.","ref":"AWS.FraudDetector.html#batch_create_variable/3","title":"AWS.FraudDetector.batch_create_variable/3","type":"function"},{"doc":"Gets a batch of variables.","ref":"AWS.FraudDetector.html#batch_get_variable/3","title":"AWS.FraudDetector.batch_get_variable/3","type":"function"},{"doc":"Cancels an in-progress batch import job.","ref":"AWS.FraudDetector.html#cancel_batch_import_job/3","title":"AWS.FraudDetector.cancel_batch_import_job/3","type":"function"},{"doc":"Cancels the specified batch prediction job.","ref":"AWS.FraudDetector.html#cancel_batch_prediction_job/3","title":"AWS.FraudDetector.cancel_batch_prediction_job/3","type":"function"},{"doc":"Creates a batch import job.","ref":"AWS.FraudDetector.html#create_batch_import_job/3","title":"AWS.FraudDetector.create_batch_import_job/3","type":"function"},{"doc":"Creates a batch prediction job.","ref":"AWS.FraudDetector.html#create_batch_prediction_job/3","title":"AWS.FraudDetector.create_batch_prediction_job/3","type":"function"},{"doc":"Creates a detector version.\n\nThe detector version starts in a `DRAFT` status.","ref":"AWS.FraudDetector.html#create_detector_version/3","title":"AWS.FraudDetector.create_detector_version/3","type":"function"},{"doc":"Creates a list.\n\nList is a set of input data for a variable in your event dataset. You use the\ninput data in a rule that's associated with your detector. For more information,\nsee [Lists](https://docs.aws.amazon.com/frauddetector/latest/ug/lists.html).","ref":"AWS.FraudDetector.html#create_list/3","title":"AWS.FraudDetector.create_list/3","type":"function"},{"doc":"Creates a model using the specified model type.","ref":"AWS.FraudDetector.html#create_model/3","title":"AWS.FraudDetector.create_model/3","type":"function"},{"doc":"Creates a version of the model using the specified model type and model id.","ref":"AWS.FraudDetector.html#create_model_version/3","title":"AWS.FraudDetector.create_model_version/3","type":"function"},{"doc":"Creates a rule for use with the specified detector.","ref":"AWS.FraudDetector.html#create_rule/3","title":"AWS.FraudDetector.create_rule/3","type":"function"},{"doc":"Creates a variable.","ref":"AWS.FraudDetector.html#create_variable/3","title":"AWS.FraudDetector.create_variable/3","type":"function"},{"doc":"Deletes the specified batch import job ID record.\n\nThis action does not delete the data that was batch imported.","ref":"AWS.FraudDetector.html#delete_batch_import_job/3","title":"AWS.FraudDetector.delete_batch_import_job/3","type":"function"},{"doc":"Deletes a batch prediction job.","ref":"AWS.FraudDetector.html#delete_batch_prediction_job/3","title":"AWS.FraudDetector.delete_batch_prediction_job/3","type":"function"},{"doc":"Deletes the detector.\n\nBefore deleting a detector, you must first delete all detector versions and rule\nversions associated with the detector.\n\nWhen you delete a detector, Amazon Fraud Detector permanently deletes the\ndetector and the data is no longer stored in Amazon Fraud Detector.","ref":"AWS.FraudDetector.html#delete_detector/3","title":"AWS.FraudDetector.delete_detector/3","type":"function"},{"doc":"Deletes the detector version.\n\nYou cannot delete detector versions that are in `ACTIVE` status.\n\nWhen you delete a detector version, Amazon Fraud Detector permanently deletes\nthe detector and the data is no longer stored in Amazon Fraud Detector.","ref":"AWS.FraudDetector.html#delete_detector_version/3","title":"AWS.FraudDetector.delete_detector_version/3","type":"function"},{"doc":"Deletes an entity type.\n\nYou cannot delete an entity type that is included in an event type.\n\nWhen you delete an entity type, Amazon Fraud Detector permanently deletes that\nentity type and the data is no longer stored in Amazon Fraud Detector.","ref":"AWS.FraudDetector.html#delete_entity_type/3","title":"AWS.FraudDetector.delete_entity_type/3","type":"function"},{"doc":"Deletes the specified event.\n\nWhen you delete an event, Amazon Fraud Detector permanently deletes that event\nand the event data is no longer stored in Amazon Fraud Detector. If\n`deleteAuditHistory` is `True`, event data is available through search for up to\n30 seconds after the delete operation is completed.","ref":"AWS.FraudDetector.html#delete_event/3","title":"AWS.FraudDetector.delete_event/3","type":"function"},{"doc":"Deletes an event type.\n\nYou cannot delete an event type that is used in a detector or a model.\n\nWhen you delete an event type, Amazon Fraud Detector permanently deletes that\nevent type and the data is no longer stored in Amazon Fraud Detector.","ref":"AWS.FraudDetector.html#delete_event_type/3","title":"AWS.FraudDetector.delete_event_type/3","type":"function"},{"doc":"Deletes all events of a particular event type.","ref":"AWS.FraudDetector.html#delete_events_by_event_type/3","title":"AWS.FraudDetector.delete_events_by_event_type/3","type":"function"},{"doc":"Removes a SageMaker model from Amazon Fraud Detector.\n\nYou can remove an Amazon SageMaker model if it is not associated with a detector\nversion. Removing a SageMaker model disconnects it from Amazon Fraud Detector,\nbut the model remains available in SageMaker.","ref":"AWS.FraudDetector.html#delete_external_model/3","title":"AWS.FraudDetector.delete_external_model/3","type":"function"},{"doc":"Deletes a label.\n\nYou cannot delete labels that are included in an event type in Amazon Fraud\nDetector.\n\nYou cannot delete a label assigned to an event ID. You must first delete the\nrelevant event ID.\n\nWhen you delete a label, Amazon Fraud Detector permanently deletes that label\nand the data is no longer stored in Amazon Fraud Detector.","ref":"AWS.FraudDetector.html#delete_label/3","title":"AWS.FraudDetector.delete_label/3","type":"function"},{"doc":"Deletes the list, provided it is not used in a rule.\n\nWhen you delete a list, Amazon Fraud Detector permanently deletes that list and\nthe elements in the list.","ref":"AWS.FraudDetector.html#delete_list/3","title":"AWS.FraudDetector.delete_list/3","type":"function"},{"doc":"Deletes a model.\n\nYou can delete models and model versions in Amazon Fraud Detector, provided that\nthey are not associated with a detector version.\n\nWhen you delete a model, Amazon Fraud Detector permanently deletes that model\nand the data is no longer stored in Amazon Fraud Detector.","ref":"AWS.FraudDetector.html#delete_model/3","title":"AWS.FraudDetector.delete_model/3","type":"function"},{"doc":"Deletes a model version.\n\nYou can delete models and model versions in Amazon Fraud Detector, provided that\nthey are not associated with a detector version.\n\nWhen you delete a model version, Amazon Fraud Detector permanently deletes that\nmodel version and the data is no longer stored in Amazon Fraud Detector.","ref":"AWS.FraudDetector.html#delete_model_version/3","title":"AWS.FraudDetector.delete_model_version/3","type":"function"},{"doc":"Deletes an outcome.\n\nYou cannot delete an outcome that is used in a rule version.\n\nWhen you delete an outcome, Amazon Fraud Detector permanently deletes that\noutcome and the data is no longer stored in Amazon Fraud Detector.","ref":"AWS.FraudDetector.html#delete_outcome/3","title":"AWS.FraudDetector.delete_outcome/3","type":"function"},{"doc":"Deletes the rule.\n\nYou cannot delete a rule if it is used by an `ACTIVE` or `INACTIVE` detector\nversion.\n\nWhen you delete a rule, Amazon Fraud Detector permanently deletes that rule and\nthe data is no longer stored in Amazon Fraud Detector.","ref":"AWS.FraudDetector.html#delete_rule/3","title":"AWS.FraudDetector.delete_rule/3","type":"function"},{"doc":"Deletes a variable.\n\nYou can't delete variables that are included in an event type in Amazon Fraud\nDetector.\n\nAmazon Fraud Detector automatically deletes model output variables and SageMaker\nmodel output variables when you delete the model. You can't delete these\nvariables manually.\n\nWhen you delete a variable, Amazon Fraud Detector permanently deletes that\nvariable and the data is no longer stored in Amazon Fraud Detector.","ref":"AWS.FraudDetector.html#delete_variable/3","title":"AWS.FraudDetector.delete_variable/3","type":"function"},{"doc":"Gets all versions for a specified detector.","ref":"AWS.FraudDetector.html#describe_detector/3","title":"AWS.FraudDetector.describe_detector/3","type":"function"},{"doc":"Gets all of the model versions for the specified model type or for the specified\nmodel type and model ID.\n\nYou can also get details for a single, specified model version.","ref":"AWS.FraudDetector.html#describe_model_versions/3","title":"AWS.FraudDetector.describe_model_versions/3","type":"function"},{"doc":"Gets all batch import jobs or a specific job of the specified ID.\n\nThis is a paginated API. If you provide a null `maxResults`, this action\nretrieves a maximum of 50 records per page. If you provide a `maxResults`, the\nvalue must be between 1 and 50. To get the next page results, provide the\npagination token from the `GetBatchImportJobsResponse` as part of your request.\nA null pagination token fetches the records from the beginning.","ref":"AWS.FraudDetector.html#get_batch_import_jobs/3","title":"AWS.FraudDetector.get_batch_import_jobs/3","type":"function"},{"doc":"Gets all batch prediction jobs or a specific job if you specify a job ID.\n\nThis is a paginated API. If you provide a null maxResults, this action retrieves\na maximum of 50 records per page. If you provide a maxResults, the value must be\nbetween 1 and 50. To get the next page results, provide the pagination token\nfrom the GetBatchPredictionJobsResponse as part of your request. A null\npagination token fetches the records from the beginning.","ref":"AWS.FraudDetector.html#get_batch_prediction_jobs/3","title":"AWS.FraudDetector.get_batch_prediction_jobs/3","type":"function"},{"doc":"Retrieves the status of a `DeleteEventsByEventType` action.","ref":"AWS.FraudDetector.html#get_delete_events_by_event_type_status/3","title":"AWS.FraudDetector.get_delete_events_by_event_type_status/3","type":"function"},{"doc":"Gets a particular detector version.","ref":"AWS.FraudDetector.html#get_detector_version/3","title":"AWS.FraudDetector.get_detector_version/3","type":"function"},{"doc":"Gets all detectors or a single detector if a `detectorId` is specified.\n\nThis is a paginated API. If you provide a null `maxResults`, this action\nretrieves a maximum of 10 records per page. If you provide a `maxResults`, the\nvalue must be between 5 and 10. To get the next page results, provide the\npagination token from the `GetDetectorsResponse` as part of your request. A null\npagination token fetches the records from the beginning.","ref":"AWS.FraudDetector.html#get_detectors/3","title":"AWS.FraudDetector.get_detectors/3","type":"function"},{"doc":"Gets all entity types or a specific entity type if a name is specified.\n\nThis is a paginated API. If you provide a null `maxResults`, this action\nretrieves a maximum of 10 records per page. If you provide a `maxResults`, the\nvalue must be between 5 and 10. To get the next page results, provide the\npagination token from the `GetEntityTypesResponse` as part of your request. A\nnull pagination token fetches the records from the beginning.","ref":"AWS.FraudDetector.html#get_entity_types/3","title":"AWS.FraudDetector.get_entity_types/3","type":"function"},{"doc":"Retrieves details of events stored with Amazon Fraud Detector.\n\nThis action does not retrieve prediction results.","ref":"AWS.FraudDetector.html#get_event/3","title":"AWS.FraudDetector.get_event/3","type":"function"},{"doc":"Evaluates an event against a detector version.\n\nIf a version ID is not provided, the detector’s (`ACTIVE`) version is used.","ref":"AWS.FraudDetector.html#get_event_prediction/3","title":"AWS.FraudDetector.get_event_prediction/3","type":"function"},{"doc":"Gets details of the past fraud predictions for the specified event ID, event\ntype, detector ID, and detector version ID that was generated in the specified\ntime period.","ref":"AWS.FraudDetector.html#get_event_prediction_metadata/3","title":"AWS.FraudDetector.get_event_prediction_metadata/3","type":"function"},{"doc":"Gets all event types or a specific event type if name is provided.\n\nThis is a paginated API. If you provide a null `maxResults`, this action\nretrieves a maximum of 10 records per page. If you provide a `maxResults`, the\nvalue must be between 5 and 10. To get the next page results, provide the\npagination token from the `GetEventTypesResponse` as part of your request. A\nnull pagination token fetches the records from the beginning.","ref":"AWS.FraudDetector.html#get_event_types/3","title":"AWS.FraudDetector.get_event_types/3","type":"function"},{"doc":"Gets the details for one or more Amazon SageMaker models that have been imported\ninto the service.\n\nThis is a paginated API. If you provide a null `maxResults`, this actions\nretrieves a maximum of 10 records per page. If you provide a `maxResults`, the\nvalue must be between 5 and 10. To get the next page results, provide the\npagination token from the `GetExternalModelsResult` as part of your request. A\nnull pagination token fetches the records from the beginning.","ref":"AWS.FraudDetector.html#get_external_models/3","title":"AWS.FraudDetector.get_external_models/3","type":"function"},{"doc":"Gets the encryption key if a KMS key has been specified to be used to encrypt\ncontent in Amazon Fraud Detector.","ref":"AWS.FraudDetector.html#get_kms_encryption_key/3","title":"AWS.FraudDetector.get_kms_encryption_key/3","type":"function"},{"doc":"Gets all labels or a specific label if name is provided.\n\nThis is a paginated API. If you provide a null `maxResults`, this action\nretrieves a maximum of 50 records per page. If you provide a `maxResults`, the\nvalue must be between 10 and 50. To get the next page results, provide the\npagination token from the `GetGetLabelsResponse` as part of your request. A null\npagination token fetches the records from the beginning.","ref":"AWS.FraudDetector.html#get_labels/3","title":"AWS.FraudDetector.get_labels/3","type":"function"},{"doc":"Gets all the elements in the specified list.","ref":"AWS.FraudDetector.html#get_list_elements/3","title":"AWS.FraudDetector.get_list_elements/3","type":"function"},{"doc":"Gets the metadata of either all the lists under the account or the specified\nlist.","ref":"AWS.FraudDetector.html#get_lists_metadata/3","title":"AWS.FraudDetector.get_lists_metadata/3","type":"function"},{"doc":"Gets the details of the specified model version.","ref":"AWS.FraudDetector.html#get_model_version/3","title":"AWS.FraudDetector.get_model_version/3","type":"function"},{"doc":"Gets one or more models.\n\nGets all models for the Amazon Web Services account if no model type and no\nmodel id provided. Gets all models for the Amazon Web Services account and model\ntype, if the model type is specified but model id is not provided. Gets a\nspecific model if (model type, model id) tuple is specified.\n\nThis is a paginated API. If you provide a null `maxResults`, this action\nretrieves a maximum of 10 records per page. If you provide a `maxResults`, the\nvalue must be between 1 and 10. To get the next page results, provide the\npagination token from the response as part of your request. A null pagination\ntoken fetches the records from the beginning.","ref":"AWS.FraudDetector.html#get_models/3","title":"AWS.FraudDetector.get_models/3","type":"function"},{"doc":"Gets one or more outcomes.\n\nThis is a paginated API. If you provide a null `maxResults`, this actions\nretrieves a maximum of 100 records per page. If you provide a `maxResults`, the\nvalue must be between 50 and 100. To get the next page results, provide the\npagination token from the `GetOutcomesResult` as part of your request. A null\npagination token fetches the records from the beginning.","ref":"AWS.FraudDetector.html#get_outcomes/3","title":"AWS.FraudDetector.get_outcomes/3","type":"function"},{"doc":"Get all rules for a detector (paginated) if `ruleId` and `ruleVersion` are not\nspecified.\n\nGets all rules for the detector and the `ruleId` if present (paginated). Gets a\nspecific rule if both the `ruleId` and the `ruleVersion` are specified.\n\nThis is a paginated API. Providing null maxResults results in retrieving maximum\nof 100 records per page. If you provide maxResults the value must be between 50\nand 100. To get the next page result, a provide a pagination token from\nGetRulesResult as part of your request. Null pagination token fetches the\nrecords from the beginning.","ref":"AWS.FraudDetector.html#get_rules/3","title":"AWS.FraudDetector.get_rules/3","type":"function"},{"doc":"Gets all of the variables or the specific variable.\n\nThis is a paginated API. Providing null `maxSizePerPage` results in retrieving\nmaximum of 100 records per page. If you provide `maxSizePerPage` the value must\nbe between 50 and 100. To get the next page result, a provide a pagination token\nfrom `GetVariablesResult` as part of your request. Null pagination token fetches\nthe records from the beginning.","ref":"AWS.FraudDetector.html#get_variables/3","title":"AWS.FraudDetector.get_variables/3","type":"function"},{"doc":"Gets a list of past predictions.\n\nThe list can be filtered by detector ID, detector version ID, event ID, event\ntype, or by specifying a time period. If filter is not specified, the most\nrecent prediction is returned.\n\nFor example, the following filter lists all past predictions for `xyz` event\ntype - `{ \"eventType\":{ \"value\": \"xyz\" }” } `\n\nThis is a paginated API. If you provide a null `maxResults`, this action will\nretrieve a maximum of 10 records per page. If you provide a `maxResults`, the\nvalue must be between 50 and 100. To get the next page results, provide the\n`nextToken` from the response as part of your request. A null `nextToken`\nfetches the records from the beginning.","ref":"AWS.FraudDetector.html#list_event_predictions/3","title":"AWS.FraudDetector.list_event_predictions/3","type":"function"},{"doc":"Lists all tags associated with the resource.\n\nThis is a paginated API. To get the next page results, provide the pagination\ntoken from the response as part of your request. A null pagination token fetches\nthe records from the beginning.","ref":"AWS.FraudDetector.html#list_tags_for_resource/3","title":"AWS.FraudDetector.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.FraudDetector.html#metadata/0","title":"AWS.FraudDetector.metadata/0","type":"function"},{"doc":"Creates or updates a detector.","ref":"AWS.FraudDetector.html#put_detector/3","title":"AWS.FraudDetector.put_detector/3","type":"function"},{"doc":"Creates or updates an entity type.\n\nAn entity represents who is performing the event. As part of a fraud prediction,\nyou pass the entity ID to indicate the specific entity who performed the event.\nAn entity type classifies the entity. Example classifications include customer,\nmerchant, or account.","ref":"AWS.FraudDetector.html#put_entity_type/3","title":"AWS.FraudDetector.put_entity_type/3","type":"function"},{"doc":"Creates or updates an event type.\n\nAn event is a business activity that is evaluated for fraud risk. With Amazon\nFraud Detector, you generate fraud predictions for events. An event type defines\nthe structure for an event sent to Amazon Fraud Detector. This includes the\nvariables sent as part of the event, the entity performing the event (such as a\ncustomer), and the labels that classify the event. Example event types include\nonline payment transactions, account registrations, and authentications.","ref":"AWS.FraudDetector.html#put_event_type/3","title":"AWS.FraudDetector.put_event_type/3","type":"function"},{"doc":"Creates or updates an Amazon SageMaker model endpoint.\n\nYou can also use this action to update the configuration of the model endpoint,\nincluding the IAM role and/or the mapped variables.","ref":"AWS.FraudDetector.html#put_external_model/3","title":"AWS.FraudDetector.put_external_model/3","type":"function"},{"doc":"Specifies the KMS key to be used to encrypt content in Amazon Fraud Detector.","ref":"AWS.FraudDetector.html#put_kms_encryption_key/3","title":"AWS.FraudDetector.put_kms_encryption_key/3","type":"function"},{"doc":"Creates or updates label.\n\nA label classifies an event as fraudulent or legitimate. Labels are associated\nwith event types and used to train supervised machine learning models in Amazon\nFraud Detector.","ref":"AWS.FraudDetector.html#put_label/3","title":"AWS.FraudDetector.put_label/3","type":"function"},{"doc":"Creates or updates an outcome.","ref":"AWS.FraudDetector.html#put_outcome/3","title":"AWS.FraudDetector.put_outcome/3","type":"function"},{"doc":"Stores events in Amazon Fraud Detector without generating fraud predictions for\nthose events.\n\nFor example, you can use `SendEvent` to upload a historical dataset, which you\ncan then later use to train a model.","ref":"AWS.FraudDetector.html#send_event/3","title":"AWS.FraudDetector.send_event/3","type":"function"},{"doc":"Assigns tags to a resource.","ref":"AWS.FraudDetector.html#tag_resource/3","title":"AWS.FraudDetector.tag_resource/3","type":"function"},{"doc":"Removes tags from a resource.","ref":"AWS.FraudDetector.html#untag_resource/3","title":"AWS.FraudDetector.untag_resource/3","type":"function"},{"doc":"Updates a detector version.\n\nThe detector version attributes that you can update include models, external\nmodel endpoints, rules, rule execution mode, and description. You can only\nupdate a `DRAFT` detector version.","ref":"AWS.FraudDetector.html#update_detector_version/3","title":"AWS.FraudDetector.update_detector_version/3","type":"function"},{"doc":"Updates the detector version's description.\n\nYou can update the metadata for any detector version (`DRAFT, ACTIVE,` or\n`INACTIVE`).","ref":"AWS.FraudDetector.html#update_detector_version_metadata/3","title":"AWS.FraudDetector.update_detector_version_metadata/3","type":"function"},{"doc":"Updates the detector version’s status.\n\nYou can perform the following promotions or demotions using\n`UpdateDetectorVersionStatus`: `DRAFT` to `ACTIVE`, `ACTIVE` to `INACTIVE`, and\n`INACTIVE` to `ACTIVE`.","ref":"AWS.FraudDetector.html#update_detector_version_status/3","title":"AWS.FraudDetector.update_detector_version_status/3","type":"function"},{"doc":"Updates the specified event with a new label.","ref":"AWS.FraudDetector.html#update_event_label/3","title":"AWS.FraudDetector.update_event_label/3","type":"function"},{"doc":"Updates a list.","ref":"AWS.FraudDetector.html#update_list/3","title":"AWS.FraudDetector.update_list/3","type":"function"},{"doc":"Updates model description.","ref":"AWS.FraudDetector.html#update_model/3","title":"AWS.FraudDetector.update_model/3","type":"function"},{"doc":"Updates a model version.\n\nUpdating a model version retrains an existing model version using updated\ntraining data and produces a new minor version of the model. You can update the\ntraining data set location and data access role attributes using this action.\nThis action creates and trains a new minor version of the model, for example\nversion 1.01, 1.02, 1.03.","ref":"AWS.FraudDetector.html#update_model_version/3","title":"AWS.FraudDetector.update_model_version/3","type":"function"},{"doc":"Updates the status of a model version.\n\nYou can perform the following status updates:\n\n  1. Change the `TRAINING_IN_PROGRESS` status to `TRAINING_CANCELLED`.\n\n  2. Change the `TRAINING_COMPLETE` status to `ACTIVE`.\n\n  3. Change `ACTIVE` to `INACTIVE`.","ref":"AWS.FraudDetector.html#update_model_version_status/3","title":"AWS.FraudDetector.update_model_version_status/3","type":"function"},{"doc":"Updates a rule's metadata.\n\nThe description attribute can be updated.","ref":"AWS.FraudDetector.html#update_rule_metadata/3","title":"AWS.FraudDetector.update_rule_metadata/3","type":"function"},{"doc":"Updates a rule version resulting in a new rule version.\n\nUpdates a rule version resulting in a new rule version (version 1, 2, 3 ...).","ref":"AWS.FraudDetector.html#update_rule_version/3","title":"AWS.FraudDetector.update_rule_version/3","type":"function"},{"doc":"Updates a variable.","ref":"AWS.FraudDetector.html#update_variable/3","title":"AWS.FraudDetector.update_variable/3","type":"function"},{"doc":"You can use the Amazon Web Services Free Tier API to query programmatically your\nFree Tier usage data.\n\nFree Tier tracks your monthly usage data for all free tier offers that are\nassociated with your Amazon Web Services account. You can use the Free Tier API\nto filter and show only the data that you want.\n\nService endpoint\n\nThe Free Tier API provides the following endpoint:\n\n  * https://freetier.us-east-1.api.aws\n\nFor more information, see [Using the Amazon Web Services Free Tier](https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-free-tier.html)\nin the *Billing User Guide*.","ref":"AWS.FreeTier.html","title":"AWS.FreeTier","type":"module"},{"doc":"Returns a list of all Free Tier usage objects that match your filters.","ref":"AWS.FreeTier.html#get_free_tier_usage/3","title":"AWS.FreeTier.get_free_tier_usage/3","type":"function"},{"doc":"","ref":"AWS.FreeTier.html#metadata/0","title":"AWS.FreeTier.metadata/0","type":"function"},{"doc":"Amazon GameLift provides solutions for hosting session-based multiplayer game\nservers in the cloud, including tools for deploying, operating, and scaling game\nservers.\n\nBuilt on Amazon Web Services global computing infrastructure, GameLift helps you\ndeliver high-performance, high-reliability, low-cost game servers while\ndynamically scaling your resource usage to meet player demand.","ref":"AWS.GameLift.html","title":"AWS.GameLift","type":"module"},{"doc":"Get more information on these Amazon GameLift solutions in the [Amazon GameLift Developer Guide](https://docs.aws.amazon.com/gamelift/latest/developerguide/).\n\n  * Amazon GameLift managed hosting -- Amazon GameLift offers a fully\nmanaged service to set up and maintain computing machines for hosting, manage\ngame session and player session life cycle, and handle security, storage, and\nperformance tracking. You can use automatic scaling tools to balance player\ndemand and hosting costs, configure your game session management to minimize\nplayer latency, and add FlexMatch for matchmaking.\n\n  * Managed hosting with Realtime Servers -- With Amazon GameLift\nRealtime Servers, you can quickly configure and set up ready-to-go game servers\nfor your game. Realtime Servers provides a game server framework with core\nAmazon GameLift infrastructure already built in. Then use the full range of\nAmazon GameLift managed hosting features, including FlexMatch, for your game.\n\n  * Amazon GameLift FleetIQ -- Use Amazon GameLift FleetIQ as a\nstandalone service while hosting your games using EC2 instances and Auto Scaling\ngroups. Amazon GameLift FleetIQ provides optimizations for game hosting,\nincluding boosting the viability of low-cost Spot Instances gaming. For a\ncomplete solution, pair the Amazon GameLift FleetIQ and FlexMatch standalone\nservices.\n\n  * Amazon GameLift FlexMatch -- Add matchmaking to your game hosting\nsolution. FlexMatch is a customizable matchmaking service for multiplayer games.\nUse FlexMatch as integrated with Amazon GameLift managed hosting or incorporate\nFlexMatch as a standalone service into your own hosting solution.","ref":"AWS.GameLift.html#module-about-amazon-gamelift-solutions","title":"About Amazon GameLift solutions - AWS.GameLift","type":"module"},{"doc":"This reference guide describes the low-level service API for Amazon GameLift.\nWith each topic in this guide, you can find links to language-specific SDK\nguides and the Amazon Web Services CLI reference. Useful links:\n\n  * [Amazon GameLift API operations listed by tasks](https://docs.aws.amazon.com/gamelift/latest/developerguide/reference-awssdk.html)\n\n  * [ Amazon GameLift tools and resources](https://docs.aws.amazon.com/gamelift/latest/developerguide/gamelift-components.html)","ref":"AWS.GameLift.html#module-about-this-api-reference","title":"About this API Reference - AWS.GameLift","type":"module"},{"doc":"Registers a player's acceptance or rejection of a proposed FlexMatch match.\n\nA matchmaking configuration may require player acceptance; if so, then matches\nbuilt with that configuration cannot be completed unless all players accept the\nproposed match within a specified time limit.\n\nWhen FlexMatch builds a match, all the matchmaking tickets involved in the\nproposed match are placed into status `REQUIRES_ACCEPTANCE`. This is a trigger\nfor your game to get acceptance from all players in each ticket. Calls to this\naction are only valid for tickets that are in this status; calls for tickets not\nin this status result in an error.\n\nTo register acceptance, specify the ticket ID, one or more players, and an\nacceptance response. When all players have accepted, Amazon GameLift advances\nthe matchmaking tickets to status `PLACING`, and attempts to create a new game\nsession for the match.\n\nIf any player rejects the match, or if acceptances are not received before a\nspecified timeout, the proposed match is dropped. Each matchmaking ticket in the\nfailed match is handled as follows:\n\n  * If the ticket has one or more players who rejected the match or\nfailed to respond, the ticket status is set `CANCELLED` and processing is\nterminated.\n\n  * If all players in the ticket accepted the match, the ticket status\nis returned to `SEARCHING` to find a new match.","ref":"AWS.GameLift.html#accept_match/3","title":"AWS.GameLift.accept_match/3","type":"function"},{"doc":"[ Add FlexMatch to a game client](https://docs.aws.amazon.com/gamelift/latest/flexmatchguide/match-client.html)\n\n[ FlexMatch events](https://docs.aws.amazon.com/gamelift/latest/flexmatchguide/match-events.html)\n(reference)","ref":"AWS.GameLift.html#accept_match/3-learn-more","title":"Learn more - AWS.GameLift.accept_match/3","type":"function"},{"doc":"","ref":"AWS.GameLift.html#claim_game_server/3","title":"AWS.GameLift.claim_game_server/3","type":"function"},{"doc":"server groups.\n\nLocates an available game server and temporarily reserves it to host gameplay\nand players.\n\nThis operation is called from a game client or client service (such as a\nmatchmaker) to request hosting resources for a new game session. In response,\nAmazon GameLift FleetIQ locates an available game server, places it in `CLAIMED`\nstatus for 60 seconds, and returns connection information that players can use\nto connect to the game server.\n\nTo claim a game server, identify a game server group. You can also specify a\ngame server ID, although this approach bypasses Amazon GameLift FleetIQ\nplacement optimization. Optionally, include game data to pass to the game server\nat the start of a game session, such as a game map or player information. Add\nfilter options to further restrict how a game server is chosen, such as only\nallowing game servers on `ACTIVE` instances to be claimed.\n\nWhen a game server is successfully claimed, connection information is returned.\nA claimed game server's utilization status remains `AVAILABLE` while the claim\nstatus is set to `CLAIMED` for up to 60 seconds. This time period gives the game\nserver time to update its status to `UTILIZED` after players join. If the game\nserver's status is not updated within 60 seconds, the game server reverts to\nunclaimed status and is available to be claimed by another request. The claim\ntime period is a fixed value and is not configurable.\n\nIf you try to claim a specific game server, this request will fail in the\nfollowing cases:\n\n  * If the game server utilization status is `UTILIZED`.\n\n  * If the game server claim status is `CLAIMED`.\n\n  * If the game server is running on an instance in `DRAINING` status\nand the provided filter option does not allow placing on `DRAINING` instances.","ref":"AWS.GameLift.html#claim_game_server/3-this-operation-is-used-with-the-amazon-gamelift-fleetiq-solution-and-game","title":"This operation is used with the Amazon GameLift FleetIQ solution and game - AWS.GameLift.claim_game_server/3","type":"function"},{"doc":"[Amazon GameLift FleetIQ Guide](https://docs.aws.amazon.com/gamelift/latest/fleetiqguide/gsg-intro.html)","ref":"AWS.GameLift.html#claim_game_server/3-learn-more","title":"Learn more - AWS.GameLift.claim_game_server/3","type":"function"},{"doc":"Creates an alias for a fleet.\n\nIn most situations, you can use an alias ID in place of a fleet ID. An alias\nprovides a level of abstraction for a fleet that is useful when redirecting\nplayer traffic from one fleet to another, such as when updating your game build.\n\nAmazon GameLift supports two types of routing strategies for aliases: simple and\nterminal. A simple alias points to an active fleet. A terminal alias is used to\ndisplay messaging or link to a URL instead of routing players to an active\nfleet. For example, you might use a terminal alias when a game version is no\nlonger supported and you want to direct players to an upgrade site.\n\nTo create a fleet alias, specify an alias name, routing strategy, and optional\ndescription. Each simple alias can point to only one fleet, but a fleet can have\nmultiple aliases. If successful, a new alias record is returned, including an\nalias ID and an ARN. You can reassign an alias to another fleet by calling\n`UpdateAlias`.","ref":"AWS.GameLift.html#create_alias/3","title":"AWS.GameLift.create_alias/3","type":"function"},{"doc":"[All APIs by task](https://docs.aws.amazon.com/gamelift/latest/developerguide/reference-awssdk.html#reference-awssdk-resources-fleets)","ref":"AWS.GameLift.html#create_alias/3-related-actions","title":"Related actions - AWS.GameLift.create_alias/3","type":"function"},{"doc":"Creates a new Amazon GameLift build resource for your game server binary files.\n\nCombine game server binaries into a zip file for use with Amazon GameLift.\n\nWhen setting up a new game build for Amazon GameLift, we recommend using the CLI\ncommand **\n[upload-build](https://docs.aws.amazon.com/cli/latest/reference/gamelift/upload-build.html) **. This helper command combines two tasks: (1) it uploads your build files from\na file directory to an Amazon GameLift Amazon S3 location, and (2) it creates a\nnew build resource.\n\nYou can use the `CreateBuild` operation in the following scenarios:\n\n  * Create a new game build with build files that are in an Amazon S3\nlocation under an Amazon Web Services account that you control. To use this\noption, you give Amazon GameLift access to the Amazon S3 bucket. With\npermissions in place, specify a build name, operating system, and the Amazon S3\nstorage location of your game build.\n\n  * Upload your build files to a Amazon GameLift Amazon S3 location.\nTo use this option, specify a build name and operating system. This operation\ncreates a new build resource and also returns an Amazon S3 location with\ntemporary access credentials. Use the credentials to manually upload your build\nfiles to the specified Amazon S3 location. For more information, see [Uploading\nObjects](https://docs.aws.amazon.com/AmazonS3/latest/dev/UploadingObjects.html)\nin the *Amazon S3 Developer Guide*. After you upload build files to the Amazon\nGameLift Amazon S3 location, you can't update them.\n\nIf successful, this operation creates a new build resource with a unique build\nID and places it in `INITIALIZED` status. A build must be in `READY` status\nbefore you can create fleets with it.","ref":"AWS.GameLift.html#create_build/3","title":"AWS.GameLift.create_build/3","type":"function"},{"doc":"[Uploading Your Game](https://docs.aws.amazon.com/gamelift/latest/developerguide/gamelift-build-intro.html)\n\n[ Create a Build with Files in Amazon S3](https://docs.aws.amazon.com/gamelift/latest/developerguide/gamelift-build-cli-uploading.html#gamelift-build-cli-uploading-create-build)\n\n[All APIs by task](https://docs.aws.amazon.com/gamelift/latest/developerguide/reference-awssdk.html#reference-awssdk-resources-fleets)","ref":"AWS.GameLift.html#create_build/3-learn-more","title":"Learn more - AWS.GameLift.create_build/3","type":"function"},{"doc":"Creates a fleet of Amazon Elastic Compute Cloud (Amazon EC2) instances to host\nyour custom game server or Realtime Servers.\n\nUse this operation to configure the computing resources for your fleet and\nprovide instructions for running game servers on each instance.\n\nMost Amazon GameLift fleets can deploy instances to multiple locations,\nincluding the home Region (where the fleet is created) and an optional set of\nremote locations. Fleets that are created in the following Amazon Web Services\nRegions support multiple locations: us-east-1 (N. Virginia), us-west-2 (Oregon),\neu-central-1 (Frankfurt), eu-west-1 (Ireland), ap-southeast-2 (Sydney),\nap-northeast-1 (Tokyo), and ap-northeast-2 (Seoul). Fleets that are created in\nother Amazon GameLift Regions can deploy instances in the fleet's home Region\nonly. All fleet instances use the same configuration regardless of location;\nhowever, you can adjust capacity settings and turn auto-scaling on/off for each\nlocation.\n\nTo create a fleet, choose the hardware for your instances, specify a game server\nbuild or Realtime script to deploy, and provide a runtime configuration to\ndirect Amazon GameLift how to start and run game servers on each instance in the\nfleet. Set permissions for inbound traffic to your game servers, and enable\noptional features as needed. When creating a multi-location fleet, provide a\nlist of additional remote locations.\n\nIf you need to debug your fleet, fetch logs, view performance metrics or other\nactions on the fleet, create the development fleet with port 22/3389 open. As a\nbest practice, we recommend opening ports for remote access only when you need\nthem and closing them when you're finished.\n\nIf successful, this operation creates a new Fleet resource and places it in\n`NEW` status, which prompts Amazon GameLift to initiate the [fleet creation workflow](https://docs.aws.amazon.com/gamelift/latest/developerguide/fleets-creating-all.html#fleets-creation-workflow).\nYou can track fleet creation by checking fleet status using\n`DescribeFleetAttributes` and `DescribeFleetLocationAttributes`/, or by\nmonitoring fleet creation events using `DescribeFleetEvents`.\n\nWhen the fleet status changes to `ACTIVE`, you can enable automatic scaling with\n`PutScalingPolicy` and set capacity for the home Region with\n`UpdateFleetCapacity`. When the status of each remote location reaches `ACTIVE`,\nyou can set capacity by location using `UpdateFleetCapacity`.","ref":"AWS.GameLift.html#create_fleet/3","title":"AWS.GameLift.create_fleet/3","type":"function"},{"doc":"[Setting up fleets](https://docs.aws.amazon.com/gamelift/latest/developerguide/fleets-intro.html)\n\n[Debug fleet creation issues](https://docs.aws.amazon.com/gamelift/latest/developerguide/fleets-creating-debug.html#fleets-creating-debug-creation)\n\n[Multi-location fleets](https://docs.aws.amazon.com/gamelift/latest/developerguide/fleets-intro.html)","ref":"AWS.GameLift.html#create_fleet/3-learn-more","title":"Learn more - AWS.GameLift.create_fleet/3","type":"function"},{"doc":"Adds remote locations to a fleet and begins populating the new locations with\nEC2 instances.\n\nThe new instances conform to the fleet's instance type, auto-scaling, and other\nconfiguration settings.\n\nThis operation cannot be used with fleets that don't support remote locations.\nFleets can have multiple locations only if they reside in Amazon Web Services\nRegions that support this feature and were created after the feature was\nreleased in March 2021.\n\nTo add fleet locations, specify the fleet to be updated and provide a list of\none or more locations.\n\nIf successful, this operation returns the list of added locations with their\nstatus set to `NEW`. Amazon GameLift initiates the process of starting an\ninstance in each added location. You can track the status of each new location\nby monitoring location creation events using\n[DescribeFleetEvents](https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeFleetEvents.html).","ref":"AWS.GameLift.html#create_fleet_locations/3","title":"AWS.GameLift.create_fleet_locations/3","type":"function"},{"doc":"[Setting up\nfleets](https://docs.aws.amazon.com/gamelift/latest/developerguide/fleets-intro.html)\n\n[Multi-location fleets](https://docs.aws.amazon.com/gamelift/latest/developerguide/fleets-intro.html)","ref":"AWS.GameLift.html#create_fleet_locations/3-learn-more","title":"Learn more - AWS.GameLift.create_fleet_locations/3","type":"function"},{"doc":"","ref":"AWS.GameLift.html#create_game_server_group/3","title":"AWS.GameLift.create_game_server_group/3","type":"function"},{"doc":"server groups.\n\nCreates a Amazon GameLift FleetIQ game server group for managing game hosting on\na collection of Amazon Elastic Compute Cloud instances for game hosting.\n\nThis operation creates the game server group, creates an Auto Scaling group in\nyour Amazon Web Services account, and establishes a link between the two groups.\nYou can view the status of your game server groups in the Amazon GameLift\nconsole. Game server group metrics and events are emitted to Amazon CloudWatch.\n\nBefore creating a new game server group, you must have the following:\n\n  * An Amazon Elastic Compute Cloud launch template that specifies how\nto launch Amazon Elastic Compute Cloud instances with your game server build.\nFor more information, see [ Launching an Instance from a Launch Template](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-launch-templates.html)\nin the *Amazon Elastic Compute Cloud User Guide*.\n\n  * An IAM role that extends limited access to your Amazon Web\nServices account to allow Amazon GameLift FleetIQ to create and interact with\nthe Auto Scaling group. For more information, see [Create IAM roles for cross-service\ninteraction](https://docs.aws.amazon.com/gamelift/latest/fleetiqguide/gsg-iam-permissions-roles.html)\nin the *Amazon GameLift FleetIQ Developer Guide*.\n\nTo create a new game server group, specify a unique group name, IAM role and\nAmazon Elastic Compute Cloud launch template, and provide a list of instance\ntypes that can be used in the group. You must also set initial maximum and\nminimum limits on the group's instance count. You can optionally set an Auto\nScaling policy with target tracking based on a Amazon GameLift FleetIQ metric.\n\nOnce the game server group and corresponding Auto Scaling group are created, you\nhave full access to change the Auto Scaling group's configuration as needed.\nSeveral properties that are set when creating a game server group, including\nmaximum/minimum size and auto-scaling policy settings, must be updated directly\nin the Auto Scaling group. Keep in mind that some Auto Scaling group properties\nare periodically updated by Amazon GameLift FleetIQ as part of its balancing\nactivities to optimize for availability and cost.","ref":"AWS.GameLift.html#create_game_server_group/3-this-operation-is-used-with-the-amazon-gamelift-fleetiq-solution-and-game","title":"This operation is used with the Amazon GameLift FleetIQ solution and game - AWS.GameLift.create_game_server_group/3","type":"function"},{"doc":"[Amazon GameLift FleetIQ Guide](https://docs.aws.amazon.com/gamelift/latest/fleetiqguide/gsg-intro.html)","ref":"AWS.GameLift.html#create_game_server_group/3-learn-more","title":"Learn more - AWS.GameLift.create_game_server_group/3","type":"function"},{"doc":"Creates a multiplayer game session for players in a specific fleet location.\n\nThis operation prompts an available server process to start a game session and\nretrieves connection information for the new game session. As an alternative,\nconsider using the Amazon GameLift game session placement feature with\n[StartGameSessionPlacement](https://docs.aws.amazon.com/gamelift/latest/apireference/API_StartGameSessionPlacement.html) , which uses the FleetIQ algorithm and queues to optimize the placement process.\n\nWhen creating a game session, you specify exactly where you want to place it and\nprovide a set of game session configuration settings. The target fleet must be\nin `ACTIVE` status.\n\nYou can use this operation in the following ways:\n\n  * To create a game session on an instance in a fleet's home Region,\nprovide a fleet or alias ID along with your game session configuration.\n\n  * To create a game session on an instance in a fleet's remote\nlocation, provide a fleet or alias ID and a location name, along with your game\nsession configuration.\n\n  * To create a game session on an instance in an Anywhere fleet,\nspecify the fleet's custom location.\n\nIf successful, Amazon GameLift initiates a workflow to start a new game session\nand returns a `GameSession` object containing the game session configuration and\nstatus. When the game session status is `ACTIVE`, it is updated with connection\ninformation and you can create player sessions for the game session. By default,\nnewly created game sessions are open to new players. You can restrict new player\naccess by using\n[UpdateGameSession](https://docs.aws.amazon.com/gamelift/latest/apireference/API_UpdateGameSession.html)\nto change the game session's player session creation policy.\n\nAmazon GameLift retains logs for active for 14 days. To access the logs, call\n[GetGameSessionLogUrl](https://docs.aws.amazon.com/gamelift/latest/apireference/API_GetGameSessionLogUrl.html) to download the log files.\n\n*Available in Amazon GameLift Local.*","ref":"AWS.GameLift.html#create_game_session/3","title":"AWS.GameLift.create_game_session/3","type":"function"},{"doc":"[Start a game\nsession](https://docs.aws.amazon.com/gamelift/latest/developerguide/gamelift-sdk-server-api.html#gamelift-sdk-server-startsession)\n\n[All APIs by task](https://docs.aws.amazon.com/gamelift/latest/developerguide/reference-awssdk.html#reference-awssdk-resources-fleets)","ref":"AWS.GameLift.html#create_game_session/3-learn-more","title":"Learn more - AWS.GameLift.create_game_session/3","type":"function"},{"doc":"Creates a placement queue that processes requests for new game sessions.\n\nA queue uses FleetIQ algorithms to determine the best placement locations and\nfind an available game server there, then prompts the game server process to\nstart a new game session.\n\nA game session queue is configured with a set of destinations (Amazon GameLift\nfleets or aliases), which determine the locations where the queue can place new\ngame sessions. These destinations can span multiple fleet types (Spot and\nOn-Demand), instance types, and Amazon Web Services Regions. If the queue\nincludes multi-location fleets, the queue is able to place game sessions in all\nof a fleet's remote locations. You can opt to filter out individual locations if\nneeded.\n\nThe queue configuration also determines how FleetIQ selects the best available\nplacement for a new game session. Before searching for an available game server,\nFleetIQ first prioritizes the queue's destinations and locations, with the best\nplacement locations on top. You can set up the queue to use the FleetIQ default\nprioritization or provide an alternate set of priorities.\n\nTo create a new queue, provide a name, timeout value, and a list of\ndestinations. Optionally, specify a sort configuration and/or a filter, and\ndefine a set of latency cap policies. You can also include the ARN for an Amazon\nSimple Notification Service (SNS) topic to receive notifications of game session\nplacement activity. Notifications using SNS or CloudWatch events is the\npreferred way to track placement activity.\n\nIf successful, a new `GameSessionQueue` object is returned with an assigned\nqueue ARN. New game session requests, which are submitted to queue with\n[StartGameSessionPlacement](https://docs.aws.amazon.com/gamelift/latest/apireference/API_StartGameSessionPlacement.html) or\n[StartMatchmaking](https://docs.aws.amazon.com/gamelift/latest/apireference/API_StartMatchmaking.html),\nreference a queue's name or ARN.","ref":"AWS.GameLift.html#create_game_session_queue/3","title":"AWS.GameLift.create_game_session_queue/3","type":"function"},{"doc":"[ Design a game session queue](https://docs.aws.amazon.com/gamelift/latest/developerguide/queues-design.html)\n\n[ Create a game session queue](https://docs.aws.amazon.com/gamelift/latest/developerguide/queues-creating.html)","ref":"AWS.GameLift.html#create_game_session_queue/3-learn-more","title":"Learn more - AWS.GameLift.create_game_session_queue/3","type":"function"},{"doc":"[CreateGameSessionQueue](https://docs.aws.amazon.com/gamelift/latest/apireference/API_CreateGameSessionQueue.html) |\n[DescribeGameSessionQueues](https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeGameSessionQueues.html)\n|\n[UpdateGameSessionQueue](https://docs.aws.amazon.com/gamelift/latest/apireference/API_UpdateGameSessionQueue.html) |\n[DeleteGameSessionQueue](https://docs.aws.amazon.com/gamelift/latest/apireference/API_DeleteGameSessionQueue.html)\n| [All APIs by task](https://docs.aws.amazon.com/gamelift/latest/developerguide/reference-awssdk.html#reference-awssdk-resources-fleets)","ref":"AWS.GameLift.html#create_game_session_queue/3-related-actions","title":"Related actions - AWS.GameLift.create_game_session_queue/3","type":"function"},{"doc":"Creates a custom location for use in an Anywhere fleet.","ref":"AWS.GameLift.html#create_location/3","title":"AWS.GameLift.create_location/3","type":"function"},{"doc":"Defines a new matchmaking configuration for use with FlexMatch.\n\nWhether your are using FlexMatch with Amazon GameLift hosting or as a standalone\nmatchmaking service, the matchmaking configuration sets out rules for matching\nplayers and forming teams. If you're also using Amazon GameLift hosting, it\ndefines how to start game sessions for each match. Your matchmaking system can\nuse multiple configurations to handle different game scenarios. All matchmaking\nrequests identify the matchmaking configuration to use and provide player\nattributes consistent with that configuration.\n\nTo create a matchmaking configuration, you must provide the following:\nconfiguration name and FlexMatch mode (with or without Amazon GameLift hosting);\na rule set that specifies how to evaluate players and find acceptable matches;\nwhether player acceptance is required; and the maximum time allowed for a\nmatchmaking attempt. When using FlexMatch with Amazon GameLift hosting, you also\nneed to identify the game session queue to use when starting a game session for\nthe match.\n\nIn addition, you must set up an Amazon Simple Notification Service topic to\nreceive matchmaking notifications. Provide the topic ARN in the matchmaking\nconfiguration.","ref":"AWS.GameLift.html#create_matchmaking_configuration/3","title":"AWS.GameLift.create_matchmaking_configuration/3","type":"function"},{"doc":"[ Design a FlexMatch matchmaker](https://docs.aws.amazon.com/gamelift/latest/flexmatchguide/match-configuration.html)\n\n[ Set up FlexMatch event notification](https://docs.aws.amazon.com/gamelift/latest/flexmatchguide/match-notification.html)","ref":"AWS.GameLift.html#create_matchmaking_configuration/3-learn-more","title":"Learn more - AWS.GameLift.create_matchmaking_configuration/3","type":"function"},{"doc":"Creates a new rule set for FlexMatch matchmaking.\n\nA rule set describes the type of match to create, such as the number and size of\nteams. It also sets the parameters for acceptable player matches, such as\nminimum skill level or character type.\n\nTo create a matchmaking rule set, provide unique rule set name and the rule set\nbody in JSON format. Rule sets must be defined in the same Region as the\nmatchmaking configuration they are used with.\n\nSince matchmaking rule sets cannot be edited, it is a good idea to check the\nrule set syntax using\n[ValidateMatchmakingRuleSet](https://docs.aws.amazon.com/gamelift/latest/apireference/API_ValidateMatchmakingRuleSet.html) before creating a new rule set.","ref":"AWS.GameLift.html#create_matchmaking_rule_set/3","title":"AWS.GameLift.create_matchmaking_rule_set/3","type":"function"},{"doc":"* [Build a rule\nset](https://docs.aws.amazon.com/gamelift/latest/flexmatchguide/match-rulesets.html)\n\n  * [Design a matchmaker](https://docs.aws.amazon.com/gamelift/latest/flexmatchguide/match-configuration.html)\n\n  * [Matchmaking with FlexMatch](https://docs.aws.amazon.com/gamelift/latest/flexmatchguide/match-intro.html)","ref":"AWS.GameLift.html#create_matchmaking_rule_set/3-learn-more","title":"Learn more - AWS.GameLift.create_matchmaking_rule_set/3","type":"function"},{"doc":"Reserves an open player slot in a game session for a player.\n\nNew player sessions can be created in any game session with an open slot that is\nin `ACTIVE` status and has a player creation policy of `ACCEPT_ALL`. You can add\na group of players to a game session with\n[CreatePlayerSessions](https://docs.aws.amazon.com/gamelift/latest/apireference/API_CreatePlayerSessions.html) .\n\nTo create a player session, specify a game session ID, player ID, and optionally\na set of player data.\n\nIf successful, a slot is reserved in the game session for the player and a new\n`PlayerSessions` object is returned with a player session ID. The player\nreferences the player session ID when sending a connection request to the game\nsession, and the game server can use it to validate the player reservation with\nthe Amazon GameLift service. Player sessions cannot be updated.\n\nThe maximum number of players per game session is 200. It is not adjustable.","ref":"AWS.GameLift.html#create_player_session/3","title":"AWS.GameLift.create_player_session/3","type":"function"},{"doc":"[All APIs by\ntask](https://docs.aws.amazon.com/gamelift/latest/developerguide/reference-awssdk.html#reference-awssdk-resources-fleets)","ref":"AWS.GameLift.html#create_player_session/3-related-actions","title":"Related actions - AWS.GameLift.create_player_session/3","type":"function"},{"doc":"Reserves open slots in a game session for a group of players.\n\nNew player sessions can be created in any game session with an open slot that is\nin `ACTIVE` status and has a player creation policy of `ACCEPT_ALL`. To add a\nsingle player to a game session, use\n[CreatePlayerSession](https://docs.aws.amazon.com/gamelift/latest/apireference/API_CreatePlayerSession.html)  To create player sessions, specify a game session ID and a list of player IDs.\nOptionally, provide a set of player data for each player ID.\n\nIf successful, a slot is reserved in the game session for each player, and new\n`PlayerSession` objects are returned with player session IDs. Each player\nreferences their player session ID when sending a connection request to the game\nsession, and the game server can use it to validate the player reservation with\nthe Amazon GameLift service. Player sessions cannot be updated.\n\nThe maximum number of players per game session is 200. It is not adjustable.","ref":"AWS.GameLift.html#create_player_sessions/3","title":"AWS.GameLift.create_player_sessions/3","type":"function"},{"doc":"[All APIs by\ntask](https://docs.aws.amazon.com/gamelift/latest/developerguide/reference-awssdk.html#reference-awssdk-resources-fleets)","ref":"AWS.GameLift.html#create_player_sessions/3-related-actions","title":"Related actions - AWS.GameLift.create_player_sessions/3","type":"function"},{"doc":"Creates a new script record for your Realtime Servers script.\n\nRealtime scripts are JavaScript that provide configuration settings and optional\ncustom game logic for your game. The script is deployed when you create a\nRealtime Servers fleet to host your game sessions. Script logic is executed\nduring an active game session.\n\nTo create a new script record, specify a script name and provide the script\nfile(s). The script files and all dependencies must be zipped into a single\nfile. You can pull the zip file from either of these locations:\n\n  * A locally available directory. Use the *ZipFile* parameter for\nthis option.\n\n  * An Amazon Simple Storage Service (Amazon S3) bucket under your\nAmazon Web Services account. Use the *StorageLocation* parameter for this\noption. You'll need to have an Identity Access Management (IAM) role that allows\nthe Amazon GameLift service to access your S3 bucket.\n\nIf the call is successful, a new script record is created with a unique script\nID. If the script file is provided as a local file, the file is uploaded to an\nAmazon GameLift-owned S3 bucket and the script record's storage location\nreflects this location. If the script file is provided as an S3 bucket, Amazon\nGameLift accesses the file at this storage location as needed for deployment.","ref":"AWS.GameLift.html#create_script/3","title":"AWS.GameLift.create_script/3","type":"function"},{"doc":"[Amazon GameLift Realtime Servers](https://docs.aws.amazon.com/gamelift/latest/developerguide/realtime-intro.html)\n\n[Set Up a Role for Amazon GameLift Access](https://docs.aws.amazon.com/gamelift/latest/developerguide/setting-up-role.html)","ref":"AWS.GameLift.html#create_script/3-learn-more","title":"Learn more - AWS.GameLift.create_script/3","type":"function"},{"doc":"[All APIs by task](https://docs.aws.amazon.com/gamelift/latest/developerguide/reference-awssdk.html#reference-awssdk-resources-fleets)","ref":"AWS.GameLift.html#create_script/3-related-actions","title":"Related actions - AWS.GameLift.create_script/3","type":"function"},{"doc":"Requests authorization to create or delete a peer connection between the VPC for\nyour Amazon GameLift fleet and a virtual private cloud (VPC) in your Amazon Web\nServices account.\n\nVPC peering enables the game servers on your fleet to communicate directly with\nother Amazon Web Services resources. After you've received authorization, use\n[CreateVpcPeeringConnection](https://docs.aws.amazon.com/gamelift/latest/apireference/API_CreateVpcPeeringConnection.html) to establish the peering connection. For more information, see [VPC Peering with\nAmazon GameLift\nFleets](https://docs.aws.amazon.com/gamelift/latest/developerguide/vpc-peering.html).\n\nYou can peer with VPCs that are owned by any Amazon Web Services account you\nhave access to, including the account that you use to manage your Amazon\nGameLift fleets. You cannot peer with VPCs that are in different Regions.\n\nTo request authorization to create a connection, call this operation from the\nAmazon Web Services account with the VPC that you want to peer to your Amazon\nGameLift fleet. For example, to enable your game servers to retrieve data from a\nDynamoDB table, use the account that manages that DynamoDB resource. Identify\nthe following values: (1) The ID of the VPC that you want to peer with, and (2)\nthe ID of the Amazon Web Services account that you use to manage Amazon\nGameLift. If successful, VPC peering is authorized for the specified VPC.\n\nTo request authorization to delete a connection, call this operation from the\nAmazon Web Services account with the VPC that is peered with your Amazon\nGameLift fleet. Identify the following values: (1) VPC ID that you want to\ndelete the peering connection for, and (2) ID of the Amazon Web Services account\nthat you use to manage Amazon GameLift.\n\nThe authorization remains valid for 24 hours unless it is canceled. You must\ncreate or delete the peering connection while the authorization is valid.","ref":"AWS.GameLift.html#create_vpc_peering_authorization/3","title":"AWS.GameLift.create_vpc_peering_authorization/3","type":"function"},{"doc":"[All APIs by task](https://docs.aws.amazon.com/gamelift/latest/developerguide/reference-awssdk.html#reference-awssdk-resources-fleets)","ref":"AWS.GameLift.html#create_vpc_peering_authorization/3-related-actions","title":"Related actions - AWS.GameLift.create_vpc_peering_authorization/3","type":"function"},{"doc":"Establishes a VPC peering connection between a virtual private cloud (VPC) in an\nAmazon Web Services account with the VPC for your Amazon GameLift fleet.\n\nVPC peering enables the game servers on your fleet to communicate directly with\nother Amazon Web Services resources. You can peer with VPCs in any Amazon Web\nServices account that you have access to, including the account that you use to\nmanage your Amazon GameLift fleets. You cannot peer with VPCs that are in\ndifferent Regions. For more information, see [VPC Peering with Amazon GameLift Fleets](https://docs.aws.amazon.com/gamelift/latest/developerguide/vpc-peering.html).\n\nBefore calling this operation to establish the peering connection, you first\nneed to use\n[CreateVpcPeeringAuthorization](https://docs.aws.amazon.com/gamelift/latest/apireference/API_CreateVpcPeeringAuthorization.html) and identify the VPC you want to peer with. Once the authorization for the\nspecified VPC is issued, you have 24 hours to establish the connection. These\ntwo operations handle all tasks necessary to peer the two VPCs, including\nacceptance, updating routing tables, etc.\n\nTo establish the connection, call this operation from the Amazon Web Services\naccount that is used to manage the Amazon GameLift fleets. Identify the\nfollowing values: (1) The ID of the fleet you want to be enable a VPC peering\nconnection for; (2) The Amazon Web Services account with the VPC that you want\nto peer with; and (3) The ID of the VPC you want to peer with. This operation is\nasynchronous. If successful, a connection request is created. You can use\ncontinuous polling to track the request's status using\n[DescribeVpcPeeringConnections](https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeVpcPeeringConnections.html)\n, or by monitoring fleet events for success or failure using\n[DescribeFleetEvents](https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeFleetEvents.html) .","ref":"AWS.GameLift.html#create_vpc_peering_connection/3","title":"AWS.GameLift.create_vpc_peering_connection/3","type":"function"},{"doc":"[All APIs by\ntask](https://docs.aws.amazon.com/gamelift/latest/developerguide/reference-awssdk.html#reference-awssdk-resources-fleets)","ref":"AWS.GameLift.html#create_vpc_peering_connection/3-related-actions","title":"Related actions - AWS.GameLift.create_vpc_peering_connection/3","type":"function"},{"doc":"Deletes an alias.\n\nThis operation removes all record of the alias. Game clients attempting to\naccess a server process using the deleted alias receive an error. To delete an\nalias, specify the alias ID to be deleted.","ref":"AWS.GameLift.html#delete_alias/3","title":"AWS.GameLift.delete_alias/3","type":"function"},{"doc":"[All APIs by task](https://docs.aws.amazon.com/gamelift/latest/developerguide/reference-awssdk.html#reference-awssdk-resources-fleets)","ref":"AWS.GameLift.html#delete_alias/3-related-actions","title":"Related actions - AWS.GameLift.delete_alias/3","type":"function"},{"doc":"Deletes a build.\n\nThis operation permanently deletes the build resource and any uploaded build\nfiles. Deleting a build does not affect the status of any active fleets using\nthe build, but you can no longer create new fleets with the deleted build.\n\nTo delete a build, specify the build ID.","ref":"AWS.GameLift.html#delete_build/3","title":"AWS.GameLift.delete_build/3","type":"function"},{"doc":"[ Upload a Custom Server Build](https://docs.aws.amazon.com/gamelift/latest/developerguide/gamelift-build-intro.html)\n\n[All APIs by task](https://docs.aws.amazon.com/gamelift/latest/developerguide/reference-awssdk.html#reference-awssdk-resources-fleets)","ref":"AWS.GameLift.html#delete_build/3-learn-more","title":"Learn more - AWS.GameLift.delete_build/3","type":"function"},{"doc":"Deletes all resources and information related a fleet.\n\nAny current fleet instances, including those in remote locations, are shut down.\nYou don't need to call `DeleteFleetLocations` separately.\n\nIf the fleet being deleted has a VPC peering connection, you first need to get a\nvalid authorization (good for 24 hours) by calling\n[CreateVpcPeeringAuthorization](https://docs.aws.amazon.com/gamelift/latest/apireference/API_CreateVpcPeeringAuthorization.html). You do not need to explicitly delete the VPC peering connection.\n\nTo delete a fleet, specify the fleet ID to be terminated. During the deletion\nprocess the fleet status is changed to `DELETING`. When completed, the status\nswitches to `TERMINATED` and the fleet event `FLEET_DELETED` is sent.","ref":"AWS.GameLift.html#delete_fleet/3","title":"AWS.GameLift.delete_fleet/3","type":"function"},{"doc":"[Setting up Amazon GameLift\nFleets](https://docs.aws.amazon.com/gamelift/latest/developerguide/fleets-intro.html)","ref":"AWS.GameLift.html#delete_fleet/3-learn-more","title":"Learn more - AWS.GameLift.delete_fleet/3","type":"function"},{"doc":"Removes locations from a multi-location fleet.\n\nWhen deleting a location, all game server process and all instances that are\nstill active in the location are shut down.\n\nTo delete fleet locations, identify the fleet ID and provide a list of the\nlocations to be deleted.\n\nIf successful, GameLift sets the location status to `DELETING`, and begins to\nshut down existing server processes and terminate instances in each location\nbeing deleted. When completed, the location status changes to `TERMINATED`.","ref":"AWS.GameLift.html#delete_fleet_locations/3","title":"AWS.GameLift.delete_fleet_locations/3","type":"function"},{"doc":"[Setting up Amazon GameLift fleets](https://docs.aws.amazon.com/gamelift/latest/developerguide/fleets-intro.html)","ref":"AWS.GameLift.html#delete_fleet_locations/3-learn-more","title":"Learn more - AWS.GameLift.delete_fleet_locations/3","type":"function"},{"doc":"","ref":"AWS.GameLift.html#delete_game_server_group/3","title":"AWS.GameLift.delete_game_server_group/3","type":"function"},{"doc":"server groups.\n\nTerminates a game server group and permanently deletes the game server group\nrecord.\n\nYou have several options for how these resources are impacted when deleting the\ngame server group. Depending on the type of delete operation selected, this\noperation might affect these resources:\n\n  * The game server group\n\n  * The corresponding Auto Scaling group\n\n  * All game servers that are currently running in the group\n\nTo delete a game server group, identify the game server group to delete and\nspecify the type of delete operation to initiate. Game server groups can only be\ndeleted if they are in `ACTIVE` or `ERROR` status.\n\nIf the delete request is successful, a series of operations are kicked off. The\ngame server group status is changed to `DELETE_SCHEDULED`, which prevents new\ngame servers from being registered and stops automatic scaling activity. Once\nall game servers in the game server group are deregistered, Amazon GameLift\nFleetIQ can begin deleting resources. If any of the delete operations fail, the\ngame server group is placed in `ERROR` status.\n\nAmazon GameLift FleetIQ emits delete events to Amazon CloudWatch.","ref":"AWS.GameLift.html#delete_game_server_group/3-this-operation-is-used-with-the-amazon-gamelift-fleetiq-solution-and-game","title":"This operation is used with the Amazon GameLift FleetIQ solution and game - AWS.GameLift.delete_game_server_group/3","type":"function"},{"doc":"[Amazon GameLift FleetIQ Guide](https://docs.aws.amazon.com/gamelift/latest/fleetiqguide/gsg-intro.html)","ref":"AWS.GameLift.html#delete_game_server_group/3-learn-more","title":"Learn more - AWS.GameLift.delete_game_server_group/3","type":"function"},{"doc":"Deletes a game session queue.\n\nOnce a queue is successfully deleted, unfulfilled\n[StartGameSessionPlacement](https://docs.aws.amazon.com/gamelift/latest/apireference/API_StartGameSessionPlacement.html)\nrequests that reference the queue will fail. To delete a queue, specify the\nqueue name.","ref":"AWS.GameLift.html#delete_game_session_queue/3","title":"AWS.GameLift.delete_game_session_queue/3","type":"function"},{"doc":"Deletes a custom location.\n\nBefore deleting a custom location, review any fleets currently using the custom\nlocation and deregister the location if it is in use. For more information, see\n[DeregisterCompute](https://docs.aws.amazon.com/gamelift/latest/apireference/API_DeregisterCompute.html).","ref":"AWS.GameLift.html#delete_location/3","title":"AWS.GameLift.delete_location/3","type":"function"},{"doc":"Permanently removes a FlexMatch matchmaking configuration.\n\nTo delete, specify the configuration name. A matchmaking configuration cannot be\ndeleted if it is being used in any active matchmaking tickets.","ref":"AWS.GameLift.html#delete_matchmaking_configuration/3","title":"AWS.GameLift.delete_matchmaking_configuration/3","type":"function"},{"doc":"Deletes an existing matchmaking rule set.\n\nTo delete the rule set, provide the rule set name. Rule sets cannot be deleted\nif they are currently being used by a matchmaking configuration.","ref":"AWS.GameLift.html#delete_matchmaking_rule_set/3","title":"AWS.GameLift.delete_matchmaking_rule_set/3","type":"function"},{"doc":"* [Build a rule set](https://docs.aws.amazon.com/gamelift/latest/flexmatchguide/match-rulesets.html)","ref":"AWS.GameLift.html#delete_matchmaking_rule_set/3-learn-more","title":"Learn more - AWS.GameLift.delete_matchmaking_rule_set/3","type":"function"},{"doc":"Deletes a fleet scaling policy.\n\nOnce deleted, the policy is no longer in force and Amazon GameLift removes all\nrecord of it. To delete a scaling policy, specify both the scaling policy name\nand the fleet ID it is associated with.\n\nTo temporarily suspend scaling policies, use\n[StopFleetActions](https://docs.aws.amazon.com/gamelift/latest/apireference/API_StopFleetActions.html).\nThis operation suspends all policies for the fleet.","ref":"AWS.GameLift.html#delete_scaling_policy/3","title":"AWS.GameLift.delete_scaling_policy/3","type":"function"},{"doc":"Deletes a Realtime script.\n\nThis operation permanently deletes the script record. If script files were\nuploaded, they are also deleted (files stored in an S3 bucket are not deleted).\n\nTo delete a script, specify the script ID. Before deleting a script, be sure to\nterminate all fleets that are deployed with the script being deleted. Fleet\ninstances periodically check for script updates, and if the script record no\nlonger exists, the instance will go into an error state and be unable to host\ngame sessions.","ref":"AWS.GameLift.html#delete_script/3","title":"AWS.GameLift.delete_script/3","type":"function"},{"doc":"[Amazon GameLift Realtime Servers](https://docs.aws.amazon.com/gamelift/latest/developerguide/realtime-intro.html)","ref":"AWS.GameLift.html#delete_script/3-learn-more","title":"Learn more - AWS.GameLift.delete_script/3","type":"function"},{"doc":"[All APIs by task](https://docs.aws.amazon.com/gamelift/latest/developerguide/reference-awssdk.html#reference-awssdk-resources-fleets)","ref":"AWS.GameLift.html#delete_script/3-related-actions","title":"Related actions - AWS.GameLift.delete_script/3","type":"function"},{"doc":"Cancels a pending VPC peering authorization for the specified VPC.\n\nIf you need to delete an existing VPC peering connection, use\n[DeleteVpcPeeringConnection](https://docs.aws.amazon.com/gamelift/latest/apireference/API_DeleteVpcPeeringConnection.html).","ref":"AWS.GameLift.html#delete_vpc_peering_authorization/3","title":"AWS.GameLift.delete_vpc_peering_authorization/3","type":"function"},{"doc":"[All APIs by\ntask](https://docs.aws.amazon.com/gamelift/latest/developerguide/reference-awssdk.html#reference-awssdk-resources-fleets)","ref":"AWS.GameLift.html#delete_vpc_peering_authorization/3-related-actions","title":"Related actions - AWS.GameLift.delete_vpc_peering_authorization/3","type":"function"},{"doc":"Removes a VPC peering connection.\n\nTo delete the connection, you must have a valid authorization for the VPC\npeering connection that you want to delete..\n\nOnce a valid authorization exists, call this operation from the Amazon Web\nServices account that is used to manage the Amazon GameLift fleets. Identify the\nconnection to delete by the connection ID and fleet ID. If successful, the\nconnection is removed.","ref":"AWS.GameLift.html#delete_vpc_peering_connection/3","title":"AWS.GameLift.delete_vpc_peering_connection/3","type":"function"},{"doc":"[All APIs by task](https://docs.aws.amazon.com/gamelift/latest/developerguide/reference-awssdk.html#reference-awssdk-resources-fleets)","ref":"AWS.GameLift.html#delete_vpc_peering_connection/3-related-actions","title":"Related actions - AWS.GameLift.delete_vpc_peering_connection/3","type":"function"},{"doc":"Removes a compute resource from an Amazon GameLift Anywhere fleet.\n\nDeregistered computes can no longer host game sessions through Amazon GameLift.","ref":"AWS.GameLift.html#deregister_compute/3","title":"AWS.GameLift.deregister_compute/3","type":"function"},{"doc":"","ref":"AWS.GameLift.html#deregister_game_server/3","title":"AWS.GameLift.deregister_game_server/3","type":"function"},{"doc":"server groups.\n\nRemoves the game server from a game server group.\n\nAs a result of this operation, the deregistered game server can no longer be\nclaimed and will not be returned in a list of active game servers.\n\nTo deregister a game server, specify the game server group and game server ID.\nIf successful, this operation emits a CloudWatch event with termination\ntimestamp and reason.","ref":"AWS.GameLift.html#deregister_game_server/3-this-operation-is-used-with-the-amazon-gamelift-fleetiq-solution-and-game","title":"This operation is used with the Amazon GameLift FleetIQ solution and game - AWS.GameLift.deregister_game_server/3","type":"function"},{"doc":"[Amazon GameLift FleetIQ Guide](https://docs.aws.amazon.com/gamelift/latest/fleetiqguide/gsg-intro.html)","ref":"AWS.GameLift.html#deregister_game_server/3-learn-more","title":"Learn more - AWS.GameLift.deregister_game_server/3","type":"function"},{"doc":"Retrieves properties for an alias.\n\nThis operation returns all alias metadata and settings. To get an alias's target\nfleet ID only, use `ResolveAlias`.\n\nTo get alias properties, specify the alias ID. If successful, the requested\nalias record is returned.","ref":"AWS.GameLift.html#describe_alias/3","title":"AWS.GameLift.describe_alias/3","type":"function"},{"doc":"[All APIs by task](https://docs.aws.amazon.com/gamelift/latest/developerguide/reference-awssdk.html#reference-awssdk-resources-fleets)","ref":"AWS.GameLift.html#describe_alias/3-related-actions","title":"Related actions - AWS.GameLift.describe_alias/3","type":"function"},{"doc":"Retrieves properties for a custom game build.\n\nTo request a build resource, specify a build ID. If successful, an object\ncontaining the build properties is returned.","ref":"AWS.GameLift.html#describe_build/3","title":"AWS.GameLift.describe_build/3","type":"function"},{"doc":"[ Upload a Custom Server Build](https://docs.aws.amazon.com/gamelift/latest/developerguide/gamelift-build-intro.html)\n\n[All APIs by task](https://docs.aws.amazon.com/gamelift/latest/developerguide/reference-awssdk.html#reference-awssdk-resources-fleets)","ref":"AWS.GameLift.html#describe_build/3-learn-more","title":"Learn more - AWS.GameLift.describe_build/3","type":"function"},{"doc":"Retrieves properties for a compute resource in an Amazon GameLift fleet.\n\nCall `ListCompute` to get a list of compute resources in a fleet. You can\nrequest information for computes in either managed EC2 fleets or Anywhere\nfleets.\n\nTo request compute properties, specify the compute name and fleet ID.\n\nIf successful, this operation returns details for the requested compute\nresource. For managed EC2 fleets, this operation returns the fleet's EC2\ninstances. For Anywhere fleets, this operation returns the fleet's registered\ncomputes.","ref":"AWS.GameLift.html#describe_compute/3","title":"AWS.GameLift.describe_compute/3","type":"function"},{"doc":"Retrieves the instance limits and current utilization for an Amazon Web Services\nRegion or location.\n\nInstance limits control the number of instances, per instance type, per\nlocation, that your Amazon Web Services account can use. Learn more at [Amazon EC2 Instance Types](http://aws.amazon.com/ec2/instance-types/). The information\nreturned includes the maximum number of instances allowed and your account's\ncurrent usage across all fleets. This information can affect your ability to\nscale your Amazon GameLift fleets. You can request a limit increase for your\naccount by using the **Service limits** page in the Amazon GameLift console.\n\nInstance limits differ based on whether the instances are deployed in a fleet's\nhome Region or in a remote location. For remote locations, limits also differ\nbased on the combination of home Region and remote location. All requests must\nspecify an Amazon Web Services Region (either explicitly or as your default\nsettings). To get the limit for a remote location, you must also specify the\nlocation. For example, the following requests all return different results:\n\n  * Request specifies the Region `ap-northeast-1` with no location.\nThe result is limits and usage data on all instance types that are deployed in\n`us-east-2`, by all of the fleets that reside in `ap-northeast-1`.\n\n  * Request specifies the Region `us-east-1` with location\n`ca-central-1`. The result is limits and usage data on all instance types that\nare deployed in `ca-central-1`, by all of the fleets that reside in `us-east-2`.\nThese limits do not affect fleets in any other Regions that deploy instances to\n`ca-central-1`.\n\n  * Request specifies the Region `eu-west-1` with location\n`ca-central-1`. The result is limits and usage data on all instance types that\nare deployed in `ca-central-1`, by all of the fleets that reside in `eu-west-1`.\n\nThis operation can be used in the following ways:\n\n  * To get limit and usage data for all instance types that are\ndeployed in an Amazon Web Services Region by fleets that reside in the same\nRegion: Specify the Region only. Optionally, specify a single instance type to\nretrieve information for.\n\n  * To get limit and usage data for all instance types that are\ndeployed to a remote location by fleets that reside in different Amazon Web\nServices Region: Provide both the Amazon Web Services Region and the remote\nlocation. Optionally, specify a single instance type to retrieve information\nfor.\n\nIf successful, an `EC2InstanceLimits` object is returned with limits and usage\ndata for each requested instance type.","ref":"AWS.GameLift.html#describe_ec2_instance_limits/3","title":"AWS.GameLift.describe_ec2_instance_limits/3","type":"function"},{"doc":"[Setting up Amazon GameLift fleets](https://docs.aws.amazon.com/gamelift/latest/developerguide/fleets-intro.html)","ref":"AWS.GameLift.html#describe_ec2_instance_limits/3-learn-more","title":"Learn more - AWS.GameLift.describe_ec2_instance_limits/3","type":"function"},{"doc":"Retrieves core fleet-wide properties, including the computing hardware and\ndeployment configuration for all instances in the fleet.\n\nThis operation can be used in the following ways:\n\n  * To get attributes for one or more specific fleets, provide a list\nof fleet IDs or fleet ARNs.\n\n  * To get attributes for all fleets, do not provide a fleet\nidentifier.\n\nWhen requesting attributes for multiple fleets, use the pagination parameters to\nretrieve results as a set of sequential pages.\n\nIf successful, a `FleetAttributes` object is returned for each fleet requested,\nunless the fleet identifier is not found.\n\nSome API operations limit the number of fleet IDs that allowed in one request.\nIf a request exceeds this limit, the request fails and the error message\ncontains the maximum allowed number.","ref":"AWS.GameLift.html#describe_fleet_attributes/3","title":"AWS.GameLift.describe_fleet_attributes/3","type":"function"},{"doc":"[Setting up Amazon GameLift fleets](https://docs.aws.amazon.com/gamelift/latest/developerguide/fleets-intro.html)","ref":"AWS.GameLift.html#describe_fleet_attributes/3-learn-more","title":"Learn more - AWS.GameLift.describe_fleet_attributes/3","type":"function"},{"doc":"Retrieves the resource capacity settings for one or more fleets.\n\nThe data returned includes the current fleet capacity (number of EC2 instances),\nand settings that can control how capacity scaling. For fleets with remote\nlocations, this operation retrieves data for the fleet's home Region only.\n\nThis operation can be used in the following ways:\n\n  * To get capacity data for one or more specific fleets, provide a\nlist of fleet IDs or fleet ARNs.\n\n  * To get capacity data for all fleets, do not provide a fleet\nidentifier.\n\nWhen requesting multiple fleets, use the pagination parameters to retrieve\nresults as a set of sequential pages.\n\nIf successful, a `FleetCapacity` object is returned for each requested fleet ID.\nEach FleetCapacity object includes a `Location` property, which is set to the\nfleet's home Region. When a list of fleet IDs is provided, attribute objects are\nreturned only for fleets that currently exist.\n\nSome API operations may limit the number of fleet IDs that are allowed in one\nrequest. If a request exceeds this limit, the request fails and the error\nmessage includes the maximum allowed.","ref":"AWS.GameLift.html#describe_fleet_capacity/3","title":"AWS.GameLift.describe_fleet_capacity/3","type":"function"},{"doc":"[Setting up Amazon GameLift fleets](https://docs.aws.amazon.com/gamelift/latest/developerguide/fleets-intro.html)\n\n[GameLift metrics for fleets](https://docs.aws.amazon.com/gamelift/latest/developerguide/monitoring-cloudwatch.html#gamelift-metrics-fleet)","ref":"AWS.GameLift.html#describe_fleet_capacity/3-learn-more","title":"Learn more - AWS.GameLift.describe_fleet_capacity/3","type":"function"},{"doc":"Retrieves entries from a fleet's event log.\n\nFleet events are initiated by changes in status, such as during fleet creation\nand termination, changes in capacity, etc. If a fleet has multiple locations,\nevents are also initiated by changes to status and capacity in remote locations.\n\nYou can specify a time range to limit the result set. Use the pagination\nparameters to retrieve results as a set of sequential pages.\n\nIf successful, a collection of event log entries matching the request are\nreturned.","ref":"AWS.GameLift.html#describe_fleet_events/3","title":"AWS.GameLift.describe_fleet_events/3","type":"function"},{"doc":"[Setting up Amazon GameLift fleets](https://docs.aws.amazon.com/gamelift/latest/developerguide/fleets-intro.html)","ref":"AWS.GameLift.html#describe_fleet_events/3-learn-more","title":"Learn more - AWS.GameLift.describe_fleet_events/3","type":"function"},{"doc":"Retrieves information on a fleet's remote locations, including life-cycle status\nand any suspended fleet activity.\n\nThis operation can be used in the following ways:\n\n  * To get data for specific locations, provide a fleet identifier and\na list of locations. Location data is returned in the order that it is\nrequested.\n\n  * To get data for all locations, provide a fleet identifier only.\nLocation data is returned in no particular order.\n\nWhen requesting attributes for multiple locations, use the pagination parameters\nto retrieve results as a set of sequential pages.\n\nIf successful, a `LocationAttributes` object is returned for each requested\nlocation. If the fleet does not have a requested location, no information is\nreturned. This operation does not return the home Region. To get information on\na fleet's home Region, call `DescribeFleetAttributes`.","ref":"AWS.GameLift.html#describe_fleet_location_attributes/3","title":"AWS.GameLift.describe_fleet_location_attributes/3","type":"function"},{"doc":"[Setting up Amazon GameLift fleets](https://docs.aws.amazon.com/gamelift/latest/developerguide/fleets-intro.html)","ref":"AWS.GameLift.html#describe_fleet_location_attributes/3-learn-more","title":"Learn more - AWS.GameLift.describe_fleet_location_attributes/3","type":"function"},{"doc":"Retrieves the resource capacity settings for a fleet location.\n\nThe data returned includes the current capacity (number of EC2 instances) and\nsome scaling settings for the requested fleet location. Use this operation to\nretrieve capacity information for a fleet's remote location or home Region (you\ncan also retrieve home Region capacity by calling `DescribeFleetCapacity`).\n\nTo retrieve capacity data, identify a fleet and location.\n\nIf successful, a `FleetCapacity` object is returned for the requested fleet\nlocation.","ref":"AWS.GameLift.html#describe_fleet_location_capacity/3","title":"AWS.GameLift.describe_fleet_location_capacity/3","type":"function"},{"doc":"[Setting up Amazon GameLift fleets](https://docs.aws.amazon.com/gamelift/latest/developerguide/fleets-intro.html)\n\n[GameLift metrics for fleets](https://docs.aws.amazon.com/gamelift/latest/developerguide/monitoring-cloudwatch.html#gamelift-metrics-fleet)","ref":"AWS.GameLift.html#describe_fleet_location_capacity/3-learn-more","title":"Learn more - AWS.GameLift.describe_fleet_location_capacity/3","type":"function"},{"doc":"Retrieves current usage data for a fleet location.\n\nUtilization data provides a snapshot of current game hosting activity at the\nrequested location. Use this operation to retrieve utilization information for a\nfleet's remote location or home Region (you can also retrieve home Region\nutilization by calling `DescribeFleetUtilization`).\n\nTo retrieve utilization data, identify a fleet and location.\n\nIf successful, a `FleetUtilization` object is returned for the requested fleet\nlocation.","ref":"AWS.GameLift.html#describe_fleet_location_utilization/3","title":"AWS.GameLift.describe_fleet_location_utilization/3","type":"function"},{"doc":"[Setting up Amazon GameLift fleets](https://docs.aws.amazon.com/gamelift/latest/developerguide/fleets-intro.html)\n\n[GameLift metrics for fleets](https://docs.aws.amazon.com/gamelift/latest/developerguide/monitoring-cloudwatch.html#gamelift-metrics-fleet)","ref":"AWS.GameLift.html#describe_fleet_location_utilization/3-learn-more","title":"Learn more - AWS.GameLift.describe_fleet_location_utilization/3","type":"function"},{"doc":"Retrieves a fleet's inbound connection permissions.\n\nConnection permissions specify the range of IP addresses and port settings that\nincoming traffic can use to access server processes in the fleet. Game sessions\nthat are running on instances in the fleet must use connections that fall in\nthis range.\n\nThis operation can be used in the following ways:\n\n  * To retrieve the inbound connection permissions for a fleet,\nidentify the fleet's unique identifier.\n\n  * To check the status of recent updates to a fleet remote location,\nspecify the fleet ID and a location. Port setting updates can take time to\npropagate across all locations.\n\nIf successful, a set of `IpPermission` objects is returned for the requested\nfleet ID. When a location is specified, a pending status is included. If the\nrequested fleet has been deleted, the result set is empty.","ref":"AWS.GameLift.html#describe_fleet_port_settings/3","title":"AWS.GameLift.describe_fleet_port_settings/3","type":"function"},{"doc":"[Setting up Amazon GameLift fleets](https://docs.aws.amazon.com/gamelift/latest/developerguide/fleets-intro.html)","ref":"AWS.GameLift.html#describe_fleet_port_settings/3-learn-more","title":"Learn more - AWS.GameLift.describe_fleet_port_settings/3","type":"function"},{"doc":"Retrieves utilization statistics for one or more fleets.\n\nUtilization data provides a snapshot of how the fleet's hosting resources are\ncurrently being used. For fleets with remote locations, this operation retrieves\ndata for the fleet's home Region only. See\n[DescribeFleetLocationUtilization](https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeFleetLocationUtilization.html) to get utilization statistics for a fleet's remote locations.\n\nThis operation can be used in the following ways:\n\n  * To get utilization data for one or more specific fleets, provide a\nlist of fleet IDs or fleet ARNs.\n\n  * To get utilization data for all fleets, do not provide a fleet\nidentifier.\n\nWhen requesting multiple fleets, use the pagination parameters to retrieve\nresults as a set of sequential pages.\n\nIf successful, a\n[FleetUtilization](https://docs.aws.amazon.com/gamelift/latest/apireference/API_FleetUtilization.html)\nobject is returned for each requested fleet ID, unless the fleet identifier is\nnot found. Each fleet utilization object includes a `Location` property, which\nis set to the fleet's home Region.\n\nSome API operations may limit the number of fleet IDs allowed in one request. If\na request exceeds this limit, the request fails and the error message includes\nthe maximum allowed.","ref":"AWS.GameLift.html#describe_fleet_utilization/3","title":"AWS.GameLift.describe_fleet_utilization/3","type":"function"},{"doc":"[Setting up Amazon GameLift Fleets](https://docs.aws.amazon.com/gamelift/latest/developerguide/fleets-intro.html)\n\n[GameLift Metrics for Fleets](https://docs.aws.amazon.com/gamelift/latest/developerguide/monitoring-cloudwatch.html#gamelift-metrics-fleet)","ref":"AWS.GameLift.html#describe_fleet_utilization/3-learn-more","title":"Learn more - AWS.GameLift.describe_fleet_utilization/3","type":"function"},{"doc":"","ref":"AWS.GameLift.html#describe_game_server/3","title":"AWS.GameLift.describe_game_server/3","type":"function"},{"doc":"server groups.\n\nRetrieves information for a registered game server.\n\nInformation includes game server status, health check info, and the instance\nthat the game server is running on.\n\nTo retrieve game server information, specify the game server ID. If successful,\nthe requested game server object is returned.","ref":"AWS.GameLift.html#describe_game_server/3-this-operation-is-used-with-the-amazon-gamelift-fleetiq-solution-and-game","title":"This operation is used with the Amazon GameLift FleetIQ solution and game - AWS.GameLift.describe_game_server/3","type":"function"},{"doc":"[Amazon GameLift FleetIQ Guide](https://docs.aws.amazon.com/gamelift/latest/fleetiqguide/gsg-intro.html)","ref":"AWS.GameLift.html#describe_game_server/3-learn-more","title":"Learn more - AWS.GameLift.describe_game_server/3","type":"function"},{"doc":"","ref":"AWS.GameLift.html#describe_game_server_group/3","title":"AWS.GameLift.describe_game_server_group/3","type":"function"},{"doc":"server groups.\n\nRetrieves information on a game server group.\n\nThis operation returns only properties related to Amazon GameLift FleetIQ. To\nview or update properties for the corresponding Auto Scaling group, such as\nlaunch template, auto scaling policies, and maximum/minimum group size, access\nthe Auto Scaling group directly.\n\nTo get attributes for a game server group, provide a group name or ARN value. If\nsuccessful, a `GameServerGroup` object is returned.","ref":"AWS.GameLift.html#describe_game_server_group/3-this-operation-is-used-with-the-amazon-gamelift-fleetiq-solution-and-game","title":"This operation is used with the Amazon GameLift FleetIQ solution and game - AWS.GameLift.describe_game_server_group/3","type":"function"},{"doc":"[Amazon GameLift FleetIQ Guide](https://docs.aws.amazon.com/gamelift/latest/fleetiqguide/gsg-intro.html)","ref":"AWS.GameLift.html#describe_game_server_group/3-learn-more","title":"Learn more - AWS.GameLift.describe_game_server_group/3","type":"function"},{"doc":"","ref":"AWS.GameLift.html#describe_game_server_instances/3","title":"AWS.GameLift.describe_game_server_instances/3","type":"function"},{"doc":"server groups.\n\nRetrieves status information about the Amazon EC2 instances associated with a\nAmazon GameLift FleetIQ game server group.\n\nUse this operation to detect when instances are active or not available to host\nnew game servers.\n\nTo request status for all instances in the game server group, provide a game\nserver group ID only. To request status for specific instances, provide the game\nserver group ID and one or more instance IDs. Use the pagination parameters to\nretrieve results in sequential segments. If successful, a collection of\n`GameServerInstance` objects is returned.\n\nThis operation is not designed to be called with every game server claim\nrequest; this practice can cause you to exceed your API limit, which results in\nerrors. Instead, as a best practice, cache the results and refresh your cache no\nmore than once every 10 seconds.","ref":"AWS.GameLift.html#describe_game_server_instances/3-this-operation-is-used-with-the-amazon-gamelift-fleetiq-solution-and-game","title":"This operation is used with the Amazon GameLift FleetIQ solution and game - AWS.GameLift.describe_game_server_instances/3","type":"function"},{"doc":"[Amazon GameLift FleetIQ Guide](https://docs.aws.amazon.com/gamelift/latest/fleetiqguide/gsg-intro.html)","ref":"AWS.GameLift.html#describe_game_server_instances/3-learn-more","title":"Learn more - AWS.GameLift.describe_game_server_instances/3","type":"function"},{"doc":"Retrieves additional game session properties, including the game session\nprotection policy in force, a set of one or more game sessions in a specific\nfleet location.\n\nYou can optionally filter the results by current game session status.\n\nThis operation can be used in the following ways:\n\n  * To retrieve details for all game sessions that are currently\nrunning on all locations in a fleet, provide a fleet or alias ID, with an\noptional status filter. This approach returns details from the fleet's home\nRegion and all remote locations.\n\n  * To retrieve details for all game sessions that are currently\nrunning on a specific fleet location, provide a fleet or alias ID and a location\nname, with optional status filter. The location can be the fleet's home Region\nor any remote location.\n\n  * To retrieve details for a specific game session, provide the game\nsession ID. This approach looks for the game session ID in all fleets that\nreside in the Amazon Web Services Region defined in the request.\n\nUse the pagination parameters to retrieve results as a set of sequential pages.\n\nIf successful, a `GameSessionDetail` object is returned for each game session\nthat matches the request.","ref":"AWS.GameLift.html#describe_game_session_details/3","title":"AWS.GameLift.describe_game_session_details/3","type":"function"},{"doc":"[Find a game session](https://docs.aws.amazon.com/gamelift/latest/developerguide/gamelift-sdk-client-api.html#gamelift-sdk-client-api-find)\n\n[All APIs by task](https://docs.aws.amazon.com/gamelift/latest/developerguide/reference-awssdk.html#reference-awssdk-resources-fleets)","ref":"AWS.GameLift.html#describe_game_session_details/3-learn-more","title":"Learn more - AWS.GameLift.describe_game_session_details/3","type":"function"},{"doc":"Retrieves information, including current status, about a game session placement\nrequest.\n\nTo get game session placement details, specify the placement ID.\n\nThis operation is not designed to be continually called to track game session\nstatus. This practice can cause you to exceed your API limit, which results in\nerrors. Instead, you must configure configure an Amazon Simple Notification\nService (SNS) topic to receive notifications from FlexMatch or queues.\nContinuously polling with `DescribeGameSessionPlacement` should only be used for\ngames in development with low game session usage.","ref":"AWS.GameLift.html#describe_game_session_placement/3","title":"AWS.GameLift.describe_game_session_placement/3","type":"function"},{"doc":"Retrieves the properties for one or more game session queues.\n\nWhen requesting multiple queues, use the pagination parameters to retrieve\nresults as a set of sequential pages. When specifying a list of queues, objects\nare returned only for queues that currently exist in the Region.","ref":"AWS.GameLift.html#describe_game_session_queues/3","title":"AWS.GameLift.describe_game_session_queues/3","type":"function"},{"doc":"[ View Your Queues](https://docs.aws.amazon.com/gamelift/latest/developerguide/queues-console.html)","ref":"AWS.GameLift.html#describe_game_session_queues/3-learn-more","title":"Learn more - AWS.GameLift.describe_game_session_queues/3","type":"function"},{"doc":"Retrieves a set of one or more game sessions in a specific fleet location.\n\nYou can optionally filter the results by current game session status.\n\nThis operation can be used in the following ways:\n\n  * To retrieve all game sessions that are currently running on all\nlocations in a fleet, provide a fleet or alias ID, with an optional status\nfilter. This approach returns all game sessions in the fleet's home Region and\nall remote locations.\n\n  * To retrieve all game sessions that are currently running on a\nspecific fleet location, provide a fleet or alias ID and a location name, with\noptional status filter. The location can be the fleet's home Region or any\nremote location.\n\n  * To retrieve a specific game session, provide the game session ID.\nThis approach looks for the game session ID in all fleets that reside in the\nAmazon Web Services Region defined in the request.\n\nUse the pagination parameters to retrieve results as a set of sequential pages.\n\nIf successful, a `GameSession` object is returned for each game session that\nmatches the request.\n\nThis operation is not designed to be continually called to track game session\nstatus. This practice can cause you to exceed your API limit, which results in\nerrors. Instead, you must configure an Amazon Simple Notification Service (SNS)\ntopic to receive notifications from FlexMatch or queues. Continuously polling\nwith `DescribeGameSessions` should only be used for games in development with\nlow game session usage.\n\n*Available in Amazon GameLift Local.*","ref":"AWS.GameLift.html#describe_game_sessions/3","title":"AWS.GameLift.describe_game_sessions/3","type":"function"},{"doc":"[Find a game session](https://docs.aws.amazon.com/gamelift/latest/developerguide/gamelift-sdk-client-api.html#gamelift-sdk-client-api-find)\n\n[All APIs by task](https://docs.aws.amazon.com/gamelift/latest/developerguide/reference-awssdk.html#reference-awssdk-resources-fleets)","ref":"AWS.GameLift.html#describe_game_sessions/3-learn-more","title":"Learn more - AWS.GameLift.describe_game_sessions/3","type":"function"},{"doc":"Retrieves information about the EC2 instances in an Amazon GameLift managed\nfleet, including instance ID, connection data, and status.\n\nYou can use this operation with a multi-location fleet to get location-specific\ninstance information. As an alternative, use the operations `ListCompute` and\n`DescribeCompute` to retrieve information for compute resources, including EC2\nand Anywhere fleets.\n\nYou can call this operation in the following ways:\n\n  * To get information on all instances in a fleet's home Region,\nspecify the fleet ID.\n\n  * To get information on all instances in a fleet's remote location,\nspecify the fleet ID and location name.\n\n  * To get information on a specific instance in a fleet, specify the\nfleet ID and instance ID.\n\nUse the pagination parameters to retrieve results as a set of sequential pages.\n\nIf successful, this operation returns `Instance` objects for each requested\ninstance, listed in no particular order. If you call this operation for an\nAnywhere fleet, you receive an InvalidRequestException.","ref":"AWS.GameLift.html#describe_instances/3","title":"AWS.GameLift.describe_instances/3","type":"function"},{"doc":"[Remotely connect to fleet instances](https://docs.aws.amazon.com/gamelift/latest/developerguide/fleets-remote-access.html)\n\n[Debug fleet issues](https://docs.aws.amazon.com/gamelift/latest/developerguide/fleets-creating-debug.html)","ref":"AWS.GameLift.html#describe_instances/3-learn-more","title":"Learn more - AWS.GameLift.describe_instances/3","type":"function"},{"doc":"[All APIs by task](https://docs.aws.amazon.com/gamelift/latest/developerguide/reference-awssdk.html#reference-awssdk-resources-fleets)","ref":"AWS.GameLift.html#describe_instances/3-related-actions","title":"Related actions - AWS.GameLift.describe_instances/3","type":"function"},{"doc":"Retrieves one or more matchmaking tickets.\n\nUse this operation to retrieve ticket information, including--after a successful\nmatch is made--connection information for the resulting new game session.\n\nTo request matchmaking tickets, provide a list of up to 10 ticket IDs. If the\nrequest is successful, a ticket object is returned for each requested ID that\ncurrently exists.\n\nThis operation is not designed to be continually called to track matchmaking\nticket status. This practice can cause you to exceed your API limit, which\nresults in errors. Instead, as a best practice, set up an Amazon Simple\nNotification Service to receive notifications, and provide the topic ARN in the\nmatchmaking configuration.","ref":"AWS.GameLift.html#describe_matchmaking/3","title":"AWS.GameLift.describe_matchmaking/3","type":"function"},{"doc":"[ Add FlexMatch to a game client](https://docs.aws.amazon.com/gamelift/latest/flexmatchguide/match-client.html)\n\n[ Set Up FlexMatch event notification](https://docs.aws.amazon.com/gamelift/latest/flexmatchguide/match-notification.html)","ref":"AWS.GameLift.html#describe_matchmaking/3-learn-more","title":"Learn more - AWS.GameLift.describe_matchmaking/3","type":"function"},{"doc":"Retrieves the details of FlexMatch matchmaking configurations.\n\nThis operation offers the following options: (1) retrieve all matchmaking\nconfigurations, (2) retrieve configurations for a specified list, or (3)\nretrieve all configurations that use a specified rule set name. When requesting\nmultiple items, use the pagination parameters to retrieve results as a set of\nsequential pages.\n\nIf successful, a configuration is returned for each requested name. When\nspecifying a list of names, only configurations that currently exist are\nreturned.","ref":"AWS.GameLift.html#describe_matchmaking_configurations/3","title":"AWS.GameLift.describe_matchmaking_configurations/3","type":"function"},{"doc":"[ Setting up FlexMatch matchmakers](https://docs.aws.amazon.com/gamelift/latest/flexmatchguide/matchmaker-build.html)","ref":"AWS.GameLift.html#describe_matchmaking_configurations/3-learn-more","title":"Learn more - AWS.GameLift.describe_matchmaking_configurations/3","type":"function"},{"doc":"Retrieves the details for FlexMatch matchmaking rule sets.\n\nYou can request all existing rule sets for the Region, or provide a list of one\nor more rule set names. When requesting multiple items, use the pagination\nparameters to retrieve results as a set of sequential pages. If successful, a\nrule set is returned for each requested name.","ref":"AWS.GameLift.html#describe_matchmaking_rule_sets/3","title":"AWS.GameLift.describe_matchmaking_rule_sets/3","type":"function"},{"doc":"* [Build a rule set](https://docs.aws.amazon.com/gamelift/latest/flexmatchguide/match-rulesets.html)","ref":"AWS.GameLift.html#describe_matchmaking_rule_sets/3-learn-more","title":"Learn more - AWS.GameLift.describe_matchmaking_rule_sets/3","type":"function"},{"doc":"Retrieves properties for one or more player sessions.\n\nThis action can be used in the following ways:\n\n  * To retrieve a specific player session, provide the player session\nID only.\n\n  * To retrieve all player sessions in a game session, provide the\ngame session ID only.\n\n  * To retrieve all player sessions for a specific player, provide a\nplayer ID only.\n\nTo request player sessions, specify either a player session ID, game session ID,\nor player ID. You can filter this request by player session status. If you\nprovide a specific `PlayerSessionId` or `PlayerId`, Amazon GameLift ignores the\nfilter criteria. Use the pagination parameters to retrieve results as a set of\nsequential pages.\n\nIf successful, a `PlayerSession` object is returned for each session that\nmatches the request.","ref":"AWS.GameLift.html#describe_player_sessions/3","title":"AWS.GameLift.describe_player_sessions/3","type":"function"},{"doc":"[All APIs by task](https://docs.aws.amazon.com/gamelift/latest/developerguide/reference-awssdk.html#reference-awssdk-resources-fleets)","ref":"AWS.GameLift.html#describe_player_sessions/3-related-actions","title":"Related actions - AWS.GameLift.describe_player_sessions/3","type":"function"},{"doc":"Retrieves a fleet's runtime configuration settings.\n\nThe runtime configuration tells Amazon GameLift which server processes to run\n(and how) on each instance in the fleet.\n\nTo get the runtime configuration that is currently in forces for a fleet,\nprovide the fleet ID.\n\nIf successful, a `RuntimeConfiguration` object is returned for the requested\nfleet. If the requested fleet has been deleted, the result set is empty.","ref":"AWS.GameLift.html#describe_runtime_configuration/3","title":"AWS.GameLift.describe_runtime_configuration/3","type":"function"},{"doc":"[Setting up Amazon GameLift fleets](https://docs.aws.amazon.com/gamelift/latest/developerguide/fleets-intro.html)\n\n[Running multiple processes on a fleet](https://docs.aws.amazon.com/gamelift/latest/developerguide/fleets-multiprocess.html)","ref":"AWS.GameLift.html#describe_runtime_configuration/3-learn-more","title":"Learn more - AWS.GameLift.describe_runtime_configuration/3","type":"function"},{"doc":"Retrieves all scaling policies applied to a fleet.\n\nTo get a fleet's scaling policies, specify the fleet ID. You can filter this\nrequest by policy status, such as to retrieve only active scaling policies. Use\nthe pagination parameters to retrieve results as a set of sequential pages. If\nsuccessful, set of `ScalingPolicy` objects is returned for the fleet.\n\nA fleet may have all of its scaling policies suspended. This operation does not\naffect the status of the scaling policies, which remains ACTIVE.","ref":"AWS.GameLift.html#describe_scaling_policies/3","title":"AWS.GameLift.describe_scaling_policies/3","type":"function"},{"doc":"Retrieves properties for a Realtime script.\n\nTo request a script record, specify the script ID. If successful, an object\ncontaining the script properties is returned.","ref":"AWS.GameLift.html#describe_script/3","title":"AWS.GameLift.describe_script/3","type":"function"},{"doc":"[Amazon GameLift Realtime Servers](https://docs.aws.amazon.com/gamelift/latest/developerguide/realtime-intro.html)","ref":"AWS.GameLift.html#describe_script/3-learn-more","title":"Learn more - AWS.GameLift.describe_script/3","type":"function"},{"doc":"[All APIs by task](https://docs.aws.amazon.com/gamelift/latest/developerguide/reference-awssdk.html#reference-awssdk-resources-fleets)","ref":"AWS.GameLift.html#describe_script/3-related-actions","title":"Related actions - AWS.GameLift.describe_script/3","type":"function"},{"doc":"Retrieves valid VPC peering authorizations that are pending for the Amazon Web\nServices account.\n\nThis operation returns all VPC peering authorizations and requests for peering.\nThis includes those initiated and received by this account.","ref":"AWS.GameLift.html#describe_vpc_peering_authorizations/3","title":"AWS.GameLift.describe_vpc_peering_authorizations/3","type":"function"},{"doc":"[All APIs by task](https://docs.aws.amazon.com/gamelift/latest/developerguide/reference-awssdk.html#reference-awssdk-resources-fleets)","ref":"AWS.GameLift.html#describe_vpc_peering_authorizations/3-related-actions","title":"Related actions - AWS.GameLift.describe_vpc_peering_authorizations/3","type":"function"},{"doc":"Retrieves information on VPC peering connections.\n\nUse this operation to get peering information for all fleets or for one specific\nfleet ID.\n\nTo retrieve connection information, call this operation from the Amazon Web\nServices account that is used to manage the Amazon GameLift fleets. Specify a\nfleet ID or leave the parameter empty to retrieve all connection records. If\nsuccessful, the retrieved information includes both active and pending\nconnections. Active connections identify the IpV4 CIDR block that the VPC uses\nto connect.","ref":"AWS.GameLift.html#describe_vpc_peering_connections/3","title":"AWS.GameLift.describe_vpc_peering_connections/3","type":"function"},{"doc":"[All APIs by task](https://docs.aws.amazon.com/gamelift/latest/developerguide/reference-awssdk.html#reference-awssdk-resources-fleets)","ref":"AWS.GameLift.html#describe_vpc_peering_connections/3-related-actions","title":"Related actions - AWS.GameLift.describe_vpc_peering_connections/3","type":"function"},{"doc":"Requests authorization to remotely connect to a compute resource in an Amazon\nGameLift fleet.\n\nCall this action to connect to an instance in a managed EC2 fleet if the fleet's\ngame build uses Amazon GameLift server SDK 5.x or later. To connect to instances\nwith game builds that use server SDK 4.x or earlier, call `GetInstanceAccess`.\n\nTo request access to a compute, identify the specific EC2 instance and the fleet\nit belongs to. You can retrieve instances for a managed EC2 fleet by calling\n`ListCompute`.\n\nIf successful, this operation returns a set of temporary Amazon Web Services\ncredentials, including a two-part access key and a session token. Use these\ncredentials with Amazon EC2 Systems Manager (SSM) to start a session with the\ncompute. For more details, see [ Starting a session (CLI)](https://docs.aws.amazon.com/systems-manager/latest/userguide/session-manager-working-with-sessions-start.html#sessions-start-cli)\nin the *Amazon EC2 Systems Manager User Guide*.","ref":"AWS.GameLift.html#get_compute_access/3","title":"AWS.GameLift.get_compute_access/3","type":"function"},{"doc":"[Remotely connect to fleet instances](https://docs.aws.amazon.com/gamelift/latest/developerguide/fleets-remote-access.html)\n\n[Debug fleet issues](https://docs.aws.amazon.com/gamelift/latest/developerguide/fleets-creating-debug.html)","ref":"AWS.GameLift.html#get_compute_access/3-learn-more","title":"Learn more - AWS.GameLift.get_compute_access/3","type":"function"},{"doc":"Requests an authentication token from Amazon GameLift for a registered compute\nin an Anywhere fleet.\n\nThe game servers that are running on the compute use this token to authenticate\nwith the Amazon GameLift service. Each server process must provide a valid\nauthentication token in its call to the Amazon GameLift server SDK action\n`InitSDK()`.\n\nAuthentication tokens are valid for a limited time span. Use a mechanism to\nregularly request a fresh authentication token before the current token expires.","ref":"AWS.GameLift.html#get_compute_auth_token/3","title":"AWS.GameLift.get_compute_auth_token/3","type":"function"},{"doc":"* [Create an Anywhere fleet](https://docs.aws.amazon.com/gamelift/latest/developerguide/fleets-creating-anywhere.html)\n\n  * [Test your integration](https://docs.aws.amazon.com/gamelift/latest/developerguide/integration-testing.html)\n\n  * [Server SDK reference guides](https://docs.aws.amazon.com/gamelift/latest/developerguide/reference-serversdk.html)\n(for version 5.x)","ref":"AWS.GameLift.html#get_compute_auth_token/3-learn-more","title":"Learn more - AWS.GameLift.get_compute_auth_token/3","type":"function"},{"doc":"Retrieves the location of stored game session logs for a specified game session\non Amazon GameLift managed fleets.\n\nWhen a game session is terminated, Amazon GameLift automatically stores the logs\nin Amazon S3 and retains them for 14 days. Use this URL to download the logs.\n\nSee the [Amazon Web Services Service Limits](https://docs.aws.amazon.com/general/latest/gr/aws_service_limits.html#limits_gamelift)\npage for maximum log file sizes. Log files that exceed this limit are not saved.\n\n[All APIs by task](https://docs.aws.amazon.com/gamelift/latest/developerguide/reference-awssdk.html#reference-awssdk-resources-fleets)","ref":"AWS.GameLift.html#get_game_session_log_url/3","title":"AWS.GameLift.get_game_session_log_url/3","type":"function"},{"doc":"Requests authorization to remotely connect to an instance in an Amazon GameLift\nmanaged fleet.\n\nUse this operation to connect to instances with game servers that use Amazon\nGameLift server SDK 4.x or earlier. To connect to instances with game servers\nthat use server SDK 5.x or later, call `GetComputeAccess`.\n\nTo request access to an instance, specify IDs for the instance and the fleet it\nbelongs to. You can retrieve instance IDs for a fleet by calling\n[DescribeInstances](https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeInstances.html) with the fleet ID.\n\nIf successful, this operation returns an IP address and credentials. The\nreturned credentials match the operating system of the instance, as follows:\n\n  * For a Windows instance: returns a user name and secret (password)\nfor use with a Windows Remote Desktop client.\n\n  * For a Linux instance: returns a user name and secret (RSA private\nkey) for use with an SSH client. You must save the secret to a `.pem` file. If\nyou're using the CLI, see the example [ Get credentials for a Linux\ninstance](https://docs.aws.amazon.com/gamelift/latest/apireference/API_GetInstanceAccess.html#API_GetInstanceAccess_Examples)\nfor tips on automatically saving the secret to a `.pem` file.","ref":"AWS.GameLift.html#get_instance_access/3","title":"AWS.GameLift.get_instance_access/3","type":"function"},{"doc":"[Remotely connect to fleet instances](https://docs.aws.amazon.com/gamelift/latest/developerguide/fleets-remote-access.html)\n\n[Debug fleet issues](https://docs.aws.amazon.com/gamelift/latest/developerguide/fleets-creating-debug.html)","ref":"AWS.GameLift.html#get_instance_access/3-learn-more","title":"Learn more - AWS.GameLift.get_instance_access/3","type":"function"},{"doc":"[All APIs by task](https://docs.aws.amazon.com/gamelift/latest/developerguide/reference-awssdk.html#reference-awssdk-resources-fleets)","ref":"AWS.GameLift.html#get_instance_access/3-related-actions","title":"Related actions - AWS.GameLift.get_instance_access/3","type":"function"},{"doc":"Retrieves all aliases for this Amazon Web Services account.\n\nYou can filter the result set by alias name and/or routing strategy type. Use\nthe pagination parameters to retrieve results in sequential pages.\n\nReturned aliases are not listed in any particular order.","ref":"AWS.GameLift.html#list_aliases/3","title":"AWS.GameLift.list_aliases/3","type":"function"},{"doc":"[All APIs by task](https://docs.aws.amazon.com/gamelift/latest/developerguide/reference-awssdk.html#reference-awssdk-resources-fleets)","ref":"AWS.GameLift.html#list_aliases/3-related-actions","title":"Related actions - AWS.GameLift.list_aliases/3","type":"function"},{"doc":"Retrieves build resources for all builds associated with the Amazon Web Services\naccount in use.\n\nYou can limit results to builds that are in a specific status by using the\n`Status` parameter. Use the pagination parameters to retrieve results in a set\nof sequential pages.\n\nBuild resources are not listed in any particular order.","ref":"AWS.GameLift.html#list_builds/3","title":"AWS.GameLift.list_builds/3","type":"function"},{"doc":"[ Upload a Custom Server Build](https://docs.aws.amazon.com/gamelift/latest/developerguide/gamelift-build-intro.html)\n\n[All APIs by task](https://docs.aws.amazon.com/gamelift/latest/developerguide/reference-awssdk.html#reference-awssdk-resources-fleets)","ref":"AWS.GameLift.html#list_builds/3-learn-more","title":"Learn more - AWS.GameLift.list_builds/3","type":"function"},{"doc":"Retrieves the compute resources in an Amazon GameLift fleet.\n\nYou can request information for either managed EC2 fleets or Anywhere fleets.\n\nTo request a list of computes, specify the fleet ID. You can filter the result\nset by location. Use the pagination parameters to retrieve results in a set of\nsequential pages.\n\nIf successful, this operation returns the compute resource for the requested\nfleet. For managed EC2 fleets, it returns a list of EC2 instances. For Anywhere\nfleets, it returns a list of registered compute names.","ref":"AWS.GameLift.html#list_compute/3","title":"AWS.GameLift.list_compute/3","type":"function"},{"doc":"Retrieves a collection of fleet resources in an Amazon Web Services Region.\n\nYou can call this operation to get fleets in a previously selected default\nRegion (see\n[https://docs.aws.amazon.com/credref/latest/refdocs/setting-global-region.html](https://docs.aws.amazon.com/credref/latest/refdocs/setting-global-region.html)or specify a Region in your request. You can filter the result set to find only\nthose fleets that are deployed with a specific build or script. For fleets that\nhave multiple locations, this operation retrieves fleets based on their home\nRegion only.\n\nThis operation can be used in the following ways:\n\n  * To get a list of all fleets in a Region, don't provide a build or\nscript identifier.\n\n  * To get a list of all fleets where a specific custom game build is\ndeployed, provide the build ID.\n\n  * To get a list of all Realtime Servers fleets with a specific\nconfiguration script, provide the script ID.\n\nUse the pagination parameters to retrieve results as a set of sequential pages.\n\nIf successful, a list of fleet IDs that match the request parameters is\nreturned. A NextToken value is also returned if there are more result pages to\nretrieve.\n\nFleet resources are not listed in a particular order.","ref":"AWS.GameLift.html#list_fleets/3","title":"AWS.GameLift.list_fleets/3","type":"function"},{"doc":"[Setting up Amazon GameLift\nfleets](https://docs.aws.amazon.com/gamelift/latest/developerguide/fleets-intro.html)","ref":"AWS.GameLift.html#list_fleets/3-learn-more","title":"Learn more - AWS.GameLift.list_fleets/3","type":"function"},{"doc":"Lists a game server groups.","ref":"AWS.GameLift.html#list_game_server_groups/3","title":"AWS.GameLift.list_game_server_groups/3","type":"function"},{"doc":"","ref":"AWS.GameLift.html#list_game_servers/3","title":"AWS.GameLift.list_game_servers/3","type":"function"},{"doc":"server groups.\n\nRetrieves information on all game servers that are currently active in a\nspecified game server group.\n\nYou can opt to sort the list by game server age. Use the pagination parameters\nto retrieve results in a set of sequential segments.","ref":"AWS.GameLift.html#list_game_servers/3-this-operation-is-used-with-the-amazon-gamelift-fleetiq-solution-and-game","title":"This operation is used with the Amazon GameLift FleetIQ solution and game - AWS.GameLift.list_game_servers/3","type":"function"},{"doc":"[Amazon GameLift FleetIQ Guide](https://docs.aws.amazon.com/gamelift/latest/fleetiqguide/gsg-intro.html)","ref":"AWS.GameLift.html#list_game_servers/3-learn-more","title":"Learn more - AWS.GameLift.list_game_servers/3","type":"function"},{"doc":"Lists all custom and Amazon Web Services locations.","ref":"AWS.GameLift.html#list_locations/3","title":"AWS.GameLift.list_locations/3","type":"function"},{"doc":"Retrieves script records for all Realtime scripts that are associated with the\nAmazon Web Services account in use.","ref":"AWS.GameLift.html#list_scripts/3","title":"AWS.GameLift.list_scripts/3","type":"function"},{"doc":"[Amazon GameLift Realtime Servers](https://docs.aws.amazon.com/gamelift/latest/developerguide/realtime-intro.html)","ref":"AWS.GameLift.html#list_scripts/3-learn-more","title":"Learn more - AWS.GameLift.list_scripts/3","type":"function"},{"doc":"[All APIs by task](https://docs.aws.amazon.com/gamelift/latest/developerguide/reference-awssdk.html#reference-awssdk-resources-fleets)","ref":"AWS.GameLift.html#list_scripts/3-related-actions","title":"Related actions - AWS.GameLift.list_scripts/3","type":"function"},{"doc":"Retrieves all tags assigned to a Amazon GameLift resource.\n\nUse resource tags to organize Amazon Web Services resources for a range of\npurposes. This operation handles the permissions necessary to manage tags for\nAmazon GameLift resources that support tagging.\n\nTo list tags for a resource, specify the unique ARN value for the resource.","ref":"AWS.GameLift.html#list_tags_for_resource/3","title":"AWS.GameLift.list_tags_for_resource/3","type":"function"},{"doc":"[Tagging Amazon Web Services Resources](https://docs.aws.amazon.com/general/latest/gr/aws_tagging.html) in\nthe *Amazon Web Services General Reference*\n\n[ Amazon Web Services Tagging Strategies](http://aws.amazon.com/answers/account-management/aws-tagging-strategies/)","ref":"AWS.GameLift.html#list_tags_for_resource/3-learn-more","title":"Learn more - AWS.GameLift.list_tags_for_resource/3","type":"function"},{"doc":"[All APIs by task](https://docs.aws.amazon.com/gamelift/latest/developerguide/reference-awssdk.html#reference-awssdk-resources-fleets)","ref":"AWS.GameLift.html#list_tags_for_resource/3-related-actions","title":"Related actions - AWS.GameLift.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.GameLift.html#metadata/0","title":"AWS.GameLift.metadata/0","type":"function"},{"doc":"Creates or updates a scaling policy for a fleet.\n\nScaling policies are used to automatically scale a fleet's hosting capacity to\nmeet player demand. An active scaling policy instructs Amazon GameLift to track\na fleet metric and automatically change the fleet's capacity when a certain\nthreshold is reached. There are two types of scaling policies: target-based and\nrule-based. Use a target-based policy to quickly and efficiently manage fleet\nscaling; this option is the most commonly used. Use rule-based policies when you\nneed to exert fine-grained control over auto-scaling.\n\nFleets can have multiple scaling policies of each type in force at the same\ntime; you can have one target-based policy, one or multiple rule-based scaling\npolicies, or both. We recommend caution, however, because multiple auto-scaling\npolicies can have unintended consequences.\n\nLearn more about how to work with auto-scaling in [Set Up Fleet Automatic Scaling](https://docs.aws.amazon.com/gamelift/latest/developerguide/fleets-autoscaling.html).","ref":"AWS.GameLift.html#put_scaling_policy/3","title":"AWS.GameLift.put_scaling_policy/3","type":"function"},{"doc":"A target-based policy tracks a single metric: PercentAvailableGameSessions. This\nmetric tells us how much of a fleet's hosting capacity is ready to host game\nsessions but is not currently in use. This is the fleet's buffer; it measures\nthe additional player demand that the fleet could handle at current capacity.\nWith a target-based policy, you set your ideal buffer size and leave it to\nAmazon GameLift to take whatever action is needed to maintain that target.\n\nFor example, you might choose to maintain a 10% buffer for a fleet that has the\ncapacity to host 100 simultaneous game sessions. This policy tells Amazon\nGameLift to take action whenever the fleet's available capacity falls below or\nrises above 10 game sessions. Amazon GameLift will start new instances or stop\nunused instances in order to return to the 10% buffer.\n\nTo create or update a target-based policy, specify a fleet ID and name, and set\nthe policy type to \"TargetBased\". Specify the metric to track\n(PercentAvailableGameSessions) and reference a `TargetConfiguration` object with\nyour desired buffer value. Exclude all other parameters. On a successful\nrequest, the policy name is returned. The scaling policy is automatically in\nforce as soon as it's successfully created. If the fleet's auto-scaling actions\nare temporarily suspended, the new policy will be in force once the fleet\nactions are restarted.","ref":"AWS.GameLift.html#put_scaling_policy/3-target-based-policy","title":"Target-based policy - AWS.GameLift.put_scaling_policy/3","type":"function"},{"doc":"A rule-based policy tracks specified fleet metric, sets a threshold value, and\nspecifies the type of action to initiate when triggered. With a rule-based\npolicy, you can select from several available fleet metrics. Each policy\nspecifies whether to scale up or scale down (and by how much), so you need one\npolicy for each type of action.\n\nFor example, a policy may make the following statement: \"If the percentage of\nidle instances is greater than 20% for more than 15 minutes, then reduce the\nfleet capacity by 10%.\"\n\nA policy's rule statement has the following structure:\n\nIf `[MetricName]` is `[ComparisonOperator]` `[Threshold]` for `[EvaluationPeriods]` minutes, then `[ScalingAdjustmentType]` to/by `[ScalingAdjustment]`.\n\nTo implement the example, the rule statement would look like this:\n\nIf `[PercentIdleInstances]` is `[GreaterThanThreshold]` `[20]` for `[15]` minutes, then `[PercentChangeInCapacity]` to/by `[10]`.\n\nTo create or update a scaling policy, specify a unique combination of name and\nfleet ID, and set the policy type to \"RuleBased\". Specify the parameter values\nfor a policy rule statement. On a successful request, the policy name is\nreturned. Scaling policies are automatically in force as soon as they're\nsuccessfully created. If the fleet's auto-scaling actions are temporarily\nsuspended, the new policy will be in force once the fleet actions are restarted.","ref":"AWS.GameLift.html#put_scaling_policy/3-rule-based-policy","title":"Rule-based policy - AWS.GameLift.put_scaling_policy/3","type":"function"},{"doc":"Registers a compute resource to an Amazon GameLift Anywhere fleet.\n\nWith Anywhere fleets you can incorporate your own computing hardware into an\nAmazon GameLift game hosting solution.\n\nTo register a compute to a fleet, give the compute a name (must be unique within\nthe fleet) and specify the compute resource's DNS name or IP address. Provide\nthe Anywhere fleet ID and a fleet location to associate with the compute being\nregistered. You can optionally include the path to a TLS certificate on the\ncompute resource.\n\nIf successful, this operation returns the compute details, including an Amazon\nGameLift SDK endpoint. Game server processes that run on the compute use this\nendpoint to communicate with the Amazon GameLift service. Each server process\nincludes the SDK endpoint in its call to the Amazon GameLift server SDK action\n`InitSDK()`.","ref":"AWS.GameLift.html#register_compute/3","title":"AWS.GameLift.register_compute/3","type":"function"},{"doc":"* [Create an Anywhere fleet](https://docs.aws.amazon.com/gamelift/latest/developerguide/fleets-creating-anywhere.html)\n\n  * [Test your integration](https://docs.aws.amazon.com/gamelift/latest/developerguide/integration-testing.html)\n\n  * [Server SDK reference guides](https://docs.aws.amazon.com/gamelift/latest/developerguide/reference-serversdk.html)\n(for version 5.x)","ref":"AWS.GameLift.html#register_compute/3-learn-more","title":"Learn more - AWS.GameLift.register_compute/3","type":"function"},{"doc":"","ref":"AWS.GameLift.html#register_game_server/3","title":"AWS.GameLift.register_game_server/3","type":"function"},{"doc":"server groups.\n\nCreates a new game server resource and notifies Amazon GameLift FleetIQ that the\ngame server is ready to host gameplay and players.\n\nThis operation is called by a game server process that is running on an instance\nin a game server group. Registering game servers enables Amazon GameLift FleetIQ\nto track available game servers and enables game clients and services to claim a\ngame server for a new game session.\n\nTo register a game server, identify the game server group and instance where the\ngame server is running, and provide a unique identifier for the game server. You\ncan also include connection and game server data.\n\nOnce a game server is successfully registered, it is put in status `AVAILABLE`.\nA request to register a game server may fail if the instance it is running on is\nin the process of shutting down as part of instance balancing or scale-down\nactivity.","ref":"AWS.GameLift.html#register_game_server/3-this-operation-is-used-with-the-amazon-gamelift-fleetiq-solution-and-game","title":"This operation is used with the Amazon GameLift FleetIQ solution and game - AWS.GameLift.register_game_server/3","type":"function"},{"doc":"[Amazon GameLift FleetIQ Guide](https://docs.aws.amazon.com/gamelift/latest/fleetiqguide/gsg-intro.html)","ref":"AWS.GameLift.html#register_game_server/3-learn-more","title":"Learn more - AWS.GameLift.register_game_server/3","type":"function"},{"doc":"Retrieves a fresh set of credentials for use when uploading a new set of game\nbuild files to Amazon GameLift's Amazon S3.\n\nThis is done as part of the build creation process; see\n[GameSession](https://docs.aws.amazon.com/gamelift/latest/apireference/API_CreateBuild.html).  To request new credentials, specify the build ID as returned with an initial\n`CreateBuild` request. If successful, a new set of credentials are returned,\nalong with the S3 storage location associated with the build ID.","ref":"AWS.GameLift.html#request_upload_credentials/3","title":"AWS.GameLift.request_upload_credentials/3","type":"function"},{"doc":"[ Create a Build with Files in\nS3](https://docs.aws.amazon.com/gamelift/latest/developerguide/gamelift-build-cli-uploading.html#gamelift-build-cli-uploading-create-build)\n\n[All APIs by task](https://docs.aws.amazon.com/gamelift/latest/developerguide/reference-awssdk.html#reference-awssdk-resources-fleets)","ref":"AWS.GameLift.html#request_upload_credentials/3-learn-more","title":"Learn more - AWS.GameLift.request_upload_credentials/3","type":"function"},{"doc":"Retrieves the fleet ID that an alias is currently pointing to.","ref":"AWS.GameLift.html#resolve_alias/3","title":"AWS.GameLift.resolve_alias/3","type":"function"},{"doc":"[All APIs by task](https://docs.aws.amazon.com/gamelift/latest/developerguide/reference-awssdk.html#reference-awssdk-resources-fleets)","ref":"AWS.GameLift.html#resolve_alias/3-related-actions","title":"Related actions - AWS.GameLift.resolve_alias/3","type":"function"},{"doc":"","ref":"AWS.GameLift.html#resume_game_server_group/3","title":"AWS.GameLift.resume_game_server_group/3","type":"function"},{"doc":"server groups.\n\nReinstates activity on a game server group after it has been suspended.\n\nA game server group might be suspended by the\n[SuspendGameServerGroup](gamelift/latest/apireference/API_SuspendGameServerGroup.html) operation, or it might be suspended involuntarily due to a configuration\nproblem. In the second case, you can manually resume activity on the group once\nthe configuration problem has been resolved. Refer to the game server group\nstatus and status reason for more information on why group activity is\nsuspended.\n\nTo resume activity, specify a game server group ARN and the type of activity to\nbe resumed. If successful, a `GameServerGroup` object is returned showing that\nthe resumed activity is no longer listed in `SuspendedActions`.","ref":"AWS.GameLift.html#resume_game_server_group/3-this-operation-is-used-with-the-amazon-gamelift-fleetiq-solution-and-game","title":"This operation is used with the Amazon GameLift FleetIQ solution and game - AWS.GameLift.resume_game_server_group/3","type":"function"},{"doc":"[Amazon GameLift FleetIQ\nGuide](https://docs.aws.amazon.com/gamelift/latest/fleetiqguide/gsg-intro.html)","ref":"AWS.GameLift.html#resume_game_server_group/3-learn-more","title":"Learn more - AWS.GameLift.resume_game_server_group/3","type":"function"},{"doc":"Retrieves all active game sessions that match a set of search criteria and sorts\nthem into a specified order.\n\nThis operation is not designed to continually track game session status because\nthat practice can cause you to exceed your API limit and generate errors.\nInstead, configure an Amazon Simple Notification Service (Amazon SNS) topic to\nreceive notifications from a matchmaker or game session placement queue.\n\nWhen searching for game sessions, you specify exactly where you want to search\nand provide a search filter expression, a sort expression, or both. A search\nrequest can search only one fleet, but it can search all of a fleet's locations.\n\nThis operation can be used in the following ways:\n\n  * To search all game sessions that are currently running on all\nlocations in a fleet, provide a fleet or alias ID. This approach returns game\nsessions in the fleet's home Region and all remote locations that fit the search\ncriteria.\n\n  * To search all game sessions that are currently running on a\nspecific fleet location, provide a fleet or alias ID and a location name. For\nlocation, you can specify a fleet's home Region or any remote location.\n\nUse the pagination parameters to retrieve results as a set of sequential pages.\n\nIf successful, a `GameSession` object is returned for each game session that\nmatches the request. Search finds game sessions that are in `ACTIVE` status\nonly. To retrieve information on game sessions in other statuses, use\n[DescribeGameSessions](https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeGameSessions.html) .\n\nTo set search and sort criteria, create a filter expression using the following\ngame session attributes. For game session search examples, see the Examples\nsection of this topic.\n\n  * **gameSessionId** -- A unique identifier for the game session. You\ncan use either a `GameSessionId` or `GameSessionArn` value.\n\n  * **gameSessionName** -- Name assigned to a game session. Game\nsession names do not need to be unique to a game session.\n\n  * **gameSessionProperties** -- A set of key-value pairs that can\nstore custom data in a game session. For example: `{\"Key\": \"difficulty\",\n\"Value\": \"novice\"}`. The filter expression must specify the `GameProperty` -- a\n`Key` and a string `Value` to search for the game sessions.\n\nFor example, to search for the above key-value pair, specify the following\nsearch filter: `gameSessionProperties.difficulty = \"novice\"`. All game property\nvalues are searched as strings.\n\nFor examples of searching game sessions, see the ones below, and also see\n[Search game sessions by game\nproperty](https://docs.aws.amazon.com/gamelift/latest/developerguide/gamelift-sdk-client-api.html#game-properties-search).\n\n  * **maximumSessions** -- Maximum number of player sessions allowed\nfor a game session.\n\n  * **creationTimeMillis** -- Value indicating when a game session was\ncreated. It is expressed in Unix time as milliseconds.\n\n  * **playerSessionCount** -- Number of players currently connected to\na game session. This value changes rapidly as players join the session or drop\nout.\n\n  * **hasAvailablePlayerSessions** -- Boolean value indicating whether\na game session has reached its maximum number of players. It is highly\nrecommended that all search requests include this filter attribute to optimize\nsearch performance and return only sessions that players can join.\n\nReturned values for `playerSessionCount` and `hasAvailablePlayerSessions` change\nquickly as players join sessions and others drop out. Results should be\nconsidered a snapshot in time. Be sure to refresh search results often, and\nhandle sessions that fill up before a player can join.\n\n[All APIs by task](https://docs.aws.amazon.com/gamelift/latest/developerguide/reference-awssdk.html#reference-awssdk-resources-fleets)","ref":"AWS.GameLift.html#search_game_sessions/3","title":"AWS.GameLift.search_game_sessions/3","type":"function"},{"doc":"Resumes certain types of activity on fleet instances that were suspended with\n[StopFleetActions](https://docs.aws.amazon.com/gamelift/latest/apireference/API_StopFleetActions.html).  For multi-location fleets, fleet actions are managed separately for each\nlocation. Currently, this operation is used to restart a fleet's auto-scaling\nactivity.\n\nThis operation can be used in the following ways:\n\n  * To restart actions on instances in the fleet's home Region,\nprovide a fleet ID and the type of actions to resume.\n\n  * To restart actions on instances in one of the fleet's remote\nlocations, provide a fleet ID, a location name, and the type of actions to\nresume.\n\nIf successful, Amazon GameLift once again initiates scaling events as triggered\nby the fleet's scaling policies. If actions on the fleet location were never\nstopped, this operation will have no effect.","ref":"AWS.GameLift.html#start_fleet_actions/3","title":"AWS.GameLift.start_fleet_actions/3","type":"function"},{"doc":"[Setting up Amazon GameLift\nfleets](https://docs.aws.amazon.com/gamelift/latest/developerguide/fleets-intro.html)","ref":"AWS.GameLift.html#start_fleet_actions/3-learn-more","title":"Learn more - AWS.GameLift.start_fleet_actions/3","type":"function"},{"doc":"Places a request for a new game session in a queue.\n\nWhen processing a placement request, Amazon GameLift searches for available\nresources on the queue's destinations, scanning each until it finds resources or\nthe placement request times out.\n\nA game session placement request can also request player sessions. When a new\ngame session is successfully created, Amazon GameLift creates a player session\nfor each player included in the request.\n\nWhen placing a game session, by default Amazon GameLift tries each fleet in the\norder they are listed in the queue configuration. Ideally, a queue's\ndestinations are listed in preference order.\n\nAlternatively, when requesting a game session with players, you can also provide\nlatency data for each player in relevant Regions. Latency data indicates the\nperformance lag a player experiences when connected to a fleet in the Region.\nAmazon GameLift uses latency data to reorder the list of destinations to place\nthe game session in a Region with minimal lag. If latency data is provided for\nmultiple players, Amazon GameLift calculates each Region's average lag for all\nplayers and reorders to get the best game play across all players.\n\nTo place a new game session request, specify the following:\n\n  * The queue name and a set of game session properties and settings\n\n  * A unique ID (such as a UUID) for the placement. You use this ID to\ntrack the status of the placement request\n\n  * (Optional) A set of player data and a unique player ID for each\nplayer that you are joining to the new game session (player data is optional,\nbut if you include it, you must also provide a unique ID for each player)\n\n  * Latency data for all players (if you want to optimize game play\nfor the players)\n\nIf successful, a new game session placement is created.\n\nTo track the status of a placement request, call\n[DescribeGameSessionPlacement](https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeGameSessionPlacement.html)\nand check the request's status. If the status is `FULFILLED`, a new game session\nhas been created and a game session ARN and Region are referenced. If the\nplacement request times out, you can resubmit the request or retry it with a\ndifferent queue.","ref":"AWS.GameLift.html#start_game_session_placement/3","title":"AWS.GameLift.start_game_session_placement/3","type":"function"},{"doc":"Finds new players to fill open slots in currently running game sessions.\n\nThe backfill match process is essentially identical to the process of forming\nnew matches. Backfill requests use the same matchmaker that was used to make the\noriginal match, and they provide matchmaking data for all players currently in\nthe game session. FlexMatch uses this information to select new players so that\nbackfilled match continues to meet the original match requirements.\n\nWhen using FlexMatch with Amazon GameLift managed hosting, you can request a\nbackfill match from a client service by calling this operation with a\n`GameSessions` ID. You also have the option of making backfill requests directly\nfrom your game server. In response to a request, FlexMatch creates player\nsessions for the new players, updates the `GameSession` resource, and sends\nupdated matchmaking data to the game server. You can request a backfill match at\nany point after a game session is started. Each game session can have only one\nactive backfill request at a time; a subsequent request automatically replaces\nthe earlier request.\n\nWhen using FlexMatch as a standalone component, request a backfill match by\ncalling this operation without a game session identifier. As with newly formed\nmatches, matchmaking results are returned in a matchmaking event so that your\ngame can update the game session that is being backfilled.\n\nTo request a backfill match, specify a unique ticket ID, the original\nmatchmaking configuration, and matchmaking data for all current players in the\ngame session being backfilled. Optionally, specify the `GameSession` ARN. If\nsuccessful, a match backfill ticket is created and returned with status set to\nQUEUED. Track the status of backfill tickets using the same method for tracking\ntickets for new matches.\n\nOnly game sessions created by FlexMatch are supported for match backfill.","ref":"AWS.GameLift.html#start_match_backfill/3","title":"AWS.GameLift.start_match_backfill/3","type":"function"},{"doc":"[ Backfill existing games with FlexMatch](https://docs.aws.amazon.com/gamelift/latest/flexmatchguide/match-backfill.html)\n\n[ Matchmaking events](https://docs.aws.amazon.com/gamelift/latest/flexmatchguide/match-events.html)\n(reference)\n\n[ How Amazon GameLift FlexMatch works](https://docs.aws.amazon.com/gamelift/latest/flexmatchguide/gamelift-match.html)","ref":"AWS.GameLift.html#start_match_backfill/3-learn-more","title":"Learn more - AWS.GameLift.start_match_backfill/3","type":"function"},{"doc":"Uses FlexMatch to create a game match for a group of players based on custom\nmatchmaking rules.\n\nWith games that use Amazon GameLift managed hosting, this operation also\ntriggers Amazon GameLift to find hosting resources and start a new game session\nfor the new match. Each matchmaking request includes information on one or more\nplayers and specifies the FlexMatch matchmaker to use. When a request is for\nmultiple players, FlexMatch attempts to build a match that includes all players\nin the request, placing them in the same team and finding additional players as\nneeded to fill the match.\n\nTo start matchmaking, provide a unique ticket ID, specify a matchmaking\nconfiguration, and include the players to be matched. You must also include any\nplayer attributes that are required by the matchmaking configuration's rule set.\nIf successful, a matchmaking ticket is returned with status set to `QUEUED`.\n\nTrack matchmaking events to respond as needed and acquire game session\nconnection information for successfully completed matches. Ticket status updates\nare tracked using event notification through Amazon Simple Notification Service,\nwhich is defined in the matchmaking configuration.","ref":"AWS.GameLift.html#start_matchmaking/3","title":"AWS.GameLift.start_matchmaking/3","type":"function"},{"doc":"[ Add FlexMatch to a game client](https://docs.aws.amazon.com/gamelift/latest/flexmatchguide/match-client.html)\n\n[ Set Up FlexMatch event notification](https://docs.aws.amazon.com/gamelift/latest/flexmatchguide/match-notification.html)\n\n[ How Amazon GameLift FlexMatch works](https://docs.aws.amazon.com/gamelift/latest/flexmatchguide/gamelift-match.html)","ref":"AWS.GameLift.html#start_matchmaking/3-learn-more","title":"Learn more - AWS.GameLift.start_matchmaking/3","type":"function"},{"doc":"Suspends certain types of activity in a fleet location.\n\nCurrently, this operation is used to stop auto-scaling activity. For\nmulti-location fleets, fleet actions are managed separately for each location.\n\nStopping fleet actions has several potential purposes. It allows you to\ntemporarily stop auto-scaling activity but retain your scaling policies for use\nin the future. For multi-location fleets, you can set up fleet-wide\nauto-scaling, and then opt out of it for certain locations.\n\nThis operation can be used in the following ways:\n\n  * To stop actions on instances in the fleet's home Region, provide a\nfleet ID and the type of actions to suspend.\n\n  * To stop actions on instances in one of the fleet's remote\nlocations, provide a fleet ID, a location name, and the type of actions to\nsuspend.\n\nIf successful, Amazon GameLift no longer initiates scaling events except in\nresponse to manual changes using\n[UpdateFleetCapacity](https://docs.aws.amazon.com/gamelift/latest/apireference/API_UpdateFleetCapacity.html).","ref":"AWS.GameLift.html#stop_fleet_actions/3","title":"AWS.GameLift.stop_fleet_actions/3","type":"function"},{"doc":"[Setting up Amazon GameLift\nFleets](https://docs.aws.amazon.com/gamelift/latest/developerguide/fleets-intro.html)","ref":"AWS.GameLift.html#stop_fleet_actions/3-learn-more","title":"Learn more - AWS.GameLift.stop_fleet_actions/3","type":"function"},{"doc":"Cancels a game session placement that is in `PENDING` status.\n\nTo stop a placement, provide the placement ID values. If successful, the\nplacement is moved to `CANCELLED` status.","ref":"AWS.GameLift.html#stop_game_session_placement/3","title":"AWS.GameLift.stop_game_session_placement/3","type":"function"},{"doc":"Cancels a matchmaking ticket or match backfill ticket that is currently being\nprocessed.\n\nTo stop the matchmaking operation, specify the ticket ID. If successful, work on\nthe ticket is stopped, and the ticket status is changed to `CANCELLED`.\n\nThis call is also used to turn off automatic backfill for an individual game\nsession. This is for game sessions that are created with a matchmaking\nconfiguration that has automatic backfill enabled. The ticket ID is included in\nthe `MatchmakerData` of an updated game session object, which is provided to the\ngame server.\n\nIf the operation is successful, the service sends back an empty JSON struct with\nthe HTTP 200 response (not an empty HTTP body).","ref":"AWS.GameLift.html#stop_matchmaking/3","title":"AWS.GameLift.stop_matchmaking/3","type":"function"},{"doc":"[ Add FlexMatch to a game client](https://docs.aws.amazon.com/gamelift/latest/flexmatchguide/match-client.html)","ref":"AWS.GameLift.html#stop_matchmaking/3-learn-more","title":"Learn more - AWS.GameLift.stop_matchmaking/3","type":"function"},{"doc":"","ref":"AWS.GameLift.html#suspend_game_server_group/3","title":"AWS.GameLift.suspend_game_server_group/3","type":"function"},{"doc":"server groups.\n\nTemporarily stops activity on a game server group without terminating instances\nor the game server group.\n\nYou can restart activity by calling\n[ResumeGameServerGroup](gamelift/latest/apireference/API_ResumeGameServerGroup.html). You can suspend the following activity:\n\n  * **Instance type replacement** - This activity evaluates the\ncurrent game hosting viability of all Spot instance types that are defined for\nthe game server group. It updates the Auto Scaling group to remove nonviable\nSpot Instance types, which have a higher chance of game server interruptions. It\nthen balances capacity across the remaining viable Spot Instance types. When\nthis activity is suspended, the Auto Scaling group continues with its current\nbalance, regardless of viability. Instance protection, utilization metrics, and\ncapacity scaling activities continue to be active.\n\nTo suspend activity, specify a game server group ARN and the type of activity to\nbe suspended. If successful, a `GameServerGroup` object is returned showing that\nthe activity is listed in `SuspendedActions`.","ref":"AWS.GameLift.html#suspend_game_server_group/3-this-operation-is-used-with-the-amazon-gamelift-fleetiq-solution-and-game","title":"This operation is used with the Amazon GameLift FleetIQ solution and game - AWS.GameLift.suspend_game_server_group/3","type":"function"},{"doc":"[Amazon GameLift FleetIQ\nGuide](https://docs.aws.amazon.com/gamelift/latest/fleetiqguide/gsg-intro.html)","ref":"AWS.GameLift.html#suspend_game_server_group/3-learn-more","title":"Learn more - AWS.GameLift.suspend_game_server_group/3","type":"function"},{"doc":"Assigns a tag to an Amazon GameLift resource.\n\nYou can use tags to organize resources, create IAM permissions policies to\nmanage access to groups of resources, customize Amazon Web Services cost\nbreakdowns, and more. This operation handles the permissions necessary to manage\ntags for Amazon GameLift resources that support tagging.\n\nTo add a tag to a resource, specify the unique ARN value for the resource and\nprovide a tag list containing one or more tags. The operation succeeds even if\nthe list includes tags that are already assigned to the resource.","ref":"AWS.GameLift.html#tag_resource/3","title":"AWS.GameLift.tag_resource/3","type":"function"},{"doc":"[Tagging Amazon Web Services Resources](https://docs.aws.amazon.com/general/latest/gr/aws_tagging.html) in\nthe *Amazon Web Services General Reference*\n\n[ Amazon Web Services Tagging Strategies](http://aws.amazon.com/answers/account-management/aws-tagging-strategies/)","ref":"AWS.GameLift.html#tag_resource/3-learn-more","title":"Learn more - AWS.GameLift.tag_resource/3","type":"function"},{"doc":"[All APIs by task](https://docs.aws.amazon.com/gamelift/latest/developerguide/reference-awssdk.html#reference-awssdk-resources-fleets)","ref":"AWS.GameLift.html#tag_resource/3-related-actions","title":"Related actions - AWS.GameLift.tag_resource/3","type":"function"},{"doc":"Removes a tag assigned to a Amazon GameLift resource.\n\nYou can use resource tags to organize Amazon Web Services resources for a range\nof purposes. This operation handles the permissions necessary to manage tags for\nAmazon GameLift resources that support tagging.\n\nTo remove a tag from a resource, specify the unique ARN value for the resource\nand provide a string list containing one or more tags to remove. This operation\nsucceeds even if the list includes tags that aren't assigned to the resource.","ref":"AWS.GameLift.html#untag_resource/3","title":"AWS.GameLift.untag_resource/3","type":"function"},{"doc":"[Tagging Amazon Web Services Resources](https://docs.aws.amazon.com/general/latest/gr/aws_tagging.html) in\nthe *Amazon Web Services General Reference*\n\n[ Amazon Web Services Tagging Strategies](http://aws.amazon.com/answers/account-management/aws-tagging-strategies/)","ref":"AWS.GameLift.html#untag_resource/3-learn-more","title":"Learn more - AWS.GameLift.untag_resource/3","type":"function"},{"doc":"[All APIs by task](https://docs.aws.amazon.com/gamelift/latest/developerguide/reference-awssdk.html#reference-awssdk-resources-fleets)","ref":"AWS.GameLift.html#untag_resource/3-related-actions","title":"Related actions - AWS.GameLift.untag_resource/3","type":"function"},{"doc":"Updates properties for an alias.\n\nTo update properties, specify the alias ID to be updated and provide the\ninformation to be changed. To reassign an alias to another fleet, provide an\nupdated routing strategy. If successful, the updated alias record is returned.","ref":"AWS.GameLift.html#update_alias/3","title":"AWS.GameLift.update_alias/3","type":"function"},{"doc":"[All APIs by task](https://docs.aws.amazon.com/gamelift/latest/developerguide/reference-awssdk.html#reference-awssdk-resources-fleets)","ref":"AWS.GameLift.html#update_alias/3-related-actions","title":"Related actions - AWS.GameLift.update_alias/3","type":"function"},{"doc":"Updates metadata in a build resource, including the build name and version.\n\nTo update the metadata, specify the build ID to update and provide the new\nvalues. If successful, a build object containing the updated metadata is\nreturned.","ref":"AWS.GameLift.html#update_build/3","title":"AWS.GameLift.update_build/3","type":"function"},{"doc":"[ Upload a Custom Server Build](https://docs.aws.amazon.com/gamelift/latest/developerguide/gamelift-build-intro.html)\n\n[All APIs by task](https://docs.aws.amazon.com/gamelift/latest/developerguide/reference-awssdk.html#reference-awssdk-resources-fleets)","ref":"AWS.GameLift.html#update_build/3-learn-more","title":"Learn more - AWS.GameLift.update_build/3","type":"function"},{"doc":"Updates a fleet's mutable attributes, including game session protection and\nresource creation limits.\n\nTo update fleet attributes, specify the fleet ID and the property values that\nyou want to change.\n\nIf successful, an updated `FleetAttributes` object is returned.","ref":"AWS.GameLift.html#update_fleet_attributes/3","title":"AWS.GameLift.update_fleet_attributes/3","type":"function"},{"doc":"[Setting up Amazon GameLift fleets](https://docs.aws.amazon.com/gamelift/latest/developerguide/fleets-intro.html)","ref":"AWS.GameLift.html#update_fleet_attributes/3-learn-more","title":"Learn more - AWS.GameLift.update_fleet_attributes/3","type":"function"},{"doc":"Updates capacity settings for a fleet.\n\nFor fleets with multiple locations, use this operation to manage capacity\nsettings in each location individually. Fleet capacity determines the number of\ngame sessions and players that can be hosted based on the fleet configuration.\nUse this operation to set the following fleet capacity properties:\n\n  * Minimum/maximum size: Set hard limits on fleet capacity. Amazon\nGameLift cannot set the fleet's capacity to a value outside of this range,\nwhether the capacity is changed manually or through automatic scaling.\n\n  * Desired capacity: Manually set the number of Amazon EC2 instances\nto be maintained in a fleet location. Before changing a fleet's desired\ncapacity, you may want to call\n[DescribeEC2InstanceLimits](https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeEC2InstanceLimits.html) to get the maximum capacity of the fleet's Amazon EC2 instance type.\nAlternatively, consider using automatic scaling to adjust capacity based on\nplayer demand.\n\nThis operation can be used in the following ways:\n\n  * To update capacity for a fleet's home Region, or if the fleet has\nno remote locations, omit the `Location` parameter. The fleet must be in\n`ACTIVE` status.\n\n  * To update capacity for a fleet's remote location, include the\n`Location` parameter set to the location to be updated. The location must be in\n`ACTIVE` status.\n\nIf successful, capacity settings are updated immediately. In response a change\nin desired capacity, Amazon GameLift initiates steps to start new instances or\nterminate existing instances in the requested fleet location. This continues\nuntil the location's active instance count matches the new desired instance\ncount. You can track a fleet's current capacity by calling\n[DescribeFleetCapacity](https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeFleetCapacity.html)\nor\n[DescribeFleetLocationCapacity](https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeFleetLocationCapacity.html). If the requested desired instance count is higher than the instance type's\nlimit, the `LimitExceeded` exception occurs.","ref":"AWS.GameLift.html#update_fleet_capacity/3","title":"AWS.GameLift.update_fleet_capacity/3","type":"function"},{"doc":"[Scaling fleet\ncapacity](https://docs.aws.amazon.com/gamelift/latest/developerguide/fleets-manage-capacity.html)","ref":"AWS.GameLift.html#update_fleet_capacity/3-learn-more","title":"Learn more - AWS.GameLift.update_fleet_capacity/3","type":"function"},{"doc":"Updates permissions that allow inbound traffic to connect to game sessions that\nare being hosted on instances in the fleet.\n\nTo update settings, specify the fleet ID to be updated and specify the changes\nto be made. List the permissions you want to add in\n`InboundPermissionAuthorizations`, and permissions you want to remove in\n`InboundPermissionRevocations`. Permissions to be removed must match existing\nfleet permissions.\n\nIf successful, the fleet ID for the updated fleet is returned. For fleets with\nremote locations, port setting updates can take time to propagate across all\nlocations. You can check the status of updates in each location by calling\n`DescribeFleetPortSettings` with a location name.","ref":"AWS.GameLift.html#update_fleet_port_settings/3","title":"AWS.GameLift.update_fleet_port_settings/3","type":"function"},{"doc":"[Setting up Amazon GameLift fleets](https://docs.aws.amazon.com/gamelift/latest/developerguide/fleets-intro.html)","ref":"AWS.GameLift.html#update_fleet_port_settings/3-learn-more","title":"Learn more - AWS.GameLift.update_fleet_port_settings/3","type":"function"},{"doc":"","ref":"AWS.GameLift.html#update_game_server/3","title":"AWS.GameLift.update_game_server/3","type":"function"},{"doc":"server groups.\n\nUpdates information about a registered game server to help Amazon GameLift\nFleetIQ track game server availability.\n\nThis operation is called by a game server process that is running on an instance\nin a game server group.\n\nUse this operation to update the following types of game server information. You\ncan make all three types of updates in the same request:\n\n  * To update the game server's utilization status from `AVAILABLE`\n(when the game server is available to be claimed) to `UTILIZED` (when the game\nserver is currently hosting games). Identify the game server and game server\ngroup and specify the new utilization status. You can't change the status from\nto `UTILIZED` to `AVAILABLE` .\n\n  * To report health status, identify the game server and game server\ngroup and set health check to `HEALTHY`. If a game server does not report health\nstatus for a certain length of time, the game server is no longer considered\nhealthy. As a result, it will be eventually deregistered from the game server\ngroup to avoid affecting utilization metrics. The best practice is to report\nhealth every 60 seconds.\n\n  * To change game server metadata, provide updated game server data.\n\nOnce a game server is successfully updated, the relevant statuses and timestamps\nare updated.","ref":"AWS.GameLift.html#update_game_server/3-this-operation-is-used-with-the-amazon-gamelift-fleetiq-solution-and-game","title":"This operation is used with the Amazon GameLift FleetIQ solution and game - AWS.GameLift.update_game_server/3","type":"function"},{"doc":"[Amazon GameLift FleetIQ Guide](https://docs.aws.amazon.com/gamelift/latest/fleetiqguide/gsg-intro.html)","ref":"AWS.GameLift.html#update_game_server/3-learn-more","title":"Learn more - AWS.GameLift.update_game_server/3","type":"function"},{"doc":"","ref":"AWS.GameLift.html#update_game_server_group/3","title":"AWS.GameLift.update_game_server_group/3","type":"function"},{"doc":"server groups.\n\nUpdates Amazon GameLift FleetIQ-specific properties for a game server group.\n\nMany Auto Scaling group properties are updated on the Auto Scaling group\ndirectly, including the launch template, Auto Scaling policies, and\nmaximum/minimum/desired instance counts.\n\nTo update the game server group, specify the game server group ID and provide\nthe updated values. Before applying the updates, the new values are validated to\nensure that Amazon GameLift FleetIQ can continue to perform instance balancing\nactivity. If successful, a `GameServerGroup` object is returned.","ref":"AWS.GameLift.html#update_game_server_group/3-this-operation-is-used-with-the-amazon-gamelift-fleetiq-solution-and-game","title":"This operation is used with the Amazon GameLift FleetIQ solution and game - AWS.GameLift.update_game_server_group/3","type":"function"},{"doc":"[Amazon GameLift FleetIQ Guide](https://docs.aws.amazon.com/gamelift/latest/fleetiqguide/gsg-intro.html)","ref":"AWS.GameLift.html#update_game_server_group/3-learn-more","title":"Learn more - AWS.GameLift.update_game_server_group/3","type":"function"},{"doc":"Updates the mutable properties of a game session.\n\nTo update a game session, specify the game session ID and the values you want to\nchange.\n\nIf successful, the updated `GameSession` object is returned.\n\n[All APIs by task](https://docs.aws.amazon.com/gamelift/latest/developerguide/reference-awssdk.html#reference-awssdk-resources-fleets)","ref":"AWS.GameLift.html#update_game_session/3","title":"AWS.GameLift.update_game_session/3","type":"function"},{"doc":"Updates the configuration of a game session queue, which determines how the\nqueue processes new game session requests.\n\nTo update settings, specify the queue name to be updated and provide the new\nsettings. When updating destinations, provide a complete list of destinations.","ref":"AWS.GameLift.html#update_game_session_queue/3","title":"AWS.GameLift.update_game_session_queue/3","type":"function"},{"doc":"[ Using Multi-Region Queues](https://docs.aws.amazon.com/gamelift/latest/developerguide/queues-intro.html)","ref":"AWS.GameLift.html#update_game_session_queue/3-learn-more","title":"Learn more - AWS.GameLift.update_game_session_queue/3","type":"function"},{"doc":"Updates settings for a FlexMatch matchmaking configuration.\n\nThese changes affect all matches and game sessions that are created after the\nupdate. To update settings, specify the configuration name to be updated and\nprovide the new settings.","ref":"AWS.GameLift.html#update_matchmaking_configuration/3","title":"AWS.GameLift.update_matchmaking_configuration/3","type":"function"},{"doc":"[ Design a FlexMatch matchmaker](https://docs.aws.amazon.com/gamelift/latest/flexmatchguide/match-configuration.html)","ref":"AWS.GameLift.html#update_matchmaking_configuration/3-learn-more","title":"Learn more - AWS.GameLift.update_matchmaking_configuration/3","type":"function"},{"doc":"Updates the current runtime configuration for the specified fleet, which tells\nAmazon GameLift how to launch server processes on all instances in the fleet.\n\nYou can update a fleet's runtime configuration at any time after the fleet is\ncreated; it does not need to be in `ACTIVE` status.\n\nTo update runtime configuration, specify the fleet ID and provide a\n`RuntimeConfiguration` with an updated set of server process configurations.\n\nIf successful, the fleet's runtime configuration settings are updated. Each\ninstance in the fleet regularly checks for and retrieves updated runtime\nconfigurations. Instances immediately begin complying with the new configuration\nby launching new server processes or not replacing existing processes when they\nshut down. Updating a fleet's runtime configuration never affects existing\nserver processes.","ref":"AWS.GameLift.html#update_runtime_configuration/3","title":"AWS.GameLift.update_runtime_configuration/3","type":"function"},{"doc":"[Setting up Amazon GameLift fleets](https://docs.aws.amazon.com/gamelift/latest/developerguide/fleets-intro.html)","ref":"AWS.GameLift.html#update_runtime_configuration/3-learn-more","title":"Learn more - AWS.GameLift.update_runtime_configuration/3","type":"function"},{"doc":"Updates Realtime script metadata and content.\n\nTo update script metadata, specify the script ID and provide updated name and/or\nversion values.\n\nTo update script content, provide an updated zip file by pointing to either a\nlocal file or an Amazon S3 bucket location. You can use either method regardless\nof how the original script was uploaded. Use the *Version* parameter to track\nupdates to the script.\n\nIf the call is successful, the updated metadata is stored in the script record\nand a revised script is uploaded to the Amazon GameLift service. Once the script\nis updated and acquired by a fleet instance, the new version is used for all new\ngame sessions.","ref":"AWS.GameLift.html#update_script/3","title":"AWS.GameLift.update_script/3","type":"function"},{"doc":"[Amazon GameLift Realtime Servers](https://docs.aws.amazon.com/gamelift/latest/developerguide/realtime-intro.html)","ref":"AWS.GameLift.html#update_script/3-learn-more","title":"Learn more - AWS.GameLift.update_script/3","type":"function"},{"doc":"[All APIs by task](https://docs.aws.amazon.com/gamelift/latest/developerguide/reference-awssdk.html#reference-awssdk-resources-fleets)","ref":"AWS.GameLift.html#update_script/3-related-actions","title":"Related actions - AWS.GameLift.update_script/3","type":"function"},{"doc":"Validates the syntax of a matchmaking rule or rule set.\n\nThis operation checks that the rule set is using syntactically correct JSON and\nthat it conforms to allowed property expressions. To validate syntax, provide a\nrule set JSON string.","ref":"AWS.GameLift.html#validate_matchmaking_rule_set/3","title":"AWS.GameLift.validate_matchmaking_rule_set/3","type":"function"},{"doc":"* [Build a rule set](https://docs.aws.amazon.com/gamelift/latest/flexmatchguide/match-rulesets.html)","ref":"AWS.GameLift.html#validate_matchmaking_rule_set/3-learn-more","title":"Learn more - AWS.GameLift.validate_matchmaking_rule_set/3","type":"function"},{"doc":"Amazon S3 Glacier (Glacier) is a storage solution for \"cold data.\"\n\nGlacier is an extremely low-cost storage service that provides secure, durable,\nand easy-to-use storage for data backup and archival.\n\nWith Glacier, customers can store their data cost effectively for months, years,\nor decades. Glacier also enables customers to offload the administrative burdens\nof operating and scaling storage to AWS, so they don't have to worry about\ncapacity planning, hardware provisioning, data replication, hardware failure and\nrecovery, or time-consuming hardware migrations.\n\nGlacier is a great storage choice when low storage cost is paramount and your\ndata is rarely retrieved. If your application requires fast or frequent access\nto your data, consider using Amazon S3. For more information, see [Amazon Simple Storage Service (Amazon S3)](http://aws.amazon.com/s3/).\n\nYou can store any kind of data in any format. There is no maximum limit on the\ntotal amount of data you can store in Glacier.\n\nIf you are a first-time user of Glacier, we recommend that you begin by reading\nthe following sections in the *Amazon S3 Glacier Developer Guide*:\n\n  * [What is Amazon S3 Glacier](https://docs.aws.amazon.com/amazonglacier/latest/dev/introduction.html)\n- This section of the Developer Guide describes the underlying data model, the\noperations it supports, and the AWS SDKs that you can use to interact with the\nservice.\n\n  * [Getting Started with Amazon S3 Glacier](https://docs.aws.amazon.com/amazonglacier/latest/dev/amazon-glacier-getting-started.html)\n- The Getting Started section walks you through the process of creating a vault,\nuploading archives, creating jobs to download archives, retrieving the job\noutput, and deleting archives.","ref":"AWS.Glacier.html","title":"AWS.Glacier","type":"module"},{"doc":"This operation aborts a multipart upload identified by the upload ID.\n\nAfter the Abort Multipart Upload request succeeds, you cannot upload any more\nparts to the multipart upload or complete the multipart upload. Aborting a\ncompleted upload fails. However, aborting an already-aborted upload will\nsucceed, for a short time. For more information about uploading a part and\ncompleting a multipart upload, see `UploadMultipartPart` and\n`CompleteMultipartUpload`.\n\nThis operation is idempotent.\n\nAn AWS account has full permission to perform all operations (actions). However,\nAWS Identity and Access Management (IAM) users don't have any permissions by\ndefault. You must grant them explicit permission to perform specific actions.\nFor more information, see [Access Control Using AWS Identity and Access Management\n(IAM)](https://docs.aws.amazon.com/amazonglacier/latest/dev/using-iam-with-amazon-glacier.html).\n\nFor conceptual information and underlying REST API, see [Working with Archives in Amazon S3\nGlacier](https://docs.aws.amazon.com/amazonglacier/latest/dev/working-with-archives.html)\nand [Abort Multipart Upload](https://docs.aws.amazon.com/amazonglacier/latest/dev/api-multipart-abort-upload.html)\nin the *Amazon Glacier Developer Guide*.","ref":"AWS.Glacier.html#abort_multipart_upload/6","title":"AWS.Glacier.abort_multipart_upload/6","type":"function"},{"doc":"This operation aborts the vault locking process if the vault lock is not in the\n`Locked` state.\n\nIf the vault lock is in the `Locked` state when this operation is requested, the\noperation returns an `AccessDeniedException` error. Aborting the vault locking\nprocess removes the vault lock policy from the specified vault.\n\nA vault lock is put into the `InProgress` state by calling `InitiateVaultLock`.\nA vault lock is put into the `Locked` state by calling `CompleteVaultLock`. You\ncan get the state of a vault lock by calling `GetVaultLock`. For more\ninformation about the vault locking process, see [Amazon Glacier Vault Lock](https://docs.aws.amazon.com/amazonglacier/latest/dev/vault-lock.html). For\nmore information about vault lock policies, see [Amazon Glacier Access Control with Vault Lock\nPolicies](https://docs.aws.amazon.com/amazonglacier/latest/dev/vault-lock-policy.html).\n\nThis operation is idempotent. You can successfully invoke this operation\nmultiple times, if the vault lock is in the `InProgress` state or if there is no\npolicy associated with the vault.","ref":"AWS.Glacier.html#abort_vault_lock/5","title":"AWS.Glacier.abort_vault_lock/5","type":"function"},{"doc":"This operation adds the specified tags to a vault.\n\nEach tag is composed of a key and a value. Each vault can have up to 10 tags. If\nyour request would cause the tag limit for the vault to be exceeded, the\noperation throws the `LimitExceededException` error. If a tag already exists on\nthe vault under a specified key, the existing key value will be overwritten. For\nmore information about tags, see [Tagging Amazon S3 Glacier Resources](https://docs.aws.amazon.com/amazonglacier/latest/dev/tagging.html).","ref":"AWS.Glacier.html#add_tags_to_vault/5","title":"AWS.Glacier.add_tags_to_vault/5","type":"function"},{"doc":"You call this operation to inform Amazon S3 Glacier (Glacier) that all the\narchive parts have been uploaded and that Glacier can now assemble the archive\nfrom the uploaded parts.\n\nAfter assembling and saving the archive to the vault, Glacier returns the URI\npath of the newly created archive resource. Using the URI path, you can then\naccess the archive. After you upload an archive, you should save the archive ID\nreturned to retrieve the archive at a later point. You can also get the vault\ninventory to obtain a list of archive IDs in a vault. For more information, see\n`InitiateJob`.\n\nIn the request, you must include the computed SHA256 tree hash of the entire\narchive you have uploaded. For information about computing a SHA256 tree hash,\nsee [Computing Checksums](https://docs.aws.amazon.com/amazonglacier/latest/dev/checksum-calculations.html).\nOn the server side, Glacier also constructs the SHA256 tree hash of the\nassembled archive. If the values match, Glacier saves the archive to the vault;\notherwise, it returns an error, and the operation fails. The `ListParts`\noperation returns a list of parts uploaded for a specific multipart upload. It\nincludes checksum information for each uploaded part that can be used to debug a\nbad checksum issue.\n\nAdditionally, Glacier also checks for any missing content ranges when assembling\nthe archive, if missing content ranges are found, Glacier returns an error and\nthe operation fails.\n\nComplete Multipart Upload is an idempotent operation. After your first\nsuccessful complete multipart upload, if you call the operation again within a\nshort period, the operation will succeed and return the same archive ID. This is\nuseful in the event you experience a network issue that causes an aborted\nconnection or receive a 500 server error, in which case you can repeat your\nComplete Multipart Upload request and get the same archive ID without creating\nduplicate archives. Note, however, that after the multipart upload completes,\nyou cannot call the List Parts operation and the multipart upload will not\nappear in List Multipart Uploads response, even if idempotent complete is\npossible.\n\nAn AWS account has full permission to perform all operations (actions). However,\nAWS Identity and Access Management (IAM) users don't have any permissions by\ndefault. You must grant them explicit permission to perform specific actions.\nFor more information, see [Access Control Using AWS Identity and Access Management\n(IAM)](https://docs.aws.amazon.com/amazonglacier/latest/dev/using-iam-with-amazon-glacier.html).\n\nFor conceptual information and underlying REST API, see [Uploading Large Archives in Parts (Multipart\nUpload)](https://docs.aws.amazon.com/amazonglacier/latest/dev/uploading-archive-mpu.html)\nand [Complete Multipart Upload](https://docs.aws.amazon.com/amazonglacier/latest/dev/api-multipart-complete-upload.html)\nin the *Amazon Glacier Developer Guide*.","ref":"AWS.Glacier.html#complete_multipart_upload/6","title":"AWS.Glacier.complete_multipart_upload/6","type":"function"},{"doc":"This operation completes the vault locking process by transitioning the vault\nlock from the `InProgress` state to the `Locked` state, which causes the vault\nlock policy to become unchangeable.\n\nA vault lock is put into the `InProgress` state by calling `InitiateVaultLock`.\nYou can obtain the state of the vault lock by calling `GetVaultLock`. For more\ninformation about the vault locking process, [Amazon Glacier Vault Lock](https://docs.aws.amazon.com/amazonglacier/latest/dev/vault-lock.html).\n\nThis operation is idempotent. This request is always successful if the vault\nlock is in the `Locked` state and the provided lock ID matches the lock ID\noriginally used to lock the vault.\n\nIf an invalid lock ID is passed in the request when the vault lock is in the\n`Locked` state, the operation returns an `AccessDeniedException` error. If an\ninvalid lock ID is passed in the request when the vault lock is in the\n`InProgress` state, the operation throws an `InvalidParameter` error.","ref":"AWS.Glacier.html#complete_vault_lock/6","title":"AWS.Glacier.complete_vault_lock/6","type":"function"},{"doc":"This operation creates a new vault with the specified name.\n\nThe name of the vault must be unique within a region for an AWS account. You can\ncreate up to 1,000 vaults per account. If you need to create more vaults,\ncontact Amazon S3 Glacier.\n\nYou must use the following guidelines when naming a vault.\n\n  * Names can be between 1 and 255 characters long.\n\n  * Allowed characters are a-z, A-Z, 0-9, '_' (underscore), '-'\n(hyphen), and '.' (period).\n\nThis operation is idempotent.\n\nAn AWS account has full permission to perform all operations (actions). However,\nAWS Identity and Access Management (IAM) users don't have any permissions by\ndefault. You must grant them explicit permission to perform specific actions.\nFor more information, see [Access Control Using AWS Identity and Access Management\n(IAM)](https://docs.aws.amazon.com/amazonglacier/latest/dev/using-iam-with-amazon-glacier.html).\n\nFor conceptual information and underlying REST API, see [Creating a Vault in Amazon\nGlacier](https://docs.aws.amazon.com/amazonglacier/latest/dev/creating-vaults.html)\nand [Create Vault\n](https://docs.aws.amazon.com/amazonglacier/latest/dev/api-vault-put.html) in\nthe *Amazon Glacier Developer Guide*.","ref":"AWS.Glacier.html#create_vault/5","title":"AWS.Glacier.create_vault/5","type":"function"},{"doc":"This operation deletes an archive from a vault.\n\nSubsequent requests to initiate a retrieval of this archive will fail. Archive\nretrievals that are in progress for this archive ID may or may not succeed\naccording to the following scenarios:\n\n  * If the archive retrieval job is actively preparing the data for\ndownload when Amazon S3 Glacier receives the delete archive request, the\narchival retrieval operation might fail.\n\n  * If the archive retrieval job has successfully prepared the archive\nfor download when Amazon S3 Glacier receives the delete archive request, you\nwill be able to download the output.\n\nThis operation is idempotent. Attempting to delete an already-deleted archive\ndoes not result in an error.\n\nAn AWS account has full permission to perform all operations (actions). However,\nAWS Identity and Access Management (IAM) users don't have any permissions by\ndefault. You must grant them explicit permission to perform specific actions.\nFor more information, see [Access Control Using AWS Identity and Access Management\n(IAM)](https://docs.aws.amazon.com/amazonglacier/latest/dev/using-iam-with-amazon-glacier.html).\n\nFor conceptual information and underlying REST API, see [Deleting an Archive in Amazon\nGlacier](https://docs.aws.amazon.com/amazonglacier/latest/dev/deleting-an-archive.html)\nand [Delete Archive](https://docs.aws.amazon.com/amazonglacier/latest/dev/api-archive-delete.html)\nin the *Amazon Glacier Developer Guide*.","ref":"AWS.Glacier.html#delete_archive/6","title":"AWS.Glacier.delete_archive/6","type":"function"},{"doc":"This operation deletes a vault.\n\nAmazon S3 Glacier will delete a vault only if there are no archives in the vault\nas of the last inventory and there have been no writes to the vault since the\nlast inventory. If either of these conditions is not satisfied, the vault\ndeletion fails (that is, the vault is not removed) and Amazon S3 Glacier returns\nan error. You can use `DescribeVault` to return the number of archives in a\nvault, and you can use [Initiate a Job (POST jobs)](https://docs.aws.amazon.com/amazonglacier/latest/dev/api-initiate-job-post.html)\nto initiate a new inventory retrieval for a vault. The inventory contains the\narchive IDs you use to delete archives using [Delete Archive (DELETE archive)](https://docs.aws.amazon.com/amazonglacier/latest/dev/api-archive-delete.html).\n\nThis operation is idempotent.\n\nAn AWS account has full permission to perform all operations (actions). However,\nAWS Identity and Access Management (IAM) users don't have any permissions by\ndefault. You must grant them explicit permission to perform specific actions.\nFor more information, see [Access Control Using AWS Identity and Access Management\n(IAM)](https://docs.aws.amazon.com/amazonglacier/latest/dev/using-iam-with-amazon-glacier.html).\n\nFor conceptual information and underlying REST API, see [Deleting a Vault in Amazon\nGlacier](https://docs.aws.amazon.com/amazonglacier/latest/dev/deleting-vaults.html)\nand [Delete Vault\n](https://docs.aws.amazon.com/amazonglacier/latest/dev/api-vault-delete.html) in\nthe *Amazon S3 Glacier Developer Guide*.","ref":"AWS.Glacier.html#delete_vault/5","title":"AWS.Glacier.delete_vault/5","type":"function"},{"doc":"This operation deletes the access policy associated with the specified vault.\n\nThe operation is eventually consistent; that is, it might take some time for\nAmazon S3 Glacier to completely remove the access policy, and you might still\nsee the effect of the policy for a short time after you send the delete request.\n\nThis operation is idempotent. You can invoke delete multiple times, even if\nthere is no policy associated with the vault. For more information about vault\naccess policies, see [Amazon Glacier Access Control with Vault Access Policies](https://docs.aws.amazon.com/amazonglacier/latest/dev/vault-access-policy.html).","ref":"AWS.Glacier.html#delete_vault_access_policy/5","title":"AWS.Glacier.delete_vault_access_policy/5","type":"function"},{"doc":"This operation deletes the notification configuration set for a vault.\n\nThe operation is eventually consistent; that is, it might take some time for\nAmazon S3 Glacier to completely disable the notifications and you might still\nreceive some notifications for a short time after you send the delete request.\n\nAn AWS account has full permission to perform all operations (actions). However,\nAWS Identity and Access Management (IAM) users don't have any permissions by\ndefault. You must grant them explicit permission to perform specific actions.\nFor more information, see [Access Control Using AWS Identity and Access Management\n(IAM)](https://docs.aws.amazon.com/amazonglacier/latest/dev/using-iam-with-amazon-glacier.html).\n\nFor conceptual information and underlying REST API, see [Configuring Vault Notifications in Amazon S3\nGlacier](https://docs.aws.amazon.com/amazonglacier/latest/dev/configuring-notifications.html)\nand [Delete Vault Notification Configuration\n](https://docs.aws.amazon.com/amazonglacier/latest/dev/api-vault-notifications-delete.html)\nin the Amazon S3 Glacier Developer Guide.","ref":"AWS.Glacier.html#delete_vault_notifications/5","title":"AWS.Glacier.delete_vault_notifications/5","type":"function"},{"doc":"This operation returns information about a job you previously initiated,\nincluding the job initiation date, the user who initiated the job, the job\nstatus code/message and the Amazon SNS topic to notify after Amazon S3 Glacier\n(Glacier) completes the job.\n\nFor more information about initiating a job, see `InitiateJob`.\n\nThis operation enables you to check the status of your job. However, it is\nstrongly recommended that you set up an Amazon SNS topic and specify it in your\ninitiate job request so that Glacier can notify the topic after it completes the\njob.\n\nA job ID will not expire for at least 24 hours after Glacier completes the job.\n\nAn AWS account has full permission to perform all operations (actions). However,\nAWS Identity and Access Management (IAM) users don't have any permissions by\ndefault. You must grant them explicit permission to perform specific actions.\nFor more information, see [Access Control Using AWS Identity and Access Management\n(IAM)](https://docs.aws.amazon.com/amazonglacier/latest/dev/using-iam-with-amazon-glacier.html).\n\nFor more information about using this operation, see the documentation for the\nunderlying REST API [Describe Job](https://docs.aws.amazon.com/amazonglacier/latest/dev/api-describe-job-get.html)\nin the *Amazon Glacier Developer Guide*.","ref":"AWS.Glacier.html#describe_job/5","title":"AWS.Glacier.describe_job/5","type":"function"},{"doc":"This operation returns information about a vault, including the vault's Amazon\nResource Name (ARN), the date the vault was created, the number of archives it\ncontains, and the total size of all the archives in the vault.\n\nThe number of archives and their total size are as of the last inventory\ngeneration. This means that if you add or remove an archive from a vault, and\nthen immediately use Describe Vault, the change in contents will not be\nimmediately reflected. If you want to retrieve the latest inventory of the\nvault, use `InitiateJob`. Amazon S3 Glacier generates vault inventories\napproximately daily. For more information, see [Downloading a Vault Inventory in Amazon S3\nGlacier](https://docs.aws.amazon.com/amazonglacier/latest/dev/vault-inventory.html).\n\nAn AWS account has full permission to perform all operations (actions). However,\nAWS Identity and Access Management (IAM) users don't have any permissions by\ndefault. You must grant them explicit permission to perform specific actions.\nFor more information, see [Access Control Using AWS Identity and Access Management\n(IAM)](https://docs.aws.amazon.com/amazonglacier/latest/dev/using-iam-with-amazon-glacier.html).\n\nFor conceptual information and underlying REST API, see [Retrieving Vault Metadata in Amazon S3\nGlacier](https://docs.aws.amazon.com/amazonglacier/latest/dev/retrieving-vault-info.html)\nand [Describe Vault\n](https://docs.aws.amazon.com/amazonglacier/latest/dev/api-vault-get.html) in\nthe *Amazon Glacier Developer Guide*.","ref":"AWS.Glacier.html#describe_vault/4","title":"AWS.Glacier.describe_vault/4","type":"function"},{"doc":"This operation returns the current data retrieval policy for the account and\nregion specified in the GET request.\n\nFor more information about data retrieval policies, see [Amazon Glacier Data Retrieval\nPolicies](https://docs.aws.amazon.com/amazonglacier/latest/dev/data-retrieval-policy.html).","ref":"AWS.Glacier.html#get_data_retrieval_policy/3","title":"AWS.Glacier.get_data_retrieval_policy/3","type":"function"},{"doc":"This operation downloads the output of the job you initiated using\n`InitiateJob`.\n\nDepending on the job type you specified when you initiated the job, the output\nwill be either the content of an archive or a vault inventory.\n\nYou can download all the job output or download a portion of the output by\nspecifying a byte range. In the case of an archive retrieval job, depending on\nthe byte range you specify, Amazon S3 Glacier (Glacier) returns the checksum for\nthe portion of the data. You can compute the checksum on the client and verify\nthat the values match to ensure the portion you downloaded is the correct data.\n\nA job ID will not expire for at least 24 hours after Glacier completes the job.\nThat a byte range. For both archive and inventory retrieval jobs, you should\nverify the downloaded size against the size returned in the headers from the\n**Get Job Output** response.\n\nFor archive retrieval jobs, you should also verify that the size is what you\nexpected. If you download a portion of the output, the expected size is based on\nthe range of bytes you specified. For example, if you specify a range of\n`bytes=0-1048575`, you should verify your download size is 1,048,576 bytes. If\nyou download an entire archive, the expected size is the size of the archive\nwhen you uploaded it to Amazon S3 Glacier The expected size is also returned in\nthe headers from the **Get Job Output** response.\n\nIn the case of an archive retrieval job, depending on the byte range you\nspecify, Glacier returns the checksum for the portion of the data. To ensure the\nportion you downloaded is the correct data, compute the checksum on the client,\nverify that the values match, and verify that the size is what you expected.\n\nA job ID does not expire for at least 24 hours after Glacier completes the job.\nThat is, you can download the job output within the 24 hours period after Amazon\nGlacier completes the job.\n\nAn AWS account has full permission to perform all operations (actions). However,\nAWS Identity and Access Management (IAM) users don't have any permissions by\ndefault. You must grant them explicit permission to perform specific actions.\nFor more information, see [Access Control Using AWS Identity and Access Management\n(IAM)](https://docs.aws.amazon.com/amazonglacier/latest/dev/using-iam-with-amazon-glacier.html).\n\nFor conceptual information and the underlying REST API, see [Downloading a Vault Inventory](https://docs.aws.amazon.com/amazonglacier/latest/dev/vault-inventory.html),\n[Downloading an Archive](https://docs.aws.amazon.com/amazonglacier/latest/dev/downloading-an-archive.html),\nand [Get Job Output\n](https://docs.aws.amazon.com/amazonglacier/latest/dev/api-job-output-get.html)","ref":"AWS.Glacier.html#get_job_output/6","title":"AWS.Glacier.get_job_output/6","type":"function"},{"doc":"This operation retrieves the `access-policy` subresource set on the vault; for\nmore information on setting this subresource, see [Set Vault Access Policy (PUT access-policy)](https://docs.aws.amazon.com/amazonglacier/latest/dev/api-SetVaultAccessPolicy.html).\n\nIf there is no access policy set on the vault, the operation returns a `404 Not\nfound` error. For more information about vault access policies, see [Amazon Glacier Access Control with Vault Access\nPolicies](https://docs.aws.amazon.com/amazonglacier/latest/dev/vault-access-policy.html).","ref":"AWS.Glacier.html#get_vault_access_policy/4","title":"AWS.Glacier.get_vault_access_policy/4","type":"function"},{"doc":"This operation retrieves the following attributes from the `lock-policy`\nsubresource set on the specified vault:\n\n  * The vault lock policy set on the vault.\n\n  * The state of the vault lock, which is either `InProgess` or\n`Locked`.\n\n  * When the lock ID expires. The lock ID is used to complete the\nvault locking process.\n\n  * When the vault lock was initiated and put into the `InProgress`\nstate.\n\nA vault lock is put into the `InProgress` state by calling `InitiateVaultLock`.\nA vault lock is put into the `Locked` state by calling `CompleteVaultLock`. You\ncan abort the vault locking process by calling `AbortVaultLock`. For more\ninformation about the vault locking process, [Amazon Glacier Vault Lock](https://docs.aws.amazon.com/amazonglacier/latest/dev/vault-lock.html).\n\nIf there is no vault lock policy set on the vault, the operation returns a `404\nNot found` error. For more information about vault lock policies, [Amazon Glacier Access Control with Vault Lock\nPolicies](https://docs.aws.amazon.com/amazonglacier/latest/dev/vault-lock-policy.html).","ref":"AWS.Glacier.html#get_vault_lock/4","title":"AWS.Glacier.get_vault_lock/4","type":"function"},{"doc":"This operation retrieves the `notification-configuration` subresource of the\nspecified vault.\n\nFor information about setting a notification configuration on a vault, see\n`SetVaultNotifications`. If a notification configuration for a vault is not set,\nthe operation returns a `404 Not Found` error. For more information about vault\nnotifications, see [Configuring Vault Notifications in Amazon S3 Glacier](https://docs.aws.amazon.com/amazonglacier/latest/dev/configuring-notifications.html).\n\nAn AWS account has full permission to perform all operations (actions). However,\nAWS Identity and Access Management (IAM) users don't have any permissions by\ndefault. You must grant them explicit permission to perform specific actions.\nFor more information, see [Access Control Using AWS Identity and Access Management\n(IAM)](https://docs.aws.amazon.com/amazonglacier/latest/dev/using-iam-with-amazon-glacier.html).\n\nFor conceptual information and underlying REST API, see [Configuring Vault Notifications in Amazon S3\nGlacier](https://docs.aws.amazon.com/amazonglacier/latest/dev/configuring-notifications.html)\nand [Get Vault Notification Configuration\n](https://docs.aws.amazon.com/amazonglacier/latest/dev/api-vault-notifications-get.html)\nin the *Amazon Glacier Developer Guide*.","ref":"AWS.Glacier.html#get_vault_notifications/4","title":"AWS.Glacier.get_vault_notifications/4","type":"function"},{"doc":"This operation initiates a job of the specified type, which can be a select, an\narchival retrieval, or a vault retrieval.\n\nFor more information about using this operation, see the documentation for the\nunderlying REST API [Initiate a Job](https://docs.aws.amazon.com/amazonglacier/latest/dev/api-initiate-job-post.html).","ref":"AWS.Glacier.html#initiate_job/5","title":"AWS.Glacier.initiate_job/5","type":"function"},{"doc":"This operation initiates a multipart upload.\n\nAmazon S3 Glacier creates a multipart upload resource and returns its ID in the\nresponse. The multipart upload ID is used in subsequent requests to upload parts\nof an archive (see `UploadMultipartPart`).\n\nWhen you initiate a multipart upload, you specify the part size in number of\nbytes. The part size must be a megabyte (1024 KB) multiplied by a power of 2-for\nexample, 1048576 (1 MB), 2097152 (2 MB), 4194304 (4 MB), 8388608 (8 MB), and so\non. The minimum allowable part size is 1 MB, and the maximum is 4 GB.\n\nEvery part you upload to this resource (see `UploadMultipartPart`), except the\nlast one, must have the same size. The last one can be the same size or smaller.\nFor example, suppose you want to upload a 16.2 MB file. If you initiate the\nmultipart upload with a part size of 4 MB, you will upload four parts of 4 MB\neach and one part of 0.2 MB.\n\nYou don't need to know the size of the archive when you start a multipart upload\nbecause Amazon S3 Glacier does not require you to specify the overall archive\nsize.\n\nAfter you complete the multipart upload, Amazon S3 Glacier (Glacier) removes the\nmultipart upload resource referenced by the ID. Glacier also removes the\nmultipart upload resource if you cancel the multipart upload or it may be\nremoved if there is no activity for a period of 24 hours.\n\nAn AWS account has full permission to perform all operations (actions). However,\nAWS Identity and Access Management (IAM) users don't have any permissions by\ndefault. You must grant them explicit permission to perform specific actions.\nFor more information, see [Access Control Using AWS Identity and Access Management\n(IAM)](https://docs.aws.amazon.com/amazonglacier/latest/dev/using-iam-with-amazon-glacier.html).\n\nFor conceptual information and underlying REST API, see [Uploading Large Archives in Parts (Multipart\nUpload)](https://docs.aws.amazon.com/amazonglacier/latest/dev/uploading-archive-mpu.html)\nand [Initiate Multipart Upload](https://docs.aws.amazon.com/amazonglacier/latest/dev/api-multipart-initiate-upload.html)\nin the *Amazon Glacier Developer Guide*.","ref":"AWS.Glacier.html#initiate_multipart_upload/5","title":"AWS.Glacier.initiate_multipart_upload/5","type":"function"},{"doc":"This operation initiates the vault locking process by doing the following:\n\n  * Installing a vault lock policy on the specified vault.\n\n  * Setting the lock state of vault lock to `InProgress`.\n\n  * Returning a lock ID, which is used to complete the vault locking\nprocess.\n\nYou can set one vault lock policy for each vault and this policy can be up to 20\nKB in size. For more information about vault lock policies, see [Amazon Glacier Access Control with Vault Lock\nPolicies](https://docs.aws.amazon.com/amazonglacier/latest/dev/vault-lock-policy.html).\n\nYou must complete the vault locking process within 24 hours after the vault lock\nenters the `InProgress` state. After the 24 hour window ends, the lock ID\nexpires, the vault automatically exits the `InProgress` state, and the vault\nlock policy is removed from the vault. You call `CompleteVaultLock` to complete\nthe vault locking process by setting the state of the vault lock to `Locked`.\n\nAfter a vault lock is in the `Locked` state, you cannot initiate a new vault\nlock for the vault.\n\nYou can abort the vault locking process by calling `AbortVaultLock`. You can get\nthe state of the vault lock by calling `GetVaultLock`. For more information\nabout the vault locking process, [Amazon Glacier Vault Lock](https://docs.aws.amazon.com/amazonglacier/latest/dev/vault-lock.html).\n\nIf this operation is called when the vault lock is in the `InProgress` state,\nthe operation returns an `AccessDeniedException` error. When the vault lock is\nin the `InProgress` state you must call `AbortVaultLock` before you can initiate\na new vault lock policy.","ref":"AWS.Glacier.html#initiate_vault_lock/5","title":"AWS.Glacier.initiate_vault_lock/5","type":"function"},{"doc":"This operation lists jobs for a vault, including jobs that are in-progress and\njobs that have recently finished.\n\nThe List Job operation returns a list of these jobs sorted by job initiation\ntime.\n\nAmazon Glacier retains recently completed jobs for a period before deleting\nthem; however, it eventually removes completed jobs. The output of completed\njobs can be retrieved. Retaining completed jobs for a period of time after they\nhave completed enables you to get a job output in the event you miss the job\ncompletion notification or your first attempt to download it fails. For example,\nsuppose you start an archive retrieval job to download an archive. After the job\ncompletes, you start to download the archive but encounter a network error. In\nthis scenario, you can retry and download the archive while the job exists.\n\nThe List Jobs operation supports pagination. You should always check the\nresponse `Marker` field. If there are no more jobs to list, the `Marker` field\nis set to `null`. If there are more jobs to list, the `Marker` field is set to a\nnon-null value, which you can use to continue the pagination of the list. To\nreturn a list of jobs that begins at a specific job, set the marker request\nparameter to the `Marker` value for that job that you obtained from a previous\nList Jobs request.\n\nYou can set a maximum limit for the number of jobs returned in the response by\nspecifying the `limit` parameter in the request. The default limit is 50. The\nnumber of jobs returned might be fewer than the limit, but the number of\nreturned jobs never exceeds the limit.\n\nAdditionally, you can filter the jobs list returned by specifying the optional\n`statuscode` parameter or `completed` parameter, or both. Using the `statuscode`\nparameter, you can specify to return only jobs that match either the\n`InProgress`, `Succeeded`, or `Failed` status. Using the `completed` parameter,\nyou can specify to return only jobs that were completed (`true`) or jobs that\nwere not completed (`false`).\n\nFor more information about using this operation, see the documentation for the\nunderlying REST API [List Jobs](https://docs.aws.amazon.com/amazonglacier/latest/dev/api-jobs-get.html).","ref":"AWS.Glacier.html#list_jobs/8","title":"AWS.Glacier.list_jobs/8","type":"function"},{"doc":"This operation lists in-progress multipart uploads for the specified vault.\n\nAn in-progress multipart upload is a multipart upload that has been initiated by\nan `InitiateMultipartUpload` request, but has not yet been completed or aborted.\nThe list returned in the List Multipart Upload response has no guaranteed order.\n\nThe List Multipart Uploads operation supports pagination. By default, this\noperation returns up to 50 multipart uploads in the response. You should always\ncheck the response for a `marker` at which to continue the list; if there are no\nmore items the `marker` is `null`. To return a list of multipart uploads that\nbegins at a specific upload, set the `marker` request parameter to the value you\nobtained from a previous List Multipart Upload request. You can also limit the\nnumber of uploads returned in the response by specifying the `limit` parameter\nin the request.\n\nNote the difference between this operation and listing parts (`ListParts`). The\nList Multipart Uploads operation lists all multipart uploads for a vault and\ndoes not require a multipart upload ID. The List Parts operation requires a\nmultipart upload ID since parts are associated with a single upload.\n\nAn AWS account has full permission to perform all operations (actions). However,\nAWS Identity and Access Management (IAM) users don't have any permissions by\ndefault. You must grant them explicit permission to perform specific actions.\nFor more information, see [Access Control Using AWS Identity and Access Management\n(IAM)](https://docs.aws.amazon.com/amazonglacier/latest/dev/using-iam-with-amazon-glacier.html).\n\nFor conceptual information and the underlying REST API, see [Working with Archives in Amazon S3\nGlacier](https://docs.aws.amazon.com/amazonglacier/latest/dev/working-with-archives.html)\nand [List Multipart Uploads\n](https://docs.aws.amazon.com/amazonglacier/latest/dev/api-multipart-list-uploads.html)\nin the *Amazon Glacier Developer Guide*.","ref":"AWS.Glacier.html#list_multipart_uploads/6","title":"AWS.Glacier.list_multipart_uploads/6","type":"function"},{"doc":"This operation lists the parts of an archive that have been uploaded in a\nspecific multipart upload.\n\nYou can make this request at any time during an in-progress multipart upload\nbefore you complete the upload (see `CompleteMultipartUpload`. List Parts\nreturns an error for completed uploads. The list returned in the List Parts\nresponse is sorted by part range.\n\nThe List Parts operation supports pagination. By default, this operation returns\nup to 50 uploaded parts in the response. You should always check the response\nfor a `marker` at which to continue the list; if there are no more items the\n`marker` is `null`. To return a list of parts that begins at a specific part,\nset the `marker` request parameter to the value you obtained from a previous\nList Parts request. You can also limit the number of parts returned in the\nresponse by specifying the `limit` parameter in the request.\n\nAn AWS account has full permission to perform all operations (actions). However,\nAWS Identity and Access Management (IAM) users don't have any permissions by\ndefault. You must grant them explicit permission to perform specific actions.\nFor more information, see [Access Control Using AWS Identity and Access Management\n(IAM)](https://docs.aws.amazon.com/amazonglacier/latest/dev/using-iam-with-amazon-glacier.html).\n\nFor conceptual information and the underlying REST API, see [Working with Archives in Amazon S3\nGlacier](https://docs.aws.amazon.com/amazonglacier/latest/dev/working-with-archives.html)\nand [List Parts](https://docs.aws.amazon.com/amazonglacier/latest/dev/api-multipart-list-parts.html)\nin the *Amazon Glacier Developer Guide*.","ref":"AWS.Glacier.html#list_parts/7","title":"AWS.Glacier.list_parts/7","type":"function"},{"doc":"This operation lists the provisioned capacity units for the specified AWS\naccount.","ref":"AWS.Glacier.html#list_provisioned_capacity/3","title":"AWS.Glacier.list_provisioned_capacity/3","type":"function"},{"doc":"This operation lists all the tags attached to a vault.\n\nThe operation returns an empty map if there are no tags. For more information\nabout tags, see [Tagging Amazon S3 Glacier Resources](https://docs.aws.amazon.com/amazonglacier/latest/dev/tagging.html).","ref":"AWS.Glacier.html#list_tags_for_vault/4","title":"AWS.Glacier.list_tags_for_vault/4","type":"function"},{"doc":"This operation lists all vaults owned by the calling user's account.\n\nThe list returned in the response is ASCII-sorted by vault name.\n\nBy default, this operation returns up to 10 items. If there are more vaults to\nlist, the response `marker` field contains the vault Amazon Resource Name (ARN)\nat which to continue the list with a new List Vaults request; otherwise, the\n`marker` field is `null`. To return a list of vaults that begins at a specific\nvault, set the `marker` request parameter to the vault ARN you obtained from a\nprevious List Vaults request. You can also limit the number of vaults returned\nin the response by specifying the `limit` parameter in the request.\n\nAn AWS account has full permission to perform all operations (actions). However,\nAWS Identity and Access Management (IAM) users don't have any permissions by\ndefault. You must grant them explicit permission to perform specific actions.\nFor more information, see [Access Control Using AWS Identity and Access Management\n(IAM)](https://docs.aws.amazon.com/amazonglacier/latest/dev/using-iam-with-amazon-glacier.html).\n\nFor conceptual information and underlying REST API, see [Retrieving Vault Metadata in Amazon S3\nGlacier](https://docs.aws.amazon.com/amazonglacier/latest/dev/retrieving-vault-info.html)\nand [List Vaults\n](https://docs.aws.amazon.com/amazonglacier/latest/dev/api-vaults-get.html) in\nthe *Amazon Glacier Developer Guide*.","ref":"AWS.Glacier.html#list_vaults/5","title":"AWS.Glacier.list_vaults/5","type":"function"},{"doc":"","ref":"AWS.Glacier.html#metadata/0","title":"AWS.Glacier.metadata/0","type":"function"},{"doc":"This operation purchases a provisioned capacity unit for an AWS account.","ref":"AWS.Glacier.html#purchase_provisioned_capacity/4","title":"AWS.Glacier.purchase_provisioned_capacity/4","type":"function"},{"doc":"This operation removes one or more tags from the set of tags attached to a\nvault.\n\nFor more information about tags, see [Tagging Amazon S3 Glacier Resources](https://docs.aws.amazon.com/amazonglacier/latest/dev/tagging.html).\nThis operation is idempotent. The operation will be successful, even if there\nare no tags attached to the vault.","ref":"AWS.Glacier.html#remove_tags_from_vault/5","title":"AWS.Glacier.remove_tags_from_vault/5","type":"function"},{"doc":"This operation sets and then enacts a data retrieval policy in the region\nspecified in the PUT request.\n\nYou can set one policy per region for an AWS account. The policy is enacted\nwithin a few minutes of a successful PUT operation.\n\nThe set policy operation does not affect retrieval jobs that were in progress\nbefore the policy was enacted. For more information about data retrieval\npolicies, see [Amazon Glacier Data Retrieval Policies](https://docs.aws.amazon.com/amazonglacier/latest/dev/data-retrieval-policy.html).","ref":"AWS.Glacier.html#set_data_retrieval_policy/4","title":"AWS.Glacier.set_data_retrieval_policy/4","type":"function"},{"doc":"This operation configures an access policy for a vault and will overwrite an\nexisting policy.\n\nTo configure a vault access policy, send a PUT request to the `access-policy`\nsubresource of the vault. An access policy is specific to a vault and is also\ncalled a vault subresource. You can set one access policy per vault and the\npolicy can be up to 20 KB in size. For more information about vault access\npolicies, see [Amazon Glacier Access Control with Vault Access Policies](https://docs.aws.amazon.com/amazonglacier/latest/dev/vault-access-policy.html).","ref":"AWS.Glacier.html#set_vault_access_policy/5","title":"AWS.Glacier.set_vault_access_policy/5","type":"function"},{"doc":"This operation configures notifications that will be sent when specific events\nhappen to a vault.\n\nBy default, you don't get any notifications.\n\nTo configure vault notifications, send a PUT request to the\n`notification-configuration` subresource of the vault. The request should\ninclude a JSON document that provides an Amazon SNS topic and specific events\nfor which you want Amazon S3 Glacier to send notifications to the topic.\n\nAmazon SNS topics must grant permission to the vault to be allowed to publish\nnotifications to the topic. You can configure a vault to publish a notification\nfor the following vault events:\n\n  * **ArchiveRetrievalCompleted** This event occurs when a job that\nwas initiated for an archive retrieval is completed (`InitiateJob`). The status\nof the completed job can be \"Succeeded\" or \"Failed\". The notification sent to\nthe SNS topic is the same output as returned from `DescribeJob`.\n\n  * **InventoryRetrievalCompleted** This event occurs when a job that\nwas initiated for an inventory retrieval is completed (`InitiateJob`). The\nstatus of the completed job can be \"Succeeded\" or \"Failed\". The notification\nsent to the SNS topic is the same output as returned from `DescribeJob`.\n\nAn AWS account has full permission to perform all operations (actions). However,\nAWS Identity and Access Management (IAM) users don't have any permissions by\ndefault. You must grant them explicit permission to perform specific actions.\nFor more information, see [Access Control Using AWS Identity and Access Management\n(IAM)](https://docs.aws.amazon.com/amazonglacier/latest/dev/using-iam-with-amazon-glacier.html).\n\nFor conceptual information and underlying REST API, see [Configuring Vault Notifications in Amazon S3\nGlacier](https://docs.aws.amazon.com/amazonglacier/latest/dev/configuring-notifications.html)\nand [Set Vault Notification Configuration\n](https://docs.aws.amazon.com/amazonglacier/latest/dev/api-vault-notifications-put.html)\nin the *Amazon Glacier Developer Guide*.","ref":"AWS.Glacier.html#set_vault_notifications/5","title":"AWS.Glacier.set_vault_notifications/5","type":"function"},{"doc":"This operation adds an archive to a vault.\n\nThis is a synchronous operation, and for a successful upload, your data is\ndurably persisted. Amazon S3 Glacier returns the archive ID in the\n`x-amz-archive-id` header of the response.\n\nYou must use the archive ID to access your data in Amazon S3 Glacier. After you\nupload an archive, you should save the archive ID returned so that you can\nretrieve or delete the archive later. Besides saving the archive ID, you can\nalso index it and give it a friendly name to allow for better searching. You can\nalso use the optional archive description field to specify how the archive is\nreferred to in an external index of archives, such as you might create in Amazon\nDynamoDB. You can also get the vault inventory to obtain a list of archive IDs\nin a vault. For more information, see `InitiateJob`.\n\nYou must provide a SHA256 tree hash of the data you are uploading. For\ninformation about computing a SHA256 tree hash, see [Computing Checksums](https://docs.aws.amazon.com/amazonglacier/latest/dev/checksum-calculations.html).\n\nYou can optionally specify an archive description of up to 1,024 printable ASCII\ncharacters. You can get the archive description when you either retrieve the\narchive or get the vault inventory. For more information, see `InitiateJob`.\nAmazon Glacier does not interpret the description in any way. An archive\ndescription does not need to be unique. You cannot use the description to\nretrieve or sort the archive list.\n\nArchives are immutable. After you upload an archive, you cannot edit the archive\nor its description.\n\nAn AWS account has full permission to perform all operations (actions). However,\nAWS Identity and Access Management (IAM) users don't have any permissions by\ndefault. You must grant them explicit permission to perform specific actions.\nFor more information, see [Access Control Using AWS Identity and Access Management\n(IAM)](https://docs.aws.amazon.com/amazonglacier/latest/dev/using-iam-with-amazon-glacier.html).\n\nFor conceptual information and underlying REST API, see [Uploading an Archive in Amazon\nGlacier](https://docs.aws.amazon.com/amazonglacier/latest/dev/uploading-an-archive.html)\nand [Upload Archive](https://docs.aws.amazon.com/amazonglacier/latest/dev/api-archive-post.html)\nin the *Amazon Glacier Developer Guide*.","ref":"AWS.Glacier.html#upload_archive/5","title":"AWS.Glacier.upload_archive/5","type":"function"},{"doc":"This operation uploads a part of an archive.\n\nYou can upload archive parts in any order. You can also upload them in parallel.\nYou can upload up to 10,000 parts for a multipart upload.\n\nAmazon Glacier rejects your upload part request if any of the following\nconditions is true:\n\n  * **SHA256 tree hash does not match**To ensure that part data is not\ncorrupted in transmission, you compute a SHA256 tree hash of the part and\ninclude it in your request. Upon receiving the part data, Amazon S3 Glacier also\ncomputes a SHA256 tree hash. If these hash values don't match, the operation\nfails. For information about computing a SHA256 tree hash, see [Computing Checksums](https://docs.aws.amazon.com/amazonglacier/latest/dev/checksum-calculations.html).\n\n  * **Part size does not match**The size of each part except the last\nmust match the size specified in the corresponding `InitiateMultipartUpload`\nrequest. The size of the last part must be the same size as, or smaller than,\nthe specified size.\n\nIf you upload a part whose size is smaller than the part size you specified in\nyour initiate multipart upload request and that part is not the last part, then\nthe upload part request will succeed. However, the subsequent Complete Multipart\nUpload request will fail.\n\n  * **Range does not align**The byte range value in the request does\nnot align with the part size specified in the corresponding initiate request.\nFor example, if you specify a part size of 4194304 bytes (4 MB), then 0 to\n4194303 bytes (4 MB - 1) and 4194304 (4 MB) to 8388607 (8 MB - 1) are valid part\nranges. However, if you set a range value of 2 MB to 6 MB, the range does not\nalign with the part size and the upload will fail.\n\nThis operation is idempotent. If you upload the same part multiple times, the\ndata included in the most recent request overwrites the previously uploaded\ndata.\n\nAn AWS account has full permission to perform all operations (actions). However,\nAWS Identity and Access Management (IAM) users don't have any permissions by\ndefault. You must grant them explicit permission to perform specific actions.\nFor more information, see [Access Control Using AWS Identity and Access Management\n(IAM)](https://docs.aws.amazon.com/amazonglacier/latest/dev/using-iam-with-amazon-glacier.html).\n\nFor conceptual information and underlying REST API, see [Uploading Large Archives in Parts (Multipart\nUpload)](https://docs.aws.amazon.com/amazonglacier/latest/dev/uploading-archive-mpu.html)\nand [Upload Part\n](https://docs.aws.amazon.com/amazonglacier/latest/dev/api-upload-part.html) in\nthe *Amazon Glacier Developer Guide*.","ref":"AWS.Glacier.html#upload_multipart_part/6","title":"AWS.Glacier.upload_multipart_part/6","type":"function"},{"doc":"Global Accelerator\n\nThis is the *Global Accelerator API Reference*.\n\nThis guide is for developers who need detailed information about Global\nAccelerator API actions, data types, and errors. For more information about\nGlobal Accelerator features, see the [Global Accelerator Developer Guide](https://docs.aws.amazon.com/global-accelerator/latest/dg/what-is-global-accelerator.html).\n\nGlobal Accelerator is a service in which you create *accelerators* to improve\nthe performance of your applications for local and global users. Depending on\nthe type of accelerator you choose, you can gain additional benefits.\n\n  * By using a standard accelerator, you can improve availability of\nyour internet applications that are used by a global audience. With a standard\naccelerator, Global Accelerator directs traffic to optimal endpoints over the\nAmazon Web Services global network.\n\n  * For other scenarios, you might choose a custom routing\naccelerator. With a custom routing accelerator, you can use application logic to\ndirectly map one or more users to a specific endpoint among many endpoints.\n\nGlobal Accelerator is a global service that supports endpoints in multiple\nAmazon Web Services Regions but you must specify the US West (Oregon) Region to\ncreate, update, or otherwise work with accelerators. That is, for example,\nspecify `--region us-west-2` on Amazon Web Services CLI commands.\n\nBy default, Global Accelerator provides you with static IP addresses that you\nassociate with your accelerator. The static IP addresses are anycast from the\nAmazon Web Services edge network. For IPv4, Global Accelerator provides two\nstatic IPv4 addresses. For dual-stack, Global Accelerator provides a total of\nfour addresses: two static IPv4 addresses and two static IPv6 addresses. With a\nstandard accelerator for IPv4, instead of using the addresses that Global\nAccelerator provides, you can configure these entry points to be IPv4 addresses\nfrom your own IP address ranges that you bring to Global Accelerator (BYOIP).\n\nFor a standard accelerator, they distribute incoming application traffic across\nmultiple endpoint resources in multiple Amazon Web Services Regions , which\nincreases the availability of your applications. Endpoints for standard\naccelerators can be Network Load Balancers, Application Load Balancers, Amazon\nEC2 instances, or Elastic IP addresses that are located in one Amazon Web\nServices Region or multiple Amazon Web Services Regions. For custom routing\naccelerators, you map traffic that arrives to the static IP addresses to\nspecific Amazon EC2 servers in endpoints that are virtual private cloud (VPC)\nsubnets.\n\nThe static IP addresses remain assigned to your accelerator for as long as it\nexists, even if you disable the accelerator and it no longer accepts or routes\ntraffic. However, when you *delete* an accelerator, you lose the static IP\naddresses that are assigned to it, so you can no longer route traffic by using\nthem. You can use IAM policies like tag-based permissions with Global\nAccelerator to limit the users who have permissions to delete an accelerator.\nFor more information, see [Tag-based policies](https://docs.aws.amazon.com/global-accelerator/latest/dg/access-control-manage-access-tag-policies.html).\n\nFor standard accelerators, Global Accelerator uses the Amazon Web Services\nglobal network to route traffic to the optimal regional endpoint based on\nhealth, client location, and policies that you configure. The service reacts\ninstantly to changes in health or configuration to ensure that internet traffic\nfrom clients is always directed to healthy endpoints.\n\nFor more information about understanding and using Global Accelerator, see the\n[Global Accelerator Developer Guide](https://docs.aws.amazon.com/global-accelerator/latest/dg/what-is-global-accelerator.html).","ref":"AWS.GlobalAccelerator.html","title":"AWS.GlobalAccelerator","type":"module"},{"doc":"Associate a virtual private cloud (VPC) subnet endpoint with your custom routing\naccelerator.\n\nThe listener port range must be large enough to support the number of IP\naddresses that can be specified in your subnet. The number of ports required is:\nsubnet size times the number of ports per destination EC2 instances. For\nexample, a subnet defined as /24 requires a listener port range of at least 255\nports.\n\nNote: You must have enough remaining listener ports available to map to the\nsubnet ports, or the call will fail with a LimitExceededException.\n\nBy default, all destinations in a subnet in a custom routing accelerator cannot\nreceive traffic. To enable all destinations to receive traffic, or to specify\nindividual port mappings that can receive traffic, see the [\nAllowCustomRoutingTraffic](https://docs.aws.amazon.com/global-accelerator/latest/api/API_AllowCustomRoutingTraffic.html)\noperation.","ref":"AWS.GlobalAccelerator.html#add_custom_routing_endpoints/3","title":"AWS.GlobalAccelerator.add_custom_routing_endpoints/3","type":"function"},{"doc":"Add endpoints to an endpoint group.\n\nThe `AddEndpoints` API operation is the recommended option for adding endpoints.\nThe alternative options are to add endpoints when you create an endpoint group\n(with the\n[CreateEndpointGroup](https://docs.aws.amazon.com/global-accelerator/latest/api/API_CreateEndpointGroup.html) API) or when you update an endpoint group (with the\n[UpdateEndpointGroup](https://docs.aws.amazon.com/global-accelerator/latest/api/API_UpdateEndpointGroup.html)\nAPI).\n\nThere are two advantages to using `AddEndpoints` to add endpoints in Global\nAccelerator:\n\n  * It's faster, because Global Accelerator only has to resolve the\nnew endpoints that you're adding, rather than resolving new and existing\nendpoints.\n\n  * It's more convenient, because you don't need to specify the\ncurrent endpoints that are already in the endpoint group, in addition to the new\nendpoints that you want to add.\n\nFor information about endpoint types and requirements for endpoints that you can\nadd to Global Accelerator, see [ Endpoints for standard accelerators](https://docs.aws.amazon.com/global-accelerator/latest/dg/about-endpoints.html)\nin the *Global Accelerator Developer Guide*.","ref":"AWS.GlobalAccelerator.html#add_endpoints/3","title":"AWS.GlobalAccelerator.add_endpoints/3","type":"function"},{"doc":"Advertises an IPv4 address range that is provisioned for use with your Amazon\nWeb Services resources through bring your own IP addresses (BYOIP).\n\nIt can take a few minutes before traffic to the specified addresses starts\nrouting to Amazon Web Services because of propagation delays.\n\nTo stop advertising the BYOIP address range, use [\nWithdrawByoipCidr](https://docs.aws.amazon.com/global-accelerator/latest/api/WithdrawByoipCidr.html).\n\nFor more information, see [Bring your own IP addresses (BYOIP)](https://docs.aws.amazon.com/global-accelerator/latest/dg/using-byoip.html)\nin the *Global Accelerator Developer Guide*.","ref":"AWS.GlobalAccelerator.html#advertise_byoip_cidr/3","title":"AWS.GlobalAccelerator.advertise_byoip_cidr/3","type":"function"},{"doc":"Specify the Amazon EC2 instance (destination) IP addresses and ports for a VPC\nsubnet endpoint that can receive traffic for a custom routing accelerator.\n\nYou can allow traffic to all destinations in the subnet endpoint, or allow\ntraffic to a specified list of destination IP addresses and ports in the subnet.\nNote that you cannot specify IP addresses or ports outside of the range that you\nconfigured for the endpoint group.\n\nAfter you make changes, you can verify that the updates are complete by checking\nthe status of your accelerator: the status changes from IN_PROGRESS to DEPLOYED.","ref":"AWS.GlobalAccelerator.html#allow_custom_routing_traffic/3","title":"AWS.GlobalAccelerator.allow_custom_routing_traffic/3","type":"function"},{"doc":"Create an accelerator.\n\nAn accelerator includes one or more listeners that process inbound connections\nand direct traffic to one or more endpoint groups, each of which includes\nendpoints, such as Network Load Balancers.\n\nGlobal Accelerator is a global service that supports endpoints in multiple\nAmazon Web Services Regions but you must specify the US West (Oregon) Region to\ncreate, update, or otherwise work with accelerators. That is, for example,\nspecify `--region us-west-2` on Amazon Web Services CLI commands.","ref":"AWS.GlobalAccelerator.html#create_accelerator/3","title":"AWS.GlobalAccelerator.create_accelerator/3","type":"function"},{"doc":"Create a cross-account attachment in Global Accelerator.\n\nYou create a cross-account attachment to specify the *principals* who have\npermission to add to accelerators in their own account the resources in your\naccount that you also list in the attachment.\n\nA principal can be an Amazon Web Services account number or the Amazon Resource\nName (ARN) for an accelerator. For account numbers that are listed as\nprincipals, to add a resource listed in the attachment to an accelerator, you\nmust sign in to an account specified as a principal. Then you can add the\nresources that are listed to any of your accelerators. If an accelerator ARN is\nlisted in the cross-account attachment as a principal, anyone with permission to\nmake updates to the accelerator can add as endpoints resources that are listed\nin the attachment.","ref":"AWS.GlobalAccelerator.html#create_cross_account_attachment/3","title":"AWS.GlobalAccelerator.create_cross_account_attachment/3","type":"function"},{"doc":"Create a custom routing accelerator.\n\nA custom routing accelerator directs traffic to one of possibly thousands of\nAmazon EC2 instance destinations running in a single or multiple virtual private\nclouds (VPC) subnet endpoints.\n\nBe aware that, by default, all destination EC2 instances in a VPC subnet\nendpoint cannot receive traffic. To enable all destinations to receive traffic,\nor to specify individual port mappings that can receive traffic, see the [\nAllowCustomRoutingTraffic](https://docs.aws.amazon.com/global-accelerator/latest/api/API_AllowCustomRoutingTraffic.html)\noperation.\n\nGlobal Accelerator is a global service that supports endpoints in multiple\nAmazon Web Services Regions but you must specify the US West (Oregon) Region to\ncreate, update, or otherwise work with accelerators. That is, for example,\nspecify `--region us-west-2` on Amazon Web Services CLI commands.","ref":"AWS.GlobalAccelerator.html#create_custom_routing_accelerator/3","title":"AWS.GlobalAccelerator.create_custom_routing_accelerator/3","type":"function"},{"doc":"Create an endpoint group for the specified listener for a custom routing\naccelerator.\n\nAn endpoint group is a collection of endpoints in one Amazon Web Services\nRegion.","ref":"AWS.GlobalAccelerator.html#create_custom_routing_endpoint_group/3","title":"AWS.GlobalAccelerator.create_custom_routing_endpoint_group/3","type":"function"},{"doc":"Create a listener to process inbound connections from clients to a custom\nrouting accelerator.\n\nConnections arrive to assigned static IP addresses on the port range that you\nspecify.","ref":"AWS.GlobalAccelerator.html#create_custom_routing_listener/3","title":"AWS.GlobalAccelerator.create_custom_routing_listener/3","type":"function"},{"doc":"Create an endpoint group for the specified listener.\n\nAn endpoint group is a collection of endpoints in one Amazon Web Services\nRegion. A resource must be valid and active when you add it as an endpoint.\n\nFor more information about endpoint types and requirements for endpoints that\nyou can add to Global Accelerator, see [ Endpoints for standard accelerators](https://docs.aws.amazon.com/global-accelerator/latest/dg/about-endpoints.html)\nin the *Global Accelerator Developer Guide*.","ref":"AWS.GlobalAccelerator.html#create_endpoint_group/3","title":"AWS.GlobalAccelerator.create_endpoint_group/3","type":"function"},{"doc":"Create a listener to process inbound connections from clients to an accelerator.\n\nConnections arrive to assigned static IP addresses on a port, port range, or\nlist of port ranges that you specify.","ref":"AWS.GlobalAccelerator.html#create_listener/3","title":"AWS.GlobalAccelerator.create_listener/3","type":"function"},{"doc":"Delete an accelerator.\n\nBefore you can delete an accelerator, you must disable it and remove all\ndependent resources (listeners and endpoint groups). To disable the accelerator,\nupdate the accelerator to set `Enabled` to false.\n\nWhen you create an accelerator, by default, Global Accelerator provides you with\na set of two static IP addresses. Alternatively, you can bring your own IP\naddress ranges to Global Accelerator and assign IP addresses from those ranges.\n\nThe IP addresses are assigned to your accelerator for as long as it exists, even\nif you disable the accelerator and it no longer accepts or routes traffic.\nHowever, when you *delete* an accelerator, you lose the static IP addresses that\nare assigned to the accelerator, so you can no longer route traffic by using\nthem. As a best practice, ensure that you have permissions in place to avoid\ninadvertently deleting accelerators. You can use IAM policies with Global\nAccelerator to limit the users who have permissions to delete an accelerator.\nFor more information, see [Identity and access management](https://docs.aws.amazon.com/global-accelerator/latest/dg/auth-and-access-control.html)\nin the *Global Accelerator Developer Guide*.","ref":"AWS.GlobalAccelerator.html#delete_accelerator/3","title":"AWS.GlobalAccelerator.delete_accelerator/3","type":"function"},{"doc":"Delete a cross-account attachment.\n\nWhen you delete an attachment, Global Accelerator revokes the permission to use\nthe resources in the attachment from all principals in the list of principals.\nGlobal Accelerator revokes the permission for specific resources by doing the\nfollowing:\n\n  * If the principal is an account ID, Global Accelerator reviews\nevery accelerator in the account and removes cross-account endpoints from all\naccelerators.\n\n  * If the principal is an accelerator, Global Accelerator reviews\njust that accelerator and removes cross-account endpoints from it.\n\nIf there are overlapping permissions provided by multiple cross-account\nattachments, Global Accelerator only removes endpoints if there are no current\ncross-account attachments that provide access permission. For example, if you\ndelete a cross-account attachment that lists an accelerator as a principal, but\nanother cross-account attachment includes the account ID that owns that\naccelerator, endpoints will not be removed from the accelerator.","ref":"AWS.GlobalAccelerator.html#delete_cross_account_attachment/3","title":"AWS.GlobalAccelerator.delete_cross_account_attachment/3","type":"function"},{"doc":"Delete a custom routing accelerator.\n\nBefore you can delete an accelerator, you must disable it and remove all\ndependent resources (listeners and endpoint groups). To disable the accelerator,\nupdate the accelerator to set `Enabled` to false.\n\nWhen you create a custom routing accelerator, by default, Global Accelerator\nprovides you with a set of two static IP addresses.\n\nThe IP addresses are assigned to your accelerator for as long as it exists, even\nif you disable the accelerator and it no longer accepts or routes traffic.\nHowever, when you *delete* an accelerator, you lose the static IP addresses that\nare assigned to the accelerator, so you can no longer route traffic by using\nthem. As a best practice, ensure that you have permissions in place to avoid\ninadvertently deleting accelerators. You can use IAM policies with Global\nAccelerator to limit the users who have permissions to delete an accelerator.\nFor more information, see [Identity and access management](https://docs.aws.amazon.com/global-accelerator/latest/dg/auth-and-access-control.html)\nin the *Global Accelerator Developer Guide*.","ref":"AWS.GlobalAccelerator.html#delete_custom_routing_accelerator/3","title":"AWS.GlobalAccelerator.delete_custom_routing_accelerator/3","type":"function"},{"doc":"Delete an endpoint group from a listener for a custom routing accelerator.","ref":"AWS.GlobalAccelerator.html#delete_custom_routing_endpoint_group/3","title":"AWS.GlobalAccelerator.delete_custom_routing_endpoint_group/3","type":"function"},{"doc":"Delete a listener for a custom routing accelerator.","ref":"AWS.GlobalAccelerator.html#delete_custom_routing_listener/3","title":"AWS.GlobalAccelerator.delete_custom_routing_listener/3","type":"function"},{"doc":"Delete an endpoint group from a listener.","ref":"AWS.GlobalAccelerator.html#delete_endpoint_group/3","title":"AWS.GlobalAccelerator.delete_endpoint_group/3","type":"function"},{"doc":"Delete a listener from an accelerator.","ref":"AWS.GlobalAccelerator.html#delete_listener/3","title":"AWS.GlobalAccelerator.delete_listener/3","type":"function"},{"doc":"Specify the Amazon EC2 instance (destination) IP addresses and ports for a VPC\nsubnet endpoint that cannot receive traffic for a custom routing accelerator.\n\nYou can deny traffic to all destinations in the VPC endpoint, or deny traffic to\na specified list of destination IP addresses and ports. Note that you cannot\nspecify IP addresses or ports outside of the range that you configured for the\nendpoint group.\n\nAfter you make changes, you can verify that the updates are complete by checking\nthe status of your accelerator: the status changes from IN_PROGRESS to DEPLOYED.","ref":"AWS.GlobalAccelerator.html#deny_custom_routing_traffic/3","title":"AWS.GlobalAccelerator.deny_custom_routing_traffic/3","type":"function"},{"doc":"Releases the specified address range that you provisioned to use with your\nAmazon Web Services resources through bring your own IP addresses (BYOIP) and\ndeletes the corresponding address pool.\n\nBefore you can release an address range, you must stop advertising it by using\n[WithdrawByoipCidr](https://docs.aws.amazon.com/global-accelerator/latest/api/WithdrawByoipCidr.html) and you must not have any accelerators that are using static IP addresses\nallocated from its address range.\n\nFor more information, see [Bring your own IP addresses\n(BYOIP)](https://docs.aws.amazon.com/global-accelerator/latest/dg/using-byoip.html)\nin the *Global Accelerator Developer Guide*.","ref":"AWS.GlobalAccelerator.html#deprovision_byoip_cidr/3","title":"AWS.GlobalAccelerator.deprovision_byoip_cidr/3","type":"function"},{"doc":"Describe an accelerator.","ref":"AWS.GlobalAccelerator.html#describe_accelerator/3","title":"AWS.GlobalAccelerator.describe_accelerator/3","type":"function"},{"doc":"Describe the attributes of an accelerator.","ref":"AWS.GlobalAccelerator.html#describe_accelerator_attributes/3","title":"AWS.GlobalAccelerator.describe_accelerator_attributes/3","type":"function"},{"doc":"Gets configuration information about a cross-account attachment.","ref":"AWS.GlobalAccelerator.html#describe_cross_account_attachment/3","title":"AWS.GlobalAccelerator.describe_cross_account_attachment/3","type":"function"},{"doc":"Describe a custom routing accelerator.","ref":"AWS.GlobalAccelerator.html#describe_custom_routing_accelerator/3","title":"AWS.GlobalAccelerator.describe_custom_routing_accelerator/3","type":"function"},{"doc":"Describe the attributes of a custom routing accelerator.","ref":"AWS.GlobalAccelerator.html#describe_custom_routing_accelerator_attributes/3","title":"AWS.GlobalAccelerator.describe_custom_routing_accelerator_attributes/3","type":"function"},{"doc":"Describe an endpoint group for a custom routing accelerator.","ref":"AWS.GlobalAccelerator.html#describe_custom_routing_endpoint_group/3","title":"AWS.GlobalAccelerator.describe_custom_routing_endpoint_group/3","type":"function"},{"doc":"The description of a listener for a custom routing accelerator.","ref":"AWS.GlobalAccelerator.html#describe_custom_routing_listener/3","title":"AWS.GlobalAccelerator.describe_custom_routing_listener/3","type":"function"},{"doc":"Describe an endpoint group.","ref":"AWS.GlobalAccelerator.html#describe_endpoint_group/3","title":"AWS.GlobalAccelerator.describe_endpoint_group/3","type":"function"},{"doc":"Describe a listener.","ref":"AWS.GlobalAccelerator.html#describe_listener/3","title":"AWS.GlobalAccelerator.describe_listener/3","type":"function"},{"doc":"List the accelerators for an Amazon Web Services account.","ref":"AWS.GlobalAccelerator.html#list_accelerators/3","title":"AWS.GlobalAccelerator.list_accelerators/3","type":"function"},{"doc":"Lists the IP address ranges that were specified in calls to\n[ProvisionByoipCidr](https://docs.aws.amazon.com/global-accelerator/latest/api/ProvisionByoipCidr.html),\nincluding the current state and a history of state changes.","ref":"AWS.GlobalAccelerator.html#list_byoip_cidrs/3","title":"AWS.GlobalAccelerator.list_byoip_cidrs/3","type":"function"},{"doc":"List the cross-account attachments that have been created in Global Accelerator.","ref":"AWS.GlobalAccelerator.html#list_cross_account_attachments/3","title":"AWS.GlobalAccelerator.list_cross_account_attachments/3","type":"function"},{"doc":"List the accounts that have cross-account endpoints.","ref":"AWS.GlobalAccelerator.html#list_cross_account_resource_accounts/3","title":"AWS.GlobalAccelerator.list_cross_account_resource_accounts/3","type":"function"},{"doc":"List the cross-account endpoints available to add to an accelerator.","ref":"AWS.GlobalAccelerator.html#list_cross_account_resources/3","title":"AWS.GlobalAccelerator.list_cross_account_resources/3","type":"function"},{"doc":"List the custom routing accelerators for an Amazon Web Services account.","ref":"AWS.GlobalAccelerator.html#list_custom_routing_accelerators/3","title":"AWS.GlobalAccelerator.list_custom_routing_accelerators/3","type":"function"},{"doc":"List the endpoint groups that are associated with a listener for a custom\nrouting accelerator.","ref":"AWS.GlobalAccelerator.html#list_custom_routing_endpoint_groups/3","title":"AWS.GlobalAccelerator.list_custom_routing_endpoint_groups/3","type":"function"},{"doc":"List the listeners for a custom routing accelerator.","ref":"AWS.GlobalAccelerator.html#list_custom_routing_listeners/3","title":"AWS.GlobalAccelerator.list_custom_routing_listeners/3","type":"function"},{"doc":"Provides a complete mapping from the public accelerator IP address and port to\ndestination EC2 instance IP addresses and ports in the virtual public cloud\n(VPC) subnet endpoint for a custom routing accelerator.\n\nFor each subnet endpoint that you add, Global Accelerator creates a new static\nport mapping for the accelerator. The port mappings don't change after Global\nAccelerator generates them, so you can retrieve and cache the full mapping on\nyour servers.\n\nIf you remove a subnet from your accelerator, Global Accelerator removes\n(reclaims) the port mappings. If you add a subnet to your accelerator, Global\nAccelerator creates new port mappings (the existing ones don't change). If you\nadd or remove EC2 instances in your subnet, the port mappings don't change,\nbecause the mappings are created when you add the subnet to Global Accelerator.\n\nThe mappings also include a flag for each destination denoting which destination\nIP addresses and ports are allowed or denied traffic.","ref":"AWS.GlobalAccelerator.html#list_custom_routing_port_mappings/3","title":"AWS.GlobalAccelerator.list_custom_routing_port_mappings/3","type":"function"},{"doc":"List the port mappings for a specific EC2 instance (destination) in a VPC subnet\nendpoint.\n\nThe response is the mappings for one destination IP address. This is useful when\nyour subnet endpoint has mappings that span multiple custom routing accelerators\nin your account, or for scenarios where you only want to list the port mappings\nfor a specific destination instance.","ref":"AWS.GlobalAccelerator.html#list_custom_routing_port_mappings_by_destination/3","title":"AWS.GlobalAccelerator.list_custom_routing_port_mappings_by_destination/3","type":"function"},{"doc":"List the endpoint groups that are associated with a listener.","ref":"AWS.GlobalAccelerator.html#list_endpoint_groups/3","title":"AWS.GlobalAccelerator.list_endpoint_groups/3","type":"function"},{"doc":"List the listeners for an accelerator.","ref":"AWS.GlobalAccelerator.html#list_listeners/3","title":"AWS.GlobalAccelerator.list_listeners/3","type":"function"},{"doc":"List all tags for an accelerator.\n\nFor more information, see [Tagging in Global Accelerator](https://docs.aws.amazon.com/global-accelerator/latest/dg/tagging-in-global-accelerator.html)\nin the *Global Accelerator Developer Guide*.","ref":"AWS.GlobalAccelerator.html#list_tags_for_resource/3","title":"AWS.GlobalAccelerator.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.GlobalAccelerator.html#metadata/0","title":"AWS.GlobalAccelerator.metadata/0","type":"function"},{"doc":"Provisions an IP address range to use with your Amazon Web Services resources\nthrough bring your own IP addresses (BYOIP) and creates a corresponding address\npool.\n\nAfter the address range is provisioned, it is ready to be advertised using [\nAdvertiseByoipCidr](https://docs.aws.amazon.com/global-accelerator/latest/api/AdvertiseByoipCidr.html).\n\nFor more information, see [Bring your own IP addresses (BYOIP)](https://docs.aws.amazon.com/global-accelerator/latest/dg/using-byoip.html)\nin the *Global Accelerator Developer Guide*.","ref":"AWS.GlobalAccelerator.html#provision_byoip_cidr/3","title":"AWS.GlobalAccelerator.provision_byoip_cidr/3","type":"function"},{"doc":"Remove endpoints from a custom routing accelerator.","ref":"AWS.GlobalAccelerator.html#remove_custom_routing_endpoints/3","title":"AWS.GlobalAccelerator.remove_custom_routing_endpoints/3","type":"function"},{"doc":"Remove endpoints from an endpoint group.\n\nThe `RemoveEndpoints` API operation is the recommended option for removing\nendpoints. The alternative is to remove endpoints by updating an endpoint group\nby using the\n[UpdateEndpointGroup](https://docs.aws.amazon.com/global-accelerator/latest/api/API_UpdateEndpointGroup.html)\nAPI operation. There are two advantages to using `AddEndpoints` to remove\nendpoints instead:\n\n  * It's more convenient, because you only need to specify the\nendpoints that you want to remove. With the `UpdateEndpointGroup` API operation,\nyou must specify all of the endpoints in the endpoint group except the ones that\nyou want to remove from the group.\n\n  * It's faster, because Global Accelerator doesn't need to resolve\nany endpoints. With the `UpdateEndpointGroup` API operation, Global Accelerator\nmust resolve all of the endpoints that remain in the group.","ref":"AWS.GlobalAccelerator.html#remove_endpoints/3","title":"AWS.GlobalAccelerator.remove_endpoints/3","type":"function"},{"doc":"Add tags to an accelerator resource.\n\nFor more information, see [Tagging in Global Accelerator](https://docs.aws.amazon.com/global-accelerator/latest/dg/tagging-in-global-accelerator.html)\nin the *Global Accelerator Developer Guide*.","ref":"AWS.GlobalAccelerator.html#tag_resource/3","title":"AWS.GlobalAccelerator.tag_resource/3","type":"function"},{"doc":"Remove tags from a Global Accelerator resource.\n\nWhen you specify a tag key, the action removes both that key and its associated\nvalue. The operation succeeds even if you attempt to remove tags from an\naccelerator that was already removed.\n\nFor more information, see [Tagging in Global Accelerator](https://docs.aws.amazon.com/global-accelerator/latest/dg/tagging-in-global-accelerator.html)\nin the *Global Accelerator Developer Guide*.","ref":"AWS.GlobalAccelerator.html#untag_resource/3","title":"AWS.GlobalAccelerator.untag_resource/3","type":"function"},{"doc":"Update an accelerator to make changes, such as the following:\n\n  * Change the name of the accelerator.\n\n  * Disable the accelerator so that it no longer accepts or routes\ntraffic, or so that you can delete it.\n\n  * Enable the accelerator, if it is disabled.\n\n  * Change the IP address type to dual-stack if it is IPv4, or change\nthe IP address type to IPv4 if it's dual-stack.\n\nBe aware that static IP addresses remain assigned to your accelerator for as\nlong as it exists, even if you disable the accelerator and it no longer accepts\nor routes traffic. However, when you delete the accelerator, you lose the static\nIP addresses that are assigned to it, so you can no longer route traffic by\nusing them.\n\nGlobal Accelerator is a global service that supports endpoints in multiple\nAmazon Web Services Regions but you must specify the US West (Oregon) Region to\ncreate, update, or otherwise work with accelerators. That is, for example,\nspecify `--region us-west-2` on Amazon Web Services CLI commands.","ref":"AWS.GlobalAccelerator.html#update_accelerator/3","title":"AWS.GlobalAccelerator.update_accelerator/3","type":"function"},{"doc":"Update the attributes for an accelerator.","ref":"AWS.GlobalAccelerator.html#update_accelerator_attributes/3","title":"AWS.GlobalAccelerator.update_accelerator_attributes/3","type":"function"},{"doc":"Update a cross-account attachment to add or remove principals or resources.\n\nWhen you update an attachment to remove a principal (account ID or accelerator)\nor a resource, Global Accelerator revokes the permission for specific resources\nby doing the following:\n\n  * If the principal is an account ID, Global Accelerator reviews\nevery accelerator in the account and removes cross-account endpoints from all\naccelerators.\n\n  * If the principal is an accelerator, Global Accelerator reviews\njust that accelerator and removes cross-account endpoints from it.\n\nIf there are overlapping permissions provided by multiple cross-account\nattachments, Global Accelerator only removes endpoints if there are no current\ncross-account attachments that provide access permission. For example, if you\ndelete a cross-account attachment that lists an accelerator as a principal, but\nanother cross-account attachment includes the account ID that owns that\naccelerator, endpoints will not be removed from the accelerator.","ref":"AWS.GlobalAccelerator.html#update_cross_account_attachment/3","title":"AWS.GlobalAccelerator.update_cross_account_attachment/3","type":"function"},{"doc":"Update a custom routing accelerator.","ref":"AWS.GlobalAccelerator.html#update_custom_routing_accelerator/3","title":"AWS.GlobalAccelerator.update_custom_routing_accelerator/3","type":"function"},{"doc":"Update the attributes for a custom routing accelerator.","ref":"AWS.GlobalAccelerator.html#update_custom_routing_accelerator_attributes/3","title":"AWS.GlobalAccelerator.update_custom_routing_accelerator_attributes/3","type":"function"},{"doc":"Update a listener for a custom routing accelerator.","ref":"AWS.GlobalAccelerator.html#update_custom_routing_listener/3","title":"AWS.GlobalAccelerator.update_custom_routing_listener/3","type":"function"},{"doc":"Update an endpoint group.\n\nA resource must be valid and active when you add it as an endpoint.","ref":"AWS.GlobalAccelerator.html#update_endpoint_group/3","title":"AWS.GlobalAccelerator.update_endpoint_group/3","type":"function"},{"doc":"Update a listener.","ref":"AWS.GlobalAccelerator.html#update_listener/3","title":"AWS.GlobalAccelerator.update_listener/3","type":"function"},{"doc":"Stops advertising an address range that is provisioned as an address pool.\n\nYou can perform this operation at most once every 10 seconds, even if you\nspecify different address ranges each time.\n\nIt can take a few minutes before traffic to the specified addresses stops\nrouting to Amazon Web Services because of propagation delays.\n\nFor more information, see [Bring your own IP addresses (BYOIP)](https://docs.aws.amazon.com/global-accelerator/latest/dg/using-byoip.html)\nin the *Global Accelerator Developer Guide*.","ref":"AWS.GlobalAccelerator.html#withdraw_byoip_cidr/3","title":"AWS.GlobalAccelerator.withdraw_byoip_cidr/3","type":"function"},{"doc":"Glue\n\nDefines the public endpoint for the Glue service.","ref":"AWS.Glue.html","title":"AWS.Glue","type":"module"},{"doc":"Creates one or more partitions in a batch operation.","ref":"AWS.Glue.html#batch_create_partition/3","title":"AWS.Glue.batch_create_partition/3","type":"function"},{"doc":"Deletes a list of connection definitions from the Data Catalog.","ref":"AWS.Glue.html#batch_delete_connection/3","title":"AWS.Glue.batch_delete_connection/3","type":"function"},{"doc":"Deletes one or more partitions in a batch operation.","ref":"AWS.Glue.html#batch_delete_partition/3","title":"AWS.Glue.batch_delete_partition/3","type":"function"},{"doc":"Deletes multiple tables at once.\n\nAfter completing this operation, you no longer have access to the table versions\nand partitions that belong to the deleted table. Glue deletes these \"orphaned\"\nresources asynchronously in a timely manner, at the discretion of the service.\n\nTo ensure the immediate deletion of all related resources, before calling\n`BatchDeleteTable`, use `DeleteTableVersion` or `BatchDeleteTableVersion`, and\n`DeletePartition` or `BatchDeletePartition`, to delete any resources that belong\nto the table.","ref":"AWS.Glue.html#batch_delete_table/3","title":"AWS.Glue.batch_delete_table/3","type":"function"},{"doc":"Deletes a specified batch of versions of a table.","ref":"AWS.Glue.html#batch_delete_table_version/3","title":"AWS.Glue.batch_delete_table_version/3","type":"function"},{"doc":"Retrieves information about a list of blueprints.","ref":"AWS.Glue.html#batch_get_blueprints/3","title":"AWS.Glue.batch_get_blueprints/3","type":"function"},{"doc":"Returns a list of resource metadata for a given list of crawler names.\n\nAfter calling the `ListCrawlers` operation, you can call this operation to\naccess the data to which you have been granted permissions. This operation\nsupports all IAM permissions, including permission conditions that uses tags.","ref":"AWS.Glue.html#batch_get_crawlers/3","title":"AWS.Glue.batch_get_crawlers/3","type":"function"},{"doc":"Retrieves the details for the custom patterns specified by a list of names.","ref":"AWS.Glue.html#batch_get_custom_entity_types/3","title":"AWS.Glue.batch_get_custom_entity_types/3","type":"function"},{"doc":"Retrieves a list of data quality results for the specified result IDs.","ref":"AWS.Glue.html#batch_get_data_quality_result/3","title":"AWS.Glue.batch_get_data_quality_result/3","type":"function"},{"doc":"Returns a list of resource metadata for a given list of development endpoint\nnames.\n\nAfter calling the `ListDevEndpoints` operation, you can call this operation to\naccess the data to which you have been granted permissions. This operation\nsupports all IAM permissions, including permission conditions that uses tags.","ref":"AWS.Glue.html#batch_get_dev_endpoints/3","title":"AWS.Glue.batch_get_dev_endpoints/3","type":"function"},{"doc":"Returns a list of resource metadata for a given list of job names.\n\nAfter calling the `ListJobs` operation, you can call this operation to access\nthe data to which you have been granted permissions. This operation supports all\nIAM permissions, including permission conditions that uses tags.","ref":"AWS.Glue.html#batch_get_jobs/3","title":"AWS.Glue.batch_get_jobs/3","type":"function"},{"doc":"Retrieves partitions in a batch request.","ref":"AWS.Glue.html#batch_get_partition/3","title":"AWS.Glue.batch_get_partition/3","type":"function"},{"doc":"Returns the configuration for the specified table optimizers.","ref":"AWS.Glue.html#batch_get_table_optimizer/3","title":"AWS.Glue.batch_get_table_optimizer/3","type":"function"},{"doc":"Returns a list of resource metadata for a given list of trigger names.\n\nAfter calling the `ListTriggers` operation, you can call this operation to\naccess the data to which you have been granted permissions. This operation\nsupports all IAM permissions, including permission conditions that uses tags.","ref":"AWS.Glue.html#batch_get_triggers/3","title":"AWS.Glue.batch_get_triggers/3","type":"function"},{"doc":"Returns a list of resource metadata for a given list of workflow names.\n\nAfter calling the `ListWorkflows` operation, you can call this operation to\naccess the data to which you have been granted permissions. This operation\nsupports all IAM permissions, including permission conditions that uses tags.","ref":"AWS.Glue.html#batch_get_workflows/3","title":"AWS.Glue.batch_get_workflows/3","type":"function"},{"doc":"Stops one or more job runs for a specified job definition.","ref":"AWS.Glue.html#batch_stop_job_run/3","title":"AWS.Glue.batch_stop_job_run/3","type":"function"},{"doc":"Updates one or more partitions in a batch operation.","ref":"AWS.Glue.html#batch_update_partition/3","title":"AWS.Glue.batch_update_partition/3","type":"function"},{"doc":"Cancels the specified recommendation run that was being used to generate rules.","ref":"AWS.Glue.html#cancel_data_quality_rule_recommendation_run/3","title":"AWS.Glue.cancel_data_quality_rule_recommendation_run/3","type":"function"},{"doc":"Cancels a run where a ruleset is being evaluated against a data source.","ref":"AWS.Glue.html#cancel_data_quality_ruleset_evaluation_run/3","title":"AWS.Glue.cancel_data_quality_ruleset_evaluation_run/3","type":"function"},{"doc":"Cancels (stops) a task run.\n\nMachine learning task runs are asynchronous tasks that Glue runs on your behalf\nas part of various machine learning workflows. You can cancel a machine learning\ntask run at any time by calling `CancelMLTaskRun` with a task run's parent\ntransform's `TransformID` and the task run's `TaskRunId`.","ref":"AWS.Glue.html#cancel_ml_task_run/3","title":"AWS.Glue.cancel_ml_task_run/3","type":"function"},{"doc":"Cancels the statement.","ref":"AWS.Glue.html#cancel_statement/3","title":"AWS.Glue.cancel_statement/3","type":"function"},{"doc":"Validates the supplied schema.\n\nThis call has no side effects, it simply validates using the supplied schema\nusing `DataFormat` as the format. Since it does not take a schema set name, no\ncompatibility checks are performed.","ref":"AWS.Glue.html#check_schema_version_validity/3","title":"AWS.Glue.check_schema_version_validity/3","type":"function"},{"doc":"Registers a blueprint with Glue.","ref":"AWS.Glue.html#create_blueprint/3","title":"AWS.Glue.create_blueprint/3","type":"function"},{"doc":"Creates a classifier in the user's account.\n\nThis can be a `GrokClassifier`, an `XMLClassifier`, a `JsonClassifier`, or a\n`CsvClassifier`, depending on which field of the request is present.","ref":"AWS.Glue.html#create_classifier/3","title":"AWS.Glue.create_classifier/3","type":"function"},{"doc":"Creates a connection definition in the Data Catalog.\n\nConnections used for creating federated resources require the IAM\n`glue:PassConnection` permission.","ref":"AWS.Glue.html#create_connection/3","title":"AWS.Glue.create_connection/3","type":"function"},{"doc":"Creates a new crawler with specified targets, role, configuration, and optional\nschedule.\n\nAt least one crawl target must be specified, in the `s3Targets` field, the\n`jdbcTargets` field, or the `DynamoDBTargets` field.","ref":"AWS.Glue.html#create_crawler/3","title":"AWS.Glue.create_crawler/3","type":"function"},{"doc":"Creates a custom pattern that is used to detect sensitive data across the\ncolumns and rows of your structured data.\n\nEach custom pattern you create specifies a regular expression and an optional\nlist of context words. If no context words are passed only a regular expression\nis checked.","ref":"AWS.Glue.html#create_custom_entity_type/3","title":"AWS.Glue.create_custom_entity_type/3","type":"function"},{"doc":"Creates a data quality ruleset with DQDL rules applied to a specified Glue\ntable.\n\nYou create the ruleset using the Data Quality Definition Language (DQDL). For\nmore information, see the Glue developer guide.","ref":"AWS.Glue.html#create_data_quality_ruleset/3","title":"AWS.Glue.create_data_quality_ruleset/3","type":"function"},{"doc":"Creates a new database in a Data Catalog.","ref":"AWS.Glue.html#create_database/3","title":"AWS.Glue.create_database/3","type":"function"},{"doc":"Creates a new development endpoint.","ref":"AWS.Glue.html#create_dev_endpoint/3","title":"AWS.Glue.create_dev_endpoint/3","type":"function"},{"doc":"Creates a new job definition.","ref":"AWS.Glue.html#create_job/3","title":"AWS.Glue.create_job/3","type":"function"},{"doc":"Creates an Glue machine learning transform.\n\nThis operation creates the transform and all the necessary parameters to train\nit.\n\nCall this operation as the first step in the process of using a machine learning\ntransform (such as the `FindMatches` transform) for deduplicating data. You can\nprovide an optional `Description`, in addition to the parameters that you want\nto use for your algorithm.\n\nYou must also specify certain parameters for the tasks that Glue runs on your\nbehalf as part of learning from your data and creating a high-quality machine\nlearning transform. These parameters include `Role`, and optionally,\n`AllocatedCapacity`, `Timeout`, and `MaxRetries`. For more information, see\n[Jobs](https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-job.html).","ref":"AWS.Glue.html#create_ml_transform/3","title":"AWS.Glue.create_ml_transform/3","type":"function"},{"doc":"Creates a new partition.","ref":"AWS.Glue.html#create_partition/3","title":"AWS.Glue.create_partition/3","type":"function"},{"doc":"Creates a specified partition index in an existing table.","ref":"AWS.Glue.html#create_partition_index/3","title":"AWS.Glue.create_partition_index/3","type":"function"},{"doc":"Creates a new registry which may be used to hold a collection of schemas.","ref":"AWS.Glue.html#create_registry/3","title":"AWS.Glue.create_registry/3","type":"function"},{"doc":"Creates a new schema set and registers the schema definition.\n\nReturns an error if the schema set already exists without actually registering\nthe version.\n\nWhen the schema set is created, a version checkpoint will be set to the first\nversion. Compatibility mode \"DISABLED\" restricts any additional schema versions\nfrom being added after the first schema version. For all other compatibility\nmodes, validation of compatibility settings will be applied only from the second\nversion onwards when the `RegisterSchemaVersion` API is used.\n\nWhen this API is called without a `RegistryId`, this will create an entry for a\n\"default-registry\" in the registry database tables, if it is not already\npresent.","ref":"AWS.Glue.html#create_schema/3","title":"AWS.Glue.create_schema/3","type":"function"},{"doc":"Transforms a directed acyclic graph (DAG) into code.","ref":"AWS.Glue.html#create_script/3","title":"AWS.Glue.create_script/3","type":"function"},{"doc":"Creates a new security configuration.\n\nA security configuration is a set of security properties that can be used by\nGlue. You can use a security configuration to encrypt data at rest. For\ninformation about using security configurations in Glue, see [Encrypting Data Written by Crawlers, Jobs, and Development\nEndpoints](https://docs.aws.amazon.com/glue/latest/dg/encryption-security-configuration.html).","ref":"AWS.Glue.html#create_security_configuration/3","title":"AWS.Glue.create_security_configuration/3","type":"function"},{"doc":"Creates a new session.","ref":"AWS.Glue.html#create_session/3","title":"AWS.Glue.create_session/3","type":"function"},{"doc":"Creates a new table definition in the Data Catalog.","ref":"AWS.Glue.html#create_table/3","title":"AWS.Glue.create_table/3","type":"function"},{"doc":"Creates a new table optimizer for a specific function.\n\n`compaction` is the only currently supported optimizer type.","ref":"AWS.Glue.html#create_table_optimizer/3","title":"AWS.Glue.create_table_optimizer/3","type":"function"},{"doc":"Creates a new trigger.","ref":"AWS.Glue.html#create_trigger/3","title":"AWS.Glue.create_trigger/3","type":"function"},{"doc":"Creates a new function definition in the Data Catalog.","ref":"AWS.Glue.html#create_user_defined_function/3","title":"AWS.Glue.create_user_defined_function/3","type":"function"},{"doc":"Creates a new workflow.","ref":"AWS.Glue.html#create_workflow/3","title":"AWS.Glue.create_workflow/3","type":"function"},{"doc":"Deletes an existing blueprint.","ref":"AWS.Glue.html#delete_blueprint/3","title":"AWS.Glue.delete_blueprint/3","type":"function"},{"doc":"Removes a classifier from the Data Catalog.","ref":"AWS.Glue.html#delete_classifier/3","title":"AWS.Glue.delete_classifier/3","type":"function"},{"doc":"Delete the partition column statistics of a column.\n\nThe Identity and Access Management (IAM) permission required for this operation\nis `DeletePartition`.","ref":"AWS.Glue.html#delete_column_statistics_for_partition/3","title":"AWS.Glue.delete_column_statistics_for_partition/3","type":"function"},{"doc":"Retrieves table statistics of columns.\n\nThe Identity and Access Management (IAM) permission required for this operation\nis `DeleteTable`.","ref":"AWS.Glue.html#delete_column_statistics_for_table/3","title":"AWS.Glue.delete_column_statistics_for_table/3","type":"function"},{"doc":"Deletes a connection from the Data Catalog.","ref":"AWS.Glue.html#delete_connection/3","title":"AWS.Glue.delete_connection/3","type":"function"},{"doc":"Removes a specified crawler from the Glue Data Catalog, unless the crawler state\nis `RUNNING`.","ref":"AWS.Glue.html#delete_crawler/3","title":"AWS.Glue.delete_crawler/3","type":"function"},{"doc":"Deletes a custom pattern by specifying its name.","ref":"AWS.Glue.html#delete_custom_entity_type/3","title":"AWS.Glue.delete_custom_entity_type/3","type":"function"},{"doc":"Deletes a data quality ruleset.","ref":"AWS.Glue.html#delete_data_quality_ruleset/3","title":"AWS.Glue.delete_data_quality_ruleset/3","type":"function"},{"doc":"Removes a specified database from a Data Catalog.\n\nAfter completing this operation, you no longer have access to the tables (and\nall table versions and partitions that might belong to the tables) and the\nuser-defined functions in the deleted database. Glue deletes these \"orphaned\"\nresources asynchronously in a timely manner, at the discretion of the service.\n\nTo ensure the immediate deletion of all related resources, before calling\n`DeleteDatabase`, use `DeleteTableVersion` or `BatchDeleteTableVersion`,\n`DeletePartition` or `BatchDeletePartition`, `DeleteUserDefinedFunction`, and\n`DeleteTable` or `BatchDeleteTable`, to delete any resources that belong to the\ndatabase.","ref":"AWS.Glue.html#delete_database/3","title":"AWS.Glue.delete_database/3","type":"function"},{"doc":"Deletes a specified development endpoint.","ref":"AWS.Glue.html#delete_dev_endpoint/3","title":"AWS.Glue.delete_dev_endpoint/3","type":"function"},{"doc":"Deletes a specified job definition.\n\nIf the job definition is not found, no exception is thrown.","ref":"AWS.Glue.html#delete_job/3","title":"AWS.Glue.delete_job/3","type":"function"},{"doc":"Deletes an Glue machine learning transform.\n\nMachine learning transforms are a special type of transform that use machine\nlearning to learn the details of the transformation to be performed by learning\nfrom examples provided by humans. These transformations are then saved by Glue.\nIf you no longer need a transform, you can delete it by calling\n`DeleteMLTransforms`. However, any Glue jobs that still reference the deleted\ntransform will no longer succeed.","ref":"AWS.Glue.html#delete_ml_transform/3","title":"AWS.Glue.delete_ml_transform/3","type":"function"},{"doc":"Deletes a specified partition.","ref":"AWS.Glue.html#delete_partition/3","title":"AWS.Glue.delete_partition/3","type":"function"},{"doc":"Deletes a specified partition index from an existing table.","ref":"AWS.Glue.html#delete_partition_index/3","title":"AWS.Glue.delete_partition_index/3","type":"function"},{"doc":"Delete the entire registry including schema and all of its versions.\n\nTo get the status of the delete operation, you can call the `GetRegistry` API\nafter the asynchronous call. Deleting a registry will deactivate all online\noperations for the registry such as the `UpdateRegistry`, `CreateSchema`,\n`UpdateSchema`, and `RegisterSchemaVersion` APIs.","ref":"AWS.Glue.html#delete_registry/3","title":"AWS.Glue.delete_registry/3","type":"function"},{"doc":"Deletes a specified policy.","ref":"AWS.Glue.html#delete_resource_policy/3","title":"AWS.Glue.delete_resource_policy/3","type":"function"},{"doc":"Deletes the entire schema set, including the schema set and all of its versions.\n\nTo get the status of the delete operation, you can call `GetSchema` API after\nthe asynchronous call. Deleting a registry will deactivate all online operations\nfor the schema, such as the `GetSchemaByDefinition`, and `RegisterSchemaVersion`\nAPIs.","ref":"AWS.Glue.html#delete_schema/3","title":"AWS.Glue.delete_schema/3","type":"function"},{"doc":"Remove versions from the specified schema.\n\nA version number or range may be supplied. If the compatibility mode forbids\ndeleting of a version that is necessary, such as BACKWARDS_FULL, an error is\nreturned. Calling the `GetSchemaVersions` API after this call will list the\nstatus of the deleted versions.\n\nWhen the range of version numbers contain check pointed version, the API will\nreturn a 409 conflict and will not proceed with the deletion. You have to remove\nthe checkpoint first using the `DeleteSchemaCheckpoint` API before using this\nAPI.\n\nYou cannot use the `DeleteSchemaVersions` API to delete the first schema version\nin the schema set. The first schema version can only be deleted by the\n`DeleteSchema` API. This operation will also delete the attached\n`SchemaVersionMetadata` under the schema versions. Hard deletes will be enforced\non the database.\n\nIf the compatibility mode forbids deleting of a version that is necessary, such\nas BACKWARDS_FULL, an error is returned.","ref":"AWS.Glue.html#delete_schema_versions/3","title":"AWS.Glue.delete_schema_versions/3","type":"function"},{"doc":"Deletes a specified security configuration.","ref":"AWS.Glue.html#delete_security_configuration/3","title":"AWS.Glue.delete_security_configuration/3","type":"function"},{"doc":"Deletes the session.","ref":"AWS.Glue.html#delete_session/3","title":"AWS.Glue.delete_session/3","type":"function"},{"doc":"Removes a table definition from the Data Catalog.\n\nAfter completing this operation, you no longer have access to the table versions\nand partitions that belong to the deleted table. Glue deletes these \"orphaned\"\nresources asynchronously in a timely manner, at the discretion of the service.\n\nTo ensure the immediate deletion of all related resources, before calling\n`DeleteTable`, use `DeleteTableVersion` or `BatchDeleteTableVersion`, and\n`DeletePartition` or `BatchDeletePartition`, to delete any resources that belong\nto the table.","ref":"AWS.Glue.html#delete_table/3","title":"AWS.Glue.delete_table/3","type":"function"},{"doc":"Deletes an optimizer and all associated metadata for a table.\n\nThe optimization will no longer be performed on the table.","ref":"AWS.Glue.html#delete_table_optimizer/3","title":"AWS.Glue.delete_table_optimizer/3","type":"function"},{"doc":"Deletes a specified version of a table.","ref":"AWS.Glue.html#delete_table_version/3","title":"AWS.Glue.delete_table_version/3","type":"function"},{"doc":"Deletes a specified trigger.\n\nIf the trigger is not found, no exception is thrown.","ref":"AWS.Glue.html#delete_trigger/3","title":"AWS.Glue.delete_trigger/3","type":"function"},{"doc":"Deletes an existing function definition from the Data Catalog.","ref":"AWS.Glue.html#delete_user_defined_function/3","title":"AWS.Glue.delete_user_defined_function/3","type":"function"},{"doc":"Deletes a workflow.","ref":"AWS.Glue.html#delete_workflow/3","title":"AWS.Glue.delete_workflow/3","type":"function"},{"doc":"Retrieves the details of a blueprint.","ref":"AWS.Glue.html#get_blueprint/3","title":"AWS.Glue.get_blueprint/3","type":"function"},{"doc":"Retrieves the details of a blueprint run.","ref":"AWS.Glue.html#get_blueprint_run/3","title":"AWS.Glue.get_blueprint_run/3","type":"function"},{"doc":"Retrieves the details of blueprint runs for a specified blueprint.","ref":"AWS.Glue.html#get_blueprint_runs/3","title":"AWS.Glue.get_blueprint_runs/3","type":"function"},{"doc":"Retrieves the status of a migration operation.","ref":"AWS.Glue.html#get_catalog_import_status/3","title":"AWS.Glue.get_catalog_import_status/3","type":"function"},{"doc":"Retrieve a classifier by name.","ref":"AWS.Glue.html#get_classifier/3","title":"AWS.Glue.get_classifier/3","type":"function"},{"doc":"Lists all classifier objects in the Data Catalog.","ref":"AWS.Glue.html#get_classifiers/3","title":"AWS.Glue.get_classifiers/3","type":"function"},{"doc":"Retrieves partition statistics of columns.\n\nThe Identity and Access Management (IAM) permission required for this operation\nis `GetPartition`.","ref":"AWS.Glue.html#get_column_statistics_for_partition/3","title":"AWS.Glue.get_column_statistics_for_partition/3","type":"function"},{"doc":"Retrieves table statistics of columns.\n\nThe Identity and Access Management (IAM) permission required for this operation\nis `GetTable`.","ref":"AWS.Glue.html#get_column_statistics_for_table/3","title":"AWS.Glue.get_column_statistics_for_table/3","type":"function"},{"doc":"Get the associated metadata/information for a task run, given a task run ID.","ref":"AWS.Glue.html#get_column_statistics_task_run/3","title":"AWS.Glue.get_column_statistics_task_run/3","type":"function"},{"doc":"Retrieves information about all runs associated with the specified table.","ref":"AWS.Glue.html#get_column_statistics_task_runs/3","title":"AWS.Glue.get_column_statistics_task_runs/3","type":"function"},{"doc":"Retrieves a connection definition from the Data Catalog.","ref":"AWS.Glue.html#get_connection/3","title":"AWS.Glue.get_connection/3","type":"function"},{"doc":"Retrieves a list of connection definitions from the Data Catalog.","ref":"AWS.Glue.html#get_connections/3","title":"AWS.Glue.get_connections/3","type":"function"},{"doc":"Retrieves metadata for a specified crawler.","ref":"AWS.Glue.html#get_crawler/3","title":"AWS.Glue.get_crawler/3","type":"function"},{"doc":"Retrieves metrics about specified crawlers.","ref":"AWS.Glue.html#get_crawler_metrics/3","title":"AWS.Glue.get_crawler_metrics/3","type":"function"},{"doc":"Retrieves metadata for all crawlers defined in the customer account.","ref":"AWS.Glue.html#get_crawlers/3","title":"AWS.Glue.get_crawlers/3","type":"function"},{"doc":"Retrieves the details of a custom pattern by specifying its name.","ref":"AWS.Glue.html#get_custom_entity_type/3","title":"AWS.Glue.get_custom_entity_type/3","type":"function"},{"doc":"Retrieves the security configuration for a specified catalog.","ref":"AWS.Glue.html#get_data_catalog_encryption_settings/3","title":"AWS.Glue.get_data_catalog_encryption_settings/3","type":"function"},{"doc":"Retrieves the result of a data quality rule evaluation.","ref":"AWS.Glue.html#get_data_quality_result/3","title":"AWS.Glue.get_data_quality_result/3","type":"function"},{"doc":"Gets the specified recommendation run that was used to generate rules.","ref":"AWS.Glue.html#get_data_quality_rule_recommendation_run/3","title":"AWS.Glue.get_data_quality_rule_recommendation_run/3","type":"function"},{"doc":"Returns an existing ruleset by identifier or name.","ref":"AWS.Glue.html#get_data_quality_ruleset/3","title":"AWS.Glue.get_data_quality_ruleset/3","type":"function"},{"doc":"Retrieves a specific run where a ruleset is evaluated against a data source.","ref":"AWS.Glue.html#get_data_quality_ruleset_evaluation_run/3","title":"AWS.Glue.get_data_quality_ruleset_evaluation_run/3","type":"function"},{"doc":"Retrieves the definition of a specified database.","ref":"AWS.Glue.html#get_database/3","title":"AWS.Glue.get_database/3","type":"function"},{"doc":"Retrieves all databases defined in a given Data Catalog.","ref":"AWS.Glue.html#get_databases/3","title":"AWS.Glue.get_databases/3","type":"function"},{"doc":"Transforms a Python script into a directed acyclic graph (DAG).","ref":"AWS.Glue.html#get_dataflow_graph/3","title":"AWS.Glue.get_dataflow_graph/3","type":"function"},{"doc":"Retrieves information about a specified development endpoint.\n\nWhen you create a development endpoint in a virtual private cloud (VPC), Glue\nreturns only a private IP address, and the public IP address field is not\npopulated. When you create a non-VPC development endpoint, Glue returns only a\npublic IP address.","ref":"AWS.Glue.html#get_dev_endpoint/3","title":"AWS.Glue.get_dev_endpoint/3","type":"function"},{"doc":"Retrieves all the development endpoints in this Amazon Web Services account.\n\nWhen you create a development endpoint in a virtual private cloud (VPC), Glue\nreturns only a private IP address and the public IP address field is not\npopulated. When you create a non-VPC development endpoint, Glue returns only a\npublic IP address.","ref":"AWS.Glue.html#get_dev_endpoints/3","title":"AWS.Glue.get_dev_endpoints/3","type":"function"},{"doc":"Retrieves an existing job definition.","ref":"AWS.Glue.html#get_job/3","title":"AWS.Glue.get_job/3","type":"function"},{"doc":"Returns information on a job bookmark entry.\n\nFor more information about enabling and using job bookmarks, see:\n\n  * [Tracking processed data using job bookmarks](https://docs.aws.amazon.com/glue/latest/dg/monitor-continuations.html)\n\n  * [Job parameters used by Glue](https://docs.aws.amazon.com/glue/latest/dg/aws-glue-programming-etl-glue-arguments.html)\n\n  * [Job structure](https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-job.html#aws-glue-api-jobs-job-Job)","ref":"AWS.Glue.html#get_job_bookmark/3","title":"AWS.Glue.get_job_bookmark/3","type":"function"},{"doc":"Retrieves the metadata for a given job run.","ref":"AWS.Glue.html#get_job_run/3","title":"AWS.Glue.get_job_run/3","type":"function"},{"doc":"Retrieves metadata for all runs of a given job definition.","ref":"AWS.Glue.html#get_job_runs/3","title":"AWS.Glue.get_job_runs/3","type":"function"},{"doc":"Retrieves all current job definitions.","ref":"AWS.Glue.html#get_jobs/3","title":"AWS.Glue.get_jobs/3","type":"function"},{"doc":"Creates mappings.","ref":"AWS.Glue.html#get_mapping/3","title":"AWS.Glue.get_mapping/3","type":"function"},{"doc":"Gets details for a specific task run on a machine learning transform.\n\nMachine learning task runs are asynchronous tasks that Glue runs on your behalf\nas part of various machine learning workflows. You can check the stats of any\ntask run by calling `GetMLTaskRun` with the `TaskRunID` and its parent\ntransform's `TransformID`.","ref":"AWS.Glue.html#get_ml_task_run/3","title":"AWS.Glue.get_ml_task_run/3","type":"function"},{"doc":"Gets a list of runs for a machine learning transform.\n\nMachine learning task runs are asynchronous tasks that Glue runs on your behalf\nas part of various machine learning workflows. You can get a sortable,\nfilterable list of machine learning task runs by calling `GetMLTaskRuns` with\ntheir parent transform's `TransformID` and other optional parameters as\ndocumented in this section.\n\nThis operation returns a list of historic runs and must be paginated.","ref":"AWS.Glue.html#get_ml_task_runs/3","title":"AWS.Glue.get_ml_task_runs/3","type":"function"},{"doc":"Gets an Glue machine learning transform artifact and all its corresponding\nmetadata.\n\nMachine learning transforms are a special type of transform that use machine\nlearning to learn the details of the transformation to be performed by learning\nfrom examples provided by humans. These transformations are then saved by Glue.\nYou can retrieve their metadata by calling `GetMLTransform`.","ref":"AWS.Glue.html#get_ml_transform/3","title":"AWS.Glue.get_ml_transform/3","type":"function"},{"doc":"Gets a sortable, filterable list of existing Glue machine learning transforms.\n\nMachine learning transforms are a special type of transform that use machine\nlearning to learn the details of the transformation to be performed by learning\nfrom examples provided by humans. These transformations are then saved by Glue,\nand you can retrieve their metadata by calling `GetMLTransforms`.","ref":"AWS.Glue.html#get_ml_transforms/3","title":"AWS.Glue.get_ml_transforms/3","type":"function"},{"doc":"Retrieves information about a specified partition.","ref":"AWS.Glue.html#get_partition/3","title":"AWS.Glue.get_partition/3","type":"function"},{"doc":"Retrieves the partition indexes associated with a table.","ref":"AWS.Glue.html#get_partition_indexes/3","title":"AWS.Glue.get_partition_indexes/3","type":"function"},{"doc":"Retrieves information about the partitions in a table.","ref":"AWS.Glue.html#get_partitions/3","title":"AWS.Glue.get_partitions/3","type":"function"},{"doc":"Gets code to perform a specified mapping.","ref":"AWS.Glue.html#get_plan/3","title":"AWS.Glue.get_plan/3","type":"function"},{"doc":"Describes the specified registry in detail.","ref":"AWS.Glue.html#get_registry/3","title":"AWS.Glue.get_registry/3","type":"function"},{"doc":"Retrieves the resource policies set on individual resources by Resource Access\nManager during cross-account permission grants.\n\nAlso retrieves the Data Catalog resource policy.\n\nIf you enabled metadata encryption in Data Catalog settings, and you do not have\npermission on the KMS key, the operation can't return the Data Catalog resource\npolicy.","ref":"AWS.Glue.html#get_resource_policies/3","title":"AWS.Glue.get_resource_policies/3","type":"function"},{"doc":"Retrieves a specified resource policy.","ref":"AWS.Glue.html#get_resource_policy/3","title":"AWS.Glue.get_resource_policy/3","type":"function"},{"doc":"Describes the specified schema in detail.","ref":"AWS.Glue.html#get_schema/3","title":"AWS.Glue.get_schema/3","type":"function"},{"doc":"Retrieves a schema by the `SchemaDefinition`.\n\nThe schema definition is sent to the Schema Registry, canonicalized, and hashed.\nIf the hash is matched within the scope of the `SchemaName` or ARN (or the\ndefault registry, if none is supplied), that schema’s metadata is returned.\nOtherwise, a 404 or NotFound error is returned. Schema versions in `Deleted`\nstatuses will not be included in the results.","ref":"AWS.Glue.html#get_schema_by_definition/3","title":"AWS.Glue.get_schema_by_definition/3","type":"function"},{"doc":"Get the specified schema by its unique ID assigned when a version of the schema\nis created or registered.\n\nSchema versions in Deleted status will not be included in the results.","ref":"AWS.Glue.html#get_schema_version/3","title":"AWS.Glue.get_schema_version/3","type":"function"},{"doc":"Fetches the schema version difference in the specified difference type between\ntwo stored schema versions in the Schema Registry.\n\nThis API allows you to compare two schema versions between two schema\ndefinitions under the same schema.","ref":"AWS.Glue.html#get_schema_versions_diff/3","title":"AWS.Glue.get_schema_versions_diff/3","type":"function"},{"doc":"Retrieves a specified security configuration.","ref":"AWS.Glue.html#get_security_configuration/3","title":"AWS.Glue.get_security_configuration/3","type":"function"},{"doc":"Retrieves a list of all security configurations.","ref":"AWS.Glue.html#get_security_configurations/3","title":"AWS.Glue.get_security_configurations/3","type":"function"},{"doc":"Retrieves the session.","ref":"AWS.Glue.html#get_session/3","title":"AWS.Glue.get_session/3","type":"function"},{"doc":"Retrieves the statement.","ref":"AWS.Glue.html#get_statement/3","title":"AWS.Glue.get_statement/3","type":"function"},{"doc":"Retrieves the `Table` definition in a Data Catalog for a specified table.","ref":"AWS.Glue.html#get_table/3","title":"AWS.Glue.get_table/3","type":"function"},{"doc":"Returns the configuration of all optimizers associated with a specified table.","ref":"AWS.Glue.html#get_table_optimizer/3","title":"AWS.Glue.get_table_optimizer/3","type":"function"},{"doc":"Retrieves a specified version of a table.","ref":"AWS.Glue.html#get_table_version/3","title":"AWS.Glue.get_table_version/3","type":"function"},{"doc":"Retrieves a list of strings that identify available versions of a specified\ntable.","ref":"AWS.Glue.html#get_table_versions/3","title":"AWS.Glue.get_table_versions/3","type":"function"},{"doc":"Retrieves the definitions of some or all of the tables in a given `Database`.","ref":"AWS.Glue.html#get_tables/3","title":"AWS.Glue.get_tables/3","type":"function"},{"doc":"Retrieves a list of tags associated with a resource.","ref":"AWS.Glue.html#get_tags/3","title":"AWS.Glue.get_tags/3","type":"function"},{"doc":"Retrieves the definition of a trigger.","ref":"AWS.Glue.html#get_trigger/3","title":"AWS.Glue.get_trigger/3","type":"function"},{"doc":"Gets all the triggers associated with a job.","ref":"AWS.Glue.html#get_triggers/3","title":"AWS.Glue.get_triggers/3","type":"function"},{"doc":"Retrieves partition metadata from the Data Catalog that contains unfiltered\nmetadata.\n\nFor IAM authorization, the public IAM action associated with this API is\n`glue:GetPartition`.","ref":"AWS.Glue.html#get_unfiltered_partition_metadata/3","title":"AWS.Glue.get_unfiltered_partition_metadata/3","type":"function"},{"doc":"Retrieves partition metadata from the Data Catalog that contains unfiltered\nmetadata.\n\nFor IAM authorization, the public IAM action associated with this API is\n`glue:GetPartitions`.","ref":"AWS.Glue.html#get_unfiltered_partitions_metadata/3","title":"AWS.Glue.get_unfiltered_partitions_metadata/3","type":"function"},{"doc":"Retrieves table metadata from the Data Catalog that contains unfiltered\nmetadata.\n\nFor IAM authorization, the public IAM action associated with this API is\n`glue:GetTable`.","ref":"AWS.Glue.html#get_unfiltered_table_metadata/3","title":"AWS.Glue.get_unfiltered_table_metadata/3","type":"function"},{"doc":"Retrieves a specified function definition from the Data Catalog.","ref":"AWS.Glue.html#get_user_defined_function/3","title":"AWS.Glue.get_user_defined_function/3","type":"function"},{"doc":"Retrieves multiple function definitions from the Data Catalog.","ref":"AWS.Glue.html#get_user_defined_functions/3","title":"AWS.Glue.get_user_defined_functions/3","type":"function"},{"doc":"Retrieves resource metadata for a workflow.","ref":"AWS.Glue.html#get_workflow/3","title":"AWS.Glue.get_workflow/3","type":"function"},{"doc":"Retrieves the metadata for a given workflow run.","ref":"AWS.Glue.html#get_workflow_run/3","title":"AWS.Glue.get_workflow_run/3","type":"function"},{"doc":"Retrieves the workflow run properties which were set during the run.","ref":"AWS.Glue.html#get_workflow_run_properties/3","title":"AWS.Glue.get_workflow_run_properties/3","type":"function"},{"doc":"Retrieves metadata for all runs of a given workflow.","ref":"AWS.Glue.html#get_workflow_runs/3","title":"AWS.Glue.get_workflow_runs/3","type":"function"},{"doc":"Imports an existing Amazon Athena Data Catalog to Glue.","ref":"AWS.Glue.html#import_catalog_to_glue/3","title":"AWS.Glue.import_catalog_to_glue/3","type":"function"},{"doc":"Lists all the blueprint names in an account.","ref":"AWS.Glue.html#list_blueprints/3","title":"AWS.Glue.list_blueprints/3","type":"function"},{"doc":"List all task runs for a particular account.","ref":"AWS.Glue.html#list_column_statistics_task_runs/3","title":"AWS.Glue.list_column_statistics_task_runs/3","type":"function"},{"doc":"Retrieves the names of all crawler resources in this Amazon Web Services\naccount, or the resources with the specified tag.\n\nThis operation allows you to see which resources are available in your account,\nand their names.\n\nThis operation takes the optional `Tags` field, which you can use as a filter on\nthe response so that tagged resources can be retrieved as a group. If you choose\nto use tags filtering, only resources with the tag are retrieved.","ref":"AWS.Glue.html#list_crawlers/3","title":"AWS.Glue.list_crawlers/3","type":"function"},{"doc":"Returns all the crawls of a specified crawler.\n\nReturns only the crawls that have occurred since the launch date of the crawler\nhistory feature, and only retains up to 12 months of crawls. Older crawls will\nnot be returned.\n\nYou may use this API to:\n\n  * Retrive all the crawls of a specified crawler.\n\n  * Retrieve all the crawls of a specified crawler within a limited\ncount.\n\n  * Retrieve all the crawls of a specified crawler in a specific time\nrange.\n\n  * Retrieve all the crawls of a specified crawler with a particular\nstate, crawl ID, or DPU hour value.","ref":"AWS.Glue.html#list_crawls/3","title":"AWS.Glue.list_crawls/3","type":"function"},{"doc":"Lists all the custom patterns that have been created.","ref":"AWS.Glue.html#list_custom_entity_types/3","title":"AWS.Glue.list_custom_entity_types/3","type":"function"},{"doc":"Returns all data quality execution results for your account.","ref":"AWS.Glue.html#list_data_quality_results/3","title":"AWS.Glue.list_data_quality_results/3","type":"function"},{"doc":"Lists the recommendation runs meeting the filter criteria.","ref":"AWS.Glue.html#list_data_quality_rule_recommendation_runs/3","title":"AWS.Glue.list_data_quality_rule_recommendation_runs/3","type":"function"},{"doc":"Lists all the runs meeting the filter criteria, where a ruleset is evaluated\nagainst a data source.","ref":"AWS.Glue.html#list_data_quality_ruleset_evaluation_runs/3","title":"AWS.Glue.list_data_quality_ruleset_evaluation_runs/3","type":"function"},{"doc":"Returns a paginated list of rulesets for the specified list of Glue tables.","ref":"AWS.Glue.html#list_data_quality_rulesets/3","title":"AWS.Glue.list_data_quality_rulesets/3","type":"function"},{"doc":"Retrieves the names of all `DevEndpoint` resources in this Amazon Web Services\naccount, or the resources with the specified tag.\n\nThis operation allows you to see which resources are available in your account,\nand their names.\n\nThis operation takes the optional `Tags` field, which you can use as a filter on\nthe response so that tagged resources can be retrieved as a group. If you choose\nto use tags filtering, only resources with the tag are retrieved.","ref":"AWS.Glue.html#list_dev_endpoints/3","title":"AWS.Glue.list_dev_endpoints/3","type":"function"},{"doc":"Retrieves the names of all job resources in this Amazon Web Services account, or\nthe resources with the specified tag.\n\nThis operation allows you to see which resources are available in your account,\nand their names.\n\nThis operation takes the optional `Tags` field, which you can use as a filter on\nthe response so that tagged resources can be retrieved as a group. If you choose\nto use tags filtering, only resources with the tag are retrieved.","ref":"AWS.Glue.html#list_jobs/3","title":"AWS.Glue.list_jobs/3","type":"function"},{"doc":"Retrieves a sortable, filterable list of existing Glue machine learning\ntransforms in this Amazon Web Services account, or the resources with the\nspecified tag.\n\nThis operation takes the optional `Tags` field, which you can use as a filter of\nthe responses so that tagged resources can be retrieved as a group. If you\nchoose to use tag filtering, only resources with the tags are retrieved.","ref":"AWS.Glue.html#list_ml_transforms/3","title":"AWS.Glue.list_ml_transforms/3","type":"function"},{"doc":"Returns a list of registries that you have created, with minimal registry\ninformation.\n\nRegistries in the `Deleting` status will not be included in the results. Empty\nresults will be returned if there are no registries available.","ref":"AWS.Glue.html#list_registries/3","title":"AWS.Glue.list_registries/3","type":"function"},{"doc":"Returns a list of schema versions that you have created, with minimal\ninformation.\n\nSchema versions in Deleted status will not be included in the results. Empty\nresults will be returned if there are no schema versions available.","ref":"AWS.Glue.html#list_schema_versions/3","title":"AWS.Glue.list_schema_versions/3","type":"function"},{"doc":"Returns a list of schemas with minimal details.\n\nSchemas in Deleting status will not be included in the results. Empty results\nwill be returned if there are no schemas available.\n\nWhen the `RegistryId` is not provided, all the schemas across registries will be\npart of the API response.","ref":"AWS.Glue.html#list_schemas/3","title":"AWS.Glue.list_schemas/3","type":"function"},{"doc":"Retrieve a list of sessions.","ref":"AWS.Glue.html#list_sessions/3","title":"AWS.Glue.list_sessions/3","type":"function"},{"doc":"Lists statements for the session.","ref":"AWS.Glue.html#list_statements/3","title":"AWS.Glue.list_statements/3","type":"function"},{"doc":"Lists the history of previous optimizer runs for a specific table.","ref":"AWS.Glue.html#list_table_optimizer_runs/3","title":"AWS.Glue.list_table_optimizer_runs/3","type":"function"},{"doc":"Retrieves the names of all trigger resources in this Amazon Web Services\naccount, or the resources with the specified tag.\n\nThis operation allows you to see which resources are available in your account,\nand their names.\n\nThis operation takes the optional `Tags` field, which you can use as a filter on\nthe response so that tagged resources can be retrieved as a group. If you choose\nto use tags filtering, only resources with the tag are retrieved.","ref":"AWS.Glue.html#list_triggers/3","title":"AWS.Glue.list_triggers/3","type":"function"},{"doc":"Lists names of workflows created in the account.","ref":"AWS.Glue.html#list_workflows/3","title":"AWS.Glue.list_workflows/3","type":"function"},{"doc":"","ref":"AWS.Glue.html#metadata/0","title":"AWS.Glue.metadata/0","type":"function"},{"doc":"Sets the security configuration for a specified catalog.\n\nAfter the configuration has been set, the specified encryption is applied to\nevery catalog write thereafter.","ref":"AWS.Glue.html#put_data_catalog_encryption_settings/3","title":"AWS.Glue.put_data_catalog_encryption_settings/3","type":"function"},{"doc":"Sets the Data Catalog resource policy for access control.","ref":"AWS.Glue.html#put_resource_policy/3","title":"AWS.Glue.put_resource_policy/3","type":"function"},{"doc":"Puts the metadata key value pair for a specified schema version ID.\n\nA maximum of 10 key value pairs will be allowed per schema version. They can be\nadded over one or more calls.","ref":"AWS.Glue.html#put_schema_version_metadata/3","title":"AWS.Glue.put_schema_version_metadata/3","type":"function"},{"doc":"Puts the specified workflow run properties for the given workflow run.\n\nIf a property already exists for the specified run, then it overrides the value\notherwise adds the property to existing properties.","ref":"AWS.Glue.html#put_workflow_run_properties/3","title":"AWS.Glue.put_workflow_run_properties/3","type":"function"},{"doc":"Queries for the schema version metadata information.","ref":"AWS.Glue.html#query_schema_version_metadata/3","title":"AWS.Glue.query_schema_version_metadata/3","type":"function"},{"doc":"Adds a new version to the existing schema.\n\nReturns an error if new version of schema does not meet the compatibility\nrequirements of the schema set. This API will not create a new schema set and\nwill return a 404 error if the schema set is not already present in the Schema\nRegistry.\n\nIf this is the first schema definition to be registered in the Schema Registry,\nthis API will store the schema version and return immediately. Otherwise, this\ncall has the potential to run longer than other operations due to compatibility\nmodes. You can call the `GetSchemaVersion` API with the `SchemaVersionId` to\ncheck compatibility modes.\n\nIf the same schema definition is already stored in Schema Registry as a version,\nthe schema ID of the existing schema is returned to the caller.","ref":"AWS.Glue.html#register_schema_version/3","title":"AWS.Glue.register_schema_version/3","type":"function"},{"doc":"Removes a key value pair from the schema version metadata for the specified\nschema version ID.","ref":"AWS.Glue.html#remove_schema_version_metadata/3","title":"AWS.Glue.remove_schema_version_metadata/3","type":"function"},{"doc":"Resets a bookmark entry.\n\nFor more information about enabling and using job bookmarks, see:\n\n  * [Tracking processed data using job bookmarks](https://docs.aws.amazon.com/glue/latest/dg/monitor-continuations.html)\n\n  * [Job parameters used by Glue](https://docs.aws.amazon.com/glue/latest/dg/aws-glue-programming-etl-glue-arguments.html)\n\n  * [Job structure](https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-job.html#aws-glue-api-jobs-job-Job)","ref":"AWS.Glue.html#reset_job_bookmark/3","title":"AWS.Glue.reset_job_bookmark/3","type":"function"},{"doc":"Restarts selected nodes of a previous partially completed workflow run and\nresumes the workflow run.\n\nThe selected nodes and all nodes that are downstream from the selected nodes are\nrun.","ref":"AWS.Glue.html#resume_workflow_run/3","title":"AWS.Glue.resume_workflow_run/3","type":"function"},{"doc":"Executes the statement.","ref":"AWS.Glue.html#run_statement/3","title":"AWS.Glue.run_statement/3","type":"function"},{"doc":"Searches a set of tables based on properties in the table metadata as well as on\nthe parent database.\n\nYou can search against text or filter conditions.\n\nYou can only get tables that you have access to based on the security policies\ndefined in Lake Formation. You need at least a read-only access to the table for\nit to be returned. If you do not have access to all the columns in the table,\nthese columns will not be searched against when returning the list of tables\nback to you. If you have access to the columns but not the data in the columns,\nthose columns and the associated metadata for those columns will be included in\nthe search.","ref":"AWS.Glue.html#search_tables/3","title":"AWS.Glue.search_tables/3","type":"function"},{"doc":"Starts a new run of the specified blueprint.","ref":"AWS.Glue.html#start_blueprint_run/3","title":"AWS.Glue.start_blueprint_run/3","type":"function"},{"doc":"Starts a column statistics task run, for a specified table and columns.","ref":"AWS.Glue.html#start_column_statistics_task_run/3","title":"AWS.Glue.start_column_statistics_task_run/3","type":"function"},{"doc":"Starts a crawl using the specified crawler, regardless of what is scheduled.\n\nIf the crawler is already running, returns a\n[CrawlerRunningException](https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-exceptions.html#aws-glue-api-exceptions-CrawlerRunningException).","ref":"AWS.Glue.html#start_crawler/3","title":"AWS.Glue.start_crawler/3","type":"function"},{"doc":"Changes the schedule state of the specified crawler to `SCHEDULED`, unless the\ncrawler is already running or the schedule state is already `SCHEDULED`.","ref":"AWS.Glue.html#start_crawler_schedule/3","title":"AWS.Glue.start_crawler_schedule/3","type":"function"},{"doc":"Starts a recommendation run that is used to generate rules when you don't know\nwhat rules to write.\n\nGlue Data Quality analyzes the data and comes up with recommendations for a\npotential ruleset. You can then triage the ruleset and modify the generated\nruleset to your liking.\n\nRecommendation runs are automatically deleted after 90 days.","ref":"AWS.Glue.html#start_data_quality_rule_recommendation_run/3","title":"AWS.Glue.start_data_quality_rule_recommendation_run/3","type":"function"},{"doc":"Once you have a ruleset definition (either recommended or your own), you call\nthis operation to evaluate the ruleset against a data source (Glue table).\n\nThe evaluation computes results which you can retrieve with the\n`GetDataQualityResult` API.","ref":"AWS.Glue.html#start_data_quality_ruleset_evaluation_run/3","title":"AWS.Glue.start_data_quality_ruleset_evaluation_run/3","type":"function"},{"doc":"Begins an asynchronous task to export all labeled data for a particular\ntransform.\n\nThis task is the only label-related API call that is not part of the typical\nactive learning workflow. You typically use `StartExportLabelsTaskRun` when you\nwant to work with all of your existing labels at the same time, such as when you\nwant to remove or change labels that were previously submitted as truth. This\nAPI operation accepts the `TransformId` whose labels you want to export and an\nAmazon Simple Storage Service (Amazon S3) path to export the labels to. The\noperation returns a `TaskRunId`. You can check on the status of your task run by\ncalling the `GetMLTaskRun` API.","ref":"AWS.Glue.html#start_export_labels_task_run/3","title":"AWS.Glue.start_export_labels_task_run/3","type":"function"},{"doc":"Enables you to provide additional labels (examples of truth) to be used to teach\nthe machine learning transform and improve its quality.\n\nThis API operation is generally used as part of the active learning workflow\nthat starts with the `StartMLLabelingSetGenerationTaskRun` call and that\nultimately results in improving the quality of your machine learning transform.\n\nAfter the `StartMLLabelingSetGenerationTaskRun` finishes, Glue machine learning\nwill have generated a series of questions for humans to answer. (Answering these\nquestions is often called 'labeling' in the machine learning workflows). In the\ncase of the `FindMatches` transform, these questions are of the form, “What is\nthe correct way to group these rows together into groups composed entirely of\nmatching records?” After the labeling process is finished, users upload their\nanswers/labels with a call to `StartImportLabelsTaskRun`. After\n`StartImportLabelsTaskRun` finishes, all future runs of the machine learning\ntransform use the new and improved labels and perform a higher-quality\ntransformation.\n\nBy default, `StartMLLabelingSetGenerationTaskRun` continually learns from and\ncombines all labels that you upload unless you set `Replace` to true. If you set\n`Replace` to true, `StartImportLabelsTaskRun` deletes and forgets all previously\nuploaded labels and learns only from the exact set that you upload. Replacing\nlabels can be helpful if you realize that you previously uploaded incorrect\nlabels, and you believe that they are having a negative effect on your transform\nquality.\n\nYou can check on the status of your task run by calling the `GetMLTaskRun`\noperation.","ref":"AWS.Glue.html#start_import_labels_task_run/3","title":"AWS.Glue.start_import_labels_task_run/3","type":"function"},{"doc":"Starts a job run using a job definition.","ref":"AWS.Glue.html#start_job_run/3","title":"AWS.Glue.start_job_run/3","type":"function"},{"doc":"Starts a task to estimate the quality of the transform.\n\nWhen you provide label sets as examples of truth, Glue machine learning uses\nsome of those examples to learn from them. The rest of the labels are used as a\ntest to estimate quality.\n\nReturns a unique identifier for the run. You can call `GetMLTaskRun` to get more\ninformation about the stats of the `EvaluationTaskRun`.","ref":"AWS.Glue.html#start_ml_evaluation_task_run/3","title":"AWS.Glue.start_ml_evaluation_task_run/3","type":"function"},{"doc":"Starts the active learning workflow for your machine learning transform to\nimprove the transform's quality by generating label sets and adding labels.\n\nWhen the `StartMLLabelingSetGenerationTaskRun` finishes, Glue will have\ngenerated a \"labeling set\" or a set of questions for humans to answer.\n\nIn the case of the `FindMatches` transform, these questions are of the form,\n“What is the correct way to group these rows together into groups composed\nentirely of matching records?”\n\nAfter the labeling process is finished, you can upload your labels with a call\nto `StartImportLabelsTaskRun`. After `StartImportLabelsTaskRun` finishes, all\nfuture runs of the machine learning transform will use the new and improved\nlabels and perform a higher-quality transformation.","ref":"AWS.Glue.html#start_ml_labeling_set_generation_task_run/3","title":"AWS.Glue.start_ml_labeling_set_generation_task_run/3","type":"function"},{"doc":"Starts an existing trigger.\n\nSee [Triggering Jobs](https://docs.aws.amazon.com/glue/latest/dg/trigger-job.html) for\ninformation about how different types of trigger are started.","ref":"AWS.Glue.html#start_trigger/3","title":"AWS.Glue.start_trigger/3","type":"function"},{"doc":"Starts a new run of the specified workflow.","ref":"AWS.Glue.html#start_workflow_run/3","title":"AWS.Glue.start_workflow_run/3","type":"function"},{"doc":"Stops a task run for the specified table.","ref":"AWS.Glue.html#stop_column_statistics_task_run/3","title":"AWS.Glue.stop_column_statistics_task_run/3","type":"function"},{"doc":"If the specified crawler is running, stops the crawl.","ref":"AWS.Glue.html#stop_crawler/3","title":"AWS.Glue.stop_crawler/3","type":"function"},{"doc":"Sets the schedule state of the specified crawler to `NOT_SCHEDULED`, but does\nnot stop the crawler if it is already running.","ref":"AWS.Glue.html#stop_crawler_schedule/3","title":"AWS.Glue.stop_crawler_schedule/3","type":"function"},{"doc":"Stops the session.","ref":"AWS.Glue.html#stop_session/3","title":"AWS.Glue.stop_session/3","type":"function"},{"doc":"Stops a specified trigger.","ref":"AWS.Glue.html#stop_trigger/3","title":"AWS.Glue.stop_trigger/3","type":"function"},{"doc":"Stops the execution of the specified workflow run.","ref":"AWS.Glue.html#stop_workflow_run/3","title":"AWS.Glue.stop_workflow_run/3","type":"function"},{"doc":"Adds tags to a resource.\n\nA tag is a label you can assign to an Amazon Web Services resource. In Glue, you\ncan tag only certain resources. For information about what resources you can\ntag, see [Amazon Web Services Tags in Glue](https://docs.aws.amazon.com/glue/latest/dg/monitor-tags.html).","ref":"AWS.Glue.html#tag_resource/3","title":"AWS.Glue.tag_resource/3","type":"function"},{"doc":"Removes tags from a resource.","ref":"AWS.Glue.html#untag_resource/3","title":"AWS.Glue.untag_resource/3","type":"function"},{"doc":"Updates a registered blueprint.","ref":"AWS.Glue.html#update_blueprint/3","title":"AWS.Glue.update_blueprint/3","type":"function"},{"doc":"Modifies an existing classifier (a `GrokClassifier`, an `XMLClassifier`, a\n`JsonClassifier`, or a `CsvClassifier`, depending on which field is present).","ref":"AWS.Glue.html#update_classifier/3","title":"AWS.Glue.update_classifier/3","type":"function"},{"doc":"Creates or updates partition statistics of columns.\n\nThe Identity and Access Management (IAM) permission required for this operation\nis `UpdatePartition`.","ref":"AWS.Glue.html#update_column_statistics_for_partition/3","title":"AWS.Glue.update_column_statistics_for_partition/3","type":"function"},{"doc":"Creates or updates table statistics of columns.\n\nThe Identity and Access Management (IAM) permission required for this operation\nis `UpdateTable`.","ref":"AWS.Glue.html#update_column_statistics_for_table/3","title":"AWS.Glue.update_column_statistics_for_table/3","type":"function"},{"doc":"Updates a connection definition in the Data Catalog.","ref":"AWS.Glue.html#update_connection/3","title":"AWS.Glue.update_connection/3","type":"function"},{"doc":"Updates a crawler.\n\nIf a crawler is running, you must stop it using `StopCrawler` before updating\nit.","ref":"AWS.Glue.html#update_crawler/3","title":"AWS.Glue.update_crawler/3","type":"function"},{"doc":"Updates the schedule of a crawler using a `cron` expression.","ref":"AWS.Glue.html#update_crawler_schedule/3","title":"AWS.Glue.update_crawler_schedule/3","type":"function"},{"doc":"Updates the specified data quality ruleset.","ref":"AWS.Glue.html#update_data_quality_ruleset/3","title":"AWS.Glue.update_data_quality_ruleset/3","type":"function"},{"doc":"Updates an existing database definition in a Data Catalog.","ref":"AWS.Glue.html#update_database/3","title":"AWS.Glue.update_database/3","type":"function"},{"doc":"Updates a specified development endpoint.","ref":"AWS.Glue.html#update_dev_endpoint/3","title":"AWS.Glue.update_dev_endpoint/3","type":"function"},{"doc":"Updates an existing job definition.\n\nThe previous job definition is completely overwritten by this information.","ref":"AWS.Glue.html#update_job/3","title":"AWS.Glue.update_job/3","type":"function"},{"doc":"Synchronizes a job from the source control repository.\n\nThis operation takes the job artifacts that are located in the remote repository\nand updates the Glue internal stores with these artifacts.\n\nThis API supports optional parameters which take in the repository information.","ref":"AWS.Glue.html#update_job_from_source_control/3","title":"AWS.Glue.update_job_from_source_control/3","type":"function"},{"doc":"Updates an existing machine learning transform.\n\nCall this operation to tune the algorithm parameters to achieve better results.\n\nAfter calling this operation, you can call the `StartMLEvaluationTaskRun`\noperation to assess how well your new parameters achieved your goals (such as\nimproving the quality of your machine learning transform, or making it more\ncost-effective).","ref":"AWS.Glue.html#update_ml_transform/3","title":"AWS.Glue.update_ml_transform/3","type":"function"},{"doc":"Updates a partition.","ref":"AWS.Glue.html#update_partition/3","title":"AWS.Glue.update_partition/3","type":"function"},{"doc":"Updates an existing registry which is used to hold a collection of schemas.\n\nThe updated properties relate to the registry, and do not modify any of the\nschemas within the registry.","ref":"AWS.Glue.html#update_registry/3","title":"AWS.Glue.update_registry/3","type":"function"},{"doc":"Updates the description, compatibility setting, or version checkpoint for a\nschema set.\n\nFor updating the compatibility setting, the call will not validate compatibility\nfor the entire set of schema versions with the new compatibility setting. If the\nvalue for `Compatibility` is provided, the `VersionNumber` (a checkpoint) is\nalso required. The API will validate the checkpoint version number for\nconsistency.\n\nIf the value for the `VersionNumber` (checkpoint) is provided, `Compatibility`\nis optional and this can be used to set/reset a checkpoint for the schema.\n\nThis update will happen only if the schema is in the AVAILABLE state.","ref":"AWS.Glue.html#update_schema/3","title":"AWS.Glue.update_schema/3","type":"function"},{"doc":"Synchronizes a job to the source control repository.\n\nThis operation takes the job artifacts from the Glue internal stores and makes a\ncommit to the remote repository that is configured on the job.\n\nThis API supports optional parameters which take in the repository information.","ref":"AWS.Glue.html#update_source_control_from_job/3","title":"AWS.Glue.update_source_control_from_job/3","type":"function"},{"doc":"Updates a metadata table in the Data Catalog.","ref":"AWS.Glue.html#update_table/3","title":"AWS.Glue.update_table/3","type":"function"},{"doc":"Updates the configuration for an existing table optimizer.","ref":"AWS.Glue.html#update_table_optimizer/3","title":"AWS.Glue.update_table_optimizer/3","type":"function"},{"doc":"Updates a trigger definition.","ref":"AWS.Glue.html#update_trigger/3","title":"AWS.Glue.update_trigger/3","type":"function"},{"doc":"Updates an existing function definition in the Data Catalog.","ref":"AWS.Glue.html#update_user_defined_function/3","title":"AWS.Glue.update_user_defined_function/3","type":"function"},{"doc":"Updates an existing workflow.","ref":"AWS.Glue.html#update_workflow/3","title":"AWS.Glue.update_workflow/3","type":"function"},{"doc":"Amazon Managed Grafana is a fully managed and secure data visualization service\nthat you can use to instantly query, correlate, and visualize operational\nmetrics, logs, and traces from multiple sources.\n\nAmazon Managed Grafana makes it easy to deploy, operate, and scale Grafana, a\nwidely deployed data visualization tool that is popular for its extensible data\nsupport.\n\nWith Amazon Managed Grafana, you create logically isolated Grafana servers\ncalled *workspaces*. In a workspace, you can create Grafana dashboards and\nvisualizations to analyze your metrics, logs, and traces without having to\nbuild, package, or deploy any hardware to run Grafana servers.","ref":"AWS.Grafana.html","title":"AWS.Grafana","type":"module"},{"doc":"Assigns a Grafana Enterprise license to a workspace.\n\nUpgrading to Grafana Enterprise incurs additional fees. For more information,\nsee [Upgrade a workspace to Grafana Enterprise](https://docs.aws.amazon.com/grafana/latest/userguide/upgrade-to-Grafana-Enterprise.html).","ref":"AWS.Grafana.html#associate_license/5","title":"AWS.Grafana.associate_license/5","type":"function"},{"doc":"Creates a *workspace*.\n\nIn a workspace, you can create Grafana dashboards and visualizations to analyze\nyour metrics, logs, and traces. You don't have to build, package, or deploy any\nhardware to run the Grafana server.\n\nDon't use `CreateWorkspace` to modify an existing workspace. Instead, use\n[UpdateWorkspace](https://docs.aws.amazon.com/grafana/latest/APIReference/API_UpdateWorkspace.html).","ref":"AWS.Grafana.html#create_workspace/3","title":"AWS.Grafana.create_workspace/3","type":"function"},{"doc":"Creates a Grafana API key for the workspace.\n\nThis key can be used to authenticate requests sent to the workspace's HTTP API.\nSee\n[https://docs.aws.amazon.com/grafana/latest/userguide/Using-Grafana-APIs.html](https://docs.aws.amazon.com/grafana/latest/userguide/Using-Grafana-APIs.html)\nfor available APIs and example requests.","ref":"AWS.Grafana.html#create_workspace_api_key/4","title":"AWS.Grafana.create_workspace_api_key/4","type":"function"},{"doc":"Deletes an Amazon Managed Grafana workspace.","ref":"AWS.Grafana.html#delete_workspace/4","title":"AWS.Grafana.delete_workspace/4","type":"function"},{"doc":"Deletes a Grafana API key for the workspace.","ref":"AWS.Grafana.html#delete_workspace_api_key/5","title":"AWS.Grafana.delete_workspace_api_key/5","type":"function"},{"doc":"Displays information about one Amazon Managed Grafana workspace.","ref":"AWS.Grafana.html#describe_workspace/3","title":"AWS.Grafana.describe_workspace/3","type":"function"},{"doc":"Displays information about the authentication methods used in one Amazon Managed\nGrafana workspace.","ref":"AWS.Grafana.html#describe_workspace_authentication/3","title":"AWS.Grafana.describe_workspace_authentication/3","type":"function"},{"doc":"Gets the current configuration string for the given workspace.","ref":"AWS.Grafana.html#describe_workspace_configuration/3","title":"AWS.Grafana.describe_workspace_configuration/3","type":"function"},{"doc":"Removes the Grafana Enterprise license from a workspace.","ref":"AWS.Grafana.html#disassociate_license/5","title":"AWS.Grafana.disassociate_license/5","type":"function"},{"doc":"Lists the users and groups who have the Grafana `Admin` and `Editor` roles in\nthis workspace.\n\nIf you use this operation without specifying `userId` or `groupId`, the\noperation returns the roles of all users and groups. If you specify a `userId`\nor a `groupId`, only the roles for that user or group are returned. If you do\nthis, you can specify only one `userId` or one `groupId`.","ref":"AWS.Grafana.html#list_permissions/8","title":"AWS.Grafana.list_permissions/8","type":"function"},{"doc":"The `ListTagsForResource` operation returns the tags that are associated with\nthe Amazon Managed Service for Grafana resource specified by the `resourceArn`.\n\nCurrently, the only resource that can be tagged is a workspace.","ref":"AWS.Grafana.html#list_tags_for_resource/3","title":"AWS.Grafana.list_tags_for_resource/3","type":"function"},{"doc":"Lists available versions of Grafana.\n\nThese are available when calling `CreateWorkspace`. Optionally, include a\nworkspace to list the versions to which it can be upgraded.","ref":"AWS.Grafana.html#list_versions/5","title":"AWS.Grafana.list_versions/5","type":"function"},{"doc":"Returns a list of Amazon Managed Grafana workspaces in the account, with some\ninformation about each workspace.\n\nFor more complete information about one workspace, use\n[DescribeWorkspace](https://docs.aws.amazon.com/AAMG/latest/APIReference/API_DescribeWorkspace.html).","ref":"AWS.Grafana.html#list_workspaces/4","title":"AWS.Grafana.list_workspaces/4","type":"function"},{"doc":"","ref":"AWS.Grafana.html#metadata/0","title":"AWS.Grafana.metadata/0","type":"function"},{"doc":"The `TagResource` operation associates tags with an Amazon Managed Grafana\nresource.\n\nCurrently, the only resource that can be tagged is workspaces.\n\nIf you specify a new tag key for the resource, this tag is appended to the list\nof tags associated with the resource. If you specify a tag key that is already\nassociated with the resource, the new tag value that you specify replaces the\nprevious value for that tag.","ref":"AWS.Grafana.html#tag_resource/4","title":"AWS.Grafana.tag_resource/4","type":"function"},{"doc":"The `UntagResource` operation removes the association of the tag with the Amazon\nManaged Grafana resource.","ref":"AWS.Grafana.html#untag_resource/4","title":"AWS.Grafana.untag_resource/4","type":"function"},{"doc":"Updates which users in a workspace have the Grafana `Admin` or `Editor` roles.","ref":"AWS.Grafana.html#update_permissions/4","title":"AWS.Grafana.update_permissions/4","type":"function"},{"doc":"Modifies an existing Amazon Managed Grafana workspace.\n\nIf you use this operation and omit any optional parameters, the existing values\nof those parameters are not changed.\n\nTo modify the user authentication methods that the workspace uses, such as SAML\nor IAM Identity Center, use\n[UpdateWorkspaceAuthentication](https://docs.aws.amazon.com/grafana/latest/APIReference/API_UpdateWorkspaceAuthentication.html).  To modify which users in the workspace have the `Admin` and `Editor` Grafana\nroles, use\n[UpdatePermissions](https://docs.aws.amazon.com/grafana/latest/APIReference/API_UpdatePermissions.html).","ref":"AWS.Grafana.html#update_workspace/4","title":"AWS.Grafana.update_workspace/4","type":"function"},{"doc":"Use this operation to define the identity provider (IdP) that this workspace\nauthenticates users from, using SAML.\n\nYou can also map SAML assertion attributes to workspace user information and\ndefine which groups in the assertion attribute are to have the `Admin` and\n`Editor` roles in the workspace.\n\nChanges to the authentication method for a workspace may take a few minutes to\ntake effect.","ref":"AWS.Grafana.html#update_workspace_authentication/4","title":"AWS.Grafana.update_workspace_authentication/4","type":"function"},{"doc":"Updates the configuration string for the given workspace","ref":"AWS.Grafana.html#update_workspace_configuration/4","title":"AWS.Grafana.update_workspace_configuration/4","type":"function"},{"doc":"AWS IoT Greengrass seamlessly extends AWS onto physical devices so they can act\nlocally on the data they generate, while still using the cloud for management,\nanalytics, and durable storage.\n\nAWS IoT Greengrass ensures your devices can respond quickly to local events and\noperate with intermittent connectivity. AWS IoT Greengrass minimizes the cost of\ntransmitting data to the cloud by allowing you to author AWS Lambda functions\nthat execute locally.","ref":"AWS.Greengrass.html","title":"AWS.Greengrass","type":"module"},{"doc":"Associates a role with a group.\n\nYour Greengrass core will use the role to access AWS cloud services. The role's\npermissions should allow Greengrass core Lambda functions to perform actions\nagainst the cloud.","ref":"AWS.Greengrass.html#associate_role_to_group/4","title":"AWS.Greengrass.associate_role_to_group/4","type":"function"},{"doc":"Associates a role with your account.\n\nAWS IoT Greengrass will use the role to access your Lambda functions and AWS IoT\nresources. This is necessary for deployments to succeed. The role must have at\nleast minimum permissions in the policy\n''AWSGreengrassResourceAccessRolePolicy''.","ref":"AWS.Greengrass.html#associate_service_role_to_account/3","title":"AWS.Greengrass.associate_service_role_to_account/3","type":"function"},{"doc":"Creates a connector definition.\n\nYou may provide the initial version of the connector definition now or use\n''CreateConnectorDefinitionVersion'' at a later time.","ref":"AWS.Greengrass.html#create_connector_definition/3","title":"AWS.Greengrass.create_connector_definition/3","type":"function"},{"doc":"Creates a version of a connector definition which has already been defined.","ref":"AWS.Greengrass.html#create_connector_definition_version/4","title":"AWS.Greengrass.create_connector_definition_version/4","type":"function"},{"doc":"Creates a core definition.\n\nYou may provide the initial version of the core definition now or use\n''CreateCoreDefinitionVersion'' at a later time. Greengrass groups must each\ncontain exactly one Greengrass core.","ref":"AWS.Greengrass.html#create_core_definition/3","title":"AWS.Greengrass.create_core_definition/3","type":"function"},{"doc":"Creates a version of a core definition that has already been defined.\n\nGreengrass groups must each contain exactly one Greengrass core.","ref":"AWS.Greengrass.html#create_core_definition_version/4","title":"AWS.Greengrass.create_core_definition_version/4","type":"function"},{"doc":"Creates a deployment.\n\n''CreateDeployment'' requests are idempotent with respect to the\n''X-Amzn-Client-Token'' token and the request parameters.","ref":"AWS.Greengrass.html#create_deployment/4","title":"AWS.Greengrass.create_deployment/4","type":"function"},{"doc":"Creates a device definition.\n\nYou may provide the initial version of the device definition now or use\n''CreateDeviceDefinitionVersion'' at a later time.","ref":"AWS.Greengrass.html#create_device_definition/3","title":"AWS.Greengrass.create_device_definition/3","type":"function"},{"doc":"Creates a version of a device definition that has already been defined.","ref":"AWS.Greengrass.html#create_device_definition_version/4","title":"AWS.Greengrass.create_device_definition_version/4","type":"function"},{"doc":"Creates a Lambda function definition which contains a list of Lambda functions\nand their configurations to be used in a group.\n\nYou can create an initial version of the definition by providing a list of\nLambda functions and their configurations now, or use\n''CreateFunctionDefinitionVersion'' later.","ref":"AWS.Greengrass.html#create_function_definition/3","title":"AWS.Greengrass.create_function_definition/3","type":"function"},{"doc":"Creates a version of a Lambda function definition that has already been defined.","ref":"AWS.Greengrass.html#create_function_definition_version/4","title":"AWS.Greengrass.create_function_definition_version/4","type":"function"},{"doc":"Creates a group.\n\nYou may provide the initial version of the group or use ''CreateGroupVersion''\nat a later time. Tip: You can use the ''gg_group_setup'' package\n(https://github.com/awslabs/aws-greengrass-group-setup) as a library or\ncommand-line application to create and deploy Greengrass groups.","ref":"AWS.Greengrass.html#create_group/3","title":"AWS.Greengrass.create_group/3","type":"function"},{"doc":"Creates a CA for the group.\n\nIf a CA already exists, it will rotate the existing CA.","ref":"AWS.Greengrass.html#create_group_certificate_authority/4","title":"AWS.Greengrass.create_group_certificate_authority/4","type":"function"},{"doc":"Creates a version of a group which has already been defined.","ref":"AWS.Greengrass.html#create_group_version/4","title":"AWS.Greengrass.create_group_version/4","type":"function"},{"doc":"Creates a logger definition.\n\nYou may provide the initial version of the logger definition now or use\n''CreateLoggerDefinitionVersion'' at a later time.","ref":"AWS.Greengrass.html#create_logger_definition/3","title":"AWS.Greengrass.create_logger_definition/3","type":"function"},{"doc":"Creates a version of a logger definition that has already been defined.","ref":"AWS.Greengrass.html#create_logger_definition_version/4","title":"AWS.Greengrass.create_logger_definition_version/4","type":"function"},{"doc":"Creates a resource definition which contains a list of resources to be used in a\ngroup.\n\nYou can create an initial version of the definition by providing a list of\nresources now, or use ''CreateResourceDefinitionVersion'' later.","ref":"AWS.Greengrass.html#create_resource_definition/3","title":"AWS.Greengrass.create_resource_definition/3","type":"function"},{"doc":"Creates a version of a resource definition that has already been defined.","ref":"AWS.Greengrass.html#create_resource_definition_version/4","title":"AWS.Greengrass.create_resource_definition_version/4","type":"function"},{"doc":"Creates a software update for a core or group of cores (specified as an IoT\nthing group.) Use this to update the OTA Agent as well as the Greengrass core\nsoftware.\n\nIt makes use of the IoT Jobs feature which provides additional commands to\nmanage a Greengrass core software update job.","ref":"AWS.Greengrass.html#create_software_update_job/3","title":"AWS.Greengrass.create_software_update_job/3","type":"function"},{"doc":"Creates a subscription definition.\n\nYou may provide the initial version of the subscription definition now or use\n''CreateSubscriptionDefinitionVersion'' at a later time.","ref":"AWS.Greengrass.html#create_subscription_definition/3","title":"AWS.Greengrass.create_subscription_definition/3","type":"function"},{"doc":"Creates a version of a subscription definition which has already been defined.","ref":"AWS.Greengrass.html#create_subscription_definition_version/4","title":"AWS.Greengrass.create_subscription_definition_version/4","type":"function"},{"doc":"Deletes a connector definition.","ref":"AWS.Greengrass.html#delete_connector_definition/4","title":"AWS.Greengrass.delete_connector_definition/4","type":"function"},{"doc":"Deletes a core definition.","ref":"AWS.Greengrass.html#delete_core_definition/4","title":"AWS.Greengrass.delete_core_definition/4","type":"function"},{"doc":"Deletes a device definition.","ref":"AWS.Greengrass.html#delete_device_definition/4","title":"AWS.Greengrass.delete_device_definition/4","type":"function"},{"doc":"Deletes a Lambda function definition.","ref":"AWS.Greengrass.html#delete_function_definition/4","title":"AWS.Greengrass.delete_function_definition/4","type":"function"},{"doc":"Deletes a group.","ref":"AWS.Greengrass.html#delete_group/4","title":"AWS.Greengrass.delete_group/4","type":"function"},{"doc":"Deletes a logger definition.","ref":"AWS.Greengrass.html#delete_logger_definition/4","title":"AWS.Greengrass.delete_logger_definition/4","type":"function"},{"doc":"Deletes a resource definition.","ref":"AWS.Greengrass.html#delete_resource_definition/4","title":"AWS.Greengrass.delete_resource_definition/4","type":"function"},{"doc":"Deletes a subscription definition.","ref":"AWS.Greengrass.html#delete_subscription_definition/4","title":"AWS.Greengrass.delete_subscription_definition/4","type":"function"},{"doc":"Disassociates the role from a group.","ref":"AWS.Greengrass.html#disassociate_role_from_group/4","title":"AWS.Greengrass.disassociate_role_from_group/4","type":"function"},{"doc":"Disassociates the service role from your account.\n\nWithout a service role, deployments will not work.","ref":"AWS.Greengrass.html#disassociate_service_role_from_account/3","title":"AWS.Greengrass.disassociate_service_role_from_account/3","type":"function"},{"doc":"Retrieves the role associated with a particular group.","ref":"AWS.Greengrass.html#get_associated_role/3","title":"AWS.Greengrass.get_associated_role/3","type":"function"},{"doc":"Returns the status of a bulk deployment.","ref":"AWS.Greengrass.html#get_bulk_deployment_status/3","title":"AWS.Greengrass.get_bulk_deployment_status/3","type":"function"},{"doc":"Retrieves the connectivity information for a core.","ref":"AWS.Greengrass.html#get_connectivity_info/3","title":"AWS.Greengrass.get_connectivity_info/3","type":"function"},{"doc":"Retrieves information about a connector definition.","ref":"AWS.Greengrass.html#get_connector_definition/3","title":"AWS.Greengrass.get_connector_definition/3","type":"function"},{"doc":"Retrieves information about a connector definition version, including the\nconnectors that the version contains.\n\nConnectors are prebuilt modules that interact with local infrastructure, device\nprotocols, AWS, and other cloud services.","ref":"AWS.Greengrass.html#get_connector_definition_version/5","title":"AWS.Greengrass.get_connector_definition_version/5","type":"function"},{"doc":"Retrieves information about a core definition version.","ref":"AWS.Greengrass.html#get_core_definition/3","title":"AWS.Greengrass.get_core_definition/3","type":"function"},{"doc":"Retrieves information about a core definition version.","ref":"AWS.Greengrass.html#get_core_definition_version/4","title":"AWS.Greengrass.get_core_definition_version/4","type":"function"},{"doc":"Returns the status of a deployment.","ref":"AWS.Greengrass.html#get_deployment_status/4","title":"AWS.Greengrass.get_deployment_status/4","type":"function"},{"doc":"Retrieves information about a device definition.","ref":"AWS.Greengrass.html#get_device_definition/3","title":"AWS.Greengrass.get_device_definition/3","type":"function"},{"doc":"Retrieves information about a device definition version.","ref":"AWS.Greengrass.html#get_device_definition_version/5","title":"AWS.Greengrass.get_device_definition_version/5","type":"function"},{"doc":"Retrieves information about a Lambda function definition, including its creation\ntime and latest version.","ref":"AWS.Greengrass.html#get_function_definition/3","title":"AWS.Greengrass.get_function_definition/3","type":"function"},{"doc":"Retrieves information about a Lambda function definition version, including\nwhich Lambda functions are included in the version and their configurations.","ref":"AWS.Greengrass.html#get_function_definition_version/5","title":"AWS.Greengrass.get_function_definition_version/5","type":"function"},{"doc":"Retrieves information about a group.","ref":"AWS.Greengrass.html#get_group/3","title":"AWS.Greengrass.get_group/3","type":"function"},{"doc":"Retreives the CA associated with a group.\n\nReturns the public key of the CA.","ref":"AWS.Greengrass.html#get_group_certificate_authority/4","title":"AWS.Greengrass.get_group_certificate_authority/4","type":"function"},{"doc":"Retrieves the current configuration for the CA used by the group.","ref":"AWS.Greengrass.html#get_group_certificate_configuration/3","title":"AWS.Greengrass.get_group_certificate_configuration/3","type":"function"},{"doc":"Retrieves information about a group version.","ref":"AWS.Greengrass.html#get_group_version/4","title":"AWS.Greengrass.get_group_version/4","type":"function"},{"doc":"Retrieves information about a logger definition.","ref":"AWS.Greengrass.html#get_logger_definition/3","title":"AWS.Greengrass.get_logger_definition/3","type":"function"},{"doc":"Retrieves information about a logger definition version.","ref":"AWS.Greengrass.html#get_logger_definition_version/5","title":"AWS.Greengrass.get_logger_definition_version/5","type":"function"},{"doc":"Retrieves information about a resource definition, including its creation time\nand latest version.","ref":"AWS.Greengrass.html#get_resource_definition/3","title":"AWS.Greengrass.get_resource_definition/3","type":"function"},{"doc":"Retrieves information about a resource definition version, including which\nresources are included in the version.","ref":"AWS.Greengrass.html#get_resource_definition_version/4","title":"AWS.Greengrass.get_resource_definition_version/4","type":"function"},{"doc":"Retrieves the service role that is attached to your account.","ref":"AWS.Greengrass.html#get_service_role_for_account/2","title":"AWS.Greengrass.get_service_role_for_account/2","type":"function"},{"doc":"Retrieves information about a subscription definition.","ref":"AWS.Greengrass.html#get_subscription_definition/3","title":"AWS.Greengrass.get_subscription_definition/3","type":"function"},{"doc":"Retrieves information about a subscription definition version.","ref":"AWS.Greengrass.html#get_subscription_definition_version/5","title":"AWS.Greengrass.get_subscription_definition_version/5","type":"function"},{"doc":"Get the runtime configuration of a thing.","ref":"AWS.Greengrass.html#get_thing_runtime_configuration/3","title":"AWS.Greengrass.get_thing_runtime_configuration/3","type":"function"},{"doc":"Gets a paginated list of the deployments that have been started in a bulk\ndeployment operation, and their current deployment status.","ref":"AWS.Greengrass.html#list_bulk_deployment_detailed_reports/5","title":"AWS.Greengrass.list_bulk_deployment_detailed_reports/5","type":"function"},{"doc":"Returns a list of bulk deployments.","ref":"AWS.Greengrass.html#list_bulk_deployments/4","title":"AWS.Greengrass.list_bulk_deployments/4","type":"function"},{"doc":"Lists the versions of a connector definition, which are containers for\nconnectors.\n\nConnectors run on the Greengrass core and contain built-in integration with\nlocal infrastructure, device protocols, AWS, and other cloud services.","ref":"AWS.Greengrass.html#list_connector_definition_versions/5","title":"AWS.Greengrass.list_connector_definition_versions/5","type":"function"},{"doc":"Retrieves a list of connector definitions.","ref":"AWS.Greengrass.html#list_connector_definitions/4","title":"AWS.Greengrass.list_connector_definitions/4","type":"function"},{"doc":"Lists the versions of a core definition.","ref":"AWS.Greengrass.html#list_core_definition_versions/5","title":"AWS.Greengrass.list_core_definition_versions/5","type":"function"},{"doc":"Retrieves a list of core definitions.","ref":"AWS.Greengrass.html#list_core_definitions/4","title":"AWS.Greengrass.list_core_definitions/4","type":"function"},{"doc":"Returns a history of deployments for the group.","ref":"AWS.Greengrass.html#list_deployments/5","title":"AWS.Greengrass.list_deployments/5","type":"function"},{"doc":"Lists the versions of a device definition.","ref":"AWS.Greengrass.html#list_device_definition_versions/5","title":"AWS.Greengrass.list_device_definition_versions/5","type":"function"},{"doc":"Retrieves a list of device definitions.","ref":"AWS.Greengrass.html#list_device_definitions/4","title":"AWS.Greengrass.list_device_definitions/4","type":"function"},{"doc":"Lists the versions of a Lambda function definition.","ref":"AWS.Greengrass.html#list_function_definition_versions/5","title":"AWS.Greengrass.list_function_definition_versions/5","type":"function"},{"doc":"Retrieves a list of Lambda function definitions.","ref":"AWS.Greengrass.html#list_function_definitions/4","title":"AWS.Greengrass.list_function_definitions/4","type":"function"},{"doc":"Retrieves the current CAs for a group.","ref":"AWS.Greengrass.html#list_group_certificate_authorities/3","title":"AWS.Greengrass.list_group_certificate_authorities/3","type":"function"},{"doc":"Lists the versions of a group.","ref":"AWS.Greengrass.html#list_group_versions/5","title":"AWS.Greengrass.list_group_versions/5","type":"function"},{"doc":"Retrieves a list of groups.","ref":"AWS.Greengrass.html#list_groups/4","title":"AWS.Greengrass.list_groups/4","type":"function"},{"doc":"Lists the versions of a logger definition.","ref":"AWS.Greengrass.html#list_logger_definition_versions/5","title":"AWS.Greengrass.list_logger_definition_versions/5","type":"function"},{"doc":"Retrieves a list of logger definitions.","ref":"AWS.Greengrass.html#list_logger_definitions/4","title":"AWS.Greengrass.list_logger_definitions/4","type":"function"},{"doc":"Lists the versions of a resource definition.","ref":"AWS.Greengrass.html#list_resource_definition_versions/5","title":"AWS.Greengrass.list_resource_definition_versions/5","type":"function"},{"doc":"Retrieves a list of resource definitions.","ref":"AWS.Greengrass.html#list_resource_definitions/4","title":"AWS.Greengrass.list_resource_definitions/4","type":"function"},{"doc":"Lists the versions of a subscription definition.","ref":"AWS.Greengrass.html#list_subscription_definition_versions/5","title":"AWS.Greengrass.list_subscription_definition_versions/5","type":"function"},{"doc":"Retrieves a list of subscription definitions.","ref":"AWS.Greengrass.html#list_subscription_definitions/4","title":"AWS.Greengrass.list_subscription_definitions/4","type":"function"},{"doc":"Retrieves a list of resource tags for a resource arn.","ref":"AWS.Greengrass.html#list_tags_for_resource/3","title":"AWS.Greengrass.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.Greengrass.html#metadata/0","title":"AWS.Greengrass.metadata/0","type":"function"},{"doc":"Resets a group's deployments.","ref":"AWS.Greengrass.html#reset_deployments/4","title":"AWS.Greengrass.reset_deployments/4","type":"function"},{"doc":"Deploys multiple groups in one operation.\n\nThis action starts the bulk deployment of a specified set of group versions.\nEach group version deployment will be triggered with an adaptive rate that has a\nfixed upper limit. We recommend that you include an ''X-Amzn-Client-Token''\ntoken in every ''StartBulkDeployment'' request. These requests are idempotent\nwith respect to the token and the request parameters.","ref":"AWS.Greengrass.html#start_bulk_deployment/3","title":"AWS.Greengrass.start_bulk_deployment/3","type":"function"},{"doc":"Stops the execution of a bulk deployment.\n\nThis action returns a status of ''Stopping'' until the deployment is stopped.\nYou cannot start a new bulk deployment while a previous deployment is in the\n''Stopping'' state. This action doesn't rollback completed deployments or cancel\npending deployments.","ref":"AWS.Greengrass.html#stop_bulk_deployment/4","title":"AWS.Greengrass.stop_bulk_deployment/4","type":"function"},{"doc":"Adds tags to a Greengrass resource.\n\nValid resources are 'Group', 'ConnectorDefinition', 'CoreDefinition',\n'DeviceDefinition', 'FunctionDefinition', 'LoggerDefinition',\n'SubscriptionDefinition', 'ResourceDefinition', and 'BulkDeployment'.","ref":"AWS.Greengrass.html#tag_resource/4","title":"AWS.Greengrass.tag_resource/4","type":"function"},{"doc":"Remove resource tags from a Greengrass Resource.","ref":"AWS.Greengrass.html#untag_resource/4","title":"AWS.Greengrass.untag_resource/4","type":"function"},{"doc":"Updates the connectivity information for the core.\n\nAny devices that belong to the group which has this core will receive this\ninformation in order to find the location of the core and connect to it.","ref":"AWS.Greengrass.html#update_connectivity_info/4","title":"AWS.Greengrass.update_connectivity_info/4","type":"function"},{"doc":"Updates a connector definition.","ref":"AWS.Greengrass.html#update_connector_definition/4","title":"AWS.Greengrass.update_connector_definition/4","type":"function"},{"doc":"Updates a core definition.","ref":"AWS.Greengrass.html#update_core_definition/4","title":"AWS.Greengrass.update_core_definition/4","type":"function"},{"doc":"Updates a device definition.","ref":"AWS.Greengrass.html#update_device_definition/4","title":"AWS.Greengrass.update_device_definition/4","type":"function"},{"doc":"Updates a Lambda function definition.","ref":"AWS.Greengrass.html#update_function_definition/4","title":"AWS.Greengrass.update_function_definition/4","type":"function"},{"doc":"Updates a group.","ref":"AWS.Greengrass.html#update_group/4","title":"AWS.Greengrass.update_group/4","type":"function"},{"doc":"Updates the Certificate expiry time for a group.","ref":"AWS.Greengrass.html#update_group_certificate_configuration/4","title":"AWS.Greengrass.update_group_certificate_configuration/4","type":"function"},{"doc":"Updates a logger definition.","ref":"AWS.Greengrass.html#update_logger_definition/4","title":"AWS.Greengrass.update_logger_definition/4","type":"function"},{"doc":"Updates a resource definition.","ref":"AWS.Greengrass.html#update_resource_definition/4","title":"AWS.Greengrass.update_resource_definition/4","type":"function"},{"doc":"Updates a subscription definition.","ref":"AWS.Greengrass.html#update_subscription_definition/4","title":"AWS.Greengrass.update_subscription_definition/4","type":"function"},{"doc":"Updates the runtime configuration of a thing.","ref":"AWS.Greengrass.html#update_thing_runtime_configuration/4","title":"AWS.Greengrass.update_thing_runtime_configuration/4","type":"function"},{"doc":"IoT Greengrass brings local compute, messaging, data management, sync, and ML\ninference capabilities to edge devices.\n\nThis enables devices to collect and analyze data closer to the source of\ninformation, react autonomously to local events, and communicate securely with\neach other on local networks. Local devices can also communicate securely with\nAmazon Web Services IoT Core and export IoT data to the Amazon Web Services\nCloud. IoT Greengrass developers can use Lambda functions and components to\ncreate and deploy applications to fleets of edge devices for local operation.\n\nIoT Greengrass Version 2 provides a new major version of the IoT Greengrass Core\nsoftware, new APIs, and a new console. Use this API reference to learn how to\nuse the IoT Greengrass V2 API operations to manage components, manage\ndeployments, and core devices.\n\nFor more information, see [What is IoT Greengrass?](https://docs.aws.amazon.com/greengrass/v2/developerguide/what-is-iot-greengrass.html)\nin the *IoT Greengrass V2 Developer Guide*.","ref":"AWS.GreengrassV2.html","title":"AWS.GreengrassV2","type":"module"},{"doc":"Associates a Greengrass service role with IoT Greengrass for your Amazon Web\nServices account in this Amazon Web Services Region.\n\nIoT Greengrass uses this role to verify the identity of client devices and\nmanage core device connectivity information. The role must include the\n[AWSGreengrassResourceAccessRolePolicy](https://console.aws.amazon.com/iam/home#/policies/arn:awsiam::aws:policy/service-role/AWSGreengrassResourceAccessRolePolicy) managed policy or a custom policy that defines equivalent permissions for the\nIoT Greengrass features that you use. For more information, see [Greengrass\nservice\nrole](https://docs.aws.amazon.com/greengrass/v2/developerguide/greengrass-service-role.html)\nin the *IoT Greengrass Version 2 Developer Guide*.","ref":"AWS.GreengrassV2.html#associate_service_role_to_account/3","title":"AWS.GreengrassV2.associate_service_role_to_account/3","type":"function"},{"doc":"Associates a list of client devices with a core device.\n\nUse this API operation to specify which client devices can discover a core\ndevice through cloud discovery. With cloud discovery, client devices connect to\nIoT Greengrass to retrieve associated core devices' connectivity information and\ncertificates. For more information, see [Configure cloud discovery](https://docs.aws.amazon.com/greengrass/v2/developerguide/configure-cloud-discovery.html)\nin the *IoT Greengrass V2 Developer Guide*.\n\nClient devices are local IoT devices that connect to and communicate with an IoT\nGreengrass core device over MQTT. You can connect client devices to a core\ndevice to sync MQTT messages and data to Amazon Web Services IoT Core and\ninteract with client devices in Greengrass components. For more information, see\n[Interact with local IoT devices](https://docs.aws.amazon.com/greengrass/v2/developerguide/interact-with-local-iot-devices.html)\nin the *IoT Greengrass V2 Developer Guide*.","ref":"AWS.GreengrassV2.html#batch_associate_client_device_with_core_device/4","title":"AWS.GreengrassV2.batch_associate_client_device_with_core_device/4","type":"function"},{"doc":"Disassociates a list of client devices from a core device.\n\nAfter you disassociate a client device from a core device, the client device\nwon't be able to use cloud discovery to retrieve the core device's connectivity\ninformation and certificates.","ref":"AWS.GreengrassV2.html#batch_disassociate_client_device_from_core_device/4","title":"AWS.GreengrassV2.batch_disassociate_client_device_from_core_device/4","type":"function"},{"doc":"Cancels a deployment.\n\nThis operation cancels the deployment for devices that haven't yet received it.\nIf a device already received the deployment, this operation doesn't change\nanything for that device.","ref":"AWS.GreengrassV2.html#cancel_deployment/4","title":"AWS.GreengrassV2.cancel_deployment/4","type":"function"},{"doc":"Creates a component.\n\nComponents are software that run on Greengrass core devices. After you develop\nand test a component on your core device, you can use this operation to upload\nyour component to IoT Greengrass. Then, you can deploy the component to other\ncore devices.\n\nYou can use this operation to do the following:\n\n  *","ref":"AWS.GreengrassV2.html#create_component_version/3","title":"AWS.GreengrassV2.create_component_version/3","type":"function"},{"doc":"Create a component from a recipe, which is a file that defines the component's\nmetadata, parameters, dependencies, lifecycle, artifacts, and platform\ncapability. For more information, see [IoT Greengrass component recipe reference](https://docs.aws.amazon.com/greengrass/v2/developerguide/component-recipe-reference.html)\nin the *IoT Greengrass V2 Developer Guide*.\n\nTo create a component from a recipe, specify `inlineRecipe` when you call this\noperation.\n\n  *","ref":"AWS.GreengrassV2.html#create_component_version/3-create-components-from-recipes","title":"Create components from recipes - AWS.GreengrassV2.create_component_version/3","type":"function"},{"doc":"Create a component from an Lambda function that runs on IoT Greengrass. This\ncreates a recipe and artifacts from the Lambda function's deployment package.\nYou can use this operation to migrate Lambda functions from IoT Greengrass V1 to\nIoT Greengrass V2.\n\nThis function only accepts Lambda functions that use the following runtimes:\n\n    * Python 2.7 – `python2.7`\n\n    * Python 3.7 – `python3.7`\n\n    * Python 3.8 – `python3.8`\n\n    * Python 3.9 – `python3.9`\n\n    * Java 8 – `java8`\n\n    * Java 11 – `java11`\n\n    * Node.js 10 – `nodejs10.x`\n\n    * Node.js 12 – `nodejs12.x`\n\n    * Node.js 14 – `nodejs14.x`\n\nTo create a component from a Lambda function, specify `lambdaFunction` when you\ncall this operation.\n\nIoT Greengrass currently supports Lambda functions on only Linux core devices.","ref":"AWS.GreengrassV2.html#create_component_version/3-create-components-from-lambda-functions","title":"Create components from Lambda functions - AWS.GreengrassV2.create_component_version/3","type":"function"},{"doc":"Creates a continuous deployment for a target, which is a Greengrass core device\nor group of core devices.\n\nWhen you add a new core device to a group of core devices that has a deployment,\nIoT Greengrass deploys that group's deployment to the new device.\n\nYou can define one deployment for each target. When you create a new deployment\nfor a target that has an existing deployment, you replace the previous\ndeployment. IoT Greengrass applies the new deployment to the target devices.\n\nEvery deployment has a revision number that indicates how many deployment\nrevisions you define for a target. Use this operation to create a new revision\nof an existing deployment.\n\nFor more information, see the [Create deployments](https://docs.aws.amazon.com/greengrass/v2/developerguide/create-deployments.html)\nin the *IoT Greengrass V2 Developer Guide*.","ref":"AWS.GreengrassV2.html#create_deployment/3","title":"AWS.GreengrassV2.create_deployment/3","type":"function"},{"doc":"Deletes a version of a component from IoT Greengrass.\n\nThis operation deletes the component's recipe and artifacts. As a result,\ndeployments that refer to this component version will fail. If you have\ndeployments that use this component version, you can remove the component from\nthe deployment or update the deployment to use a valid version.","ref":"AWS.GreengrassV2.html#delete_component/4","title":"AWS.GreengrassV2.delete_component/4","type":"function"},{"doc":"Deletes a Greengrass core device, which is an IoT thing.\n\nThis operation removes the core device from the list of core devices. This\noperation doesn't delete the IoT thing. For more information about how to delete\nthe IoT thing, see\n[DeleteThing](https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteThing.html)\nin the *IoT API Reference*.","ref":"AWS.GreengrassV2.html#delete_core_device/4","title":"AWS.GreengrassV2.delete_core_device/4","type":"function"},{"doc":"Deletes a deployment.\n\nTo delete an active deployment, you must first cancel it. For more information,\nsee\n[CancelDeployment](https://docs.aws.amazon.com/iot/latest/apireference/API_CancelDeployment.html).\n\nDeleting a deployment doesn't affect core devices that run that deployment,\nbecause core devices store the deployment's configuration on the device.\nAdditionally, core devices can roll back to a previous deployment that has been\ndeleted.","ref":"AWS.GreengrassV2.html#delete_deployment/4","title":"AWS.GreengrassV2.delete_deployment/4","type":"function"},{"doc":"Retrieves metadata for a version of a component.","ref":"AWS.GreengrassV2.html#describe_component/3","title":"AWS.GreengrassV2.describe_component/3","type":"function"},{"doc":"Disassociates the Greengrass service role from IoT Greengrass for your Amazon\nWeb Services account in this Amazon Web Services Region.\n\nWithout a service role, IoT Greengrass can't verify the identity of client\ndevices or manage core device connectivity information. For more information,\nsee [Greengrass service role](https://docs.aws.amazon.com/greengrass/v2/developerguide/greengrass-service-role.html)\nin the *IoT Greengrass Version 2 Developer Guide*.","ref":"AWS.GreengrassV2.html#disassociate_service_role_from_account/3","title":"AWS.GreengrassV2.disassociate_service_role_from_account/3","type":"function"},{"doc":"Gets the recipe for a version of a component.","ref":"AWS.GreengrassV2.html#get_component/4","title":"AWS.GreengrassV2.get_component/4","type":"function"},{"doc":"Gets the pre-signed URL to download a public or a Lambda component artifact.\n\nCore devices call this operation to identify the URL that they can use to\ndownload an artifact to install.","ref":"AWS.GreengrassV2.html#get_component_version_artifact/4","title":"AWS.GreengrassV2.get_component_version_artifact/4","type":"function"},{"doc":"Retrieves connectivity information for a Greengrass core device.\n\nConnectivity information includes endpoints and ports where client devices can\nconnect to an MQTT broker on the core device. When a client device calls the\n[IoT Greengrass discovery API](https://docs.aws.amazon.com/greengrass/v2/developerguide/greengrass-discover-api.html),\nIoT Greengrass returns connectivity information for all of the core devices\nwhere the client device can connect. For more information, see [Connect client devices to core\ndevices](https://docs.aws.amazon.com/greengrass/v2/developerguide/connect-client-devices.html)\nin the *IoT Greengrass Version 2 Developer Guide*.","ref":"AWS.GreengrassV2.html#get_connectivity_info/3","title":"AWS.GreengrassV2.get_connectivity_info/3","type":"function"},{"doc":"Retrieves metadata for a Greengrass core device.\n\nIoT Greengrass relies on individual devices to send status updates to the Amazon\nWeb Services Cloud. If the IoT Greengrass Core software isn't running on the\ndevice, or if device isn't connected to the Amazon Web Services Cloud, then the\nreported status of that device might not reflect its current status. The status\ntimestamp indicates when the device status was last updated.\n\nCore devices send status updates at the following times:\n\n   When the IoT Greengrass Core software starts\n\n   When the core device receives a deployment from the Amazon Web\nServices Cloud\n\n   When the status of any component on the core device becomes\n`BROKEN`\n\n   At a [regular interval that you can configure](https://docs.aws.amazon.com/greengrass/v2/developerguide/greengrass-nucleus-component.html#greengrass-nucleus-component-configuration-fss),\nwhich defaults to 24 hours\n\n   For IoT Greengrass Core v2.7.0, the core device sends status\nupdates upon local deployment and cloud deployment","ref":"AWS.GreengrassV2.html#get_core_device/3","title":"AWS.GreengrassV2.get_core_device/3","type":"function"},{"doc":"Gets a deployment.\n\nDeployments define the components that run on Greengrass core devices.","ref":"AWS.GreengrassV2.html#get_deployment/3","title":"AWS.GreengrassV2.get_deployment/3","type":"function"},{"doc":"Gets the service role associated with IoT Greengrass for your Amazon Web\nServices account in this Amazon Web Services Region.\n\nIoT Greengrass uses this role to verify the identity of client devices and\nmanage core device connectivity information. For more information, see\n[Greengrass service role](https://docs.aws.amazon.com/greengrass/v2/developerguide/greengrass-service-role.html)\nin the *IoT Greengrass Version 2 Developer Guide*.","ref":"AWS.GreengrassV2.html#get_service_role_for_account/2","title":"AWS.GreengrassV2.get_service_role_for_account/2","type":"function"},{"doc":"Retrieves a paginated list of client devices that are associated with a core\ndevice.","ref":"AWS.GreengrassV2.html#list_client_devices_associated_with_core_device/5","title":"AWS.GreengrassV2.list_client_devices_associated_with_core_device/5","type":"function"},{"doc":"Retrieves a paginated list of all versions for a component.\n\nGreater versions are listed first.","ref":"AWS.GreengrassV2.html#list_component_versions/5","title":"AWS.GreengrassV2.list_component_versions/5","type":"function"},{"doc":"Retrieves a paginated list of component summaries.\n\nThis list includes components that you have permission to view.","ref":"AWS.GreengrassV2.html#list_components/5","title":"AWS.GreengrassV2.list_components/5","type":"function"},{"doc":"Retrieves a paginated list of Greengrass core devices.\n\nIoT Greengrass relies on individual devices to send status updates to the Amazon\nWeb Services Cloud. If the IoT Greengrass Core software isn't running on the\ndevice, or if device isn't connected to the Amazon Web Services Cloud, then the\nreported status of that device might not reflect its current status. The status\ntimestamp indicates when the device status was last updated.\n\nCore devices send status updates at the following times:\n\n   When the IoT Greengrass Core software starts\n\n   When the core device receives a deployment from the Amazon Web\nServices Cloud\n\n   When the status of any component on the core device becomes\n`BROKEN`\n\n   At a [regular interval that you can configure](https://docs.aws.amazon.com/greengrass/v2/developerguide/greengrass-nucleus-component.html#greengrass-nucleus-component-configuration-fss),\nwhich defaults to 24 hours\n\n   For IoT Greengrass Core v2.7.0, the core device sends status\nupdates upon local deployment and cloud deployment","ref":"AWS.GreengrassV2.html#list_core_devices/6","title":"AWS.GreengrassV2.list_core_devices/6","type":"function"},{"doc":"Retrieves a paginated list of deployments.","ref":"AWS.GreengrassV2.html#list_deployments/7","title":"AWS.GreengrassV2.list_deployments/7","type":"function"},{"doc":"Retrieves a paginated list of deployment jobs that IoT Greengrass sends to\nGreengrass core devices.","ref":"AWS.GreengrassV2.html#list_effective_deployments/5","title":"AWS.GreengrassV2.list_effective_deployments/5","type":"function"},{"doc":"Retrieves a paginated list of the components that a Greengrass core device runs.\n\nBy default, this list doesn't include components that are deployed as\ndependencies of other components. To include dependencies in the response, set\nthe `topologyFilter` parameter to `ALL`.\n\nIoT Greengrass relies on individual devices to send status updates to the Amazon\nWeb Services Cloud. If the IoT Greengrass Core software isn't running on the\ndevice, or if device isn't connected to the Amazon Web Services Cloud, then the\nreported status of that device might not reflect its current status. The status\ntimestamp indicates when the device status was last updated.\n\nCore devices send status updates at the following times:\n\n   When the IoT Greengrass Core software starts\n\n   When the core device receives a deployment from the Amazon Web\nServices Cloud\n\n   When the status of any component on the core device becomes\n`BROKEN`\n\n   At a [regular interval that you can configure](https://docs.aws.amazon.com/greengrass/v2/developerguide/greengrass-nucleus-component.html#greengrass-nucleus-component-configuration-fss),\nwhich defaults to 24 hours\n\n   For IoT Greengrass Core v2.7.0, the core device sends status\nupdates upon local deployment and cloud deployment","ref":"AWS.GreengrassV2.html#list_installed_components/6","title":"AWS.GreengrassV2.list_installed_components/6","type":"function"},{"doc":"Retrieves the list of tags for an IoT Greengrass resource.","ref":"AWS.GreengrassV2.html#list_tags_for_resource/3","title":"AWS.GreengrassV2.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.GreengrassV2.html#metadata/0","title":"AWS.GreengrassV2.metadata/0","type":"function"},{"doc":"Retrieves a list of components that meet the component, version, and platform\nrequirements of a deployment.\n\nGreengrass core devices call this operation when they receive a deployment to\nidentify the components to install.\n\nThis operation identifies components that meet all dependency requirements for a\ndeployment. If the requirements conflict, then this operation returns an error\nand the deployment fails. For example, this occurs if component `A` requires\nversion `>2.0.0` and component `B` requires version `<2.0.0` of a component\ndependency.\n\nWhen you specify the component candidates to resolve, IoT Greengrass compares\neach component's digest from the core device with the component's digest in the\nAmazon Web Services Cloud. If the digests don't match, then IoT Greengrass\nspecifies to use the version from the Amazon Web Services Cloud.\n\nTo use this operation, you must use the data plane API endpoint and authenticate\nwith an IoT device certificate. For more information, see [IoT Greengrass endpoints and\nquotas](https://docs.aws.amazon.com/general/latest/gr/greengrass.html).","ref":"AWS.GreengrassV2.html#resolve_component_candidates/3","title":"AWS.GreengrassV2.resolve_component_candidates/3","type":"function"},{"doc":"Adds tags to an IoT Greengrass resource.\n\nIf a tag already exists for the resource, this operation updates the tag's\nvalue.","ref":"AWS.GreengrassV2.html#tag_resource/4","title":"AWS.GreengrassV2.tag_resource/4","type":"function"},{"doc":"Removes a tag from an IoT Greengrass resource.","ref":"AWS.GreengrassV2.html#untag_resource/4","title":"AWS.GreengrassV2.untag_resource/4","type":"function"},{"doc":"Updates connectivity information for a Greengrass core device.\n\nConnectivity information includes endpoints and ports where client devices can\nconnect to an MQTT broker on the core device. When a client device calls the\n[IoT Greengrass discovery API](https://docs.aws.amazon.com/greengrass/v2/developerguide/greengrass-discover-api.html),\nIoT Greengrass returns connectivity information for all of the core devices\nwhere the client device can connect. For more information, see [Connect client devices to core\ndevices](https://docs.aws.amazon.com/greengrass/v2/developerguide/connect-client-devices.html)\nin the *IoT Greengrass Version 2 Developer Guide*.","ref":"AWS.GreengrassV2.html#update_connectivity_info/4","title":"AWS.GreengrassV2.update_connectivity_info/4","type":"function"},{"doc":"Welcome to the AWS Ground Station API Reference.\n\nAWS Ground Station is a fully managed service that enables you to control\nsatellite communications, downlink and process satellite data, and scale your\nsatellite operations efficiently and cost-effectively without having to build or\nmanage your own ground station infrastructure.","ref":"AWS.GroundStation.html","title":"AWS.GroundStation","type":"module"},{"doc":"Cancels a contact with a specified contact ID.","ref":"AWS.GroundStation.html#cancel_contact/4","title":"AWS.GroundStation.cancel_contact/4","type":"function"},{"doc":"Creates a `Config` with the specified `configData` parameters.\n\nOnly one type of `configData` can be specified.","ref":"AWS.GroundStation.html#create_config/3","title":"AWS.GroundStation.create_config/3","type":"function"},{"doc":"Creates a `DataflowEndpoint` group containing the specified list of\n`DataflowEndpoint` objects.\n\nThe `name` field in each endpoint is used in your mission profile\n`DataflowEndpointConfig` to specify which endpoints to use during a contact.\n\nWhen a contact uses multiple `DataflowEndpointConfig` objects, each `Config`\nmust match a `DataflowEndpoint` in the same group.","ref":"AWS.GroundStation.html#create_dataflow_endpoint_group/3","title":"AWS.GroundStation.create_dataflow_endpoint_group/3","type":"function"},{"doc":"Creates an Ephemeris with the specified `EphemerisData`.","ref":"AWS.GroundStation.html#create_ephemeris/3","title":"AWS.GroundStation.create_ephemeris/3","type":"function"},{"doc":"Creates a mission profile.\n\n`dataflowEdges` is a list of lists of strings. Each lower level list of strings\nhas two elements: a *from* ARN and a *to* ARN.","ref":"AWS.GroundStation.html#create_mission_profile/3","title":"AWS.GroundStation.create_mission_profile/3","type":"function"},{"doc":"Deletes a `Config`.","ref":"AWS.GroundStation.html#delete_config/5","title":"AWS.GroundStation.delete_config/5","type":"function"},{"doc":"Deletes a dataflow endpoint group.","ref":"AWS.GroundStation.html#delete_dataflow_endpoint_group/4","title":"AWS.GroundStation.delete_dataflow_endpoint_group/4","type":"function"},{"doc":"Deletes an ephemeris","ref":"AWS.GroundStation.html#delete_ephemeris/4","title":"AWS.GroundStation.delete_ephemeris/4","type":"function"},{"doc":"Deletes a mission profile.","ref":"AWS.GroundStation.html#delete_mission_profile/4","title":"AWS.GroundStation.delete_mission_profile/4","type":"function"},{"doc":"Describes an existing contact.","ref":"AWS.GroundStation.html#describe_contact/3","title":"AWS.GroundStation.describe_contact/3","type":"function"},{"doc":"Describes an existing ephemeris.","ref":"AWS.GroundStation.html#describe_ephemeris/3","title":"AWS.GroundStation.describe_ephemeris/3","type":"function"},{"doc":"For use by AWS Ground Station Agent and shouldn't be called directly.\n\nGets the latest configuration information for a registered agent.","ref":"AWS.GroundStation.html#get_agent_configuration/3","title":"AWS.GroundStation.get_agent_configuration/3","type":"function"},{"doc":"Returns `Config` information.\n\nOnly one `Config` response can be returned.","ref":"AWS.GroundStation.html#get_config/4","title":"AWS.GroundStation.get_config/4","type":"function"},{"doc":"Returns the dataflow endpoint group.","ref":"AWS.GroundStation.html#get_dataflow_endpoint_group/3","title":"AWS.GroundStation.get_dataflow_endpoint_group/3","type":"function"},{"doc":"Returns the number of reserved minutes used by account.","ref":"AWS.GroundStation.html#get_minute_usage/3","title":"AWS.GroundStation.get_minute_usage/3","type":"function"},{"doc":"Returns a mission profile.","ref":"AWS.GroundStation.html#get_mission_profile/3","title":"AWS.GroundStation.get_mission_profile/3","type":"function"},{"doc":"Returns a satellite.","ref":"AWS.GroundStation.html#get_satellite/3","title":"AWS.GroundStation.get_satellite/3","type":"function"},{"doc":"Returns a list of `Config` objects.","ref":"AWS.GroundStation.html#list_configs/4","title":"AWS.GroundStation.list_configs/4","type":"function"},{"doc":"Returns a list of contacts.\n\nIf `statusList` contains AVAILABLE, the request must include `groundStation`,\n`missionprofileArn`, and `satelliteArn`.","ref":"AWS.GroundStation.html#list_contacts/3","title":"AWS.GroundStation.list_contacts/3","type":"function"},{"doc":"Returns a list of `DataflowEndpoint` groups.","ref":"AWS.GroundStation.html#list_dataflow_endpoint_groups/4","title":"AWS.GroundStation.list_dataflow_endpoint_groups/4","type":"function"},{"doc":"List existing ephemerides.","ref":"AWS.GroundStation.html#list_ephemerides/3","title":"AWS.GroundStation.list_ephemerides/3","type":"function"},{"doc":"Returns a list of ground stations.","ref":"AWS.GroundStation.html#list_ground_stations/5","title":"AWS.GroundStation.list_ground_stations/5","type":"function"},{"doc":"Returns a list of mission profiles.","ref":"AWS.GroundStation.html#list_mission_profiles/4","title":"AWS.GroundStation.list_mission_profiles/4","type":"function"},{"doc":"Returns a list of satellites.","ref":"AWS.GroundStation.html#list_satellites/4","title":"AWS.GroundStation.list_satellites/4","type":"function"},{"doc":"Returns a list of tags for a specified resource.","ref":"AWS.GroundStation.html#list_tags_for_resource/3","title":"AWS.GroundStation.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.GroundStation.html#metadata/0","title":"AWS.GroundStation.metadata/0","type":"function"},{"doc":"For use by AWS Ground Station Agent and shouldn't be called directly.\n\nRegisters a new agent with AWS Ground Station.","ref":"AWS.GroundStation.html#register_agent/3","title":"AWS.GroundStation.register_agent/3","type":"function"},{"doc":"Reserves a contact using specified parameters.","ref":"AWS.GroundStation.html#reserve_contact/3","title":"AWS.GroundStation.reserve_contact/3","type":"function"},{"doc":"Assigns a tag to a resource.","ref":"AWS.GroundStation.html#tag_resource/4","title":"AWS.GroundStation.tag_resource/4","type":"function"},{"doc":"Deassigns a resource tag.","ref":"AWS.GroundStation.html#untag_resource/4","title":"AWS.GroundStation.untag_resource/4","type":"function"},{"doc":"For use by AWS Ground Station Agent and shouldn't be called directly.\n\nUpdate the status of the agent.","ref":"AWS.GroundStation.html#update_agent_status/4","title":"AWS.GroundStation.update_agent_status/4","type":"function"},{"doc":"Updates the `Config` used when scheduling contacts.\n\nUpdating a `Config` will not update the execution parameters for existing future\ncontacts scheduled with this `Config`.","ref":"AWS.GroundStation.html#update_config/5","title":"AWS.GroundStation.update_config/5","type":"function"},{"doc":"Updates an existing ephemeris","ref":"AWS.GroundStation.html#update_ephemeris/4","title":"AWS.GroundStation.update_ephemeris/4","type":"function"},{"doc":"Updates a mission profile.\n\nUpdating a mission profile will not update the execution parameters for existing\nfuture contacts.","ref":"AWS.GroundStation.html#update_mission_profile/4","title":"AWS.GroundStation.update_mission_profile/4","type":"function"},{"doc":"Amazon GuardDuty is a continuous security monitoring service that analyzes and\nprocesses the following foundational data sources - VPC flow logs, Amazon Web\nServices CloudTrail management event logs, CloudTrail S3 data event logs, EKS\naudit logs, DNS logs, Amazon EBS volume data, runtime activity belonging to\ncontainer workloads, such as Amazon EKS, Amazon ECS (including Amazon Web\nServices Fargate), and Amazon EC2 instances.\n\nIt uses threat intelligence feeds, such as lists of malicious IPs and domains,\nand machine learning to identify unexpected, potentially unauthorized, and\nmalicious activity within your Amazon Web Services environment. This can include\nissues like escalations of privileges, uses of exposed credentials, or\ncommunication with malicious IPs, domains, or presence of malware on your Amazon\nEC2 instances and container workloads. For example, GuardDuty can detect\ncompromised EC2 instances and container workloads serving malware, or mining\nbitcoin.\n\nGuardDuty also monitors Amazon Web Services account access behavior for signs of\ncompromise, such as unauthorized infrastructure deployments like EC2 instances\ndeployed in a Region that has never been used, or unusual API calls like a\npassword policy change to reduce password strength.\n\nGuardDuty informs you about the status of your Amazon Web Services environment\nby producing security findings that you can view in the GuardDuty console or\nthrough Amazon EventBridge. For more information, see the * [Amazon GuardDuty User\nGuide](https://docs.aws.amazon.com/guardduty/latest/ug/what-is-guardduty.html)\n*.","ref":"AWS.GuardDuty.html","title":"AWS.GuardDuty","type":"module"},{"doc":"Accepts the invitation to be a member account and get monitored by a GuardDuty\nadministrator account that sent the invitation.","ref":"AWS.GuardDuty.html#accept_administrator_invitation/4","title":"AWS.GuardDuty.accept_administrator_invitation/4","type":"function"},{"doc":"Accepts the invitation to be monitored by a GuardDuty administrator account.","ref":"AWS.GuardDuty.html#accept_invitation/4","title":"AWS.GuardDuty.accept_invitation/4","type":"function"},{"doc":"Archives GuardDuty findings that are specified by the list of finding IDs.\n\nOnly the administrator account can archive findings. Member accounts don't have\npermission to archive findings from their accounts.","ref":"AWS.GuardDuty.html#archive_findings/4","title":"AWS.GuardDuty.archive_findings/4","type":"function"},{"doc":"Creates a single Amazon GuardDuty detector.\n\nA detector is a resource that represents the GuardDuty service. To start using\nGuardDuty, you must create a detector in each Region where you enable the\nservice. You can have only one detector per account per Region. All data sources\nare enabled in a new detector by default.\n\nThere might be regional differences because some data sources might not be\navailable in all the Amazon Web Services Regions where GuardDuty is presently\nsupported. For more information, see [Regions and endpoints](https://docs.aws.amazon.com/guardduty/latest/ug/guardduty_regions.html).","ref":"AWS.GuardDuty.html#create_detector/3","title":"AWS.GuardDuty.create_detector/3","type":"function"},{"doc":"Creates a filter using the specified finding criteria.\n\nThe maximum number of saved filters per Amazon Web Services account per Region\nis 100. For more information, see [Quotas for GuardDuty](https://docs.aws.amazon.com/guardduty/latest/ug/guardduty_limits.html).","ref":"AWS.GuardDuty.html#create_filter/4","title":"AWS.GuardDuty.create_filter/4","type":"function"},{"doc":"Creates a new IPSet, which is called a trusted IP list in the console user\ninterface.\n\nAn IPSet is a list of IP addresses that are trusted for secure communication\nwith Amazon Web Services infrastructure and applications. GuardDuty doesn't\ngenerate findings for IP addresses that are included in IPSets. Only users from\nthe administrator account can use this operation.","ref":"AWS.GuardDuty.html#create_ip_set/4","title":"AWS.GuardDuty.create_ip_set/4","type":"function"},{"doc":"Creates member accounts of the current Amazon Web Services account by specifying\na list of Amazon Web Services account IDs.\n\nThis step is a prerequisite for managing the associated member accounts either\nby invitation or through an organization.\n\nAs a delegated administrator, using `CreateMembers` will enable GuardDuty in the\nadded member accounts, with the exception of the organization delegated\nadministrator account. A delegated administrator must enable GuardDuty prior to\nbeing added as a member.\n\nWhen you use CreateMembers as an Organizations delegated administrator,\nGuardDuty applies your organization's auto-enable settings to the member\naccounts in this request, irrespective of the accounts being new or existing\nmembers. For more information about the existing auto-enable settings for your\norganization, see\n[DescribeOrganizationConfiguration](https://docs.aws.amazon.com/guardduty/latest/APIReference/API_DescribeOrganizationConfiguration.html).  If you are adding accounts by invitation, before using\n[InviteMembers](https://docs.aws.amazon.com/guardduty/latest/APIReference/API_InviteMembers.html),\nuse `CreateMembers` after GuardDuty has been enabled in potential member\naccounts.\n\nIf you disassociate a member from a GuardDuty delegated administrator, the\nmember account details obtained from this API, including the associated email\naddresses, will be retained. This is done so that the delegated administrator\ncan invoke the\n[InviteMembers](https://docs.aws.amazon.com/guardduty/latest/APIReference/API_InviteMembers.html) API without the need to invoke the CreateMembers API again. To remove the\ndetails associated with a member account, the delegated administrator must\ninvoke the\n[DeleteMembers](https://docs.aws.amazon.com/guardduty/latest/APIReference/API_DeleteMembers.html)\nAPI.","ref":"AWS.GuardDuty.html#create_members/4","title":"AWS.GuardDuty.create_members/4","type":"function"},{"doc":"Creates a publishing destination to export findings to.\n\nThe resource to export findings to must exist before you use this operation.","ref":"AWS.GuardDuty.html#create_publishing_destination/4","title":"AWS.GuardDuty.create_publishing_destination/4","type":"function"},{"doc":"Generates sample findings of types specified by the list of finding types.\n\nIf 'NULL' is specified for `findingTypes`, the API generates sample findings of\nall supported finding types.","ref":"AWS.GuardDuty.html#create_sample_findings/4","title":"AWS.GuardDuty.create_sample_findings/4","type":"function"},{"doc":"Creates a new ThreatIntelSet.\n\nThreatIntelSets consist of known malicious IP addresses. GuardDuty generates\nfindings based on ThreatIntelSets. Only users of the administrator account can\nuse this operation.","ref":"AWS.GuardDuty.html#create_threat_intel_set/4","title":"AWS.GuardDuty.create_threat_intel_set/4","type":"function"},{"doc":"Declines invitations sent to the current member account by Amazon Web Services\naccounts specified by their account IDs.","ref":"AWS.GuardDuty.html#decline_invitations/3","title":"AWS.GuardDuty.decline_invitations/3","type":"function"},{"doc":"Deletes an Amazon GuardDuty detector that is specified by the detector ID.","ref":"AWS.GuardDuty.html#delete_detector/4","title":"AWS.GuardDuty.delete_detector/4","type":"function"},{"doc":"Deletes the filter specified by the filter name.","ref":"AWS.GuardDuty.html#delete_filter/5","title":"AWS.GuardDuty.delete_filter/5","type":"function"},{"doc":"Deletes invitations sent to the current member account by Amazon Web Services\naccounts specified by their account IDs.","ref":"AWS.GuardDuty.html#delete_invitations/3","title":"AWS.GuardDuty.delete_invitations/3","type":"function"},{"doc":"Deletes the IPSet specified by the `ipSetId`.\n\nIPSets are called trusted IP lists in the console user interface.","ref":"AWS.GuardDuty.html#delete_ip_set/5","title":"AWS.GuardDuty.delete_ip_set/5","type":"function"},{"doc":"Deletes GuardDuty member accounts (to the current GuardDuty administrator\naccount) specified by the account IDs.\n\nWith `autoEnableOrganizationMembers` configuration for your organization set to\n`ALL`, you'll receive an error if you attempt to disable GuardDuty for a member\naccount in your organization.","ref":"AWS.GuardDuty.html#delete_members/4","title":"AWS.GuardDuty.delete_members/4","type":"function"},{"doc":"Deletes the publishing definition with the specified `destinationId`.","ref":"AWS.GuardDuty.html#delete_publishing_destination/5","title":"AWS.GuardDuty.delete_publishing_destination/5","type":"function"},{"doc":"Deletes the ThreatIntelSet specified by the ThreatIntelSet ID.","ref":"AWS.GuardDuty.html#delete_threat_intel_set/5","title":"AWS.GuardDuty.delete_threat_intel_set/5","type":"function"},{"doc":"Returns a list of malware scans.\n\nEach member account can view the malware scans for their own accounts. An\nadministrator can view the malware scans for all the member accounts.\n\nThere might be regional differences because some data sources might not be\navailable in all the Amazon Web Services Regions where GuardDuty is presently\nsupported. For more information, see [Regions and endpoints](https://docs.aws.amazon.com/guardduty/latest/ug/guardduty_regions.html).","ref":"AWS.GuardDuty.html#describe_malware_scans/4","title":"AWS.GuardDuty.describe_malware_scans/4","type":"function"},{"doc":"Returns information about the account selected as the delegated administrator\nfor GuardDuty.\n\nThere might be regional differences because some data sources might not be\navailable in all the Amazon Web Services Regions where GuardDuty is presently\nsupported. For more information, see [Regions and endpoints](https://docs.aws.amazon.com/guardduty/latest/ug/guardduty_regions.html).","ref":"AWS.GuardDuty.html#describe_organization_configuration/5","title":"AWS.GuardDuty.describe_organization_configuration/5","type":"function"},{"doc":"Returns information about the publishing destination specified by the provided\n`destinationId`.","ref":"AWS.GuardDuty.html#describe_publishing_destination/4","title":"AWS.GuardDuty.describe_publishing_destination/4","type":"function"},{"doc":"Removes the existing GuardDuty delegated administrator of the organization.\n\nOnly the organization's management account can run this API operation.","ref":"AWS.GuardDuty.html#disable_organization_admin_account/3","title":"AWS.GuardDuty.disable_organization_admin_account/3","type":"function"},{"doc":"Disassociates the current GuardDuty member account from its administrator\naccount.\n\nWhen you disassociate an invited member from a GuardDuty delegated\nadministrator, the member account details obtained from the\n[CreateMembers](https://docs.aws.amazon.com/guardduty/latest/APIReference/API_CreateMembers.html) API, including the associated email addresses, are retained. This is done so\nthat the delegated administrator can invoke the\n[InviteMembers](https://docs.aws.amazon.com/guardduty/latest/APIReference/API_InviteMembers.html)\nAPI without the need to invoke the CreateMembers API again. To remove the\ndetails associated with a member account, the delegated administrator must\ninvoke the\n[DeleteMembers](https://docs.aws.amazon.com/guardduty/latest/APIReference/API_DeleteMembers.html)\nAPI.\n\nWith `autoEnableOrganizationMembers` configuration for your organization set to\n`ALL`, you'll receive an error if you attempt to disable GuardDuty in a member\naccount.","ref":"AWS.GuardDuty.html#disassociate_from_administrator_account/4","title":"AWS.GuardDuty.disassociate_from_administrator_account/4","type":"function"},{"doc":"Disassociates the current GuardDuty member account from its administrator\naccount.\n\nWhen you disassociate an invited member from a GuardDuty delegated\nadministrator, the member account details obtained from the\n[CreateMembers](https://docs.aws.amazon.com/guardduty/latest/APIReference/API_CreateMembers.html) API, including the associated email addresses, are retained. This is done so\nthat the delegated administrator can invoke the\n[InviteMembers](https://docs.aws.amazon.com/guardduty/latest/APIReference/API_InviteMembers.html)\nAPI without the need to invoke the CreateMembers API again. To remove the\ndetails associated with a member account, the delegated administrator must\ninvoke the\n[DeleteMembers](https://docs.aws.amazon.com/guardduty/latest/APIReference/API_DeleteMembers.html)\nAPI.","ref":"AWS.GuardDuty.html#disassociate_from_master_account/4","title":"AWS.GuardDuty.disassociate_from_master_account/4","type":"function"},{"doc":"Disassociates GuardDuty member accounts (from the current administrator account)\nspecified by the account IDs.\n\nWhen you disassociate an invited member from a GuardDuty delegated\nadministrator, the member account details obtained from the\n[CreateMembers](https://docs.aws.amazon.com/guardduty/latest/APIReference/API_CreateMembers.html) API, including the associated email addresses, are retained. This is done so\nthat the delegated administrator can invoke the\n[InviteMembers](https://docs.aws.amazon.com/guardduty/latest/APIReference/API_InviteMembers.html)\nAPI without the need to invoke the CreateMembers API again. To remove the\ndetails associated with a member account, the delegated administrator must\ninvoke the\n[DeleteMembers](https://docs.aws.amazon.com/guardduty/latest/APIReference/API_DeleteMembers.html)\nAPI.\n\nWith `autoEnableOrganizationMembers` configuration for your organization set to\n`ALL`, you'll receive an error if you attempt to disassociate a member account\nbefore removing them from your organization.","ref":"AWS.GuardDuty.html#disassociate_members/4","title":"AWS.GuardDuty.disassociate_members/4","type":"function"},{"doc":"Designates an Amazon Web Services account within the organization as your\nGuardDuty delegated administrator.\n\nOnly the organization's management account can run this API operation.","ref":"AWS.GuardDuty.html#enable_organization_admin_account/3","title":"AWS.GuardDuty.enable_organization_admin_account/3","type":"function"},{"doc":"Provides the details of the GuardDuty administrator account associated with the\ncurrent GuardDuty member account.\n\nIf the organization's management account or a delegated administrator runs this\nAPI, it will return success (`HTTP 200`) but no content.","ref":"AWS.GuardDuty.html#get_administrator_account/3","title":"AWS.GuardDuty.get_administrator_account/3","type":"function"},{"doc":"Retrieves aggregated statistics for your account.\n\nIf you are a GuardDuty administrator, you can retrieve the statistics for all\nthe resources associated with the active member accounts in your organization\nwho have enabled Runtime Monitoring and have the GuardDuty security agent\nrunning on their resources.","ref":"AWS.GuardDuty.html#get_coverage_statistics/4","title":"AWS.GuardDuty.get_coverage_statistics/4","type":"function"},{"doc":"Retrieves an Amazon GuardDuty detector specified by the detectorId.\n\nThere might be regional differences because some data sources might not be\navailable in all the Amazon Web Services Regions where GuardDuty is presently\nsupported. For more information, see [Regions and endpoints](https://docs.aws.amazon.com/guardduty/latest/ug/guardduty_regions.html).","ref":"AWS.GuardDuty.html#get_detector/3","title":"AWS.GuardDuty.get_detector/3","type":"function"},{"doc":"Returns the details of the filter specified by the filter name.","ref":"AWS.GuardDuty.html#get_filter/4","title":"AWS.GuardDuty.get_filter/4","type":"function"},{"doc":"Describes Amazon GuardDuty findings specified by finding IDs.","ref":"AWS.GuardDuty.html#get_findings/4","title":"AWS.GuardDuty.get_findings/4","type":"function"},{"doc":"Lists Amazon GuardDuty findings statistics for the specified detector ID.","ref":"AWS.GuardDuty.html#get_findings_statistics/4","title":"AWS.GuardDuty.get_findings_statistics/4","type":"function"},{"doc":"Returns the count of all GuardDuty membership invitations that were sent to the\ncurrent member account except the currently accepted invitation.","ref":"AWS.GuardDuty.html#get_invitations_count/2","title":"AWS.GuardDuty.get_invitations_count/2","type":"function"},{"doc":"Retrieves the IPSet specified by the `ipSetId`.","ref":"AWS.GuardDuty.html#get_ip_set/4","title":"AWS.GuardDuty.get_ip_set/4","type":"function"},{"doc":"Returns the details of the malware scan settings.\n\nThere might be regional differences because some data sources might not be\navailable in all the Amazon Web Services Regions where GuardDuty is presently\nsupported. For more information, see [Regions and endpoints](https://docs.aws.amazon.com/guardduty/latest/ug/guardduty_regions.html).","ref":"AWS.GuardDuty.html#get_malware_scan_settings/3","title":"AWS.GuardDuty.get_malware_scan_settings/3","type":"function"},{"doc":"Provides the details for the GuardDuty administrator account associated with the\ncurrent GuardDuty member account.","ref":"AWS.GuardDuty.html#get_master_account/3","title":"AWS.GuardDuty.get_master_account/3","type":"function"},{"doc":"Describes which data sources are enabled for the member account's detector.\n\nThere might be regional differences because some data sources might not be\navailable in all the Amazon Web Services Regions where GuardDuty is presently\nsupported. For more information, see [Regions and endpoints](https://docs.aws.amazon.com/guardduty/latest/ug/guardduty_regions.html).","ref":"AWS.GuardDuty.html#get_member_detectors/4","title":"AWS.GuardDuty.get_member_detectors/4","type":"function"},{"doc":"Retrieves GuardDuty member accounts (of the current GuardDuty administrator\naccount) specified by the account IDs.","ref":"AWS.GuardDuty.html#get_members/4","title":"AWS.GuardDuty.get_members/4","type":"function"},{"doc":"Retrieves how many active member accounts in your Amazon Web Services\norganization have each feature enabled within GuardDuty.\n\nOnly a delegated GuardDuty administrator of an organization can run this API.\n\nWhen you create a new Amazon Web Services organization, it might take up to 24\nhours to generate the statistics for the entire organization.","ref":"AWS.GuardDuty.html#get_organization_statistics/2","title":"AWS.GuardDuty.get_organization_statistics/2","type":"function"},{"doc":"Provides the number of days left for each data source used in the free trial\nperiod.","ref":"AWS.GuardDuty.html#get_remaining_free_trial_days/4","title":"AWS.GuardDuty.get_remaining_free_trial_days/4","type":"function"},{"doc":"Retrieves the ThreatIntelSet that is specified by the ThreatIntelSet ID.","ref":"AWS.GuardDuty.html#get_threat_intel_set/4","title":"AWS.GuardDuty.get_threat_intel_set/4","type":"function"},{"doc":"Lists Amazon GuardDuty usage statistics over the last 30 days for the specified\ndetector ID.\n\nFor newly enabled detectors or data sources, the cost returned will include only\nthe usage so far under 30 days. This may differ from the cost metrics in the\nconsole, which project usage over 30 days to provide a monthly cost estimate.\nFor more information, see [Understanding How Usage Costs are Calculated](https://docs.aws.amazon.com/guardduty/latest/ug/monitoring_costs.html#usage-calculations).","ref":"AWS.GuardDuty.html#get_usage_statistics/4","title":"AWS.GuardDuty.get_usage_statistics/4","type":"function"},{"doc":"Invites Amazon Web Services accounts to become members of an organization\nadministered by the Amazon Web Services account that invokes this API.\n\nIf you are using Amazon Web Services Organizations to manage your GuardDuty\nenvironment, this step is not needed. For more information, see [Managing accounts with\norganizations](https://docs.aws.amazon.com/guardduty/latest/ug/guardduty_organizations.html).\n\nTo invite Amazon Web Services accounts, the first step is to ensure that\nGuardDuty has been enabled in the potential member accounts. You can now invoke\nthis API to add accounts by invitation. The invited accounts can either accept\nor decline the invitation from their GuardDuty accounts. Each invited Amazon Web\nServices account can choose to accept the invitation from only one Amazon Web\nServices account. For more information, see [Managing GuardDuty accounts by invitation](https://docs.aws.amazon.com/guardduty/latest/ug/guardduty_invitations.html).\n\nAfter the invite has been accepted and you choose to disassociate a member\naccount (by using\n[DisassociateMembers](https://docs.aws.amazon.com/guardduty/latest/APIReference/API_DisassociateMembers.html)) from your account, the details of the member account obtained by invoking\n[CreateMembers](https://docs.aws.amazon.com/guardduty/latest/APIReference/API_CreateMembers.html),\nincluding the associated email addresses, will be retained. This is done so that\nyou can invoke InviteMembers without the need to invoke\n[CreateMembers](https://docs.aws.amazon.com/guardduty/latest/APIReference/API_CreateMembers.html) again. To remove the details associated with a member account, you must also\ninvoke\n[DeleteMembers](https://docs.aws.amazon.com/guardduty/latest/APIReference/API_DeleteMembers.html).","ref":"AWS.GuardDuty.html#invite_members/4","title":"AWS.GuardDuty.invite_members/4","type":"function"},{"doc":"Lists coverage details for your GuardDuty account.\n\nIf you're a GuardDuty administrator, you can retrieve all resources associated\nwith the active member accounts in your organization.\n\nMake sure the accounts have Runtime Monitoring enabled and GuardDuty agent\nrunning on their resources.","ref":"AWS.GuardDuty.html#list_coverage/4","title":"AWS.GuardDuty.list_coverage/4","type":"function"},{"doc":"Lists detectorIds of all the existing Amazon GuardDuty detector resources.","ref":"AWS.GuardDuty.html#list_detectors/4","title":"AWS.GuardDuty.list_detectors/4","type":"function"},{"doc":"Returns a paginated list of the current filters.","ref":"AWS.GuardDuty.html#list_filters/5","title":"AWS.GuardDuty.list_filters/5","type":"function"},{"doc":"Lists Amazon GuardDuty findings for the specified detector ID.","ref":"AWS.GuardDuty.html#list_findings/4","title":"AWS.GuardDuty.list_findings/4","type":"function"},{"doc":"Lists all GuardDuty membership invitations that were sent to the current Amazon\nWeb Services account.","ref":"AWS.GuardDuty.html#list_invitations/4","title":"AWS.GuardDuty.list_invitations/4","type":"function"},{"doc":"Lists the IPSets of the GuardDuty service specified by the detector ID.\n\nIf you use this operation from a member account, the IPSets returned are the\nIPSets from the associated administrator account.","ref":"AWS.GuardDuty.html#list_ip_sets/5","title":"AWS.GuardDuty.list_ip_sets/5","type":"function"},{"doc":"Lists details about all member accounts for the current GuardDuty administrator\naccount.","ref":"AWS.GuardDuty.html#list_members/6","title":"AWS.GuardDuty.list_members/6","type":"function"},{"doc":"Lists the accounts designated as GuardDuty delegated administrators.\n\nOnly the organization's management account can run this API operation.","ref":"AWS.GuardDuty.html#list_organization_admin_accounts/4","title":"AWS.GuardDuty.list_organization_admin_accounts/4","type":"function"},{"doc":"Returns a list of publishing destinations associated with the specified\n`detectorId`.","ref":"AWS.GuardDuty.html#list_publishing_destinations/5","title":"AWS.GuardDuty.list_publishing_destinations/5","type":"function"},{"doc":"Lists tags for a resource.\n\nTagging is currently supported for detectors, finding filters, IP sets, threat\nintel sets, and publishing destination, with a limit of 50 tags per resource.\nWhen invoked, this operation returns all assigned tags for a given resource.","ref":"AWS.GuardDuty.html#list_tags_for_resource/3","title":"AWS.GuardDuty.list_tags_for_resource/3","type":"function"},{"doc":"Lists the ThreatIntelSets of the GuardDuty service specified by the detector ID.\n\nIf you use this operation from a member account, the ThreatIntelSets associated\nwith the administrator account are returned.","ref":"AWS.GuardDuty.html#list_threat_intel_sets/5","title":"AWS.GuardDuty.list_threat_intel_sets/5","type":"function"},{"doc":"","ref":"AWS.GuardDuty.html#metadata/0","title":"AWS.GuardDuty.metadata/0","type":"function"},{"doc":"Initiates the malware scan.\n\nInvoking this API will automatically create the [Service-linked role\n](https://docs.aws.amazon.com/guardduty/latest/ug/slr-permissions-malware-protection.html)\nin the corresponding account.","ref":"AWS.GuardDuty.html#start_malware_scan/3","title":"AWS.GuardDuty.start_malware_scan/3","type":"function"},{"doc":"Turns on GuardDuty monitoring of the specified member accounts.\n\nUse this operation to restart monitoring of accounts that you stopped monitoring\nwith the\n[StopMonitoringMembers](https://docs.aws.amazon.com/guardduty/latest/APIReference/API_StopMonitoringMembers.html)\noperation.","ref":"AWS.GuardDuty.html#start_monitoring_members/4","title":"AWS.GuardDuty.start_monitoring_members/4","type":"function"},{"doc":"Stops GuardDuty monitoring for the specified member accounts.\n\nUse the `StartMonitoringMembers` operation to restart monitoring for those\naccounts.\n\nWith `autoEnableOrganizationMembers` configuration for your organization set to\n`ALL`, you'll receive an error if you attempt to stop monitoring the member\naccounts in your organization.","ref":"AWS.GuardDuty.html#stop_monitoring_members/4","title":"AWS.GuardDuty.stop_monitoring_members/4","type":"function"},{"doc":"Adds tags to a resource.","ref":"AWS.GuardDuty.html#tag_resource/4","title":"AWS.GuardDuty.tag_resource/4","type":"function"},{"doc":"Unarchives GuardDuty findings specified by the `findingIds`.","ref":"AWS.GuardDuty.html#unarchive_findings/4","title":"AWS.GuardDuty.unarchive_findings/4","type":"function"},{"doc":"Removes tags from a resource.","ref":"AWS.GuardDuty.html#untag_resource/4","title":"AWS.GuardDuty.untag_resource/4","type":"function"},{"doc":"Updates the Amazon GuardDuty detector specified by the detectorId.\n\nThere might be regional differences because some data sources might not be\navailable in all the Amazon Web Services Regions where GuardDuty is presently\nsupported. For more information, see [Regions and endpoints](https://docs.aws.amazon.com/guardduty/latest/ug/guardduty_regions.html).","ref":"AWS.GuardDuty.html#update_detector/4","title":"AWS.GuardDuty.update_detector/4","type":"function"},{"doc":"Updates the filter specified by the filter name.","ref":"AWS.GuardDuty.html#update_filter/5","title":"AWS.GuardDuty.update_filter/5","type":"function"},{"doc":"Marks the specified GuardDuty findings as useful or not useful.","ref":"AWS.GuardDuty.html#update_findings_feedback/4","title":"AWS.GuardDuty.update_findings_feedback/4","type":"function"},{"doc":"Updates the IPSet specified by the IPSet ID.","ref":"AWS.GuardDuty.html#update_ip_set/5","title":"AWS.GuardDuty.update_ip_set/5","type":"function"},{"doc":"Updates the malware scan settings.\n\nThere might be regional differences because some data sources might not be\navailable in all the Amazon Web Services Regions where GuardDuty is presently\nsupported. For more information, see [Regions and endpoints](https://docs.aws.amazon.com/guardduty/latest/ug/guardduty_regions.html).","ref":"AWS.GuardDuty.html#update_malware_scan_settings/4","title":"AWS.GuardDuty.update_malware_scan_settings/4","type":"function"},{"doc":"Contains information on member accounts to be updated.\n\nThere might be regional differences because some data sources might not be\navailable in all the Amazon Web Services Regions where GuardDuty is presently\nsupported. For more information, see [Regions and endpoints](https://docs.aws.amazon.com/guardduty/latest/ug/guardduty_regions.html).","ref":"AWS.GuardDuty.html#update_member_detectors/4","title":"AWS.GuardDuty.update_member_detectors/4","type":"function"},{"doc":"Configures the delegated administrator account with the provided values.\n\nYou must provide a value for either `autoEnableOrganizationMembers` or\n`autoEnable`, but not both.\n\nThere might be regional differences because some data sources might not be\navailable in all the Amazon Web Services Regions where GuardDuty is presently\nsupported. For more information, see [Regions and endpoints](https://docs.aws.amazon.com/guardduty/latest/ug/guardduty_regions.html).","ref":"AWS.GuardDuty.html#update_organization_configuration/4","title":"AWS.GuardDuty.update_organization_configuration/4","type":"function"},{"doc":"Updates information about the publishing destination specified by the\n`destinationId`.","ref":"AWS.GuardDuty.html#update_publishing_destination/5","title":"AWS.GuardDuty.update_publishing_destination/5","type":"function"},{"doc":"Updates the ThreatIntelSet specified by the ThreatIntelSet ID.","ref":"AWS.GuardDuty.html#update_threat_intel_set/5","title":"AWS.GuardDuty.update_threat_intel_set/5","type":"function"},{"doc":"Health\n\nThe Health API provides access to the Health information that appears in the\n[Health Dashboard](https://health.aws.amazon.com/health/home).  You can use the API operations to get information about events that might affect\nyour Amazon Web Services and resources.\n\nYou must have a Business, Enterprise On-Ramp, or Enterprise Support plan from\n[Amazon Web Services Support](http://aws.amazon.com/premiumsupport/) to use the\nHealth API. If you call the Health API from an Amazon Web Services account that\ndoesn't have a Business, Enterprise On-Ramp, or Enterprise Support plan, you\nreceive a `SubscriptionRequiredException` error.\n\nFor API access, you need an access key ID and a secret access key. Use temporary\ncredentials instead of long-term access keys when possible. Temporary\ncredentials include an access key ID, a secret access key, and a security token\nthat indicates when the credentials expire. For more information, see [Best practices for managing Amazon Web Services access\nkeys](https://docs.aws.amazon.com/general/latest/gr/aws-access-keys-best-practices.html)\nin the *Amazon Web Services General Reference*.\n\nYou can use the Health endpoint health.us-east-1.amazonaws.com (HTTPS) to call\nthe Health API operations. Health supports a multi-Region application\narchitecture and has two regional endpoints in an active-passive configuration.\nYou can use the high availability endpoint example to determine which Amazon Web\nServices Region is active, so that you can get the latest information from the\nAPI. For more information, see [Accessing the Health API](https://docs.aws.amazon.com/health/latest/ug/health-api.html) in the\n*Health User Guide*.\n\nFor authentication of requests, Health uses the [Signature Version 4 Signing Process](https://docs.aws.amazon.com/general/latest/gr/signature-version-4.html).\n\nIf your Amazon Web Services account is part of Organizations, you can use the\nHealth organizational view feature. This feature provides a centralized view of\nHealth events across all accounts in your organization. You can aggregate Health\nevents in real time to identify accounts in your organization that are affected\nby an operational event or get notified of security vulnerabilities. Use the\norganizational view API operations to enable this feature and return event\ninformation. For more information, see [Aggregating Health events](https://docs.aws.amazon.com/health/latest/ug/aggregate-events.html) in\nthe *Health User Guide*.\n\nWhen you use the Health API operations to return Health events, see the\nfollowing recommendations:\n\n   Use the\n[eventScopeCode](https://docs.aws.amazon.com/health/latest/APIReference/API_Event.html#AWSHealth-Type-Event-eventScopeCode)\nparameter to specify whether to return Health events that are public or\naccount-specific.\n\n   Use pagination to view all events from the response. For example,\nif you call the `DescribeEventsForOrganization` operation to get all events in\nyour organization, you might receive several page results. Specify the\n`nextToken` in the next request to return more results.","ref":"AWS.Health.html","title":"AWS.Health","type":"module"},{"doc":"Returns a list of accounts in the organization from Organizations that are\naffected by the provided event.\n\nFor more information about the different types of Health events, see\n[Event](https://docs.aws.amazon.com/health/latest/APIReference/API_Event.html).  Before you can call this operation, you must first enable Health to work with\nOrganizations. To do this, call the\n[EnableHealthServiceAccessForOrganization](https://docs.aws.amazon.com/health/latest/APIReference/API_EnableHealthServiceAccessForOrganization.html)\noperation from your organization's management account.\n\nThis API operation uses pagination. Specify the `nextToken` parameter in the\nnext request to return more results.","ref":"AWS.Health.html#describe_affected_accounts_for_organization/3","title":"AWS.Health.describe_affected_accounts_for_organization/3","type":"function"},{"doc":"Returns a list of entities that have been affected by the specified events,\nbased on the specified filter criteria.\n\nEntities can refer to individual customer resources, groups of customer\nresources, or any other construct, depending on the Amazon Web Service. Events\nthat have impact beyond that of the affected entities, or where the extent of\nimpact is unknown, include at least one entity indicating this.\n\nAt least one event ARN is required.\n\n   This API operation uses pagination. Specify the `nextToken`\nparameter in the next request to return more results.\n\n   This operation supports resource-level permissions. You can use\nthis operation to allow or deny access to specific Health events. For more\ninformation, see [Resource- and action-based conditions](https://docs.aws.amazon.com/health/latest/ug/security_iam_id-based-policy-examples.html#resource-action-based-conditions)\nin the *Health User Guide*.","ref":"AWS.Health.html#describe_affected_entities/3","title":"AWS.Health.describe_affected_entities/3","type":"function"},{"doc":"Returns a list of entities that have been affected by one or more events for one\nor more accounts in your organization in Organizations, based on the filter\ncriteria.\n\nEntities can refer to individual customer resources, groups of customer\nresources, or any other construct, depending on the Amazon Web Service.\n\nAt least one event Amazon Resource Name (ARN) and account ID are required.\n\nBefore you can call this operation, you must first enable Health to work with\nOrganizations. To do this, call the\n[EnableHealthServiceAccessForOrganization](https://docs.aws.amazon.com/health/latest/APIReference/API_EnableHealthServiceAccessForOrganization.html) operation from your organization's management account.\n\n   This API operation uses pagination. Specify the `nextToken`\nparameter in the next request to return more results.\n\n   This operation doesn't support resource-level permissions. You\ncan't use this operation to allow or deny access to specific Health events. For\nmore information, see [Resource- and action-based\nconditions](https://docs.aws.amazon.com/health/latest/ug/security_iam_id-based-policy-examples.html#resource-action-based-conditions)\nin the *Health User Guide*.","ref":"AWS.Health.html#describe_affected_entities_for_organization/3","title":"AWS.Health.describe_affected_entities_for_organization/3","type":"function"},{"doc":"Returns the number of entities that are affected by each of the specified\nevents.","ref":"AWS.Health.html#describe_entity_aggregates/3","title":"AWS.Health.describe_entity_aggregates/3","type":"function"},{"doc":"Returns a list of entity aggregates for your Organizations that are affected by\neach of the specified events.","ref":"AWS.Health.html#describe_entity_aggregates_for_organization/3","title":"AWS.Health.describe_entity_aggregates_for_organization/3","type":"function"},{"doc":"Returns the number of events of each event type (issue, scheduled change, and\naccount notification).\n\nIf no filter is specified, the counts of all events in each category are\nreturned.\n\nThis API operation uses pagination. Specify the `nextToken` parameter in the\nnext request to return more results.","ref":"AWS.Health.html#describe_event_aggregates/3","title":"AWS.Health.describe_event_aggregates/3","type":"function"},{"doc":"Returns detailed information about one or more specified events.\n\nInformation includes standard event data (Amazon Web Services Region, service,\nand so on, as returned by\n[DescribeEvents](https://docs.aws.amazon.com/health/latest/APIReference/API_DescribeEvents.html)), a detailed event description, and possible additional metadata that depends upon\nthe nature of the event. Affected entities are not included. To retrieve the\nentities, use the\n[DescribeAffectedEntities](https://docs.aws.amazon.com/health/latest/APIReference/API_DescribeAffectedEntities.html)\noperation.\n\nIf a specified event can't be retrieved, an error message is returned for that\nevent.\n\nThis operation supports resource-level permissions. You can use this operation\nto allow or deny access to specific Health events. For more information, see\n[Resource- and action-based conditions](https://docs.aws.amazon.com/health/latest/ug/security_iam_id-based-policy-examples.html#resource-action-based-conditions)\nin the *Health User Guide*.","ref":"AWS.Health.html#describe_event_details/3","title":"AWS.Health.describe_event_details/3","type":"function"},{"doc":"Returns detailed information about one or more specified events for one or more\nAmazon Web Services accounts in your organization.\n\nThis information includes standard event data (such as the Amazon Web Services\nRegion and service), an event description, and (depending on the event) possible\nmetadata. This operation doesn't return affected entities, such as the resources\nrelated to the event. To return affected entities, use the\n[DescribeAffectedEntitiesForOrganization](https://docs.aws.amazon.com/health/latest/APIReference/API_DescribeAffectedEntitiesForOrganization.html) operation.\n\nBefore you can call this operation, you must first enable Health to work with\nOrganizations. To do this, call the\n[EnableHealthServiceAccessForOrganization](https://docs.aws.amazon.com/health/latest/APIReference/API_EnableHealthServiceAccessForOrganization.html)\noperation from your organization's management account.\n\nWhen you call the `DescribeEventDetailsForOrganization` operation, specify the\n`organizationEventDetailFilters` object in the request. Depending on the Health\nevent type, note the following differences:\n\n  * To return event details for a public event, you must specify a\nnull value for the `awsAccountId` parameter. If you specify an account ID for a\npublic event, Health returns an error message because public events aren't\nspecific to an account.\n\n  * To return event details for an event that is specific to an\naccount in your organization, you must specify the `awsAccountId` parameter in\nthe request. If you don't specify an account ID, Health returns an error message\nbecause the event is specific to an account in your organization.\n\nFor more information, see\n[Event](https://docs.aws.amazon.com/health/latest/APIReference/API_Event.html).  This operation doesn't support resource-level permissions. You can't use this\noperation to allow or deny access to specific Health events. For more\ninformation, see [Resource- and action-based\nconditions](https://docs.aws.amazon.com/health/latest/ug/security_iam_id-based-policy-examples.html#resource-action-based-conditions)\nin the *Health User Guide*.","ref":"AWS.Health.html#describe_event_details_for_organization/3","title":"AWS.Health.describe_event_details_for_organization/3","type":"function"},{"doc":"Returns the event types that meet the specified filter criteria.\n\nYou can use this API operation to find information about the Health event, such\nas the category, Amazon Web Service, and event code. The metadata for each event\nappears in the\n[EventType](https://docs.aws.amazon.com/health/latest/APIReference/API_EventType.html)\nobject.\n\nIf you don't specify a filter criteria, the API operation returns all event\ntypes, in no particular order.\n\nThis API operation uses pagination. Specify the `nextToken` parameter in the\nnext request to return more results.","ref":"AWS.Health.html#describe_event_types/3","title":"AWS.Health.describe_event_types/3","type":"function"},{"doc":"Returns information about events that meet the specified filter criteria.\n\nEvents are returned in a summary form and do not include the detailed\ndescription, any additional metadata that depends on the event type, or any\naffected resources. To retrieve that information, use the\n[DescribeEventDetails](https://docs.aws.amazon.com/health/latest/APIReference/API_DescribeEventDetails.html) and\n[DescribeAffectedEntities](https://docs.aws.amazon.com/health/latest/APIReference/API_DescribeAffectedEntities.html)\noperations.\n\nIf no filter criteria are specified, all events are returned. Results are sorted\nby `lastModifiedTime`, starting with the most recent event.\n\n   When you call the `DescribeEvents` operation and specify an entity\nfor the `entityValues` parameter, Health might return public events that aren't\nspecific to that resource. For example, if you call `DescribeEvents` and specify\nan ID for an Amazon Elastic Compute Cloud (Amazon EC2) instance, Health might\nreturn events that aren't specific to that resource or service. To get events\nthat are specific to a service, use the `services` parameter in the `filter`\nobject. For more information, see\n[Event](https://docs.aws.amazon.com/health/latest/APIReference/API_Event.html).\n\n   This API operation uses pagination. Specify the `nextToken`\nparameter in the next request to return more results.","ref":"AWS.Health.html#describe_events/3","title":"AWS.Health.describe_events/3","type":"function"},{"doc":"Returns information about events across your organization in Organizations.\n\nYou can use the`filters` parameter to specify the events that you want to\nreturn. Events are returned in a summary form and don't include the affected\naccounts, detailed description, any additional metadata that depends on the\nevent type, or any affected resources. To retrieve that information, use the\nfollowing operations:\n\n  *\n[DescribeAffectedAccountsForOrganization](https://docs.aws.amazon.com/health/latest/APIReference/API_DescribeAffectedAccountsForOrganization.html)     *\n[DescribeEventDetailsForOrganization](https://docs.aws.amazon.com/health/latest/APIReference/API_DescribeEventDetailsForOrganization.html)\n\n  *\n[DescribeAffectedEntitiesForOrganization](https://docs.aws.amazon.com/health/latest/APIReference/API_DescribeAffectedEntitiesForOrganization.html) \n\nIf you don't specify a `filter`, the `DescribeEventsForOrganizations` returns\nall events across your organization. Results are sorted by `lastModifiedTime`,\nstarting with the most recent event.\n\nFor more information about the different types of Health events, see\n[Event](https://docs.aws.amazon.com/health/latest/APIReference/API_Event.html).\n\nBefore you can call this operation, you must first enable Health to work with\nOrganizations. To do this, call the\n[EnableHealthServiceAccessForOrganization](https://docs.aws.amazon.com/health/latest/APIReference/API_EnableHealthServiceAccessForOrganization.html)\noperation from your organization's management account.\n\nThis API operation uses pagination. Specify the `nextToken` parameter in the\nnext request to return more results.","ref":"AWS.Health.html#describe_events_for_organization/3","title":"AWS.Health.describe_events_for_organization/3","type":"function"},{"doc":"This operation provides status information on enabling or disabling Health to\nwork with your organization.\n\nTo call this operation, you must use the organization's management account.","ref":"AWS.Health.html#describe_health_service_status_for_organization/3","title":"AWS.Health.describe_health_service_status_for_organization/3","type":"function"},{"doc":"Disables Health from working with Organizations.\n\nTo call this operation, you must sign in to the organization's management\naccount. For more information, see [Aggregating Health events](https://docs.aws.amazon.com/health/latest/ug/aggregate-events.html) in\nthe *Health User Guide*.\n\nThis operation doesn't remove the service-linked role from the management\naccount in your organization. You must use the IAM console, API, or Command Line\nInterface (CLI) to remove the service-linked role. For more information, see\n[Deleting a Service-Linked Role](https://docs.aws.amazon.com/IAM/latest/UserGuide/using-service-linked-roles.html#delete-service-linked-role)\nin the *IAM User Guide*.\n\nYou can also disable the organizational feature by using the Organizations\n[DisableAWSServiceAccess](https://docs.aws.amazon.com/organizations/latest/APIReference/API_DisableAWSServiceAccess.html)\nAPI operation. After you call this operation, Health stops aggregating events\nfor all other Amazon Web Services accounts in your organization. If you call the\nHealth API operations for organizational view, Health returns an error. Health\ncontinues to aggregate health events for your Amazon Web Services account.","ref":"AWS.Health.html#disable_health_service_access_for_organization/3","title":"AWS.Health.disable_health_service_access_for_organization/3","type":"function"},{"doc":"Enables Health to work with Organizations.\n\nYou can use the organizational view feature to aggregate events from all Amazon\nWeb Services accounts in your organization in a centralized location.\n\nThis operation also creates a service-linked role for the management account in\nthe organization.\n\nTo call this operation, you must meet the following requirements:\n\n   You must have a Business, Enterprise On-Ramp, or Enterprise Support\nplan from [Amazon Web Services Support](http://aws.amazon.com/premiumsupport/) to use the Health API. If you call the Health API from an Amazon Web Services\naccount that doesn't have a Business, Enterprise On-Ramp, or Enterprise Support\nplan, you receive a `SubscriptionRequiredException` error.\n\n   You must have permission to call this operation from the\norganization's management account. For example IAM policies, see [Health\nidentity-based policy\nexamples](https://docs.aws.amazon.com/health/latest/ug/security_iam_id-based-policy-examples.html).\n\nIf you don't have the required support plan, you can instead use the Health\nconsole to enable the organizational view feature. For more information, see\n[Aggregating Health events](https://docs.aws.amazon.com/health/latest/ug/aggregate-events.html) in\nthe *Health User Guide*.","ref":"AWS.Health.html#enable_health_service_access_for_organization/3","title":"AWS.Health.enable_health_service_access_for_organization/3","type":"function"},{"doc":"","ref":"AWS.Health.html#metadata/0","title":"AWS.Health.metadata/0","type":"function"},{"doc":"AWS HealthLake is a HIPAA eligibile service that allows customers to store,\ntransform, query, and analyze their FHIR-formatted data in a consistent fashion\nin the cloud.","ref":"AWS.HealthLake.html","title":"AWS.HealthLake","type":"module"},{"doc":"Creates a data store that can ingest and export FHIR formatted data.","ref":"AWS.HealthLake.html#create_fhir_datastore/3","title":"AWS.HealthLake.create_fhir_datastore/3","type":"function"},{"doc":"Deletes a data store.","ref":"AWS.HealthLake.html#delete_fhir_datastore/3","title":"AWS.HealthLake.delete_fhir_datastore/3","type":"function"},{"doc":"Gets the properties associated with the FHIR data store, including the data\nstore ID, data store ARN, data store name, data store status, when the data\nstore was created, data store type version, and the data store's endpoint.","ref":"AWS.HealthLake.html#describe_fhir_datastore/3","title":"AWS.HealthLake.describe_fhir_datastore/3","type":"function"},{"doc":"Displays the properties of a FHIR export job, including the ID, ARN, name, and\nthe status of the job.","ref":"AWS.HealthLake.html#describe_fhir_export_job/3","title":"AWS.HealthLake.describe_fhir_export_job/3","type":"function"},{"doc":"Displays the properties of a FHIR import job, including the ID, ARN, name, and\nthe status of the job.","ref":"AWS.HealthLake.html#describe_fhir_import_job/3","title":"AWS.HealthLake.describe_fhir_import_job/3","type":"function"},{"doc":"Lists all FHIR data stores that are in the user’s account, regardless of data\nstore status.","ref":"AWS.HealthLake.html#list_fhir_datastores/3","title":"AWS.HealthLake.list_fhir_datastores/3","type":"function"},{"doc":"Lists all FHIR export jobs associated with an account and their statuses.","ref":"AWS.HealthLake.html#list_fhir_export_jobs/3","title":"AWS.HealthLake.list_fhir_export_jobs/3","type":"function"},{"doc":"Lists all FHIR import jobs associated with an account and their statuses.","ref":"AWS.HealthLake.html#list_fhir_import_jobs/3","title":"AWS.HealthLake.list_fhir_import_jobs/3","type":"function"},{"doc":"Returns a list of all existing tags associated with a data store.","ref":"AWS.HealthLake.html#list_tags_for_resource/3","title":"AWS.HealthLake.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.HealthLake.html#metadata/0","title":"AWS.HealthLake.metadata/0","type":"function"},{"doc":"Begins a FHIR export job.","ref":"AWS.HealthLake.html#start_fhir_export_job/3","title":"AWS.HealthLake.start_fhir_export_job/3","type":"function"},{"doc":"Begins a FHIR Import job.","ref":"AWS.HealthLake.html#start_fhir_import_job/3","title":"AWS.HealthLake.start_fhir_import_job/3","type":"function"},{"doc":"Adds a user specified key and value tag to a data store.","ref":"AWS.HealthLake.html#tag_resource/3","title":"AWS.HealthLake.tag_resource/3","type":"function"},{"doc":"Removes tags from a data store.","ref":"AWS.HealthLake.html#untag_resource/3","title":"AWS.HealthLake.untag_resource/3","type":"function"},{"doc":"Amazon Honeycode is a fully managed service that allows you to quickly build\nmobile and web apps for teams—without programming.\n\nBuild Honeycode apps for managing almost anything, like projects, customers,\noperations, approvals, resources, and even your team.","ref":"AWS.Honeycode.html","title":"AWS.Honeycode","type":"module"},{"doc":"The BatchCreateTableRows API allows you to create one or more rows at the end of\na table in a workbook.\n\nThe API allows you to specify the values to set in some or all of the columns in\nthe new rows.\n\nIf a column is not explicitly set in a specific row, then the column level\nformula specified in the table will be applied to the new row. If there is no\ncolumn level formula but the last row of the table has a formula, then that\nformula will be copied down to the new row. If there is no column level formula\nand no formula in the last row of the table, then that column will be left blank\nfor the new rows.","ref":"AWS.Honeycode.html#batch_create_table_rows/5","title":"AWS.Honeycode.batch_create_table_rows/5","type":"function"},{"doc":"The BatchDeleteTableRows API allows you to delete one or more rows from a table\nin a workbook.\n\nYou need to specify the ids of the rows that you want to delete from the table.","ref":"AWS.Honeycode.html#batch_delete_table_rows/5","title":"AWS.Honeycode.batch_delete_table_rows/5","type":"function"},{"doc":"The BatchUpdateTableRows API allows you to update one or more rows in a table in\na workbook.\n\nYou can specify the values to set in some or all of the columns in the table for\nthe specified rows. If a column is not explicitly specified in a particular row,\nthen that column will not be updated for that row. To clear out the data in a\nspecific cell, you need to set the value as an empty string (\"\").","ref":"AWS.Honeycode.html#batch_update_table_rows/5","title":"AWS.Honeycode.batch_update_table_rows/5","type":"function"},{"doc":"The BatchUpsertTableRows API allows you to upsert one or more rows in a table.\n\nThe upsert operation takes a filter expression as input and evaluates it to find\nmatching rows on the destination table. If matching rows are found, it will\nupdate the cells in the matching rows to new values specified in the request. If\nno matching rows are found, a new row is added at the end of the table and the\ncells in that row are set to the new values specified in the request.\n\nYou can specify the values to set in some or all of the columns in the table for\nthe matching or newly appended rows. If a column is not explicitly specified for\na particular row, then that column will not be updated for that row. To clear\nout the data in a specific cell, you need to set the value as an empty string\n(\"\").","ref":"AWS.Honeycode.html#batch_upsert_table_rows/5","title":"AWS.Honeycode.batch_upsert_table_rows/5","type":"function"},{"doc":"The DescribeTableDataImportJob API allows you to retrieve the status and details\nof a table data import job.","ref":"AWS.Honeycode.html#describe_table_data_import_job/5","title":"AWS.Honeycode.describe_table_data_import_job/5","type":"function"},{"doc":"The GetScreenData API allows retrieval of data from a screen in a Honeycode app.\n\nThe API allows setting local variables in the screen to filter, sort or\notherwise affect what will be displayed on the screen.","ref":"AWS.Honeycode.html#get_screen_data/3","title":"AWS.Honeycode.get_screen_data/3","type":"function"},{"doc":"The InvokeScreenAutomation API allows invoking an action defined in a screen in\na Honeycode app.\n\nThe API allows setting local variables, which can then be used in the automation\nbeing invoked. This allows automating the Honeycode app interactions to write,\nupdate or delete data in the workbook.","ref":"AWS.Honeycode.html#invoke_screen_automation/7","title":"AWS.Honeycode.invoke_screen_automation/7","type":"function"},{"doc":"The ListTableColumns API allows you to retrieve a list of all the columns in a\ntable in a workbook.","ref":"AWS.Honeycode.html#list_table_columns/5","title":"AWS.Honeycode.list_table_columns/5","type":"function"},{"doc":"The ListTableRows API allows you to retrieve a list of all the rows in a table\nin a workbook.","ref":"AWS.Honeycode.html#list_table_rows/5","title":"AWS.Honeycode.list_table_rows/5","type":"function"},{"doc":"The ListTables API allows you to retrieve a list of all the tables in a\nworkbook.","ref":"AWS.Honeycode.html#list_tables/5","title":"AWS.Honeycode.list_tables/5","type":"function"},{"doc":"The ListTagsForResource API allows you to return a resource's tags.","ref":"AWS.Honeycode.html#list_tags_for_resource/3","title":"AWS.Honeycode.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.Honeycode.html#metadata/0","title":"AWS.Honeycode.metadata/0","type":"function"},{"doc":"The QueryTableRows API allows you to use a filter formula to query for specific\nrows in a table.","ref":"AWS.Honeycode.html#query_table_rows/5","title":"AWS.Honeycode.query_table_rows/5","type":"function"},{"doc":"The StartTableDataImportJob API allows you to start an import job on a table.\n\nThis API will only return the id of the job that was started. To find out the\nstatus of the import request, you need to call the DescribeTableDataImportJob\nAPI.","ref":"AWS.Honeycode.html#start_table_data_import_job/5","title":"AWS.Honeycode.start_table_data_import_job/5","type":"function"},{"doc":"The TagResource API allows you to add tags to an ARN-able resource.\n\nResource includes workbook, table, screen and screen-automation.","ref":"AWS.Honeycode.html#tag_resource/4","title":"AWS.Honeycode.tag_resource/4","type":"function"},{"doc":"The UntagResource API allows you to removes tags from an ARN-able resource.\n\nResource includes workbook, table, screen and screen-automation.","ref":"AWS.Honeycode.html#untag_resource/4","title":"AWS.Honeycode.untag_resource/4","type":"function"},{"doc":"Identity and Access Management\n\nIdentity and Access Management (IAM) is a web service for securely controlling\naccess to Amazon Web Services services.\n\nWith IAM, you can centrally manage users, security credentials such as access\nkeys, and permissions that control which Amazon Web Services resources users and\napplications can access. For more information about IAM, see [Identity and Access Management (IAM)](http://aws.amazon.com/iam/) and the [Identity and Access Management User\nGuide](https://docs.aws.amazon.com/IAM/latest/UserGuide/).","ref":"AWS.IAM.html","title":"AWS.IAM","type":"module"},{"doc":"Adds a new client ID (also known as audience) to the list of client IDs already\nregistered for the specified IAM OpenID Connect (OIDC) provider resource.\n\nThis operation is idempotent; it does not fail or return an error if you add an\nexisting client ID to the provider.","ref":"AWS.IAM.html#add_client_id_to_open_id_connect_provider/3","title":"AWS.IAM.add_client_id_to_open_id_connect_provider/3","type":"function"},{"doc":"Adds the specified IAM role to the specified instance profile.\n\nAn instance profile can contain only one role, and this quota cannot be\nincreased. You can remove the existing role and then add a different role to an\ninstance profile. You must then wait for the change to appear across all of\nAmazon Web Services because of [eventual consistency](https://en.wikipedia.org/wiki/Eventual_consistency). To force the\nchange, you must [disassociate the instance profile](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DisassociateIamInstanceProfile.html)\nand then [associate the instance profile](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AssociateIamInstanceProfile.html),\nor you can stop your instance and then restart it.\n\nThe caller of this operation must be granted the `PassRole` permission on the\nIAM role by a permissions policy.\n\nFor more information about roles, see [IAM roles](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles.html) in the\n*IAM User Guide*. For more information about instance profiles, see [Using instance\nprofiles](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_use_switch-role-ec2_instance-profiles.html)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#add_role_to_instance_profile/3","title":"AWS.IAM.add_role_to_instance_profile/3","type":"function"},{"doc":"Adds the specified user to the specified group.","ref":"AWS.IAM.html#add_user_to_group/3","title":"AWS.IAM.add_user_to_group/3","type":"function"},{"doc":"Attaches the specified managed policy to the specified IAM group.\n\nYou use this operation to attach a managed policy to a group. To embed an inline\npolicy in a group, use [ `PutGroupPolicy`\n](https://docs.aws.amazon.com/IAM/latest/APIReference/API_PutGroupPolicy.html).\n\nAs a best practice, you can validate your IAM policies. To learn more, see\n[Validating IAM policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_policy-validator.html)\nin the *IAM User Guide*.\n\nFor more information about policies, see [Managed policies and inline policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/policies-managed-vs-inline.html)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#attach_group_policy/3","title":"AWS.IAM.attach_group_policy/3","type":"function"},{"doc":"Attaches the specified managed policy to the specified IAM role.\n\nWhen you attach a managed policy to a role, the managed policy becomes part of\nthe role's permission (access) policy.\n\nYou cannot use a managed policy as the role's trust policy. The role's trust\npolicy is created at the same time as the role, using [ `CreateRole`\n](https://docs.aws.amazon.com/IAM/latest/APIReference/API_CreateRole.html). You\ncan update a role's trust policy using [ `UpdateAssumerolePolicy`\n](https://docs.aws.amazon.com/IAM/latest/APIReference/API_UpdateAssumeRolePolicy.html).\n\nUse this operation to attach a *managed* policy to a role. To embed an inline\npolicy in a role, use [ `PutRolePolicy`\n](https://docs.aws.amazon.com/IAM/latest/APIReference/API_PutRolePolicy.html).\nFor more information about policies, see [Managed policies and inline policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/policies-managed-vs-inline.html)\nin the *IAM User Guide*.\n\nAs a best practice, you can validate your IAM policies. To learn more, see\n[Validating IAM policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_policy-validator.html)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#attach_role_policy/3","title":"AWS.IAM.attach_role_policy/3","type":"function"},{"doc":"Attaches the specified managed policy to the specified user.\n\nYou use this operation to attach a *managed* policy to a user. To embed an\ninline policy in a user, use [ `PutUserPolicy`\n](https://docs.aws.amazon.com/IAM/latest/APIReference/API_PutUserPolicy.html).\n\nAs a best practice, you can validate your IAM policies. To learn more, see\n[Validating IAM policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_policy-validator.html)\nin the *IAM User Guide*.\n\nFor more information about policies, see [Managed policies and inline policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/policies-managed-vs-inline.html)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#attach_user_policy/3","title":"AWS.IAM.attach_user_policy/3","type":"function"},{"doc":"Changes the password of the IAM user who is calling this operation.\n\nThis operation can be performed using the CLI, the Amazon Web Services API, or\nthe **My Security Credentials** page in the Amazon Web Services Management\nConsole. The Amazon Web Services account root user password is not affected by\nthis operation.\n\nUse `UpdateLoginProfile` to use the CLI, the Amazon Web Services API, or the\n**Users** page in the IAM console to change the password for any IAM user. For\nmore information about modifying passwords, see [Managing passwords](https://docs.aws.amazon.com/IAM/latest/UserGuide/Using_ManagingLogins.html)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#change_password/3","title":"AWS.IAM.change_password/3","type":"function"},{"doc":"Creates a new Amazon Web Services secret access key and corresponding Amazon Web\nServices access key ID for the specified user.\n\nThe default status for new keys is `Active`.\n\nIf you do not specify a user name, IAM determines the user name implicitly based\non the Amazon Web Services access key ID signing the request. This operation\nworks for access keys under the Amazon Web Services account. Consequently, you\ncan use this operation to manage Amazon Web Services account root user\ncredentials. This is true even if the Amazon Web Services account has no\nassociated users.\n\nFor information about quotas on the number of keys you can create, see [IAM and STS\nquotas](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_iam-quotas.html)\nin the *IAM User Guide*.\n\nTo ensure the security of your Amazon Web Services account, the secret access\nkey is accessible only during key and user creation. You must save the key (for\nexample, in a text file) if you want to be able to access it again. If a secret\nkey is lost, you can delete the access keys for the associated user and then\ncreate new keys.","ref":"AWS.IAM.html#create_access_key/3","title":"AWS.IAM.create_access_key/3","type":"function"},{"doc":"Creates an alias for your Amazon Web Services account.\n\nFor information about using an Amazon Web Services account alias, see [Creating, deleting, and listing an Amazon Web Services account\nalias](https://docs.aws.amazon.com/signin/latest/userguide/CreateAccountAlias.html)\nin the *Amazon Web Services Sign-In User Guide*.","ref":"AWS.IAM.html#create_account_alias/3","title":"AWS.IAM.create_account_alias/3","type":"function"},{"doc":"Creates a new group.\n\nFor information about the number of groups you can create, see [IAM and STS quotas](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_iam-quotas.html)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#create_group/3","title":"AWS.IAM.create_group/3","type":"function"},{"doc":"Creates a new instance profile.\n\nFor information about instance profiles, see [Using roles for applications on Amazon\nEC2](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_use_switch-role-ec2.html)\nin the *IAM User Guide*, and [Instance profiles](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-roles-for-amazon-ec2.html#ec2-instance-profile)\nin the *Amazon EC2 User Guide*.\n\nFor information about the number of instance profiles you can create, see [IAM object\nquotas](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_iam-quotas.html)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#create_instance_profile/3","title":"AWS.IAM.create_instance_profile/3","type":"function"},{"doc":"Creates a password for the specified IAM user.\n\nA password allows an IAM user to access Amazon Web Services services through the\nAmazon Web Services Management Console.\n\nYou can use the CLI, the Amazon Web Services API, or the **Users** page in the\nIAM console to create a password for any IAM user. Use `ChangePassword` to\nupdate your own existing password in the **My Security Credentials** page in the\nAmazon Web Services Management Console.\n\nFor more information about managing passwords, see [Managing passwords](https://docs.aws.amazon.com/IAM/latest/UserGuide/Using_ManagingLogins.html)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#create_login_profile/3","title":"AWS.IAM.create_login_profile/3","type":"function"},{"doc":"Creates an IAM entity to describe an identity provider (IdP) that supports\n[OpenID Connect (OIDC)](http://openid.net/connect/).   The OIDC provider that you create with this operation can be used as a principal\nin a role's trust policy. Such a policy establishes a trust relationship between\nAmazon Web Services and the OIDC provider.\n\nIf you are using an OIDC identity provider from Google, Facebook, or Amazon\nCognito, you don't need to create a separate IAM identity provider. These OIDC\nidentity providers are already built-in to Amazon Web Services and are available\nfor your use. Instead, you can move directly to creating new roles using your\nidentity provider. To learn more, see [Creating a role for web identity or\nOpenID connect\nfederation](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_create_for-idp_oidc.html)\nin the *IAM User Guide*.\n\nWhen you create the IAM OIDC provider, you specify the following:\n\n  * The URL of the OIDC identity provider (IdP) to trust\n\n  * A list of client IDs (also known as audiences) that identify the\napplication or applications allowed to authenticate using the OIDC provider\n\n  * A list of tags that are attached to the specified IAM OIDC\nprovider\n\n  * A list of thumbprints of one or more server certificates that the\nIdP uses\n\nYou get all of this information from the OIDC IdP you want to use to access\nAmazon Web Services.\n\nAmazon Web Services secures communication with some OIDC identity providers\n(IdPs) through our library of trusted root certificate authorities (CAs) instead\nof using a certificate thumbprint to verify your IdP server certificate. In\nthese cases, your legacy thumbprint remains in your configuration, but is no\nlonger used for validation. These OIDC IdPs include Auth0, GitHub, GitLab,\nGoogle, and those that use an Amazon S3 bucket to host a JSON Web Key Set (JWKS)\nendpoint.\n\nThe trust for the OIDC provider is derived from the IAM provider that this\noperation creates. Therefore, it is best to limit access to the\n`CreateOpenIDConnectProvider` operation to highly privileged users.","ref":"AWS.IAM.html#create_open_id_connect_provider/3","title":"AWS.IAM.create_open_id_connect_provider/3","type":"function"},{"doc":"Creates a new managed policy for your Amazon Web Services account.\n\nThis operation creates a policy version with a version identifier of `v1` and\nsets v1 as the policy's default version. For more information about policy\nversions, see [Versioning for managed policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/policies-managed-versions.html)\nin the *IAM User Guide*.\n\nAs a best practice, you can validate your IAM policies. To learn more, see\n[Validating IAM policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_policy-validator.html)\nin the *IAM User Guide*.\n\nFor more information about managed policies in general, see [Managed policies and inline\npolicies](https://docs.aws.amazon.com/IAM/latest/UserGuide/policies-managed-vs-inline.html)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#create_policy/3","title":"AWS.IAM.create_policy/3","type":"function"},{"doc":"Creates a new version of the specified managed policy.\n\nTo update a managed policy, you create a new policy version. A managed policy\ncan have up to five versions. If the policy has five versions, you must delete\nan existing version using `DeletePolicyVersion` before you create a new version.\n\nOptionally, you can set the new version as the policy's default version. The\ndefault version is the version that is in effect for the IAM users, groups, and\nroles to which the policy is attached.\n\nFor more information about managed policy versions, see [Versioning for managed policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/policies-managed-versions.html)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#create_policy_version/3","title":"AWS.IAM.create_policy_version/3","type":"function"},{"doc":"Creates a new role for your Amazon Web Services account.\n\nFor more information about roles, see [IAM roles](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles.html) in the\n*IAM User Guide*. For information about quotas for role names and the number of\nroles you can create, see [IAM and STS quotas](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_iam-quotas.html)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#create_role/3","title":"AWS.IAM.create_role/3","type":"function"},{"doc":"Creates an IAM resource that describes an identity provider (IdP) that supports\nSAML 2.0.\n\nThe SAML provider resource that you create with this operation can be used as a\nprincipal in an IAM role's trust policy. Such a policy can enable federated\nusers who sign in using the SAML IdP to assume the role. You can create an IAM\nrole that supports Web-based single sign-on (SSO) to the Amazon Web Services\nManagement Console or one that supports API access to Amazon Web Services.\n\nWhen you create the SAML provider resource, you upload a SAML metadata document\nthat you get from your IdP. That document includes the issuer's name, expiration\ninformation, and keys that can be used to validate the SAML authentication\nresponse (assertions) that the IdP sends. You must generate the metadata\ndocument using the identity management software that is used as your\norganization's IdP.\n\nThis operation requires [Signature Version 4](https://docs.aws.amazon.com/general/latest/gr/signature-version-4.html).\n\nFor more information, see [Enabling SAML 2.0 federated users to access the Amazon Web Services Management\nConsole](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_providers_enable-console-saml.html)\nand [About SAML 2.0-based federation](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_providers_saml.html)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#create_saml_provider/3","title":"AWS.IAM.create_saml_provider/3","type":"function"},{"doc":"Creates an IAM role that is linked to a specific Amazon Web Services service.\n\nThe service controls the attached policies and when the role can be deleted.\nThis helps ensure that the service is not broken by an unexpectedly changed or\ndeleted role, which could put your Amazon Web Services resources into an unknown\nstate. Allowing the service to control the role helps improve service stability\nand proper cleanup when a service and its role are no longer needed. For more\ninformation, see [Using service-linked roles](https://docs.aws.amazon.com/IAM/latest/UserGuide/using-service-linked-roles.html)\nin the *IAM User Guide*.\n\nTo attach a policy to this service-linked role, you must make the request using\nthe Amazon Web Services service that depends on this role.","ref":"AWS.IAM.html#create_service_linked_role/3","title":"AWS.IAM.create_service_linked_role/3","type":"function"},{"doc":"Generates a set of credentials consisting of a user name and password that can\nbe used to access the service specified in the request.\n\nThese credentials are generated by IAM, and can be used only for the specified\nservice.\n\nYou can have a maximum of two sets of service-specific credentials for each\nsupported service per user.\n\nYou can create service-specific credentials for CodeCommit and Amazon Keyspaces\n(for Apache Cassandra).\n\nYou can reset the password to a new service-generated value by calling\n`ResetServiceSpecificCredential`.\n\nFor more information about service-specific credentials, see [Using IAM with CodeCommit: Git credentials, SSH keys, and Amazon Web Services access\nkeys](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_ssh-keys.html)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#create_service_specific_credential/3","title":"AWS.IAM.create_service_specific_credential/3","type":"function"},{"doc":"Creates a new IAM user for your Amazon Web Services account.\n\nFor information about quotas for the number of IAM users you can create, see\n[IAM and STS quotas](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_iam-quotas.html)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#create_user/3","title":"AWS.IAM.create_user/3","type":"function"},{"doc":"Creates a new virtual MFA device for the Amazon Web Services account.\n\nAfter creating the virtual MFA, use `EnableMFADevice` to attach the MFA device\nto an IAM user. For more information about creating and working with virtual MFA\ndevices, see [Using a virtual MFA device](https://docs.aws.amazon.com/IAM/latest/UserGuide/Using_VirtualMFA.html)\nin the *IAM User Guide*.\n\nFor information about the maximum number of MFA devices you can create, see [IAM and STS\nquotas](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_iam-quotas.html)\nin the *IAM User Guide*.\n\nThe seed information contained in the QR code and the Base32 string should be\ntreated like any other secret access information. In other words, protect the\nseed information as you would your Amazon Web Services access keys or your\npasswords. After you provision your virtual device, you should ensure that the\ninformation is destroyed following secure procedures.","ref":"AWS.IAM.html#create_virtual_mfa_device/3","title":"AWS.IAM.create_virtual_mfa_device/3","type":"function"},{"doc":"Deactivates the specified MFA device and removes it from association with the\nuser name for which it was originally enabled.\n\nFor more information about creating and working with virtual MFA devices, see\n[Enabling a virtual multi-factor authentication (MFA) device](https://docs.aws.amazon.com/IAM/latest/UserGuide/Using_VirtualMFA.html)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#deactivate_mfa_device/3","title":"AWS.IAM.deactivate_mfa_device/3","type":"function"},{"doc":"Deletes the access key pair associated with the specified IAM user.\n\nIf you do not specify a user name, IAM determines the user name implicitly based\non the Amazon Web Services access key ID signing the request. This operation\nworks for access keys under the Amazon Web Services account. Consequently, you\ncan use this operation to manage Amazon Web Services account root user\ncredentials even if the Amazon Web Services account has no associated users.","ref":"AWS.IAM.html#delete_access_key/3","title":"AWS.IAM.delete_access_key/3","type":"function"},{"doc":"Deletes the specified Amazon Web Services account alias.\n\nFor information about using an Amazon Web Services account alias, see [Creating, deleting, and listing an Amazon Web Services account\nalias](https://docs.aws.amazon.com/signin/latest/userguide/CreateAccountAlias.html)\nin the *Amazon Web Services Sign-In User Guide*.","ref":"AWS.IAM.html#delete_account_alias/3","title":"AWS.IAM.delete_account_alias/3","type":"function"},{"doc":"Deletes the password policy for the Amazon Web Services account.\n\nThere are no parameters.","ref":"AWS.IAM.html#delete_account_password_policy/3","title":"AWS.IAM.delete_account_password_policy/3","type":"function"},{"doc":"Deletes the specified IAM group.\n\nThe group must not contain any users or have any attached policies.","ref":"AWS.IAM.html#delete_group/3","title":"AWS.IAM.delete_group/3","type":"function"},{"doc":"Deletes the specified inline policy that is embedded in the specified IAM group.\n\nA group can also have managed policies attached to it. To detach a managed\npolicy from a group, use `DetachGroupPolicy`. For more information about\npolicies, refer to [Managed policies and inline policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/policies-managed-vs-inline.html)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#delete_group_policy/3","title":"AWS.IAM.delete_group_policy/3","type":"function"},{"doc":"Deletes the specified instance profile.\n\nThe instance profile must not have an associated role.\n\nMake sure that you do not have any Amazon EC2 instances running with the\ninstance profile you are about to delete. Deleting a role or instance profile\nthat is associated with a running instance will break any applications running\non the instance.\n\nFor more information about instance profiles, see [Using instance profiles](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_use_switch-role-ec2_instance-profiles.html)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#delete_instance_profile/3","title":"AWS.IAM.delete_instance_profile/3","type":"function"},{"doc":"Deletes the password for the specified IAM user, For more information, see\n[Managing passwords for IAM users](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_passwords_admin-change-user.html).\n\nYou can use the CLI, the Amazon Web Services API, or the **Users** page in the\nIAM console to delete a password for any IAM user. You can use `ChangePassword`\nto update, but not delete, your own password in the","ref":"AWS.IAM.html#delete_login_profile/3","title":"AWS.IAM.delete_login_profile/3","type":"function"},{"doc":"page in the Amazon Web Services Management Console.\n\nDeleting a user's password does not prevent a user from accessing Amazon Web\nServices through the command line interface or the API. To prevent all user\naccess, you must also either make any access keys inactive or delete them. For\nmore information about making keys inactive or deleting them, see\n`UpdateAccessKey` and `DeleteAccessKey`.","ref":"AWS.IAM.html#delete_login_profile/3-my-security-credentials","title":"My Security Credentials - AWS.IAM.delete_login_profile/3","type":"function"},{"doc":"Deletes an OpenID Connect identity provider (IdP) resource object in IAM.\n\nDeleting an IAM OIDC provider resource does not update any roles that reference\nthe provider as a principal in their trust policies. Any attempt to assume a\nrole that references a deleted provider fails.\n\nThis operation is idempotent; it does not fail or return an error if you call\nthe operation for a provider that does not exist.","ref":"AWS.IAM.html#delete_open_id_connect_provider/3","title":"AWS.IAM.delete_open_id_connect_provider/3","type":"function"},{"doc":"Deletes the specified managed policy.\n\nBefore you can delete a managed policy, you must first detach the policy from\nall users, groups, and roles that it is attached to. In addition, you must\ndelete all the policy's versions. The following steps describe the process for\ndeleting a managed policy:\n\n  * Detach the policy from all users, groups, and roles that the\npolicy is attached to, using `DetachUserPolicy`, `DetachGroupPolicy`, or\n`DetachRolePolicy`. To list all the users, groups, and roles that a policy is\nattached to, use `ListEntitiesForPolicy`.\n\n  * Delete all versions of the policy using `DeletePolicyVersion`. To\nlist the policy's versions, use `ListPolicyVersions`. You cannot use\n`DeletePolicyVersion` to delete the version that is marked as the default\nversion. You delete the policy's default version in the next step of the\nprocess.\n\n  * Delete the policy (this automatically deletes the policy's default\nversion) using this operation.\n\nFor information about managed policies, see [Managed policies and inline policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/policies-managed-vs-inline.html)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#delete_policy/3","title":"AWS.IAM.delete_policy/3","type":"function"},{"doc":"Deletes the specified version from the specified managed policy.\n\nYou cannot delete the default version from a policy using this operation. To\ndelete the default version from a policy, use `DeletePolicy`. To find out which\nversion of a policy is marked as the default version, use `ListPolicyVersions`.\n\nFor information about versions for managed policies, see [Versioning for managed policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/policies-managed-versions.html)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#delete_policy_version/3","title":"AWS.IAM.delete_policy_version/3","type":"function"},{"doc":"Deletes the specified role.\n\nUnlike the Amazon Web Services Management Console, when you delete a role\nprogrammatically, you must delete the items attached to the role manually, or\nthe deletion fails. For more information, see [Deleting an IAM role](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_manage_delete.html#roles-managingrole-deleting-cli).\nBefore attempting to delete a role, remove the following attached items:\n\n  * Inline policies (`DeleteRolePolicy`)\n\n  * Attached managed policies (`DetachRolePolicy`)\n\n  * Instance profile (`RemoveRoleFromInstanceProfile`)\n\n  * Optional – Delete instance profile after detaching from role for\nresource clean up (`DeleteInstanceProfile`)\n\nMake sure that you do not have any Amazon EC2 instances running with the role\nyou are about to delete. Deleting a role or instance profile that is associated\nwith a running instance will break any applications running on the instance.","ref":"AWS.IAM.html#delete_role/3","title":"AWS.IAM.delete_role/3","type":"function"},{"doc":"Deletes the permissions boundary for the specified IAM role.\n\nYou cannot set the boundary for a service-linked role.\n\nDeleting the permissions boundary for a role might increase its permissions. For\nexample, it might allow anyone who assumes the role to perform all the actions\ngranted in its permissions policies.","ref":"AWS.IAM.html#delete_role_permissions_boundary/3","title":"AWS.IAM.delete_role_permissions_boundary/3","type":"function"},{"doc":"Deletes the specified inline policy that is embedded in the specified IAM role.\n\nA role can also have managed policies attached to it. To detach a managed policy\nfrom a role, use `DetachRolePolicy`. For more information about policies, refer\nto [Managed policies and inline policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/policies-managed-vs-inline.html)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#delete_role_policy/3","title":"AWS.IAM.delete_role_policy/3","type":"function"},{"doc":"Deletes a SAML provider resource in IAM.\n\nDeleting the provider resource from IAM does not update any roles that reference\nthe SAML provider resource's ARN as a principal in their trust policies. Any\nattempt to assume a role that references a non-existent provider resource ARN\nfails.\n\nThis operation requires [Signature Version 4](https://docs.aws.amazon.com/general/latest/gr/signature-version-4.html).","ref":"AWS.IAM.html#delete_saml_provider/3","title":"AWS.IAM.delete_saml_provider/3","type":"function"},{"doc":"Deletes the specified server certificate.\n\nFor more information about working with server certificates, see [Working with server\ncertificates](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_server-certs.html)\nin the *IAM User Guide*. This topic also includes a list of Amazon Web Services\nservices that can use the server certificates that you manage with IAM.\n\nIf you are using a server certificate with Elastic Load Balancing, deleting the\ncertificate could have implications for your application. If Elastic Load\nBalancing doesn't detect the deletion of bound certificates, it may continue to\nuse the certificates. This could cause Elastic Load Balancing to stop accepting\ntraffic. We recommend that you remove the reference to the certificate from\nElastic Load Balancing before using this command to delete the certificate. For\nmore information, see\n[DeleteLoadBalancerListeners](https://docs.aws.amazon.com/ElasticLoadBalancing/latest/APIReference/API_DeleteLoadBalancerListeners.html)\nin the *Elastic Load Balancing API Reference*.","ref":"AWS.IAM.html#delete_server_certificate/3","title":"AWS.IAM.delete_server_certificate/3","type":"function"},{"doc":"Submits a service-linked role deletion request and returns a `DeletionTaskId`,\nwhich you can use to check the status of the deletion.\n\nBefore you call this operation, confirm that the role has no active sessions and\nthat any resources used by the role in the linked service are deleted. If you\ncall this operation more than once for the same service-linked role and an\nearlier deletion task is not complete, then the `DeletionTaskId` of the earlier\nrequest is returned.\n\nIf you submit a deletion request for a service-linked role whose linked service\nis still accessing a resource, then the deletion task fails. If it fails, the\n`GetServiceLinkedRoleDeletionStatus` operation returns the reason for the\nfailure, usually including the resources that must be deleted. To delete the\nservice-linked role, you must first remove those resources from the linked\nservice and then submit the deletion request again. Resources are specific to\nthe service that is linked to the role. For more information about removing\nresources from a service, see the [Amazon Web Services documentation](http://docs.aws.amazon.com/) for your service.\n\nFor more information about service-linked roles, see [Roles terms and concepts: Amazon Web Services service-linked\nrole](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_terms-and-concepts.html#iam-term-service-linked-role)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#delete_service_linked_role/3","title":"AWS.IAM.delete_service_linked_role/3","type":"function"},{"doc":"Deletes the specified service-specific credential.","ref":"AWS.IAM.html#delete_service_specific_credential/3","title":"AWS.IAM.delete_service_specific_credential/3","type":"function"},{"doc":"Deletes a signing certificate associated with the specified IAM user.\n\nIf you do not specify a user name, IAM determines the user name implicitly based\non the Amazon Web Services access key ID signing the request. This operation\nworks for access keys under the Amazon Web Services account. Consequently, you\ncan use this operation to manage Amazon Web Services account root user\ncredentials even if the Amazon Web Services account has no associated IAM users.","ref":"AWS.IAM.html#delete_signing_certificate/3","title":"AWS.IAM.delete_signing_certificate/3","type":"function"},{"doc":"Deletes the specified SSH public key.\n\nThe SSH public key deleted by this operation is used only for authenticating the\nassociated IAM user to an CodeCommit repository. For more information about\nusing SSH keys to authenticate to an CodeCommit repository, see [Set up CodeCommit for SSH\nconnections](https://docs.aws.amazon.com/codecommit/latest/userguide/setting-up-credentials-ssh.html)\nin the *CodeCommit User Guide*.","ref":"AWS.IAM.html#delete_ssh_public_key/3","title":"AWS.IAM.delete_ssh_public_key/3","type":"function"},{"doc":"Deletes the specified IAM user.\n\nUnlike the Amazon Web Services Management Console, when you delete a user\nprogrammatically, you must delete the items attached to the user manually, or\nthe deletion fails. For more information, see [Deleting an IAM user](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_users_manage.html#id_users_deleting_cli).\nBefore attempting to delete a user, remove the following items:\n\n  * Password (`DeleteLoginProfile`)\n\n  * Access keys (`DeleteAccessKey`)\n\n  * Signing certificate (`DeleteSigningCertificate`)\n\n  * SSH public key (`DeleteSSHPublicKey`)\n\n  * Git credentials (`DeleteServiceSpecificCredential`)\n\n  * Multi-factor authentication (MFA) device (`DeactivateMFADevice`,\n`DeleteVirtualMFADevice`)\n\n  * Inline policies (`DeleteUserPolicy`)\n\n  * Attached managed policies (`DetachUserPolicy`)\n\n  * Group memberships (`RemoveUserFromGroup`)","ref":"AWS.IAM.html#delete_user/3","title":"AWS.IAM.delete_user/3","type":"function"},{"doc":"Deletes the permissions boundary for the specified IAM user.\n\nDeleting the permissions boundary for a user might increase its permissions by\nallowing the user to perform all the actions granted in its permissions\npolicies.","ref":"AWS.IAM.html#delete_user_permissions_boundary/3","title":"AWS.IAM.delete_user_permissions_boundary/3","type":"function"},{"doc":"Deletes the specified inline policy that is embedded in the specified IAM user.\n\nA user can also have managed policies attached to it. To detach a managed policy\nfrom a user, use `DetachUserPolicy`. For more information about policies, refer\nto [Managed policies and inline policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/policies-managed-vs-inline.html)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#delete_user_policy/3","title":"AWS.IAM.delete_user_policy/3","type":"function"},{"doc":"Deletes a virtual MFA device.\n\nYou must deactivate a user's virtual MFA device before you can delete it. For\ninformation about deactivating MFA devices, see `DeactivateMFADevice`.","ref":"AWS.IAM.html#delete_virtual_mfa_device/3","title":"AWS.IAM.delete_virtual_mfa_device/3","type":"function"},{"doc":"Removes the specified managed policy from the specified IAM group.\n\nA group can also have inline policies embedded with it. To delete an inline\npolicy, use `DeleteGroupPolicy`. For information about policies, see [Managed policies and inline\npolicies](https://docs.aws.amazon.com/IAM/latest/UserGuide/policies-managed-vs-inline.html)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#detach_group_policy/3","title":"AWS.IAM.detach_group_policy/3","type":"function"},{"doc":"Removes the specified managed policy from the specified role.\n\nA role can also have inline policies embedded with it. To delete an inline\npolicy, use `DeleteRolePolicy`. For information about policies, see [Managed policies and inline\npolicies](https://docs.aws.amazon.com/IAM/latest/UserGuide/policies-managed-vs-inline.html)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#detach_role_policy/3","title":"AWS.IAM.detach_role_policy/3","type":"function"},{"doc":"Removes the specified managed policy from the specified user.\n\nA user can also have inline policies embedded with it. To delete an inline\npolicy, use `DeleteUserPolicy`. For information about policies, see [Managed policies and inline\npolicies](https://docs.aws.amazon.com/IAM/latest/UserGuide/policies-managed-vs-inline.html)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#detach_user_policy/3","title":"AWS.IAM.detach_user_policy/3","type":"function"},{"doc":"Enables the specified MFA device and associates it with the specified IAM user.\n\nWhen enabled, the MFA device is required for every subsequent login by the IAM\nuser associated with the device.","ref":"AWS.IAM.html#enable_mfa_device/3","title":"AWS.IAM.enable_mfa_device/3","type":"function"},{"doc":"Generates a credential report for the Amazon Web Services account.\n\nFor more information about the credential report, see [Getting credential reports](https://docs.aws.amazon.com/IAM/latest/UserGuide/credential-reports.html)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#generate_credential_report/3","title":"AWS.IAM.generate_credential_report/3","type":"function"},{"doc":"Generates a report for service last accessed data for Organizations.\n\nYou can generate a report for any entities (organization root, organizational\nunit, or account) or policies in your organization.\n\nTo call this operation, you must be signed in using your Organizations\nmanagement account credentials. You can use your long-term IAM user or root user\ncredentials, or temporary credentials from assuming an IAM role. SCPs must be\nenabled for your organization root. You must have the required IAM and\nOrganizations permissions. For more information, see [Refining permissions using service last accessed\ndata](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_access-advisor.html)\nin the *IAM User Guide*.\n\nYou can generate a service last accessed data report for entities by specifying\nonly the entity's path. This data includes a list of services that are allowed\nby any service control policies (SCPs) that apply to the entity.\n\nYou can generate a service last accessed data report for a policy by specifying\nan entity's path and an optional Organizations policy ID. This data includes a\nlist of services that are allowed by the specified SCP.\n\nFor each service in both report types, the data includes the most recent account\nactivity that the policy allows to account principals in the entity or the\nentity's children. For important information about the data, reporting period,\npermissions required, troubleshooting, and supported Regions see [Reducing permissions using service last accessed\ndata](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_access-advisor.html)\nin the *IAM User Guide*.\n\nThe data includes all attempts to access Amazon Web Services, not just the\nsuccessful ones. This includes all attempts that were made using the Amazon Web\nServices Management Console, the Amazon Web Services API through any of the\nSDKs, or any of the command line tools. An unexpected entry in the service last\naccessed data does not mean that an account has been compromised, because the\nrequest might have been denied. Refer to your CloudTrail logs as the\nauthoritative source for information about all API calls and whether they were\nsuccessful or denied access. For more information, see [Logging IAM events with CloudTrail](https://docs.aws.amazon.com/IAM/latest/UserGuide/cloudtrail-integration.html)\nin the *IAM User Guide*.\n\nThis operation returns a `JobId`. Use this parameter in the `\n`GetOrganizationsAccessReport` ` operation to check the status of the report\ngeneration. To check the status of this request, use the `JobId` parameter in\nthe ` `GetOrganizationsAccessReport` ` operation and test the `JobStatus`\nresponse parameter. When the job is complete, you can retrieve the report.\n\nTo generate a service last accessed data report for entities, specify an entity\npath without specifying the optional Organizations policy ID. The type of entity\nthat you specify determines the data returned in the report.\n\n  * **Root** – When you specify the organizations root as the entity,\nthe resulting report lists all of the services allowed by SCPs that are attached\nto your root. For each service, the report includes data for all accounts in\nyour organization except the management account, because the management account\nis not limited by SCPs.\n\n  * **OU** – When you specify an organizational unit (OU) as the\nentity, the resulting report lists all of the services allowed by SCPs that are\nattached to the OU and its parents. For each service, the report includes data\nfor all accounts in the OU or its children. This data excludes the management\naccount, because the management account is not limited by SCPs.\n\n  * **management account** – When you specify the management account,\nthe resulting report lists all Amazon Web Services services, because the\nmanagement account is not limited by SCPs. For each service, the report includes\ndata for only the management account.\n\n  * **Account** – When you specify another account as the entity, the\nresulting report lists all of the services allowed by SCPs that are attached to\nthe account and its parents. For each service, the report includes data for only\nthe specified account.\n\nTo generate a service last accessed data report for policies, specify an entity\npath and the optional Organizations policy ID. The type of entity that you\nspecify determines the data returned for each service.\n\n  * **Root** – When you specify the root entity and a policy ID, the\nresulting report lists all of the services that are allowed by the specified\nSCP. For each service, the report includes data for all accounts in your\norganization to which the SCP applies. This data excludes the management\naccount, because the management account is not limited by SCPs. If the SCP is\nnot attached to any entities in the organization, then the report will return a\nlist of services with no data.\n\n  * **OU** – When you specify an OU entity and a policy ID, the\nresulting report lists all of the services that are allowed by the specified\nSCP. For each service, the report includes data for all accounts in the OU or\nits children to which the SCP applies. This means that other accounts outside\nthe OU that are affected by the SCP might not be included in the data. This data\nexcludes the management account, because the management account is not limited\nby SCPs. If the SCP is not attached to the OU or one of its children, the report\nwill return a list of services with no data.\n\n  * **management account** – When you specify the management account,\nthe resulting report lists all Amazon Web Services services, because the\nmanagement account is not limited by SCPs. If you specify a policy ID in the CLI\nor API, the policy is ignored. For each service, the report includes data for\nonly the management account.\n\n  * **Account** – When you specify another account entity and a policy\nID, the resulting report lists all of the services that are allowed by the\nspecified SCP. For each service, the report includes data for only the specified\naccount. This means that other accounts in the organization that are affected by\nthe SCP might not be included in the data. If the SCP is not attached to the\naccount, the report will return a list of services with no data.\n\nService last accessed data does not use other policy types when determining\nwhether a principal could access a service. These other policy types include\nidentity-based policies, resource-based policies, access control lists, IAM\npermissions boundaries, and STS assume role policies. It only applies SCP logic.\nFor more about the evaluation of policy types, see [Evaluating policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_evaluation-logic.html#policy-eval-basics)\nin the *IAM User Guide*.\n\nFor more information about service last accessed data, see [Reducing policy scope by viewing user\nactivity](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_access-advisor.html)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#generate_organizations_access_report/3","title":"AWS.IAM.generate_organizations_access_report/3","type":"function"},{"doc":"Generates a report that includes details about when an IAM resource (user,\ngroup, role, or policy) was last used in an attempt to access Amazon Web\nServices services.\n\nRecent activity usually appears within four hours. IAM reports activity for at\nleast the last 400 days, or less if your Region began supporting this feature\nwithin the last year. For more information, see [Regions where data is tracked](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_access-advisor.html#access-advisor_tracking-period).\nFor more information about services and actions for which action last accessed\ninformation is displayed, see [IAM action last accessed information services and actions](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_access-advisor-action-last-accessed.html).\n\nThe service last accessed data includes all attempts to access an Amazon Web\nServices API, not just the successful ones. This includes all attempts that were\nmade using the Amazon Web Services Management Console, the Amazon Web Services\nAPI through any of the SDKs, or any of the command line tools. An unexpected\nentry in the service last accessed data does not mean that your account has been\ncompromised, because the request might have been denied. Refer to your\nCloudTrail logs as the authoritative source for information about all API calls\nand whether they were successful or denied access. For more information,\nsee [Logging IAM events with CloudTrail](https://docs.aws.amazon.com/IAM/latest/UserGuide/cloudtrail-integration.html)\nin the *IAM User Guide*.\n\nThe `GenerateServiceLastAccessedDetails` operation returns a `JobId`. Use this\nparameter in the following operations to retrieve the following details from\nyour report:\n\n  * `GetServiceLastAccessedDetails` – Use this operation for users,\ngroups, roles, or policies to list every Amazon Web Services service that the\nresource could access using permissions policies. For each service, the response\nincludes information about the most recent access attempt.\n\nThe `JobId` returned by `GenerateServiceLastAccessedDetail` must be used by the\nsame role within a session, or by the same user when used to call\n`GetServiceLastAccessedDetail`.\n\n  * `GetServiceLastAccessedDetailsWithEntities` – Use this operation\nfor groups and policies to list information about the associated entities (users\nor roles) that attempted to access a specific Amazon Web Services service.\n\nTo check the status of the `GenerateServiceLastAccessedDetails` request, use the\n`JobId` parameter in the same operations and test the `JobStatus` response\nparameter.\n\nFor additional information about the permissions policies that allow an identity\n(user, group, or role) to access specific services, use the\n`ListPoliciesGrantingServiceAccess` operation.\n\nService last accessed data does not use other policy types when determining\nwhether a resource could access a service. These other policy types include\nresource-based policies, access control lists, Organizations policies, IAM\npermissions boundaries, and STS assume role policies. It only applies\npermissions policy logic. For more about the evaluation of policy types, see\n[Evaluating policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_evaluation-logic.html#policy-eval-basics)\nin the *IAM User Guide*.\n\nFor more information about service and action last accessed data, see [Reducing permissions using service last accessed\ndata](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_access-advisor.html)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#generate_service_last_accessed_details/3","title":"AWS.IAM.generate_service_last_accessed_details/3","type":"function"},{"doc":"Retrieves information about when the specified access key was last used.\n\nThe information includes the date and time of last use, along with the Amazon\nWeb Services service and Region that were specified in the last request made\nwith that key.","ref":"AWS.IAM.html#get_access_key_last_used/3","title":"AWS.IAM.get_access_key_last_used/3","type":"function"},{"doc":"Retrieves information about all IAM users, groups, roles, and policies in your\nAmazon Web Services account, including their relationships to one another.\n\nUse this operation to obtain a snapshot of the configuration of IAM permissions\n(users, groups, roles, and policies) in your account.\n\nPolicies returned by this operation are URL-encoded compliant with [RFC 3986](https://tools.ietf.org/html/rfc3986). You can use a URL decoding method to\nconvert the policy back to plain JSON text. For example, if you use Java, you\ncan use the `decode` method of the `java.net.URLDecoder` utility class in the\nJava SDK. Other languages and SDKs provide similar functionality.\n\nYou can optionally filter the results using the `Filter` parameter. You can\npaginate the results using the `MaxItems` and `Marker` parameters.","ref":"AWS.IAM.html#get_account_authorization_details/3","title":"AWS.IAM.get_account_authorization_details/3","type":"function"},{"doc":"Retrieves the password policy for the Amazon Web Services account.\n\nThis tells you the complexity requirements and mandatory rotation periods for\nthe IAM user passwords in your account. For more information about using a\npassword policy, see [Managing an IAM password policy](https://docs.aws.amazon.com/IAM/latest/UserGuide/Using_ManagingPasswordPolicies.html).","ref":"AWS.IAM.html#get_account_password_policy/3","title":"AWS.IAM.get_account_password_policy/3","type":"function"},{"doc":"Retrieves information about IAM entity usage and IAM quotas in the Amazon Web\nServices account.\n\nFor information about IAM quotas, see [IAM and STS quotas](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_iam-quotas.html)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#get_account_summary/3","title":"AWS.IAM.get_account_summary/3","type":"function"},{"doc":"Gets a list of all of the context keys referenced in the input policies.\n\nThe policies are supplied as a list of one or more strings. To get the context\nkeys from policies associated with an IAM user, group, or role, use\n`GetContextKeysForPrincipalPolicy`.\n\nContext keys are variables maintained by Amazon Web Services and its services\nthat provide details about the context of an API query request. Context keys can\nbe evaluated by testing against a value specified in an IAM policy. Use\n`GetContextKeysForCustomPolicy` to understand what key names and values you must\nsupply when you call `SimulateCustomPolicy`. Note that all parameters are shown\nin unencoded form here for clarity but must be URL encoded to be included as a\npart of a real HTML request.","ref":"AWS.IAM.html#get_context_keys_for_custom_policy/3","title":"AWS.IAM.get_context_keys_for_custom_policy/3","type":"function"},{"doc":"Gets a list of all of the context keys referenced in all the IAM policies that\nare attached to the specified IAM entity.\n\nThe entity can be an IAM user, group, or role. If you specify a user, then the\nrequest also includes all of the policies attached to groups that the user is a\nmember of.\n\nYou can optionally include a list of one or more additional policies, specified\nas strings. If you want to include *only* a list of policies by string, use\n`GetContextKeysForCustomPolicy` instead.\n\n**Note:** This operation discloses information about the permissions granted to\nother users. If you do not want users to see other user's permissions, then\nconsider allowing them to use `GetContextKeysForCustomPolicy` instead.\n\nContext keys are variables maintained by Amazon Web Services and its services\nthat provide details about the context of an API query request. Context keys can\nbe evaluated by testing against a value in an IAM policy. Use\n`GetContextKeysForPrincipalPolicy` to understand what key names and values you\nmust supply when you call `SimulatePrincipalPolicy`.","ref":"AWS.IAM.html#get_context_keys_for_principal_policy/3","title":"AWS.IAM.get_context_keys_for_principal_policy/3","type":"function"},{"doc":"Retrieves a credential report for the Amazon Web Services account.\n\nFor more information about the credential report, see [Getting credential reports](https://docs.aws.amazon.com/IAM/latest/UserGuide/credential-reports.html)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#get_credential_report/3","title":"AWS.IAM.get_credential_report/3","type":"function"},{"doc":"Returns a list of IAM users that are in the specified IAM group.\n\nYou can paginate the results using the `MaxItems` and `Marker` parameters.","ref":"AWS.IAM.html#get_group/3","title":"AWS.IAM.get_group/3","type":"function"},{"doc":"Retrieves the specified inline policy document that is embedded in the specified\nIAM group.\n\nPolicies returned by this operation are URL-encoded compliant with [RFC 3986](https://tools.ietf.org/html/rfc3986). You can use a URL decoding method to\nconvert the policy back to plain JSON text. For example, if you use Java, you\ncan use the `decode` method of the `java.net.URLDecoder` utility class in the\nJava SDK. Other languages and SDKs provide similar functionality.\n\nAn IAM group can also have managed policies attached to it. To retrieve a\nmanaged policy document that is attached to a group, use `GetPolicy` to\ndetermine the policy's default version, then use `GetPolicyVersion` to retrieve\nthe policy document.\n\nFor more information about policies, see [Managed policies and inline policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/policies-managed-vs-inline.html)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#get_group_policy/3","title":"AWS.IAM.get_group_policy/3","type":"function"},{"doc":"Retrieves information about the specified instance profile, including the\ninstance profile's path, GUID, ARN, and role.\n\nFor more information about instance profiles, see [Using instance profiles](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_use_switch-role-ec2_instance-profiles.html)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#get_instance_profile/3","title":"AWS.IAM.get_instance_profile/3","type":"function"},{"doc":"Retrieves the user name for the specified IAM user.\n\nA login profile is created when you create a password for the user to access the\nAmazon Web Services Management Console. If the user does not exist or does not\nhave a password, the operation returns a 404 (`NoSuchEntity`) error.\n\nIf you create an IAM user with access to the console, the `CreateDate` reflects\nthe date you created the initial password for the user.\n\nIf you create an IAM user with programmatic access, and then later add a\npassword for the user to access the Amazon Web Services Management Console, the\n`CreateDate` reflects the initial password creation date. A user with\nprogrammatic access does not have a login profile unless you create a password\nfor the user to access the Amazon Web Services Management Console.","ref":"AWS.IAM.html#get_login_profile/3","title":"AWS.IAM.get_login_profile/3","type":"function"},{"doc":"Retrieves information about an MFA device for a specified user.","ref":"AWS.IAM.html#get_mfa_device/3","title":"AWS.IAM.get_mfa_device/3","type":"function"},{"doc":"Returns information about the specified OpenID Connect (OIDC) provider resource\nobject in IAM.","ref":"AWS.IAM.html#get_open_id_connect_provider/3","title":"AWS.IAM.get_open_id_connect_provider/3","type":"function"},{"doc":"Retrieves the service last accessed data report for Organizations that was\npreviously generated using the ` `GenerateOrganizationsAccessReport` `\noperation.\n\nThis operation retrieves the status of your report job and the report contents.\n\nDepending on the parameters that you passed when you generated the report, the\ndata returned could include different information. For details, see\n`GenerateOrganizationsAccessReport`.\n\nTo call this operation, you must be signed in to the management account in your\norganization. SCPs must be enabled for your organization root. You must have\npermissions to perform this operation. For more information, see [Refining permissions using service last accessed\ndata](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_access-advisor.html)\nin the *IAM User Guide*.\n\nFor each service that principals in an account (root user, IAM users, or IAM\nroles) could access using SCPs, the operation returns details about the most\nrecent access attempt. If there was no attempt, the service is listed without\ndetails about the most recent attempt to access the service. If the operation\nfails, it returns the reason that it failed.\n\nBy default, the list is sorted by service namespace.","ref":"AWS.IAM.html#get_organizations_access_report/3","title":"AWS.IAM.get_organizations_access_report/3","type":"function"},{"doc":"Retrieves information about the specified managed policy, including the policy's\ndefault version and the total number of IAM users, groups, and roles to which\nthe policy is attached.\n\nTo retrieve the list of the specific users, groups, and roles that the policy is\nattached to, use `ListEntitiesForPolicy`. This operation returns metadata about\nthe policy. To retrieve the actual policy document for a specific version of the\npolicy, use `GetPolicyVersion`.\n\nThis operation retrieves information about managed policies. To retrieve\ninformation about an inline policy that is embedded with an IAM user, group, or\nrole, use `GetUserPolicy`, `GetGroupPolicy`, or `GetRolePolicy`.\n\nFor more information about policies, see [Managed policies and inline policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/policies-managed-vs-inline.html)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#get_policy/3","title":"AWS.IAM.get_policy/3","type":"function"},{"doc":"Retrieves information about the specified version of the specified managed\npolicy, including the policy document.\n\nPolicies returned by this operation are URL-encoded compliant with [RFC 3986](https://tools.ietf.org/html/rfc3986). You can use a URL decoding method to\nconvert the policy back to plain JSON text. For example, if you use Java, you\ncan use the `decode` method of the `java.net.URLDecoder` utility class in the\nJava SDK. Other languages and SDKs provide similar functionality.\n\nTo list the available versions for a policy, use `ListPolicyVersions`.\n\nThis operation retrieves information about managed policies. To retrieve\ninformation about an inline policy that is embedded in a user, group, or role,\nuse `GetUserPolicy`, `GetGroupPolicy`, or `GetRolePolicy`.\n\nFor more information about the types of policies, see [Managed policies and inline\npolicies](https://docs.aws.amazon.com/IAM/latest/UserGuide/policies-managed-vs-inline.html)\nin the *IAM User Guide*.\n\nFor more information about managed policy versions, see [Versioning for managed policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/policies-managed-versions.html)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#get_policy_version/3","title":"AWS.IAM.get_policy_version/3","type":"function"},{"doc":"Retrieves information about the specified role, including the role's path, GUID,\nARN, and the role's trust policy that grants permission to assume the role.\n\nFor more information about roles, see [IAM roles](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles.html) in the\n*IAM User Guide*.\n\nPolicies returned by this operation are URL-encoded compliant with [RFC 3986](https://tools.ietf.org/html/rfc3986). You can use a URL decoding method to\nconvert the policy back to plain JSON text. For example, if you use Java, you\ncan use the `decode` method of the `java.net.URLDecoder` utility class in the\nJava SDK. Other languages and SDKs provide similar functionality.","ref":"AWS.IAM.html#get_role/3","title":"AWS.IAM.get_role/3","type":"function"},{"doc":"Retrieves the specified inline policy document that is embedded with the\nspecified IAM role.\n\nPolicies returned by this operation are URL-encoded compliant with [RFC 3986](https://tools.ietf.org/html/rfc3986). You can use a URL decoding method to\nconvert the policy back to plain JSON text. For example, if you use Java, you\ncan use the `decode` method of the `java.net.URLDecoder` utility class in the\nJava SDK. Other languages and SDKs provide similar functionality.\n\nAn IAM role can also have managed policies attached to it. To retrieve a managed\npolicy document that is attached to a role, use `GetPolicy` to determine the\npolicy's default version, then use `GetPolicyVersion` to retrieve the policy\ndocument.\n\nFor more information about policies, see [Managed policies and inline policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/policies-managed-vs-inline.html)\nin the *IAM User Guide*.\n\nFor more information about roles, see [IAM roles](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles.html) in the\n*IAM User Guide*.","ref":"AWS.IAM.html#get_role_policy/3","title":"AWS.IAM.get_role_policy/3","type":"function"},{"doc":"Returns the SAML provider metadocument that was uploaded when the IAM SAML\nprovider resource object was created or updated.\n\nThis operation requires [Signature Version 4](https://docs.aws.amazon.com/general/latest/gr/signature-version-4.html).","ref":"AWS.IAM.html#get_saml_provider/3","title":"AWS.IAM.get_saml_provider/3","type":"function"},{"doc":"Retrieves information about the specified server certificate stored in IAM.\n\nFor more information about working with server certificates, see [Working with server\ncertificates](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_server-certs.html)\nin the *IAM User Guide*. This topic includes a list of Amazon Web Services\nservices that can use the server certificates that you manage with IAM.","ref":"AWS.IAM.html#get_server_certificate/3","title":"AWS.IAM.get_server_certificate/3","type":"function"},{"doc":"Retrieves a service last accessed report that was created using the\n`GenerateServiceLastAccessedDetails` operation.\n\nYou can use the `JobId` parameter in `GetServiceLastAccessedDetails` to retrieve\nthe status of your report job. When the report is complete, you can retrieve the\ngenerated report. The report includes a list of Amazon Web Services services\nthat the resource (user, group, role, or managed policy) can access.\n\nService last accessed data does not use other policy types when determining\nwhether a resource could access a service. These other policy types include\nresource-based policies, access control lists, Organizations policies, IAM\npermissions boundaries, and STS assume role policies. It only applies\npermissions policy logic. For more about the evaluation of policy types, see\n[Evaluating policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_evaluation-logic.html#policy-eval-basics)\nin the *IAM User Guide*.\n\nFor each service that the resource could access using permissions policies, the\noperation returns details about the most recent access attempt. If there was no\nattempt, the service is listed without details about the most recent attempt to\naccess the service. If the operation fails, the `GetServiceLastAccessedDetails`\noperation returns the reason that it failed.\n\nThe `GetServiceLastAccessedDetails` operation returns a list of services. This\nlist includes the number of entities that have attempted to access the service\nand the date and time of the last attempt. It also returns the ARN of the\nfollowing entity, depending on the resource ARN that you used to generate the\nreport:\n\n  * **User** – Returns the user ARN that you used to generate the\nreport\n\n  * **Group** – Returns the ARN of the group member (user) that last\nattempted to access the service\n\n  * **Role** – Returns the role ARN that you used to generate the\nreport\n\n  * **Policy** – Returns the ARN of the user or role that last used\nthe policy to attempt to access the service\n\nBy default, the list is sorted by service namespace.\n\nIf you specified `ACTION_LEVEL` granularity when you generated the report, this\noperation returns service and action last accessed data. This includes the most\nrecent access attempt for each tracked action within a service. Otherwise, this\noperation returns only service data.\n\nFor more information about service and action last accessed data, see [Reducing permissions using service last accessed\ndata](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_access-advisor.html)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#get_service_last_accessed_details/3","title":"AWS.IAM.get_service_last_accessed_details/3","type":"function"},{"doc":"After you generate a group or policy report using the\n`GenerateServiceLastAccessedDetails` operation, you can use the `JobId`\nparameter in `GetServiceLastAccessedDetailsWithEntities`.\n\nThis operation retrieves the status of your report job and a list of entities\nthat could have used group or policy permissions to access the specified\nservice.\n\n  * **Group** – For a group report, this operation returns a list of\nusers in the group that could have used the group’s policies in an attempt to\naccess the service.\n\n  * **Policy** – For a policy report, this operation returns a list of\nentities (users or roles) that could have used the policy in an attempt to\naccess the service.\n\nYou can also use this operation for user or role reports to retrieve details\nabout those entities.\n\nIf the operation fails, the `GetServiceLastAccessedDetailsWithEntities`\noperation returns the reason that it failed.\n\nBy default, the list of associated entities is sorted by date, with the most\nrecent access listed first.","ref":"AWS.IAM.html#get_service_last_accessed_details_with_entities/3","title":"AWS.IAM.get_service_last_accessed_details_with_entities/3","type":"function"},{"doc":"Retrieves the status of your service-linked role deletion.\n\nAfter you use `DeleteServiceLinkedRole` to submit a service-linked role for\ndeletion, you can use the `DeletionTaskId` parameter in\n`GetServiceLinkedRoleDeletionStatus` to check the status of the deletion. If the\ndeletion fails, this operation returns the reason that it failed, if that\ninformation is returned by the service.","ref":"AWS.IAM.html#get_service_linked_role_deletion_status/3","title":"AWS.IAM.get_service_linked_role_deletion_status/3","type":"function"},{"doc":"Retrieves the specified SSH public key, including metadata about the key.\n\nThe SSH public key retrieved by this operation is used only for authenticating\nthe associated IAM user to an CodeCommit repository. For more information about\nusing SSH keys to authenticate to an CodeCommit repository, see [Set up CodeCommit for SSH\nconnections](https://docs.aws.amazon.com/codecommit/latest/userguide/setting-up-credentials-ssh.html)\nin the *CodeCommit User Guide*.","ref":"AWS.IAM.html#get_ssh_public_key/3","title":"AWS.IAM.get_ssh_public_key/3","type":"function"},{"doc":"Retrieves information about the specified IAM user, including the user's\ncreation date, path, unique ID, and ARN.\n\nIf you do not specify a user name, IAM determines the user name implicitly based\non the Amazon Web Services access key ID used to sign the request to this\noperation.","ref":"AWS.IAM.html#get_user/3","title":"AWS.IAM.get_user/3","type":"function"},{"doc":"Retrieves the specified inline policy document that is embedded in the specified\nIAM user.\n\nPolicies returned by this operation are URL-encoded compliant with [RFC 3986](https://tools.ietf.org/html/rfc3986). You can use a URL decoding method to\nconvert the policy back to plain JSON text. For example, if you use Java, you\ncan use the `decode` method of the `java.net.URLDecoder` utility class in the\nJava SDK. Other languages and SDKs provide similar functionality.\n\nAn IAM user can also have managed policies attached to it. To retrieve a managed\npolicy document that is attached to a user, use `GetPolicy` to determine the\npolicy's default version. Then use `GetPolicyVersion` to retrieve the policy\ndocument.\n\nFor more information about policies, see [Managed policies and inline policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/policies-managed-vs-inline.html)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#get_user_policy/3","title":"AWS.IAM.get_user_policy/3","type":"function"},{"doc":"Returns information about the access key IDs associated with the specified IAM\nuser.\n\nIf there is none, the operation returns an empty list.\n\nAlthough each user is limited to a small number of keys, you can still paginate\nthe results using the `MaxItems` and `Marker` parameters.\n\nIf the `UserName` is not specified, the user name is determined implicitly based\non the Amazon Web Services access key ID used to sign the request. If a\ntemporary access key is used, then `UserName` is required. If a long-term key is\nassigned to the user, then `UserName` is not required.\n\nThis operation works for access keys under the Amazon Web Services account. If\nthe Amazon Web Services account has no associated users, the root user returns\nit's own access key IDs by running this command.\n\nTo ensure the security of your Amazon Web Services account, the secret access\nkey is accessible only during key and user creation.","ref":"AWS.IAM.html#list_access_keys/3","title":"AWS.IAM.list_access_keys/3","type":"function"},{"doc":"Lists the account alias associated with the Amazon Web Services account (Note:\nyou can have only one).\n\nFor information about using an Amazon Web Services account alias, see [Creating, deleting, and listing an Amazon Web Services account\nalias](https://docs.aws.amazon.com/signin/latest/userguide/CreateAccountAlias.html)\nin the *Amazon Web Services Sign-In User Guide*.","ref":"AWS.IAM.html#list_account_aliases/3","title":"AWS.IAM.list_account_aliases/3","type":"function"},{"doc":"Lists all managed policies that are attached to the specified IAM group.\n\nAn IAM group can also have inline policies embedded with it. To list the inline\npolicies for a group, use `ListGroupPolicies`. For information about policies,\nsee [Managed policies and inline policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/policies-managed-vs-inline.html)\nin the *IAM User Guide*.\n\nYou can paginate the results using the `MaxItems` and `Marker` parameters. You\ncan use the `PathPrefix` parameter to limit the list of policies to only those\nmatching the specified path prefix. If there are no policies attached to the\nspecified group (or none that match the specified path prefix), the operation\nreturns an empty list.","ref":"AWS.IAM.html#list_attached_group_policies/3","title":"AWS.IAM.list_attached_group_policies/3","type":"function"},{"doc":"Lists all managed policies that are attached to the specified IAM role.\n\nAn IAM role can also have inline policies embedded with it. To list the inline\npolicies for a role, use `ListRolePolicies`. For information about policies, see\n[Managed policies and inline policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/policies-managed-vs-inline.html)\nin the *IAM User Guide*.\n\nYou can paginate the results using the `MaxItems` and `Marker` parameters. You\ncan use the `PathPrefix` parameter to limit the list of policies to only those\nmatching the specified path prefix. If there are no policies attached to the\nspecified role (or none that match the specified path prefix), the operation\nreturns an empty list.","ref":"AWS.IAM.html#list_attached_role_policies/3","title":"AWS.IAM.list_attached_role_policies/3","type":"function"},{"doc":"Lists all managed policies that are attached to the specified IAM user.\n\nAn IAM user can also have inline policies embedded with it. To list the inline\npolicies for a user, use `ListUserPolicies`. For information about policies, see\n[Managed policies and inline policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/policies-managed-vs-inline.html)\nin the *IAM User Guide*.\n\nYou can paginate the results using the `MaxItems` and `Marker` parameters. You\ncan use the `PathPrefix` parameter to limit the list of policies to only those\nmatching the specified path prefix. If there are no policies attached to the\nspecified group (or none that match the specified path prefix), the operation\nreturns an empty list.","ref":"AWS.IAM.html#list_attached_user_policies/3","title":"AWS.IAM.list_attached_user_policies/3","type":"function"},{"doc":"Lists all IAM users, groups, and roles that the specified managed policy is\nattached to.\n\nYou can use the optional `EntityFilter` parameter to limit the results to a\nparticular type of entity (users, groups, or roles). For example, to list only\nthe roles that are attached to the specified policy, set `EntityFilter` to\n`Role`.\n\nYou can paginate the results using the `MaxItems` and `Marker` parameters.","ref":"AWS.IAM.html#list_entities_for_policy/3","title":"AWS.IAM.list_entities_for_policy/3","type":"function"},{"doc":"Lists the names of the inline policies that are embedded in the specified IAM\ngroup.\n\nAn IAM group can also have managed policies attached to it. To list the managed\npolicies that are attached to a group, use `ListAttachedGroupPolicies`. For more\ninformation about policies, see [Managed policies and inline policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/policies-managed-vs-inline.html)\nin the *IAM User Guide*.\n\nYou can paginate the results using the `MaxItems` and `Marker` parameters. If\nthere are no inline policies embedded with the specified group, the operation\nreturns an empty list.","ref":"AWS.IAM.html#list_group_policies/3","title":"AWS.IAM.list_group_policies/3","type":"function"},{"doc":"Lists the IAM groups that have the specified path prefix.\n\nYou can paginate the results using the `MaxItems` and `Marker` parameters.","ref":"AWS.IAM.html#list_groups/3","title":"AWS.IAM.list_groups/3","type":"function"},{"doc":"Lists the IAM groups that the specified IAM user belongs to.\n\nYou can paginate the results using the `MaxItems` and `Marker` parameters.","ref":"AWS.IAM.html#list_groups_for_user/3","title":"AWS.IAM.list_groups_for_user/3","type":"function"},{"doc":"Lists the tags that are attached to the specified IAM instance profile.\n\nThe returned list of tags is sorted by tag key. For more information about\ntagging, see [Tagging IAM resources](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_tags.html) in the\n*IAM User Guide*.","ref":"AWS.IAM.html#list_instance_profile_tags/3","title":"AWS.IAM.list_instance_profile_tags/3","type":"function"},{"doc":"Lists the instance profiles that have the specified path prefix.\n\nIf there are none, the operation returns an empty list. For more information\nabout instance profiles, see [Using instance profiles](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_use_switch-role-ec2_instance-profiles.html)\nin the *IAM User Guide*.\n\nIAM resource-listing operations return a subset of the available attributes for\nthe resource. For example, this operation does not return tags, even though they\nare an attribute of the returned object. To view all of the information for an\ninstance profile, see `GetInstanceProfile`.\n\nYou can paginate the results using the `MaxItems` and `Marker` parameters.","ref":"AWS.IAM.html#list_instance_profiles/3","title":"AWS.IAM.list_instance_profiles/3","type":"function"},{"doc":"Lists the instance profiles that have the specified associated IAM role.\n\nIf there are none, the operation returns an empty list. For more information\nabout instance profiles, go to [Using instance profiles](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_use_switch-role-ec2_instance-profiles.html)\nin the *IAM User Guide*.\n\nYou can paginate the results using the `MaxItems` and `Marker` parameters.","ref":"AWS.IAM.html#list_instance_profiles_for_role/3","title":"AWS.IAM.list_instance_profiles_for_role/3","type":"function"},{"doc":"Lists the tags that are attached to the specified IAM virtual multi-factor\nauthentication (MFA) device.\n\nThe returned list of tags is sorted by tag key. For more information about\ntagging, see [Tagging IAM resources](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_tags.html) in the\n*IAM User Guide*.","ref":"AWS.IAM.html#list_mfa_device_tags/3","title":"AWS.IAM.list_mfa_device_tags/3","type":"function"},{"doc":"Lists the MFA devices for an IAM user.\n\nIf the request includes a IAM user name, then this operation lists all the MFA\ndevices associated with the specified user. If you do not specify a user name,\nIAM determines the user name implicitly based on the Amazon Web Services access\nkey ID signing the request for this operation.\n\nYou can paginate the results using the `MaxItems` and `Marker` parameters.","ref":"AWS.IAM.html#list_mfa_devices/3","title":"AWS.IAM.list_mfa_devices/3","type":"function"},{"doc":"Lists the tags that are attached to the specified OpenID Connect\n(OIDC)-compatible identity provider.\n\nThe returned list of tags is sorted by tag key. For more information, see [About web identity\nfederation](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_providers_oidc.html).\n\nFor more information about tagging, see [Tagging IAM resources](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_tags.html) in the\n*IAM User Guide*.","ref":"AWS.IAM.html#list_open_id_connect_provider_tags/3","title":"AWS.IAM.list_open_id_connect_provider_tags/3","type":"function"},{"doc":"Lists information about the IAM OpenID Connect (OIDC) provider resource objects\ndefined in the Amazon Web Services account.\n\nIAM resource-listing operations return a subset of the available attributes for\nthe resource. For example, this operation does not return tags, even though they\nare an attribute of the returned object. To view all of the information for an\nOIDC provider, see `GetOpenIDConnectProvider`.","ref":"AWS.IAM.html#list_open_id_connect_providers/3","title":"AWS.IAM.list_open_id_connect_providers/3","type":"function"},{"doc":"Lists all the managed policies that are available in your Amazon Web Services\naccount, including your own customer-defined managed policies and all Amazon Web\nServices managed policies.\n\nYou can filter the list of policies that is returned using the optional\n`OnlyAttached`, `Scope`, and `PathPrefix` parameters. For example, to list only\nthe customer managed policies in your Amazon Web Services account, set `Scope`\nto `Local`. To list only Amazon Web Services managed policies, set `Scope` to\n`AWS`.\n\nYou can paginate the results using the `MaxItems` and `Marker` parameters.\n\nFor more information about managed policies, see [Managed policies and inline policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/policies-managed-vs-inline.html)\nin the *IAM User Guide*.\n\nIAM resource-listing operations return a subset of the available attributes for\nthe resource. For example, this operation does not return tags, even though they\nare an attribute of the returned object. To view all of the information for a\ncustomer manged policy, see `GetPolicy`.","ref":"AWS.IAM.html#list_policies/3","title":"AWS.IAM.list_policies/3","type":"function"},{"doc":"Retrieves a list of policies that the IAM identity (user, group, or role) can\nuse to access each specified service.\n\nThis operation does not use other policy types when determining whether a\nresource could access a service. These other policy types include resource-based\npolicies, access control lists, Organizations policies, IAM permissions\nboundaries, and STS assume role policies. It only applies permissions policy\nlogic. For more about the evaluation of policy types, see [Evaluating policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_evaluation-logic.html#policy-eval-basics)\nin the *IAM User Guide*.\n\nThe list of policies returned by the operation depends on the ARN of the\nidentity that you provide.\n\n  * **User** – The list of policies includes the managed and inline\npolicies that are attached to the user directly. The list also includes any\nadditional managed and inline policies that are attached to the group to which\nthe user belongs.\n\n  * **Group** – The list of policies includes only the managed and\ninline policies that are attached to the group directly. Policies that are\nattached to the group’s user are not included.\n\n  * **Role** – The list of policies includes only the managed and\ninline policies that are attached to the role.\n\nFor each managed policy, this operation returns the ARN and policy name. For\neach inline policy, it returns the policy name and the entity to which it is\nattached. Inline policies do not have an ARN. For more information about these\npolicy types, see [Managed policies and inline policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_managed-vs-inline.html)\nin the *IAM User Guide*.\n\nPolicies that are attached to users and roles as permissions boundaries are not\nreturned. To view which managed policy is currently used to set the permissions\nboundary for a user or role, use the `GetUser` or `GetRole` operations.","ref":"AWS.IAM.html#list_policies_granting_service_access/3","title":"AWS.IAM.list_policies_granting_service_access/3","type":"function"},{"doc":"Lists the tags that are attached to the specified IAM customer managed policy.\n\nThe returned list of tags is sorted by tag key. For more information about\ntagging, see [Tagging IAM resources](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_tags.html) in the\n*IAM User Guide*.","ref":"AWS.IAM.html#list_policy_tags/3","title":"AWS.IAM.list_policy_tags/3","type":"function"},{"doc":"Lists information about the versions of the specified managed policy, including\nthe version that is currently set as the policy's default version.\n\nFor more information about managed policies, see [Managed policies and inline policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/policies-managed-vs-inline.html)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#list_policy_versions/3","title":"AWS.IAM.list_policy_versions/3","type":"function"},{"doc":"Lists the names of the inline policies that are embedded in the specified IAM\nrole.\n\nAn IAM role can also have managed policies attached to it. To list the managed\npolicies that are attached to a role, use `ListAttachedRolePolicies`. For more\ninformation about policies, see [Managed policies and inline policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/policies-managed-vs-inline.html)\nin the *IAM User Guide*.\n\nYou can paginate the results using the `MaxItems` and `Marker` parameters. If\nthere are no inline policies embedded with the specified role, the operation\nreturns an empty list.","ref":"AWS.IAM.html#list_role_policies/3","title":"AWS.IAM.list_role_policies/3","type":"function"},{"doc":"Lists the tags that are attached to the specified role.\n\nThe returned list of tags is sorted by tag key. For more information about\ntagging, see [Tagging IAM resources](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_tags.html) in the\n*IAM User Guide*.","ref":"AWS.IAM.html#list_role_tags/3","title":"AWS.IAM.list_role_tags/3","type":"function"},{"doc":"Lists the IAM roles that have the specified path prefix.\n\nIf there are none, the operation returns an empty list. For more information\nabout roles, see [IAM roles](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles.html) in the\n*IAM User Guide*.\n\nIAM resource-listing operations return a subset of the available attributes for\nthe resource. This operation does not return the following attributes, even\nthough they are an attribute of the returned object:\n\n   PermissionsBoundary\n\n   RoleLastUsed\n\n   Tags\n\nTo view all of the information for a role, see `GetRole`.\n\nYou can paginate the results using the `MaxItems` and `Marker` parameters.","ref":"AWS.IAM.html#list_roles/3","title":"AWS.IAM.list_roles/3","type":"function"},{"doc":"Lists the tags that are attached to the specified Security Assertion Markup\nLanguage (SAML) identity provider.\n\nThe returned list of tags is sorted by tag key. For more information, see [About SAML 2.0-based\nfederation](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_providers_saml.html).\n\nFor more information about tagging, see [Tagging IAM resources](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_tags.html) in the\n*IAM User Guide*.","ref":"AWS.IAM.html#list_saml_provider_tags/3","title":"AWS.IAM.list_saml_provider_tags/3","type":"function"},{"doc":"Lists the SAML provider resource objects defined in IAM in the account.\n\nIAM resource-listing operations return a subset of the available attributes for\nthe resource. For example, this operation does not return tags, even though they\nare an attribute of the returned object. To view all of the information for a\nSAML provider, see `GetSAMLProvider`.\n\nThis operation requires [Signature Version 4](https://docs.aws.amazon.com/general/latest/gr/signature-version-4.html).","ref":"AWS.IAM.html#list_saml_providers/3","title":"AWS.IAM.list_saml_providers/3","type":"function"},{"doc":"Lists the tags that are attached to the specified IAM server certificate.\n\nThe returned list of tags is sorted by tag key. For more information about\ntagging, see [Tagging IAM resources](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_tags.html) in the\n*IAM User Guide*.\n\nFor certificates in a Region supported by Certificate Manager (ACM), we\nrecommend that you don't use IAM server certificates. Instead, use ACM to\nprovision, manage, and deploy your server certificates. For more information\nabout IAM server certificates, [Working with server certificates](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_server-certs.html)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#list_server_certificate_tags/3","title":"AWS.IAM.list_server_certificate_tags/3","type":"function"},{"doc":"Lists the server certificates stored in IAM that have the specified path prefix.\n\nIf none exist, the operation returns an empty list.\n\nYou can paginate the results using the `MaxItems` and `Marker` parameters.\n\nFor more information about working with server certificates, see [Working with server\ncertificates](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_server-certs.html)\nin the *IAM User Guide*. This topic also includes a list of Amazon Web Services\nservices that can use the server certificates that you manage with IAM.\n\nIAM resource-listing operations return a subset of the available attributes for\nthe resource. For example, this operation does not return tags, even though they\nare an attribute of the returned object. To view all of the information for a\nservercertificate, see `GetServerCertificate`.","ref":"AWS.IAM.html#list_server_certificates/3","title":"AWS.IAM.list_server_certificates/3","type":"function"},{"doc":"Returns information about the service-specific credentials associated with the\nspecified IAM user.\n\nIf none exists, the operation returns an empty list. The service-specific\ncredentials returned by this operation are used only for authenticating the IAM\nuser to a specific service. For more information about using service-specific\ncredentials to authenticate to an Amazon Web Services service, see [Set up service-specific\ncredentials](https://docs.aws.amazon.com/codecommit/latest/userguide/setting-up-gc.html)\nin the CodeCommit User Guide.","ref":"AWS.IAM.html#list_service_specific_credentials/3","title":"AWS.IAM.list_service_specific_credentials/3","type":"function"},{"doc":"Returns information about the signing certificates associated with the specified\nIAM user.\n\nIf none exists, the operation returns an empty list.\n\nAlthough each user is limited to a small number of signing certificates, you can\nstill paginate the results using the `MaxItems` and `Marker` parameters.\n\nIf the `UserName` field is not specified, the user name is determined implicitly\nbased on the Amazon Web Services access key ID used to sign the request for this\noperation. This operation works for access keys under the Amazon Web Services\naccount. Consequently, you can use this operation to manage Amazon Web Services\naccount root user credentials even if the Amazon Web Services account has no\nassociated users.","ref":"AWS.IAM.html#list_signing_certificates/3","title":"AWS.IAM.list_signing_certificates/3","type":"function"},{"doc":"Returns information about the SSH public keys associated with the specified IAM\nuser.\n\nIf none exists, the operation returns an empty list.\n\nThe SSH public keys returned by this operation are used only for authenticating\nthe IAM user to an CodeCommit repository. For more information about using SSH\nkeys to authenticate to an CodeCommit repository, see [Set up CodeCommit for SSH connections](https://docs.aws.amazon.com/codecommit/latest/userguide/setting-up-credentials-ssh.html)\nin the *CodeCommit User Guide*.\n\nAlthough each user is limited to a small number of keys, you can still paginate\nthe results using the `MaxItems` and `Marker` parameters.","ref":"AWS.IAM.html#list_ssh_public_keys/3","title":"AWS.IAM.list_ssh_public_keys/3","type":"function"},{"doc":"Lists the names of the inline policies embedded in the specified IAM user.\n\nAn IAM user can also have managed policies attached to it. To list the managed\npolicies that are attached to a user, use `ListAttachedUserPolicies`. For more\ninformation about policies, see [Managed policies and inline policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/policies-managed-vs-inline.html)\nin the *IAM User Guide*.\n\nYou can paginate the results using the `MaxItems` and `Marker` parameters. If\nthere are no inline policies embedded with the specified user, the operation\nreturns an empty list.","ref":"AWS.IAM.html#list_user_policies/3","title":"AWS.IAM.list_user_policies/3","type":"function"},{"doc":"Lists the tags that are attached to the specified IAM user.\n\nThe returned list of tags is sorted by tag key. For more information about\ntagging, see [Tagging IAM resources](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_tags.html) in the\n*IAM User Guide*.","ref":"AWS.IAM.html#list_user_tags/3","title":"AWS.IAM.list_user_tags/3","type":"function"},{"doc":"Lists the IAM users that have the specified path prefix.\n\nIf no path prefix is specified, the operation returns all users in the Amazon\nWeb Services account. If there are none, the operation returns an empty list.\n\nIAM resource-listing operations return a subset of the available attributes for\nthe resource. This operation does not return the following attributes, even\nthough they are an attribute of the returned object:\n\n   PermissionsBoundary\n\n   Tags\n\nTo view all of the information for a user, see `GetUser`.\n\nYou can paginate the results using the `MaxItems` and `Marker` parameters.","ref":"AWS.IAM.html#list_users/3","title":"AWS.IAM.list_users/3","type":"function"},{"doc":"Lists the virtual MFA devices defined in the Amazon Web Services account by\nassignment status.\n\nIf you do not specify an assignment status, the operation returns a list of all\nvirtual MFA devices. Assignment status can be `Assigned`, `Unassigned`, or\n`Any`.\n\nIAM resource-listing operations return a subset of the available attributes for\nthe resource. For example, this operation does not return tags, even though they\nare an attribute of the returned object. To view tag information for a virtual\nMFA device, see `ListMFADeviceTags`.\n\nYou can paginate the results using the `MaxItems` and `Marker` parameters.","ref":"AWS.IAM.html#list_virtual_mfa_devices/3","title":"AWS.IAM.list_virtual_mfa_devices/3","type":"function"},{"doc":"","ref":"AWS.IAM.html#metadata/0","title":"AWS.IAM.metadata/0","type":"function"},{"doc":"Adds or updates an inline policy document that is embedded in the specified IAM\ngroup.\n\nA user can also have managed policies attached to it. To attach a managed policy\nto a group, use [ `AttachGroupPolicy`\n](https://docs.aws.amazon.com/IAM/latest/APIReference/API_AttachGroupPolicy.html).\nTo create a new managed policy, use [ `CreatePolicy`\n](https://docs.aws.amazon.com/IAM/latest/APIReference/API_CreatePolicy.html).\nFor information about policies, see [Managed policies and inline policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/policies-managed-vs-inline.html)\nin the *IAM User Guide*.\n\nFor information about the maximum number of inline policies that you can embed\nin a group, see [IAM and STS quotas](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_iam-quotas.html)\nin the *IAM User Guide*.\n\nBecause policy documents can be large, you should use POST rather than GET when\ncalling `PutGroupPolicy`. For general information about using the Query API with\nIAM, see [Making query requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/IAM_UsingQueryAPI.html)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#put_group_policy/3","title":"AWS.IAM.put_group_policy/3","type":"function"},{"doc":"Adds or updates the policy that is specified as the IAM role's permissions\nboundary.\n\nYou can use an Amazon Web Services managed policy or a customer managed policy\nto set the boundary for a role. Use the boundary to control the maximum\npermissions that the role can have. Setting a permissions boundary is an\nadvanced feature that can affect the permissions for the role.\n\nYou cannot set the boundary for a service-linked role.\n\nPolicies used as permissions boundaries do not provide permissions. You must\nalso attach a permissions policy to the role. To learn how the effective\npermissions for a role are evaluated, see [IAM JSON policy evaluation logic](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_evaluation-logic.html)\nin the IAM User Guide.","ref":"AWS.IAM.html#put_role_permissions_boundary/3","title":"AWS.IAM.put_role_permissions_boundary/3","type":"function"},{"doc":"Adds or updates an inline policy document that is embedded in the specified IAM\nrole.\n\nWhen you embed an inline policy in a role, the inline policy is used as part of\nthe role's access (permissions) policy. The role's trust policy is created at\nthe same time as the role, using [ `CreateRole`\n](https://docs.aws.amazon.com/IAM/latest/APIReference/API_CreateRole.html). You\ncan update a role's trust policy using [ `UpdateAssumeRolePolicy`\n](https://docs.aws.amazon.com/IAM/latest/APIReference/API_UpdateAssumeRolePolicy.html).\nFor more information about roles, see [IAM roles](https://docs.aws.amazon.com/IAM/latest/UserGuide/roles-toplevel.html) in\nthe *IAM User Guide*.\n\nA role can also have a managed policy attached to it. To attach a managed policy\nto a role, use [ `AttachRolePolicy`\n](https://docs.aws.amazon.com/IAM/latest/APIReference/API_AttachRolePolicy.html).\nTo create a new managed policy, use [ `CreatePolicy`\n](https://docs.aws.amazon.com/IAM/latest/APIReference/API_CreatePolicy.html).\nFor information about policies, see [Managed policies and inline policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/policies-managed-vs-inline.html)\nin the *IAM User Guide*.\n\nFor information about the maximum number of inline policies that you can embed\nwith a role, see [IAM and STS quotas](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_iam-quotas.html)\nin the *IAM User Guide*.\n\nBecause policy documents can be large, you should use POST rather than GET when\ncalling `PutRolePolicy`. For general information about using the Query API with\nIAM, see [Making query requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/IAM_UsingQueryAPI.html)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#put_role_policy/3","title":"AWS.IAM.put_role_policy/3","type":"function"},{"doc":"Adds or updates the policy that is specified as the IAM user's permissions\nboundary.\n\nYou can use an Amazon Web Services managed policy or a customer managed policy\nto set the boundary for a user. Use the boundary to control the maximum\npermissions that the user can have. Setting a permissions boundary is an\nadvanced feature that can affect the permissions for the user.\n\nPolicies that are used as permissions boundaries do not provide permissions. You\nmust also attach a permissions policy to the user. To learn how the effective\npermissions for a user are evaluated, see [IAM JSON policy evaluation logic](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_evaluation-logic.html)\nin the IAM User Guide.","ref":"AWS.IAM.html#put_user_permissions_boundary/3","title":"AWS.IAM.put_user_permissions_boundary/3","type":"function"},{"doc":"Adds or updates an inline policy document that is embedded in the specified IAM\nuser.\n\nAn IAM user can also have a managed policy attached to it. To attach a managed\npolicy to a user, use [ `AttachUserPolicy`\n](https://docs.aws.amazon.com/IAM/latest/APIReference/API_AttachUserPolicy.html).\nTo create a new managed policy, use [ `CreatePolicy`\n](https://docs.aws.amazon.com/IAM/latest/APIReference/API_CreatePolicy.html).\nFor information about policies, see [Managed policies and inline policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/policies-managed-vs-inline.html)\nin the *IAM User Guide*.\n\nFor information about the maximum number of inline policies that you can embed\nin a user, see [IAM and STS quotas](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_iam-quotas.html)\nin the *IAM User Guide*.\n\nBecause policy documents can be large, you should use POST rather than GET when\ncalling `PutUserPolicy`. For general information about using the Query API with\nIAM, see [Making query requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/IAM_UsingQueryAPI.html)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#put_user_policy/3","title":"AWS.IAM.put_user_policy/3","type":"function"},{"doc":"Removes the specified client ID (also known as audience) from the list of client\nIDs registered for the specified IAM OpenID Connect (OIDC) provider resource\nobject.\n\nThis operation is idempotent; it does not fail or return an error if you try to\nremove a client ID that does not exist.","ref":"AWS.IAM.html#remove_client_id_from_open_id_connect_provider/3","title":"AWS.IAM.remove_client_id_from_open_id_connect_provider/3","type":"function"},{"doc":"Removes the specified IAM role from the specified EC2 instance profile.\n\nMake sure that you do not have any Amazon EC2 instances running with the role\nyou are about to remove from the instance profile. Removing a role from an\ninstance profile that is associated with a running instance might break any\napplications running on the instance.\n\nFor more information about roles, see [IAM roles](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles.html) in the\n*IAM User Guide*. For more information about instance profiles, see [Using instance\nprofiles](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_use_switch-role-ec2_instance-profiles.html)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#remove_role_from_instance_profile/3","title":"AWS.IAM.remove_role_from_instance_profile/3","type":"function"},{"doc":"Removes the specified user from the specified group.","ref":"AWS.IAM.html#remove_user_from_group/3","title":"AWS.IAM.remove_user_from_group/3","type":"function"},{"doc":"Resets the password for a service-specific credential.\n\nThe new password is Amazon Web Services generated and cryptographically strong.\nIt cannot be configured by the user. Resetting the password immediately\ninvalidates the previous password associated with this user.","ref":"AWS.IAM.html#reset_service_specific_credential/3","title":"AWS.IAM.reset_service_specific_credential/3","type":"function"},{"doc":"Synchronizes the specified MFA device with its IAM resource object on the Amazon\nWeb Services servers.\n\nFor more information about creating and working with virtual MFA devices, see\n[Using a virtual MFA device](https://docs.aws.amazon.com/IAM/latest/UserGuide/Using_VirtualMFA.html)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#resync_mfa_device/3","title":"AWS.IAM.resync_mfa_device/3","type":"function"},{"doc":"Sets the specified version of the specified policy as the policy's default\n(operative) version.\n\nThis operation affects all users, groups, and roles that the policy is attached\nto. To list the users, groups, and roles that the policy is attached to, use\n`ListEntitiesForPolicy`.\n\nFor information about managed policies, see [Managed policies and inline policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/policies-managed-vs-inline.html)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#set_default_policy_version/3","title":"AWS.IAM.set_default_policy_version/3","type":"function"},{"doc":"Sets the specified version of the global endpoint token as the token version\nused for the Amazon Web Services account.\n\nBy default, Security Token Service (STS) is available as a global service, and\nall STS requests go to a single endpoint at `https://sts.amazonaws.com`. Amazon\nWeb Services recommends using Regional STS endpoints to reduce latency, build in\nredundancy, and increase session token availability. For information about\nRegional endpoints for STS, see [Security Token Service endpoints and quotas](https://docs.aws.amazon.com/general/latest/gr/sts.html) in the *Amazon\nWeb Services General Reference*.\n\nIf you make an STS call to the global endpoint, the resulting session tokens\nmight be valid in some Regions but not others. It depends on the version that is\nset in this operation. Version 1 tokens are valid only in Amazon Web Services\nRegions that are available by default. These tokens do not work in manually\nenabled Regions, such as Asia Pacific (Hong Kong). Version 2 tokens are valid in\nall Regions. However, version 2 tokens are longer and might affect systems where\nyou temporarily store tokens. For information, see [Activating and deactivating STS in an Amazon Web Services\nRegion](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_enable-regions.html)\nin the *IAM User Guide*.\n\nTo view the current session token version, see the `GlobalEndpointTokenVersion`\nentry in the response of the `GetAccountSummary` operation.","ref":"AWS.IAM.html#set_security_token_service_preferences/3","title":"AWS.IAM.set_security_token_service_preferences/3","type":"function"},{"doc":"Simulate how a set of IAM policies and optionally a resource-based policy works\nwith a list of API operations and Amazon Web Services resources to determine the\npolicies' effective permissions.\n\nThe policies are provided as strings.\n\nThe simulation does not perform the API operations; it only checks the\nauthorization to determine if the simulated policies allow or deny the\noperations. You can simulate resources that don't exist in your account.\n\nIf you want to simulate existing policies that are attached to an IAM user,\ngroup, or role, use `SimulatePrincipalPolicy` instead.\n\nContext keys are variables that are maintained by Amazon Web Services and its\nservices and which provide details about the context of an API query request.\nYou can use the `Condition` element of an IAM policy to evaluate context keys.\nTo get the list of context keys that the policies require for correct\nsimulation, use `GetContextKeysForCustomPolicy`.\n\nIf the output is long, you can use `MaxItems` and `Marker` parameters to\npaginate the results.\n\nThe IAM policy simulator evaluates statements in the identity-based policy and\nthe inputs that you provide during simulation. The policy simulator results can\ndiffer from your live Amazon Web Services environment. We recommend that you\ncheck your policies against your live Amazon Web Services environment after\ntesting using the policy simulator to confirm that you have the desired results.\nFor more information about using the policy simulator, see [Testing IAM policies with the IAM policy simulator\n](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_testing-policies.html)in\nthe *IAM User Guide*.","ref":"AWS.IAM.html#simulate_custom_policy/3","title":"AWS.IAM.simulate_custom_policy/3","type":"function"},{"doc":"Simulate how a set of IAM policies attached to an IAM entity works with a list\nof API operations and Amazon Web Services resources to determine the policies'\neffective permissions.\n\nThe entity can be an IAM user, group, or role. If you specify a user, then the\nsimulation also includes all of the policies that are attached to groups that\nthe user belongs to. You can simulate resources that don't exist in your\naccount.\n\nYou can optionally include a list of one or more additional policies specified\nas strings to include in the simulation. If you want to simulate only policies\nspecified as strings, use `SimulateCustomPolicy` instead.\n\nYou can also optionally include one resource-based policy to be evaluated with\neach of the resources included in the simulation for IAM users only.\n\nThe simulation does not perform the API operations; it only checks the\nauthorization to determine if the simulated policies allow or deny the\noperations.\n\n**Note:** This operation discloses information about the permissions granted to\nother users. If you do not want users to see other user's permissions, then\nconsider allowing them to use `SimulateCustomPolicy` instead.\n\nContext keys are variables maintained by Amazon Web Services and its services\nthat provide details about the context of an API query request. You can use the\n`Condition` element of an IAM policy to evaluate context keys. To get the list\nof context keys that the policies require for correct simulation, use\n`GetContextKeysForPrincipalPolicy`.\n\nIf the output is long, you can use the `MaxItems` and `Marker` parameters to\npaginate the results.\n\nThe IAM policy simulator evaluates statements in the identity-based policy and\nthe inputs that you provide during simulation. The policy simulator results can\ndiffer from your live Amazon Web Services environment. We recommend that you\ncheck your policies against your live Amazon Web Services environment after\ntesting using the policy simulator to confirm that you have the desired results.\nFor more information about using the policy simulator, see [Testing IAM policies with the IAM policy simulator\n](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_testing-policies.html)in\nthe *IAM User Guide*.","ref":"AWS.IAM.html#simulate_principal_policy/3","title":"AWS.IAM.simulate_principal_policy/3","type":"function"},{"doc":"Adds one or more tags to an IAM instance profile.\n\nIf a tag with the same key name already exists, then that tag is overwritten\nwith the new value.\n\nEach tag consists of a key name and an associated value. By assigning tags to\nyour resources, you can do the following:\n\n  * **Administrative grouping and discovery** - Attach tags to\nresources to aid in organization and search. For example, you could search for\nall resources with the key name *Project* and the value *MyImportantProject*. Or\nsearch for all resources with the key name *Cost Center* and the value *41200*.\n\n  * **Access control** - Include tags in IAM user-based and\nresource-based policies. You can use tags to restrict access to only an IAM\ninstance profile that has a specified tag attached. For examples of policies\nthat show how to use tags to control access, see [Control access using IAM tags](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_tags.html) in the\n*IAM User Guide*.\n\n   If any one of the tags is invalid or if you exceed the allowed\nmaximum number of tags, then the entire request fails and the resource is not\ncreated. For more information about tagging, see [Tagging IAM resources](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_tags.html) in the\n*IAM User Guide*.\n\n   Amazon Web Services always interprets the tag `Value` as a single\nstring. If you need to store an array, you can store comma-separated values in\nthe string. However, you must interpret the value in your code.","ref":"AWS.IAM.html#tag_instance_profile/3","title":"AWS.IAM.tag_instance_profile/3","type":"function"},{"doc":"Adds one or more tags to an IAM virtual multi-factor authentication (MFA)\ndevice.\n\nIf a tag with the same key name already exists, then that tag is overwritten\nwith the new value.\n\nA tag consists of a key name and an associated value. By assigning tags to your\nresources, you can do the following:\n\n  * **Administrative grouping and discovery** - Attach tags to\nresources to aid in organization and search. For example, you could search for\nall resources with the key name *Project* and the value *MyImportantProject*. Or\nsearch for all resources with the key name *Cost Center* and the value *41200*.\n\n  * **Access control** - Include tags in IAM user-based and\nresource-based policies. You can use tags to restrict access to only an IAM\nvirtual MFA device that has a specified tag attached. For examples of policies\nthat show how to use tags to control access, see [Control access using IAM tags](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_tags.html) in the\n*IAM User Guide*.\n\n   If any one of the tags is invalid or if you exceed the allowed\nmaximum number of tags, then the entire request fails and the resource is not\ncreated. For more information about tagging, see [Tagging IAM resources](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_tags.html) in the\n*IAM User Guide*.\n\n   Amazon Web Services always interprets the tag `Value` as a single\nstring. If you need to store an array, you can store comma-separated values in\nthe string. However, you must interpret the value in your code.","ref":"AWS.IAM.html#tag_mfa_device/3","title":"AWS.IAM.tag_mfa_device/3","type":"function"},{"doc":"Adds one or more tags to an OpenID Connect (OIDC)-compatible identity provider.\n\nFor more information about these providers, see [About web identity federation](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_providers_oidc.html).\nIf a tag with the same key name already exists, then that tag is overwritten\nwith the new value.\n\nA tag consists of a key name and an associated value. By assigning tags to your\nresources, you can do the following:\n\n  * **Administrative grouping and discovery** - Attach tags to\nresources to aid in organization and search. For example, you could search for\nall resources with the key name *Project* and the value *MyImportantProject*. Or\nsearch for all resources with the key name *Cost Center* and the value *41200*.\n\n  * **Access control** - Include tags in IAM identity-based and\nresource-based policies. You can use tags to restrict access to only an OIDC\nprovider that has a specified tag attached. For examples of policies that show\nhow to use tags to control access, see [Control access using IAM tags](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_tags.html) in the\n*IAM User Guide*.\n\n   If any one of the tags is invalid or if you exceed the allowed\nmaximum number of tags, then the entire request fails and the resource is not\ncreated. For more information about tagging, see [Tagging IAM resources](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_tags.html) in the\n*IAM User Guide*.\n\n   Amazon Web Services always interprets the tag `Value` as a single\nstring. If you need to store an array, you can store comma-separated values in\nthe string. However, you must interpret the value in your code.","ref":"AWS.IAM.html#tag_open_id_connect_provider/3","title":"AWS.IAM.tag_open_id_connect_provider/3","type":"function"},{"doc":"Adds one or more tags to an IAM customer managed policy.\n\nIf a tag with the same key name already exists, then that tag is overwritten\nwith the new value.\n\nA tag consists of a key name and an associated value. By assigning tags to your\nresources, you can do the following:\n\n  * **Administrative grouping and discovery** - Attach tags to\nresources to aid in organization and search. For example, you could search for\nall resources with the key name *Project* and the value *MyImportantProject*. Or\nsearch for all resources with the key name *Cost Center* and the value *41200*.\n\n  * **Access control** - Include tags in IAM user-based and\nresource-based policies. You can use tags to restrict access to only an IAM\ncustomer managed policy that has a specified tag attached. For examples of\npolicies that show how to use tags to control access, see [Control access using IAM tags](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_tags.html) in\nthe *IAM User Guide*.\n\n   If any one of the tags is invalid or if you exceed the allowed\nmaximum number of tags, then the entire request fails and the resource is not\ncreated. For more information about tagging, see [Tagging IAM resources](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_tags.html) in the\n*IAM User Guide*.\n\n   Amazon Web Services always interprets the tag `Value` as a single\nstring. If you need to store an array, you can store comma-separated values in\nthe string. However, you must interpret the value in your code.","ref":"AWS.IAM.html#tag_policy/3","title":"AWS.IAM.tag_policy/3","type":"function"},{"doc":"Adds one or more tags to an IAM role.\n\nThe role can be a regular role or a service-linked role. If a tag with the same\nkey name already exists, then that tag is overwritten with the new value.\n\nA tag consists of a key name and an associated value. By assigning tags to your\nresources, you can do the following:\n\n  * **Administrative grouping and discovery** - Attach tags to\nresources to aid in organization and search. For example, you could search for\nall resources with the key name *Project* and the value *MyImportantProject*. Or\nsearch for all resources with the key name *Cost Center* and the value *41200*.\n\n  * **Access control** - Include tags in IAM user-based and\nresource-based policies. You can use tags to restrict access to only an IAM role\nthat has a specified tag attached. You can also restrict access to only those\nresources that have a certain tag attached. For examples of policies that show\nhow to use tags to control access, see [Control access using IAM tags](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_tags.html) in the\n*IAM User Guide*.\n\n  * **Cost allocation** - Use tags to help track which individuals and\nteams are using which Amazon Web Services resources.\n\n   If any one of the tags is invalid or if you exceed the allowed\nmaximum number of tags, then the entire request fails and the resource is not\ncreated. For more information about tagging, see [Tagging IAM resources](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_tags.html) in the\n*IAM User Guide*.\n\n   Amazon Web Services always interprets the tag `Value` as a single\nstring. If you need to store an array, you can store comma-separated values in\nthe string. However, you must interpret the value in your code.\n\nFor more information about tagging, see [Tagging IAM identities](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_tags.html) in\nthe *IAM User Guide*.","ref":"AWS.IAM.html#tag_role/3","title":"AWS.IAM.tag_role/3","type":"function"},{"doc":"Adds one or more tags to a Security Assertion Markup Language (SAML) identity\nprovider.\n\nFor more information about these providers, see [About SAML 2.0-based federation\n](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_providers_saml.html).\nIf a tag with the same key name already exists, then that tag is overwritten\nwith the new value.\n\nA tag consists of a key name and an associated value. By assigning tags to your\nresources, you can do the following:\n\n  * **Administrative grouping and discovery** - Attach tags to\nresources to aid in organization and search. For example, you could search for\nall resources with the key name *Project* and the value *MyImportantProject*. Or\nsearch for all resources with the key name *Cost Center* and the value *41200*.\n\n  * **Access control** - Include tags in IAM user-based and\nresource-based policies. You can use tags to restrict access to only a SAML\nidentity provider that has a specified tag attached. For examples of policies\nthat show how to use tags to control access, see [Control access using IAM tags](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_tags.html) in the\n*IAM User Guide*.\n\n   If any one of the tags is invalid or if you exceed the allowed\nmaximum number of tags, then the entire request fails and the resource is not\ncreated. For more information about tagging, see [Tagging IAM resources](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_tags.html) in the\n*IAM User Guide*.\n\n   Amazon Web Services always interprets the tag `Value` as a single\nstring. If you need to store an array, you can store comma-separated values in\nthe string. However, you must interpret the value in your code.","ref":"AWS.IAM.html#tag_saml_provider/3","title":"AWS.IAM.tag_saml_provider/3","type":"function"},{"doc":"Adds one or more tags to an IAM server certificate.\n\nIf a tag with the same key name already exists, then that tag is overwritten\nwith the new value.\n\nFor certificates in a Region supported by Certificate Manager (ACM), we\nrecommend that you don't use IAM server certificates. Instead, use ACM to\nprovision, manage, and deploy your server certificates. For more information\nabout IAM server certificates, [Working with server certificates](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_server-certs.html)\nin the *IAM User Guide*.\n\nA tag consists of a key name and an associated value. By assigning tags to your\nresources, you can do the following:\n\n  * **Administrative grouping and discovery** - Attach tags to\nresources to aid in organization and search. For example, you could search for\nall resources with the key name *Project* and the value *MyImportantProject*. Or\nsearch for all resources with the key name *Cost Center* and the value *41200*.\n\n  * **Access control** - Include tags in IAM user-based and\nresource-based policies. You can use tags to restrict access to only a server\ncertificate that has a specified tag attached. For examples of policies that\nshow how to use tags to control access, see [Control access using IAM tags](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_tags.html) in the\n*IAM User Guide*.\n\n  * **Cost allocation** - Use tags to help track which individuals and\nteams are using which Amazon Web Services resources.\n\n   If any one of the tags is invalid or if you exceed the allowed\nmaximum number of tags, then the entire request fails and the resource is not\ncreated. For more information about tagging, see [Tagging IAM resources](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_tags.html) in the\n*IAM User Guide*.\n\n   Amazon Web Services always interprets the tag `Value` as a single\nstring. If you need to store an array, you can store comma-separated values in\nthe string. However, you must interpret the value in your code.","ref":"AWS.IAM.html#tag_server_certificate/3","title":"AWS.IAM.tag_server_certificate/3","type":"function"},{"doc":"Adds one or more tags to an IAM user.\n\nIf a tag with the same key name already exists, then that tag is overwritten\nwith the new value.\n\nA tag consists of a key name and an associated value. By assigning tags to your\nresources, you can do the following:\n\n  * **Administrative grouping and discovery** - Attach tags to\nresources to aid in organization and search. For example, you could search for\nall resources with the key name *Project* and the value *MyImportantProject*. Or\nsearch for all resources with the key name *Cost Center* and the value *41200*.\n\n  * **Access control** - Include tags in IAM identity-based and\nresource-based policies. You can use tags to restrict access to only an IAM\nrequesting user that has a specified tag attached. You can also restrict access\nto only those resources that have a certain tag attached. For examples of\npolicies that show how to use tags to control access, see [Control access using IAM tags](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_tags.html) in\nthe *IAM User Guide*.\n\n  * **Cost allocation** - Use tags to help track which individuals and\nteams are using which Amazon Web Services resources.\n\n   If any one of the tags is invalid or if you exceed the allowed\nmaximum number of tags, then the entire request fails and the resource is not\ncreated. For more information about tagging, see [Tagging IAM resources](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_tags.html) in the\n*IAM User Guide*.\n\n   Amazon Web Services always interprets the tag `Value` as a single\nstring. If you need to store an array, you can store comma-separated values in\nthe string. However, you must interpret the value in your code.\n\nFor more information about tagging, see [Tagging IAM identities](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_tags.html) in\nthe *IAM User Guide*.","ref":"AWS.IAM.html#tag_user/3","title":"AWS.IAM.tag_user/3","type":"function"},{"doc":"Removes the specified tags from the IAM instance profile.\n\nFor more information about tagging, see [Tagging IAM resources](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_tags.html) in the\n*IAM User Guide*.","ref":"AWS.IAM.html#untag_instance_profile/3","title":"AWS.IAM.untag_instance_profile/3","type":"function"},{"doc":"Removes the specified tags from the IAM virtual multi-factor authentication\n(MFA) device.\n\nFor more information about tagging, see [Tagging IAM resources](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_tags.html) in the\n*IAM User Guide*.","ref":"AWS.IAM.html#untag_mfa_device/3","title":"AWS.IAM.untag_mfa_device/3","type":"function"},{"doc":"Removes the specified tags from the specified OpenID Connect (OIDC)-compatible\nidentity provider in IAM.\n\nFor more information about OIDC providers, see [About web identity federation](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_providers_oidc.html).\nFor more information about tagging, see [Tagging IAM resources](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_tags.html) in the\n*IAM User Guide*.","ref":"AWS.IAM.html#untag_open_id_connect_provider/3","title":"AWS.IAM.untag_open_id_connect_provider/3","type":"function"},{"doc":"Removes the specified tags from the customer managed policy.\n\nFor more information about tagging, see [Tagging IAM resources](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_tags.html) in the\n*IAM User Guide*.","ref":"AWS.IAM.html#untag_policy/3","title":"AWS.IAM.untag_policy/3","type":"function"},{"doc":"Removes the specified tags from the role.\n\nFor more information about tagging, see [Tagging IAM resources](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_tags.html) in the\n*IAM User Guide*.","ref":"AWS.IAM.html#untag_role/3","title":"AWS.IAM.untag_role/3","type":"function"},{"doc":"Removes the specified tags from the specified Security Assertion Markup Language\n(SAML) identity provider in IAM.\n\nFor more information about these providers, see [About web identity federation](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_providers_oidc.html).\nFor more information about tagging, see [Tagging IAM resources](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_tags.html) in the\n*IAM User Guide*.","ref":"AWS.IAM.html#untag_saml_provider/3","title":"AWS.IAM.untag_saml_provider/3","type":"function"},{"doc":"Removes the specified tags from the IAM server certificate.\n\nFor more information about tagging, see [Tagging IAM resources](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_tags.html) in the\n*IAM User Guide*.\n\nFor certificates in a Region supported by Certificate Manager (ACM), we\nrecommend that you don't use IAM server certificates. Instead, use ACM to\nprovision, manage, and deploy your server certificates. For more information\nabout IAM server certificates, [Working with server certificates](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_server-certs.html)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#untag_server_certificate/3","title":"AWS.IAM.untag_server_certificate/3","type":"function"},{"doc":"Removes the specified tags from the user.\n\nFor more information about tagging, see [Tagging IAM resources](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_tags.html) in the\n*IAM User Guide*.","ref":"AWS.IAM.html#untag_user/3","title":"AWS.IAM.untag_user/3","type":"function"},{"doc":"Changes the status of the specified access key from Active to Inactive, or vice\nversa.\n\nThis operation can be used to disable a user's key as part of a key rotation\nworkflow.\n\nIf the `UserName` is not specified, the user name is determined implicitly based\non the Amazon Web Services access key ID used to sign the request. If a\ntemporary access key is used, then `UserName` is required. If a long-term key is\nassigned to the user, then `UserName` is not required. This operation works for\naccess keys under the Amazon Web Services account. Consequently, you can use\nthis operation to manage Amazon Web Services account root user credentials even\nif the Amazon Web Services account has no associated users.\n\nFor information about rotating keys, see [Managing keys and certificates](https://docs.aws.amazon.com/IAM/latest/UserGuide/ManagingCredentials.html)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#update_access_key/3","title":"AWS.IAM.update_access_key/3","type":"function"},{"doc":"Updates the password policy settings for the Amazon Web Services account.\n\nThis operation does not support partial updates. No parameters are required, but\nif you do not specify a parameter, that parameter's value reverts to its default\nvalue. See the **Request Parameters** section for each parameter's default\nvalue. Also note that some parameters do not allow the default parameter to be\nexplicitly set. Instead, to invoke the default value, do not include that\nparameter when you invoke the operation.\n\nFor more information about using a password policy, see [Managing an IAM password\npolicy](https://docs.aws.amazon.com/IAM/latest/UserGuide/Using_ManagingPasswordPolicies.html)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#update_account_password_policy/3","title":"AWS.IAM.update_account_password_policy/3","type":"function"},{"doc":"Updates the policy that grants an IAM entity permission to assume a role.\n\nThis is typically referred to as the \"role trust policy\". For more information\nabout roles, see [Using roles to delegate permissions and federate identities](https://docs.aws.amazon.com/IAM/latest/UserGuide/roles-toplevel.html).","ref":"AWS.IAM.html#update_assume_role_policy/3","title":"AWS.IAM.update_assume_role_policy/3","type":"function"},{"doc":"Updates the name and/or the path of the specified IAM group.\n\nYou should understand the implications of changing a group's path or name. For\nmore information, see [Renaming users and groups](https://docs.aws.amazon.com/IAM/latest/UserGuide/Using_WorkingWithGroupsAndUsers.html)\nin the *IAM User Guide*.\n\nThe person making the request (the principal), must have permission to change\nthe role group with the old name and the new name. For example, to change the\ngroup named `Managers` to `MGRs`, the principal must have a policy that allows\nthem to update both groups. If the principal has permission to update the\n`Managers` group, but not the `MGRs` group, then the update fails. For more\ninformation about permissions, see [Access management](https://docs.aws.amazon.com/IAM/latest/UserGuide/access.html).","ref":"AWS.IAM.html#update_group/3","title":"AWS.IAM.update_group/3","type":"function"},{"doc":"Changes the password for the specified IAM user.\n\nYou can use the CLI, the Amazon Web Services API, or the **Users** page in the\nIAM console to change the password for any IAM user. Use `ChangePassword` to\nchange your own password in the **My Security Credentials** page in the Amazon\nWeb Services Management Console.\n\nFor more information about modifying passwords, see [Managing passwords](https://docs.aws.amazon.com/IAM/latest/UserGuide/Using_ManagingLogins.html)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#update_login_profile/3","title":"AWS.IAM.update_login_profile/3","type":"function"},{"doc":"Replaces the existing list of server certificate thumbprints associated with an\nOpenID Connect (OIDC) provider resource object with a new list of thumbprints.\n\nThe list that you pass with this operation completely replaces the existing list\nof thumbprints. (The lists are not merged.)\n\nTypically, you need to update a thumbprint only when the identity provider\ncertificate changes, which occurs rarely. However, if the provider's certificate\n*does* change, any attempt to assume an IAM role that specifies the OIDC\nprovider as a principal fails until the certificate thumbprint is updated.\n\nAmazon Web Services secures communication with some OIDC identity providers\n(IdPs) through our library of trusted root certificate authorities (CAs) instead\nof using a certificate thumbprint to verify your IdP server certificate. In\nthese cases, your legacy thumbprint remains in your configuration, but is no\nlonger used for validation. These OIDC IdPs include Auth0, GitHub, GitLab,\nGoogle, and those that use an Amazon S3 bucket to host a JSON Web Key Set (JWKS)\nendpoint.\n\nTrust for the OIDC provider is derived from the provider certificate and is\nvalidated by the thumbprint. Therefore, it is best to limit access to the\n`UpdateOpenIDConnectProviderThumbprint` operation to highly privileged users.","ref":"AWS.IAM.html#update_open_id_connect_provider_thumbprint/3","title":"AWS.IAM.update_open_id_connect_provider_thumbprint/3","type":"function"},{"doc":"Updates the description or maximum session duration setting of a role.","ref":"AWS.IAM.html#update_role/3","title":"AWS.IAM.update_role/3","type":"function"},{"doc":"Use `UpdateRole` instead.\n\nModifies only the description of a role. This operation performs the same\nfunction as the `Description` parameter in the `UpdateRole` operation.","ref":"AWS.IAM.html#update_role_description/3","title":"AWS.IAM.update_role_description/3","type":"function"},{"doc":"Updates the metadata document for an existing SAML provider resource object.\n\nThis operation requires [Signature Version 4](https://docs.aws.amazon.com/general/latest/gr/signature-version-4.html).","ref":"AWS.IAM.html#update_saml_provider/3","title":"AWS.IAM.update_saml_provider/3","type":"function"},{"doc":"Updates the name and/or the path of the specified server certificate stored in\nIAM.\n\nFor more information about working with server certificates, see [Working with server\ncertificates](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_server-certs.html)\nin the *IAM User Guide*. This topic also includes a list of Amazon Web Services\nservices that can use the server certificates that you manage with IAM.\n\nYou should understand the implications of changing a server certificate's path\nor name. For more information, see [Renaming a server certificate](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_server-certs_manage.html#RenamingServerCerts)\nin the *IAM User Guide*.\n\nThe person making the request (the principal), must have permission to change\nthe server certificate with the old name and the new name. For example, to\nchange the certificate named `ProductionCert` to `ProdCert`, the principal must\nhave a policy that allows them to update both certificates. If the principal has\npermission to update the `ProductionCert` group, but not the `ProdCert`\ncertificate, then the update fails. For more information about permissions, see\n[Access management](https://docs.aws.amazon.com/IAM/latest/UserGuide/access.html) in the\n*IAM User Guide*.","ref":"AWS.IAM.html#update_server_certificate/3","title":"AWS.IAM.update_server_certificate/3","type":"function"},{"doc":"Sets the status of a service-specific credential to `Active` or `Inactive`.\n\nService-specific credentials that are inactive cannot be used for authentication\nto the service. This operation can be used to disable a user's service-specific\ncredential as part of a credential rotation work flow.","ref":"AWS.IAM.html#update_service_specific_credential/3","title":"AWS.IAM.update_service_specific_credential/3","type":"function"},{"doc":"Changes the status of the specified user signing certificate from active to\ndisabled, or vice versa.\n\nThis operation can be used to disable an IAM user's signing certificate as part\nof a certificate rotation work flow.\n\nIf the `UserName` field is not specified, the user name is determined implicitly\nbased on the Amazon Web Services access key ID used to sign the request. This\noperation works for access keys under the Amazon Web Services account.\nConsequently, you can use this operation to manage Amazon Web Services account\nroot user credentials even if the Amazon Web Services account has no associated\nusers.","ref":"AWS.IAM.html#update_signing_certificate/3","title":"AWS.IAM.update_signing_certificate/3","type":"function"},{"doc":"Sets the status of an IAM user's SSH public key to active or inactive.\n\nSSH public keys that are inactive cannot be used for authentication. This\noperation can be used to disable a user's SSH public key as part of a key\nrotation work flow.\n\nThe SSH public key affected by this operation is used only for authenticating\nthe associated IAM user to an CodeCommit repository. For more information about\nusing SSH keys to authenticate to an CodeCommit repository, see [Set up CodeCommit for SSH\nconnections](https://docs.aws.amazon.com/codecommit/latest/userguide/setting-up-credentials-ssh.html)\nin the *CodeCommit User Guide*.","ref":"AWS.IAM.html#update_ssh_public_key/3","title":"AWS.IAM.update_ssh_public_key/3","type":"function"},{"doc":"Updates the name and/or the path of the specified IAM user.\n\nYou should understand the implications of changing an IAM user's path or name.\nFor more information, see [Renaming an IAM user](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_users_manage.html#id_users_renaming)\nand [Renaming an IAM group](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_groups_manage_rename.html)\nin the *IAM User Guide*.\n\nTo change a user name, the requester must have appropriate permissions on both\nthe source object and the target object. For example, to change Bob to Robert,\nthe entity making the request must have permission on Bob and Robert, or must\nhave permission on all (*). For more information about permissions, see\n[Permissions and policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/PermissionsAndPolicies.html).","ref":"AWS.IAM.html#update_user/3","title":"AWS.IAM.update_user/3","type":"function"},{"doc":"Uploads a server certificate entity for the Amazon Web Services account.\n\nThe server certificate entity includes a public key certificate, a private key,\nand an optional certificate chain, which should all be PEM-encoded.\n\nWe recommend that you use [Certificate Manager](https://docs.aws.amazon.com/acm/) to provision, manage, and deploy your\nserver certificates. With ACM you can request a certificate, deploy it to Amazon\nWeb Services resources, and let ACM handle certificate renewals for you.\nCertificates provided by ACM are free. For more information about using ACM, see\nthe [Certificate Manager User Guide](https://docs.aws.amazon.com/acm/latest/userguide/).\n\nFor more information about working with server certificates, see [Working with server\ncertificates](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_server-certs.html)\nin the *IAM User Guide*. This topic includes a list of Amazon Web Services\nservices that can use the server certificates that you manage with IAM.\n\nFor information about the number of server certificates you can upload, see [IAM and STS\nquotas](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_iam-quotas.html)\nin the *IAM User Guide*.\n\nBecause the body of the public key certificate, private key, and the certificate\nchain can be large, you should use POST rather than GET when calling\n`UploadServerCertificate`. For information about setting up signatures and\nauthorization through the API, see [Signing Amazon Web Services API requests](https://docs.aws.amazon.com/general/latest/gr/signing_aws_api_requests.html)\nin the *Amazon Web Services General Reference*. For general information about\nusing the Query API with IAM, see [Calling the API by making HTTP query requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/programming.html) in\nthe *IAM User Guide*.","ref":"AWS.IAM.html#upload_server_certificate/3","title":"AWS.IAM.upload_server_certificate/3","type":"function"},{"doc":"Uploads an X.509 signing certificate and associates it with the specified IAM\nuser.\n\nSome Amazon Web Services services require you to use certificates to validate\nrequests that are signed with a corresponding private key. When you upload the\ncertificate, its default status is `Active`.\n\nFor information about when you would use an X.509 signing certificate, see\n[Managing server certificates in IAM](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_server-certs.html)\nin the *IAM User Guide*.\n\nIf the `UserName` is not specified, the IAM user name is determined implicitly\nbased on the Amazon Web Services access key ID used to sign the request. This\noperation works for access keys under the Amazon Web Services account.\nConsequently, you can use this operation to manage Amazon Web Services account\nroot user credentials even if the Amazon Web Services account has no associated\nusers.\n\nBecause the body of an X.509 certificate can be large, you should use POST\nrather than GET when calling `UploadSigningCertificate`. For information about\nsetting up signatures and authorization through the API, see [Signing Amazon Web Services API\nrequests](https://docs.aws.amazon.com/general/latest/gr/signing_aws_api_requests.html)\nin the *Amazon Web Services General Reference*. For general information about\nusing the Query API with IAM, see [Making query requests](https://docs.aws.amazon.com/IAM/latest/UserGuide/IAM_UsingQueryAPI.html)\nin the *IAM User Guide*.","ref":"AWS.IAM.html#upload_signing_certificate/3","title":"AWS.IAM.upload_signing_certificate/3","type":"function"},{"doc":"Uploads an SSH public key and associates it with the specified IAM user.\n\nThe SSH public key uploaded by this operation can be used only for\nauthenticating the associated IAM user to an CodeCommit repository. For more\ninformation about using SSH keys to authenticate to an CodeCommit repository,\nsee [Set up CodeCommit for SSH connections](https://docs.aws.amazon.com/codecommit/latest/userguide/setting-up-credentials-ssh.html)\nin the *CodeCommit User Guide*.","ref":"AWS.IAM.html#upload_ssh_public_key/3","title":"AWS.IAM.upload_ssh_public_key/3","type":"function"},{"doc":"","ref":"AWS.IVSRealTime.html","title":"AWS.IVSRealTime","type":"module"},{"doc":"The Amazon Interactive Video Service (IVS) real-time API is REST compatible,\nusing a standard HTTP API and an AWS EventBridge event stream for responses.\n\nJSON is used for both requests and responses, including errors.\n\nTerminology:\n\n  * A *stage* is a virtual space where participants can exchange video\nin real time.\n\n  * A *participant token* is a token that authenticates a participant\nwhen they join a stage.\n\n  * A *participant object* represents participants (people) in the\nstage and contains information about them. When a token is created, it includes\na participant ID; when a participant uses that token to join a stage, the\nparticipant is associated with that participant ID. There is a 1:1 mapping\nbetween participant tokens and participants.\n\n  * Server-side composition: The *composition* process composites\nparticipants of a stage into a single video and forwards it to a set of outputs\n(e.g., IVS channels). Composition endpoints support this process.\n\n  * Server-side composition: A *composition* controls the look of the\noutputs, including how participants are positioned in the video.","ref":"AWS.IVSRealTime.html#module-introduction","title":"Introduction - AWS.IVSRealTime","type":"module"},{"doc":"The following resources contain information about your IVS live stream (see\n[Getting Started with Amazon IVS Real-Time Streaming](https://docs.aws.amazon.com/ivs/latest/RealTimeUserGuide/getting-started.html)):\n\n  * **Stage** — A stage is a virtual space where participants can\nexchange video in real time.","ref":"AWS.IVSRealTime.html#module-resources","title":"Resources - AWS.IVSRealTime","type":"module"},{"doc":"A *tag* is a metadata label that you assign to an AWS resource. A tag comprises\na *key* and a *value*, both set by you. For example, you might set a tag as\n`topic:nature` to label a particular video category. See [Tagging AWS Resources](https://docs.aws.amazon.com/general/latest/gr/aws_tagging.html) for\nmore information, including restrictions that apply to tags and \"Tag naming\nlimits and requirements\"; Amazon IVS stages has no service-specific constraints\nbeyond what is documented there.\n\nTags can help you identify and organize your AWS resources. For example, you can\nuse the same tag for different resources to indicate that they are related. You\ncan also use tags to manage access (see [Access Tags](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_tags.html)).\n\nThe Amazon IVS real-time API has these tag-related endpoints: `TagResource`,\n`UntagResource`, and `ListTagsForResource`. The following resource supports\ntagging: Stage.\n\nAt most 50 tags can be applied to a resource.","ref":"AWS.IVSRealTime.html#module-tagging","title":"Tagging - AWS.IVSRealTime","type":"module"},{"doc":"* `CreateParticipantToken` — Creates an additional token for a\nspecified stage. This can be done after stage creation or when tokens expire.\n\n  * `CreateStage` — Creates a new stage (and optionally participant\ntokens).\n\n  * `DeleteStage` — Shuts down and deletes the specified stage\n(disconnecting all participants).\n\n  * `DisconnectParticipant` — Disconnects a specified participant and\nrevokes the participant permanently from a specified stage.\n\n  * `GetParticipant` — Gets information about the specified\nparticipant token.\n\n  * `GetStage` — Gets information for the specified stage.\n\n  * `GetStageSession` — Gets information for the specified stage\nsession.\n\n  * `ListParticipantEvents` — Lists events for a specified participant\nthat occurred during a specified stage session.\n\n  * `ListParticipants` — Lists all participants in a specified stage\nsession.\n\n  * `ListStages` — Gets summary information about all stages in your\naccount, in the AWS region where the API request is processed.\n\n  * `ListStageSessions` — Gets all sessions for a specified stage.\n\n  * `UpdateStage` — Updates a stage’s configuration.","ref":"AWS.IVSRealTime.html#module-stages-endpoints","title":"Stages Endpoints - AWS.IVSRealTime","type":"module"},{"doc":"* `GetComposition` — Gets information about the specified\nComposition resource.\n\n  * `ListCompositions` — Gets summary information about all\nCompositions in your account, in the AWS region where the API request is\nprocessed.\n\n  * `StartComposition` — Starts a Composition from a stage based on\nthe configuration provided in the request.\n\n  * `StopComposition` — Stops and deletes a Composition resource. Any\nbroadcast from the Composition resource is stopped.","ref":"AWS.IVSRealTime.html#module-composition-endpoints","title":"Composition Endpoints - AWS.IVSRealTime","type":"module"},{"doc":"* `CreateEncoderConfiguration` — Creates an EncoderConfiguration\nobject.\n\n  * `DeleteEncoderConfiguration` — Deletes an EncoderConfiguration\nresource. Ensures that no Compositions are using this template; otherwise,\nreturns an error.\n\n  * `GetEncoderConfiguration` — Gets information about the specified\nEncoderConfiguration resource.\n\n  * `ListEncoderConfigurations` — Gets summary information about all\nEncoderConfigurations in your account, in the AWS region where the API request\nis processed.","ref":"AWS.IVSRealTime.html#module-encoderconfiguration-endpoints","title":"EncoderConfiguration Endpoints - AWS.IVSRealTime","type":"module"},{"doc":"* `CreateStorageConfiguration` — Creates a new storage\nconfiguration, used to enable recording to Amazon S3.\n\n  * `DeleteStorageConfiguration` — Deletes the storage configuration\nfor the specified ARN.\n\n  * `GetStorageConfiguration` — Gets the storage configuration for the\nspecified ARN.\n\n  * `ListStorageConfigurations` — Gets summary information about all\nstorage configurations in your account, in the AWS region where the API request\nis processed.","ref":"AWS.IVSRealTime.html#module-storageconfiguration-endpoints","title":"StorageConfiguration Endpoints - AWS.IVSRealTime","type":"module"},{"doc":"* `ListTagsForResource` — Gets information about AWS tags for the\nspecified ARN.\n\n  * `TagResource` — Adds or updates tags for the AWS resource with the\nspecified ARN.\n\n  * `UntagResource` — Removes tags from the resource with the\nspecified ARN.","ref":"AWS.IVSRealTime.html#module-tags-endpoints","title":"Tags Endpoints - AWS.IVSRealTime","type":"module"},{"doc":"Creates an EncoderConfiguration object.","ref":"AWS.IVSRealTime.html#create_encoder_configuration/3","title":"AWS.IVSRealTime.create_encoder_configuration/3","type":"function"},{"doc":"Creates an additional token for a specified stage.\n\nThis can be done after stage creation or when tokens expire. Tokens always are\nscoped to the stage for which they are created.\n\nEncryption keys are owned by Amazon IVS and never used directly by your\napplication.","ref":"AWS.IVSRealTime.html#create_participant_token/3","title":"AWS.IVSRealTime.create_participant_token/3","type":"function"},{"doc":"Creates a new stage (and optionally participant tokens).","ref":"AWS.IVSRealTime.html#create_stage/3","title":"AWS.IVSRealTime.create_stage/3","type":"function"},{"doc":"Creates a new storage configuration, used to enable recording to Amazon S3.\n\nWhen a StorageConfiguration is created, IVS will modify the S3 bucketPolicy of\nthe provided bucket. This will ensure that IVS has sufficient permissions to\nwrite content to the provided bucket.","ref":"AWS.IVSRealTime.html#create_storage_configuration/3","title":"AWS.IVSRealTime.create_storage_configuration/3","type":"function"},{"doc":"Deletes an EncoderConfiguration resource.\n\nEnsures that no Compositions are using this template; otherwise, returns an\nerror.","ref":"AWS.IVSRealTime.html#delete_encoder_configuration/3","title":"AWS.IVSRealTime.delete_encoder_configuration/3","type":"function"},{"doc":"Shuts down and deletes the specified stage (disconnecting all participants).","ref":"AWS.IVSRealTime.html#delete_stage/3","title":"AWS.IVSRealTime.delete_stage/3","type":"function"},{"doc":"Deletes the storage configuration for the specified ARN.\n\nIf you try to delete a storage configuration that is used by a Composition, you\nwill get an error (409 ConflictException). To avoid this, for all Compositions\nthat reference the storage configuration, first use `StopComposition` and wait\nfor it to complete, then use DeleteStorageConfiguration.","ref":"AWS.IVSRealTime.html#delete_storage_configuration/3","title":"AWS.IVSRealTime.delete_storage_configuration/3","type":"function"},{"doc":"Disconnects a specified participant and revokes the participant permanently from\na specified stage.","ref":"AWS.IVSRealTime.html#disconnect_participant/3","title":"AWS.IVSRealTime.disconnect_participant/3","type":"function"},{"doc":"Get information about the specified Composition resource.","ref":"AWS.IVSRealTime.html#get_composition/3","title":"AWS.IVSRealTime.get_composition/3","type":"function"},{"doc":"Gets information about the specified EncoderConfiguration resource.","ref":"AWS.IVSRealTime.html#get_encoder_configuration/3","title":"AWS.IVSRealTime.get_encoder_configuration/3","type":"function"},{"doc":"Gets information about the specified participant token.","ref":"AWS.IVSRealTime.html#get_participant/3","title":"AWS.IVSRealTime.get_participant/3","type":"function"},{"doc":"Gets information for the specified stage.","ref":"AWS.IVSRealTime.html#get_stage/3","title":"AWS.IVSRealTime.get_stage/3","type":"function"},{"doc":"Gets information for the specified stage session.","ref":"AWS.IVSRealTime.html#get_stage_session/3","title":"AWS.IVSRealTime.get_stage_session/3","type":"function"},{"doc":"Gets the storage configuration for the specified ARN.","ref":"AWS.IVSRealTime.html#get_storage_configuration/3","title":"AWS.IVSRealTime.get_storage_configuration/3","type":"function"},{"doc":"Gets summary information about all Compositions in your account, in the AWS\nregion where the API request is processed.","ref":"AWS.IVSRealTime.html#list_compositions/3","title":"AWS.IVSRealTime.list_compositions/3","type":"function"},{"doc":"Gets summary information about all EncoderConfigurations in your account, in the\nAWS region where the API request is processed.","ref":"AWS.IVSRealTime.html#list_encoder_configurations/3","title":"AWS.IVSRealTime.list_encoder_configurations/3","type":"function"},{"doc":"Lists events for a specified participant that occurred during a specified stage\nsession.","ref":"AWS.IVSRealTime.html#list_participant_events/3","title":"AWS.IVSRealTime.list_participant_events/3","type":"function"},{"doc":"Lists all participants in a specified stage session.","ref":"AWS.IVSRealTime.html#list_participants/3","title":"AWS.IVSRealTime.list_participants/3","type":"function"},{"doc":"Gets all sessions for a specified stage.","ref":"AWS.IVSRealTime.html#list_stage_sessions/3","title":"AWS.IVSRealTime.list_stage_sessions/3","type":"function"},{"doc":"Gets summary information about all stages in your account, in the AWS region\nwhere the API request is processed.","ref":"AWS.IVSRealTime.html#list_stages/3","title":"AWS.IVSRealTime.list_stages/3","type":"function"},{"doc":"Gets summary information about all storage configurations in your account, in\nthe AWS region where the API request is processed.","ref":"AWS.IVSRealTime.html#list_storage_configurations/3","title":"AWS.IVSRealTime.list_storage_configurations/3","type":"function"},{"doc":"Gets information about AWS tags for the specified ARN.","ref":"AWS.IVSRealTime.html#list_tags_for_resource/3","title":"AWS.IVSRealTime.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.IVSRealTime.html#metadata/0","title":"AWS.IVSRealTime.metadata/0","type":"function"},{"doc":"Starts a Composition from a stage based on the configuration provided in the\nrequest.\n\nA Composition is an ephemeral resource that exists after this endpoint returns\nsuccessfully. Composition stops and the resource is deleted:\n\n  * When `StopComposition` is called.\n\n  * After a 1-minute timeout, when all participants are disconnected\nfrom the stage.\n\n  * After a 1-minute timeout, if there are no participants in the\nstage when StartComposition is called.\n\n  * When broadcasting to the IVS channel fails and all retries are\nexhausted.\n\n  * When broadcasting is disconnected and all attempts to reconnect\nare exhausted.","ref":"AWS.IVSRealTime.html#start_composition/3","title":"AWS.IVSRealTime.start_composition/3","type":"function"},{"doc":"Stops and deletes a Composition resource.\n\nAny broadcast from the Composition resource is stopped.","ref":"AWS.IVSRealTime.html#stop_composition/3","title":"AWS.IVSRealTime.stop_composition/3","type":"function"},{"doc":"Adds or updates tags for the AWS resource with the specified ARN.","ref":"AWS.IVSRealTime.html#tag_resource/4","title":"AWS.IVSRealTime.tag_resource/4","type":"function"},{"doc":"Removes tags from the resource with the specified ARN.","ref":"AWS.IVSRealTime.html#untag_resource/4","title":"AWS.IVSRealTime.untag_resource/4","type":"function"},{"doc":"Updates a stage’s configuration.","ref":"AWS.IVSRealTime.html#update_stage/3","title":"AWS.IVSRealTime.update_stage/3","type":"function"},{"doc":"The Identity Store service used by IAM Identity Center provides a single place\nto retrieve all of your identities (users and groups).\n\nFor more information, see the [IAM Identity Center User Guide](https://docs.aws.amazon.com/singlesignon/latest/userguide/what-is.html).\n\nThis reference guide describes the identity store operations that you can call\nprogrammatically and includes detailed information about data types and errors.\n\nIAM Identity Center uses the `sso` and `identitystore` API namespaces.","ref":"AWS.Identitystore.html","title":"AWS.Identitystore","type":"module"},{"doc":"Creates a group within the specified identity store.","ref":"AWS.Identitystore.html#create_group/3","title":"AWS.Identitystore.create_group/3","type":"function"},{"doc":"Creates a relationship between a member and a group.\n\nThe following identifiers must be specified: `GroupId`, `IdentityStoreId`, and\n`MemberId`.","ref":"AWS.Identitystore.html#create_group_membership/3","title":"AWS.Identitystore.create_group_membership/3","type":"function"},{"doc":"Creates a user within the specified identity store.","ref":"AWS.Identitystore.html#create_user/3","title":"AWS.Identitystore.create_user/3","type":"function"},{"doc":"Delete a group within an identity store given `GroupId`.","ref":"AWS.Identitystore.html#delete_group/3","title":"AWS.Identitystore.delete_group/3","type":"function"},{"doc":"Delete a membership within a group given `MembershipId`.","ref":"AWS.Identitystore.html#delete_group_membership/3","title":"AWS.Identitystore.delete_group_membership/3","type":"function"},{"doc":"Deletes a user within an identity store given `UserId`.","ref":"AWS.Identitystore.html#delete_user/3","title":"AWS.Identitystore.delete_user/3","type":"function"},{"doc":"Retrieves the group metadata and attributes from `GroupId` in an identity store.\n\nIf you have administrator access to a member account, you can use this API from\nthe member account. Read about [member accounts](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_accounts_access.html)\nin the *Organizations User Guide*.","ref":"AWS.Identitystore.html#describe_group/3","title":"AWS.Identitystore.describe_group/3","type":"function"},{"doc":"Retrieves membership metadata and attributes from `MembershipId` in an identity\nstore.\n\nIf you have administrator access to a member account, you can use this API from\nthe member account. Read about [member accounts](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_accounts_access.html)\nin the *Organizations User Guide*.","ref":"AWS.Identitystore.html#describe_group_membership/3","title":"AWS.Identitystore.describe_group_membership/3","type":"function"},{"doc":"Retrieves the user metadata and attributes from the `UserId` in an identity\nstore.\n\nIf you have administrator access to a member account, you can use this API from\nthe member account. Read about [member accounts](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_accounts_access.html)\nin the *Organizations User Guide*.","ref":"AWS.Identitystore.html#describe_user/3","title":"AWS.Identitystore.describe_user/3","type":"function"},{"doc":"Retrieves `GroupId` in an identity store.\n\nIf you have administrator access to a member account, you can use this API from\nthe member account. Read about [member accounts](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_accounts_access.html)\nin the *Organizations User Guide*.","ref":"AWS.Identitystore.html#get_group_id/3","title":"AWS.Identitystore.get_group_id/3","type":"function"},{"doc":"Retrieves the `MembershipId` in an identity store.\n\nIf you have administrator access to a member account, you can use this API from\nthe member account. Read about [member accounts](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_accounts_access.html)\nin the *Organizations User Guide*.","ref":"AWS.Identitystore.html#get_group_membership_id/3","title":"AWS.Identitystore.get_group_membership_id/3","type":"function"},{"doc":"Retrieves the `UserId` in an identity store.\n\nIf you have administrator access to a member account, you can use this API from\nthe member account. Read about [member accounts](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_accounts_access.html)\nin the *Organizations User Guide*.","ref":"AWS.Identitystore.html#get_user_id/3","title":"AWS.Identitystore.get_user_id/3","type":"function"},{"doc":"Checks the user's membership in all requested groups and returns if the member\nexists in all queried groups.\n\nIf you have administrator access to a member account, you can use this API from\nthe member account. Read about [member accounts](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_accounts_access.html)\nin the *Organizations User Guide*.","ref":"AWS.Identitystore.html#is_member_in_groups/3","title":"AWS.Identitystore.is_member_in_groups/3","type":"function"},{"doc":"For the specified group in the specified identity store, returns the list of all\n`GroupMembership` objects and returns results in paginated form.\n\nIf you have administrator access to a member account, you can use this API from\nthe member account. Read about [member accounts](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_accounts_access.html)\nin the *Organizations User Guide*.","ref":"AWS.Identitystore.html#list_group_memberships/3","title":"AWS.Identitystore.list_group_memberships/3","type":"function"},{"doc":"For the specified member in the specified identity store, returns the list of\nall `GroupMembership` objects and returns results in paginated form.\n\nIf you have administrator access to a member account, you can use this API from\nthe member account. Read about [member accounts](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_accounts_access.html)\nin the *Organizations User Guide*.","ref":"AWS.Identitystore.html#list_group_memberships_for_member/3","title":"AWS.Identitystore.list_group_memberships_for_member/3","type":"function"},{"doc":"Lists all groups in the identity store.\n\nReturns a paginated list of complete `Group` objects. Filtering for a `Group` by\nthe `DisplayName` attribute is deprecated. Instead, use the `GetGroupId` API\naction.\n\nIf you have administrator access to a member account, you can use this API from\nthe member account. Read about [member accounts](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_accounts_access.html)\nin the *Organizations User Guide*.","ref":"AWS.Identitystore.html#list_groups/3","title":"AWS.Identitystore.list_groups/3","type":"function"},{"doc":"Lists all users in the identity store.\n\nReturns a paginated list of complete `User` objects. Filtering for a `User` by\nthe `UserName` attribute is deprecated. Instead, use the `GetUserId` API action.\n\nIf you have administrator access to a member account, you can use this API from\nthe member account. Read about [member accounts](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_accounts_access.html)\nin the *Organizations User Guide*.","ref":"AWS.Identitystore.html#list_users/3","title":"AWS.Identitystore.list_users/3","type":"function"},{"doc":"","ref":"AWS.Identitystore.html#metadata/0","title":"AWS.Identitystore.metadata/0","type":"function"},{"doc":"For the specified group in the specified identity store, updates the group\nmetadata and attributes.","ref":"AWS.Identitystore.html#update_group/3","title":"AWS.Identitystore.update_group/3","type":"function"},{"doc":"For the specified user in the specified identity store, updates the user\nmetadata and attributes.","ref":"AWS.Identitystore.html#update_user/3","title":"AWS.Identitystore.update_user/3","type":"function"},{"doc":"EC2 Image Builder is a fully managed Amazon Web Services service that makes it\neasier to automate the creation, management, and deployment of customized,\nsecure, and up-to-date \"golden\" server images that are pre-installed and\npre-configured with software and settings to meet specific IT standards.","ref":"AWS.Imagebuilder.html","title":"AWS.Imagebuilder","type":"module"},{"doc":"CancelImageCreation cancels the creation of Image.\n\nThis operation can only be used on images in a non-terminal state.","ref":"AWS.Imagebuilder.html#cancel_image_creation/3","title":"AWS.Imagebuilder.cancel_image_creation/3","type":"function"},{"doc":"Cancel a specific image lifecycle policy runtime instance.","ref":"AWS.Imagebuilder.html#cancel_lifecycle_execution/3","title":"AWS.Imagebuilder.cancel_lifecycle_execution/3","type":"function"},{"doc":"Creates a new component that can be used to build, validate, test, and assess\nyour image.\n\nThe component is based on a YAML document that you specify using exactly one of\nthe following methods:\n\n  * Inline, using the `data` property in the request body.\n\n  * A URL that points to a YAML document file stored in Amazon S3,\nusing the `uri` property in the request body.","ref":"AWS.Imagebuilder.html#create_component/3","title":"AWS.Imagebuilder.create_component/3","type":"function"},{"doc":"Creates a new container recipe.\n\nContainer recipes define how images are configured, tested, and assessed.","ref":"AWS.Imagebuilder.html#create_container_recipe/3","title":"AWS.Imagebuilder.create_container_recipe/3","type":"function"},{"doc":"Creates a new distribution configuration.\n\nDistribution configurations define and configure the outputs of your pipeline.","ref":"AWS.Imagebuilder.html#create_distribution_configuration/3","title":"AWS.Imagebuilder.create_distribution_configuration/3","type":"function"},{"doc":"Creates a new image.\n\nThis request will create a new image along with all of the configured output\nresources defined in the distribution configuration. You must specify exactly\none recipe for your image, using either a ContainerRecipeArn or an\nImageRecipeArn.","ref":"AWS.Imagebuilder.html#create_image/3","title":"AWS.Imagebuilder.create_image/3","type":"function"},{"doc":"Creates a new image pipeline.\n\nImage pipelines enable you to automate the creation and distribution of images.","ref":"AWS.Imagebuilder.html#create_image_pipeline/3","title":"AWS.Imagebuilder.create_image_pipeline/3","type":"function"},{"doc":"Creates a new image recipe.\n\nImage recipes define how images are configured, tested, and assessed.","ref":"AWS.Imagebuilder.html#create_image_recipe/3","title":"AWS.Imagebuilder.create_image_recipe/3","type":"function"},{"doc":"Creates a new infrastructure configuration.\n\nAn infrastructure configuration defines the environment in which your image will\nbe built and tested.","ref":"AWS.Imagebuilder.html#create_infrastructure_configuration/3","title":"AWS.Imagebuilder.create_infrastructure_configuration/3","type":"function"},{"doc":"Create a lifecycle policy resource.","ref":"AWS.Imagebuilder.html#create_lifecycle_policy/3","title":"AWS.Imagebuilder.create_lifecycle_policy/3","type":"function"},{"doc":"Create a new workflow or a new version of an existing workflow.","ref":"AWS.Imagebuilder.html#create_workflow/3","title":"AWS.Imagebuilder.create_workflow/3","type":"function"},{"doc":"Deletes a component build version.","ref":"AWS.Imagebuilder.html#delete_component/3","title":"AWS.Imagebuilder.delete_component/3","type":"function"},{"doc":"Deletes a container recipe.","ref":"AWS.Imagebuilder.html#delete_container_recipe/3","title":"AWS.Imagebuilder.delete_container_recipe/3","type":"function"},{"doc":"Deletes a distribution configuration.","ref":"AWS.Imagebuilder.html#delete_distribution_configuration/3","title":"AWS.Imagebuilder.delete_distribution_configuration/3","type":"function"},{"doc":"Deletes an Image Builder image resource.\n\nThis does not delete any EC2 AMIs or ECR container images that are created\nduring the image build process. You must clean those up separately, using the\nappropriate Amazon EC2 or Amazon ECR console actions, or API or CLI commands.\n\n  * To deregister an EC2 Linux AMI, see [Deregister your Linux AMI](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/deregister-ami.html) in\nthe * *Amazon EC2 User Guide* *.\n\n  * To deregister an EC2 Windows AMI, see [Deregister your Windows AMI](https://docs.aws.amazon.com/AWSEC2/latest/WindowsGuide/deregister-ami.html)\nin the * *Amazon EC2 Windows Guide* *.\n\n  * To delete a container image from Amazon ECR, see [Deleting an image](https://docs.aws.amazon.com/AmazonECR/latest/userguide/delete_image.html)\nin the *Amazon ECR User Guide*.","ref":"AWS.Imagebuilder.html#delete_image/3","title":"AWS.Imagebuilder.delete_image/3","type":"function"},{"doc":"Deletes an image pipeline.","ref":"AWS.Imagebuilder.html#delete_image_pipeline/3","title":"AWS.Imagebuilder.delete_image_pipeline/3","type":"function"},{"doc":"Deletes an image recipe.","ref":"AWS.Imagebuilder.html#delete_image_recipe/3","title":"AWS.Imagebuilder.delete_image_recipe/3","type":"function"},{"doc":"Deletes an infrastructure configuration.","ref":"AWS.Imagebuilder.html#delete_infrastructure_configuration/3","title":"AWS.Imagebuilder.delete_infrastructure_configuration/3","type":"function"},{"doc":"Delete the specified lifecycle policy resource.","ref":"AWS.Imagebuilder.html#delete_lifecycle_policy/3","title":"AWS.Imagebuilder.delete_lifecycle_policy/3","type":"function"},{"doc":"Deletes a specific workflow resource.","ref":"AWS.Imagebuilder.html#delete_workflow/3","title":"AWS.Imagebuilder.delete_workflow/3","type":"function"},{"doc":"Gets a component object.","ref":"AWS.Imagebuilder.html#get_component/3","title":"AWS.Imagebuilder.get_component/3","type":"function"},{"doc":"Gets a component policy.","ref":"AWS.Imagebuilder.html#get_component_policy/3","title":"AWS.Imagebuilder.get_component_policy/3","type":"function"},{"doc":"Retrieves a container recipe.","ref":"AWS.Imagebuilder.html#get_container_recipe/3","title":"AWS.Imagebuilder.get_container_recipe/3","type":"function"},{"doc":"Retrieves the policy for a container recipe.","ref":"AWS.Imagebuilder.html#get_container_recipe_policy/3","title":"AWS.Imagebuilder.get_container_recipe_policy/3","type":"function"},{"doc":"Gets a distribution configuration.","ref":"AWS.Imagebuilder.html#get_distribution_configuration/3","title":"AWS.Imagebuilder.get_distribution_configuration/3","type":"function"},{"doc":"Gets an image.","ref":"AWS.Imagebuilder.html#get_image/3","title":"AWS.Imagebuilder.get_image/3","type":"function"},{"doc":"Gets an image pipeline.","ref":"AWS.Imagebuilder.html#get_image_pipeline/3","title":"AWS.Imagebuilder.get_image_pipeline/3","type":"function"},{"doc":"Gets an image policy.","ref":"AWS.Imagebuilder.html#get_image_policy/3","title":"AWS.Imagebuilder.get_image_policy/3","type":"function"},{"doc":"Gets an image recipe.","ref":"AWS.Imagebuilder.html#get_image_recipe/3","title":"AWS.Imagebuilder.get_image_recipe/3","type":"function"},{"doc":"Gets an image recipe policy.","ref":"AWS.Imagebuilder.html#get_image_recipe_policy/3","title":"AWS.Imagebuilder.get_image_recipe_policy/3","type":"function"},{"doc":"Gets an infrastructure configuration.","ref":"AWS.Imagebuilder.html#get_infrastructure_configuration/3","title":"AWS.Imagebuilder.get_infrastructure_configuration/3","type":"function"},{"doc":"Get the runtime information that was logged for a specific runtime instance of\nthe lifecycle policy.","ref":"AWS.Imagebuilder.html#get_lifecycle_execution/3","title":"AWS.Imagebuilder.get_lifecycle_execution/3","type":"function"},{"doc":"Get details for the specified image lifecycle policy.","ref":"AWS.Imagebuilder.html#get_lifecycle_policy/3","title":"AWS.Imagebuilder.get_lifecycle_policy/3","type":"function"},{"doc":"Get a workflow resource object.","ref":"AWS.Imagebuilder.html#get_workflow/3","title":"AWS.Imagebuilder.get_workflow/3","type":"function"},{"doc":"Get the runtime information that was logged for a specific runtime instance of\nthe workflow.","ref":"AWS.Imagebuilder.html#get_workflow_execution/3","title":"AWS.Imagebuilder.get_workflow_execution/3","type":"function"},{"doc":"Get the runtime information that was logged for a specific runtime instance of\nthe workflow step.","ref":"AWS.Imagebuilder.html#get_workflow_step_execution/3","title":"AWS.Imagebuilder.get_workflow_step_execution/3","type":"function"},{"doc":"Imports a component and transforms its data into a component document.","ref":"AWS.Imagebuilder.html#import_component/3","title":"AWS.Imagebuilder.import_component/3","type":"function"},{"doc":"When you export your virtual machine (VM) from its virtualization environment,\nthat process creates a set of one or more disk container files that act as\nsnapshots of your VM’s environment, settings, and data.\n\nThe Amazon EC2 API\n[ImportImage](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ImportImage.html) action uses those files to import your VM and create an AMI. To import using the\nCLI command, see\n[import-image](https://docs.aws.amazon.com/cli/latest/reference/ec2/import-image.html)\n\nYou can reference the task ID from the VM import to pull in the AMI that the\nimport created as the base image for your Image Builder recipe.","ref":"AWS.Imagebuilder.html#import_vm_image/3","title":"AWS.Imagebuilder.import_vm_image/3","type":"function"},{"doc":"Returns the list of component build versions for the specified semantic version.\n\nThe semantic version has four nodes:  . . / . You can\nassign values for the first three, and can filter on all of them.\n\n**Filtering:** With semantic versioning, you have the flexibility to use\nwildcards (x) to specify the most recent versions or nodes when selecting the\nbase image or components for your recipe. When you use a wildcard in any node,\nall nodes to the right of the first wildcard must also be wildcards.","ref":"AWS.Imagebuilder.html#list_component_build_versions/3","title":"AWS.Imagebuilder.list_component_build_versions/3","type":"function"},{"doc":"Returns the list of components that can be filtered by name, or by using the\nlisted `filters` to streamline results.\n\nNewly created components can take up to two minutes to appear in the\nListComponents API Results.\n\nThe semantic version has four nodes:  . . / . You can\nassign values for the first three, and can filter on all of them.\n\n**Filtering:** With semantic versioning, you have the flexibility to use\nwildcards (x) to specify the most recent versions or nodes when selecting the\nbase image or components for your recipe. When you use a wildcard in any node,\nall nodes to the right of the first wildcard must also be wildcards.","ref":"AWS.Imagebuilder.html#list_components/3","title":"AWS.Imagebuilder.list_components/3","type":"function"},{"doc":"Returns a list of container recipes.","ref":"AWS.Imagebuilder.html#list_container_recipes/3","title":"AWS.Imagebuilder.list_container_recipes/3","type":"function"},{"doc":"Returns a list of distribution configurations.","ref":"AWS.Imagebuilder.html#list_distribution_configurations/3","title":"AWS.Imagebuilder.list_distribution_configurations/3","type":"function"},{"doc":"Returns a list of image build versions.","ref":"AWS.Imagebuilder.html#list_image_build_versions/3","title":"AWS.Imagebuilder.list_image_build_versions/3","type":"function"},{"doc":"List the Packages that are associated with an Image Build Version, as determined\nby Amazon Web Services Systems Manager Inventory at build time.","ref":"AWS.Imagebuilder.html#list_image_packages/3","title":"AWS.Imagebuilder.list_image_packages/3","type":"function"},{"doc":"Returns a list of images created by the specified pipeline.","ref":"AWS.Imagebuilder.html#list_image_pipeline_images/3","title":"AWS.Imagebuilder.list_image_pipeline_images/3","type":"function"},{"doc":"Returns a list of image pipelines.","ref":"AWS.Imagebuilder.html#list_image_pipelines/3","title":"AWS.Imagebuilder.list_image_pipelines/3","type":"function"},{"doc":"Returns a list of image recipes.","ref":"AWS.Imagebuilder.html#list_image_recipes/3","title":"AWS.Imagebuilder.list_image_recipes/3","type":"function"},{"doc":"Returns a list of image scan aggregations for your account.\n\nYou can filter by the type of key that Image Builder uses to group results. For\nexample, if you want to get a list of findings by severity level for one of your\npipelines, you might specify your pipeline with the `imagePipelineArn` filter.\nIf you don't specify a filter, Image Builder returns an aggregation for your\naccount.\n\nTo streamline results, you can use the following filters in your request:\n\n  * `accountId`\n\n  * `imageBuildVersionArn`\n\n  * `imagePipelineArn`\n\n  * `vulnerabilityId`","ref":"AWS.Imagebuilder.html#list_image_scan_finding_aggregations/3","title":"AWS.Imagebuilder.list_image_scan_finding_aggregations/3","type":"function"},{"doc":"Returns a list of image scan findings for your account.","ref":"AWS.Imagebuilder.html#list_image_scan_findings/3","title":"AWS.Imagebuilder.list_image_scan_findings/3","type":"function"},{"doc":"Returns the list of images that you have access to.\n\nNewly created images can take up to two minutes to appear in the ListImages API\nResults.","ref":"AWS.Imagebuilder.html#list_images/3","title":"AWS.Imagebuilder.list_images/3","type":"function"},{"doc":"Returns a list of infrastructure configurations.","ref":"AWS.Imagebuilder.html#list_infrastructure_configurations/3","title":"AWS.Imagebuilder.list_infrastructure_configurations/3","type":"function"},{"doc":"List resources that the runtime instance of the image lifecycle identified for\nlifecycle actions.","ref":"AWS.Imagebuilder.html#list_lifecycle_execution_resources/3","title":"AWS.Imagebuilder.list_lifecycle_execution_resources/3","type":"function"},{"doc":"Get the lifecycle runtime history for the specified resource.","ref":"AWS.Imagebuilder.html#list_lifecycle_executions/3","title":"AWS.Imagebuilder.list_lifecycle_executions/3","type":"function"},{"doc":"Get a list of lifecycle policies in your Amazon Web Services account.","ref":"AWS.Imagebuilder.html#list_lifecycle_policies/3","title":"AWS.Imagebuilder.list_lifecycle_policies/3","type":"function"},{"doc":"Returns the list of tags for the specified resource.","ref":"AWS.Imagebuilder.html#list_tags_for_resource/3","title":"AWS.Imagebuilder.list_tags_for_resource/3","type":"function"},{"doc":"Get a list of workflow steps that are waiting for action for workflows in your\nAmazon Web Services account.","ref":"AWS.Imagebuilder.html#list_waiting_workflow_steps/3","title":"AWS.Imagebuilder.list_waiting_workflow_steps/3","type":"function"},{"doc":"Returns a list of build versions for a specific workflow resource.","ref":"AWS.Imagebuilder.html#list_workflow_build_versions/3","title":"AWS.Imagebuilder.list_workflow_build_versions/3","type":"function"},{"doc":"Returns a list of workflow runtime instance metadata objects for a specific\nimage build version.","ref":"AWS.Imagebuilder.html#list_workflow_executions/3","title":"AWS.Imagebuilder.list_workflow_executions/3","type":"function"},{"doc":"Returns runtime data for each step in a runtime instance of the workflow that\nyou specify in the request.","ref":"AWS.Imagebuilder.html#list_workflow_step_executions/3","title":"AWS.Imagebuilder.list_workflow_step_executions/3","type":"function"},{"doc":"Lists workflow build versions based on filtering parameters.","ref":"AWS.Imagebuilder.html#list_workflows/3","title":"AWS.Imagebuilder.list_workflows/3","type":"function"},{"doc":"","ref":"AWS.Imagebuilder.html#metadata/0","title":"AWS.Imagebuilder.metadata/0","type":"function"},{"doc":"Applies a policy to a component.\n\nWe recommend that you call the RAM API\n[CreateResourceShare](https://docs.aws.amazon.com/ram/latest/APIReference/API_CreateResourceShare.html) to share resources. If you call the Image Builder API `PutComponentPolicy`, you\nmust also call the RAM API\n[PromoteResourceShareCreatedFromPolicy](https://docs.aws.amazon.com/ram/latest/APIReference/API_PromoteResourceShareCreatedFromPolicy.html)\nin order for the resource to be visible to all principals with whom the resource\nis shared.","ref":"AWS.Imagebuilder.html#put_component_policy/3","title":"AWS.Imagebuilder.put_component_policy/3","type":"function"},{"doc":"Applies a policy to a container image.\n\nWe recommend that you call the RAM API CreateResourceShare\n(https://docs.aws.amazon.com//ram/latest/APIReference/API_CreateResourceShare.html)\nto share resources. If you call the Image Builder API `PutContainerImagePolicy`,\nyou must also call the RAM API PromoteResourceShareCreatedFromPolicy\n(https://docs.aws.amazon.com//ram/latest/APIReference/API_PromoteResourceShareCreatedFromPolicy.html)\nin order for the resource to be visible to all principals with whom the resource\nis shared.","ref":"AWS.Imagebuilder.html#put_container_recipe_policy/3","title":"AWS.Imagebuilder.put_container_recipe_policy/3","type":"function"},{"doc":"Applies a policy to an image.\n\nWe recommend that you call the RAM API\n[CreateResourceShare](https://docs.aws.amazon.com/ram/latest/APIReference/API_CreateResourceShare.html) to share resources. If you call the Image Builder API `PutImagePolicy`, you must\nalso call the RAM API\n[PromoteResourceShareCreatedFromPolicy](https://docs.aws.amazon.com/ram/latest/APIReference/API_PromoteResourceShareCreatedFromPolicy.html)\nin order for the resource to be visible to all principals with whom the resource\nis shared.","ref":"AWS.Imagebuilder.html#put_image_policy/3","title":"AWS.Imagebuilder.put_image_policy/3","type":"function"},{"doc":"Applies a policy to an image recipe.\n\nWe recommend that you call the RAM API\n[CreateResourceShare](https://docs.aws.amazon.com/ram/latest/APIReference/API_CreateResourceShare.html) to share resources. If you call the Image Builder API `PutImageRecipePolicy`,\nyou must also call the RAM API\n[PromoteResourceShareCreatedFromPolicy](https://docs.aws.amazon.com/ram/latest/APIReference/API_PromoteResourceShareCreatedFromPolicy.html)\nin order for the resource to be visible to all principals with whom the resource\nis shared.","ref":"AWS.Imagebuilder.html#put_image_recipe_policy/3","title":"AWS.Imagebuilder.put_image_recipe_policy/3","type":"function"},{"doc":"Pauses or resumes image creation when the associated workflow runs a\n`WaitForAction` step.","ref":"AWS.Imagebuilder.html#send_workflow_step_action/3","title":"AWS.Imagebuilder.send_workflow_step_action/3","type":"function"},{"doc":"Manually triggers a pipeline to create an image.","ref":"AWS.Imagebuilder.html#start_image_pipeline_execution/3","title":"AWS.Imagebuilder.start_image_pipeline_execution/3","type":"function"},{"doc":"Begin asynchronous resource state update for lifecycle changes to the specified\nimage resources.","ref":"AWS.Imagebuilder.html#start_resource_state_update/3","title":"AWS.Imagebuilder.start_resource_state_update/3","type":"function"},{"doc":"Adds a tag to a resource.","ref":"AWS.Imagebuilder.html#tag_resource/4","title":"AWS.Imagebuilder.tag_resource/4","type":"function"},{"doc":"Removes a tag from a resource.","ref":"AWS.Imagebuilder.html#untag_resource/4","title":"AWS.Imagebuilder.untag_resource/4","type":"function"},{"doc":"Updates a new distribution configuration.\n\nDistribution configurations define and configure the outputs of your pipeline.","ref":"AWS.Imagebuilder.html#update_distribution_configuration/3","title":"AWS.Imagebuilder.update_distribution_configuration/3","type":"function"},{"doc":"Updates an image pipeline.\n\nImage pipelines enable you to automate the creation and distribution of images.\nYou must specify exactly one recipe for your image, using either a\n`containerRecipeArn` or an `imageRecipeArn`.\n\nUpdateImagePipeline does not support selective updates for the pipeline. You\nmust specify all of the required properties in the update request, not just the\nproperties that have changed.","ref":"AWS.Imagebuilder.html#update_image_pipeline/3","title":"AWS.Imagebuilder.update_image_pipeline/3","type":"function"},{"doc":"Updates a new infrastructure configuration.\n\nAn infrastructure configuration defines the environment in which your image will\nbe built and tested.","ref":"AWS.Imagebuilder.html#update_infrastructure_configuration/3","title":"AWS.Imagebuilder.update_infrastructure_configuration/3","type":"function"},{"doc":"Update the specified lifecycle policy.","ref":"AWS.Imagebuilder.html#update_lifecycle_policy/3","title":"AWS.Imagebuilder.update_lifecycle_policy/3","type":"function"},{"doc":"AWS Import/Export Service\n\nAWS Import/Export accelerates transferring large amounts of data between the AWS\ncloud and portable storage devices that you mail to us.\n\nAWS Import/Export transfers data directly onto and off of your storage devices\nusing Amazon's high-speed internal network and bypassing the Internet. For large\ndata sets, AWS Import/Export is often faster than Internet transfer and more\ncost effective than upgrading your connectivity.","ref":"AWS.ImportExport.html","title":"AWS.ImportExport","type":"module"},{"doc":"This operation cancels a specified job.\n\nOnly the job owner can cancel it. The operation fails if the job has already\nstarted or is complete.","ref":"AWS.ImportExport.html#cancel_job/3","title":"AWS.ImportExport.cancel_job/3","type":"function"},{"doc":"This operation initiates the process of scheduling an upload or download of your\ndata.\n\nYou include in the request a manifest that describes the data transfer\nspecifics. The response to the request includes a job ID, which you can use in\nother operations, a signature that you use to identify your storage device, and\nthe address where you should ship your storage device.","ref":"AWS.ImportExport.html#create_job/3","title":"AWS.ImportExport.create_job/3","type":"function"},{"doc":"This operation generates a pre-paid UPS shipping label that you will use to ship\nyour device to AWS for processing.","ref":"AWS.ImportExport.html#get_shipping_label/3","title":"AWS.ImportExport.get_shipping_label/3","type":"function"},{"doc":"This operation returns information about a job, including where the job is in\nthe processing pipeline, the status of the results, and the signature value\nassociated with the job.\n\nYou can only return information about jobs you own.","ref":"AWS.ImportExport.html#get_status/3","title":"AWS.ImportExport.get_status/3","type":"function"},{"doc":"This operation returns the jobs associated with the requester.\n\nAWS Import/Export lists the jobs in reverse chronological order based on the\ndate of creation. For example if Job Test1 was created 2009Dec30 and Test2 was\ncreated 2010Feb05, the ListJobs operation would return Test2 followed by Test1.","ref":"AWS.ImportExport.html#list_jobs/3","title":"AWS.ImportExport.list_jobs/3","type":"function"},{"doc":"","ref":"AWS.ImportExport.html#metadata/0","title":"AWS.ImportExport.metadata/0","type":"function"},{"doc":"You use this operation to change the parameters specified in the original\nmanifest file by supplying a new manifest file.\n\nThe manifest file attached to this request replaces the original manifest file.\nYou can only use the operation after a CreateJob request but before the data\ntransfer starts and you can only use it on jobs you own.","ref":"AWS.ImportExport.html#update_job/3","title":"AWS.ImportExport.update_job/3","type":"function"},{"doc":"Amazon Inspector\n\nAmazon Inspector enables you to analyze the behavior of your AWS resources and\nto identify potential security issues.\n\nFor more information, see [ Amazon Inspector User Guide](https://docs.aws.amazon.com/inspector/latest/userguide/inspector_introduction.html).","ref":"AWS.Inspector.html","title":"AWS.Inspector","type":"module"},{"doc":"Assigns attributes (key and value pairs) to the findings that are specified by\nthe ARNs of the findings.","ref":"AWS.Inspector.html#add_attributes_to_findings/3","title":"AWS.Inspector.add_attributes_to_findings/3","type":"function"},{"doc":"Creates a new assessment target using the ARN of the resource group that is\ngenerated by `CreateResourceGroup`.\n\nIf resourceGroupArn is not specified, all EC2 instances in the current AWS\naccount and region are included in the assessment target. If the [service-linked role](https://docs.aws.amazon.com/inspector/latest/userguide/inspector_slr.html)\nisn’t already registered, this action also creates and registers a\nservice-linked role to grant Amazon Inspector access to AWS Services needed to\nperform security assessments. You can create up to 50 assessment targets per AWS\naccount. You can run up to 500 concurrent agents per AWS account. For more\ninformation, see [ Amazon Inspector Assessment Targets](https://docs.aws.amazon.com/inspector/latest/userguide/inspector_applications.html).","ref":"AWS.Inspector.html#create_assessment_target/3","title":"AWS.Inspector.create_assessment_target/3","type":"function"},{"doc":"Creates an assessment template for the assessment target that is specified by\nthe ARN of the assessment target.\n\nIf the [service-linked role](https://docs.aws.amazon.com/inspector/latest/userguide/inspector_slr.html)\nisn’t already registered, this action also creates and registers a\nservice-linked role to grant Amazon Inspector access to AWS Services needed to\nperform security assessments.","ref":"AWS.Inspector.html#create_assessment_template/3","title":"AWS.Inspector.create_assessment_template/3","type":"function"},{"doc":"Starts the generation of an exclusions preview for the specified assessment\ntemplate.\n\nThe exclusions preview lists the potential exclusions (ExclusionPreview) that\nInspector can detect before it runs the assessment.","ref":"AWS.Inspector.html#create_exclusions_preview/3","title":"AWS.Inspector.create_exclusions_preview/3","type":"function"},{"doc":"Creates a resource group using the specified set of tags (key and value pairs)\nthat are used to select the EC2 instances to be included in an Amazon Inspector\nassessment target.\n\nThe created resource group is then used to create an Amazon Inspector assessment\ntarget. For more information, see `CreateAssessmentTarget`.","ref":"AWS.Inspector.html#create_resource_group/3","title":"AWS.Inspector.create_resource_group/3","type":"function"},{"doc":"Deletes the assessment run that is specified by the ARN of the assessment run.","ref":"AWS.Inspector.html#delete_assessment_run/3","title":"AWS.Inspector.delete_assessment_run/3","type":"function"},{"doc":"Deletes the assessment target that is specified by the ARN of the assessment\ntarget.","ref":"AWS.Inspector.html#delete_assessment_target/3","title":"AWS.Inspector.delete_assessment_target/3","type":"function"},{"doc":"Deletes the assessment template that is specified by the ARN of the assessment\ntemplate.","ref":"AWS.Inspector.html#delete_assessment_template/3","title":"AWS.Inspector.delete_assessment_template/3","type":"function"},{"doc":"Describes the assessment runs that are specified by the ARNs of the assessment\nruns.","ref":"AWS.Inspector.html#describe_assessment_runs/3","title":"AWS.Inspector.describe_assessment_runs/3","type":"function"},{"doc":"Describes the assessment targets that are specified by the ARNs of the\nassessment targets.","ref":"AWS.Inspector.html#describe_assessment_targets/3","title":"AWS.Inspector.describe_assessment_targets/3","type":"function"},{"doc":"Describes the assessment templates that are specified by the ARNs of the\nassessment templates.","ref":"AWS.Inspector.html#describe_assessment_templates/3","title":"AWS.Inspector.describe_assessment_templates/3","type":"function"},{"doc":"Describes the IAM role that enables Amazon Inspector to access your AWS account.","ref":"AWS.Inspector.html#describe_cross_account_access_role/3","title":"AWS.Inspector.describe_cross_account_access_role/3","type":"function"},{"doc":"Describes the exclusions that are specified by the exclusions' ARNs.","ref":"AWS.Inspector.html#describe_exclusions/3","title":"AWS.Inspector.describe_exclusions/3","type":"function"},{"doc":"Describes the findings that are specified by the ARNs of the findings.","ref":"AWS.Inspector.html#describe_findings/3","title":"AWS.Inspector.describe_findings/3","type":"function"},{"doc":"Describes the resource groups that are specified by the ARNs of the resource\ngroups.","ref":"AWS.Inspector.html#describe_resource_groups/3","title":"AWS.Inspector.describe_resource_groups/3","type":"function"},{"doc":"Describes the rules packages that are specified by the ARNs of the rules\npackages.","ref":"AWS.Inspector.html#describe_rules_packages/3","title":"AWS.Inspector.describe_rules_packages/3","type":"function"},{"doc":"Produces an assessment report that includes detailed and comprehensive results\nof a specified assessment run.","ref":"AWS.Inspector.html#get_assessment_report/3","title":"AWS.Inspector.get_assessment_report/3","type":"function"},{"doc":"Retrieves the exclusions preview (a list of ExclusionPreview objects) specified\nby the preview token.\n\nYou can obtain the preview token by running the CreateExclusionsPreview API.","ref":"AWS.Inspector.html#get_exclusions_preview/3","title":"AWS.Inspector.get_exclusions_preview/3","type":"function"},{"doc":"Information about the data that is collected for the specified assessment run.","ref":"AWS.Inspector.html#get_telemetry_metadata/3","title":"AWS.Inspector.get_telemetry_metadata/3","type":"function"},{"doc":"Lists the agents of the assessment runs that are specified by the ARNs of the\nassessment runs.","ref":"AWS.Inspector.html#list_assessment_run_agents/3","title":"AWS.Inspector.list_assessment_run_agents/3","type":"function"},{"doc":"Lists the assessment runs that correspond to the assessment templates that are\nspecified by the ARNs of the assessment templates.","ref":"AWS.Inspector.html#list_assessment_runs/3","title":"AWS.Inspector.list_assessment_runs/3","type":"function"},{"doc":"Lists the ARNs of the assessment targets within this AWS account.\n\nFor more information about assessment targets, see [Amazon Inspector Assessment Targets](https://docs.aws.amazon.com/inspector/latest/userguide/inspector_applications.html).","ref":"AWS.Inspector.html#list_assessment_targets/3","title":"AWS.Inspector.list_assessment_targets/3","type":"function"},{"doc":"Lists the assessment templates that correspond to the assessment targets that\nare specified by the ARNs of the assessment targets.","ref":"AWS.Inspector.html#list_assessment_templates/3","title":"AWS.Inspector.list_assessment_templates/3","type":"function"},{"doc":"Lists all the event subscriptions for the assessment template that is specified\nby the ARN of the assessment template.\n\nFor more information, see `SubscribeToEvent` and `UnsubscribeFromEvent`.","ref":"AWS.Inspector.html#list_event_subscriptions/3","title":"AWS.Inspector.list_event_subscriptions/3","type":"function"},{"doc":"List exclusions that are generated by the assessment run.","ref":"AWS.Inspector.html#list_exclusions/3","title":"AWS.Inspector.list_exclusions/3","type":"function"},{"doc":"Lists findings that are generated by the assessment runs that are specified by\nthe ARNs of the assessment runs.","ref":"AWS.Inspector.html#list_findings/3","title":"AWS.Inspector.list_findings/3","type":"function"},{"doc":"Lists all available Amazon Inspector rules packages.","ref":"AWS.Inspector.html#list_rules_packages/3","title":"AWS.Inspector.list_rules_packages/3","type":"function"},{"doc":"Lists all tags associated with an assessment template.","ref":"AWS.Inspector.html#list_tags_for_resource/3","title":"AWS.Inspector.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.Inspector.html#metadata/0","title":"AWS.Inspector.metadata/0","type":"function"},{"doc":"Previews the agents installed on the EC2 instances that are part of the\nspecified assessment target.","ref":"AWS.Inspector.html#preview_agents/3","title":"AWS.Inspector.preview_agents/3","type":"function"},{"doc":"Registers the IAM role that grants Amazon Inspector access to AWS Services\nneeded to perform security assessments.","ref":"AWS.Inspector.html#register_cross_account_access_role/3","title":"AWS.Inspector.register_cross_account_access_role/3","type":"function"},{"doc":"Removes entire attributes (key and value pairs) from the findings that are\nspecified by the ARNs of the findings where an attribute with the specified key\nexists.","ref":"AWS.Inspector.html#remove_attributes_from_findings/3","title":"AWS.Inspector.remove_attributes_from_findings/3","type":"function"},{"doc":"Sets tags (key and value pairs) to the assessment template that is specified by\nthe ARN of the assessment template.","ref":"AWS.Inspector.html#set_tags_for_resource/3","title":"AWS.Inspector.set_tags_for_resource/3","type":"function"},{"doc":"Starts the assessment run specified by the ARN of the assessment template.\n\nFor this API to function properly, you must not exceed the limit of running up\nto 500 concurrent agents per AWS account.","ref":"AWS.Inspector.html#start_assessment_run/3","title":"AWS.Inspector.start_assessment_run/3","type":"function"},{"doc":"Stops the assessment run that is specified by the ARN of the assessment run.","ref":"AWS.Inspector.html#stop_assessment_run/3","title":"AWS.Inspector.stop_assessment_run/3","type":"function"},{"doc":"Enables the process of sending Amazon Simple Notification Service (SNS)\nnotifications about a specified event to a specified SNS topic.","ref":"AWS.Inspector.html#subscribe_to_event/3","title":"AWS.Inspector.subscribe_to_event/3","type":"function"},{"doc":"Disables the process of sending Amazon Simple Notification Service (SNS)\nnotifications about a specified event to a specified SNS topic.","ref":"AWS.Inspector.html#unsubscribe_from_event/3","title":"AWS.Inspector.unsubscribe_from_event/3","type":"function"},{"doc":"Updates the assessment target that is specified by the ARN of the assessment\ntarget.\n\nIf resourceGroupArn is not specified, all EC2 instances in the current AWS\naccount and region are included in the assessment target.","ref":"AWS.Inspector.html#update_assessment_target/3","title":"AWS.Inspector.update_assessment_target/3","type":"function"},{"doc":"Amazon Inspector is a vulnerability discovery service that automates continuous\nscanning for security vulnerabilities within your Amazon EC2, Amazon ECR, and\nAmazon Web Services Lambda environments.","ref":"AWS.Inspector2.html","title":"AWS.Inspector2","type":"module"},{"doc":"Associates an Amazon Web Services account with an Amazon Inspector delegated\nadministrator.\n\nAn HTTP 200 response indicates the association was successfully started, but\ndoesn’t indicate whether it was completed. You can check if the association\ncompleted by using\n[ListMembers](https://docs.aws.amazon.com/inspector/v2/APIReference/API_ListMembers.html) for multiple accounts or\n[GetMembers](https://docs.aws.amazon.com/inspector/v2/APIReference/API_GetMember.html)\nfor a single account.","ref":"AWS.Inspector2.html#associate_member/3","title":"AWS.Inspector2.associate_member/3","type":"function"},{"doc":"Retrieves the Amazon Inspector status of multiple Amazon Web Services accounts\nwithin your environment.","ref":"AWS.Inspector2.html#batch_get_account_status/3","title":"AWS.Inspector2.batch_get_account_status/3","type":"function"},{"doc":"Retrieves code snippets from findings that Amazon Inspector detected code\nvulnerabilities in.","ref":"AWS.Inspector2.html#batch_get_code_snippet/3","title":"AWS.Inspector2.batch_get_code_snippet/3","type":"function"},{"doc":"Gets vulnerability details for findings.","ref":"AWS.Inspector2.html#batch_get_finding_details/3","title":"AWS.Inspector2.batch_get_finding_details/3","type":"function"},{"doc":"Gets free trial status for multiple Amazon Web Services accounts.","ref":"AWS.Inspector2.html#batch_get_free_trial_info/3","title":"AWS.Inspector2.batch_get_free_trial_info/3","type":"function"},{"doc":"Retrieves Amazon Inspector deep inspection activation status of multiple member\naccounts within your organization.\n\nYou must be the delegated administrator of an organization in Amazon Inspector\nto use this API.","ref":"AWS.Inspector2.html#batch_get_member_ec2_deep_inspection_status/3","title":"AWS.Inspector2.batch_get_member_ec2_deep_inspection_status/3","type":"function"},{"doc":"Activates or deactivates Amazon Inspector deep inspection for the provided\nmember accounts in your organization.\n\nYou must be the delegated administrator of an organization in Amazon Inspector\nto use this API.","ref":"AWS.Inspector2.html#batch_update_member_ec2_deep_inspection_status/3","title":"AWS.Inspector2.batch_update_member_ec2_deep_inspection_status/3","type":"function"},{"doc":"Cancels the given findings report.","ref":"AWS.Inspector2.html#cancel_findings_report/3","title":"AWS.Inspector2.cancel_findings_report/3","type":"function"},{"doc":"Cancels a software bill of materials (SBOM) report.","ref":"AWS.Inspector2.html#cancel_sbom_export/3","title":"AWS.Inspector2.cancel_sbom_export/3","type":"function"},{"doc":"Creates a CIS scan configuration.","ref":"AWS.Inspector2.html#create_cis_scan_configuration/3","title":"AWS.Inspector2.create_cis_scan_configuration/3","type":"function"},{"doc":"Creates a filter resource using specified filter criteria.\n\nWhen the filter action is set to `SUPPRESS` this action creates a suppression\nrule.","ref":"AWS.Inspector2.html#create_filter/3","title":"AWS.Inspector2.create_filter/3","type":"function"},{"doc":"Creates a finding report.\n\nBy default only `ACTIVE` findings are returned in the report. To see `SUPRESSED`\nor `CLOSED` findings you must specify a value for the `findingStatus` filter\ncriteria.","ref":"AWS.Inspector2.html#create_findings_report/3","title":"AWS.Inspector2.create_findings_report/3","type":"function"},{"doc":"Creates a software bill of materials (SBOM) report.","ref":"AWS.Inspector2.html#create_sbom_export/3","title":"AWS.Inspector2.create_sbom_export/3","type":"function"},{"doc":"Deletes a CIS scan configuration.","ref":"AWS.Inspector2.html#delete_cis_scan_configuration/3","title":"AWS.Inspector2.delete_cis_scan_configuration/3","type":"function"},{"doc":"Deletes a filter resource.","ref":"AWS.Inspector2.html#delete_filter/3","title":"AWS.Inspector2.delete_filter/3","type":"function"},{"doc":"Describe Amazon Inspector configuration settings for an Amazon Web Services\norganization.","ref":"AWS.Inspector2.html#describe_organization_configuration/3","title":"AWS.Inspector2.describe_organization_configuration/3","type":"function"},{"doc":"Disables Amazon Inspector scans for one or more Amazon Web Services accounts.\n\nDisabling all scan types in an account disables the Amazon Inspector service.","ref":"AWS.Inspector2.html#disable/3","title":"AWS.Inspector2.disable/3","type":"function"},{"doc":"Disables the Amazon Inspector delegated administrator for your organization.","ref":"AWS.Inspector2.html#disable_delegated_admin_account/3","title":"AWS.Inspector2.disable_delegated_admin_account/3","type":"function"},{"doc":"Disassociates a member account from an Amazon Inspector delegated administrator.","ref":"AWS.Inspector2.html#disassociate_member/3","title":"AWS.Inspector2.disassociate_member/3","type":"function"},{"doc":"Enables Amazon Inspector scans for one or more Amazon Web Services accounts.","ref":"AWS.Inspector2.html#enable/3","title":"AWS.Inspector2.enable/3","type":"function"},{"doc":"Enables the Amazon Inspector delegated administrator for your Organizations\norganization.","ref":"AWS.Inspector2.html#enable_delegated_admin_account/3","title":"AWS.Inspector2.enable_delegated_admin_account/3","type":"function"},{"doc":"Retrieves a CIS scan report.","ref":"AWS.Inspector2.html#get_cis_scan_report/3","title":"AWS.Inspector2.get_cis_scan_report/3","type":"function"},{"doc":"Retrieves CIS scan result details.","ref":"AWS.Inspector2.html#get_cis_scan_result_details/3","title":"AWS.Inspector2.get_cis_scan_result_details/3","type":"function"},{"doc":"Retrieves setting configurations for Inspector scans.","ref":"AWS.Inspector2.html#get_configuration/3","title":"AWS.Inspector2.get_configuration/3","type":"function"},{"doc":"Retrieves information about the Amazon Inspector delegated administrator for\nyour organization.","ref":"AWS.Inspector2.html#get_delegated_admin_account/3","title":"AWS.Inspector2.get_delegated_admin_account/3","type":"function"},{"doc":"Retrieves the activation status of Amazon Inspector deep inspection and custom\npaths associated with your account.","ref":"AWS.Inspector2.html#get_ec2_deep_inspection_configuration/3","title":"AWS.Inspector2.get_ec2_deep_inspection_configuration/3","type":"function"},{"doc":"Gets an encryption key.","ref":"AWS.Inspector2.html#get_encryption_key/4","title":"AWS.Inspector2.get_encryption_key/4","type":"function"},{"doc":"Gets the status of a findings report.","ref":"AWS.Inspector2.html#get_findings_report_status/3","title":"AWS.Inspector2.get_findings_report_status/3","type":"function"},{"doc":"Gets member information for your organization.","ref":"AWS.Inspector2.html#get_member/3","title":"AWS.Inspector2.get_member/3","type":"function"},{"doc":"Gets details of a software bill of materials (SBOM) report.","ref":"AWS.Inspector2.html#get_sbom_export/3","title":"AWS.Inspector2.get_sbom_export/3","type":"function"},{"doc":"Lists the permissions an account has to configure Amazon Inspector.","ref":"AWS.Inspector2.html#list_account_permissions/3","title":"AWS.Inspector2.list_account_permissions/3","type":"function"},{"doc":"Lists CIS scan configurations.","ref":"AWS.Inspector2.html#list_cis_scan_configurations/3","title":"AWS.Inspector2.list_cis_scan_configurations/3","type":"function"},{"doc":"Lists scan results aggregated by checks.","ref":"AWS.Inspector2.html#list_cis_scan_results_aggregated_by_checks/3","title":"AWS.Inspector2.list_cis_scan_results_aggregated_by_checks/3","type":"function"},{"doc":"Lists scan results aggregated by a target resource.","ref":"AWS.Inspector2.html#list_cis_scan_results_aggregated_by_target_resource/3","title":"AWS.Inspector2.list_cis_scan_results_aggregated_by_target_resource/3","type":"function"},{"doc":"Returns a CIS scan list.","ref":"AWS.Inspector2.html#list_cis_scans/3","title":"AWS.Inspector2.list_cis_scans/3","type":"function"},{"doc":"Lists coverage details for you environment.","ref":"AWS.Inspector2.html#list_coverage/3","title":"AWS.Inspector2.list_coverage/3","type":"function"},{"doc":"Lists Amazon Inspector coverage statistics for your environment.","ref":"AWS.Inspector2.html#list_coverage_statistics/3","title":"AWS.Inspector2.list_coverage_statistics/3","type":"function"},{"doc":"Lists information about the Amazon Inspector delegated administrator of your\norganization.","ref":"AWS.Inspector2.html#list_delegated_admin_accounts/3","title":"AWS.Inspector2.list_delegated_admin_accounts/3","type":"function"},{"doc":"Lists the filters associated with your account.","ref":"AWS.Inspector2.html#list_filters/3","title":"AWS.Inspector2.list_filters/3","type":"function"},{"doc":"Lists aggregated finding data for your environment based on specific criteria.","ref":"AWS.Inspector2.html#list_finding_aggregations/3","title":"AWS.Inspector2.list_finding_aggregations/3","type":"function"},{"doc":"Lists findings for your environment.","ref":"AWS.Inspector2.html#list_findings/3","title":"AWS.Inspector2.list_findings/3","type":"function"},{"doc":"List members associated with the Amazon Inspector delegated administrator for\nyour organization.","ref":"AWS.Inspector2.html#list_members/3","title":"AWS.Inspector2.list_members/3","type":"function"},{"doc":"Lists all tags attached to a given resource.","ref":"AWS.Inspector2.html#list_tags_for_resource/3","title":"AWS.Inspector2.list_tags_for_resource/3","type":"function"},{"doc":"Lists the Amazon Inspector usage totals over the last 30 days.","ref":"AWS.Inspector2.html#list_usage_totals/3","title":"AWS.Inspector2.list_usage_totals/3","type":"function"},{"doc":"","ref":"AWS.Inspector2.html#metadata/0","title":"AWS.Inspector2.metadata/0","type":"function"},{"doc":"Resets an encryption key.\n\nAfter the key is reset your resources will be encrypted by an Amazon Web\nServices owned key.","ref":"AWS.Inspector2.html#reset_encryption_key/3","title":"AWS.Inspector2.reset_encryption_key/3","type":"function"},{"doc":"Lists Amazon Inspector coverage details for a specific vulnerability.","ref":"AWS.Inspector2.html#search_vulnerabilities/3","title":"AWS.Inspector2.search_vulnerabilities/3","type":"function"},{"doc":"Sends a CIS session health.\n\nThis API is used by the Amazon Inspector SSM plugin to communicate with the\nAmazon Inspector service. The Amazon Inspector SSM plugin calls this API to\nstart a CIS scan session for the scan ID supplied by the service.","ref":"AWS.Inspector2.html#send_cis_session_health/3","title":"AWS.Inspector2.send_cis_session_health/3","type":"function"},{"doc":"Sends a CIS session telemetry.\n\nThis API is used by the Amazon Inspector SSM plugin to communicate with the\nAmazon Inspector service. The Amazon Inspector SSM plugin calls this API to\nstart a CIS scan session for the scan ID supplied by the service.","ref":"AWS.Inspector2.html#send_cis_session_telemetry/3","title":"AWS.Inspector2.send_cis_session_telemetry/3","type":"function"},{"doc":"Starts a CIS session.\n\nThis API is used by the Amazon Inspector SSM plugin to communicate with the\nAmazon Inspector service. The Amazon Inspector SSM plugin calls this API to\nstart a CIS scan session for the scan ID supplied by the service.","ref":"AWS.Inspector2.html#start_cis_session/3","title":"AWS.Inspector2.start_cis_session/3","type":"function"},{"doc":"Stops a CIS session.\n\nThis API is used by the Amazon Inspector SSM plugin to communicate with the\nAmazon Inspector service. The Amazon Inspector SSM plugin calls this API to\nstart a CIS scan session for the scan ID supplied by the service.","ref":"AWS.Inspector2.html#stop_cis_session/3","title":"AWS.Inspector2.stop_cis_session/3","type":"function"},{"doc":"Adds tags to a resource.","ref":"AWS.Inspector2.html#tag_resource/4","title":"AWS.Inspector2.tag_resource/4","type":"function"},{"doc":"Removes tags from a resource.","ref":"AWS.Inspector2.html#untag_resource/4","title":"AWS.Inspector2.untag_resource/4","type":"function"},{"doc":"Updates a CIS scan configuration.","ref":"AWS.Inspector2.html#update_cis_scan_configuration/3","title":"AWS.Inspector2.update_cis_scan_configuration/3","type":"function"},{"doc":"Updates setting configurations for your Amazon Inspector account.\n\nWhen you use this API as an Amazon Inspector delegated administrator this\nupdates the setting for all accounts you manage. Member accounts in an\norganization cannot update this setting.","ref":"AWS.Inspector2.html#update_configuration/3","title":"AWS.Inspector2.update_configuration/3","type":"function"},{"doc":"Activates, deactivates Amazon Inspector deep inspection, or updates custom paths\nfor your account.","ref":"AWS.Inspector2.html#update_ec2_deep_inspection_configuration/3","title":"AWS.Inspector2.update_ec2_deep_inspection_configuration/3","type":"function"},{"doc":"Updates an encryption key.\n\nA `ResourceNotFoundException` means that an Amazon Web Services owned key is\nbeing used for encryption.","ref":"AWS.Inspector2.html#update_encryption_key/3","title":"AWS.Inspector2.update_encryption_key/3","type":"function"},{"doc":"Specifies the action that is to be applied to the findings that match the\nfilter.","ref":"AWS.Inspector2.html#update_filter/3","title":"AWS.Inspector2.update_filter/3","type":"function"},{"doc":"Updates the Amazon Inspector deep inspection custom paths for your organization.\n\nYou must be an Amazon Inspector delegated administrator to use this API.","ref":"AWS.Inspector2.html#update_org_ec2_deep_inspection_configuration/3","title":"AWS.Inspector2.update_org_ec2_deep_inspection_configuration/3","type":"function"},{"doc":"Updates the configurations for your Amazon Inspector organization.","ref":"AWS.Inspector2.html#update_organization_configuration/3","title":"AWS.Inspector2.update_organization_configuration/3","type":"function"},{"doc":"Amazon CloudWatch Internet Monitor provides visibility into how internet issues\nimpact the performance and availability between your applications hosted on\nAmazon Web Services and your end users.\n\nIt can reduce the time it takes for you to diagnose internet issues from days to\nminutes. Internet Monitor uses the connectivity data that Amazon Web Services\ncaptures from its global networking footprint to calculate a baseline of\nperformance and availability for internet traffic. This is the same data that\nAmazon Web Services uses to monitor internet uptime and availability. With those\nmeasurements as a baseline, Internet Monitor raises awareness for you when there\nare significant problems for your end users in the different geographic\nlocations where your application runs.\n\nInternet Monitor publishes internet measurements to CloudWatch Logs and\nCloudWatch Metrics, to easily support using CloudWatch tools with health\ninformation for geographies and networks specific to your application. Internet\nMonitor sends health events to Amazon EventBridge so that you can set up\nnotifications. If an issue is caused by the Amazon Web Services network, you\nalso automatically receive an Amazon Web Services Health Dashboard notification\nwith the steps that Amazon Web Services is taking to mitigate the problem.\n\nTo use Internet Monitor, you create a *monitor* and associate your application's\nresources with it - VPCs, NLBs, CloudFront distributions, or WorkSpaces\ndirectories - so Internet Monitor can determine where your application's\ninternet traffic is. Internet Monitor then provides internet measurements from\nAmazon Web Services that are specific to the locations and ASNs (typically,\ninternet service providers or ISPs) that communicate with your application.\n\nFor more information, see [Using Amazon CloudWatch Internet Monitor](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch-InternetMonitor.html)\nin the *Amazon CloudWatch User Guide*.","ref":"AWS.InternetMonitor.html","title":"AWS.InternetMonitor","type":"module"},{"doc":"Creates a monitor in Amazon CloudWatch Internet Monitor.\n\nA monitor is built based on information from the application resources that you\nadd: VPCs, Network Load Balancers (NLBs), Amazon CloudFront distributions, and\nAmazon WorkSpaces directories. Internet Monitor then publishes internet\nmeasurements from Amazon Web Services that are specific to the *city-networks*.\nThat is, the locations and ASNs (typically internet service providers or ISPs),\nwhere clients access your application. For more information, see [Using Amazon CloudWatch Internet\nMonitor](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch-InternetMonitor.html)\nin the *Amazon CloudWatch User Guide*.\n\nWhen you create a monitor, you choose the percentage of traffic that you want to\nmonitor. You can also set a maximum limit for the number of city-networks where\nclient traffic is monitored, that caps the total traffic that Internet Monitor\nmonitors. A city-network maximum is the limit of city-networks, but you only pay\nfor the number of city-networks that are actually monitored. You can update your\nmonitor at any time to change the percentage of traffic to monitor or the\ncity-networks maximum. For more information, see [Choosing a city-network maximum\nvalue](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/IMCityNetworksMaximum.html)\nin the *Amazon CloudWatch User Guide*.","ref":"AWS.InternetMonitor.html#create_monitor/3","title":"AWS.InternetMonitor.create_monitor/3","type":"function"},{"doc":"Deletes a monitor in Amazon CloudWatch Internet Monitor.","ref":"AWS.InternetMonitor.html#delete_monitor/4","title":"AWS.InternetMonitor.delete_monitor/4","type":"function"},{"doc":"Gets information the Amazon CloudWatch Internet Monitor has created and stored\nabout a health event for a specified monitor.\n\nThis information includes the impacted locations, and all the information\nrelated to the event, by location.\n\nThe information returned includes the impact on performance, availability, and\nround-trip time, information about the network providers (ASNs), the event type,\nand so on.\n\nInformation rolled up at the global traffic level is also returned, including\nthe impact type and total traffic impact.","ref":"AWS.InternetMonitor.html#get_health_event/4","title":"AWS.InternetMonitor.get_health_event/4","type":"function"},{"doc":"Gets information about a monitor in Amazon CloudWatch Internet Monitor based on\na monitor name.\n\nThe information returned includes the Amazon Resource Name (ARN), create time,\nmodified time, resources included in the monitor, and status information.","ref":"AWS.InternetMonitor.html#get_monitor/3","title":"AWS.InternetMonitor.get_monitor/3","type":"function"},{"doc":"Return the data for a query with the Amazon CloudWatch Internet Monitor query\ninterface.\n\nSpecify the query that you want to return results for by providing a `QueryId`\nand a monitor name.\n\nFor more information about using the query interface, including examples, see\n[Using the Amazon CloudWatch Internet Monitor query interface](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch-IM-view-cw-tools-cwim-query.html)\nin the Amazon CloudWatch Internet Monitor User Guide.","ref":"AWS.InternetMonitor.html#get_query_results/6","title":"AWS.InternetMonitor.get_query_results/6","type":"function"},{"doc":"Returns the current status of a query for the Amazon CloudWatch Internet Monitor\nquery interface, for a specified query ID and monitor.\n\nWhen you run a query, check the status to make sure that the query has\n`SUCCEEDED` before you review the results.\n\n  * `QUEUED`: The query is scheduled to run.\n\n  * `RUNNING`: The query is in progress but not complete.\n\n  * `SUCCEEDED`: The query completed sucessfully.\n\n  * `FAILED`: The query failed due to an error.\n\n  * `CANCELED`: The query was canceled.","ref":"AWS.InternetMonitor.html#get_query_status/4","title":"AWS.InternetMonitor.get_query_status/4","type":"function"},{"doc":"Lists all health events for a monitor in Amazon CloudWatch Internet Monitor.\n\nReturns information for health events including the event start and end time and\nthe status.\n\nHealth events that have start times during the time frame that is requested are\nnot included in the list of health events.","ref":"AWS.InternetMonitor.html#list_health_events/8","title":"AWS.InternetMonitor.list_health_events/8","type":"function"},{"doc":"Lists all of your monitors for Amazon CloudWatch Internet Monitor and their\nstatuses, along with the Amazon Resource Name (ARN) and name of each monitor.","ref":"AWS.InternetMonitor.html#list_monitors/5","title":"AWS.InternetMonitor.list_monitors/5","type":"function"},{"doc":"Lists the tags for a resource.\n\nTags are supported only for monitors in Amazon CloudWatch Internet Monitor.","ref":"AWS.InternetMonitor.html#list_tags_for_resource/3","title":"AWS.InternetMonitor.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.InternetMonitor.html#metadata/0","title":"AWS.InternetMonitor.metadata/0","type":"function"},{"doc":"Start a query to return data for a specific query type for the Amazon CloudWatch\nInternet Monitor query interface.\n\nSpecify a time period for the data that you want returned by using `StartTime`\nand `EndTime`. You filter the query results to return by providing parameters\nthat you specify with `FilterParameters`.\n\nFor more information about using the query interface, including examples, see\n[Using the Amazon CloudWatch Internet Monitor query interface](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch-IM-view-cw-tools-cwim-query.html)\nin the Amazon CloudWatch Internet Monitor User Guide.","ref":"AWS.InternetMonitor.html#start_query/4","title":"AWS.InternetMonitor.start_query/4","type":"function"},{"doc":"Stop a query that is progress for a specific monitor.","ref":"AWS.InternetMonitor.html#stop_query/5","title":"AWS.InternetMonitor.stop_query/5","type":"function"},{"doc":"Adds a tag to a resource.\n\nTags are supported only for monitors in Amazon CloudWatch Internet Monitor. You\ncan add a maximum of 50 tags in Internet Monitor.\n\nA minimum of one tag is required for this call. It returns an error if you use\nthe `TagResource` request with 0 tags.","ref":"AWS.InternetMonitor.html#tag_resource/4","title":"AWS.InternetMonitor.tag_resource/4","type":"function"},{"doc":"Removes a tag from a resource.","ref":"AWS.InternetMonitor.html#untag_resource/4","title":"AWS.InternetMonitor.untag_resource/4","type":"function"},{"doc":"Updates a monitor.\n\nYou can update a monitor to change the percentage of traffic to monitor or the\nmaximum number of city-networks (locations and ASNs), to add or remove\nresources, or to change the status of the monitor. Note that you can't change\nthe name of a monitor.\n\nThe city-network maximum that you choose is the limit, but you only pay for the\nnumber of city-networks that are actually monitored. For more information, see\n[Choosing a city-network maximum value](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/IMCityNetworksMaximum.html)\nin the *Amazon CloudWatch User Guide*.","ref":"AWS.InternetMonitor.html#update_monitor/4","title":"AWS.InternetMonitor.update_monitor/4","type":"function"},{"doc":"IoT\n\nIoT provides secure, bi-directional communication between Internet-connected\ndevices (such as sensors, actuators, embedded devices, or smart appliances) and\nthe Amazon Web Services cloud.\n\nYou can discover your custom IoT-Data endpoint to communicate with, configure\nrules for data processing and integration with other services, organize\nresources associated with each device (Registry), configure logging, and create\nand manage policies and credentials to authenticate devices.\n\nThe service endpoints that expose this API are listed in [Amazon Web Services IoT Core Endpoints and\nQuotas](https://docs.aws.amazon.com/general/latest/gr/iot-core.html). You must\nuse the endpoint for the region that has the resources you want to access.\n\nThe service name used by [Amazon Web Services Signature Version 4](https://docs.aws.amazon.com/general/latest/gr/signature-version-4.html) to\nsign the request is: *execute-api*.\n\nFor more information about how IoT works, see the [Developer Guide](https://docs.aws.amazon.com/iot/latest/developerguide/aws-iot-how-it-works.html).\n\nFor information about how to use the credentials provider for IoT, see\n[Authorizing Direct Calls to Amazon Web Services Services](https://docs.aws.amazon.com/iot/latest/developerguide/authorizing-direct-aws.html).","ref":"AWS.IoT.html","title":"AWS.IoT","type":"module"},{"doc":"Accepts a pending certificate transfer.\n\nThe default state of the certificate is INACTIVE.\n\nTo check for pending certificate transfers, call `ListCertificates` to enumerate\nyour certificates.\n\nRequires permission to access the\n[AcceptCertificateTransfer](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#accept_certificate_transfer/4","title":"AWS.IoT.accept_certificate_transfer/4","type":"function"},{"doc":"Adds a thing to a billing group.\n\nRequires permission to access the\n[AddThingToBillingGroup](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#add_thing_to_billing_group/3","title":"AWS.IoT.add_thing_to_billing_group/3","type":"function"},{"doc":"Adds a thing to a thing group.\n\nRequires permission to access the\n[AddThingToThingGroup](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#add_thing_to_thing_group/3","title":"AWS.IoT.add_thing_to_thing_group/3","type":"function"},{"doc":"Associates a group with a continuous job.\n\nThe following criteria must be met:\n\n  * The job must have been created with the `targetSelection` field\nset to \"CONTINUOUS\".\n\n  * The job status must currently be \"IN_PROGRESS\".\n\n  * The total number of targets associated with a job must not exceed\n100.\n\nRequires permission to access the\n[AssociateTargetsWithJob](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#associate_targets_with_job/4","title":"AWS.IoT.associate_targets_with_job/4","type":"function"},{"doc":"Attaches the specified policy to the specified principal (certificate or other\ncredential).\n\nRequires permission to access the\n[AttachPolicy](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#attach_policy/4","title":"AWS.IoT.attach_policy/4","type":"function"},{"doc":"Attaches the specified policy to the specified principal (certificate or other\ncredential).\n\n**Note:** This action is deprecated and works as expected for backward\ncompatibility, but we won't add enhancements. Use `AttachPolicy` instead.\n\nRequires permission to access the\n[AttachPrincipalPolicy](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#attach_principal_policy/4","title":"AWS.IoT.attach_principal_policy/4","type":"function"},{"doc":"Associates a Device Defender security profile with a thing group or this\naccount.\n\nEach thing group or account can have up to five security profiles associated\nwith it.\n\nRequires permission to access the\n[AttachSecurityProfile](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#attach_security_profile/4","title":"AWS.IoT.attach_security_profile/4","type":"function"},{"doc":"Attaches the specified principal to the specified thing.\n\nA principal can be X.509 certificates, Amazon Cognito identities or federated\nidentities.\n\nRequires permission to access the\n[AttachThingPrincipal](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#attach_thing_principal/4","title":"AWS.IoT.attach_thing_principal/4","type":"function"},{"doc":"Cancels a mitigation action task that is in progress.\n\nIf the task is not in progress, an InvalidRequestException occurs.\n\nRequires permission to access the\n[CancelAuditMitigationActionsTask](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#cancel_audit_mitigation_actions_task/4","title":"AWS.IoT.cancel_audit_mitigation_actions_task/4","type":"function"},{"doc":"Cancels an audit that is in progress.\n\nThe audit can be either scheduled or on demand. If the audit isn't in progress,\nan \"InvalidRequestException\" occurs.\n\nRequires permission to access the\n[CancelAuditTask](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#cancel_audit_task/4","title":"AWS.IoT.cancel_audit_task/4","type":"function"},{"doc":"Cancels a pending transfer for the specified certificate.\n\n**Note** Only the transfer source account can use this operation to cancel a\ntransfer. (Transfer destinations can use `RejectCertificateTransfer` instead.)\nAfter transfer, IoT returns the certificate to the source account in the\nINACTIVE state. After the destination account has accepted the transfer, the\ntransfer cannot be cancelled.\n\nAfter a certificate transfer is cancelled, the status of the certificate changes\nfrom PENDING_TRANSFER to INACTIVE.\n\nRequires permission to access the\n[CancelCertificateTransfer](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#cancel_certificate_transfer/4","title":"AWS.IoT.cancel_certificate_transfer/4","type":"function"},{"doc":"Cancels a Device Defender ML Detect mitigation action.\n\nRequires permission to access the\n[CancelDetectMitigationActionsTask](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#cancel_detect_mitigation_actions_task/4","title":"AWS.IoT.cancel_detect_mitigation_actions_task/4","type":"function"},{"doc":"Cancels a job.\n\nRequires permission to access the\n[CancelJob](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#cancel_job/4","title":"AWS.IoT.cancel_job/4","type":"function"},{"doc":"Cancels the execution of a job for a given thing.\n\nRequires permission to access the\n[CancelJobExecution](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#cancel_job_execution/5","title":"AWS.IoT.cancel_job_execution/5","type":"function"},{"doc":"Clears the default authorizer.\n\nRequires permission to access the\n[ClearDefaultAuthorizer](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#clear_default_authorizer/3","title":"AWS.IoT.clear_default_authorizer/3","type":"function"},{"doc":"Confirms a topic rule destination.\n\nWhen you create a rule requiring a destination, IoT sends a confirmation message\nto the endpoint or base address you specify. The message includes a token which\nyou pass back when calling `ConfirmTopicRuleDestination` to confirm that you own\nor have access to the endpoint.\n\nRequires permission to access the\n[ConfirmTopicRuleDestination](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#confirm_topic_rule_destination/3","title":"AWS.IoT.confirm_topic_rule_destination/3","type":"function"},{"doc":"Creates a Device Defender audit suppression.\n\nRequires permission to access the\n[CreateAuditSuppression](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#create_audit_suppression/3","title":"AWS.IoT.create_audit_suppression/3","type":"function"},{"doc":"Creates an authorizer.\n\nRequires permission to access the\n[CreateAuthorizer](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#create_authorizer/4","title":"AWS.IoT.create_authorizer/4","type":"function"},{"doc":"Creates a billing group.\n\nRequires permission to access the\n[CreateBillingGroup](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#create_billing_group/4","title":"AWS.IoT.create_billing_group/4","type":"function"},{"doc":"Creates an X.509 certificate using the specified certificate signing request.\n\nRequires permission to access the\n[CreateCertificateFromCsr](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions) action.\n\nThe CSR must include a public key that is either an RSA key with a length of at\nleast 2048 bits or an ECC key from NIST P-256, NIST P-384, or NIST P-521 curves.\nFor supported certificates, consult [ Certificate signing algorithms supported\nby\nIoT](https://docs.aws.amazon.com/iot/latest/developerguide/x509-client-certs.html#x509-cert-algorithms).\n\nReusing the same certificate signing request (CSR) results in a distinct\ncertificate.\n\nYou can create multiple certificates in a batch by creating a directory, copying\nmultiple `.csr` files into that directory, and then specifying that directory on\nthe command line. The following commands show how to create a batch of\ncertificates given a batch of CSRs. In the following commands, we assume that a\nset of CSRs are located inside of the directory my-csr-directory:\n\nOn Linux and OS X, the command is:\n\n`$ ls my-csr-directory/ | xargs -I {} aws iot create-certificate-from-csr\n--certificate-signing-request file://my-csr-directory/{}`\n\nThis command lists all of the CSRs in my-csr-directory and pipes each CSR file\nname to the `aws iot create-certificate-from-csr` Amazon Web Services CLI\ncommand to create a certificate for the corresponding CSR.\n\nYou can also run the `aws iot create-certificate-from-csr` part of the command\nin parallel to speed up the certificate creation process:\n\n`$ ls my-csr-directory/ | xargs -P 10 -I {} aws iot create-certificate-from-csr\n--certificate-signing-request file://my-csr-directory/{} `\n\nOn Windows PowerShell, the command to create certificates for all CSRs in\nmy-csr-directory is:\n\n`> ls -Name my-csr-directory | %{aws iot create-certificate-from-csr\n--certificate-signing-request file://my-csr-directory/$_} `\n\nOn a Windows command prompt, the command to create certificates for all CSRs in\nmy-csr-directory is:\n\n`> forfiles /p my-csr-directory /c \"cmd /c aws iot create-certificate-from-csr\n--certificate-signing-request file://@path\" `","ref":"AWS.IoT.html#create_certificate_from_csr/3","title":"AWS.IoT.create_certificate_from_csr/3","type":"function"},{"doc":"Creates an Amazon Web Services IoT Core certificate provider.\n\nYou can use Amazon Web Services IoT Core certificate provider to customize how\nto sign a certificate signing request (CSR) in IoT fleet provisioning. For more\ninformation, see [Customizing certificate signing using Amazon Web Services IoT Core certificate\nprovider](https://docs.aws.amazon.com/iot/latest/developerguide/provisioning-cert-provider.html)\nfrom *Amazon Web Services IoT Core Developer Guide*.\n\nRequires permission to access the\n[CreateCertificateProvider](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions) action.\n\nAfter you create a certificate provider, the behavior of [\n`CreateCertificateFromCsr` API for fleet\nprovisioning](https://docs.aws.amazon.com/iot/latest/developerguide/fleet-provision-api.html#create-cert-csr)\nwill change and all API calls to `CreateCertificateFromCsr` will invoke the\ncertificate provider to create the certificates. It can take up to a few minutes\nfor this behavior to change after a certificate provider is created.","ref":"AWS.IoT.html#create_certificate_provider/4","title":"AWS.IoT.create_certificate_provider/4","type":"function"},{"doc":"Use this API to define a Custom Metric published by your devices to Device\nDefender.\n\nRequires permission to access the\n[CreateCustomMetric](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#create_custom_metric/4","title":"AWS.IoT.create_custom_metric/4","type":"function"},{"doc":"Create a dimension that you can use to limit the scope of a metric used in a\nsecurity profile for IoT Device Defender.\n\nFor example, using a `TOPIC_FILTER` dimension, you can narrow down the scope of\nthe metric only to MQTT topics whose name match the pattern specified in the\ndimension.\n\nRequires permission to access the\n[CreateDimension](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#create_dimension/4","title":"AWS.IoT.create_dimension/4","type":"function"},{"doc":"Creates a domain configuration.\n\nRequires permission to access the\n[CreateDomainConfiguration](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#create_domain_configuration/4","title":"AWS.IoT.create_domain_configuration/4","type":"function"},{"doc":"Creates a dynamic thing group.\n\nRequires permission to access the\n[CreateDynamicThingGroup](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#create_dynamic_thing_group/4","title":"AWS.IoT.create_dynamic_thing_group/4","type":"function"},{"doc":"Creates a fleet metric.\n\nRequires permission to access the\n[CreateFleetMetric](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#create_fleet_metric/4","title":"AWS.IoT.create_fleet_metric/4","type":"function"},{"doc":"Creates a job.\n\nRequires permission to access the\n[CreateJob](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#create_job/4","title":"AWS.IoT.create_job/4","type":"function"},{"doc":"Creates a job template.\n\nRequires permission to access the\n[CreateJobTemplate](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#create_job_template/4","title":"AWS.IoT.create_job_template/4","type":"function"},{"doc":"Creates a 2048-bit RSA key pair and issues an X.509 certificate using the issued\npublic key.\n\nYou can also call `CreateKeysAndCertificate` over MQTT from a device, for more\ninformation, see [Provisioning MQTT API](https://docs.aws.amazon.com/iot/latest/developerguide/provision-wo-cert.html#provision-mqtt-api).\n\n**Note** This is the only time IoT issues the private key for this certificate,\nso it is important to keep it in a secure location.\n\nRequires permission to access the\n[CreateKeysAndCertificate](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#create_keys_and_certificate/3","title":"AWS.IoT.create_keys_and_certificate/3","type":"function"},{"doc":"Defines an action that can be applied to audit findings by using\nStartAuditMitigationActionsTask.\n\nOnly certain types of mitigation actions can be applied to specific check names.\nFor more information, see [Mitigation actions](https://docs.aws.amazon.com/iot/latest/developerguide/device-defender-mitigation-actions.html).\nEach mitigation action can apply only one type of change.\n\nRequires permission to access the\n[CreateMitigationAction](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#create_mitigation_action/4","title":"AWS.IoT.create_mitigation_action/4","type":"function"},{"doc":"Creates an IoT OTA update on a target group of things or groups.\n\nRequires permission to access the\n[CreateOTAUpdate](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#create_ota_update/4","title":"AWS.IoT.create_ota_update/4","type":"function"},{"doc":"Creates an IoT software package that can be deployed to your fleet.\n\nRequires permission to access the\n[CreatePackage](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions) and\n[GetIndexingConfiguration](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\nactions.","ref":"AWS.IoT.html#create_package/4","title":"AWS.IoT.create_package/4","type":"function"},{"doc":"Creates a new version for an existing IoT software package.\n\nRequires permission to access the\n[CreatePackageVersion](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions) and\n[GetIndexingConfiguration](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\nactions.","ref":"AWS.IoT.html#create_package_version/5","title":"AWS.IoT.create_package_version/5","type":"function"},{"doc":"Creates an IoT policy.\n\nThe created policy is the default version for the policy. This operation creates\na policy version with a version identifier of **1** and sets **1** as the\npolicy's default version.\n\nRequires permission to access the\n[CreatePolicy](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#create_policy/4","title":"AWS.IoT.create_policy/4","type":"function"},{"doc":"Creates a new version of the specified IoT policy.\n\nTo update a policy, create a new policy version. A managed policy can have up to\nfive versions. If the policy has five versions, you must use\n`DeletePolicyVersion` to delete an existing version before you create a new one.\n\nOptionally, you can set the new version as the policy's default version. The\ndefault version is the operative version (that is, the version that is in effect\nfor the certificates to which the policy is attached).\n\nRequires permission to access the\n[CreatePolicyVersion](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#create_policy_version/4","title":"AWS.IoT.create_policy_version/4","type":"function"},{"doc":"Creates a provisioning claim.\n\nRequires permission to access the\n[CreateProvisioningClaim](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#create_provisioning_claim/4","title":"AWS.IoT.create_provisioning_claim/4","type":"function"},{"doc":"Creates a provisioning template.\n\nRequires permission to access the\n[CreateProvisioningTemplate](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#create_provisioning_template/3","title":"AWS.IoT.create_provisioning_template/3","type":"function"},{"doc":"Creates a new version of a provisioning template.\n\nRequires permission to access the\n[CreateProvisioningTemplateVersion](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#create_provisioning_template_version/4","title":"AWS.IoT.create_provisioning_template_version/4","type":"function"},{"doc":"Creates a role alias.\n\nRequires permission to access the\n[CreateRoleAlias](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#create_role_alias/4","title":"AWS.IoT.create_role_alias/4","type":"function"},{"doc":"Creates a scheduled audit that is run at a specified time interval.\n\nRequires permission to access the\n[CreateScheduledAudit](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#create_scheduled_audit/4","title":"AWS.IoT.create_scheduled_audit/4","type":"function"},{"doc":"Creates a Device Defender security profile.\n\nRequires permission to access the\n[CreateSecurityProfile](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#create_security_profile/4","title":"AWS.IoT.create_security_profile/4","type":"function"},{"doc":"Creates a stream for delivering one or more large files in chunks over MQTT.\n\nA stream transports data bytes in chunks or blocks packaged as MQTT messages\nfrom a source like S3. You can have one or more files associated with a stream.\n\nRequires permission to access the\n[CreateStream](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#create_stream/4","title":"AWS.IoT.create_stream/4","type":"function"},{"doc":"Creates a thing record in the registry.\n\nIf this call is made multiple times using the same thing name and configuration,\nthe call will succeed. If this call is made with the same thing name but\ndifferent configuration a `ResourceAlreadyExistsException` is thrown.\n\nThis is a control plane operation. See\n[Authorization](https://docs.aws.amazon.com/iot/latest/developerguide/iot-authorization.html) for information about authorizing control plane actions.\n\nRequires permission to access the\n[CreateThing](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#create_thing/4","title":"AWS.IoT.create_thing/4","type":"function"},{"doc":"Create a thing group.\n\nThis is a control plane operation. See\n[Authorization](https://docs.aws.amazon.com/iot/latest/developerguide/iot-authorization.html) for information about authorizing control plane actions.\n\nIf the `ThingGroup` that you create has the exact same attributes as an existing\n`ThingGroup`, you will get a 200 success response.\n\nRequires permission to access the\n[CreateThingGroup](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#create_thing_group/4","title":"AWS.IoT.create_thing_group/4","type":"function"},{"doc":"Creates a new thing type.\n\nRequires permission to access the\n[CreateThingType](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#create_thing_type/4","title":"AWS.IoT.create_thing_type/4","type":"function"},{"doc":"Creates a rule.\n\nCreating rules is an administrator-level action. Any user who has permission to\ncreate rules will be able to access data processed by the rule.\n\nRequires permission to access the\n[CreateTopicRule](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#create_topic_rule/4","title":"AWS.IoT.create_topic_rule/4","type":"function"},{"doc":"Creates a topic rule destination.\n\nThe destination must be confirmed prior to use.\n\nRequires permission to access the\n[CreateTopicRuleDestination](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#create_topic_rule_destination/3","title":"AWS.IoT.create_topic_rule_destination/3","type":"function"},{"doc":"Restores the default settings for Device Defender audits for this account.\n\nAny configuration data you entered is deleted and all audit checks are reset to\ndisabled.\n\nRequires permission to access the\n[DeleteAccountAuditConfiguration](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#delete_account_audit_configuration/3","title":"AWS.IoT.delete_account_audit_configuration/3","type":"function"},{"doc":"Deletes a Device Defender audit suppression.\n\nRequires permission to access the\n[DeleteAuditSuppression](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#delete_audit_suppression/3","title":"AWS.IoT.delete_audit_suppression/3","type":"function"},{"doc":"Deletes an authorizer.\n\nRequires permission to access the\n[DeleteAuthorizer](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#delete_authorizer/4","title":"AWS.IoT.delete_authorizer/4","type":"function"},{"doc":"Deletes the billing group.\n\nRequires permission to access the\n[DeleteBillingGroup](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#delete_billing_group/4","title":"AWS.IoT.delete_billing_group/4","type":"function"},{"doc":"Deletes a registered CA certificate.\n\nRequires permission to access the\n[DeleteCACertificate](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#delete_ca_certificate/4","title":"AWS.IoT.delete_ca_certificate/4","type":"function"},{"doc":"Deletes the specified certificate.\n\nA certificate cannot be deleted if it has a policy or IoT thing attached to it\nor if its status is set to ACTIVE. To delete a certificate, first use the\n`DetachPolicy` action to detach all policies. Next, use the `UpdateCertificate`\naction to set the certificate to the INACTIVE status.\n\nRequires permission to access the\n[DeleteCertificate](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#delete_certificate/4","title":"AWS.IoT.delete_certificate/4","type":"function"},{"doc":"Deletes a certificate provider.\n\nRequires permission to access the\n[DeleteCertificateProvider](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.\n\nIf you delete the certificate provider resource, the behavior of\n`CreateCertificateFromCsr` will resume, and IoT will create certificates signed\nby IoT from a certificate signing request (CSR).","ref":"AWS.IoT.html#delete_certificate_provider/4","title":"AWS.IoT.delete_certificate_provider/4","type":"function"},{"doc":"Deletes a Device Defender detect custom metric.\n\nRequires permission to access the\n[DeleteCustomMetric](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions) action.\n\nBefore you can delete a custom metric, you must first remove the custom metric\nfrom all security profiles it's a part of. The security profile associated with\nthe custom metric can be found using the\n[ListSecurityProfiles](https://docs.aws.amazon.com/iot/latest/apireference/API_ListSecurityProfiles.html)\nAPI with `metricName` set to your custom metric name.","ref":"AWS.IoT.html#delete_custom_metric/4","title":"AWS.IoT.delete_custom_metric/4","type":"function"},{"doc":"Removes the specified dimension from your Amazon Web Services accounts.\n\nRequires permission to access the\n[DeleteDimension](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#delete_dimension/4","title":"AWS.IoT.delete_dimension/4","type":"function"},{"doc":"Deletes the specified domain configuration.\n\nRequires permission to access the\n[DeleteDomainConfiguration](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#delete_domain_configuration/4","title":"AWS.IoT.delete_domain_configuration/4","type":"function"},{"doc":"Deletes a dynamic thing group.\n\nRequires permission to access the\n[DeleteDynamicThingGroup](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#delete_dynamic_thing_group/4","title":"AWS.IoT.delete_dynamic_thing_group/4","type":"function"},{"doc":"Deletes the specified fleet metric.\n\nReturns successfully with no error if the deletion is successful or you specify\na fleet metric that doesn't exist.\n\nRequires permission to access the\n[DeleteFleetMetric](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#delete_fleet_metric/4","title":"AWS.IoT.delete_fleet_metric/4","type":"function"},{"doc":"Deletes a job and its related job executions.\n\nDeleting a job may take time, depending on the number of job executions created\nfor the job and various other factors. While the job is being deleted, the\nstatus of the job will be shown as \"DELETION_IN_PROGRESS\". Attempting to delete\nor cancel a job whose status is already \"DELETION_IN_PROGRESS\" will result in an\nerror.\n\nOnly 10 jobs may have status \"DELETION_IN_PROGRESS\" at the same time, or a\nLimitExceededException will occur.\n\nRequires permission to access the\n[DeleteJob](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#delete_job/4","title":"AWS.IoT.delete_job/4","type":"function"},{"doc":"Deletes a job execution.\n\nRequires permission to access the\n[DeleteJobExecution](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#delete_job_execution/6","title":"AWS.IoT.delete_job_execution/6","type":"function"},{"doc":"Deletes the specified job template.","ref":"AWS.IoT.html#delete_job_template/4","title":"AWS.IoT.delete_job_template/4","type":"function"},{"doc":"Deletes a defined mitigation action from your Amazon Web Services accounts.\n\nRequires permission to access the\n[DeleteMitigationAction](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#delete_mitigation_action/4","title":"AWS.IoT.delete_mitigation_action/4","type":"function"},{"doc":"Delete an OTA update.\n\nRequires permission to access the\n[DeleteOTAUpdate](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#delete_ota_update/4","title":"AWS.IoT.delete_ota_update/4","type":"function"},{"doc":"Deletes a specific version from a software package.\n\n**Note:** All package versions must be deleted before deleting the software\npackage.\n\nRequires permission to access the\n[DeletePackageVersion](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#delete_package/4","title":"AWS.IoT.delete_package/4","type":"function"},{"doc":"Deletes a specific version from a software package.\n\n**Note:** If a package version is designated as default, you must remove the\ndesignation from the software package using the `UpdatePackage` action.","ref":"AWS.IoT.html#delete_package_version/5","title":"AWS.IoT.delete_package_version/5","type":"function"},{"doc":"Deletes the specified policy.\n\nA policy cannot be deleted if it has non-default versions or it is attached to\nany certificate.\n\nTo delete a policy, use the `DeletePolicyVersion` action to delete all\nnon-default versions of the policy; use the `DetachPolicy` action to detach the\npolicy from any certificate; and then use the DeletePolicy action to delete the\npolicy.\n\nWhen a policy is deleted using DeletePolicy, its default version is deleted with\nit.\n\nBecause of the distributed nature of Amazon Web Services, it can take up to five\nminutes after a policy is detached before it's ready to be deleted.\n\nRequires permission to access the\n[DeletePolicy](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#delete_policy/4","title":"AWS.IoT.delete_policy/4","type":"function"},{"doc":"Deletes the specified version of the specified policy.\n\nYou cannot delete the default version of a policy using this action. To delete\nthe default version of a policy, use `DeletePolicy`. To find out which version\nof a policy is marked as the default version, use ListPolicyVersions.\n\nRequires permission to access the\n[DeletePolicyVersion](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#delete_policy_version/5","title":"AWS.IoT.delete_policy_version/5","type":"function"},{"doc":"Deletes a provisioning template.\n\nRequires permission to access the\n[DeleteProvisioningTemplate](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#delete_provisioning_template/4","title":"AWS.IoT.delete_provisioning_template/4","type":"function"},{"doc":"Deletes a provisioning template version.\n\nRequires permission to access the\n[DeleteProvisioningTemplateVersion](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#delete_provisioning_template_version/5","title":"AWS.IoT.delete_provisioning_template_version/5","type":"function"},{"doc":"Deletes a CA certificate registration code.\n\nRequires permission to access the\n[DeleteRegistrationCode](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#delete_registration_code/3","title":"AWS.IoT.delete_registration_code/3","type":"function"},{"doc":"Deletes a role alias\n\nRequires permission to access the\n[DeleteRoleAlias](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#delete_role_alias/4","title":"AWS.IoT.delete_role_alias/4","type":"function"},{"doc":"Deletes a scheduled audit.\n\nRequires permission to access the\n[DeleteScheduledAudit](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#delete_scheduled_audit/4","title":"AWS.IoT.delete_scheduled_audit/4","type":"function"},{"doc":"Deletes a Device Defender security profile.\n\nRequires permission to access the\n[DeleteSecurityProfile](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#delete_security_profile/4","title":"AWS.IoT.delete_security_profile/4","type":"function"},{"doc":"Deletes a stream.\n\nRequires permission to access the\n[DeleteStream](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#delete_stream/4","title":"AWS.IoT.delete_stream/4","type":"function"},{"doc":"Deletes the specified thing.\n\nReturns successfully with no error if the deletion is successful or you specify\na thing that doesn't exist.\n\nRequires permission to access the\n[DeleteThing](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#delete_thing/4","title":"AWS.IoT.delete_thing/4","type":"function"},{"doc":"Deletes a thing group.\n\nRequires permission to access the\n[DeleteThingGroup](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#delete_thing_group/4","title":"AWS.IoT.delete_thing_group/4","type":"function"},{"doc":"Deletes the specified thing type.\n\nYou cannot delete a thing type if it has things associated with it. To delete a\nthing type, first mark it as deprecated by calling `DeprecateThingType`, then\nremove any associated things by calling `UpdateThing` to change the thing type\non any associated thing, and finally use `DeleteThingType` to delete the thing\ntype.\n\nRequires permission to access the\n[DeleteThingType](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#delete_thing_type/4","title":"AWS.IoT.delete_thing_type/4","type":"function"},{"doc":"Deletes the rule.\n\nRequires permission to access the\n[DeleteTopicRule](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#delete_topic_rule/4","title":"AWS.IoT.delete_topic_rule/4","type":"function"},{"doc":"Deletes a topic rule destination.\n\nRequires permission to access the\n[DeleteTopicRuleDestination](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#delete_topic_rule_destination/4","title":"AWS.IoT.delete_topic_rule_destination/4","type":"function"},{"doc":"Deletes a logging level.\n\nRequires permission to access the\n[DeleteV2LoggingLevel](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#delete_v2_logging_level/3","title":"AWS.IoT.delete_v2_logging_level/3","type":"function"},{"doc":"Deprecates a thing type.\n\nYou can not associate new things with deprecated thing type.\n\nRequires permission to access the\n[DeprecateThingType](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#deprecate_thing_type/4","title":"AWS.IoT.deprecate_thing_type/4","type":"function"},{"doc":"Gets information about the Device Defender audit settings for this account.\n\nSettings include how audit notifications are sent and which audit checks are\nenabled or disabled.\n\nRequires permission to access the\n[DescribeAccountAuditConfiguration](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#describe_account_audit_configuration/2","title":"AWS.IoT.describe_account_audit_configuration/2","type":"function"},{"doc":"Gets information about a single audit finding.\n\nProperties include the reason for noncompliance, the severity of the issue, and\nthe start time when the audit that returned the finding.\n\nRequires permission to access the\n[DescribeAuditFinding](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#describe_audit_finding/3","title":"AWS.IoT.describe_audit_finding/3","type":"function"},{"doc":"Gets information about an audit mitigation task that is used to apply mitigation\nactions to a set of audit findings.\n\nProperties include the actions being applied, the audit checks to which they're\nbeing applied, the task status, and aggregated task statistics.","ref":"AWS.IoT.html#describe_audit_mitigation_actions_task/3","title":"AWS.IoT.describe_audit_mitigation_actions_task/3","type":"function"},{"doc":"Gets information about a Device Defender audit suppression.","ref":"AWS.IoT.html#describe_audit_suppression/3","title":"AWS.IoT.describe_audit_suppression/3","type":"function"},{"doc":"Gets information about a Device Defender audit.\n\nRequires permission to access the\n[DescribeAuditTask](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#describe_audit_task/3","title":"AWS.IoT.describe_audit_task/3","type":"function"},{"doc":"Describes an authorizer.\n\nRequires permission to access the\n[DescribeAuthorizer](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#describe_authorizer/3","title":"AWS.IoT.describe_authorizer/3","type":"function"},{"doc":"Returns information about a billing group.\n\nRequires permission to access the\n[DescribeBillingGroup](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#describe_billing_group/3","title":"AWS.IoT.describe_billing_group/3","type":"function"},{"doc":"Describes a registered CA certificate.\n\nRequires permission to access the\n[DescribeCACertificate](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#describe_ca_certificate/3","title":"AWS.IoT.describe_ca_certificate/3","type":"function"},{"doc":"Gets information about the specified certificate.\n\nRequires permission to access the\n[DescribeCertificate](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#describe_certificate/3","title":"AWS.IoT.describe_certificate/3","type":"function"},{"doc":"Describes a certificate provider.\n\nRequires permission to access the\n[DescribeCertificateProvider](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#describe_certificate_provider/3","title":"AWS.IoT.describe_certificate_provider/3","type":"function"},{"doc":"Gets information about a Device Defender detect custom metric.\n\nRequires permission to access the\n[DescribeCustomMetric](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#describe_custom_metric/3","title":"AWS.IoT.describe_custom_metric/3","type":"function"},{"doc":"Describes the default authorizer.\n\nRequires permission to access the\n[DescribeDefaultAuthorizer](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#describe_default_authorizer/2","title":"AWS.IoT.describe_default_authorizer/2","type":"function"},{"doc":"Gets information about a Device Defender ML Detect mitigation action.\n\nRequires permission to access the\n[DescribeDetectMitigationActionsTask](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#describe_detect_mitigation_actions_task/3","title":"AWS.IoT.describe_detect_mitigation_actions_task/3","type":"function"},{"doc":"Provides details about a dimension that is defined in your Amazon Web Services\naccounts.\n\nRequires permission to access the\n[DescribeDimension](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#describe_dimension/3","title":"AWS.IoT.describe_dimension/3","type":"function"},{"doc":"Gets summary information about a domain configuration.\n\nRequires permission to access the\n[DescribeDomainConfiguration](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#describe_domain_configuration/3","title":"AWS.IoT.describe_domain_configuration/3","type":"function"},{"doc":"Returns or creates a unique endpoint specific to the Amazon Web Services account\nmaking the call.\n\nThe first time `DescribeEndpoint` is called, an endpoint is created. All\nsubsequent calls to `DescribeEndpoint` return the same endpoint.\n\nRequires permission to access the\n[DescribeEndpoint](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#describe_endpoint/3","title":"AWS.IoT.describe_endpoint/3","type":"function"},{"doc":"Describes event configurations.\n\nRequires permission to access the\n[DescribeEventConfigurations](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#describe_event_configurations/2","title":"AWS.IoT.describe_event_configurations/2","type":"function"},{"doc":"Gets information about the specified fleet metric.\n\nRequires permission to access the\n[DescribeFleetMetric](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#describe_fleet_metric/3","title":"AWS.IoT.describe_fleet_metric/3","type":"function"},{"doc":"Describes a search index.\n\nRequires permission to access the\n[DescribeIndex](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#describe_index/3","title":"AWS.IoT.describe_index/3","type":"function"},{"doc":"Describes a job.\n\nRequires permission to access the\n[DescribeJob](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#describe_job/3","title":"AWS.IoT.describe_job/3","type":"function"},{"doc":"Describes a job execution.\n\nRequires permission to access the\n[DescribeJobExecution](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#describe_job_execution/5","title":"AWS.IoT.describe_job_execution/5","type":"function"},{"doc":"Returns information about a job template.","ref":"AWS.IoT.html#describe_job_template/3","title":"AWS.IoT.describe_job_template/3","type":"function"},{"doc":"View details of a managed job template.","ref":"AWS.IoT.html#describe_managed_job_template/4","title":"AWS.IoT.describe_managed_job_template/4","type":"function"},{"doc":"Gets information about a mitigation action.\n\nRequires permission to access the\n[DescribeMitigationAction](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#describe_mitigation_action/3","title":"AWS.IoT.describe_mitigation_action/3","type":"function"},{"doc":"Returns information about a provisioning template.\n\nRequires permission to access the\n[DescribeProvisioningTemplate](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#describe_provisioning_template/3","title":"AWS.IoT.describe_provisioning_template/3","type":"function"},{"doc":"Returns information about a provisioning template version.\n\nRequires permission to access the\n[DescribeProvisioningTemplateVersion](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#describe_provisioning_template_version/4","title":"AWS.IoT.describe_provisioning_template_version/4","type":"function"},{"doc":"Describes a role alias.\n\nRequires permission to access the\n[DescribeRoleAlias](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#describe_role_alias/3","title":"AWS.IoT.describe_role_alias/3","type":"function"},{"doc":"Gets information about a scheduled audit.\n\nRequires permission to access the\n[DescribeScheduledAudit](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#describe_scheduled_audit/3","title":"AWS.IoT.describe_scheduled_audit/3","type":"function"},{"doc":"Gets information about a Device Defender security profile.\n\nRequires permission to access the\n[DescribeSecurityProfile](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#describe_security_profile/3","title":"AWS.IoT.describe_security_profile/3","type":"function"},{"doc":"Gets information about a stream.\n\nRequires permission to access the\n[DescribeStream](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#describe_stream/3","title":"AWS.IoT.describe_stream/3","type":"function"},{"doc":"Gets information about the specified thing.\n\nRequires permission to access the\n[DescribeThing](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#describe_thing/3","title":"AWS.IoT.describe_thing/3","type":"function"},{"doc":"Describe a thing group.\n\nRequires permission to access the\n[DescribeThingGroup](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#describe_thing_group/3","title":"AWS.IoT.describe_thing_group/3","type":"function"},{"doc":"Describes a bulk thing provisioning task.\n\nRequires permission to access the\n[DescribeThingRegistrationTask](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#describe_thing_registration_task/3","title":"AWS.IoT.describe_thing_registration_task/3","type":"function"},{"doc":"Gets information about the specified thing type.\n\nRequires permission to access the\n[DescribeThingType](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#describe_thing_type/3","title":"AWS.IoT.describe_thing_type/3","type":"function"},{"doc":"Detaches a policy from the specified target.\n\nBecause of the distributed nature of Amazon Web Services, it can take up to five\nminutes after a policy is detached before it's ready to be deleted.\n\nRequires permission to access the\n[DetachPolicy](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#detach_policy/4","title":"AWS.IoT.detach_policy/4","type":"function"},{"doc":"Removes the specified policy from the specified certificate.\n\n**Note:** This action is deprecated and works as expected for backward\ncompatibility, but we won't add enhancements. Use `DetachPolicy` instead.\n\nRequires permission to access the\n[DetachPrincipalPolicy](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#detach_principal_policy/4","title":"AWS.IoT.detach_principal_policy/4","type":"function"},{"doc":"Disassociates a Device Defender security profile from a thing group or from this\naccount.\n\nRequires permission to access the\n[DetachSecurityProfile](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#detach_security_profile/4","title":"AWS.IoT.detach_security_profile/4","type":"function"},{"doc":"Detaches the specified principal from the specified thing.\n\nA principal can be X.509 certificates, IAM users, groups, and roles, Amazon\nCognito identities or federated identities.\n\nThis call is asynchronous. It might take several seconds for the detachment to\npropagate.\n\nRequires permission to access the\n[DetachThingPrincipal](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#detach_thing_principal/4","title":"AWS.IoT.detach_thing_principal/4","type":"function"},{"doc":"Disables the rule.\n\nRequires permission to access the\n[DisableTopicRule](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#disable_topic_rule/4","title":"AWS.IoT.disable_topic_rule/4","type":"function"},{"doc":"Enables the rule.\n\nRequires permission to access the\n[EnableTopicRule](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#enable_topic_rule/4","title":"AWS.IoT.enable_topic_rule/4","type":"function"},{"doc":"Returns a Device Defender's ML Detect Security Profile training model's status.\n\nRequires permission to access the\n[GetBehaviorModelTrainingSummaries](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#get_behavior_model_training_summaries/5","title":"AWS.IoT.get_behavior_model_training_summaries/5","type":"function"},{"doc":"Aggregates on indexed data with search queries pertaining to particular fields.\n\nRequires permission to access the\n[GetBucketsAggregation](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#get_buckets_aggregation/3","title":"AWS.IoT.get_buckets_aggregation/3","type":"function"},{"doc":"Returns the approximate count of unique values that match the query.\n\nRequires permission to access the\n[GetCardinality](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#get_cardinality/3","title":"AWS.IoT.get_cardinality/3","type":"function"},{"doc":"Gets a list of the policies that have an effect on the authorization behavior of\nthe specified device when it connects to the IoT device gateway.\n\nRequires permission to access the\n[GetEffectivePolicies](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#get_effective_policies/3","title":"AWS.IoT.get_effective_policies/3","type":"function"},{"doc":"Gets the indexing configuration.\n\nRequires permission to access the\n[GetIndexingConfiguration](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#get_indexing_configuration/2","title":"AWS.IoT.get_indexing_configuration/2","type":"function"},{"doc":"Gets a job document.\n\nRequires permission to access the\n[GetJobDocument](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#get_job_document/3","title":"AWS.IoT.get_job_document/3","type":"function"},{"doc":"Gets the logging options.\n\nNOTE: use of this command is not recommended. Use `GetV2LoggingOptions` instead.\n\nRequires permission to access the\n[GetLoggingOptions](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#get_logging_options/2","title":"AWS.IoT.get_logging_options/2","type":"function"},{"doc":"Gets an OTA update.\n\nRequires permission to access the\n[GetOTAUpdate](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#get_ota_update/3","title":"AWS.IoT.get_ota_update/3","type":"function"},{"doc":"Gets information about the specified software package.\n\nRequires permission to access the\n[GetPackage](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#get_package/3","title":"AWS.IoT.get_package/3","type":"function"},{"doc":"Gets information about the specified software package's configuration.\n\nRequires permission to access the\n[GetPackageConfiguration](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#get_package_configuration/2","title":"AWS.IoT.get_package_configuration/2","type":"function"},{"doc":"Gets information about the specified package version.\n\nRequires permission to access the\n[GetPackageVersion](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#get_package_version/4","title":"AWS.IoT.get_package_version/4","type":"function"},{"doc":"Groups the aggregated values that match the query into percentile groupings.\n\nThe default percentile groupings are: 1,5,25,50,75,95,99, although you can\nspecify your own when you call `GetPercentiles`. This function returns a value\nfor each percentile group specified (or the default percentile groupings). The\npercentile group \"1\" contains the aggregated field value that occurs in\napproximately one percent of the values that match the query. The percentile\ngroup \"5\" contains the aggregated field value that occurs in approximately five\npercent of the values that match the query, and so on. The result is an\napproximation, the more values that match the query, the more accurate the\npercentile values.\n\nRequires permission to access the\n[GetPercentiles](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#get_percentiles/3","title":"AWS.IoT.get_percentiles/3","type":"function"},{"doc":"Gets information about the specified policy with the policy document of the\ndefault version.\n\nRequires permission to access the\n[GetPolicy](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#get_policy/3","title":"AWS.IoT.get_policy/3","type":"function"},{"doc":"Gets information about the specified policy version.\n\nRequires permission to access the\n[GetPolicyVersion](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#get_policy_version/4","title":"AWS.IoT.get_policy_version/4","type":"function"},{"doc":"Gets a registration code used to register a CA certificate with IoT.\n\nIoT will create a registration code as part of this API call if the registration\ncode doesn't exist or has been deleted. If you already have a registration code,\nthis API call will return the same registration code.\n\nRequires permission to access the\n[GetRegistrationCode](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#get_registration_code/2","title":"AWS.IoT.get_registration_code/2","type":"function"},{"doc":"Returns the count, average, sum, minimum, maximum, sum of squares, variance, and\nstandard deviation for the specified aggregated field.\n\nIf the aggregation field is of type `String`, only the count statistic is\nreturned.\n\nRequires permission to access the\n[GetStatistics](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#get_statistics/3","title":"AWS.IoT.get_statistics/3","type":"function"},{"doc":"Gets information about the rule.\n\nRequires permission to access the\n[GetTopicRule](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#get_topic_rule/3","title":"AWS.IoT.get_topic_rule/3","type":"function"},{"doc":"Gets information about a topic rule destination.\n\nRequires permission to access the\n[GetTopicRuleDestination](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#get_topic_rule_destination/3","title":"AWS.IoT.get_topic_rule_destination/3","type":"function"},{"doc":"Gets the fine grained logging options.\n\nRequires permission to access the\n[GetV2LoggingOptions](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#get_v2_logging_options/2","title":"AWS.IoT.get_v2_logging_options/2","type":"function"},{"doc":"Lists the active violations for a given Device Defender security profile.\n\nRequires permission to access the\n[ListActiveViolations](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_active_violations/9","title":"AWS.IoT.list_active_violations/9","type":"function"},{"doc":"Lists the policies attached to the specified thing group.\n\nRequires permission to access the\n[ListAttachedPolicies](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_attached_policies/4","title":"AWS.IoT.list_attached_policies/4","type":"function"},{"doc":"Lists the findings (results) of a Device Defender audit or of the audits\nperformed during a specified time period.\n\n(Findings are retained for 90 days.)\n\nRequires permission to access the\n[ListAuditFindings](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_audit_findings/3","title":"AWS.IoT.list_audit_findings/3","type":"function"},{"doc":"Gets the status of audit mitigation action tasks that were executed.\n\nRequires permission to access the\n[ListAuditMitigationActionsExecutions](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_audit_mitigation_actions_executions/7","title":"AWS.IoT.list_audit_mitigation_actions_executions/7","type":"function"},{"doc":"Gets a list of audit mitigation action tasks that match the specified filters.\n\nRequires permission to access the\n[ListAuditMitigationActionsTasks](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_audit_mitigation_actions_tasks/9","title":"AWS.IoT.list_audit_mitigation_actions_tasks/9","type":"function"},{"doc":"Lists your Device Defender audit listings.\n\nRequires permission to access the\n[ListAuditSuppressions](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_audit_suppressions/3","title":"AWS.IoT.list_audit_suppressions/3","type":"function"},{"doc":"Lists the Device Defender audits that have been performed during a given time\nperiod.\n\nRequires permission to access the\n[ListAuditTasks](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_audit_tasks/8","title":"AWS.IoT.list_audit_tasks/8","type":"function"},{"doc":"Lists the authorizers registered in your account.\n\nRequires permission to access the\n[ListAuthorizers](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_authorizers/6","title":"AWS.IoT.list_authorizers/6","type":"function"},{"doc":"Lists the billing groups you have created.\n\nRequires permission to access the\n[ListBillingGroups](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_billing_groups/5","title":"AWS.IoT.list_billing_groups/5","type":"function"},{"doc":"Lists the CA certificates registered for your Amazon Web Services account.\n\nThe results are paginated with a default page size of 25. You can use the\nreturned marker to retrieve additional results.\n\nRequires permission to access the\n[ListCACertificates](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_ca_certificates/6","title":"AWS.IoT.list_ca_certificates/6","type":"function"},{"doc":"Lists all your certificate providers in your Amazon Web Services account.\n\nRequires permission to access the\n[ListCertificateProviders](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_certificate_providers/4","title":"AWS.IoT.list_certificate_providers/4","type":"function"},{"doc":"Lists the certificates registered in your Amazon Web Services account.\n\nThe results are paginated with a default page size of 25. You can use the\nreturned marker to retrieve additional results.\n\nRequires permission to access the\n[ListCertificates](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_certificates/5","title":"AWS.IoT.list_certificates/5","type":"function"},{"doc":"List the device certificates signed by the specified CA certificate.\n\nRequires permission to access the\n[ListCertificatesByCA](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_certificates_by_ca/6","title":"AWS.IoT.list_certificates_by_ca/6","type":"function"},{"doc":"Lists your Device Defender detect custom metrics.\n\nRequires permission to access the\n[ListCustomMetrics](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_custom_metrics/4","title":"AWS.IoT.list_custom_metrics/4","type":"function"},{"doc":"Lists mitigation actions executions for a Device Defender ML Detect Security\nProfile.\n\nRequires permission to access the\n[ListDetectMitigationActionsExecutions](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_detect_mitigation_actions_executions/9","title":"AWS.IoT.list_detect_mitigation_actions_executions/9","type":"function"},{"doc":"List of Device Defender ML Detect mitigation actions tasks.\n\nRequires permission to access the\n[ListDetectMitigationActionsTasks](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_detect_mitigation_actions_tasks/6","title":"AWS.IoT.list_detect_mitigation_actions_tasks/6","type":"function"},{"doc":"List the set of dimensions that are defined for your Amazon Web Services\naccounts.\n\nRequires permission to access the\n[ListDimensions](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_dimensions/4","title":"AWS.IoT.list_dimensions/4","type":"function"},{"doc":"Gets a list of domain configurations for the user.\n\nThis list is sorted alphabetically by domain configuration name.\n\nRequires permission to access the\n[ListDomainConfigurations](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_domain_configurations/5","title":"AWS.IoT.list_domain_configurations/5","type":"function"},{"doc":"Lists all your fleet metrics.\n\nRequires permission to access the\n[ListFleetMetrics](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_fleet_metrics/4","title":"AWS.IoT.list_fleet_metrics/4","type":"function"},{"doc":"Lists the search indices.\n\nRequires permission to access the\n[ListIndices](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_indices/4","title":"AWS.IoT.list_indices/4","type":"function"},{"doc":"Lists the job executions for a job.\n\nRequires permission to access the\n[ListJobExecutionsForJob](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_job_executions_for_job/6","title":"AWS.IoT.list_job_executions_for_job/6","type":"function"},{"doc":"Lists the job executions for the specified thing.\n\nRequires permission to access the\n[ListJobExecutionsForThing](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_job_executions_for_thing/8","title":"AWS.IoT.list_job_executions_for_thing/8","type":"function"},{"doc":"Returns a list of job templates.\n\nRequires permission to access the\n[ListJobTemplates](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_job_templates/4","title":"AWS.IoT.list_job_templates/4","type":"function"},{"doc":"Lists jobs.\n\nRequires permission to access the\n[ListJobs](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_jobs/9","title":"AWS.IoT.list_jobs/9","type":"function"},{"doc":"Returns a list of managed job templates.","ref":"AWS.IoT.html#list_managed_job_templates/5","title":"AWS.IoT.list_managed_job_templates/5","type":"function"},{"doc":"Lists the values reported for an IoT Device Defender metric (device-side metric,\ncloud-side metric, or custom metric) by the given thing during the specified\ntime period.","ref":"AWS.IoT.html#list_metric_values/10","title":"AWS.IoT.list_metric_values/10","type":"function"},{"doc":"Gets a list of all mitigation actions that match the specified filter criteria.\n\nRequires permission to access the\n[ListMitigationActions](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_mitigation_actions/5","title":"AWS.IoT.list_mitigation_actions/5","type":"function"},{"doc":"Lists OTA updates.\n\nRequires permission to access the\n[ListOTAUpdates](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_ota_updates/5","title":"AWS.IoT.list_ota_updates/5","type":"function"},{"doc":"Lists certificates that are being transferred but not yet accepted.\n\nRequires permission to access the\n[ListOutgoingCertificates](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_outgoing_certificates/5","title":"AWS.IoT.list_outgoing_certificates/5","type":"function"},{"doc":"Lists the software package versions associated to the account.\n\nRequires permission to access the\n[ListPackageVersions](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_package_versions/6","title":"AWS.IoT.list_package_versions/6","type":"function"},{"doc":"Lists the software packages associated to the account.\n\nRequires permission to access the\n[ListPackages](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_packages/4","title":"AWS.IoT.list_packages/4","type":"function"},{"doc":"Lists your policies.\n\nRequires permission to access the\n[ListPolicies](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_policies/5","title":"AWS.IoT.list_policies/5","type":"function"},{"doc":"Lists the principals associated with the specified policy.\n\n**Note:** This action is deprecated and works as expected for backward\ncompatibility, but we won't add enhancements. Use `ListTargetsForPolicy`\ninstead.\n\nRequires permission to access the\n[ListPolicyPrincipals](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_policy_principals/6","title":"AWS.IoT.list_policy_principals/6","type":"function"},{"doc":"Lists the versions of the specified policy and identifies the default version.\n\nRequires permission to access the\n[ListPolicyVersions](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_policy_versions/3","title":"AWS.IoT.list_policy_versions/3","type":"function"},{"doc":"Lists the policies attached to the specified principal.\n\nIf you use an Cognito identity, the ID must be in [AmazonCognito Identity format](https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_GetCredentialsForIdentity.html#API_GetCredentialsForIdentity_RequestSyntax).\n\n**Note:** This action is deprecated and works as expected for backward\ncompatibility, but we won't add enhancements. Use `ListAttachedPolicies`\ninstead.\n\nRequires permission to access the\n[ListPrincipalPolicies](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_principal_policies/6","title":"AWS.IoT.list_principal_policies/6","type":"function"},{"doc":"Lists the things associated with the specified principal.\n\nA principal can be X.509 certificates, IAM users, groups, and roles, Amazon\nCognito identities or federated identities.\n\nRequires permission to access the\n[ListPrincipalThings](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_principal_things/5","title":"AWS.IoT.list_principal_things/5","type":"function"},{"doc":"A list of provisioning template versions.\n\nRequires permission to access the\n[ListProvisioningTemplateVersions](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_provisioning_template_versions/5","title":"AWS.IoT.list_provisioning_template_versions/5","type":"function"},{"doc":"Lists the provisioning templates in your Amazon Web Services account.\n\nRequires permission to access the\n[ListProvisioningTemplates](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_provisioning_templates/4","title":"AWS.IoT.list_provisioning_templates/4","type":"function"},{"doc":"The related resources of an Audit finding.\n\nThe following resources can be returned from calling this API:\n\n  * DEVICE_CERTIFICATE\n\n  * CA_CERTIFICATE\n\n  * IOT_POLICY\n\n  * COGNITO_IDENTITY_POOL\n\n  * CLIENT_ID\n\n  * ACCOUNT_SETTINGS\n\n  * ROLE_ALIAS\n\n  * IAM_ROLE\n\n  * ISSUER_CERTIFICATE\n\nThis API is similar to DescribeAuditFinding's\n[RelatedResources](https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeAuditFinding.html) but provides pagination and is not limited to 10 resources. When calling\n[DescribeAuditFinding](https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeAuditFinding.html)\nfor the intermediate CA revoked for active device certificates check,\nRelatedResources will not be populated. You must use this API,\nListRelatedResourcesForAuditFinding, to list the certificates.","ref":"AWS.IoT.html#list_related_resources_for_audit_finding/5","title":"AWS.IoT.list_related_resources_for_audit_finding/5","type":"function"},{"doc":"Lists the role aliases registered in your account.\n\nRequires permission to access the\n[ListRoleAliases](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_role_aliases/5","title":"AWS.IoT.list_role_aliases/5","type":"function"},{"doc":"Lists all of your scheduled audits.\n\nRequires permission to access the\n[ListScheduledAudits](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_scheduled_audits/4","title":"AWS.IoT.list_scheduled_audits/4","type":"function"},{"doc":"Lists the Device Defender security profiles you've created.\n\nYou can filter security profiles by dimension or custom metric.\n\nRequires permission to access the\n[ListSecurityProfiles](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.\n\n`dimensionName` and `metricName` cannot be used in the same request.","ref":"AWS.IoT.html#list_security_profiles/6","title":"AWS.IoT.list_security_profiles/6","type":"function"},{"doc":"Lists the Device Defender security profiles attached to a target (thing group).\n\nRequires permission to access the\n[ListSecurityProfilesForTarget](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_security_profiles_for_target/6","title":"AWS.IoT.list_security_profiles_for_target/6","type":"function"},{"doc":"Lists all of the streams in your Amazon Web Services account.\n\nRequires permission to access the\n[ListStreams](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_streams/5","title":"AWS.IoT.list_streams/5","type":"function"},{"doc":"Lists the tags (metadata) you have assigned to the resource.\n\nRequires permission to access the\n[ListTagsForResource](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_tags_for_resource/4","title":"AWS.IoT.list_tags_for_resource/4","type":"function"},{"doc":"List targets for the specified policy.\n\nRequires permission to access the\n[ListTargetsForPolicy](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_targets_for_policy/4","title":"AWS.IoT.list_targets_for_policy/4","type":"function"},{"doc":"Lists the targets (thing groups) associated with a given Device Defender\nsecurity profile.\n\nRequires permission to access the\n[ListTargetsForSecurityProfile](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_targets_for_security_profile/5","title":"AWS.IoT.list_targets_for_security_profile/5","type":"function"},{"doc":"List the thing groups in your account.\n\nRequires permission to access the\n[ListThingGroups](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_thing_groups/7","title":"AWS.IoT.list_thing_groups/7","type":"function"},{"doc":"List the thing groups to which the specified thing belongs.\n\nRequires permission to access the\n[ListThingGroupsForThing](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_thing_groups_for_thing/5","title":"AWS.IoT.list_thing_groups_for_thing/5","type":"function"},{"doc":"Lists the principals associated with the specified thing.\n\nA principal can be X.509 certificates, IAM users, groups, and roles, Amazon\nCognito identities or federated identities.\n\nRequires permission to access the\n[ListThingPrincipals](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_thing_principals/5","title":"AWS.IoT.list_thing_principals/5","type":"function"},{"doc":"Information about the thing registration tasks.","ref":"AWS.IoT.html#list_thing_registration_task_reports/6","title":"AWS.IoT.list_thing_registration_task_reports/6","type":"function"},{"doc":"List bulk thing provisioning tasks.\n\nRequires permission to access the\n[ListThingRegistrationTasks](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_thing_registration_tasks/5","title":"AWS.IoT.list_thing_registration_tasks/5","type":"function"},{"doc":"Lists the existing thing types.\n\nRequires permission to access the\n[ListThingTypes](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_thing_types/5","title":"AWS.IoT.list_thing_types/5","type":"function"},{"doc":"Lists your things.\n\nUse the **attributeName** and **attributeValue** parameters to filter your\nthings. For example, calling `ListThings` with attributeName=Color and\nattributeValue=Red retrieves all things in the registry that contain an\nattribute **Color** with the value **Red**. For more information, see [List Things](https://docs.aws.amazon.com/iot/latest/developerguide/thing-registry.html#list-things)\nfrom the *Amazon Web Services IoT Core Developer Guide*.\n\nRequires permission to access the\n[ListThings](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.\n\nYou will not be charged for calling this API if an `Access denied` error is\nreturned. You will also not be charged if no attributes or pagination token was\nprovided in request and no pagination token and no results were returned.","ref":"AWS.IoT.html#list_things/8","title":"AWS.IoT.list_things/8","type":"function"},{"doc":"Lists the things you have added to the given billing group.\n\nRequires permission to access the\n[ListThingsInBillingGroup](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_things_in_billing_group/5","title":"AWS.IoT.list_things_in_billing_group/5","type":"function"},{"doc":"Lists the things in the specified group.\n\nRequires permission to access the\n[ListThingsInThingGroup](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_things_in_thing_group/6","title":"AWS.IoT.list_things_in_thing_group/6","type":"function"},{"doc":"Lists all the topic rule destinations in your Amazon Web Services account.\n\nRequires permission to access the\n[ListTopicRuleDestinations](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_topic_rule_destinations/4","title":"AWS.IoT.list_topic_rule_destinations/4","type":"function"},{"doc":"Lists the rules for the specific topic.\n\nRequires permission to access the\n[ListTopicRules](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_topic_rules/6","title":"AWS.IoT.list_topic_rules/6","type":"function"},{"doc":"Lists logging levels.\n\nRequires permission to access the\n[ListV2LoggingLevels](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_v2_logging_levels/5","title":"AWS.IoT.list_v2_logging_levels/5","type":"function"},{"doc":"Lists the Device Defender security profile violations discovered during the\ngiven time period.\n\nYou can use filters to limit the results to those alerts issued for a particular\nsecurity profile, behavior, or thing (device).\n\nRequires permission to access the\n[ListViolationEvents](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#list_violation_events/11","title":"AWS.IoT.list_violation_events/11","type":"function"},{"doc":"","ref":"AWS.IoT.html#metadata/0","title":"AWS.IoT.metadata/0","type":"function"},{"doc":"Set a verification state and provide a description of that verification state on\na violation (detect alarm).","ref":"AWS.IoT.html#put_verification_state_on_violation/4","title":"AWS.IoT.put_verification_state_on_violation/4","type":"function"},{"doc":"Registers a CA certificate with Amazon Web Services IoT Core.\n\nThere is no limit to the number of CA certificates you can register in your\nAmazon Web Services account. You can register up to 10 CA certificates with the\nsame `CA subject field` per Amazon Web Services account.\n\nRequires permission to access the\n[RegisterCACertificate](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#register_ca_certificate/3","title":"AWS.IoT.register_ca_certificate/3","type":"function"},{"doc":"Registers a device certificate with IoT in the same [certificate mode](https://docs.aws.amazon.com/iot/latest/apireference/API_CertificateDescription.html#iot-Type-CertificateDescription-certificateMode)\nas the signing CA.\n\nIf you have more than one CA certificate that has the same subject field, you\nmust specify the CA certificate that was used to sign the device certificate\nbeing registered.\n\nRequires permission to access the\n[RegisterCertificate](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#register_certificate/3","title":"AWS.IoT.register_certificate/3","type":"function"},{"doc":"Register a certificate that does not have a certificate authority (CA).\n\nFor supported certificates, consult [ Certificate signing algorithms supported by\nIoT](https://docs.aws.amazon.com/iot/latest/developerguide/x509-client-certs.html#x509-cert-algorithms).","ref":"AWS.IoT.html#register_certificate_without_ca/3","title":"AWS.IoT.register_certificate_without_ca/3","type":"function"},{"doc":"Provisions a thing in the device registry.\n\nRegisterThing calls other IoT control plane APIs. These calls might exceed your\naccount level [ IoT Throttling Limits](https://docs.aws.amazon.com/general/latest/gr/aws_service_limits.html#limits_iot)\nand cause throttle errors. Please contact [Amazon Web Services Customer Support](https://console.aws.amazon.com/support/home) to raise your throttling\nlimits if necessary.\n\nRequires permission to access the\n[RegisterThing](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#register_thing/3","title":"AWS.IoT.register_thing/3","type":"function"},{"doc":"Rejects a pending certificate transfer.\n\nAfter IoT rejects a certificate transfer, the certificate status changes from\n**PENDING_TRANSFER** to **INACTIVE**.\n\nTo check for pending certificate transfers, call `ListCertificates` to enumerate\nyour certificates.\n\nThis operation can only be called by the transfer destination. After it is\ncalled, the certificate will be returned to the source's account in the INACTIVE\nstate.\n\nRequires permission to access the\n[RejectCertificateTransfer](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#reject_certificate_transfer/4","title":"AWS.IoT.reject_certificate_transfer/4","type":"function"},{"doc":"Removes the given thing from the billing group.\n\nRequires permission to access the\n[RemoveThingFromBillingGroup](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.\n\nThis call is asynchronous. It might take several seconds for the detachment to\npropagate.","ref":"AWS.IoT.html#remove_thing_from_billing_group/3","title":"AWS.IoT.remove_thing_from_billing_group/3","type":"function"},{"doc":"Remove the specified thing from the specified group.\n\nYou must specify either a `thingGroupArn` or a `thingGroupName` to identify the\nthing group and either a `thingArn` or a `thingName` to identify the thing to\nremove from the thing group.\n\nRequires permission to access the\n[RemoveThingFromThingGroup](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#remove_thing_from_thing_group/3","title":"AWS.IoT.remove_thing_from_thing_group/3","type":"function"},{"doc":"Replaces the rule.\n\nYou must specify all parameters for the new rule. Creating rules is an\nadministrator-level action. Any user who has permission to create rules will be\nable to access data processed by the rule.\n\nRequires permission to access the\n[ReplaceTopicRule](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#replace_topic_rule/4","title":"AWS.IoT.replace_topic_rule/4","type":"function"},{"doc":"The query search index.\n\nRequires permission to access the\n[SearchIndex](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#search_index/3","title":"AWS.IoT.search_index/3","type":"function"},{"doc":"Sets the default authorizer.\n\nThis will be used if a websocket connection is made without specifying an\nauthorizer.\n\nRequires permission to access the\n[SetDefaultAuthorizer](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#set_default_authorizer/3","title":"AWS.IoT.set_default_authorizer/3","type":"function"},{"doc":"Sets the specified version of the specified policy as the policy's default\n(operative) version.\n\nThis action affects all certificates to which the policy is attached. To list\nthe principals the policy is attached to, use the `ListPrincipalPolicies`\naction.\n\nRequires permission to access the\n[SetDefaultPolicyVersion](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#set_default_policy_version/5","title":"AWS.IoT.set_default_policy_version/5","type":"function"},{"doc":"Sets the logging options.\n\nNOTE: use of this command is not recommended. Use `SetV2LoggingOptions` instead.\n\nRequires permission to access the\n[SetLoggingOptions](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#set_logging_options/3","title":"AWS.IoT.set_logging_options/3","type":"function"},{"doc":"Sets the logging level.\n\nRequires permission to access the\n[SetV2LoggingLevel](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#set_v2_logging_level/3","title":"AWS.IoT.set_v2_logging_level/3","type":"function"},{"doc":"Sets the logging options for the V2 logging service.\n\nRequires permission to access the\n[SetV2LoggingOptions](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#set_v2_logging_options/3","title":"AWS.IoT.set_v2_logging_options/3","type":"function"},{"doc":"Starts a task that applies a set of mitigation actions to the specified target.\n\nRequires permission to access the\n[StartAuditMitigationActionsTask](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#start_audit_mitigation_actions_task/4","title":"AWS.IoT.start_audit_mitigation_actions_task/4","type":"function"},{"doc":"Starts a Device Defender ML Detect mitigation actions task.\n\nRequires permission to access the\n[StartDetectMitigationActionsTask](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#start_detect_mitigation_actions_task/4","title":"AWS.IoT.start_detect_mitigation_actions_task/4","type":"function"},{"doc":"Starts an on-demand Device Defender audit.\n\nRequires permission to access the\n[StartOnDemandAuditTask](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#start_on_demand_audit_task/3","title":"AWS.IoT.start_on_demand_audit_task/3","type":"function"},{"doc":"Creates a bulk thing provisioning task.\n\nRequires permission to access the\n[StartThingRegistrationTask](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#start_thing_registration_task/3","title":"AWS.IoT.start_thing_registration_task/3","type":"function"},{"doc":"Cancels a bulk thing provisioning task.\n\nRequires permission to access the\n[StopThingRegistrationTask](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#stop_thing_registration_task/4","title":"AWS.IoT.stop_thing_registration_task/4","type":"function"},{"doc":"Adds to or modifies the tags of the given resource.\n\nTags are metadata which can be used to manage a resource.\n\nRequires permission to access the\n[TagResource](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#tag_resource/3","title":"AWS.IoT.tag_resource/3","type":"function"},{"doc":"Tests if a specified principal is authorized to perform an IoT action on a\nspecified resource.\n\nUse this to test and debug the authorization behavior of devices that connect to\nthe IoT device gateway.\n\nRequires permission to access the\n[TestAuthorization](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#test_authorization/3","title":"AWS.IoT.test_authorization/3","type":"function"},{"doc":"Tests a custom authorization behavior by invoking a specified custom authorizer.\n\nUse this to test and debug the custom authorization behavior of devices that\nconnect to the IoT device gateway.\n\nRequires permission to access the\n[TestInvokeAuthorizer](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#test_invoke_authorizer/4","title":"AWS.IoT.test_invoke_authorizer/4","type":"function"},{"doc":"Transfers the specified certificate to the specified Amazon Web Services\naccount.\n\nRequires permission to access the\n[TransferCertificate](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.\n\nYou can cancel the transfer until it is acknowledged by the recipient.\n\nNo notification is sent to the transfer destination's account. It is up to the\ncaller to notify the transfer target.\n\nThe certificate being transferred must not be in the ACTIVE state. You can use\nthe `UpdateCertificate` action to deactivate it.\n\nThe certificate must not have any policies attached to it. You can use the\n`DetachPolicy` action to detach them.","ref":"AWS.IoT.html#transfer_certificate/4","title":"AWS.IoT.transfer_certificate/4","type":"function"},{"doc":"Removes the given tags (metadata) from the resource.\n\nRequires permission to access the\n[UntagResource](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#untag_resource/3","title":"AWS.IoT.untag_resource/3","type":"function"},{"doc":"Configures or reconfigures the Device Defender audit settings for this account.\n\nSettings include how audit notifications are sent and which audit checks are\nenabled or disabled.\n\nRequires permission to access the\n[UpdateAccountAuditConfiguration](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#update_account_audit_configuration/3","title":"AWS.IoT.update_account_audit_configuration/3","type":"function"},{"doc":"Updates a Device Defender audit suppression.","ref":"AWS.IoT.html#update_audit_suppression/3","title":"AWS.IoT.update_audit_suppression/3","type":"function"},{"doc":"Updates an authorizer.\n\nRequires permission to access the\n[UpdateAuthorizer](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#update_authorizer/4","title":"AWS.IoT.update_authorizer/4","type":"function"},{"doc":"Updates information about the billing group.\n\nRequires permission to access the\n[UpdateBillingGroup](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#update_billing_group/4","title":"AWS.IoT.update_billing_group/4","type":"function"},{"doc":"Updates a registered CA certificate.\n\nRequires permission to access the\n[UpdateCACertificate](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#update_ca_certificate/4","title":"AWS.IoT.update_ca_certificate/4","type":"function"},{"doc":"Updates the status of the specified certificate.\n\nThis operation is idempotent.\n\nRequires permission to access the\n[UpdateCertificate](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.\n\nCertificates must be in the ACTIVE state to authenticate devices that use a\ncertificate to connect to IoT.\n\nWithin a few minutes of updating a certificate from the ACTIVE state to any\nother state, IoT disconnects all devices that used that certificate to connect.\nDevices cannot use a certificate that is not in the ACTIVE state to reconnect.","ref":"AWS.IoT.html#update_certificate/4","title":"AWS.IoT.update_certificate/4","type":"function"},{"doc":"Updates a certificate provider.\n\nRequires permission to access the\n[UpdateCertificateProvider](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#update_certificate_provider/4","title":"AWS.IoT.update_certificate_provider/4","type":"function"},{"doc":"Updates a Device Defender detect custom metric.\n\nRequires permission to access the\n[UpdateCustomMetric](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#update_custom_metric/4","title":"AWS.IoT.update_custom_metric/4","type":"function"},{"doc":"Updates the definition for a dimension.\n\nYou cannot change the type of a dimension after it is created (you can delete it\nand recreate it).\n\nRequires permission to access the\n[UpdateDimension](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#update_dimension/4","title":"AWS.IoT.update_dimension/4","type":"function"},{"doc":"Updates values stored in the domain configuration.\n\nDomain configurations for default endpoints can't be updated.\n\nRequires permission to access the\n[UpdateDomainConfiguration](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#update_domain_configuration/4","title":"AWS.IoT.update_domain_configuration/4","type":"function"},{"doc":"Updates a dynamic thing group.\n\nRequires permission to access the\n[UpdateDynamicThingGroup](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#update_dynamic_thing_group/4","title":"AWS.IoT.update_dynamic_thing_group/4","type":"function"},{"doc":"Updates the event configurations.\n\nRequires permission to access the\n[UpdateEventConfigurations](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#update_event_configurations/3","title":"AWS.IoT.update_event_configurations/3","type":"function"},{"doc":"Updates the data for a fleet metric.\n\nRequires permission to access the\n[UpdateFleetMetric](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#update_fleet_metric/4","title":"AWS.IoT.update_fleet_metric/4","type":"function"},{"doc":"Updates the search configuration.\n\nRequires permission to access the\n[UpdateIndexingConfiguration](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#update_indexing_configuration/3","title":"AWS.IoT.update_indexing_configuration/3","type":"function"},{"doc":"Updates supported fields of the specified job.\n\nRequires permission to access the\n[UpdateJob](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#update_job/4","title":"AWS.IoT.update_job/4","type":"function"},{"doc":"Updates the definition for the specified mitigation action.\n\nRequires permission to access the\n[UpdateMitigationAction](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#update_mitigation_action/4","title":"AWS.IoT.update_mitigation_action/4","type":"function"},{"doc":"Updates the supported fields for a specific software package.\n\nRequires permission to access the\n[UpdatePackage](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions) and\n[GetIndexingConfiguration](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\nactions.","ref":"AWS.IoT.html#update_package/4","title":"AWS.IoT.update_package/4","type":"function"},{"doc":"Updates the software package configuration.\n\nRequires permission to access the\n[UpdatePackageConfiguration](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions) and\n[iam:PassRole](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_use_passrole.html)\nactions.","ref":"AWS.IoT.html#update_package_configuration/3","title":"AWS.IoT.update_package_configuration/3","type":"function"},{"doc":"Updates the supported fields for a specific package version.\n\nRequires permission to access the\n[UpdatePackageVersion](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions) and\n[GetIndexingConfiguration](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\nactions.","ref":"AWS.IoT.html#update_package_version/5","title":"AWS.IoT.update_package_version/5","type":"function"},{"doc":"Updates a provisioning template.\n\nRequires permission to access the\n[UpdateProvisioningTemplate](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#update_provisioning_template/4","title":"AWS.IoT.update_provisioning_template/4","type":"function"},{"doc":"Updates a role alias.\n\nRequires permission to access the\n[UpdateRoleAlias](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#update_role_alias/4","title":"AWS.IoT.update_role_alias/4","type":"function"},{"doc":"Updates a scheduled audit, including which checks are performed and how often\nthe audit takes place.\n\nRequires permission to access the\n[UpdateScheduledAudit](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#update_scheduled_audit/4","title":"AWS.IoT.update_scheduled_audit/4","type":"function"},{"doc":"Updates a Device Defender security profile.\n\nRequires permission to access the\n[UpdateSecurityProfile](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#update_security_profile/4","title":"AWS.IoT.update_security_profile/4","type":"function"},{"doc":"Updates an existing stream.\n\nThe stream version will be incremented by one.\n\nRequires permission to access the\n[UpdateStream](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#update_stream/4","title":"AWS.IoT.update_stream/4","type":"function"},{"doc":"Updates the data for a thing.\n\nRequires permission to access the\n[UpdateThing](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#update_thing/4","title":"AWS.IoT.update_thing/4","type":"function"},{"doc":"Update a thing group.\n\nRequires permission to access the\n[UpdateThingGroup](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#update_thing_group/4","title":"AWS.IoT.update_thing_group/4","type":"function"},{"doc":"Updates the groups to which the thing belongs.\n\nRequires permission to access the\n[UpdateThingGroupsForThing](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#update_thing_groups_for_thing/3","title":"AWS.IoT.update_thing_groups_for_thing/3","type":"function"},{"doc":"Updates a topic rule destination.\n\nYou use this to change the status, endpoint URL, or confirmation URL of the\ndestination.\n\nRequires permission to access the\n[UpdateTopicRuleDestination](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#update_topic_rule_destination/3","title":"AWS.IoT.update_topic_rule_destination/3","type":"function"},{"doc":"Validates a Device Defender security profile behaviors specification.\n\nRequires permission to access the\n[ValidateSecurityProfileBehaviors](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoT.html#validate_security_profile_behaviors/3","title":"AWS.IoT.validate_security_profile_behaviors/3","type":"function"},{"doc":"Describes all of the AWS IoT 1-Click device-related API operations for the\nservice.\n\nAlso provides sample requests, responses, and errors for the supported web\nservices\nprotocols.","ref":"AWS.IoT1ClickDevices.html","title":"AWS.IoT1ClickDevices","type":"module"},{"doc":"Adds device(s) to your account (i.e., claim one or more devices) if and only if\nyou\nreceived a claim code with the device(s).","ref":"AWS.IoT1ClickDevices.html#claim_devices_by_claim_code/4","title":"AWS.IoT1ClickDevices.claim_devices_by_claim_code/4","type":"function"},{"doc":"Given a device ID, returns a DescribeDeviceResponse object describing the\ndetails of the device.","ref":"AWS.IoT1ClickDevices.html#describe_device/3","title":"AWS.IoT1ClickDevices.describe_device/3","type":"function"},{"doc":"Given a device ID, finalizes the claim request for the associated device.\n\nClaiming a device consists of initiating a claim, then publishing a device\nevent,\nand finalizing the claim. For a device of type button, a device event can\nbe published by simply clicking the device.","ref":"AWS.IoT1ClickDevices.html#finalize_device_claim/4","title":"AWS.IoT1ClickDevices.finalize_device_claim/4","type":"function"},{"doc":"Given a device ID, returns the invokable methods associated with the device.","ref":"AWS.IoT1ClickDevices.html#get_device_methods/3","title":"AWS.IoT1ClickDevices.get_device_methods/3","type":"function"},{"doc":"Given a device ID, initiates a claim request for the associated device.\n\nClaiming a device consists of initiating a claim, then publishing a device\nevent,\nand finalizing the claim. For a device of type button, a device event can\nbe published by simply clicking the device.","ref":"AWS.IoT1ClickDevices.html#initiate_device_claim/4","title":"AWS.IoT1ClickDevices.initiate_device_claim/4","type":"function"},{"doc":"Given a device ID, issues a request to invoke a named device method (with\npossible\nparameters).\n\nSee the \"Example POST\" code snippet below.","ref":"AWS.IoT1ClickDevices.html#invoke_device_method/4","title":"AWS.IoT1ClickDevices.invoke_device_method/4","type":"function"},{"doc":"Using a device ID, returns a DeviceEventsResponse object containing an\narray of events for the device.","ref":"AWS.IoT1ClickDevices.html#list_device_events/7","title":"AWS.IoT1ClickDevices.list_device_events/7","type":"function"},{"doc":"Lists the 1-Click compatible devices associated with your AWS account.","ref":"AWS.IoT1ClickDevices.html#list_devices/5","title":"AWS.IoT1ClickDevices.list_devices/5","type":"function"},{"doc":"Lists the tags associated with the specified resource ARN.","ref":"AWS.IoT1ClickDevices.html#list_tags_for_resource/3","title":"AWS.IoT1ClickDevices.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.IoT1ClickDevices.html#metadata/0","title":"AWS.IoT1ClickDevices.metadata/0","type":"function"},{"doc":"Adds or updates the tags associated with the resource ARN.\n\nSee [AWS IoT 1-Click Service Limits](https://docs.aws.amazon.com/iot-1-click/latest/developerguide/1click-appendix.html#1click-limits)\nfor the maximum number of tags allowed per\nresource.","ref":"AWS.IoT1ClickDevices.html#tag_resource/4","title":"AWS.IoT1ClickDevices.tag_resource/4","type":"function"},{"doc":"Disassociates a device from your AWS account using its device ID.","ref":"AWS.IoT1ClickDevices.html#unclaim_device/4","title":"AWS.IoT1ClickDevices.unclaim_device/4","type":"function"},{"doc":"Using tag keys, deletes the tags (key/value pairs) associated with the specified\nresource ARN.","ref":"AWS.IoT1ClickDevices.html#untag_resource/4","title":"AWS.IoT1ClickDevices.untag_resource/4","type":"function"},{"doc":"Using a Boolean value (true or false), this operation\nenables or disables the device given a device ID.","ref":"AWS.IoT1ClickDevices.html#update_device_state/4","title":"AWS.IoT1ClickDevices.update_device_state/4","type":"function"},{"doc":"The AWS IoT 1-Click Projects API Reference","ref":"AWS.IoT1ClickProjects.html","title":"AWS.IoT1ClickProjects","type":"module"},{"doc":"Associates a physical device with a placement.","ref":"AWS.IoT1ClickProjects.html#associate_device_with_placement/6","title":"AWS.IoT1ClickProjects.associate_device_with_placement/6","type":"function"},{"doc":"Creates an empty placement.","ref":"AWS.IoT1ClickProjects.html#create_placement/4","title":"AWS.IoT1ClickProjects.create_placement/4","type":"function"},{"doc":"Creates an empty project with a placement template.\n\nA project contains zero or more placements that adhere to the placement template\ndefined in the project.","ref":"AWS.IoT1ClickProjects.html#create_project/3","title":"AWS.IoT1ClickProjects.create_project/3","type":"function"},{"doc":"Deletes a placement.\n\nTo delete a placement, it must not have any devices associated with it.\n\nWhen you delete a placement, all associated data becomes irretrievable.","ref":"AWS.IoT1ClickProjects.html#delete_placement/5","title":"AWS.IoT1ClickProjects.delete_placement/5","type":"function"},{"doc":"Deletes a project.\n\nTo delete a project, it must not have any placements associated with it.\n\nWhen you delete a project, all associated data becomes irretrievable.","ref":"AWS.IoT1ClickProjects.html#delete_project/4","title":"AWS.IoT1ClickProjects.delete_project/4","type":"function"},{"doc":"Describes a placement in a project.","ref":"AWS.IoT1ClickProjects.html#describe_placement/4","title":"AWS.IoT1ClickProjects.describe_placement/4","type":"function"},{"doc":"Returns an object describing a project.","ref":"AWS.IoT1ClickProjects.html#describe_project/3","title":"AWS.IoT1ClickProjects.describe_project/3","type":"function"},{"doc":"Removes a physical device from a placement.","ref":"AWS.IoT1ClickProjects.html#disassociate_device_from_placement/6","title":"AWS.IoT1ClickProjects.disassociate_device_from_placement/6","type":"function"},{"doc":"Returns an object enumerating the devices in a placement.","ref":"AWS.IoT1ClickProjects.html#get_devices_in_placement/4","title":"AWS.IoT1ClickProjects.get_devices_in_placement/4","type":"function"},{"doc":"Lists the placement(s) of a project.","ref":"AWS.IoT1ClickProjects.html#list_placements/5","title":"AWS.IoT1ClickProjects.list_placements/5","type":"function"},{"doc":"Lists the AWS IoT 1-Click project(s) associated with your AWS account and\nregion.","ref":"AWS.IoT1ClickProjects.html#list_projects/4","title":"AWS.IoT1ClickProjects.list_projects/4","type":"function"},{"doc":"Lists the tags (metadata key/value pairs) which you have assigned to the\nresource.","ref":"AWS.IoT1ClickProjects.html#list_tags_for_resource/3","title":"AWS.IoT1ClickProjects.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.IoT1ClickProjects.html#metadata/0","title":"AWS.IoT1ClickProjects.metadata/0","type":"function"},{"doc":"Creates or modifies tags for a resource.\n\nTags are key/value pairs (metadata) that can be used to manage a resource. For\nmore information, see [AWS Tagging Strategies](https://aws.amazon.com/answers/account-management/aws-tagging-strategies/).","ref":"AWS.IoT1ClickProjects.html#tag_resource/4","title":"AWS.IoT1ClickProjects.tag_resource/4","type":"function"},{"doc":"Removes one or more tags (metadata key/value pairs) from a resource.","ref":"AWS.IoT1ClickProjects.html#untag_resource/4","title":"AWS.IoT1ClickProjects.untag_resource/4","type":"function"},{"doc":"Updates a placement with the given attributes.\n\nTo clear an attribute, pass an empty value (i.e., \"\").","ref":"AWS.IoT1ClickProjects.html#update_placement/5","title":"AWS.IoT1ClickProjects.update_placement/5","type":"function"},{"doc":"Updates a project associated with your AWS account and region.\n\nWith the exception of device template names, you can pass just the values that\nneed to be updated because the update request will change only the values that\nare provided. To clear a value, pass the empty string (i.e., `\"\"`).","ref":"AWS.IoT1ClickProjects.html#update_project/4","title":"AWS.IoT1ClickProjects.update_project/4","type":"function"},{"doc":"IoT Analytics allows you to collect large amounts of device data, process\nmessages, and store them.\n\nYou can then query the data and run sophisticated analytics on it. IoT Analytics\nenables advanced data exploration through integration with Jupyter Notebooks and\ndata visualization through integration with Amazon QuickSight.\n\nTraditional analytics and business intelligence tools are designed to process\nstructured data. IoT data often comes from devices that record noisy processes\n(such as temperature, motion, or sound). As a result the data from these devices\ncan have significant gaps, corrupted messages, and false readings that must be\ncleaned up before analysis can occur. Also, IoT data is often only meaningful in\nthe context of other data from external sources.\n\nIoT Analytics automates the steps required to analyze data from IoT devices. IoT\nAnalytics filters, transforms, and enriches IoT data before storing it in a\ntime-series data store for analysis. You can set up the service to collect only\nthe data you need from your devices, apply mathematical transforms to process\nthe data, and enrich the data with device-specific metadata such as device type\nand location before storing it. Then, you can analyze your data by running\nqueries using the built-in SQL query engine, or perform more complex analytics\nand machine learning inference. IoT Analytics includes pre-built models for\ncommon IoT use cases so you can answer questions like which devices are about to\nfail or which customers are at risk of abandoning their wearable devices.","ref":"AWS.IoTAnalytics.html","title":"AWS.IoTAnalytics","type":"module"},{"doc":"Sends messages to a channel.","ref":"AWS.IoTAnalytics.html#batch_put_message/3","title":"AWS.IoTAnalytics.batch_put_message/3","type":"function"},{"doc":"Cancels the reprocessing of data through the pipeline.","ref":"AWS.IoTAnalytics.html#cancel_pipeline_reprocessing/5","title":"AWS.IoTAnalytics.cancel_pipeline_reprocessing/5","type":"function"},{"doc":"Used to create a channel.\n\nA channel collects data from an MQTT topic and archives the raw, unprocessed\nmessages before publishing the data to a pipeline.","ref":"AWS.IoTAnalytics.html#create_channel/3","title":"AWS.IoTAnalytics.create_channel/3","type":"function"},{"doc":"Used to create a dataset.\n\nA dataset stores data retrieved from a data store by applying a `queryAction` (a\nSQL query) or a `containerAction` (executing a containerized application). This\noperation creates the skeleton of a dataset. The dataset can be populated\nmanually by calling `CreateDatasetContent` or automatically according to a\ntrigger you specify.","ref":"AWS.IoTAnalytics.html#create_dataset/3","title":"AWS.IoTAnalytics.create_dataset/3","type":"function"},{"doc":"Creates the content of a dataset by applying a `queryAction` (a SQL query) or a\n`containerAction` (executing a containerized application).","ref":"AWS.IoTAnalytics.html#create_dataset_content/4","title":"AWS.IoTAnalytics.create_dataset_content/4","type":"function"},{"doc":"Creates a data store, which is a repository for messages.","ref":"AWS.IoTAnalytics.html#create_datastore/3","title":"AWS.IoTAnalytics.create_datastore/3","type":"function"},{"doc":"Creates a pipeline.\n\nA pipeline consumes messages from a channel and allows you to process the\nmessages before storing them in a data store. You must specify both a `channel`\nand a `datastore` activity and, optionally, as many as 23 additional activities\nin the `pipelineActivities` array.","ref":"AWS.IoTAnalytics.html#create_pipeline/3","title":"AWS.IoTAnalytics.create_pipeline/3","type":"function"},{"doc":"Deletes the specified channel.","ref":"AWS.IoTAnalytics.html#delete_channel/4","title":"AWS.IoTAnalytics.delete_channel/4","type":"function"},{"doc":"Deletes the specified dataset.\n\nYou do not have to delete the content of the dataset before you perform this\noperation.","ref":"AWS.IoTAnalytics.html#delete_dataset/4","title":"AWS.IoTAnalytics.delete_dataset/4","type":"function"},{"doc":"Deletes the content of the specified dataset.","ref":"AWS.IoTAnalytics.html#delete_dataset_content/4","title":"AWS.IoTAnalytics.delete_dataset_content/4","type":"function"},{"doc":"Deletes the specified data store.","ref":"AWS.IoTAnalytics.html#delete_datastore/4","title":"AWS.IoTAnalytics.delete_datastore/4","type":"function"},{"doc":"Deletes the specified pipeline.","ref":"AWS.IoTAnalytics.html#delete_pipeline/4","title":"AWS.IoTAnalytics.delete_pipeline/4","type":"function"},{"doc":"Retrieves information about a channel.","ref":"AWS.IoTAnalytics.html#describe_channel/4","title":"AWS.IoTAnalytics.describe_channel/4","type":"function"},{"doc":"Retrieves information about a dataset.","ref":"AWS.IoTAnalytics.html#describe_dataset/3","title":"AWS.IoTAnalytics.describe_dataset/3","type":"function"},{"doc":"Retrieves information about a data store.","ref":"AWS.IoTAnalytics.html#describe_datastore/4","title":"AWS.IoTAnalytics.describe_datastore/4","type":"function"},{"doc":"Retrieves the current settings of the IoT Analytics logging options.","ref":"AWS.IoTAnalytics.html#describe_logging_options/2","title":"AWS.IoTAnalytics.describe_logging_options/2","type":"function"},{"doc":"Retrieves information about a pipeline.","ref":"AWS.IoTAnalytics.html#describe_pipeline/3","title":"AWS.IoTAnalytics.describe_pipeline/3","type":"function"},{"doc":"Retrieves the contents of a dataset as presigned URIs.","ref":"AWS.IoTAnalytics.html#get_dataset_content/4","title":"AWS.IoTAnalytics.get_dataset_content/4","type":"function"},{"doc":"Retrieves a list of channels.","ref":"AWS.IoTAnalytics.html#list_channels/4","title":"AWS.IoTAnalytics.list_channels/4","type":"function"},{"doc":"Lists information about dataset contents that have been created.","ref":"AWS.IoTAnalytics.html#list_dataset_contents/7","title":"AWS.IoTAnalytics.list_dataset_contents/7","type":"function"},{"doc":"Retrieves information about datasets.","ref":"AWS.IoTAnalytics.html#list_datasets/4","title":"AWS.IoTAnalytics.list_datasets/4","type":"function"},{"doc":"Retrieves a list of data stores.","ref":"AWS.IoTAnalytics.html#list_datastores/4","title":"AWS.IoTAnalytics.list_datastores/4","type":"function"},{"doc":"Retrieves a list of pipelines.","ref":"AWS.IoTAnalytics.html#list_pipelines/4","title":"AWS.IoTAnalytics.list_pipelines/4","type":"function"},{"doc":"Lists the tags (metadata) that you have assigned to the resource.","ref":"AWS.IoTAnalytics.html#list_tags_for_resource/3","title":"AWS.IoTAnalytics.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.IoTAnalytics.html#metadata/0","title":"AWS.IoTAnalytics.metadata/0","type":"function"},{"doc":"Sets or updates the IoT Analytics logging options.\n\nIf you update the value of any `loggingOptions` field, it takes up to one minute\nfor the change to take effect. Also, if you change the policy attached to the\nrole you specified in the `roleArn` field (for example, to correct an invalid\npolicy), it takes up to five minutes for that change to take effect.","ref":"AWS.IoTAnalytics.html#put_logging_options/3","title":"AWS.IoTAnalytics.put_logging_options/3","type":"function"},{"doc":"Simulates the results of running a pipeline activity on a message payload.","ref":"AWS.IoTAnalytics.html#run_pipeline_activity/3","title":"AWS.IoTAnalytics.run_pipeline_activity/3","type":"function"},{"doc":"Retrieves a sample of messages from the specified channel ingested during the\nspecified timeframe.\n\nUp to 10 messages can be retrieved.","ref":"AWS.IoTAnalytics.html#sample_channel_data/6","title":"AWS.IoTAnalytics.sample_channel_data/6","type":"function"},{"doc":"Starts the reprocessing of raw message data through the pipeline.","ref":"AWS.IoTAnalytics.html#start_pipeline_reprocessing/4","title":"AWS.IoTAnalytics.start_pipeline_reprocessing/4","type":"function"},{"doc":"Adds to or modifies the tags of the given resource.\n\nTags are metadata that can be used to manage a resource.","ref":"AWS.IoTAnalytics.html#tag_resource/3","title":"AWS.IoTAnalytics.tag_resource/3","type":"function"},{"doc":"Removes the given tags (metadata) from the resource.","ref":"AWS.IoTAnalytics.html#untag_resource/3","title":"AWS.IoTAnalytics.untag_resource/3","type":"function"},{"doc":"Used to update the settings of a channel.","ref":"AWS.IoTAnalytics.html#update_channel/4","title":"AWS.IoTAnalytics.update_channel/4","type":"function"},{"doc":"Updates the settings of a dataset.","ref":"AWS.IoTAnalytics.html#update_dataset/4","title":"AWS.IoTAnalytics.update_dataset/4","type":"function"},{"doc":"Used to update the settings of a data store.","ref":"AWS.IoTAnalytics.html#update_datastore/4","title":"AWS.IoTAnalytics.update_datastore/4","type":"function"},{"doc":"Updates the settings of a pipeline.\n\nYou must specify both a `channel` and a `datastore` activity and, optionally, as\nmany as 23 additional activities in the `pipelineActivities` array.","ref":"AWS.IoTAnalytics.html#update_pipeline/4","title":"AWS.IoTAnalytics.update_pipeline/4","type":"function"},{"doc":"IoT data\n\nIoT data enables secure, bi-directional communication between Internet-connected\nthings (such as sensors, actuators, embedded devices, or smart appliances) and\nthe Amazon Web Services cloud.\n\nIt implements a broker for applications and things to publish messages over HTTP\n(Publish) and retrieve, update, and delete shadows. A shadow is a persistent\nrepresentation of your things and their state in the Amazon Web Services cloud.\n\nFind the endpoint address for actions in IoT data by running this CLI command:\n\n`aws iot describe-endpoint --endpoint-type iot:Data-ATS`\n\nThe service name used by [Amazon Web ServicesSignature Version 4](https://docs.aws.amazon.com/general/latest/gr/signature-version-4.html) to\nsign requests is: *iotdevicegateway*.","ref":"AWS.IoTDataPlane.html","title":"AWS.IoTDataPlane","type":"module"},{"doc":"Deletes the shadow for the specified thing.\n\nRequires permission to access the\n[DeleteThingShadow](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions) action.\n\nFor more information, see\n[DeleteThingShadow](http://docs.aws.amazon.com/iot/latest/developerguide/API_DeleteThingShadow.html)\nin the IoT Developer Guide.","ref":"AWS.IoTDataPlane.html#delete_thing_shadow/4","title":"AWS.IoTDataPlane.delete_thing_shadow/4","type":"function"},{"doc":"Gets the details of a single retained message for the specified topic.\n\nThis action returns the message payload of the retained message, which can incur\nmessaging costs. To list only the topic names of the retained messages, call\n[ListRetainedMessages](https://docs.aws.amazon.com/iot/latest/apireference/API_iotdata_ListRetainedMessages.html).  Requires permission to access the\n[GetRetainedMessage](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiotfleethubfordevicemanagement.html#awsiotfleethubfordevicemanagement-actions-as-permissions)\naction.\n\nFor more information about messaging costs, see [Amazon Web Services IoT Core pricing - Messaging](http://aws.amazon.com/iot-core/pricing/#Messaging).","ref":"AWS.IoTDataPlane.html#get_retained_message/3","title":"AWS.IoTDataPlane.get_retained_message/3","type":"function"},{"doc":"Gets the shadow for the specified thing.\n\nRequires permission to access the\n[GetThingShadow](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions) action.\n\nFor more information, see\n[GetThingShadow](http://docs.aws.amazon.com/iot/latest/developerguide/API_GetThingShadow.html)\nin the IoT Developer Guide.","ref":"AWS.IoTDataPlane.html#get_thing_shadow/4","title":"AWS.IoTDataPlane.get_thing_shadow/4","type":"function"},{"doc":"Lists the shadows for the specified thing.\n\nRequires permission to access the\n[ListNamedShadowsForThing](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoTDataPlane.html#list_named_shadows_for_thing/5","title":"AWS.IoTDataPlane.list_named_shadows_for_thing/5","type":"function"},{"doc":"Lists summary information about the retained messages stored for the account.\n\nThis action returns only the topic names of the retained messages. It doesn't\nreturn any message payloads. Although this action doesn't return a message\npayload, it can still incur messaging costs.\n\nTo get the message payload of a retained message, call\n[GetRetainedMessage](https://docs.aws.amazon.com/iot/latest/apireference/API_iotdata_GetRetainedMessage.html) with the topic name of the retained message.\n\nRequires permission to access the\n[ListRetainedMessages](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiotfleethubfordevicemanagement.html#awsiotfleethubfordevicemanagement-actions-as-permissions)\naction.\n\nFor more information about messaging costs, see [Amazon Web Services IoT Core pricing - Messaging](http://aws.amazon.com/iot-core/pricing/#Messaging).","ref":"AWS.IoTDataPlane.html#list_retained_messages/4","title":"AWS.IoTDataPlane.list_retained_messages/4","type":"function"},{"doc":"","ref":"AWS.IoTDataPlane.html#metadata/0","title":"AWS.IoTDataPlane.metadata/0","type":"function"},{"doc":"Publishes an MQTT message.\n\nRequires permission to access the\n[Publish](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions) action.\n\nFor more information about MQTT messages, see [MQTT\nProtocol](http://docs.aws.amazon.com/iot/latest/developerguide/mqtt.html) in the\nIoT Developer Guide.\n\nFor more information about messaging costs, see [Amazon Web Services IoT Core pricing - Messaging](http://aws.amazon.com/iot-core/pricing/#Messaging).","ref":"AWS.IoTDataPlane.html#publish/4","title":"AWS.IoTDataPlane.publish/4","type":"function"},{"doc":"Updates the shadow for the specified thing.\n\nRequires permission to access the\n[UpdateThingShadow](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions) action.\n\nFor more information, see\n[UpdateThingShadow](http://docs.aws.amazon.com/iot/latest/developerguide/API_UpdateThingShadow.html)\nin the IoT Developer Guide.","ref":"AWS.IoTDataPlane.html#update_thing_shadow/4","title":"AWS.IoTDataPlane.update_thing_shadow/4","type":"function"},{"doc":"AWS IoT Events monitors your equipment or device fleets for failures or changes\nin operation, and triggers actions when such events occur.\n\nYou can use AWS IoT Events API operations to create, read, update, and delete\ninputs and detector models, and to list their versions.","ref":"AWS.IoTEvents.html","title":"AWS.IoTEvents","type":"module"},{"doc":"Creates an alarm model to monitor an AWS IoT Events input attribute.\n\nYou can use the alarm to get notified when the value is outside a specified\nrange. For more information, see [Create an alarm model](https://docs.aws.amazon.com/iotevents/latest/developerguide/create-alarms.html)\nin the *AWS IoT Events Developer Guide*.","ref":"AWS.IoTEvents.html#create_alarm_model/3","title":"AWS.IoTEvents.create_alarm_model/3","type":"function"},{"doc":"Creates a detector model.","ref":"AWS.IoTEvents.html#create_detector_model/3","title":"AWS.IoTEvents.create_detector_model/3","type":"function"},{"doc":"Creates an input.","ref":"AWS.IoTEvents.html#create_input/3","title":"AWS.IoTEvents.create_input/3","type":"function"},{"doc":"Deletes an alarm model.\n\nAny alarm instances that were created based on this alarm model are also\ndeleted. This action can't be undone.","ref":"AWS.IoTEvents.html#delete_alarm_model/4","title":"AWS.IoTEvents.delete_alarm_model/4","type":"function"},{"doc":"Deletes a detector model.\n\nAny active instances of the detector model are also deleted.","ref":"AWS.IoTEvents.html#delete_detector_model/4","title":"AWS.IoTEvents.delete_detector_model/4","type":"function"},{"doc":"Deletes an input.","ref":"AWS.IoTEvents.html#delete_input/4","title":"AWS.IoTEvents.delete_input/4","type":"function"},{"doc":"Retrieves information about an alarm model.\n\nIf you don't specify a value for the `alarmModelVersion` parameter, the latest\nversion is returned.","ref":"AWS.IoTEvents.html#describe_alarm_model/4","title":"AWS.IoTEvents.describe_alarm_model/4","type":"function"},{"doc":"Describes a detector model.\n\nIf the `version` parameter is not specified, information about the latest\nversion is returned.","ref":"AWS.IoTEvents.html#describe_detector_model/4","title":"AWS.IoTEvents.describe_detector_model/4","type":"function"},{"doc":"Retrieves runtime information about a detector model analysis.\n\nAfter AWS IoT Events starts analyzing your detector model, you have up to 24\nhours to retrieve the analysis results.","ref":"AWS.IoTEvents.html#describe_detector_model_analysis/3","title":"AWS.IoTEvents.describe_detector_model_analysis/3","type":"function"},{"doc":"Describes an input.","ref":"AWS.IoTEvents.html#describe_input/3","title":"AWS.IoTEvents.describe_input/3","type":"function"},{"doc":"Retrieves the current settings of the AWS IoT Events logging options.","ref":"AWS.IoTEvents.html#describe_logging_options/2","title":"AWS.IoTEvents.describe_logging_options/2","type":"function"},{"doc":"Retrieves one or more analysis results of the detector model.\n\nAfter AWS IoT Events starts analyzing your detector model, you have up to 24\nhours to retrieve the analysis results.","ref":"AWS.IoTEvents.html#get_detector_model_analysis_results/5","title":"AWS.IoTEvents.get_detector_model_analysis_results/5","type":"function"},{"doc":"Lists all the versions of an alarm model.\n\nThe operation returns only the metadata associated with each alarm model\nversion.","ref":"AWS.IoTEvents.html#list_alarm_model_versions/5","title":"AWS.IoTEvents.list_alarm_model_versions/5","type":"function"},{"doc":"Lists the alarm models that you created.\n\nThe operation returns only the metadata associated with each alarm model.","ref":"AWS.IoTEvents.html#list_alarm_models/4","title":"AWS.IoTEvents.list_alarm_models/4","type":"function"},{"doc":"Lists all the versions of a detector model.\n\nOnly the metadata associated with each detector model version is returned.","ref":"AWS.IoTEvents.html#list_detector_model_versions/5","title":"AWS.IoTEvents.list_detector_model_versions/5","type":"function"},{"doc":"Lists the detector models you have created.\n\nOnly the metadata associated with each detector model is returned.","ref":"AWS.IoTEvents.html#list_detector_models/4","title":"AWS.IoTEvents.list_detector_models/4","type":"function"},{"doc":"Lists one or more input routings.","ref":"AWS.IoTEvents.html#list_input_routings/3","title":"AWS.IoTEvents.list_input_routings/3","type":"function"},{"doc":"Lists the inputs you have created.","ref":"AWS.IoTEvents.html#list_inputs/4","title":"AWS.IoTEvents.list_inputs/4","type":"function"},{"doc":"Lists the tags (metadata) you have assigned to the resource.","ref":"AWS.IoTEvents.html#list_tags_for_resource/3","title":"AWS.IoTEvents.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.IoTEvents.html#metadata/0","title":"AWS.IoTEvents.metadata/0","type":"function"},{"doc":"Sets or updates the AWS IoT Events logging options.\n\nIf you update the value of any `loggingOptions` field, it takes up to one minute\nfor the change to take effect. If you change the policy attached to the role you\nspecified in the `roleArn` field (for example, to correct an invalid policy), it\ntakes up to five minutes for that change to take effect.","ref":"AWS.IoTEvents.html#put_logging_options/3","title":"AWS.IoTEvents.put_logging_options/3","type":"function"},{"doc":"Performs an analysis of your detector model.\n\nFor more information, see [Troubleshooting a detector model](https://docs.aws.amazon.com/iotevents/latest/developerguide/iotevents-analyze-api.html)\nin the *AWS IoT Events Developer Guide*.","ref":"AWS.IoTEvents.html#start_detector_model_analysis/3","title":"AWS.IoTEvents.start_detector_model_analysis/3","type":"function"},{"doc":"Adds to or modifies the tags of the given resource.\n\nTags are metadata that can be used to manage a resource.","ref":"AWS.IoTEvents.html#tag_resource/3","title":"AWS.IoTEvents.tag_resource/3","type":"function"},{"doc":"Removes the given tags (metadata) from the resource.","ref":"AWS.IoTEvents.html#untag_resource/3","title":"AWS.IoTEvents.untag_resource/3","type":"function"},{"doc":"Updates an alarm model.\n\nAny alarms that were created based on the previous version are deleted and then\ncreated again as new data arrives.","ref":"AWS.IoTEvents.html#update_alarm_model/4","title":"AWS.IoTEvents.update_alarm_model/4","type":"function"},{"doc":"Updates a detector model.\n\nDetectors (instances) spawned by the previous version are deleted and then\nre-created as new inputs arrive.","ref":"AWS.IoTEvents.html#update_detector_model/4","title":"AWS.IoTEvents.update_detector_model/4","type":"function"},{"doc":"Updates an input.","ref":"AWS.IoTEvents.html#update_input/4","title":"AWS.IoTEvents.update_input/4","type":"function"},{"doc":"IoT Events monitors your equipment or device fleets for failures or changes in\noperation, and triggers actions when such events occur.\n\nYou can use IoT Events Data API commands to send inputs to detectors, list\ndetectors, and view or update a detector's status.\n\nFor more information, see [What is IoT Events?](https://docs.aws.amazon.com/iotevents/latest/developerguide/what-is-iotevents.html)\nin the *IoT Events Developer Guide*.","ref":"AWS.IoTEventsData.html","title":"AWS.IoTEventsData","type":"module"},{"doc":"Acknowledges one or more alarms.\n\nThe alarms change to the `ACKNOWLEDGED` state after you acknowledge them.","ref":"AWS.IoTEventsData.html#batch_acknowledge_alarm/3","title":"AWS.IoTEventsData.batch_acknowledge_alarm/3","type":"function"},{"doc":"Deletes one or more detectors that were created.\n\nWhen a detector is deleted, its state will be cleared and the detector will be\nremoved from the list of detectors. The deleted detector will no longer appear\nif referenced in the\n[ListDetectors](https://docs.aws.amazon.com/iotevents/latest/apireference/API_iotevents-data_ListDetectors.html)\nAPI call.","ref":"AWS.IoTEventsData.html#batch_delete_detector/3","title":"AWS.IoTEventsData.batch_delete_detector/3","type":"function"},{"doc":"Disables one or more alarms.\n\nThe alarms change to the `DISABLED` state after you disable them.","ref":"AWS.IoTEventsData.html#batch_disable_alarm/3","title":"AWS.IoTEventsData.batch_disable_alarm/3","type":"function"},{"doc":"Enables one or more alarms.\n\nThe alarms change to the `NORMAL` state after you enable them.","ref":"AWS.IoTEventsData.html#batch_enable_alarm/3","title":"AWS.IoTEventsData.batch_enable_alarm/3","type":"function"},{"doc":"Sends a set of messages to the IoT Events system.\n\nEach message payload is transformed into the input you specify (`\"inputName\"`)\nand ingested into any detectors that monitor that input. If multiple messages\nare sent, the order in which the messages are processed isn't guaranteed. To\nguarantee ordering, you must send messages one at a time and wait for a\nsuccessful response.","ref":"AWS.IoTEventsData.html#batch_put_message/3","title":"AWS.IoTEventsData.batch_put_message/3","type":"function"},{"doc":"Resets one or more alarms.\n\nThe alarms return to the `NORMAL` state after you reset them.","ref":"AWS.IoTEventsData.html#batch_reset_alarm/3","title":"AWS.IoTEventsData.batch_reset_alarm/3","type":"function"},{"doc":"Changes one or more alarms to the snooze mode.\n\nThe alarms change to the `SNOOZE_DISABLED` state after you set them to the\nsnooze mode.","ref":"AWS.IoTEventsData.html#batch_snooze_alarm/3","title":"AWS.IoTEventsData.batch_snooze_alarm/3","type":"function"},{"doc":"Updates the state, variable values, and timer settings of one or more detectors\n(instances) of a specified detector model.","ref":"AWS.IoTEventsData.html#batch_update_detector/3","title":"AWS.IoTEventsData.batch_update_detector/3","type":"function"},{"doc":"Retrieves information about an alarm.","ref":"AWS.IoTEventsData.html#describe_alarm/4","title":"AWS.IoTEventsData.describe_alarm/4","type":"function"},{"doc":"Returns information about the specified detector (instance).","ref":"AWS.IoTEventsData.html#describe_detector/4","title":"AWS.IoTEventsData.describe_detector/4","type":"function"},{"doc":"Lists one or more alarms.\n\nThe operation returns only the metadata associated with each alarm.","ref":"AWS.IoTEventsData.html#list_alarms/5","title":"AWS.IoTEventsData.list_alarms/5","type":"function"},{"doc":"Lists detectors (the instances of a detector model).","ref":"AWS.IoTEventsData.html#list_detectors/6","title":"AWS.IoTEventsData.list_detectors/6","type":"function"},{"doc":"","ref":"AWS.IoTEventsData.html#metadata/0","title":"AWS.IoTEventsData.metadata/0","type":"function"},{"doc":"With Fleet Hub for AWS IoT Device Management you can build stand-alone web\napplications for monitoring the health of your device fleets.\n\nFleet Hub for AWS IoT Device Management is in public preview and is subject to\nchange.","ref":"AWS.IoTFleetHub.html","title":"AWS.IoTFleetHub","type":"module"},{"doc":"Creates a Fleet Hub for AWS IoT Device Management web application.\n\nFleet Hub for AWS IoT Device Management is in public preview and is subject to\nchange.","ref":"AWS.IoTFleetHub.html#create_application/3","title":"AWS.IoTFleetHub.create_application/3","type":"function"},{"doc":"Deletes a Fleet Hub for AWS IoT Device Management web application.\n\nFleet Hub for AWS IoT Device Management is in public preview and is subject to\nchange.","ref":"AWS.IoTFleetHub.html#delete_application/4","title":"AWS.IoTFleetHub.delete_application/4","type":"function"},{"doc":"Gets information about a Fleet Hub for AWS IoT Device Management web\napplication.\n\nFleet Hub for AWS IoT Device Management is in public preview and is subject to\nchange.","ref":"AWS.IoTFleetHub.html#describe_application/3","title":"AWS.IoTFleetHub.describe_application/3","type":"function"},{"doc":"Gets a list of Fleet Hub for AWS IoT Device Management web applications for the\ncurrent account.\n\nFleet Hub for AWS IoT Device Management is in public preview and is subject to\nchange.","ref":"AWS.IoTFleetHub.html#list_applications/3","title":"AWS.IoTFleetHub.list_applications/3","type":"function"},{"doc":"Lists the tags for the specified resource.\n\nFleet Hub for AWS IoT Device Management is in public preview and is subject to\nchange.","ref":"AWS.IoTFleetHub.html#list_tags_for_resource/3","title":"AWS.IoTFleetHub.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.IoTFleetHub.html#metadata/0","title":"AWS.IoTFleetHub.metadata/0","type":"function"},{"doc":"Adds to or modifies the tags of the specified resource.\n\nTags are metadata which can be used to manage a resource.\n\nFleet Hub for AWS IoT Device Management is in public preview and is subject to\nchange.","ref":"AWS.IoTFleetHub.html#tag_resource/4","title":"AWS.IoTFleetHub.tag_resource/4","type":"function"},{"doc":"Removes the specified tags (metadata) from the resource.\n\nFleet Hub for AWS IoT Device Management is in public preview and is subject to\nchange.","ref":"AWS.IoTFleetHub.html#untag_resource/4","title":"AWS.IoTFleetHub.untag_resource/4","type":"function"},{"doc":"Updates information about a Fleet Hub for a AWS IoT Device Management web\napplication.\n\nFleet Hub for AWS IoT Device Management is in public preview and is subject to\nchange.","ref":"AWS.IoTFleetHub.html#update_application/4","title":"AWS.IoTFleetHub.update_application/4","type":"function"},{"doc":"Amazon Web Services IoT FleetWise is a fully managed service that you can use to\ncollect, model, and transfer vehicle data to the Amazon Web Services cloud at\nscale.\n\nWith Amazon Web Services IoT FleetWise, you can standardize all of your vehicle\ndata models, independent of the in-vehicle communication architecture, and\ndefine data collection rules to transfer only high-value data to the cloud.\n\nFor more information, see [What is Amazon Web Services IoT FleetWise?](https://docs.aws.amazon.com/iot-fleetwise/latest/developerguide/) in\nthe *Amazon Web Services IoT FleetWise Developer Guide*.","ref":"AWS.IoTFleetWise.html","title":"AWS.IoTFleetWise","type":"module"},{"doc":"Adds, or associates, a vehicle with a fleet.","ref":"AWS.IoTFleetWise.html#associate_vehicle_fleet/3","title":"AWS.IoTFleetWise.associate_vehicle_fleet/3","type":"function"},{"doc":"Creates a group, or batch, of vehicles.\n\nYou must specify a decoder manifest and a vehicle model (model manifest) for\neach vehicle.\n\nFor more information, see [Create multiple vehicles (AWS CLI)](https://docs.aws.amazon.com/iot-fleetwise/latest/developerguide/create-vehicles-cli.html)\nin the *Amazon Web Services IoT FleetWise Developer Guide*.","ref":"AWS.IoTFleetWise.html#batch_create_vehicle/3","title":"AWS.IoTFleetWise.batch_create_vehicle/3","type":"function"},{"doc":"Updates a group, or batch, of vehicles.\n\nYou must specify a decoder manifest and a vehicle model (model manifest) for\neach vehicle.\n\nFor more information, see [Update multiple vehicles (AWS CLI)](https://docs.aws.amazon.com/iot-fleetwise/latest/developerguide/update-vehicles-cli.html)\nin the *Amazon Web Services IoT FleetWise Developer Guide*.","ref":"AWS.IoTFleetWise.html#batch_update_vehicle/3","title":"AWS.IoTFleetWise.batch_update_vehicle/3","type":"function"},{"doc":"Creates an orchestration of data collection rules.\n\nThe Amazon Web Services IoT FleetWise Edge Agent software running in vehicles\nuses campaigns to decide how to collect and transfer data to the cloud. You\ncreate campaigns in the cloud. After you or your team approve campaigns, Amazon\nWeb Services IoT FleetWise automatically deploys them to vehicles.\n\nFor more information, see [Collect and transfer data with campaigns](https://docs.aws.amazon.com/iot-fleetwise/latest/developerguide/campaigns.html)\nin the *Amazon Web Services IoT FleetWise Developer Guide*.","ref":"AWS.IoTFleetWise.html#create_campaign/3","title":"AWS.IoTFleetWise.create_campaign/3","type":"function"},{"doc":"Creates the decoder manifest associated with a model manifest.\n\nTo create a decoder manifest, the following must be true:\n\n  * Every signal decoder has a unique name.\n\n  * Each signal decoder is associated with a network interface.\n\n  * Each network interface has a unique ID.\n\n  * The signal decoders are specified in the model manifest.","ref":"AWS.IoTFleetWise.html#create_decoder_manifest/3","title":"AWS.IoTFleetWise.create_decoder_manifest/3","type":"function"},{"doc":"Creates a fleet that represents a group of vehicles.\n\nYou must create both a signal catalog and vehicles before you can create a\nfleet.\n\nFor more information, see\n[Fleets](https://docs.aws.amazon.com/iot-fleetwise/latest/developerguide/fleets.html)\nin the *Amazon Web Services IoT FleetWise Developer Guide*.","ref":"AWS.IoTFleetWise.html#create_fleet/3","title":"AWS.IoTFleetWise.create_fleet/3","type":"function"},{"doc":"Creates a vehicle model (model manifest) that specifies signals (attributes,\nbranches, sensors, and actuators).\n\nFor more information, see [Vehicle models](https://docs.aws.amazon.com/iot-fleetwise/latest/developerguide/vehicle-models.html)\nin the *Amazon Web Services IoT FleetWise Developer Guide*.","ref":"AWS.IoTFleetWise.html#create_model_manifest/3","title":"AWS.IoTFleetWise.create_model_manifest/3","type":"function"},{"doc":"Creates a collection of standardized signals that can be reused to create\nvehicle models.","ref":"AWS.IoTFleetWise.html#create_signal_catalog/3","title":"AWS.IoTFleetWise.create_signal_catalog/3","type":"function"},{"doc":"Creates a vehicle, which is an instance of a vehicle model (model manifest).\n\nVehicles created from the same vehicle model consist of the same signals\ninherited from the vehicle model.\n\nIf you have an existing Amazon Web Services IoT thing, you can use Amazon Web\nServices IoT FleetWise to create a vehicle and collect data from your thing.\n\nFor more information, see [Create a vehicle (AWS CLI)](https://docs.aws.amazon.com/iot-fleetwise/latest/developerguide/create-vehicle-cli.html)\nin the *Amazon Web Services IoT FleetWise Developer Guide*.","ref":"AWS.IoTFleetWise.html#create_vehicle/3","title":"AWS.IoTFleetWise.create_vehicle/3","type":"function"},{"doc":"Deletes a data collection campaign.\n\nDeleting a campaign suspends all data collection and removes it from any\nvehicles.","ref":"AWS.IoTFleetWise.html#delete_campaign/3","title":"AWS.IoTFleetWise.delete_campaign/3","type":"function"},{"doc":"Deletes a decoder manifest.\n\nYou can't delete a decoder manifest if it has vehicles associated with it.\n\nIf the decoder manifest is successfully deleted, Amazon Web Services IoT\nFleetWise sends back an HTTP 200 response with an empty body.","ref":"AWS.IoTFleetWise.html#delete_decoder_manifest/3","title":"AWS.IoTFleetWise.delete_decoder_manifest/3","type":"function"},{"doc":"Deletes a fleet.\n\nBefore you delete a fleet, all vehicles must be dissociated from the fleet. For\nmore information, see [Delete a fleet (AWS CLI)](https://docs.aws.amazon.com/iot-fleetwise/latest/developerguide/delete-fleet-cli.html)\nin the *Amazon Web Services IoT FleetWise Developer Guide*.\n\nIf the fleet is successfully deleted, Amazon Web Services IoT FleetWise sends\nback an HTTP 200 response with an empty body.","ref":"AWS.IoTFleetWise.html#delete_fleet/3","title":"AWS.IoTFleetWise.delete_fleet/3","type":"function"},{"doc":"Deletes a vehicle model (model manifest).\n\nIf the vehicle model is successfully deleted, Amazon Web Services IoT FleetWise\nsends back an HTTP 200 response with an empty body.","ref":"AWS.IoTFleetWise.html#delete_model_manifest/3","title":"AWS.IoTFleetWise.delete_model_manifest/3","type":"function"},{"doc":"Deletes a signal catalog.\n\nIf the signal catalog is successfully deleted, Amazon Web Services IoT FleetWise\nsends back an HTTP 200 response with an empty body.","ref":"AWS.IoTFleetWise.html#delete_signal_catalog/3","title":"AWS.IoTFleetWise.delete_signal_catalog/3","type":"function"},{"doc":"Deletes a vehicle and removes it from any campaigns.\n\nIf the vehicle is successfully deleted, Amazon Web Services IoT FleetWise sends\nback an HTTP 200 response with an empty body.","ref":"AWS.IoTFleetWise.html#delete_vehicle/3","title":"AWS.IoTFleetWise.delete_vehicle/3","type":"function"},{"doc":"Removes, or disassociates, a vehicle from a fleet.\n\nDisassociating a vehicle from a fleet doesn't delete the vehicle.\n\nIf the vehicle is successfully dissociated from a fleet, Amazon Web Services IoT\nFleetWise sends back an HTTP 200 response with an empty body.","ref":"AWS.IoTFleetWise.html#disassociate_vehicle_fleet/3","title":"AWS.IoTFleetWise.disassociate_vehicle_fleet/3","type":"function"},{"doc":"Retrieves information about a campaign.","ref":"AWS.IoTFleetWise.html#get_campaign/3","title":"AWS.IoTFleetWise.get_campaign/3","type":"function"},{"doc":"Retrieves information about a created decoder manifest.","ref":"AWS.IoTFleetWise.html#get_decoder_manifest/3","title":"AWS.IoTFleetWise.get_decoder_manifest/3","type":"function"},{"doc":"Retrieves the encryption configuration for resources and data in Amazon Web\nServices IoT FleetWise.","ref":"AWS.IoTFleetWise.html#get_encryption_configuration/3","title":"AWS.IoTFleetWise.get_encryption_configuration/3","type":"function"},{"doc":"Retrieves information about a fleet.","ref":"AWS.IoTFleetWise.html#get_fleet/3","title":"AWS.IoTFleetWise.get_fleet/3","type":"function"},{"doc":"Retrieves the logging options.","ref":"AWS.IoTFleetWise.html#get_logging_options/3","title":"AWS.IoTFleetWise.get_logging_options/3","type":"function"},{"doc":"Retrieves information about a vehicle model (model manifest).","ref":"AWS.IoTFleetWise.html#get_model_manifest/3","title":"AWS.IoTFleetWise.get_model_manifest/3","type":"function"},{"doc":"Retrieves information about the status of registering your Amazon Web Services\naccount, IAM, and Amazon Timestream resources so that Amazon Web Services IoT\nFleetWise can transfer your vehicle data to the Amazon Web Services Cloud.\n\nFor more information, including step-by-step procedures, see [Setting up Amazon Web Services IoT\nFleetWise](https://docs.aws.amazon.com/iot-fleetwise/latest/developerguide/setting-up.html).\n\nThis API operation doesn't require input parameters.","ref":"AWS.IoTFleetWise.html#get_register_account_status/3","title":"AWS.IoTFleetWise.get_register_account_status/3","type":"function"},{"doc":"Retrieves information about a signal catalog.","ref":"AWS.IoTFleetWise.html#get_signal_catalog/3","title":"AWS.IoTFleetWise.get_signal_catalog/3","type":"function"},{"doc":"Retrieves information about a vehicle.","ref":"AWS.IoTFleetWise.html#get_vehicle/3","title":"AWS.IoTFleetWise.get_vehicle/3","type":"function"},{"doc":"Retrieves information about the status of a vehicle with any associated\ncampaigns.","ref":"AWS.IoTFleetWise.html#get_vehicle_status/3","title":"AWS.IoTFleetWise.get_vehicle_status/3","type":"function"},{"doc":"Creates a decoder manifest using your existing CAN DBC file from your local\ndevice.","ref":"AWS.IoTFleetWise.html#import_decoder_manifest/3","title":"AWS.IoTFleetWise.import_decoder_manifest/3","type":"function"},{"doc":"Creates a signal catalog using your existing VSS formatted content from your\nlocal device.","ref":"AWS.IoTFleetWise.html#import_signal_catalog/3","title":"AWS.IoTFleetWise.import_signal_catalog/3","type":"function"},{"doc":"Lists information about created campaigns.\n\nThis API operation uses pagination. Specify the `nextToken` parameter in the\nrequest to return more results.","ref":"AWS.IoTFleetWise.html#list_campaigns/3","title":"AWS.IoTFleetWise.list_campaigns/3","type":"function"},{"doc":"Lists the network interfaces specified in a decoder manifest.\n\nThis API operation uses pagination. Specify the `nextToken` parameter in the\nrequest to return more results.","ref":"AWS.IoTFleetWise.html#list_decoder_manifest_network_interfaces/3","title":"AWS.IoTFleetWise.list_decoder_manifest_network_interfaces/3","type":"function"},{"doc":"A list of information about signal decoders specified in a decoder manifest.\n\nThis API operation uses pagination. Specify the `nextToken` parameter in the\nrequest to return more results.","ref":"AWS.IoTFleetWise.html#list_decoder_manifest_signals/3","title":"AWS.IoTFleetWise.list_decoder_manifest_signals/3","type":"function"},{"doc":"Lists decoder manifests.\n\nThis API operation uses pagination. Specify the `nextToken` parameter in the\nrequest to return more results.","ref":"AWS.IoTFleetWise.html#list_decoder_manifests/3","title":"AWS.IoTFleetWise.list_decoder_manifests/3","type":"function"},{"doc":"Retrieves information for each created fleet in an Amazon Web Services account.\n\nThis API operation uses pagination. Specify the `nextToken` parameter in the\nrequest to return more results.","ref":"AWS.IoTFleetWise.html#list_fleets/3","title":"AWS.IoTFleetWise.list_fleets/3","type":"function"},{"doc":"Retrieves a list of IDs for all fleets that the vehicle is associated with.\n\nThis API operation uses pagination. Specify the `nextToken` parameter in the\nrequest to return more results.","ref":"AWS.IoTFleetWise.html#list_fleets_for_vehicle/3","title":"AWS.IoTFleetWise.list_fleets_for_vehicle/3","type":"function"},{"doc":"Lists information about nodes specified in a vehicle model (model manifest).\n\nThis API operation uses pagination. Specify the `nextToken` parameter in the\nrequest to return more results.","ref":"AWS.IoTFleetWise.html#list_model_manifest_nodes/3","title":"AWS.IoTFleetWise.list_model_manifest_nodes/3","type":"function"},{"doc":"Retrieves a list of vehicle models (model manifests).\n\nThis API operation uses pagination. Specify the `nextToken` parameter in the\nrequest to return more results.","ref":"AWS.IoTFleetWise.html#list_model_manifests/3","title":"AWS.IoTFleetWise.list_model_manifests/3","type":"function"},{"doc":"Lists of information about the signals (nodes) specified in a signal catalog.\n\nThis API operation uses pagination. Specify the `nextToken` parameter in the\nrequest to return more results.","ref":"AWS.IoTFleetWise.html#list_signal_catalog_nodes/3","title":"AWS.IoTFleetWise.list_signal_catalog_nodes/3","type":"function"},{"doc":"Lists all the created signal catalogs in an Amazon Web Services account.\n\nYou can use to list information about each signal (node) specified in a signal\ncatalog.\n\nThis API operation uses pagination. Specify the `nextToken` parameter in the\nrequest to return more results.","ref":"AWS.IoTFleetWise.html#list_signal_catalogs/3","title":"AWS.IoTFleetWise.list_signal_catalogs/3","type":"function"},{"doc":"Lists the tags (metadata) you have assigned to the resource.","ref":"AWS.IoTFleetWise.html#list_tags_for_resource/3","title":"AWS.IoTFleetWise.list_tags_for_resource/3","type":"function"},{"doc":"Retrieves a list of summaries of created vehicles.\n\nThis API operation uses pagination. Specify the `nextToken` parameter in the\nrequest to return more results.","ref":"AWS.IoTFleetWise.html#list_vehicles/3","title":"AWS.IoTFleetWise.list_vehicles/3","type":"function"},{"doc":"Retrieves a list of summaries of all vehicles associated with a fleet.\n\nThis API operation uses pagination. Specify the `nextToken` parameter in the\nrequest to return more results.","ref":"AWS.IoTFleetWise.html#list_vehicles_in_fleet/3","title":"AWS.IoTFleetWise.list_vehicles_in_fleet/3","type":"function"},{"doc":"","ref":"AWS.IoTFleetWise.html#metadata/0","title":"AWS.IoTFleetWise.metadata/0","type":"function"},{"doc":"Creates or updates the encryption configuration.\n\nAmazon Web Services IoT FleetWise can encrypt your data and resources using an\nAmazon Web Services managed key. Or, you can use a KMS key that you own and\nmanage. For more information, see [Data encryption](https://docs.aws.amazon.com/iot-fleetwise/latest/developerguide/data-encryption.html)\nin the *Amazon Web Services IoT FleetWise Developer Guide*.","ref":"AWS.IoTFleetWise.html#put_encryption_configuration/3","title":"AWS.IoTFleetWise.put_encryption_configuration/3","type":"function"},{"doc":"Creates or updates the logging option.","ref":"AWS.IoTFleetWise.html#put_logging_options/3","title":"AWS.IoTFleetWise.put_logging_options/3","type":"function"},{"doc":"This API operation contains deprecated parameters.\n\nRegister your account again without the Timestream resources parameter so that\nAmazon Web Services IoT FleetWise can remove the Timestream metadata stored. You\nshould then pass the data destination into the\n[CreateCampaign](https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_CreateCampaign.html) API operation.\n\nYou must delete any existing campaigns that include an empty data destination\nbefore you register your account again. For more information, see the\n[DeleteCampaign](https://docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_DeleteCampaign.html)\nAPI operation.\n\nIf you want to delete the Timestream inline policy from the service-linked role,\nsuch as to mitigate an overly permissive policy, you must first delete any\nexisting campaigns. Then delete the service-linked role and register your\naccount again to enable CloudWatch metrics. For more information, see\n[DeleteServiceLinkedRole](https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeleteServiceLinkedRole.html) in the *Identity and Access Management API Reference*.\n\nRegisters your Amazon Web Services account, IAM, and Amazon Timestream resources\nso Amazon Web Services IoT FleetWise can transfer your vehicle data to the\nAmazon Web Services Cloud. For more information, including step-by-step\nprocedures, see [Setting up Amazon Web Services IoT\nFleetWise](https://docs.aws.amazon.com/iot-fleetwise/latest/developerguide/setting-up.html).\n\nAn Amazon Web Services account is **not** the same thing as a \"user.\" An [Amazon Web Services\nuser](https://docs.aws.amazon.com/IAM/latest/UserGuide/introduction_identity-management.html#intro-identity-users)\nis an identity that you create using Identity and Access Management (IAM) and\ntakes the form of either an [IAM user](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_users.html) or an [IAM role, both with\ncredentials](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles.html). A\nsingle Amazon Web Services account can, and typically does, contain many users\nand roles.","ref":"AWS.IoTFleetWise.html#register_account/3","title":"AWS.IoTFleetWise.register_account/3","type":"function"},{"doc":"Adds to or modifies the tags of the given resource.\n\nTags are metadata which can be used to manage a resource.","ref":"AWS.IoTFleetWise.html#tag_resource/3","title":"AWS.IoTFleetWise.tag_resource/3","type":"function"},{"doc":"Removes the given tags (metadata) from the resource.","ref":"AWS.IoTFleetWise.html#untag_resource/3","title":"AWS.IoTFleetWise.untag_resource/3","type":"function"},{"doc":"Updates a campaign.","ref":"AWS.IoTFleetWise.html#update_campaign/3","title":"AWS.IoTFleetWise.update_campaign/3","type":"function"},{"doc":"Updates a decoder manifest.\n\nA decoder manifest can only be updated when the status is `DRAFT`. Only `ACTIVE`\ndecoder manifests can be associated with vehicles.","ref":"AWS.IoTFleetWise.html#update_decoder_manifest/3","title":"AWS.IoTFleetWise.update_decoder_manifest/3","type":"function"},{"doc":"Updates the description of an existing fleet.\n\nIf the fleet is successfully updated, Amazon Web Services IoT FleetWise sends\nback an HTTP 200 response with an empty HTTP body.","ref":"AWS.IoTFleetWise.html#update_fleet/3","title":"AWS.IoTFleetWise.update_fleet/3","type":"function"},{"doc":"Updates a vehicle model (model manifest).\n\nIf created vehicles are associated with a vehicle model, it can't be updated.","ref":"AWS.IoTFleetWise.html#update_model_manifest/3","title":"AWS.IoTFleetWise.update_model_manifest/3","type":"function"},{"doc":"Updates a signal catalog.","ref":"AWS.IoTFleetWise.html#update_signal_catalog/3","title":"AWS.IoTFleetWise.update_signal_catalog/3","type":"function"},{"doc":"Updates a vehicle.","ref":"AWS.IoTFleetWise.html#update_vehicle/3","title":"AWS.IoTFleetWise.update_vehicle/3","type":"function"},{"doc":"AWS IoT Jobs is a service that allows you to define a set of jobs — remote\noperations that are sent to and executed on one or more devices connected to AWS\nIoT.\n\nFor example, you can define a job that instructs a set of devices to download\nand install application or firmware updates, reboot, rotate certificates, or\nperform remote troubleshooting operations.\n\nTo create a job, you make a job document which is a description of the remote\noperations to be performed, and you specify a list of targets that should\nperform the operations. The targets can be individual things, thing groups or\nboth.\n\nAWS IoT Jobs sends a message to inform the targets that a job is available. The\ntarget starts the execution of the job by downloading the job document,\nperforming the operations it specifies, and reporting its progress to AWS IoT.\nThe Jobs service provides commands to track the progress of a job on a specific\ntarget and for all the targets of the job","ref":"AWS.IoTJobsDataPlane.html","title":"AWS.IoTJobsDataPlane","type":"module"},{"doc":"Gets details of a job execution.","ref":"AWS.IoTJobsDataPlane.html#describe_job_execution/6","title":"AWS.IoTJobsDataPlane.describe_job_execution/6","type":"function"},{"doc":"Gets the list of all jobs for a thing that are not in a terminal status.","ref":"AWS.IoTJobsDataPlane.html#get_pending_job_executions/3","title":"AWS.IoTJobsDataPlane.get_pending_job_executions/3","type":"function"},{"doc":"","ref":"AWS.IoTJobsDataPlane.html#metadata/0","title":"AWS.IoTJobsDataPlane.metadata/0","type":"function"},{"doc":"Gets and starts the next pending (status IN_PROGRESS or QUEUED) job execution\nfor a thing.","ref":"AWS.IoTJobsDataPlane.html#start_next_pending_job_execution/4","title":"AWS.IoTJobsDataPlane.start_next_pending_job_execution/4","type":"function"},{"doc":"Updates the status of a job execution.","ref":"AWS.IoTJobsDataPlane.html#update_job_execution/5","title":"AWS.IoTJobsDataPlane.update_job_execution/5","type":"function"},{"doc":"An example service, deployed with the Octane Service creator, which will echo\nthe string","ref":"AWS.IoTRoboRunner.html","title":"AWS.IoTRoboRunner","type":"module"},{"doc":"Grants permission to create a destination","ref":"AWS.IoTRoboRunner.html#create_destination/3","title":"AWS.IoTRoboRunner.create_destination/3","type":"function"},{"doc":"Grants permission to create a site","ref":"AWS.IoTRoboRunner.html#create_site/3","title":"AWS.IoTRoboRunner.create_site/3","type":"function"},{"doc":"Grants permission to create a worker","ref":"AWS.IoTRoboRunner.html#create_worker/3","title":"AWS.IoTRoboRunner.create_worker/3","type":"function"},{"doc":"Grants permission to create a worker fleet","ref":"AWS.IoTRoboRunner.html#create_worker_fleet/3","title":"AWS.IoTRoboRunner.create_worker_fleet/3","type":"function"},{"doc":"Grants permission to delete a destination","ref":"AWS.IoTRoboRunner.html#delete_destination/3","title":"AWS.IoTRoboRunner.delete_destination/3","type":"function"},{"doc":"Grants permission to delete a site","ref":"AWS.IoTRoboRunner.html#delete_site/3","title":"AWS.IoTRoboRunner.delete_site/3","type":"function"},{"doc":"Grants permission to delete a worker","ref":"AWS.IoTRoboRunner.html#delete_worker/3","title":"AWS.IoTRoboRunner.delete_worker/3","type":"function"},{"doc":"Grants permission to delete a worker fleet","ref":"AWS.IoTRoboRunner.html#delete_worker_fleet/3","title":"AWS.IoTRoboRunner.delete_worker_fleet/3","type":"function"},{"doc":"Grants permission to get a destination","ref":"AWS.IoTRoboRunner.html#get_destination/3","title":"AWS.IoTRoboRunner.get_destination/3","type":"function"},{"doc":"Grants permission to get a site","ref":"AWS.IoTRoboRunner.html#get_site/3","title":"AWS.IoTRoboRunner.get_site/3","type":"function"},{"doc":"Grants permission to get a worker","ref":"AWS.IoTRoboRunner.html#get_worker/3","title":"AWS.IoTRoboRunner.get_worker/3","type":"function"},{"doc":"Grants permission to get a worker fleet","ref":"AWS.IoTRoboRunner.html#get_worker_fleet/3","title":"AWS.IoTRoboRunner.get_worker_fleet/3","type":"function"},{"doc":"Grants permission to list destinations","ref":"AWS.IoTRoboRunner.html#list_destinations/6","title":"AWS.IoTRoboRunner.list_destinations/6","type":"function"},{"doc":"Grants permission to list sites","ref":"AWS.IoTRoboRunner.html#list_sites/4","title":"AWS.IoTRoboRunner.list_sites/4","type":"function"},{"doc":"Grants permission to list worker fleets","ref":"AWS.IoTRoboRunner.html#list_worker_fleets/5","title":"AWS.IoTRoboRunner.list_worker_fleets/5","type":"function"},{"doc":"Grants permission to list workers","ref":"AWS.IoTRoboRunner.html#list_workers/6","title":"AWS.IoTRoboRunner.list_workers/6","type":"function"},{"doc":"","ref":"AWS.IoTRoboRunner.html#metadata/0","title":"AWS.IoTRoboRunner.metadata/0","type":"function"},{"doc":"Grants permission to update a destination","ref":"AWS.IoTRoboRunner.html#update_destination/3","title":"AWS.IoTRoboRunner.update_destination/3","type":"function"},{"doc":"Grants permission to update a site","ref":"AWS.IoTRoboRunner.html#update_site/3","title":"AWS.IoTRoboRunner.update_site/3","type":"function"},{"doc":"Grants permission to update a worker","ref":"AWS.IoTRoboRunner.html#update_worker/3","title":"AWS.IoTRoboRunner.update_worker/3","type":"function"},{"doc":"Grants permission to update a worker fleet","ref":"AWS.IoTRoboRunner.html#update_worker_fleet/3","title":"AWS.IoTRoboRunner.update_worker_fleet/3","type":"function"},{"doc":"IoT Secure Tunneling\n\nIoT Secure Tunneling creates remote connections to devices deployed in the\nfield.\n\nFor more information about how IoT Secure Tunneling works, see [IoT Secure Tunneling](https://docs.aws.amazon.com/iot/latest/developerguide/secure-tunneling.html).","ref":"AWS.IoTSecureTunneling.html","title":"AWS.IoTSecureTunneling","type":"module"},{"doc":"Closes a tunnel identified by the unique tunnel id.\n\nWhen a `CloseTunnel` request is received, we close the WebSocket connections\nbetween the client and proxy server so no data can be transmitted.\n\nRequires permission to access the\n[CloseTunnel](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoTSecureTunneling.html#close_tunnel/3","title":"AWS.IoTSecureTunneling.close_tunnel/3","type":"function"},{"doc":"Gets information about a tunnel identified by the unique tunnel id.\n\nRequires permission to access the\n[DescribeTunnel](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoTSecureTunneling.html#describe_tunnel/3","title":"AWS.IoTSecureTunneling.describe_tunnel/3","type":"function"},{"doc":"Lists the tags for the specified resource.","ref":"AWS.IoTSecureTunneling.html#list_tags_for_resource/3","title":"AWS.IoTSecureTunneling.list_tags_for_resource/3","type":"function"},{"doc":"List all tunnels for an Amazon Web Services account.\n\nTunnels are listed by creation time in descending order, newer tunnels will be\nlisted before older tunnels.\n\nRequires permission to access the\n[ListTunnels](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoTSecureTunneling.html#list_tunnels/3","title":"AWS.IoTSecureTunneling.list_tunnels/3","type":"function"},{"doc":"","ref":"AWS.IoTSecureTunneling.html#metadata/0","title":"AWS.IoTSecureTunneling.metadata/0","type":"function"},{"doc":"Creates a new tunnel, and returns two client access tokens for clients to use to\nconnect to the IoT Secure Tunneling proxy server.\n\nRequires permission to access the\n[OpenTunnel](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IoTSecureTunneling.html#open_tunnel/3","title":"AWS.IoTSecureTunneling.open_tunnel/3","type":"function"},{"doc":"Revokes the current client access token (CAT) and returns new CAT for clients to\nuse when reconnecting to secure tunneling to access the same tunnel.\n\nRequires permission to access the\n[RotateTunnelAccessToken](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.\n\nRotating the CAT doesn't extend the tunnel duration. For example, say the tunnel\nduration is 12 hours and the tunnel has already been open for 4 hours. When you\nrotate the access tokens, the new tokens that are generated can only be used for\nthe remaining 8 hours.","ref":"AWS.IoTSecureTunneling.html#rotate_tunnel_access_token/3","title":"AWS.IoTSecureTunneling.rotate_tunnel_access_token/3","type":"function"},{"doc":"A resource tag.","ref":"AWS.IoTSecureTunneling.html#tag_resource/3","title":"AWS.IoTSecureTunneling.tag_resource/3","type":"function"},{"doc":"Removes a tag from a resource.","ref":"AWS.IoTSecureTunneling.html#untag_resource/3","title":"AWS.IoTSecureTunneling.untag_resource/3","type":"function"},{"doc":"Welcome to the IoT SiteWise API Reference.\n\nIoT SiteWise is an Amazon Web Services service that connects [Industrial Internet of Things\n(IIoT)](https://en.wikipedia.org/wiki/Internet_of_things#Industrial_applications)\ndevices to the power of the Amazon Web Services Cloud. For more information, see\nthe [IoT SiteWise User Guide](https://docs.aws.amazon.com/iot-sitewise/latest/userguide/). For\ninformation about IoT SiteWise quotas, see\n[Quotas](https://docs.aws.amazon.com/iot-sitewise/latest/userguide/quotas.html)\nin the *IoT SiteWise User Guide*.","ref":"AWS.IoTSiteWise.html","title":"AWS.IoTSiteWise","type":"module"},{"doc":"Associates a child asset with the given parent asset through a hierarchy defined\nin the parent asset's model.\n\nFor more information, see [Associating assets](https://docs.aws.amazon.com/iot-sitewise/latest/userguide/add-associated-assets.html)\nin the *IoT SiteWise User Guide*.","ref":"AWS.IoTSiteWise.html#associate_assets/4","title":"AWS.IoTSiteWise.associate_assets/4","type":"function"},{"doc":"Associates a time series (data stream) with an asset property.","ref":"AWS.IoTSiteWise.html#associate_time_series_to_asset_property/3","title":"AWS.IoTSiteWise.associate_time_series_to_asset_property/3","type":"function"},{"doc":"Associates a group (batch) of assets with an IoT SiteWise Monitor project.","ref":"AWS.IoTSiteWise.html#batch_associate_project_assets/4","title":"AWS.IoTSiteWise.batch_associate_project_assets/4","type":"function"},{"doc":"Disassociates a group (batch) of assets from an IoT SiteWise Monitor project.","ref":"AWS.IoTSiteWise.html#batch_disassociate_project_assets/4","title":"AWS.IoTSiteWise.batch_disassociate_project_assets/4","type":"function"},{"doc":"Gets aggregated values (for example, average, minimum, and maximum) for one or\nmore asset properties.\n\nFor more information, see [Querying aggregates](https://docs.aws.amazon.com/iot-sitewise/latest/userguide/query-industrial-data.html#aggregates)\nin the *IoT SiteWise User Guide*.","ref":"AWS.IoTSiteWise.html#batch_get_asset_property_aggregates/3","title":"AWS.IoTSiteWise.batch_get_asset_property_aggregates/3","type":"function"},{"doc":"Gets the current value for one or more asset properties.\n\nFor more information, see [Querying current values](https://docs.aws.amazon.com/iot-sitewise/latest/userguide/query-industrial-data.html#current-values)\nin the *IoT SiteWise User Guide*.","ref":"AWS.IoTSiteWise.html#batch_get_asset_property_value/3","title":"AWS.IoTSiteWise.batch_get_asset_property_value/3","type":"function"},{"doc":"Gets the historical values for one or more asset properties.\n\nFor more information, see [Querying historical values](https://docs.aws.amazon.com/iot-sitewise/latest/userguide/query-industrial-data.html#historical-values)\nin the *IoT SiteWise User Guide*.","ref":"AWS.IoTSiteWise.html#batch_get_asset_property_value_history/3","title":"AWS.IoTSiteWise.batch_get_asset_property_value_history/3","type":"function"},{"doc":"Sends a list of asset property values to IoT SiteWise.\n\nEach value is a timestamp-quality-value (TQV) data point. For more information,\nsee [Ingesting data using the API](https://docs.aws.amazon.com/iot-sitewise/latest/userguide/ingest-api.html)\nin the *IoT SiteWise User Guide*.\n\nTo identify an asset property, you must specify one of the following:\n\n  * The `assetId` and `propertyId` of an asset property.\n\n  * A `propertyAlias`, which is a data stream alias (for example,\n`/company/windfarm/3/turbine/7/temperature`). To define an asset property's\nalias, see\n[UpdateAssetProperty](https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_UpdateAssetProperty.html). \n\nWith respect to Unix epoch time, IoT SiteWise accepts only TQVs that have a\ntimestamp of no more than 7 days in the past and no more than 10 minutes in the\nfuture. IoT SiteWise rejects timestamps outside of the inclusive range of [-7\ndays, +10 minutes] and returns a `TimestampOutOfRangeException` error.\n\nFor each asset property, IoT SiteWise overwrites TQVs with duplicate timestamps\nunless the newer TQV has a different quality. For example, if you store a TQV\n`{T1, GOOD, V1}`, then storing `{T1, GOOD, V2}` replaces the existing TQV.\n\nIoT SiteWise authorizes access to each `BatchPutAssetPropertyValue` entry\nindividually. For more information, see [BatchPutAssetPropertyValue authorization](https://docs.aws.amazon.com/iot-sitewise/latest/userguide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-batchputassetpropertyvalue-action)\nin the *IoT SiteWise User Guide*.","ref":"AWS.IoTSiteWise.html#batch_put_asset_property_value/3","title":"AWS.IoTSiteWise.batch_put_asset_property_value/3","type":"function"},{"doc":"Creates an access policy that grants the specified identity (IAM Identity Center\nuser, IAM Identity Center group, or IAM user) access to the specified IoT\nSiteWise Monitor portal or project resource.","ref":"AWS.IoTSiteWise.html#create_access_policy/3","title":"AWS.IoTSiteWise.create_access_policy/3","type":"function"},{"doc":"Creates an asset from an existing asset model.\n\nFor more information, see [Creating assets](https://docs.aws.amazon.com/iot-sitewise/latest/userguide/create-assets.html)\nin the *IoT SiteWise User Guide*.","ref":"AWS.IoTSiteWise.html#create_asset/3","title":"AWS.IoTSiteWise.create_asset/3","type":"function"},{"doc":"Creates an asset model from specified property and hierarchy definitions.\n\nYou create assets from asset models. With asset models, you can easily create\nassets of the same type that have standardized definitions. Each asset created\nfrom a model inherits the asset model's property and hierarchy definitions. For\nmore information, see [Defining asset models](https://docs.aws.amazon.com/iot-sitewise/latest/userguide/define-models.html)\nin the *IoT SiteWise User Guide*.\n\nYou can create two types of asset models, `ASSET_MODEL` or `COMPONENT_MODEL`.\n\n  * **ASSET_MODEL** – (default) An asset model that you can use to\ncreate assets. Can't be included as a component in another asset model.\n\n  * **COMPONENT_MODEL** – A reusable component that you can include in\nthe composite models of other asset models. You can't create assets directly\nfrom this type of asset model.","ref":"AWS.IoTSiteWise.html#create_asset_model/3","title":"AWS.IoTSiteWise.create_asset_model/3","type":"function"},{"doc":"Creates a custom composite model from specified property and hierarchy\ndefinitions.\n\nThere are two types of custom composite models, `inline` and\n`component-model-based`.\n\nUse component-model-based custom composite models to define standard, reusable\ncomponents. A component-model-based custom composite model consists of a name, a\ndescription, and the ID of the component model it references. A\ncomponent-model-based custom composite model has no properties of its own; its\nreferenced component model provides its associated properties to any created\nassets. For more information, see [Custom composite models (Components)](https://docs.aws.amazon.com/iot-sitewise/latest/userguide/custom-composite-models.html)\nin the *IoT SiteWise User Guide*.\n\nUse inline custom composite models to organize the properties of an asset model.\nThe properties of inline custom composite models are local to the asset model\nwhere they are included and can't be used to create multiple assets.\n\nTo create a component-model-based model, specify the `composedAssetModelId` of\nan existing asset model with `assetModelType` of `COMPONENT_MODEL`.\n\nTo create an inline model, specify the `assetModelCompositeModelProperties` and\ndon't include an `composedAssetModelId`.","ref":"AWS.IoTSiteWise.html#create_asset_model_composite_model/4","title":"AWS.IoTSiteWise.create_asset_model_composite_model/4","type":"function"},{"doc":"Defines a job to ingest data to IoT SiteWise from Amazon S3.\n\nFor more information, see [Create a bulk import job (CLI)](https://docs.aws.amazon.com/iot-sitewise/latest/userguide/CreateBulkImportJob.html)\nin the *Amazon Simple Storage Service User Guide*.\n\nBefore you create a bulk import job, you must enable IoT SiteWise warm tier or\nIoT SiteWise cold tier. For more information about how to configure storage\nsettings, see\n[PutStorageConfiguration](https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_PutStorageConfiguration.html).\n\nBulk import is designed to store historical data to IoT SiteWise. It does not\ntrigger computations or notifications on IoT SiteWise warm or cold tier storage.","ref":"AWS.IoTSiteWise.html#create_bulk_import_job/3","title":"AWS.IoTSiteWise.create_bulk_import_job/3","type":"function"},{"doc":"Creates a dashboard in an IoT SiteWise Monitor project.","ref":"AWS.IoTSiteWise.html#create_dashboard/3","title":"AWS.IoTSiteWise.create_dashboard/3","type":"function"},{"doc":"Creates a gateway, which is a virtual or edge device that delivers industrial\ndata streams from local servers to IoT SiteWise.\n\nFor more information, see [Ingesting data using a gateway](https://docs.aws.amazon.com/iot-sitewise/latest/userguide/gateway-connector.html)\nin the *IoT SiteWise User Guide*.","ref":"AWS.IoTSiteWise.html#create_gateway/3","title":"AWS.IoTSiteWise.create_gateway/3","type":"function"},{"doc":"Creates a portal, which can contain projects and dashboards.\n\nIoT SiteWise Monitor uses IAM Identity Center or IAM to authenticate portal\nusers and manage user permissions.\n\nBefore you can sign in to a new portal, you must add at least one identity to\nthat portal. For more information, see [Adding or removing portal administrators](https://docs.aws.amazon.com/iot-sitewise/latest/userguide/administer-portals.html#portal-change-admins)\nin the *IoT SiteWise User Guide*.","ref":"AWS.IoTSiteWise.html#create_portal/3","title":"AWS.IoTSiteWise.create_portal/3","type":"function"},{"doc":"Creates a project in the specified portal.\n\nMake sure that the project name and description don't contain confidential\ninformation.","ref":"AWS.IoTSiteWise.html#create_project/3","title":"AWS.IoTSiteWise.create_project/3","type":"function"},{"doc":"Deletes an access policy that grants the specified identity access to the\nspecified IoT SiteWise Monitor resource.\n\nYou can use this operation to revoke access to an IoT SiteWise Monitor resource.","ref":"AWS.IoTSiteWise.html#delete_access_policy/4","title":"AWS.IoTSiteWise.delete_access_policy/4","type":"function"},{"doc":"Deletes an asset.\n\nThis action can't be undone. For more information, see [Deleting assets and models](https://docs.aws.amazon.com/iot-sitewise/latest/userguide/delete-assets-and-models.html)\nin the *IoT SiteWise User Guide*.\n\nYou can't delete an asset that's associated to another asset. For more\ninformation, see\n[DisassociateAssets](https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DisassociateAssets.html).","ref":"AWS.IoTSiteWise.html#delete_asset/4","title":"AWS.IoTSiteWise.delete_asset/4","type":"function"},{"doc":"Deletes an asset model.\n\nThis action can't be undone. You must delete all assets created from an asset\nmodel before you can delete the model. Also, you can't delete an asset model if\na parent asset model exists that contains a property formula expression that\ndepends on the asset model that you want to delete. For more information, see\n[Deleting assets and models](https://docs.aws.amazon.com/iot-sitewise/latest/userguide/delete-assets-and-models.html)\nin the *IoT SiteWise User Guide*.","ref":"AWS.IoTSiteWise.html#delete_asset_model/4","title":"AWS.IoTSiteWise.delete_asset_model/4","type":"function"},{"doc":"Deletes a composite model.\n\nThis action can't be undone. You must delete all assets created from a composite\nmodel before you can delete the model. Also, you can't delete a composite model\nif a parent asset model exists that contains a property formula expression that\ndepends on the asset model that you want to delete. For more information, see\n[Deleting assets and models](https://docs.aws.amazon.com/iot-sitewise/latest/userguide/delete-assets-and-models.html)\nin the *IoT SiteWise User Guide*.","ref":"AWS.IoTSiteWise.html#delete_asset_model_composite_model/5","title":"AWS.IoTSiteWise.delete_asset_model_composite_model/5","type":"function"},{"doc":"Deletes a dashboard from IoT SiteWise Monitor.","ref":"AWS.IoTSiteWise.html#delete_dashboard/4","title":"AWS.IoTSiteWise.delete_dashboard/4","type":"function"},{"doc":"Deletes a gateway from IoT SiteWise.\n\nWhen you delete a gateway, some of the gateway's files remain in your gateway's\nfile system.","ref":"AWS.IoTSiteWise.html#delete_gateway/4","title":"AWS.IoTSiteWise.delete_gateway/4","type":"function"},{"doc":"Deletes a portal from IoT SiteWise Monitor.","ref":"AWS.IoTSiteWise.html#delete_portal/4","title":"AWS.IoTSiteWise.delete_portal/4","type":"function"},{"doc":"Deletes a project from IoT SiteWise Monitor.","ref":"AWS.IoTSiteWise.html#delete_project/4","title":"AWS.IoTSiteWise.delete_project/4","type":"function"},{"doc":"Deletes a time series (data stream).\n\nIf you delete a time series that's associated with an asset property, the asset\nproperty still exists, but the time series will no longer be associated with\nthis asset property.\n\nTo identify a time series, do one of the following:\n\n  * If the time series isn't associated with an asset property,\nspecify the `alias` of the time series.\n\n  * If the time series is associated with an asset property, specify\none of the following:\n\n    * The `alias` of the time series.\n\n    * The `assetId` and `propertyId` that identifies the\nasset property.","ref":"AWS.IoTSiteWise.html#delete_time_series/3","title":"AWS.IoTSiteWise.delete_time_series/3","type":"function"},{"doc":"Describes an access policy, which specifies an identity's access to an IoT\nSiteWise Monitor portal or project.","ref":"AWS.IoTSiteWise.html#describe_access_policy/3","title":"AWS.IoTSiteWise.describe_access_policy/3","type":"function"},{"doc":"Retrieves information about an action.","ref":"AWS.IoTSiteWise.html#describe_action/3","title":"AWS.IoTSiteWise.describe_action/3","type":"function"},{"doc":"Retrieves information about an asset.","ref":"AWS.IoTSiteWise.html#describe_asset/4","title":"AWS.IoTSiteWise.describe_asset/4","type":"function"},{"doc":"Retrieves information about an asset composite model (also known as an asset\ncomponent).\n\nAn `AssetCompositeModel` is an instance of an `AssetModelCompositeModel`. If you\nwant to see information about the model this is based on, call\n[DescribeAssetModelCompositeModel](https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DescribeAssetModelCompositeModel.html).","ref":"AWS.IoTSiteWise.html#describe_asset_composite_model/4","title":"AWS.IoTSiteWise.describe_asset_composite_model/4","type":"function"},{"doc":"Retrieves information about an asset model.","ref":"AWS.IoTSiteWise.html#describe_asset_model/4","title":"AWS.IoTSiteWise.describe_asset_model/4","type":"function"},{"doc":"Retrieves information about an asset model composite model (also known as an\nasset model component).\n\nFor more information, see [Custom composite models (Components)](https://docs.aws.amazon.com/iot-sitewise/latest/userguide/custom-composite-models.html)\nin the *IoT SiteWise User Guide*.","ref":"AWS.IoTSiteWise.html#describe_asset_model_composite_model/4","title":"AWS.IoTSiteWise.describe_asset_model_composite_model/4","type":"function"},{"doc":"Retrieves information about an asset property.\n\nWhen you call this operation for an attribute property, this response includes\nthe default attribute value that you define in the asset model. If you update\nthe default value in the model, this operation's response includes the new\ndefault value.\n\nThis operation doesn't return the value of the asset property. To get the value\nof an asset property, use\n[GetAssetPropertyValue](https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_GetAssetPropertyValue.html).","ref":"AWS.IoTSiteWise.html#describe_asset_property/4","title":"AWS.IoTSiteWise.describe_asset_property/4","type":"function"},{"doc":"Retrieves information about a bulk import job request.\n\nFor more information, see [Describe a bulk import job (CLI)](https://docs.aws.amazon.com/iot-sitewise/latest/userguide/DescribeBulkImportJob.html)\nin the *Amazon Simple Storage Service User Guide*.","ref":"AWS.IoTSiteWise.html#describe_bulk_import_job/3","title":"AWS.IoTSiteWise.describe_bulk_import_job/3","type":"function"},{"doc":"Retrieves information about a dashboard.","ref":"AWS.IoTSiteWise.html#describe_dashboard/3","title":"AWS.IoTSiteWise.describe_dashboard/3","type":"function"},{"doc":"Retrieves information about the default encryption configuration for the Amazon\nWeb Services account in the default or specified Region.\n\nFor more information, see [Key management](https://docs.aws.amazon.com/iot-sitewise/latest/userguide/key-management.html)\nin the *IoT SiteWise User Guide*.","ref":"AWS.IoTSiteWise.html#describe_default_encryption_configuration/2","title":"AWS.IoTSiteWise.describe_default_encryption_configuration/2","type":"function"},{"doc":"Retrieves information about a gateway.","ref":"AWS.IoTSiteWise.html#describe_gateway/3","title":"AWS.IoTSiteWise.describe_gateway/3","type":"function"},{"doc":"Retrieves information about a gateway capability configuration.\n\nEach gateway capability defines data sources for a gateway. A capability\nconfiguration can contain multiple data source configurations. If you define\nOPC-UA sources for a gateway in the IoT SiteWise console, all of your OPC-UA\nsources are stored in one capability configuration. To list all capability\nconfigurations for a gateway, use\n[DescribeGateway](https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DescribeGateway.html).","ref":"AWS.IoTSiteWise.html#describe_gateway_capability_configuration/4","title":"AWS.IoTSiteWise.describe_gateway_capability_configuration/4","type":"function"},{"doc":"Retrieves the current IoT SiteWise logging options.","ref":"AWS.IoTSiteWise.html#describe_logging_options/2","title":"AWS.IoTSiteWise.describe_logging_options/2","type":"function"},{"doc":"Retrieves information about a portal.","ref":"AWS.IoTSiteWise.html#describe_portal/3","title":"AWS.IoTSiteWise.describe_portal/3","type":"function"},{"doc":"Retrieves information about a project.","ref":"AWS.IoTSiteWise.html#describe_project/3","title":"AWS.IoTSiteWise.describe_project/3","type":"function"},{"doc":"Retrieves information about the storage configuration for IoT SiteWise.","ref":"AWS.IoTSiteWise.html#describe_storage_configuration/2","title":"AWS.IoTSiteWise.describe_storage_configuration/2","type":"function"},{"doc":"Retrieves information about a time series (data stream).\n\nTo identify a time series, do one of the following:\n\n  * If the time series isn't associated with an asset property,\nspecify the `alias` of the time series.\n\n  * If the time series is associated with an asset property, specify\none of the following:\n\n    * The `alias` of the time series.\n\n    * The `assetId` and `propertyId` that identifies the\nasset property.","ref":"AWS.IoTSiteWise.html#describe_time_series/5","title":"AWS.IoTSiteWise.describe_time_series/5","type":"function"},{"doc":"Disassociates a child asset from the given parent asset through a hierarchy\ndefined in the parent asset's model.","ref":"AWS.IoTSiteWise.html#disassociate_assets/4","title":"AWS.IoTSiteWise.disassociate_assets/4","type":"function"},{"doc":"Disassociates a time series (data stream) from an asset property.","ref":"AWS.IoTSiteWise.html#disassociate_time_series_from_asset_property/3","title":"AWS.IoTSiteWise.disassociate_time_series_from_asset_property/3","type":"function"},{"doc":"Executes an action on a target resource.","ref":"AWS.IoTSiteWise.html#execute_action/3","title":"AWS.IoTSiteWise.execute_action/3","type":"function"},{"doc":"Run SQL queries to retrieve metadata and time-series data from asset models,\nassets, measurements, metrics, transforms, and aggregates.","ref":"AWS.IoTSiteWise.html#execute_query/3","title":"AWS.IoTSiteWise.execute_query/3","type":"function"},{"doc":"Gets aggregated values for an asset property.\n\nFor more information, see [Querying aggregates](https://docs.aws.amazon.com/iot-sitewise/latest/userguide/query-industrial-data.html#aggregates)\nin the *IoT SiteWise User Guide*.\n\nTo identify an asset property, you must specify one of the following:\n\n  * The `assetId` and `propertyId` of an asset property.\n\n  * A `propertyAlias`, which is a data stream alias (for example,\n`/company/windfarm/3/turbine/7/temperature`). To define an asset property's\nalias, see\n[UpdateAssetProperty](https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_UpdateAssetProperty.html).","ref":"AWS.IoTSiteWise.html#get_asset_property_aggregates/13","title":"AWS.IoTSiteWise.get_asset_property_aggregates/13","type":"function"},{"doc":"Gets an asset property's current value.\n\nFor more information, see [Querying current values](https://docs.aws.amazon.com/iot-sitewise/latest/userguide/query-industrial-data.html#current-values)\nin the *IoT SiteWise User Guide*.\n\nTo identify an asset property, you must specify one of the following:\n\n  * The `assetId` and `propertyId` of an asset property.\n\n  * A `propertyAlias`, which is a data stream alias (for example,\n`/company/windfarm/3/turbine/7/temperature`). To define an asset property's\nalias, see\n[UpdateAssetProperty](https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_UpdateAssetProperty.html).","ref":"AWS.IoTSiteWise.html#get_asset_property_value/5","title":"AWS.IoTSiteWise.get_asset_property_value/5","type":"function"},{"doc":"Gets the history of an asset property's values.\n\nFor more information, see [Querying historical values](https://docs.aws.amazon.com/iot-sitewise/latest/userguide/query-industrial-data.html#historical-values)\nin the *IoT SiteWise User Guide*.\n\nTo identify an asset property, you must specify one of the following:\n\n  * The `assetId` and `propertyId` of an asset property.\n\n  * A `propertyAlias`, which is a data stream alias (for example,\n`/company/windfarm/3/turbine/7/temperature`). To define an asset property's\nalias, see\n[UpdateAssetProperty](https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_UpdateAssetProperty.html).","ref":"AWS.IoTSiteWise.html#get_asset_property_value_history/11","title":"AWS.IoTSiteWise.get_asset_property_value_history/11","type":"function"},{"doc":"Get interpolated values for an asset property for a specified time interval,\nduring a period of time.\n\nIf your time series is missing data points during the specified time interval,\nyou can use interpolation to estimate the missing data.\n\nFor example, you can use this operation to return the interpolated temperature\nvalues for a wind turbine every 24 hours over a duration of 7 days.\n\nTo identify an asset property, you must specify one of the following:\n\n  * The `assetId` and `propertyId` of an asset property.\n\n  * A `propertyAlias`, which is a data stream alias (for example,\n`/company/windfarm/3/turbine/7/temperature`). To define an asset property's\nalias, see\n[UpdateAssetProperty](https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_UpdateAssetProperty.html).","ref":"AWS.IoTSiteWise.html#get_interpolated_asset_property_values/15","title":"AWS.IoTSiteWise.get_interpolated_asset_property_values/15","type":"function"},{"doc":"Retrieves a paginated list of access policies for an identity (an IAM Identity\nCenter user, an IAM Identity Center group, or an IAM user) or an IoT SiteWise\nMonitor resource (a portal or project).","ref":"AWS.IoTSiteWise.html#list_access_policies/9","title":"AWS.IoTSiteWise.list_access_policies/9","type":"function"},{"doc":"Retrieves a paginated list of actions for a specific target resource.","ref":"AWS.IoTSiteWise.html#list_actions/6","title":"AWS.IoTSiteWise.list_actions/6","type":"function"},{"doc":"Retrieves a paginated list of composite models associated with the asset model","ref":"AWS.IoTSiteWise.html#list_asset_model_composite_models/5","title":"AWS.IoTSiteWise.list_asset_model_composite_models/5","type":"function"},{"doc":"Retrieves a paginated list of properties associated with an asset model.\n\nIf you update properties associated with the model before you finish listing all\nthe properties, you need to start all over again.","ref":"AWS.IoTSiteWise.html#list_asset_model_properties/6","title":"AWS.IoTSiteWise.list_asset_model_properties/6","type":"function"},{"doc":"Retrieves a paginated list of summaries of all asset models.","ref":"AWS.IoTSiteWise.html#list_asset_models/5","title":"AWS.IoTSiteWise.list_asset_models/5","type":"function"},{"doc":"Retrieves a paginated list of properties associated with an asset.\n\nIf you update properties associated with the model before you finish listing all\nthe properties, you need to start all over again.","ref":"AWS.IoTSiteWise.html#list_asset_properties/6","title":"AWS.IoTSiteWise.list_asset_properties/6","type":"function"},{"doc":"Retrieves a paginated list of asset relationships for an asset.\n\nYou can use this operation to identify an asset's root asset and all associated\nassets between that asset and its root.","ref":"AWS.IoTSiteWise.html#list_asset_relationships/6","title":"AWS.IoTSiteWise.list_asset_relationships/6","type":"function"},{"doc":"Retrieves a paginated list of asset summaries.\n\nYou can use this operation to do the following:\n\n  * List assets based on a specific asset model.\n\n  * List top-level assets.\n\nYou can't use this operation to list all assets. To retrieve summaries for all\nof your assets, use\n[ListAssetModels](https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_ListAssetModels.html)\nto get all of your asset model IDs. Then, use ListAssets to get all assets for\neach asset model.","ref":"AWS.IoTSiteWise.html#list_assets/6","title":"AWS.IoTSiteWise.list_assets/6","type":"function"},{"doc":"Retrieves a paginated list of associated assets.\n\nYou can use this operation to do the following:\n\n  * List child assets associated to a parent asset by a hierarchy that\nyou specify.\n\n  * List an asset's parent asset.","ref":"AWS.IoTSiteWise.html#list_associated_assets/7","title":"AWS.IoTSiteWise.list_associated_assets/7","type":"function"},{"doc":"Retrieves a paginated list of bulk import job requests.\n\nFor more information, see [List bulk import jobs (CLI)](https://docs.aws.amazon.com/iot-sitewise/latest/userguide/ListBulkImportJobs.html)\nin the *IoT SiteWise User Guide*.","ref":"AWS.IoTSiteWise.html#list_bulk_import_jobs/5","title":"AWS.IoTSiteWise.list_bulk_import_jobs/5","type":"function"},{"doc":"Retrieves a paginated list of composition relationships for an asset model of\ntype `COMPONENT_MODEL`.","ref":"AWS.IoTSiteWise.html#list_composition_relationships/5","title":"AWS.IoTSiteWise.list_composition_relationships/5","type":"function"},{"doc":"Retrieves a paginated list of dashboards for an IoT SiteWise Monitor project.","ref":"AWS.IoTSiteWise.html#list_dashboards/5","title":"AWS.IoTSiteWise.list_dashboards/5","type":"function"},{"doc":"Retrieves a paginated list of gateways.","ref":"AWS.IoTSiteWise.html#list_gateways/4","title":"AWS.IoTSiteWise.list_gateways/4","type":"function"},{"doc":"Retrieves a paginated list of IoT SiteWise Monitor portals.","ref":"AWS.IoTSiteWise.html#list_portals/4","title":"AWS.IoTSiteWise.list_portals/4","type":"function"},{"doc":"Retrieves a paginated list of assets associated with an IoT SiteWise Monitor\nproject.","ref":"AWS.IoTSiteWise.html#list_project_assets/5","title":"AWS.IoTSiteWise.list_project_assets/5","type":"function"},{"doc":"Retrieves a paginated list of projects for an IoT SiteWise Monitor portal.","ref":"AWS.IoTSiteWise.html#list_projects/5","title":"AWS.IoTSiteWise.list_projects/5","type":"function"},{"doc":"Retrieves the list of tags for an IoT SiteWise resource.","ref":"AWS.IoTSiteWise.html#list_tags_for_resource/3","title":"AWS.IoTSiteWise.list_tags_for_resource/3","type":"function"},{"doc":"Retrieves a paginated list of time series (data streams).","ref":"AWS.IoTSiteWise.html#list_time_series/7","title":"AWS.IoTSiteWise.list_time_series/7","type":"function"},{"doc":"","ref":"AWS.IoTSiteWise.html#metadata/0","title":"AWS.IoTSiteWise.metadata/0","type":"function"},{"doc":"Sets the default encryption configuration for the Amazon Web Services account.\n\nFor more information, see [Key management](https://docs.aws.amazon.com/iot-sitewise/latest/userguide/key-management.html)\nin the *IoT SiteWise User Guide*.","ref":"AWS.IoTSiteWise.html#put_default_encryption_configuration/3","title":"AWS.IoTSiteWise.put_default_encryption_configuration/3","type":"function"},{"doc":"Sets logging options for IoT SiteWise.","ref":"AWS.IoTSiteWise.html#put_logging_options/3","title":"AWS.IoTSiteWise.put_logging_options/3","type":"function"},{"doc":"Configures storage settings for IoT SiteWise.","ref":"AWS.IoTSiteWise.html#put_storage_configuration/3","title":"AWS.IoTSiteWise.put_storage_configuration/3","type":"function"},{"doc":"Adds tags to an IoT SiteWise resource.\n\nIf a tag already exists for the resource, this operation updates the tag's\nvalue.","ref":"AWS.IoTSiteWise.html#tag_resource/3","title":"AWS.IoTSiteWise.tag_resource/3","type":"function"},{"doc":"Removes a tag from an IoT SiteWise resource.","ref":"AWS.IoTSiteWise.html#untag_resource/3","title":"AWS.IoTSiteWise.untag_resource/3","type":"function"},{"doc":"Updates an existing access policy that specifies an identity's access to an IoT\nSiteWise Monitor portal or project resource.","ref":"AWS.IoTSiteWise.html#update_access_policy/4","title":"AWS.IoTSiteWise.update_access_policy/4","type":"function"},{"doc":"Updates an asset's name.\n\nFor more information, see [Updating assets and models](https://docs.aws.amazon.com/iot-sitewise/latest/userguide/update-assets-and-models.html)\nin the *IoT SiteWise User Guide*.","ref":"AWS.IoTSiteWise.html#update_asset/4","title":"AWS.IoTSiteWise.update_asset/4","type":"function"},{"doc":"Updates an asset model and all of the assets that were created from the model.\n\nEach asset created from the model inherits the updated asset model's property\nand hierarchy definitions. For more information, see [Updating assets and models](https://docs.aws.amazon.com/iot-sitewise/latest/userguide/update-assets-and-models.html)\nin the *IoT SiteWise User Guide*.\n\nThis operation overwrites the existing model with the provided model. To avoid\ndeleting your asset model's properties or hierarchies, you must include their\nIDs and definitions in the updated asset model payload. For more information,\nsee\n[DescribeAssetModel](https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DescribeAssetModel.html).\n\nIf you remove a property from an asset model, IoT SiteWise deletes all previous\ndata for that property. If you remove a hierarchy definition from an asset\nmodel, IoT SiteWise disassociates every asset associated with that hierarchy.\nYou can't change the type or data type of an existing property.","ref":"AWS.IoTSiteWise.html#update_asset_model/4","title":"AWS.IoTSiteWise.update_asset_model/4","type":"function"},{"doc":"Updates a composite model and all of the assets that were created from the\nmodel.\n\nEach asset created from the model inherits the updated asset model's property\nand hierarchy definitions. For more information, see [Updating assets and models](https://docs.aws.amazon.com/iot-sitewise/latest/userguide/update-assets-and-models.html)\nin the *IoT SiteWise User Guide*.\n\nIf you remove a property from a composite asset model, IoT SiteWise deletes all\nprevious data for that property. You can’t change the type or data type of an\nexisting property.\n\nTo replace an existing composite asset model property with a new one with the\nsame `name`, do the following:\n\n   Submit an `UpdateAssetModelCompositeModel` request with the entire\nexisting property removed.\n\n   Submit a second `UpdateAssetModelCompositeModel` request that\nincludes the new property. The new asset property will have the same `name` as\nthe previous one and IoT SiteWise will generate a new unique `id`.","ref":"AWS.IoTSiteWise.html#update_asset_model_composite_model/5","title":"AWS.IoTSiteWise.update_asset_model_composite_model/5","type":"function"},{"doc":"Updates an asset property's alias and notification state.\n\nThis operation overwrites the property's existing alias and notification state.\nTo keep your existing property's alias or notification state, you must include\nthe existing values in the UpdateAssetProperty request. For more information,\nsee\n[DescribeAssetProperty](https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DescribeAssetProperty.html).","ref":"AWS.IoTSiteWise.html#update_asset_property/5","title":"AWS.IoTSiteWise.update_asset_property/5","type":"function"},{"doc":"Updates an IoT SiteWise Monitor dashboard.","ref":"AWS.IoTSiteWise.html#update_dashboard/4","title":"AWS.IoTSiteWise.update_dashboard/4","type":"function"},{"doc":"Updates a gateway's name.","ref":"AWS.IoTSiteWise.html#update_gateway/4","title":"AWS.IoTSiteWise.update_gateway/4","type":"function"},{"doc":"Updates a gateway capability configuration or defines a new capability\nconfiguration.\n\nEach gateway capability defines data sources for a gateway. A capability\nconfiguration can contain multiple data source configurations. If you define\nOPC-UA sources for a gateway in the IoT SiteWise console, all of your OPC-UA\nsources are stored in one capability configuration. To list all capability\nconfigurations for a gateway, use\n[DescribeGateway](https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DescribeGateway.html).","ref":"AWS.IoTSiteWise.html#update_gateway_capability_configuration/4","title":"AWS.IoTSiteWise.update_gateway_capability_configuration/4","type":"function"},{"doc":"Updates an IoT SiteWise Monitor portal.","ref":"AWS.IoTSiteWise.html#update_portal/4","title":"AWS.IoTSiteWise.update_portal/4","type":"function"},{"doc":"Updates an IoT SiteWise Monitor project.","ref":"AWS.IoTSiteWise.html#update_project/4","title":"AWS.IoTSiteWise.update_project/4","type":"function"},{"doc":"AWS IoT Things Graph\n\nAWS IoT Things Graph provides an integrated set of tools that enable developers\nto connect devices and services that use different standards, such as units of\nmeasure and communication protocols.\n\nAWS IoT Things Graph makes it possible to build IoT applications with little to\nno code by connecting devices and services and defining how they interact at an\nabstract level.\n\nFor more information about how AWS IoT Things Graph works, see the [User Guide](https://docs.aws.amazon.com/thingsgraph/latest/ug/iot-tg-whatis.html).\n\nThe AWS IoT Things Graph service is discontinued.","ref":"AWS.IoTThingsGraph.html","title":"AWS.IoTThingsGraph","type":"module"},{"doc":"Associates a device with a concrete thing that is in the user's registry.\n\nA thing can be associated with only one device at a time. If you associate a\nthing with a new device id, its previous association will be removed.","ref":"AWS.IoTThingsGraph.html#associate_entity_to_thing/3","title":"AWS.IoTThingsGraph.associate_entity_to_thing/3","type":"function"},{"doc":"Creates a workflow template.\n\nWorkflows can be created only in the user's namespace. (The public namespace\ncontains only entities.) The workflow can contain only entities in the specified\nnamespace. The workflow is validated against the entities in the latest version\nof the user's namespace unless another namespace version is specified in the\nrequest.","ref":"AWS.IoTThingsGraph.html#create_flow_template/3","title":"AWS.IoTThingsGraph.create_flow_template/3","type":"function"},{"doc":"Creates a system instance.\n\nThis action validates the system instance, prepares the deployment-related\nresources. For Greengrass deployments, it updates the Greengrass group that is\nspecified by the `greengrassGroupName` parameter. It also adds a file to the S3\nbucket specified by the `s3BucketName` parameter. You need to call\n`DeploySystemInstance` after running this action.\n\nFor Greengrass deployments, since this action modifies and adds resources to a\nGreengrass group and an S3 bucket on the caller's behalf, the calling identity\nmust have write permissions to both the specified Greengrass group and S3\nbucket. Otherwise, the call will fail with an authorization error.\n\nFor cloud deployments, this action requires a `flowActionsRoleArn` value. This\nis an IAM role that has permissions to access AWS services, such as AWS Lambda\nand AWS IoT, that the flow uses when it executes.\n\nIf the definition document doesn't specify a version of the user's namespace,\nthe latest version will be used by default.","ref":"AWS.IoTThingsGraph.html#create_system_instance/3","title":"AWS.IoTThingsGraph.create_system_instance/3","type":"function"},{"doc":"Creates a system.\n\nThe system is validated against the entities in the latest version of the user's\nnamespace unless another namespace version is specified in the request.","ref":"AWS.IoTThingsGraph.html#create_system_template/3","title":"AWS.IoTThingsGraph.create_system_template/3","type":"function"},{"doc":"Deletes a workflow.\n\nAny new system or deployment that contains this workflow will fail to update or\ndeploy. Existing deployments that contain the workflow will continue to run\n(since they use a snapshot of the workflow taken at the time of deployment).","ref":"AWS.IoTThingsGraph.html#delete_flow_template/3","title":"AWS.IoTThingsGraph.delete_flow_template/3","type":"function"},{"doc":"Deletes the specified namespace.\n\nThis action deletes all of the entities in the namespace. Delete the systems and\nflows that use entities in the namespace before performing this action. This\naction takes no request parameters.","ref":"AWS.IoTThingsGraph.html#delete_namespace/3","title":"AWS.IoTThingsGraph.delete_namespace/3","type":"function"},{"doc":"Deletes a system instance.\n\nOnly system instances that have never been deployed, or that have been\nundeployed can be deleted.\n\nUsers can create a new system instance that has the same ID as a deleted system\ninstance.","ref":"AWS.IoTThingsGraph.html#delete_system_instance/3","title":"AWS.IoTThingsGraph.delete_system_instance/3","type":"function"},{"doc":"Deletes a system.\n\nNew deployments can't contain the system after its deletion. Existing\ndeployments that contain the system will continue to work because they use a\nsnapshot of the system that is taken when it is deployed.","ref":"AWS.IoTThingsGraph.html#delete_system_template/3","title":"AWS.IoTThingsGraph.delete_system_template/3","type":"function"},{"doc":"","ref":"AWS.IoTThingsGraph.html#deploy_system_instance/3","title":"AWS.IoTThingsGraph.deploy_system_instance/3","type":"function"},{"doc":"Deploys the system instance to the target specified in `CreateSystemInstance`.","ref":"AWS.IoTThingsGraph.html#deploy_system_instance/3-greengrass-and-cloud-deployments","title":"Greengrass and Cloud Deployments - AWS.IoTThingsGraph.deploy_system_instance/3","type":"function"},{"doc":"If the system or any workflows and entities have been updated before this action\nis called, then the deployment will create a new Amazon Simple Storage Service\nresource file and then deploy it.\n\nSince this action creates a Greengrass deployment on the caller's behalf, the\ncalling identity must have write permissions to the specified Greengrass group.\nOtherwise, the call will fail with an authorization error.\n\nFor information about the artifacts that get added to your Greengrass core\ndevice when you use this API, see [AWS IoT Things Graph and AWS IoT Greengrass](https://docs.aws.amazon.com/thingsgraph/latest/ug/iot-tg-greengrass.html).","ref":"AWS.IoTThingsGraph.html#deploy_system_instance/3-greengrass-deployments","title":"Greengrass Deployments - AWS.IoTThingsGraph.deploy_system_instance/3","type":"function"},{"doc":"Deprecates the specified workflow.\n\nThis action marks the workflow for deletion. Deprecated flows can't be deployed,\nbut existing deployments will continue to run.","ref":"AWS.IoTThingsGraph.html#deprecate_flow_template/3","title":"AWS.IoTThingsGraph.deprecate_flow_template/3","type":"function"},{"doc":"Deprecates the specified system.","ref":"AWS.IoTThingsGraph.html#deprecate_system_template/3","title":"AWS.IoTThingsGraph.deprecate_system_template/3","type":"function"},{"doc":"Gets the latest version of the user's namespace and the public version that it\nis tracking.","ref":"AWS.IoTThingsGraph.html#describe_namespace/3","title":"AWS.IoTThingsGraph.describe_namespace/3","type":"function"},{"doc":"Dissociates a device entity from a concrete thing.\n\nThe action takes only the type of the entity that you need to dissociate because\nonly one entity of a particular type can be associated with a thing.","ref":"AWS.IoTThingsGraph.html#dissociate_entity_from_thing/3","title":"AWS.IoTThingsGraph.dissociate_entity_from_thing/3","type":"function"},{"doc":"Gets definitions of the specified entities.\n\nUses the latest version of the user's namespace by default. This API returns the\nfollowing TDM entities.\n\n  * Properties\n\n  * States\n\n  * Events\n\n  * Actions\n\n  * Capabilities\n\n  * Mappings\n\n  * Devices\n\n  * Device Models\n\n  * Services\n\nThis action doesn't return definitions for systems, flows, and deployments.","ref":"AWS.IoTThingsGraph.html#get_entities/3","title":"AWS.IoTThingsGraph.get_entities/3","type":"function"},{"doc":"Gets the latest version of the `DefinitionDocument` and `FlowTemplateSummary`\nfor the specified workflow.","ref":"AWS.IoTThingsGraph.html#get_flow_template/3","title":"AWS.IoTThingsGraph.get_flow_template/3","type":"function"},{"doc":"Gets revisions of the specified workflow.\n\nOnly the last 100 revisions are stored. If the workflow has been deprecated,\nthis action will return revisions that occurred before the deprecation. This\naction won't work for workflows that have been deleted.","ref":"AWS.IoTThingsGraph.html#get_flow_template_revisions/3","title":"AWS.IoTThingsGraph.get_flow_template_revisions/3","type":"function"},{"doc":"Gets the status of a namespace deletion task.","ref":"AWS.IoTThingsGraph.html#get_namespace_deletion_status/3","title":"AWS.IoTThingsGraph.get_namespace_deletion_status/3","type":"function"},{"doc":"Gets a system instance.","ref":"AWS.IoTThingsGraph.html#get_system_instance/3","title":"AWS.IoTThingsGraph.get_system_instance/3","type":"function"},{"doc":"Gets a system.","ref":"AWS.IoTThingsGraph.html#get_system_template/3","title":"AWS.IoTThingsGraph.get_system_template/3","type":"function"},{"doc":"Gets revisions made to the specified system template.\n\nOnly the previous 100 revisions are stored. If the system has been deprecated,\nthis action will return the revisions that occurred before its deprecation. This\naction won't work with systems that have been deleted.","ref":"AWS.IoTThingsGraph.html#get_system_template_revisions/3","title":"AWS.IoTThingsGraph.get_system_template_revisions/3","type":"function"},{"doc":"Gets the status of the specified upload.","ref":"AWS.IoTThingsGraph.html#get_upload_status/3","title":"AWS.IoTThingsGraph.get_upload_status/3","type":"function"},{"doc":"Returns a list of objects that contain information about events in a flow\nexecution.","ref":"AWS.IoTThingsGraph.html#list_flow_execution_messages/3","title":"AWS.IoTThingsGraph.list_flow_execution_messages/3","type":"function"},{"doc":"Lists all tags on an AWS IoT Things Graph resource.","ref":"AWS.IoTThingsGraph.html#list_tags_for_resource/3","title":"AWS.IoTThingsGraph.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.IoTThingsGraph.html#metadata/0","title":"AWS.IoTThingsGraph.metadata/0","type":"function"},{"doc":"Searches for entities of the specified type.\n\nYou can search for entities in your namespace and the public namespace that\nyou're tracking.","ref":"AWS.IoTThingsGraph.html#search_entities/3","title":"AWS.IoTThingsGraph.search_entities/3","type":"function"},{"doc":"Searches for AWS IoT Things Graph workflow execution instances.","ref":"AWS.IoTThingsGraph.html#search_flow_executions/3","title":"AWS.IoTThingsGraph.search_flow_executions/3","type":"function"},{"doc":"Searches for summary information about workflows.","ref":"AWS.IoTThingsGraph.html#search_flow_templates/3","title":"AWS.IoTThingsGraph.search_flow_templates/3","type":"function"},{"doc":"Searches for system instances in the user's account.","ref":"AWS.IoTThingsGraph.html#search_system_instances/3","title":"AWS.IoTThingsGraph.search_system_instances/3","type":"function"},{"doc":"Searches for summary information about systems in the user's account.\n\nYou can filter by the ID of a workflow to return only systems that use the\nspecified workflow.","ref":"AWS.IoTThingsGraph.html#search_system_templates/3","title":"AWS.IoTThingsGraph.search_system_templates/3","type":"function"},{"doc":"Searches for things associated with the specified entity.\n\nYou can search by both device and device model.\n\nFor example, if two different devices, camera1 and camera2, implement the camera\ndevice model, the user can associate thing1 to camera1 and thing2 to camera2.\n`SearchThings(camera2)` will return only thing2, but `SearchThings(camera)` will\nreturn both thing1 and thing2.\n\nThis action searches for exact matches and doesn't perform partial text\nmatching.","ref":"AWS.IoTThingsGraph.html#search_things/3","title":"AWS.IoTThingsGraph.search_things/3","type":"function"},{"doc":"Creates a tag for the specified resource.","ref":"AWS.IoTThingsGraph.html#tag_resource/3","title":"AWS.IoTThingsGraph.tag_resource/3","type":"function"},{"doc":"Removes a system instance from its target (Cloud or Greengrass).","ref":"AWS.IoTThingsGraph.html#undeploy_system_instance/3","title":"AWS.IoTThingsGraph.undeploy_system_instance/3","type":"function"},{"doc":"Removes a tag from the specified resource.","ref":"AWS.IoTThingsGraph.html#untag_resource/3","title":"AWS.IoTThingsGraph.untag_resource/3","type":"function"},{"doc":"Updates the specified workflow.\n\nAll deployed systems and system instances that use the workflow will see the\nchanges in the flow when it is redeployed. If you don't want this behavior, copy\nthe workflow (creating a new workflow with a different ID), and update the copy.\nThe workflow can contain only entities in the specified namespace.","ref":"AWS.IoTThingsGraph.html#update_flow_template/3","title":"AWS.IoTThingsGraph.update_flow_template/3","type":"function"},{"doc":"Updates the specified system.\n\nYou don't need to run this action after updating a workflow. Any deployment that\nuses the system will see the changes in the system when it is redeployed.","ref":"AWS.IoTThingsGraph.html#update_system_template/3","title":"AWS.IoTThingsGraph.update_system_template/3","type":"function"},{"doc":"Asynchronously uploads one or more entity definitions to the user's namespace.\n\nThe `document` parameter is required if `syncWithPublicNamespace` and\n`deleteExistingEntites` are false. If the `syncWithPublicNamespace` parameter is\nset to `true`, the user's namespace will synchronize with the latest version of\nthe public namespace. If `deprecateExistingEntities` is set to true, all\nentities in the latest version will be deleted before the new\n`DefinitionDocument` is uploaded.\n\nWhen a user uploads entity definitions for the first time, the service creates a\nnew namespace for the user. The new namespace tracks the public namespace.\nCurrently users can have only one namespace. The namespace version increments\nwhenever a user uploads entity definitions that are backwards-incompatible and\nwhenever a user sets the `syncWithPublicNamespace` parameter or the\n`deprecateExistingEntities` parameter to `true`.\n\nThe IDs for all of the entities should be in URN format. Each entity must be in\nthe user's namespace. Users can't create entities in the public namespace, but\nentity definitions can refer to entities in the public namespace.\n\nValid entities are `Device`, `DeviceModel`, `Service`, `Capability`, `State`,\n`Action`, `Event`, `Property`, `Mapping`, `Enum`.","ref":"AWS.IoTThingsGraph.html#upload_entity_definitions/3","title":"AWS.IoTThingsGraph.upload_entity_definitions/3","type":"function"},{"doc":"IoT TwinMaker is a service with which you can build operational digital twins of\nphysical systems.\n\nIoT TwinMaker overlays measurements and analysis from real-world sensors,\ncameras, and enterprise applications so you can create data visualizations to\nmonitor your physical factory, building, or industrial plant. You can use this\nreal-world data to monitor operations and diagnose and repair errors.","ref":"AWS.IoTTwinMaker.html","title":"AWS.IoTTwinMaker","type":"module"},{"doc":"Sets values for multiple time series properties.","ref":"AWS.IoTTwinMaker.html#batch_put_property_values/4","title":"AWS.IoTTwinMaker.batch_put_property_values/4","type":"function"},{"doc":"Cancels the metadata transfer job.","ref":"AWS.IoTTwinMaker.html#cancel_metadata_transfer_job/4","title":"AWS.IoTTwinMaker.cancel_metadata_transfer_job/4","type":"function"},{"doc":"Creates a component type.","ref":"AWS.IoTTwinMaker.html#create_component_type/5","title":"AWS.IoTTwinMaker.create_component_type/5","type":"function"},{"doc":"Creates an entity.","ref":"AWS.IoTTwinMaker.html#create_entity/4","title":"AWS.IoTTwinMaker.create_entity/4","type":"function"},{"doc":"Creates a new metadata transfer job.","ref":"AWS.IoTTwinMaker.html#create_metadata_transfer_job/3","title":"AWS.IoTTwinMaker.create_metadata_transfer_job/3","type":"function"},{"doc":"Creates a scene.","ref":"AWS.IoTTwinMaker.html#create_scene/4","title":"AWS.IoTTwinMaker.create_scene/4","type":"function"},{"doc":"This action creates a SyncJob.","ref":"AWS.IoTTwinMaker.html#create_sync_job/5","title":"AWS.IoTTwinMaker.create_sync_job/5","type":"function"},{"doc":"Creates a workplace.","ref":"AWS.IoTTwinMaker.html#create_workspace/4","title":"AWS.IoTTwinMaker.create_workspace/4","type":"function"},{"doc":"Deletes a component type.","ref":"AWS.IoTTwinMaker.html#delete_component_type/5","title":"AWS.IoTTwinMaker.delete_component_type/5","type":"function"},{"doc":"Deletes an entity.","ref":"AWS.IoTTwinMaker.html#delete_entity/5","title":"AWS.IoTTwinMaker.delete_entity/5","type":"function"},{"doc":"Deletes a scene.","ref":"AWS.IoTTwinMaker.html#delete_scene/5","title":"AWS.IoTTwinMaker.delete_scene/5","type":"function"},{"doc":"Delete the SyncJob.","ref":"AWS.IoTTwinMaker.html#delete_sync_job/5","title":"AWS.IoTTwinMaker.delete_sync_job/5","type":"function"},{"doc":"Deletes a workspace.","ref":"AWS.IoTTwinMaker.html#delete_workspace/4","title":"AWS.IoTTwinMaker.delete_workspace/4","type":"function"},{"doc":"Run queries to access information from your knowledge graph of entities within\nindividual workspaces.\n\nThe ExecuteQuery action only works with [Amazon Web Services Java SDK2](https://docs.aws.amazon.com/sdk-for-java/latest/developer-guide/home.html).\nExecuteQuery will not work with any Amazon Web Services Java SDK version < 2.x.","ref":"AWS.IoTTwinMaker.html#execute_query/3","title":"AWS.IoTTwinMaker.execute_query/3","type":"function"},{"doc":"Retrieves information about a component type.","ref":"AWS.IoTTwinMaker.html#get_component_type/4","title":"AWS.IoTTwinMaker.get_component_type/4","type":"function"},{"doc":"Retrieves information about an entity.","ref":"AWS.IoTTwinMaker.html#get_entity/4","title":"AWS.IoTTwinMaker.get_entity/4","type":"function"},{"doc":"Gets a nmetadata transfer job.","ref":"AWS.IoTTwinMaker.html#get_metadata_transfer_job/3","title":"AWS.IoTTwinMaker.get_metadata_transfer_job/3","type":"function"},{"doc":"Gets the pricing plan.","ref":"AWS.IoTTwinMaker.html#get_pricing_plan/2","title":"AWS.IoTTwinMaker.get_pricing_plan/2","type":"function"},{"doc":"Gets the property values for a component, component type, entity, or workspace.\n\nYou must specify a value for either `componentName`, `componentTypeId`,\n`entityId`, or `workspaceId`.","ref":"AWS.IoTTwinMaker.html#get_property_value/4","title":"AWS.IoTTwinMaker.get_property_value/4","type":"function"},{"doc":"Retrieves information about the history of a time series property value for a\ncomponent, component type, entity, or workspace.\n\nYou must specify a value for `workspaceId`. For entity-specific queries, specify\nvalues for `componentName` and `entityId`. For cross-entity quries, specify a\nvalue for `componentTypeId`.","ref":"AWS.IoTTwinMaker.html#get_property_value_history/4","title":"AWS.IoTTwinMaker.get_property_value_history/4","type":"function"},{"doc":"Retrieves information about a scene.","ref":"AWS.IoTTwinMaker.html#get_scene/4","title":"AWS.IoTTwinMaker.get_scene/4","type":"function"},{"doc":"Gets the SyncJob.","ref":"AWS.IoTTwinMaker.html#get_sync_job/4","title":"AWS.IoTTwinMaker.get_sync_job/4","type":"function"},{"doc":"Retrieves information about a workspace.","ref":"AWS.IoTTwinMaker.html#get_workspace/3","title":"AWS.IoTTwinMaker.get_workspace/3","type":"function"},{"doc":"Lists all component types in a workspace.","ref":"AWS.IoTTwinMaker.html#list_component_types/4","title":"AWS.IoTTwinMaker.list_component_types/4","type":"function"},{"doc":"This API lists the components of an entity.","ref":"AWS.IoTTwinMaker.html#list_components/5","title":"AWS.IoTTwinMaker.list_components/5","type":"function"},{"doc":"Lists all entities in a workspace.","ref":"AWS.IoTTwinMaker.html#list_entities/4","title":"AWS.IoTTwinMaker.list_entities/4","type":"function"},{"doc":"Lists the metadata transfer jobs.","ref":"AWS.IoTTwinMaker.html#list_metadata_transfer_jobs/3","title":"AWS.IoTTwinMaker.list_metadata_transfer_jobs/3","type":"function"},{"doc":"This API lists the properties of a component.","ref":"AWS.IoTTwinMaker.html#list_properties/4","title":"AWS.IoTTwinMaker.list_properties/4","type":"function"},{"doc":"Lists all scenes in a workspace.","ref":"AWS.IoTTwinMaker.html#list_scenes/4","title":"AWS.IoTTwinMaker.list_scenes/4","type":"function"},{"doc":"List all SyncJobs.","ref":"AWS.IoTTwinMaker.html#list_sync_jobs/4","title":"AWS.IoTTwinMaker.list_sync_jobs/4","type":"function"},{"doc":"Lists the sync resources.","ref":"AWS.IoTTwinMaker.html#list_sync_resources/5","title":"AWS.IoTTwinMaker.list_sync_resources/5","type":"function"},{"doc":"Lists all tags associated with a resource.","ref":"AWS.IoTTwinMaker.html#list_tags_for_resource/3","title":"AWS.IoTTwinMaker.list_tags_for_resource/3","type":"function"},{"doc":"Retrieves information about workspaces in the current account.","ref":"AWS.IoTTwinMaker.html#list_workspaces/3","title":"AWS.IoTTwinMaker.list_workspaces/3","type":"function"},{"doc":"","ref":"AWS.IoTTwinMaker.html#metadata/0","title":"AWS.IoTTwinMaker.metadata/0","type":"function"},{"doc":"Adds tags to a resource.","ref":"AWS.IoTTwinMaker.html#tag_resource/3","title":"AWS.IoTTwinMaker.tag_resource/3","type":"function"},{"doc":"Removes tags from a resource.","ref":"AWS.IoTTwinMaker.html#untag_resource/3","title":"AWS.IoTTwinMaker.untag_resource/3","type":"function"},{"doc":"Updates information in a component type.","ref":"AWS.IoTTwinMaker.html#update_component_type/5","title":"AWS.IoTTwinMaker.update_component_type/5","type":"function"},{"doc":"Updates an entity.","ref":"AWS.IoTTwinMaker.html#update_entity/5","title":"AWS.IoTTwinMaker.update_entity/5","type":"function"},{"doc":"Update the pricing plan.","ref":"AWS.IoTTwinMaker.html#update_pricing_plan/3","title":"AWS.IoTTwinMaker.update_pricing_plan/3","type":"function"},{"doc":"Updates a scene.","ref":"AWS.IoTTwinMaker.html#update_scene/5","title":"AWS.IoTTwinMaker.update_scene/5","type":"function"},{"doc":"Updates a workspace.","ref":"AWS.IoTTwinMaker.html#update_workspace/4","title":"AWS.IoTTwinMaker.update_workspace/4","type":"function"},{"doc":"AWS IoT Wireless provides bi-directional communication between\ninternet-connected wireless devices and the AWS Cloud.\n\nTo onboard both LoRaWAN and Sidewalk devices to AWS IoT, use the IoT Wireless\nAPI. These wireless devices use the Low Power Wide Area Networking (LPWAN)\ncommunication protocol to communicate with AWS IoT.\n\nUsing the API, you can perform create, read, update, and delete operations for\nyour wireless devices, gateways, destinations, and profiles. After onboarding\nyour devices, you can use the API operations to set log levels and monitor your\ndevices with CloudWatch.\n\nYou can also use the API operations to create multicast groups and schedule a\nmulticast session for sending a downlink message to devices in the group. By\nusing Firmware Updates Over-The-Air (FUOTA) API operations, you can create a\nFUOTA task and schedule a session to update the firmware of individual devices\nor an entire group of devices in a multicast group.","ref":"AWS.IoTWireless.html","title":"AWS.IoTWireless","type":"module"},{"doc":"Associates a partner account with your AWS account.","ref":"AWS.IoTWireless.html#associate_aws_account_with_partner_account/3","title":"AWS.IoTWireless.associate_aws_account_with_partner_account/3","type":"function"},{"doc":"Associate a multicast group with a FUOTA task.","ref":"AWS.IoTWireless.html#associate_multicast_group_with_fuota_task/4","title":"AWS.IoTWireless.associate_multicast_group_with_fuota_task/4","type":"function"},{"doc":"Associate a wireless device with a FUOTA task.","ref":"AWS.IoTWireless.html#associate_wireless_device_with_fuota_task/4","title":"AWS.IoTWireless.associate_wireless_device_with_fuota_task/4","type":"function"},{"doc":"Associates a wireless device with a multicast group.","ref":"AWS.IoTWireless.html#associate_wireless_device_with_multicast_group/4","title":"AWS.IoTWireless.associate_wireless_device_with_multicast_group/4","type":"function"},{"doc":"Associates a wireless device with a thing.","ref":"AWS.IoTWireless.html#associate_wireless_device_with_thing/4","title":"AWS.IoTWireless.associate_wireless_device_with_thing/4","type":"function"},{"doc":"Associates a wireless gateway with a certificate.","ref":"AWS.IoTWireless.html#associate_wireless_gateway_with_certificate/4","title":"AWS.IoTWireless.associate_wireless_gateway_with_certificate/4","type":"function"},{"doc":"Associates a wireless gateway with a thing.","ref":"AWS.IoTWireless.html#associate_wireless_gateway_with_thing/4","title":"AWS.IoTWireless.associate_wireless_gateway_with_thing/4","type":"function"},{"doc":"Cancels an existing multicast group session.","ref":"AWS.IoTWireless.html#cancel_multicast_group_session/4","title":"AWS.IoTWireless.cancel_multicast_group_session/4","type":"function"},{"doc":"Creates a new destination that maps a device message to an AWS IoT rule.","ref":"AWS.IoTWireless.html#create_destination/3","title":"AWS.IoTWireless.create_destination/3","type":"function"},{"doc":"Creates a new device profile.","ref":"AWS.IoTWireless.html#create_device_profile/3","title":"AWS.IoTWireless.create_device_profile/3","type":"function"},{"doc":"Creates a FUOTA task.","ref":"AWS.IoTWireless.html#create_fuota_task/3","title":"AWS.IoTWireless.create_fuota_task/3","type":"function"},{"doc":"Creates a multicast group.","ref":"AWS.IoTWireless.html#create_multicast_group/3","title":"AWS.IoTWireless.create_multicast_group/3","type":"function"},{"doc":"Creates a new network analyzer configuration.","ref":"AWS.IoTWireless.html#create_network_analyzer_configuration/3","title":"AWS.IoTWireless.create_network_analyzer_configuration/3","type":"function"},{"doc":"Creates a new service profile.","ref":"AWS.IoTWireless.html#create_service_profile/3","title":"AWS.IoTWireless.create_service_profile/3","type":"function"},{"doc":"Provisions a wireless device.","ref":"AWS.IoTWireless.html#create_wireless_device/3","title":"AWS.IoTWireless.create_wireless_device/3","type":"function"},{"doc":"Provisions a wireless gateway.","ref":"AWS.IoTWireless.html#create_wireless_gateway/3","title":"AWS.IoTWireless.create_wireless_gateway/3","type":"function"},{"doc":"Creates a task for a wireless gateway.","ref":"AWS.IoTWireless.html#create_wireless_gateway_task/4","title":"AWS.IoTWireless.create_wireless_gateway_task/4","type":"function"},{"doc":"Creates a gateway task definition.","ref":"AWS.IoTWireless.html#create_wireless_gateway_task_definition/3","title":"AWS.IoTWireless.create_wireless_gateway_task_definition/3","type":"function"},{"doc":"Deletes a destination.","ref":"AWS.IoTWireless.html#delete_destination/4","title":"AWS.IoTWireless.delete_destination/4","type":"function"},{"doc":"Deletes a device profile.","ref":"AWS.IoTWireless.html#delete_device_profile/4","title":"AWS.IoTWireless.delete_device_profile/4","type":"function"},{"doc":"Deletes a FUOTA task.","ref":"AWS.IoTWireless.html#delete_fuota_task/4","title":"AWS.IoTWireless.delete_fuota_task/4","type":"function"},{"doc":"Deletes a multicast group if it is not in use by a fuota task.","ref":"AWS.IoTWireless.html#delete_multicast_group/4","title":"AWS.IoTWireless.delete_multicast_group/4","type":"function"},{"doc":"Deletes a network analyzer configuration.","ref":"AWS.IoTWireless.html#delete_network_analyzer_configuration/4","title":"AWS.IoTWireless.delete_network_analyzer_configuration/4","type":"function"},{"doc":"Remove queued messages from the downlink queue.","ref":"AWS.IoTWireless.html#delete_queued_messages/4","title":"AWS.IoTWireless.delete_queued_messages/4","type":"function"},{"doc":"Deletes a service profile.","ref":"AWS.IoTWireless.html#delete_service_profile/4","title":"AWS.IoTWireless.delete_service_profile/4","type":"function"},{"doc":"Deletes a wireless device.","ref":"AWS.IoTWireless.html#delete_wireless_device/4","title":"AWS.IoTWireless.delete_wireless_device/4","type":"function"},{"doc":"Delete an import task.","ref":"AWS.IoTWireless.html#delete_wireless_device_import_task/4","title":"AWS.IoTWireless.delete_wireless_device_import_task/4","type":"function"},{"doc":"Deletes a wireless gateway.","ref":"AWS.IoTWireless.html#delete_wireless_gateway/4","title":"AWS.IoTWireless.delete_wireless_gateway/4","type":"function"},{"doc":"Deletes a wireless gateway task.","ref":"AWS.IoTWireless.html#delete_wireless_gateway_task/4","title":"AWS.IoTWireless.delete_wireless_gateway_task/4","type":"function"},{"doc":"Deletes a wireless gateway task definition.\n\nDeleting this task definition does not affect tasks that are currently in\nprogress.","ref":"AWS.IoTWireless.html#delete_wireless_gateway_task_definition/4","title":"AWS.IoTWireless.delete_wireless_gateway_task_definition/4","type":"function"},{"doc":"Deregister a wireless device from AWS IoT Wireless.","ref":"AWS.IoTWireless.html#deregister_wireless_device/4","title":"AWS.IoTWireless.deregister_wireless_device/4","type":"function"},{"doc":"Disassociates your AWS account from a partner account.\n\nIf `PartnerAccountId` and `PartnerType` are `null`, disassociates your AWS\naccount from all partner accounts.","ref":"AWS.IoTWireless.html#disassociate_aws_account_from_partner_account/4","title":"AWS.IoTWireless.disassociate_aws_account_from_partner_account/4","type":"function"},{"doc":"Disassociates a multicast group from a fuota task.","ref":"AWS.IoTWireless.html#disassociate_multicast_group_from_fuota_task/5","title":"AWS.IoTWireless.disassociate_multicast_group_from_fuota_task/5","type":"function"},{"doc":"Disassociates a wireless device from a FUOTA task.","ref":"AWS.IoTWireless.html#disassociate_wireless_device_from_fuota_task/5","title":"AWS.IoTWireless.disassociate_wireless_device_from_fuota_task/5","type":"function"},{"doc":"Disassociates a wireless device from a multicast group.","ref":"AWS.IoTWireless.html#disassociate_wireless_device_from_multicast_group/5","title":"AWS.IoTWireless.disassociate_wireless_device_from_multicast_group/5","type":"function"},{"doc":"Disassociates a wireless device from its currently associated thing.","ref":"AWS.IoTWireless.html#disassociate_wireless_device_from_thing/4","title":"AWS.IoTWireless.disassociate_wireless_device_from_thing/4","type":"function"},{"doc":"Disassociates a wireless gateway from its currently associated certificate.","ref":"AWS.IoTWireless.html#disassociate_wireless_gateway_from_certificate/4","title":"AWS.IoTWireless.disassociate_wireless_gateway_from_certificate/4","type":"function"},{"doc":"Disassociates a wireless gateway from its currently associated thing.","ref":"AWS.IoTWireless.html#disassociate_wireless_gateway_from_thing/4","title":"AWS.IoTWireless.disassociate_wireless_gateway_from_thing/4","type":"function"},{"doc":"Gets information about a destination.","ref":"AWS.IoTWireless.html#get_destination/3","title":"AWS.IoTWireless.get_destination/3","type":"function"},{"doc":"Gets information about a device profile.","ref":"AWS.IoTWireless.html#get_device_profile/3","title":"AWS.IoTWireless.get_device_profile/3","type":"function"},{"doc":"Get the event configuration based on resource types.","ref":"AWS.IoTWireless.html#get_event_configuration_by_resource_types/2","title":"AWS.IoTWireless.get_event_configuration_by_resource_types/2","type":"function"},{"doc":"Gets information about a FUOTA task.","ref":"AWS.IoTWireless.html#get_fuota_task/3","title":"AWS.IoTWireless.get_fuota_task/3","type":"function"},{"doc":"Returns current default log levels or log levels by resource types.\n\nBased on resource types, log levels can be for wireless device log options or\nwireless gateway log options.","ref":"AWS.IoTWireless.html#get_log_levels_by_resource_types/2","title":"AWS.IoTWireless.get_log_levels_by_resource_types/2","type":"function"},{"doc":"Gets information about a multicast group.","ref":"AWS.IoTWireless.html#get_multicast_group/3","title":"AWS.IoTWireless.get_multicast_group/3","type":"function"},{"doc":"Gets information about a multicast group session.","ref":"AWS.IoTWireless.html#get_multicast_group_session/3","title":"AWS.IoTWireless.get_multicast_group_session/3","type":"function"},{"doc":"Get network analyzer configuration.","ref":"AWS.IoTWireless.html#get_network_analyzer_configuration/3","title":"AWS.IoTWireless.get_network_analyzer_configuration/3","type":"function"},{"doc":"Gets information about a partner account.\n\nIf `PartnerAccountId` and `PartnerType` are `null`, returns all partner\naccounts.","ref":"AWS.IoTWireless.html#get_partner_account/4","title":"AWS.IoTWireless.get_partner_account/4","type":"function"},{"doc":"Get the position information for a given resource.\n\nThis action is no longer supported. Calls to retrieve the position information\nshould use the\n[GetResourcePosition](https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_GetResourcePosition.html)\nAPI operation instead.","ref":"AWS.IoTWireless.html#get_position/4","title":"AWS.IoTWireless.get_position/4","type":"function"},{"doc":"Get position configuration for a given resource.\n\nThis action is no longer supported. Calls to retrieve the position configuration\nshould use the\n[GetResourcePosition](https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_GetResourcePosition.html)\nAPI operation instead.","ref":"AWS.IoTWireless.html#get_position_configuration/4","title":"AWS.IoTWireless.get_position_configuration/4","type":"function"},{"doc":"Get estimated position information as a payload in GeoJSON format.\n\nThe payload measurement data is resolved using solvers that are provided by\nthird-party vendors.","ref":"AWS.IoTWireless.html#get_position_estimate/3","title":"AWS.IoTWireless.get_position_estimate/3","type":"function"},{"doc":"Get the event configuration for a particular resource identifier.","ref":"AWS.IoTWireless.html#get_resource_event_configuration/5","title":"AWS.IoTWireless.get_resource_event_configuration/5","type":"function"},{"doc":"Fetches the log-level override, if any, for a given resource-ID and\nresource-type.\n\nIt can be used for a wireless device or a wireless gateway.","ref":"AWS.IoTWireless.html#get_resource_log_level/4","title":"AWS.IoTWireless.get_resource_log_level/4","type":"function"},{"doc":"Get the position information for a given wireless device or a wireless gateway\nresource.\n\nThe position information uses the [ World Geodetic System (WGS84)](https://gisgeography.com/wgs84-world-geodetic-system/).","ref":"AWS.IoTWireless.html#get_resource_position/4","title":"AWS.IoTWireless.get_resource_position/4","type":"function"},{"doc":"Gets the account-specific endpoint for Configuration and Update Server (CUPS)\nprotocol or LoRaWAN Network Server (LNS) connections.","ref":"AWS.IoTWireless.html#get_service_endpoint/3","title":"AWS.IoTWireless.get_service_endpoint/3","type":"function"},{"doc":"Gets information about a service profile.","ref":"AWS.IoTWireless.html#get_service_profile/3","title":"AWS.IoTWireless.get_service_profile/3","type":"function"},{"doc":"Gets information about a wireless device.","ref":"AWS.IoTWireless.html#get_wireless_device/4","title":"AWS.IoTWireless.get_wireless_device/4","type":"function"},{"doc":"Get information about an import task and count of device onboarding summary\ninformation for the import task.","ref":"AWS.IoTWireless.html#get_wireless_device_import_task/3","title":"AWS.IoTWireless.get_wireless_device_import_task/3","type":"function"},{"doc":"Gets operating information about a wireless device.","ref":"AWS.IoTWireless.html#get_wireless_device_statistics/3","title":"AWS.IoTWireless.get_wireless_device_statistics/3","type":"function"},{"doc":"Gets information about a wireless gateway.","ref":"AWS.IoTWireless.html#get_wireless_gateway/4","title":"AWS.IoTWireless.get_wireless_gateway/4","type":"function"},{"doc":"Gets the ID of the certificate that is currently associated with a wireless\ngateway.","ref":"AWS.IoTWireless.html#get_wireless_gateway_certificate/3","title":"AWS.IoTWireless.get_wireless_gateway_certificate/3","type":"function"},{"doc":"Gets the firmware version and other information about a wireless gateway.","ref":"AWS.IoTWireless.html#get_wireless_gateway_firmware_information/3","title":"AWS.IoTWireless.get_wireless_gateway_firmware_information/3","type":"function"},{"doc":"Gets operating information about a wireless gateway.","ref":"AWS.IoTWireless.html#get_wireless_gateway_statistics/3","title":"AWS.IoTWireless.get_wireless_gateway_statistics/3","type":"function"},{"doc":"Gets information about a wireless gateway task.","ref":"AWS.IoTWireless.html#get_wireless_gateway_task/3","title":"AWS.IoTWireless.get_wireless_gateway_task/3","type":"function"},{"doc":"Gets information about a wireless gateway task definition.","ref":"AWS.IoTWireless.html#get_wireless_gateway_task_definition/3","title":"AWS.IoTWireless.get_wireless_gateway_task_definition/3","type":"function"},{"doc":"Lists the destinations registered to your AWS account.","ref":"AWS.IoTWireless.html#list_destinations/4","title":"AWS.IoTWireless.list_destinations/4","type":"function"},{"doc":"Lists the device profiles registered to your AWS account.","ref":"AWS.IoTWireless.html#list_device_profiles/5","title":"AWS.IoTWireless.list_device_profiles/5","type":"function"},{"doc":"List the Sidewalk devices in an import task and their onboarding status.","ref":"AWS.IoTWireless.html#list_devices_for_wireless_device_import_task/6","title":"AWS.IoTWireless.list_devices_for_wireless_device_import_task/6","type":"function"},{"doc":"List event configurations where at least one event topic has been enabled.","ref":"AWS.IoTWireless.html#list_event_configurations/5","title":"AWS.IoTWireless.list_event_configurations/5","type":"function"},{"doc":"Lists the FUOTA tasks registered to your AWS account.","ref":"AWS.IoTWireless.html#list_fuota_tasks/4","title":"AWS.IoTWireless.list_fuota_tasks/4","type":"function"},{"doc":"Lists the multicast groups registered to your AWS account.","ref":"AWS.IoTWireless.html#list_multicast_groups/4","title":"AWS.IoTWireless.list_multicast_groups/4","type":"function"},{"doc":"List all multicast groups associated with a fuota task.","ref":"AWS.IoTWireless.html#list_multicast_groups_by_fuota_task/5","title":"AWS.IoTWireless.list_multicast_groups_by_fuota_task/5","type":"function"},{"doc":"Lists the network analyzer configurations.","ref":"AWS.IoTWireless.html#list_network_analyzer_configurations/4","title":"AWS.IoTWireless.list_network_analyzer_configurations/4","type":"function"},{"doc":"Lists the partner accounts associated with your AWS account.","ref":"AWS.IoTWireless.html#list_partner_accounts/4","title":"AWS.IoTWireless.list_partner_accounts/4","type":"function"},{"doc":"List position configurations for a given resource, such as positioning solvers.\n\nThis action is no longer supported. Calls to retrieve position information\nshould use the\n[GetResourcePosition](https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_GetResourcePosition.html)\nAPI operation instead.","ref":"AWS.IoTWireless.html#list_position_configurations/5","title":"AWS.IoTWireless.list_position_configurations/5","type":"function"},{"doc":"List queued messages in the downlink queue.","ref":"AWS.IoTWireless.html#list_queued_messages/6","title":"AWS.IoTWireless.list_queued_messages/6","type":"function"},{"doc":"Lists the service profiles registered to your AWS account.","ref":"AWS.IoTWireless.html#list_service_profiles/4","title":"AWS.IoTWireless.list_service_profiles/4","type":"function"},{"doc":"Lists the tags (metadata) you have assigned to the resource.","ref":"AWS.IoTWireless.html#list_tags_for_resource/3","title":"AWS.IoTWireless.list_tags_for_resource/3","type":"function"},{"doc":"List wireless devices that have been added to an import task.","ref":"AWS.IoTWireless.html#list_wireless_device_import_tasks/4","title":"AWS.IoTWireless.list_wireless_device_import_tasks/4","type":"function"},{"doc":"Lists the wireless devices registered to your AWS account.","ref":"AWS.IoTWireless.html#list_wireless_devices/10","title":"AWS.IoTWireless.list_wireless_devices/10","type":"function"},{"doc":"List the wireless gateway tasks definitions registered to your AWS account.","ref":"AWS.IoTWireless.html#list_wireless_gateway_task_definitions/5","title":"AWS.IoTWireless.list_wireless_gateway_task_definitions/5","type":"function"},{"doc":"Lists the wireless gateways registered to your AWS account.","ref":"AWS.IoTWireless.html#list_wireless_gateways/4","title":"AWS.IoTWireless.list_wireless_gateways/4","type":"function"},{"doc":"","ref":"AWS.IoTWireless.html#metadata/0","title":"AWS.IoTWireless.metadata/0","type":"function"},{"doc":"Put position configuration for a given resource.\n\nThis action is no longer supported. Calls to update the position configuration\nshould use the\n[UpdateResourcePosition](https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_UpdateResourcePosition.html)\nAPI operation instead.","ref":"AWS.IoTWireless.html#put_position_configuration/4","title":"AWS.IoTWireless.put_position_configuration/4","type":"function"},{"doc":"Sets the log-level override for a resource-ID and resource-type.\n\nThis option can be specified for a wireless gateway or a wireless device. A\nlimit of 200 log level override can be set per account.","ref":"AWS.IoTWireless.html#put_resource_log_level/4","title":"AWS.IoTWireless.put_resource_log_level/4","type":"function"},{"doc":"Removes the log-level overrides for all resources; both wireless devices and\nwireless gateways.","ref":"AWS.IoTWireless.html#reset_all_resource_log_levels/3","title":"AWS.IoTWireless.reset_all_resource_log_levels/3","type":"function"},{"doc":"Removes the log-level override, if any, for a specific resource-ID and\nresource-type.\n\nIt can be used for a wireless device or a wireless gateway.","ref":"AWS.IoTWireless.html#reset_resource_log_level/4","title":"AWS.IoTWireless.reset_resource_log_level/4","type":"function"},{"doc":"Sends the specified data to a multicast group.","ref":"AWS.IoTWireless.html#send_data_to_multicast_group/4","title":"AWS.IoTWireless.send_data_to_multicast_group/4","type":"function"},{"doc":"Sends a decrypted application data frame to a device.","ref":"AWS.IoTWireless.html#send_data_to_wireless_device/4","title":"AWS.IoTWireless.send_data_to_wireless_device/4","type":"function"},{"doc":"Starts a bulk association of all qualifying wireless devices with a multicast\ngroup.","ref":"AWS.IoTWireless.html#start_bulk_associate_wireless_device_with_multicast_group/4","title":"AWS.IoTWireless.start_bulk_associate_wireless_device_with_multicast_group/4","type":"function"},{"doc":"Starts a bulk disassociatin of all qualifying wireless devices from a multicast\ngroup.","ref":"AWS.IoTWireless.html#start_bulk_disassociate_wireless_device_from_multicast_group/4","title":"AWS.IoTWireless.start_bulk_disassociate_wireless_device_from_multicast_group/4","type":"function"},{"doc":"Starts a FUOTA task.","ref":"AWS.IoTWireless.html#start_fuota_task/4","title":"AWS.IoTWireless.start_fuota_task/4","type":"function"},{"doc":"Starts a multicast group session.","ref":"AWS.IoTWireless.html#start_multicast_group_session/4","title":"AWS.IoTWireless.start_multicast_group_session/4","type":"function"},{"doc":"Start import task for a single wireless device.","ref":"AWS.IoTWireless.html#start_single_wireless_device_import_task/3","title":"AWS.IoTWireless.start_single_wireless_device_import_task/3","type":"function"},{"doc":"Start import task for provisioning Sidewalk devices in bulk using an S3 CSV\nfile.","ref":"AWS.IoTWireless.html#start_wireless_device_import_task/3","title":"AWS.IoTWireless.start_wireless_device_import_task/3","type":"function"},{"doc":"Adds a tag to a resource.","ref":"AWS.IoTWireless.html#tag_resource/3","title":"AWS.IoTWireless.tag_resource/3","type":"function"},{"doc":"Simulates a provisioned device by sending an uplink data payload of `Hello`.","ref":"AWS.IoTWireless.html#test_wireless_device/4","title":"AWS.IoTWireless.test_wireless_device/4","type":"function"},{"doc":"Removes one or more tags from a resource.","ref":"AWS.IoTWireless.html#untag_resource/3","title":"AWS.IoTWireless.untag_resource/3","type":"function"},{"doc":"Updates properties of a destination.","ref":"AWS.IoTWireless.html#update_destination/4","title":"AWS.IoTWireless.update_destination/4","type":"function"},{"doc":"Update the event configuration based on resource types.","ref":"AWS.IoTWireless.html#update_event_configuration_by_resource_types/3","title":"AWS.IoTWireless.update_event_configuration_by_resource_types/3","type":"function"},{"doc":"Updates properties of a FUOTA task.","ref":"AWS.IoTWireless.html#update_fuota_task/4","title":"AWS.IoTWireless.update_fuota_task/4","type":"function"},{"doc":"Set default log level, or log levels by resource types.\n\nThis can be for wireless device log options or wireless gateways log options and\nis used to control the log messages that'll be displayed in CloudWatch.","ref":"AWS.IoTWireless.html#update_log_levels_by_resource_types/3","title":"AWS.IoTWireless.update_log_levels_by_resource_types/3","type":"function"},{"doc":"Updates properties of a multicast group session.","ref":"AWS.IoTWireless.html#update_multicast_group/4","title":"AWS.IoTWireless.update_multicast_group/4","type":"function"},{"doc":"Update network analyzer configuration.","ref":"AWS.IoTWireless.html#update_network_analyzer_configuration/4","title":"AWS.IoTWireless.update_network_analyzer_configuration/4","type":"function"},{"doc":"Updates properties of a partner account.","ref":"AWS.IoTWireless.html#update_partner_account/4","title":"AWS.IoTWireless.update_partner_account/4","type":"function"},{"doc":"Update the position information of a resource.\n\nThis action is no longer supported. Calls to update the position information\nshould use the\n[UpdateResourcePosition](https://docs.aws.amazon.com/iot-wireless/2020-11-22/apireference/API_UpdateResourcePosition.html)\nAPI operation instead.","ref":"AWS.IoTWireless.html#update_position/4","title":"AWS.IoTWireless.update_position/4","type":"function"},{"doc":"Update the event configuration for a particular resource identifier.","ref":"AWS.IoTWireless.html#update_resource_event_configuration/4","title":"AWS.IoTWireless.update_resource_event_configuration/4","type":"function"},{"doc":"Update the position information of a given wireless device or a wireless gateway\nresource.\n\nThe position coordinates are based on the [ World Geodetic System (WGS84)](https://gisgeography.com/wgs84-world-geodetic-system/).","ref":"AWS.IoTWireless.html#update_resource_position/4","title":"AWS.IoTWireless.update_resource_position/4","type":"function"},{"doc":"Updates properties of a wireless device.","ref":"AWS.IoTWireless.html#update_wireless_device/4","title":"AWS.IoTWireless.update_wireless_device/4","type":"function"},{"doc":"Update an import task to add more devices to the task.","ref":"AWS.IoTWireless.html#update_wireless_device_import_task/4","title":"AWS.IoTWireless.update_wireless_device_import_task/4","type":"function"},{"doc":"Updates properties of a wireless gateway.","ref":"AWS.IoTWireless.html#update_wireless_gateway/4","title":"AWS.IoTWireless.update_wireless_gateway/4","type":"function"},{"doc":"Amazon Web Services IoT Core Device Advisor is a cloud-based, fully managed test\ncapability for validating IoT devices during device software development.\n\nDevice Advisor provides pre-built tests that you can use to validate IoT devices\nfor reliable and secure connectivity with Amazon Web Services IoT Core before\ndeploying devices to production. By using Device Advisor, you can confirm that\nyour devices can connect to Amazon Web Services IoT Core, follow security best\npractices and, if applicable, receive software updates from IoT Device\nManagement. You can also download signed qualification reports to submit to the\nAmazon Web Services Partner Network to get your device qualified for the Amazon\nWeb Services Partner Device Catalog without the need to send your device in and\nwait for it to be tested.","ref":"AWS.IotDeviceAdvisor.html","title":"AWS.IotDeviceAdvisor","type":"module"},{"doc":"Creates a Device Advisor test suite.\n\nRequires permission to access the\n[CreateSuiteDefinition](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IotDeviceAdvisor.html#create_suite_definition/3","title":"AWS.IotDeviceAdvisor.create_suite_definition/3","type":"function"},{"doc":"Deletes a Device Advisor test suite.\n\nRequires permission to access the\n[DeleteSuiteDefinition](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IotDeviceAdvisor.html#delete_suite_definition/4","title":"AWS.IotDeviceAdvisor.delete_suite_definition/4","type":"function"},{"doc":"Gets information about an Device Advisor endpoint.","ref":"AWS.IotDeviceAdvisor.html#get_endpoint/6","title":"AWS.IotDeviceAdvisor.get_endpoint/6","type":"function"},{"doc":"Gets information about a Device Advisor test suite.\n\nRequires permission to access the\n[GetSuiteDefinition](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IotDeviceAdvisor.html#get_suite_definition/4","title":"AWS.IotDeviceAdvisor.get_suite_definition/4","type":"function"},{"doc":"Gets information about a Device Advisor test suite run.\n\nRequires permission to access the\n[GetSuiteRun](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IotDeviceAdvisor.html#get_suite_run/4","title":"AWS.IotDeviceAdvisor.get_suite_run/4","type":"function"},{"doc":"Gets a report download link for a successful Device Advisor qualifying test\nsuite run.\n\nRequires permission to access the\n[GetSuiteRunReport](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IotDeviceAdvisor.html#get_suite_run_report/4","title":"AWS.IotDeviceAdvisor.get_suite_run_report/4","type":"function"},{"doc":"Lists the Device Advisor test suites you have created.\n\nRequires permission to access the\n[ListSuiteDefinitions](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IotDeviceAdvisor.html#list_suite_definitions/4","title":"AWS.IotDeviceAdvisor.list_suite_definitions/4","type":"function"},{"doc":"Lists runs of the specified Device Advisor test suite.\n\nYou can list all runs of the test suite, or the runs of a specific version of\nthe test suite.\n\nRequires permission to access the\n[ListSuiteRuns](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IotDeviceAdvisor.html#list_suite_runs/6","title":"AWS.IotDeviceAdvisor.list_suite_runs/6","type":"function"},{"doc":"Lists the tags attached to an IoT Device Advisor resource.\n\nRequires permission to access the\n[ListTagsForResource](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IotDeviceAdvisor.html#list_tags_for_resource/3","title":"AWS.IotDeviceAdvisor.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.IotDeviceAdvisor.html#metadata/0","title":"AWS.IotDeviceAdvisor.metadata/0","type":"function"},{"doc":"Starts a Device Advisor test suite run.\n\nRequires permission to access the\n[StartSuiteRun](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IotDeviceAdvisor.html#start_suite_run/4","title":"AWS.IotDeviceAdvisor.start_suite_run/4","type":"function"},{"doc":"Stops a Device Advisor test suite run that is currently running.\n\nRequires permission to access the\n[StopSuiteRun](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IotDeviceAdvisor.html#stop_suite_run/5","title":"AWS.IotDeviceAdvisor.stop_suite_run/5","type":"function"},{"doc":"Adds to and modifies existing tags of an IoT Device Advisor resource.\n\nRequires permission to access the\n[TagResource](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IotDeviceAdvisor.html#tag_resource/4","title":"AWS.IotDeviceAdvisor.tag_resource/4","type":"function"},{"doc":"Removes tags from an IoT Device Advisor resource.\n\nRequires permission to access the\n[UntagResource](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IotDeviceAdvisor.html#untag_resource/4","title":"AWS.IotDeviceAdvisor.untag_resource/4","type":"function"},{"doc":"Updates a Device Advisor test suite.\n\nRequires permission to access the\n[UpdateSuiteDefinition](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions)\naction.","ref":"AWS.IotDeviceAdvisor.html#update_suite_definition/4","title":"AWS.IotDeviceAdvisor.update_suite_definition/4","type":"function"},{"doc":"","ref":"AWS.Ivs.html","title":"AWS.Ivs","type":"module"},{"doc":"The Amazon Interactive Video Service (IVS) API is REST compatible, using a\nstandard HTTP API and an Amazon Web Services EventBridge event stream for\nresponses.\n\nJSON is used for both requests and responses, including errors.\n\nThe API is an Amazon Web Services regional service. For a list of supported\nregions and Amazon IVS HTTPS service endpoints, see the [Amazon IVS page](https://docs.aws.amazon.com/general/latest/gr/ivs.html) in the *Amazon Web\nServices General Reference*.\n\n* **All API request parameters and URLs are case sensitive. ** *\n\nFor a summary of notable documentation changes in each release, see [ Document History](https://docs.aws.amazon.com/ivs/latest/userguide/doc-history.html).","ref":"AWS.Ivs.html#module-introduction","title":"Introduction - AWS.Ivs","type":"module"},{"doc":"* ` **Accept:** ` application/json\n\n  * ` **Accept-Encoding:** ` gzip, deflate\n\n  * ` **Content-Type:** `application/json","ref":"AWS.Ivs.html#module-allowed-header-values","title":"Allowed Header Values - AWS.Ivs","type":"module"},{"doc":"The following resources contain information about your IVS live stream (see [\nGetting Started with Amazon\nIVS](https://docs.aws.amazon.com/ivs/latest/userguide/getting-started.html)):\n\n  * **Channel** — Stores configuration data related to your live\nstream. You first create a channel and then use the channel’s stream key to\nstart your live stream. See the Channel endpoints for more information.\n\n  * **Stream key** — An identifier assigned by Amazon IVS when you\ncreate a channel, which is then used to authorize streaming. See the StreamKey\nendpoints for more information. * **Treat the stream key like a secret, since it\nallows anyone to stream to the channel.** *\n\n  * **Playback key pair** — Video playback may be restricted using\nplayback-authorization tokens, which use public-key encryption. A playback key\npair is the public-private pair of keys used to sign and validate the\nplayback-authorization token. See the PlaybackKeyPair endpoints for more\ninformation.\n\n  * **Recording configuration** — Stores configuration related to\nrecording a live stream and where to store the recorded content. Multiple\nchannels can reference the same recording configuration. See the Recording\nConfiguration endpoints for more information.\n\n  * **Playback restriction policy** — Restricts playback by countries\nand/or origin sites. See the Playback Restriction Policy endpoints for more\ninformation.","ref":"AWS.Ivs.html#module-resources","title":"Resources - AWS.Ivs","type":"module"},{"doc":"A *tag* is a metadata label that you assign to an Amazon Web Services resource.\nA tag comprises a *key* and a *value*, both set by you. For example, you might\nset a tag as `topic:nature` to label a particular video category. See [Tagging Amazon Web Services\nResources](https://docs.aws.amazon.com/general/latest/gr/aws_tagging.html) for\nmore information, including restrictions that apply to tags and \"Tag naming\nlimits and requirements\"; Amazon IVS has no service-specific constraints beyond\nwhat is documented there.\n\nTags can help you identify and organize your Amazon Web Services resources. For\nexample, you can use the same tag for different resources to indicate that they\nare related. You can also use tags to manage access (see [ Access Tags](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_tags.html)).\n\nThe Amazon IVS API has these tag-related endpoints: `TagResource`,\n`UntagResource`, and `ListTagsForResource`. The following resources support\ntagging: Channels, Stream Keys, Playback Key Pairs, and Recording\nConfigurations.\n\nAt most 50 tags can be applied to a resource.","ref":"AWS.Ivs.html#module-tagging","title":"Tagging - AWS.Ivs","type":"module"},{"doc":"Note the differences between these concepts:\n\n  * *Authentication* is about verifying identity. You need to be\nauthenticated to sign Amazon IVS API requests.\n\n  * *Authorization* is about granting permissions. Your IAM roles need\nto have permissions for Amazon IVS API requests. In addition, authorization is\nneeded to view [Amazon IVS private channels](https://docs.aws.amazon.com/ivs/latest/userguide/private-channels.html).\n(Private channels are channels that are enabled for \"playback authorization.\")","ref":"AWS.Ivs.html#module-authentication-versus-authorization","title":"Authentication versus Authorization - AWS.Ivs","type":"module"},{"doc":"All Amazon IVS API requests must be authenticated with a signature. The Amazon\nWeb Services Command-Line Interface (CLI) and Amazon IVS Player SDKs take care\nof signing the underlying API calls for you. However, if your application calls\nthe Amazon IVS API directly, it’s your responsibility to sign the requests.\n\nYou generate a signature using valid Amazon Web Services credentials that have\npermission to perform the requested action. For example, you must sign\nPutMetadata requests with a signature generated from a user account that has the\n`ivs:PutMetadata` permission.\n\nFor more information:\n\n  * Authentication and generating signatures — See [Authenticating Requests (Amazon Web Services Signature Version\n4)](https://docs.aws.amazon.com/AmazonS3/latest/API/sig-v4-authenticating-requests.html)\nin the *Amazon Web Services General Reference*.\n\n  * Managing Amazon IVS permissions — See [Identity and Access Management](https://docs.aws.amazon.com/ivs/latest/userguide/security-iam.html)\non the Security page of the *Amazon IVS User Guide*.","ref":"AWS.Ivs.html#module-authentication","title":"Authentication - AWS.Ivs","type":"module"},{"doc":"ARNs uniquely identify AWS resources. An ARN is required when you need to\nspecify a resource unambiguously across all of AWS, such as in IAM policies and\nAPI calls. For more information, see [Amazon Resource Names](https://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html)\nin the *AWS General Reference*.","ref":"AWS.Ivs.html#module-amazon-resource-names-arns","title":"Amazon Resource Names (ARNs) - AWS.Ivs","type":"module"},{"doc":"* `CreateChannel` — Creates a new channel and an associated stream\nkey to start streaming.\n\n  * `GetChannel` — Gets the channel configuration for the specified\nchannel ARN.\n\n  * `BatchGetChannel` — Performs `GetChannel` on multiple ARNs\nsimultaneously.\n\n  * `ListChannels` — Gets summary information about all channels in\nyour account, in the Amazon Web Services region where the API request is\nprocessed. This list can be filtered to match a specified name or\nrecording-configuration ARN. Filters are mutually exclusive and cannot be used\ntogether. If you try to use both filters, you will get an error (409 Conflict\nException).\n\n  * `UpdateChannel` — Updates a channel's configuration. This does not\naffect an ongoing stream of this channel. You must stop and restart the stream\nfor the changes to take effect.\n\n  * `DeleteChannel` — Deletes the specified channel.","ref":"AWS.Ivs.html#module-channel-endpoints","title":"Channel Endpoints - AWS.Ivs","type":"module"},{"doc":"* `CreatePlaybackRestrictionPolicy` — Creates a new playback\nrestriction policy, for constraining playback by countries and/or origins.\n\n  * `DeletePlaybackRestrictionPolicy` — Deletes the specified playback\nrestriction policy\n\n  * `GetPlaybackRestrictionPolicy` — Gets the specified playback\nrestriction policy.\n\n  * `ListPlaybackRestrictionPolicies` — Gets summary information about\nplayback restriction policies.\n\n  * `UpdatePlaybackRestrictionPolicy` — Updates a specified playback\nrestriction policy.","ref":"AWS.Ivs.html#module-playback-restriction-policy-endpoints","title":"Playback Restriction Policy Endpoints - AWS.Ivs","type":"module"},{"doc":"For more information, see [Setting Up Private Channels](https://docs.aws.amazon.com/ivs/latest/userguide/private-channels.html)\nin the *Amazon IVS User Guide*.\n\n  * `ImportPlaybackKeyPair` — Imports the public portion of a new key\npair and returns its `arn` and `fingerprint`. The `privateKey` can then be used\nto generate viewer authorization tokens, to grant viewers access to private\nchannels (channels enabled for playback authorization).\n\n  * `GetPlaybackKeyPair` — Gets a specified playback authorization key\npair and returns the `arn` and `fingerprint`. The `privateKey` held by the\ncaller can be used to generate viewer authorization tokens, to grant viewers\naccess to private channels.\n\n  * `ListPlaybackKeyPairs` — Gets summary information about playback\nkey pairs.\n\n  * `DeletePlaybackKeyPair` — Deletes a specified authorization key\npair. This invalidates future viewer tokens generated using the key pair’s\n`privateKey`.\n\n  * `StartViewerSessionRevocation` — Starts the process of revoking\nthe viewer session associated with a specified channel ARN and viewer ID.\nOptionally, you can provide a version to revoke viewer sessions less than and\nincluding that version.\n\n  * `BatchStartViewerSessionRevocation` — Performs\n`StartViewerSessionRevocation` on multiple channel ARN and viewer ID pairs\nsimultaneously.","ref":"AWS.Ivs.html#module-private-channel-endpoints","title":"Private Channel Endpoints - AWS.Ivs","type":"module"},{"doc":"* `CreateRecordingConfiguration` — Creates a new recording\nconfiguration, used to enable recording to Amazon S3.\n\n  * `GetRecordingConfiguration` — Gets the recording-configuration\nmetadata for the specified ARN.\n\n  * `ListRecordingConfigurations` — Gets summary information about all\nrecording configurations in your account, in the Amazon Web Services region\nwhere the API request is processed.\n\n  * `DeleteRecordingConfiguration` — Deletes the recording\nconfiguration for the specified ARN.","ref":"AWS.Ivs.html#module-recordingconfiguration-endpoints","title":"RecordingConfiguration Endpoints - AWS.Ivs","type":"module"},{"doc":"* `GetStream` — Gets information about the active (live) stream on a\nspecified channel.\n\n  * `GetStreamSession` — Gets metadata on a specified stream.\n\n  * `ListStreams` — Gets summary information about live streams in\nyour account, in the Amazon Web Services region where the API request is\nprocessed.\n\n  * `ListStreamSessions` — Gets a summary of current and previous\nstreams for a specified channel in your account, in the AWS region where the API\nrequest is processed.\n\n  * `StopStream` — Disconnects the incoming RTMPS stream for the\nspecified channel. Can be used in conjunction with `DeleteStreamKey` to prevent\nfurther streaming to a channel.\n\n  * `PutMetadata` — Inserts metadata into the active stream of the\nspecified channel. At most 5 requests per second per channel are allowed, each\nwith a maximum 1 KB payload. (If 5 TPS is not sufficient for your needs, we\nrecommend batching your data into a single PutMetadata call.) At most 155\nrequests per second per account are allowed.","ref":"AWS.Ivs.html#module-stream-endpoints","title":"Stream Endpoints - AWS.Ivs","type":"module"},{"doc":"* `CreateStreamKey` — Creates a stream key, used to initiate a\nstream, for the specified channel ARN.\n\n  * `GetStreamKey` — Gets stream key information for the specified\nARN.\n\n  * `BatchGetStreamKey` — Performs `GetStreamKey` on multiple ARNs\nsimultaneously.\n\n  * `ListStreamKeys` — Gets summary information about stream keys for\nthe specified channel.\n\n  * `DeleteStreamKey` — Deletes the stream key for the specified ARN,\nso it can no longer be used to stream.","ref":"AWS.Ivs.html#module-streamkey-endpoints","title":"StreamKey Endpoints - AWS.Ivs","type":"module"},{"doc":"* `TagResource` — Adds or updates tags for the Amazon Web Services\nresource with the specified ARN.\n\n  * `UntagResource` — Removes tags from the resource with the\nspecified ARN.\n\n  * `ListTagsForResource` — Gets information about Amazon Web Services\ntags for the specified ARN.","ref":"AWS.Ivs.html#module-amazon-web-services-tags-endpoints","title":"Amazon Web Services Tags Endpoints - AWS.Ivs","type":"module"},{"doc":"Performs `GetChannel` on multiple ARNs simultaneously.","ref":"AWS.Ivs.html#batch_get_channel/3","title":"AWS.Ivs.batch_get_channel/3","type":"function"},{"doc":"Performs `GetStreamKey` on multiple ARNs simultaneously.","ref":"AWS.Ivs.html#batch_get_stream_key/3","title":"AWS.Ivs.batch_get_stream_key/3","type":"function"},{"doc":"Performs `StartViewerSessionRevocation` on multiple channel ARN and viewer ID\npairs simultaneously.","ref":"AWS.Ivs.html#batch_start_viewer_session_revocation/3","title":"AWS.Ivs.batch_start_viewer_session_revocation/3","type":"function"},{"doc":"Creates a new channel and an associated stream key to start streaming.","ref":"AWS.Ivs.html#create_channel/3","title":"AWS.Ivs.create_channel/3","type":"function"},{"doc":"Creates a new playback restriction policy, for constraining playback by\ncountries and/or origins.","ref":"AWS.Ivs.html#create_playback_restriction_policy/3","title":"AWS.Ivs.create_playback_restriction_policy/3","type":"function"},{"doc":"Creates a new recording configuration, used to enable recording to Amazon S3.\n\n**Known issue:** In the us-east-1 region, if you use the Amazon Web Services CLI\nto create a recording configuration, it returns success even if the S3 bucket is\nin a different region. In this case, the `state` of the recording configuration\nis `CREATE_FAILED` (instead of `ACTIVE`). (In other regions, the CLI correctly\nreturns failure if the bucket is in a different region.)\n\n**Workaround:** Ensure that your S3 bucket is in the same region as the\nrecording configuration. If you create a recording configuration in a different\nregion as your S3 bucket, delete that recording configuration and create a new\none with an S3 bucket from the correct region.","ref":"AWS.Ivs.html#create_recording_configuration/3","title":"AWS.Ivs.create_recording_configuration/3","type":"function"},{"doc":"Creates a stream key, used to initiate a stream, for the specified channel ARN.\n\nNote that `CreateChannel` creates a stream key. If you subsequently use\nCreateStreamKey on the same channel, it will fail because a stream key already\nexists and there is a limit of 1 stream key per channel. To reset the stream key\non a channel, use `DeleteStreamKey` and then CreateStreamKey.","ref":"AWS.Ivs.html#create_stream_key/3","title":"AWS.Ivs.create_stream_key/3","type":"function"},{"doc":"Deletes the specified channel and its associated stream keys.\n\nIf you try to delete a live channel, you will get an error (409\nConflictException). To delete a channel that is live, call `StopStream`, wait\nfor the Amazon EventBridge \"Stream End\" event (to verify that the stream's state\nis no longer Live), then call DeleteChannel. (See [ Using EventBridge with Amazon IVS](https://docs.aws.amazon.com/ivs/latest/userguide/eventbridge.html).)","ref":"AWS.Ivs.html#delete_channel/3","title":"AWS.Ivs.delete_channel/3","type":"function"},{"doc":"Deletes a specified authorization key pair.\n\nThis invalidates future viewer tokens generated using the key pair’s\n`privateKey`. For more information, see [Setting Up Private Channels](https://docs.aws.amazon.com/ivs/latest/userguide/private-channels.html)\nin the *Amazon IVS User Guide*.","ref":"AWS.Ivs.html#delete_playback_key_pair/3","title":"AWS.Ivs.delete_playback_key_pair/3","type":"function"},{"doc":"Deletes the specified playback restriction policy.","ref":"AWS.Ivs.html#delete_playback_restriction_policy/3","title":"AWS.Ivs.delete_playback_restriction_policy/3","type":"function"},{"doc":"Deletes the recording configuration for the specified ARN.\n\nIf you try to delete a recording configuration that is associated with a\nchannel, you will get an error (409 ConflictException). To avoid this, for all\nchannels that reference the recording configuration, first use `UpdateChannel`\nto set the `recordingConfigurationArn` field to an empty string, then use\nDeleteRecordingConfiguration.","ref":"AWS.Ivs.html#delete_recording_configuration/3","title":"AWS.Ivs.delete_recording_configuration/3","type":"function"},{"doc":"Deletes the stream key for the specified ARN, so it can no longer be used to\nstream.","ref":"AWS.Ivs.html#delete_stream_key/3","title":"AWS.Ivs.delete_stream_key/3","type":"function"},{"doc":"Gets the channel configuration for the specified channel ARN.\n\nSee also `BatchGetChannel`.","ref":"AWS.Ivs.html#get_channel/3","title":"AWS.Ivs.get_channel/3","type":"function"},{"doc":"Gets a specified playback authorization key pair and returns the `arn` and\n`fingerprint`.\n\nThe `privateKey` held by the caller can be used to generate viewer authorization\ntokens, to grant viewers access to private channels. For more information, see\n[Setting Up Private Channels](https://docs.aws.amazon.com/ivs/latest/userguide/private-channels.html)\nin the *Amazon IVS User Guide*.","ref":"AWS.Ivs.html#get_playback_key_pair/3","title":"AWS.Ivs.get_playback_key_pair/3","type":"function"},{"doc":"Gets the specified playback restriction policy.","ref":"AWS.Ivs.html#get_playback_restriction_policy/3","title":"AWS.Ivs.get_playback_restriction_policy/3","type":"function"},{"doc":"Gets the recording configuration for the specified ARN.","ref":"AWS.Ivs.html#get_recording_configuration/3","title":"AWS.Ivs.get_recording_configuration/3","type":"function"},{"doc":"Gets information about the active (live) stream on a specified channel.","ref":"AWS.Ivs.html#get_stream/3","title":"AWS.Ivs.get_stream/3","type":"function"},{"doc":"Gets stream-key information for a specified ARN.","ref":"AWS.Ivs.html#get_stream_key/3","title":"AWS.Ivs.get_stream_key/3","type":"function"},{"doc":"Gets metadata on a specified stream.","ref":"AWS.Ivs.html#get_stream_session/3","title":"AWS.Ivs.get_stream_session/3","type":"function"},{"doc":"Imports the public portion of a new key pair and returns its `arn` and\n`fingerprint`.\n\nThe `privateKey` can then be used to generate viewer authorization tokens, to\ngrant viewers access to private channels. For more information, see [Setting Up Private\nChannels](https://docs.aws.amazon.com/ivs/latest/userguide/private-channels.html)\nin the *Amazon IVS User Guide*.","ref":"AWS.Ivs.html#import_playback_key_pair/3","title":"AWS.Ivs.import_playback_key_pair/3","type":"function"},{"doc":"Gets summary information about all channels in your account, in the Amazon Web\nServices region where the API request is processed.\n\nThis list can be filtered to match a specified name or recording-configuration\nARN. Filters are mutually exclusive and cannot be used together. If you try to\nuse both filters, you will get an error (409 ConflictException).","ref":"AWS.Ivs.html#list_channels/3","title":"AWS.Ivs.list_channels/3","type":"function"},{"doc":"Gets summary information about playback key pairs.\n\nFor more information, see [Setting Up Private Channels](https://docs.aws.amazon.com/ivs/latest/userguide/private-channels.html)\nin the *Amazon IVS User Guide*.","ref":"AWS.Ivs.html#list_playback_key_pairs/3","title":"AWS.Ivs.list_playback_key_pairs/3","type":"function"},{"doc":"Gets summary information about playback restriction policies.","ref":"AWS.Ivs.html#list_playback_restriction_policies/3","title":"AWS.Ivs.list_playback_restriction_policies/3","type":"function"},{"doc":"Gets summary information about all recording configurations in your account, in\nthe Amazon Web Services region where the API request is processed.","ref":"AWS.Ivs.html#list_recording_configurations/3","title":"AWS.Ivs.list_recording_configurations/3","type":"function"},{"doc":"Gets summary information about stream keys for the specified channel.","ref":"AWS.Ivs.html#list_stream_keys/3","title":"AWS.Ivs.list_stream_keys/3","type":"function"},{"doc":"Gets a summary of current and previous streams for a specified channel in your\naccount, in the AWS region where the API request is processed.","ref":"AWS.Ivs.html#list_stream_sessions/3","title":"AWS.Ivs.list_stream_sessions/3","type":"function"},{"doc":"Gets summary information about live streams in your account, in the Amazon Web\nServices region where the API request is processed.","ref":"AWS.Ivs.html#list_streams/3","title":"AWS.Ivs.list_streams/3","type":"function"},{"doc":"Gets information about Amazon Web Services tags for the specified ARN.","ref":"AWS.Ivs.html#list_tags_for_resource/3","title":"AWS.Ivs.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.Ivs.html#metadata/0","title":"AWS.Ivs.metadata/0","type":"function"},{"doc":"Inserts metadata into the active stream of the specified channel.\n\nAt most 5 requests per second per channel are allowed, each with a maximum 1 KB\npayload. (If 5 TPS is not sufficient for your needs, we recommend batching your\ndata into a single PutMetadata call.) At most 155 requests per second per\naccount are allowed. Also see [Embedding Metadata within a Video Stream](https://docs.aws.amazon.com/ivs/latest/userguide/metadata.html) in the\n*Amazon IVS User Guide*.","ref":"AWS.Ivs.html#put_metadata/3","title":"AWS.Ivs.put_metadata/3","type":"function"},{"doc":"Starts the process of revoking the viewer session associated with a specified\nchannel ARN and viewer ID.\n\nOptionally, you can provide a version to revoke viewer sessions less than and\nincluding that version. For instructions on associating a viewer ID with a\nviewer session, see [Setting Up Private Channels](https://docs.aws.amazon.com/ivs/latest/userguide/private-channels.html).","ref":"AWS.Ivs.html#start_viewer_session_revocation/3","title":"AWS.Ivs.start_viewer_session_revocation/3","type":"function"},{"doc":"Disconnects the incoming RTMPS stream for the specified channel.\n\nCan be used in conjunction with `DeleteStreamKey` to prevent further streaming\nto a channel.\n\nMany streaming client-software libraries automatically reconnect a dropped RTMPS\nsession, so to stop the stream permanently, you may want to first revoke the\n`streamKey` attached to the channel.","ref":"AWS.Ivs.html#stop_stream/3","title":"AWS.Ivs.stop_stream/3","type":"function"},{"doc":"Adds or updates tags for the Amazon Web Services resource with the specified\nARN.","ref":"AWS.Ivs.html#tag_resource/4","title":"AWS.Ivs.tag_resource/4","type":"function"},{"doc":"Removes tags from the resource with the specified ARN.","ref":"AWS.Ivs.html#untag_resource/4","title":"AWS.Ivs.untag_resource/4","type":"function"},{"doc":"Updates a channel's configuration.\n\nLive channels cannot be updated. You must stop the ongoing stream, update the\nchannel, and restart the stream for the changes to take effect.","ref":"AWS.Ivs.html#update_channel/3","title":"AWS.Ivs.update_channel/3","type":"function"},{"doc":"Updates a specified playback restriction policy.","ref":"AWS.Ivs.html#update_playback_restriction_policy/3","title":"AWS.Ivs.update_playback_restriction_policy/3","type":"function"},{"doc":"","ref":"AWS.Ivschat.html","title":"AWS.Ivschat","type":"module"},{"doc":"The Amazon IVS Chat control-plane API enables you to create and manage Amazon\nIVS Chat resources.\n\nYou also need to integrate with the [ Amazon IVS Chat Messaging API](https://docs.aws.amazon.com/ivs/latest/chatmsgapireference/chat-messaging-api.html),\nto enable users to interact with chat rooms in real time.\n\nThe API is an AWS regional service. For a list of supported regions and Amazon\nIVS Chat HTTPS service endpoints, see the Amazon IVS Chat information on the\n[Amazon IVS page](https://docs.aws.amazon.com/general/latest/gr/ivs.html) in the *AWS General Reference*.","ref":"AWS.Ivschat.html#module-introduction","title":"Introduction - AWS.Ivschat","type":"module"},{"doc":"* You create service applications using the Amazon IVS Chat API. We\nrefer to these as *applications*.\n\n  * You create front-end client applications (browser and Android/iOS\napps) using the Amazon IVS Chat Messaging API. We refer to these as *clients*.","ref":"AWS.Ivschat.html#module-notes-on-terminology","title":"Notes on terminology: - AWS.Ivschat","type":"module"},{"doc":"The following resources are part of Amazon IVS Chat:\n\n  * **LoggingConfiguration** — A configuration that allows customers\nto store and record sent messages in a chat room. See the Logging Configuration\nendpoints for more information.\n\n  * **Room** — The central Amazon IVS Chat resource through which\nclients connect to and exchange chat messages. See the Room endpoints for more\ninformation.","ref":"AWS.Ivschat.html#module-resources","title":"Resources - AWS.Ivschat","type":"module"},{"doc":"A *tag* is a metadata label that you assign to an AWS resource. A tag comprises\na *key* and a *value*, both set by you. For example, you might set a tag as\n`topic:nature` to label a particular video category. See [Tagging AWS\nResources](https://docs.aws.amazon.com/general/latest/gr/aws_tagging.html) for\nmore information, including restrictions that apply to tags and \"Tag naming\nlimits and requirements\"; Amazon IVS Chat has no service-specific constraints\nbeyond what is documented there.\n\nTags can help you identify and organize your AWS resources. For example, you can\nuse the same tag for different resources to indicate that they are related. You\ncan also use tags to manage access (see [Access Tags](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_tags.html)).\n\nThe Amazon IVS Chat API has these tag-related endpoints: `TagResource`,\n`UntagResource`, and `ListTagsForResource`. The following resource supports\ntagging: Room.\n\nAt most 50 tags can be applied to a resource.","ref":"AWS.Ivschat.html#module-tagging","title":"Tagging - AWS.Ivschat","type":"module"},{"doc":"Your Amazon IVS Chat applications (service applications and clients) must be\nauthenticated and authorized to access Amazon IVS Chat resources. Note the\ndifferences between these concepts:\n\n  * *Authentication* is about verifying identity. Requests to the\nAmazon IVS Chat API must be signed to verify your identity.\n\n  * *Authorization* is about granting permissions. Your IAM roles need\nto have permissions for Amazon IVS Chat API requests.\n\nUsers (viewers) connect to a room using secure access tokens that you create\nusing the `CreateChatToken` endpoint through the AWS SDK. You call\nCreateChatToken for every user’s chat session, passing identity and\nauthorization information about the user.","ref":"AWS.Ivschat.html#module-api-access-security","title":"API Access Security - AWS.Ivschat","type":"module"},{"doc":"HTTP API requests must be signed with an AWS SigV4 signature using your AWS\nsecurity credentials. The AWS Command Line Interface (CLI) and the AWS SDKs take\ncare of signing the underlying API calls for you. However, if your application\ncalls the Amazon IVS Chat HTTP API directly, it’s your responsibility to sign\nthe requests.\n\nYou generate a signature using valid AWS credentials for an IAM role that has\npermission to perform the requested action. For example, DeleteMessage requests\nmust be made using an IAM role that has the `ivschat:DeleteMessage` permission.\n\nFor more information:\n\n  * Authentication and generating signatures — See [Authenticating Requests (Amazon Web Services Signature Version\n4)](https://docs.aws.amazon.com/AmazonS3/latest/API/sig-v4-authenticating-requests.html)\nin the *Amazon Web Services General Reference*.\n\n  * Managing Amazon IVS permissions — See [Identity and Access Management](https://docs.aws.amazon.com/ivs/latest/userguide/security-iam.html)\non the Security page of the *Amazon IVS User Guide*.","ref":"AWS.Ivschat.html#module-signing-api-requests","title":"Signing API Requests - AWS.Ivschat","type":"module"},{"doc":"ARNs uniquely identify AWS resources. An ARN is required when you need to\nspecify a resource unambiguously across all of AWS, such as in IAM policies and\nAPI calls. For more information, see [Amazon Resource Names](https://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html)\nin the *AWS General Reference*.","ref":"AWS.Ivschat.html#module-amazon-resource-names-arns","title":"Amazon Resource Names (ARNs) - AWS.Ivschat","type":"module"},{"doc":"* `DeleteMessage` — Sends an event to a specific room which directs\nclients to delete a specific message; that is, unrender it from view and delete\nit from the client’s chat history. This event’s `EventName` is\n`aws:DELETE_MESSAGE`. This replicates the [\nDeleteMessage](https://docs.aws.amazon.com/ivs/latest/chatmsgapireference/actions-deletemessage-publish.html)\nWebSocket operation in the Amazon IVS Chat Messaging API.\n\n  * `DisconnectUser` — Disconnects all connections using a specified\nuser ID from a room. This replicates the [\nDisconnectUser](https://docs.aws.amazon.com/ivs/latest/chatmsgapireference/actions-disconnectuser-publish.html)\nWebSocket operation in the Amazon IVS Chat Messaging API.\n\n  * `SendEvent` — Sends an event to a room. Use this within your\napplication’s business logic to send events to clients of a room; e.g., to\nnotify clients to change the way the chat UI is rendered.","ref":"AWS.Ivschat.html#module-messaging-endpoints","title":"Messaging Endpoints - AWS.Ivschat","type":"module"},{"doc":"* `CreateChatToken` — Creates an encrypted token that is used by a\nchat participant to establish an individual WebSocket chat connection to a room.\nWhen the token is used to connect to chat, the connection is valid for the\nsession duration specified in the request. The token becomes invalid at the\ntoken-expiration timestamp included in the response.","ref":"AWS.Ivschat.html#module-chat-token-endpoint","title":"Chat Token Endpoint - AWS.Ivschat","type":"module"},{"doc":"* `CreateRoom` — Creates a room that allows clients to connect and\npass messages.\n\n  * `DeleteRoom` — Deletes the specified room.\n\n  * `GetRoom` — Gets the specified room.\n\n  * `ListRooms` — Gets summary information about all your rooms in the\nAWS region where the API request is processed.\n\n  * `UpdateRoom` — Updates a room’s configuration.","ref":"AWS.Ivschat.html#module-room-endpoints","title":"Room Endpoints - AWS.Ivschat","type":"module"},{"doc":"* `CreateLoggingConfiguration` — Creates a logging configuration\nthat allows clients to store and record sent messages.\n\n  * `DeleteLoggingConfiguration` — Deletes the specified logging\nconfiguration.\n\n  * `GetLoggingConfiguration` — Gets the specified logging\nconfiguration.\n\n  * `ListLoggingConfigurations` — Gets summary information about all\nyour logging configurations in the AWS region where the API request is\nprocessed.\n\n  * `UpdateLoggingConfiguration` — Updates a specified logging\nconfiguration.","ref":"AWS.Ivschat.html#module-logging-configuration-endpoints","title":"Logging Configuration Endpoints - AWS.Ivschat","type":"module"},{"doc":"* `ListTagsForResource` — Gets information about AWS tags for the\nspecified ARN.\n\n  * `TagResource` — Adds or updates tags for the AWS resource with the\nspecified ARN.\n\n  * `UntagResource` — Removes tags from the resource with the\nspecified ARN.\n\nAll the above are HTTP operations. There is a separate *messaging* API for\nmanaging Chat resources; see the [ Amazon IVS Chat Messaging API Reference](https://docs.aws.amazon.com/ivs/latest/chatmsgapireference/chat-messaging-api.html).","ref":"AWS.Ivschat.html#module-tags-endpoints","title":"Tags Endpoints - AWS.Ivschat","type":"module"},{"doc":"Creates an encrypted token that is used by a chat participant to establish an\nindividual WebSocket chat connection to a room.\n\nWhen the token is used to connect to chat, the connection is valid for the\nsession duration specified in the request. The token becomes invalid at the\ntoken-expiration timestamp included in the response.\n\nUse the `capabilities` field to permit an end user to send messages or moderate\na room.\n\nThe `attributes` field securely attaches structured data to the chat session;\nthe data is included within each message sent by the end user and received by\nother participants in the room. Common use cases for attributes include passing\nend-user profile data like an icon, display name, colors, badges, and other\ndisplay features.\n\nEncryption keys are owned by Amazon IVS Chat and never used directly by your\napplication.","ref":"AWS.Ivschat.html#create_chat_token/3","title":"AWS.Ivschat.create_chat_token/3","type":"function"},{"doc":"Creates a logging configuration that allows clients to store and record sent\nmessages.","ref":"AWS.Ivschat.html#create_logging_configuration/3","title":"AWS.Ivschat.create_logging_configuration/3","type":"function"},{"doc":"Creates a room that allows clients to connect and pass messages.","ref":"AWS.Ivschat.html#create_room/3","title":"AWS.Ivschat.create_room/3","type":"function"},{"doc":"Deletes the specified logging configuration.","ref":"AWS.Ivschat.html#delete_logging_configuration/3","title":"AWS.Ivschat.delete_logging_configuration/3","type":"function"},{"doc":"Sends an event to a specific room which directs clients to delete a specific\nmessage; that is, unrender it from view and delete it from the client’s chat\nhistory.\n\nThis event’s `EventName` is `aws:DELETE_MESSAGE`. This replicates the [\nDeleteMessage](https://docs.aws.amazon.com/ivs/latest/chatmsgapireference/actions-deletemessage-publish.html)\nWebSocket operation in the Amazon IVS Chat Messaging API.","ref":"AWS.Ivschat.html#delete_message/3","title":"AWS.Ivschat.delete_message/3","type":"function"},{"doc":"Deletes the specified room.","ref":"AWS.Ivschat.html#delete_room/3","title":"AWS.Ivschat.delete_room/3","type":"function"},{"doc":"Disconnects all connections using a specified user ID from a room.\n\nThis replicates the [\nDisconnectUser](https://docs.aws.amazon.com/ivs/latest/chatmsgapireference/actions-disconnectuser-publish.html)\nWebSocket operation in the Amazon IVS Chat Messaging API.","ref":"AWS.Ivschat.html#disconnect_user/3","title":"AWS.Ivschat.disconnect_user/3","type":"function"},{"doc":"Gets the specified logging configuration.","ref":"AWS.Ivschat.html#get_logging_configuration/3","title":"AWS.Ivschat.get_logging_configuration/3","type":"function"},{"doc":"Gets the specified room.","ref":"AWS.Ivschat.html#get_room/3","title":"AWS.Ivschat.get_room/3","type":"function"},{"doc":"Gets summary information about all your logging configurations in the AWS region\nwhere the API request is processed.","ref":"AWS.Ivschat.html#list_logging_configurations/3","title":"AWS.Ivschat.list_logging_configurations/3","type":"function"},{"doc":"Gets summary information about all your rooms in the AWS region where the API\nrequest is processed.\n\nResults are sorted in descending order of `updateTime`.","ref":"AWS.Ivschat.html#list_rooms/3","title":"AWS.Ivschat.list_rooms/3","type":"function"},{"doc":"Gets information about AWS tags for the specified ARN.","ref":"AWS.Ivschat.html#list_tags_for_resource/3","title":"AWS.Ivschat.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.Ivschat.html#metadata/0","title":"AWS.Ivschat.metadata/0","type":"function"},{"doc":"Sends an event to a room.\n\nUse this within your application’s business logic to send events to clients of a\nroom; e.g., to notify clients to change the way the chat UI is rendered.","ref":"AWS.Ivschat.html#send_event/3","title":"AWS.Ivschat.send_event/3","type":"function"},{"doc":"Adds or updates tags for the AWS resource with the specified ARN.","ref":"AWS.Ivschat.html#tag_resource/4","title":"AWS.Ivschat.tag_resource/4","type":"function"},{"doc":"Removes tags from the resource with the specified ARN.","ref":"AWS.Ivschat.html#untag_resource/4","title":"AWS.Ivschat.untag_resource/4","type":"function"},{"doc":"Updates a specified logging configuration.","ref":"AWS.Ivschat.html#update_logging_configuration/3","title":"AWS.Ivschat.update_logging_configuration/3","type":"function"},{"doc":"Updates a room’s configuration.","ref":"AWS.Ivschat.html#update_room/3","title":"AWS.Ivschat.update_room/3","type":"function"},{"doc":"Key Management Service\n\nKey Management Service (KMS) is an encryption and key management web service.\n\nThis guide describes the KMS operations that you can call programmatically. For\ngeneral information about KMS, see the [ *Key Management Service Developer Guide* ](https://docs.aws.amazon.com/kms/latest/developerguide/).\n\nKMS has replaced the term *customer master key (CMK)* with *KMS key* and *KMS\nkey*. The concept has not changed. To prevent breaking changes, KMS is keeping\nsome variations of this term.\n\nAmazon Web Services provides SDKs that consist of libraries and sample code for\nvarious programming languages and platforms (Java, Ruby, .Net, macOS, Android,\netc.). The SDKs provide a convenient way to create programmatic access to KMS\nand other Amazon Web Services services. For example, the SDKs take care of tasks\nsuch as signing requests (see below), managing errors, and retrying requests\nautomatically. For more information about the Amazon Web Services SDKs,\nincluding how to download and install them, see [Tools for Amazon Web Services](http://aws.amazon.com/tools/).\n\nWe recommend that you use the Amazon Web Services SDKs to make programmatic API\ncalls to KMS.\n\nIf you need to use FIPS 140-2 validated cryptographic modules when communicating\nwith Amazon Web Services, use the FIPS endpoint in your preferred Amazon Web\nServices Region. For more information about the available FIPS endpoints, see\n[Service endpoints](https://docs.aws.amazon.com/general/latest/gr/kms.html#kms_region) in\nthe Key Management Service topic of the *Amazon Web Services General Reference*.\n\nAll KMS API calls must be signed and be transmitted using Transport Layer\nSecurity (TLS). KMS recommends you always use the latest supported TLS version.\nClients must also support cipher suites with Perfect Forward Secrecy (PFS) such\nas Ephemeral Diffie-Hellman (DHE) or Elliptic Curve Ephemeral Diffie-Hellman\n(ECDHE). Most modern systems such as Java 7 and later support these modes.","ref":"AWS.KMS.html","title":"AWS.KMS","type":"module"},{"doc":"Requests must be signed using an access key ID and a secret access key. We\nstrongly recommend that you do not use your Amazon Web Services account root\naccess key ID and secret access key for everyday work. You can use the access\nkey ID and secret access key for an IAM user or you can use the Security Token\nService (STS) to generate temporary security credentials and use those to sign\nrequests.\n\nAll KMS requests must be signed with [Signature Version 4](https://docs.aws.amazon.com/general/latest/gr/signature-version-4.html).","ref":"AWS.KMS.html#module-signing-requests","title":"Signing Requests - AWS.KMS","type":"module"},{"doc":"KMS supports CloudTrail, a service that logs Amazon Web Services API calls and\nrelated events for your Amazon Web Services account and delivers them to an\nAmazon S3 bucket that you specify. By using the information collected by\nCloudTrail, you can determine what requests were made to KMS, who made the\nrequest, when it was made, and so on. To learn more about CloudTrail, including\nhow to turn it on and find your log files, see the [CloudTrail User Guide](https://docs.aws.amazon.com/awscloudtrail/latest/userguide/).","ref":"AWS.KMS.html#module-logging-api-requests","title":"Logging API Requests - AWS.KMS","type":"module"},{"doc":"For more information about credentials and request signing, see the following:\n\n  * [Amazon Web Services Security Credentials](https://docs.aws.amazon.com/general/latest/gr/aws-security-credentials.html)\n- This topic provides general information about the types of credentials used to\naccess Amazon Web Services.\n\n  * [Temporary Security Credentials](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp.html)\n- This section of the *IAM User Guide* describes how to create and use temporary\nsecurity credentials.\n\n  * [Signature Version 4 Signing Process](https://docs.aws.amazon.com/general/latest/gr/signature-version-4.html)\n- This set of topics walks you through the process of signing a request using an\naccess key ID and a secret access key.","ref":"AWS.KMS.html#module-additional-resources","title":"Additional Resources - AWS.KMS","type":"module"},{"doc":"Of the API operations discussed in this guide, the following will prove the most\nuseful for most applications. You will likely perform operations other than\nthese, such as creating keys and assigning policies, by using the console.\n\n  * `Encrypt`\n\n  * `Decrypt`\n\n  * `GenerateDataKey`\n\n  * `GenerateDataKeyWithoutPlaintext`","ref":"AWS.KMS.html#module-commonly-used-api-operations","title":"Commonly Used API Operations - AWS.KMS","type":"module"},{"doc":"Cancels the deletion of a KMS key.\n\nWhen this operation succeeds, the key state of the KMS key is `Disabled`. To\nenable the KMS key, use `EnableKey`.\n\nFor more information about scheduling and canceling deletion of a KMS key, see\n[Deleting KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/deleting-keys.html)\nin the *Key Management Service Developer Guide*.\n\nThe KMS key that you use for this operation must be in a compatible key state.\nFor details, see [Key states of KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/key-state.html) in\nthe *Key Management Service Developer Guide*.\n\n**Cross-account use**: No. You cannot perform this operation on a KMS key in a\ndifferent Amazon Web Services account.\n\n**Required permissions**:\n[kms:CancelKeyDeletion](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html) (key policy)\n\n**Related operations**: `ScheduleKeyDeletion`\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual\nconsistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#cancel_key_deletion/3","title":"AWS.KMS.cancel_key_deletion/3","type":"function"},{"doc":"Connects or reconnects a [custom key store](https://docs.aws.amazon.com/kms/latest/developerguide/custom-key-store-overview.html)\nto its backing key store.\n\nFor an CloudHSM key store, `ConnectCustomKeyStore` connects the key store to its\nassociated CloudHSM cluster. For an external key store, `ConnectCustomKeyStore`\nconnects the key store to the external key store proxy that communicates with\nyour external key manager.\n\nThe custom key store must be connected before you can create KMS keys in the key\nstore or use the KMS keys it contains. You can disconnect and reconnect a custom\nkey store at any time.\n\nThe connection process for a custom key store can take an extended amount of\ntime to complete. This operation starts the connection process, but it does not\nwait for it to complete. When it succeeds, this operation quickly returns an\nHTTP 200 response and a JSON object with no properties. However, this response\ndoes not indicate that the custom key store is connected. To get the connection\nstate of the custom key store, use the `DescribeCustomKeyStores` operation.\n\nThis operation is part of the [custom key stores](https://docs.aws.amazon.com/kms/latest/developerguide/custom-key-store-overview.html)\nfeature in KMS, which combines the convenience and extensive integration of KMS\nwith the isolation and control of a key store that you own and manage.\n\nThe `ConnectCustomKeyStore` operation might fail for various reasons. To find\nthe reason, use the `DescribeCustomKeyStores` operation and see the\n`ConnectionErrorCode` in the response. For help interpreting the\n`ConnectionErrorCode`, see `CustomKeyStoresListEntry`.\n\nTo fix the failure, use the `DisconnectCustomKeyStore` operation to disconnect\nthe custom key store, correct the error, use the `UpdateCustomKeyStore`\noperation if necessary, and then use `ConnectCustomKeyStore` again.","ref":"AWS.KMS.html#connect_custom_key_store/3","title":"AWS.KMS.connect_custom_key_store/3","type":"function"},{"doc":"During the connection process for an CloudHSM key store, KMS finds the CloudHSM\ncluster that is associated with the custom key store, creates the connection\ninfrastructure, connects to the cluster, logs into the CloudHSM client as the\n`kmsuser` CU, and rotates its password.\n\nTo connect an CloudHSM key store, its associated CloudHSM cluster must have at\nleast one active HSM. To get the number of active HSMs in a cluster, use the\n[DescribeClusters](https://docs.aws.amazon.com/cloudhsm/latest/APIReference/API_DescribeClusters.html) operation. To add HSMs to the cluster, use the\n[CreateHsm](https://docs.aws.amazon.com/cloudhsm/latest/APIReference/API_CreateHsm.html)\noperation. Also, the [ `kmsuser` crypto user](https://docs.aws.amazon.com/kms/latest/developerguide/key-store-concepts.html#concept-kmsuser)\n(CU) must not be logged into the cluster. This prevents KMS from using this\naccount to log in.\n\nIf you are having trouble connecting or disconnecting a CloudHSM key store, see\n[Troubleshooting an CloudHSM key store](https://docs.aws.amazon.com/kms/latest/developerguide/fix-keystore.html)\nin the *Key Management Service Developer Guide*.","ref":"AWS.KMS.html#connect_custom_key_store/3-cloudhsm-key-store","title":"CloudHSM key store - AWS.KMS.connect_custom_key_store/3","type":"function"},{"doc":"When you connect an external key store that uses public endpoint connectivity,\nKMS tests its ability to communicate with your external key manager by sending a\nrequest via the external key store proxy.\n\nWhen you connect to an external key store that uses VPC endpoint service\nconnectivity, KMS establishes the networking elements that it needs to\ncommunicate with your external key manager via the external key store proxy.\nThis includes creating an interface endpoint to the VPC endpoint service and a\nprivate hosted zone for traffic between KMS and the VPC endpoint service.\n\nTo connect an external key store, KMS must be able to connect to the external\nkey store proxy, the external key store proxy must be able to communicate with\nyour external key manager, and the external key manager must be available for\ncryptographic operations.\n\nIf you are having trouble connecting or disconnecting an external key store, see\n[Troubleshooting an external key store](https://docs.aws.amazon.com/kms/latest/developerguide/xks-troubleshooting.html)\nin the *Key Management Service Developer Guide*.\n\n**Cross-account use**: No. You cannot perform this operation on a custom key\nstore in a different Amazon Web Services account.\n\n**Required permissions**:\n[kms:ConnectCustomKeyStore](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html) (IAM policy)","ref":"AWS.KMS.html#connect_custom_key_store/3-external-key-store","title":"External key store - AWS.KMS.connect_custom_key_store/3","type":"function"},{"doc":"* `CreateCustomKeyStore`\n\n  * `DeleteCustomKeyStore`\n\n  * `DescribeCustomKeyStores`\n\n  * `DisconnectCustomKeyStore`\n\n  * `UpdateCustomKeyStore`\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual\nconsistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#connect_custom_key_store/3-related-operations","title":"Related operations - AWS.KMS.connect_custom_key_store/3","type":"function"},{"doc":"Creates a friendly name for a KMS key.\n\nAdding, deleting, or updating an alias can allow or deny permission to the KMS\nkey. For details, see [ABAC for KMS](https://docs.aws.amazon.com/kms/latest/developerguide/abac.html) in the\n*Key Management Service Developer Guide*.\n\nYou can use an alias to identify a KMS key in the KMS console, in the\n`DescribeKey` operation and in [cryptographic operations](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#cryptographic-operations),\nsuch as `Encrypt` and `GenerateDataKey`. You can also change the KMS key that's\nassociated with the alias (`UpdateAlias`) or delete the alias (`DeleteAlias`) at\nany time. These operations don't affect the underlying KMS key.\n\nYou can associate the alias with any customer managed key in the same Amazon Web\nServices Region. Each alias is associated with only one KMS key at a time, but a\nKMS key can have multiple aliases. A valid KMS key is required. You can't create\nan alias without a KMS key.\n\nThe alias must be unique in the account and Region, but you can have aliases\nwith the same name in different Regions. For detailed information about aliases,\nsee [Using aliases](https://docs.aws.amazon.com/kms/latest/developerguide/kms-alias.html)\nin the *Key Management Service Developer Guide*.\n\nThis operation does not return a response. To get the alias that you created,\nuse the `ListAliases` operation.\n\nThe KMS key that you use for this operation must be in a compatible key state.\nFor details, see [Key states of KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/key-state.html) in\nthe *Key Management Service Developer Guide*.\n\n**Cross-account use**: No. You cannot perform this operation on an alias in a\ndifferent Amazon Web Services account.","ref":"AWS.KMS.html#create_alias/3","title":"AWS.KMS.create_alias/3","type":"function"},{"doc":"*\n[kms:CreateAlias](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html) on the alias (IAM policy).\n\n  *\n[kms:CreateAlias](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html)\non the KMS key (key policy).\n\nFor details, see [Controlling access to aliases](https://docs.aws.amazon.com/kms/latest/developerguide/kms-alias.html#alias-access)\nin the *Key Management Service Developer Guide*.","ref":"AWS.KMS.html#create_alias/3-required-permissions","title":"Required permissions - AWS.KMS.create_alias/3","type":"function"},{"doc":"* `DeleteAlias`\n\n  * `ListAliases`\n\n  * `UpdateAlias`\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual consistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#create_alias/3-related-operations","title":"Related operations: - AWS.KMS.create_alias/3","type":"function"},{"doc":"Creates a [custom key store](https://docs.aws.amazon.com/kms/latest/developerguide/custom-key-store-overview.html)\nbacked by a key store that you own and manage.\n\nWhen you use a KMS key in a custom key store for a cryptographic operation, the\ncryptographic operation is actually performed in your key store using your keys.\nKMS supports [CloudHSM key stores](https://docs.aws.amazon.com/kms/latest/developerguide/keystore-cloudhsm.html)\nbacked by an [CloudHSM cluster](https://docs.aws.amazon.com/cloudhsm/latest/userguide/clusters.html)\nand [external key stores](https://docs.aws.amazon.com/kms/latest/developerguide/keystore-external.html)\nbacked by an external key store proxy and external key manager outside of Amazon\nWeb Services.\n\nThis operation is part of the [custom key stores](https://docs.aws.amazon.com/kms/latest/developerguide/custom-key-store-overview.html)\nfeature in KMS, which combines the convenience and extensive integration of KMS\nwith the isolation and control of a key store that you own and manage.\n\nBefore you create the custom key store, the required elements must be in place\nand operational. We recommend that you use the test tools that KMS provides to\nverify the configuration your external key store proxy. For details about the\nrequired elements and verification tests, see [Assemble the prerequisites (for CloudHSM key\nstores)](https://docs.aws.amazon.com/kms/latest/developerguide/create-keystore.html#before-keystore)\nor [Assemble the prerequisites (for external key stores)](https://docs.aws.amazon.com/kms/latest/developerguide/create-xks-keystore.html#xks-requirements)\nin the *Key Management Service Developer Guide*.\n\nTo create a custom key store, use the following parameters.\n\n  * To create an CloudHSM key store, specify the `CustomKeyStoreName`,\n`CloudHsmClusterId`, `KeyStorePassword`, and `TrustAnchorCertificate`. The\n`CustomKeyStoreType` parameter is optional for CloudHSM key stores. If you\ninclude it, set it to the default value, `AWS_CLOUDHSM`. For help with failures,\nsee [Troubleshooting an CloudHSM key store](https://docs.aws.amazon.com/kms/latest/developerguide/fix-keystore.html)\nin the *Key Management Service Developer Guide*.\n\n  * To create an external key store, specify the `CustomKeyStoreName`\nand a `CustomKeyStoreType` of `EXTERNAL_KEY_STORE`. Also, specify values for\n`XksProxyConnectivity`, `XksProxyAuthenticationCredential`,\n`XksProxyUriEndpoint`, and `XksProxyUriPath`. If your `XksProxyConnectivity`\nvalue is `VPC_ENDPOINT_SERVICE`, specify the `XksProxyVpcEndpointServiceName`\nparameter. For help with failures, see [Troubleshooting an external key store](https://docs.aws.amazon.com/kms/latest/developerguide/xks-troubleshooting.html)\nin the *Key Management Service Developer Guide*.\n\nFor external key stores:\n\nSome external key managers provide a simpler method for creating an external key\nstore. For details, see your external key manager documentation.\n\nWhen creating an external key store in the KMS console, you can upload a\nJSON-based proxy configuration file with the desired values. You cannot use a\nproxy configuration with the `CreateCustomKeyStore` operation. However, you can\nuse the values in the file to help you determine the correct values for the\n`CreateCustomKeyStore` parameters.\n\nWhen the operation completes successfully, it returns the ID of the new custom\nkey store. Before you can use your new custom key store, you need to use the\n`ConnectCustomKeyStore` operation to connect a new CloudHSM key store to its\nCloudHSM cluster, or to connect a new external key store to the external key\nstore proxy for your external key manager. Even if you are not going to use your\ncustom key store immediately, you might want to connect it to verify that all\nsettings are correct and then disconnect it until you are ready to use it.\n\nFor help with failures, see [Troubleshooting a custom key store](https://docs.aws.amazon.com/kms/latest/developerguide/fix-keystore.html)\nin the *Key Management Service Developer Guide*.\n\n**Cross-account use**: No. You cannot perform this operation on a custom key\nstore in a different Amazon Web Services account.\n\n**Required permissions**:\n[kms:CreateCustomKeyStore](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html) (IAM policy).","ref":"AWS.KMS.html#create_custom_key_store/3","title":"AWS.KMS.create_custom_key_store/3","type":"function"},{"doc":"* `ConnectCustomKeyStore`\n\n  * `DeleteCustomKeyStore`\n\n  * `DescribeCustomKeyStores`\n\n  * `DisconnectCustomKeyStore`\n\n  * `UpdateCustomKeyStore`\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual\nconsistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#create_custom_key_store/3-related-operations","title":"Related operations: - AWS.KMS.create_custom_key_store/3","type":"function"},{"doc":"Adds a grant to a KMS key.\n\nA *grant* is a policy instrument that allows Amazon Web Services principals to\nuse KMS keys in cryptographic operations. It also can allow them to view a KMS\nkey (`DescribeKey`) and create and manage grants. When authorizing access to a\nKMS key, grants are considered along with key policies and IAM policies. Grants\nare often used for temporary permissions because you can create one, use its\npermissions, and delete it without changing your key policies or IAM policies.\n\nFor detailed information about grants, including grant terminology, see [Grants in KMS](https://docs.aws.amazon.com/kms/latest/developerguide/grants.html) in\nthe * *Key Management Service Developer Guide* *. For examples of working with\ngrants in several programming languages, see [Programming grants](https://docs.aws.amazon.com/kms/latest/developerguide/programming-grants.html).\n\nThe `CreateGrant` operation returns a `GrantToken` and a `GrantId`.\n\n  * When you create, retire, or revoke a grant, there might be a brief\ndelay, usually less than five minutes, until the grant is available throughout\nKMS. This state is known as *eventual consistency*. Once the grant has achieved\neventual consistency, the grantee principal can use the permissions in the grant\nwithout identifying the grant.\n\nHowever, to use the permissions in the grant immediately, use the `GrantToken`\nthat `CreateGrant` returns. For details, see [Using a grant token](https://docs.aws.amazon.com/kms/latest/developerguide/grant-manage.html#using-grant-token)\nin the * *Key Management Service Developer Guide* *.\n\n  * The `CreateGrant` operation also returns a `GrantId`. You can use\nthe `GrantId` and a key identifier to identify the grant in the `RetireGrant`\nand `RevokeGrant` operations. To find the grant ID, use the `ListGrants` or\n`ListRetirableGrants` operations.\n\nThe KMS key that you use for this operation must be in a compatible key state.\nFor details, see [Key states of KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/key-state.html) in\nthe *Key Management Service Developer Guide*.\n\n**Cross-account use**: Yes. To perform this operation on a KMS key in a\ndifferent Amazon Web Services account, specify the key ARN in the value of the\n`KeyId` parameter.\n\n**Required permissions**:\n[kms:CreateGrant](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html) (key policy)","ref":"AWS.KMS.html#create_grant/3","title":"AWS.KMS.create_grant/3","type":"function"},{"doc":"* `ListGrants`\n\n  * `ListRetirableGrants`\n\n  * `RetireGrant`\n\n  * `RevokeGrant`\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual\nconsistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#create_grant/3-related-operations","title":"Related operations: - AWS.KMS.create_grant/3","type":"function"},{"doc":"Creates a unique customer managed [KMS key](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#kms-keys)\nin your Amazon Web Services account and Region.\n\nYou can use a KMS key in cryptographic operations, such as encryption and\nsigning. Some Amazon Web Services services let you use KMS keys that you create\nand manage to protect your service resources.\n\nA KMS key is a logical representation of a cryptographic key. In addition to the\nkey material used in cryptographic operations, a KMS key includes metadata, such\nas the key ID, key policy, creation date, description, and key state. For\ndetails, see [Managing keys](https://docs.aws.amazon.com/kms/latest/developerguide/getting-started.html)\nin the *Key Management Service Developer Guide*\n\nUse the parameters of `CreateKey` to specify the type of KMS key, the source of\nits key material, its key policy, description, tags, and other properties.\n\nKMS has replaced the term *customer master key (CMK)* with *KMS key* and *KMS\nkey*. The concept has not changed. To prevent breaking changes, KMS is keeping\nsome variations of this term.\n\nTo create different types of KMS keys, use the following guidance:","ref":"AWS.KMS.html#create_key/3","title":"AWS.KMS.create_key/3","type":"function"},{"doc":"#","ref":"AWS.KMS.html#create_key/3-definitions","title":"Definitions - AWS.KMS.create_key/3","type":"function"},{"doc":"By default, `CreateKey` creates a symmetric encryption KMS key with key material\nthat KMS generates. This is the basic and most widely used type of KMS key, and\nprovides the best performance.\n\nTo create a symmetric encryption KMS key, you don't need to specify any\nparameters. The default value for `KeySpec`, `SYMMETRIC_DEFAULT`, the default\nvalue for `KeyUsage`, `ENCRYPT_DECRYPT`, and the default value for `Origin`,\n`AWS_KMS`, create a symmetric encryption KMS key with KMS key material.\n\nIf you need a key for basic encryption and decryption or you are creating a KMS\nkey to protect your resources in an Amazon Web Services service, create a\nsymmetric encryption KMS key. The key material in a symmetric encryption key\nnever leaves KMS unencrypted. You can use a symmetric encryption KMS key to\nencrypt and decrypt data up to 4,096 bytes, but they are typically used to\ngenerate data keys and data keys pairs. For details, see `GenerateDataKey` and\n`GenerateDataKeyPair`.\n\n#","ref":"AWS.KMS.html#create_key/3-symmetric-encryption-kms-key","title":"Symmetric encryption KMS key - AWS.KMS.create_key/3","type":"function"},{"doc":"To create an asymmetric KMS key, use the `KeySpec` parameter to specify the type\nof key material in the KMS key. Then, use the `KeyUsage` parameter to determine\nwhether the KMS key will be used to encrypt and decrypt or sign and verify. You\ncan't change these properties after the KMS key is created.\n\nAsymmetric KMS keys contain an RSA key pair, Elliptic Curve (ECC) key pair, or\nan SM2 key pair (China Regions only). The private key in an asymmetric KMS key\nnever leaves KMS unencrypted. However, you can use the `GetPublicKey` operation\nto download the public key so it can be used outside of KMS. KMS keys with RSA\nor SM2 key pairs can be used to encrypt or decrypt data or sign and verify\nmessages (but not both). KMS keys with ECC key pairs can be used only to sign\nand verify messages. For information about asymmetric KMS keys, see [Asymmetric KMS\nkeys](https://docs.aws.amazon.com/kms/latest/developerguide/symmetric-asymmetric.html)\nin the *Key Management Service Developer Guide*.\n\n#","ref":"AWS.KMS.html#create_key/3-asymmetric-kms-keys","title":"Asymmetric KMS keys - AWS.KMS.create_key/3","type":"function"},{"doc":"To create an HMAC KMS key, set the `KeySpec` parameter to a key spec value for\nHMAC KMS keys. Then set the `KeyUsage` parameter to `GENERATE_VERIFY_MAC`. You\nmust set the key usage even though `GENERATE_VERIFY_MAC` is the only valid key\nusage value for HMAC KMS keys. You can't change these properties after the KMS\nkey is created.\n\nHMAC KMS keys are symmetric keys that never leave KMS unencrypted. You can use\nHMAC keys to generate (`GenerateMac`) and verify (`VerifyMac`) HMAC codes for\nmessages up to 4096 bytes.\n\n#","ref":"AWS.KMS.html#create_key/3-hmac-kms-key","title":"HMAC KMS key - AWS.KMS.create_key/3","type":"function"},{"doc":"#","ref":"AWS.KMS.html#create_key/3-multi-region-primary-keys","title":"Multi-Region primary keys - AWS.KMS.create_key/3","type":"function"},{"doc":"To create a multi-Region *primary key* in the local Amazon Web Services Region,\nuse the `MultiRegion` parameter with a value of `True`. To create a multi-Region\n*replica key*, that is, a KMS key with the same key ID and key material as a\nprimary key, but in a different Amazon Web Services Region, use the\n`ReplicateKey` operation. To change a replica key to a primary key, and its\nprimary key to a replica key, use the `UpdatePrimaryRegion` operation.\n\nYou can create multi-Region KMS keys for all supported KMS key types: symmetric\nencryption KMS keys, HMAC KMS keys, asymmetric encryption KMS keys, and\nasymmetric signing KMS keys. You can also create multi-Region keys with imported\nkey material. However, you can't create multi-Region keys in a custom key store.\n\nThis operation supports *multi-Region keys*, an KMS feature that lets you create\nmultiple interoperable KMS keys in different Amazon Web Services Regions.\nBecause these KMS keys have the same key ID, key material, and other metadata,\nyou can use them interchangeably to encrypt data in one Amazon Web Services\nRegion and decrypt it in a different Amazon Web Services Region without\nre-encrypting the data or making a cross-Region call. For more information about\nmulti-Region keys, see [Multi-Region keys in KMS](https://docs.aws.amazon.com/kms/latest/developerguide/multi-region-keys-overview.html)\nin the *Key Management Service Developer Guide*.\n\nTo import your own key material into a KMS key, begin by creating a KMS key with\nno key material. To do this, use the `Origin` parameter of `CreateKey` with a\nvalue of `EXTERNAL`. Next, use `GetParametersForImport` operation to get a\npublic key and import token. Use the wrapping public key to encrypt your key\nmaterial. Then, use `ImportKeyMaterial` with your import token to import the key\nmaterial. For step-by-step instructions, see [Importing Key Material](https://docs.aws.amazon.com/kms/latest/developerguide/importing-keys.html)\nin the * *Key Management Service Developer Guide* *.\n\nYou can import key material into KMS keys of all supported KMS key types:\nsymmetric encryption KMS keys, HMAC KMS keys, asymmetric encryption KMS keys,\nand asymmetric signing KMS keys. You can also create multi-Region keys with\nimported key material. However, you can't import key material into a KMS key in\na custom key store.\n\nTo create a multi-Region primary key with imported key material, use the\n`Origin` parameter of `CreateKey` with a value of `EXTERNAL` and the\n`MultiRegion` parameter with a value of `True`. To create replicas of the\nmulti-Region primary key, use the `ReplicateKey` operation. For instructions,\nsee [Importing key material into multi-Region keys](https://docs.aws.amazon.com/kms/latest/developerguide/multi-region-keys-import.html\n). For more information about multi-Region keys, see [Multi-Region keys in KMS](https://docs.aws.amazon.com/kms/latest/developerguide/multi-region-keys-overview.html)\nin the *Key Management Service Developer Guide*.\n\n#","ref":"AWS.KMS.html#create_key/3-imported-key-material","title":"Imported key material - AWS.KMS.create_key/3","type":"function"},{"doc":"A [custom key store](https://docs.aws.amazon.com/kms/latest/developerguide/custom-key-store-overview.html)\nlets you protect your Amazon Web Services resources using keys in a backing key\nstore that you own and manage. When you request a cryptographic operation with a\nKMS key in a custom key store, the operation is performed in the backing key\nstore using its cryptographic keys.\n\nKMS supports [CloudHSM key stores](https://docs.aws.amazon.com/kms/latest/developerguide/keystore-cloudhsm.html)\nbacked by an CloudHSM cluster and [external key stores](https://docs.aws.amazon.com/kms/latest/developerguide/keystore-external.html)\nbacked by an external key manager outside of Amazon Web Services. When you\ncreate a KMS key in an CloudHSM key store, KMS generates an encryption key in\nthe CloudHSM cluster and associates it with the KMS key. When you create a KMS\nkey in an external key store, you specify an existing encryption key in the\nexternal key manager.\n\nSome external key managers provide a simpler method for creating a KMS key in an\nexternal key store. For details, see your external key manager documentation.\n\nBefore you create a KMS key in a custom key store, the `ConnectionState` of the\nkey store must be `CONNECTED`. To connect the custom key store, use the\n`ConnectCustomKeyStore` operation. To find the `ConnectionState`, use the\n`DescribeCustomKeyStores` operation.\n\nTo create a KMS key in a custom key store, use the `CustomKeyStoreId`. Use the\ndefault `KeySpec` value, `SYMMETRIC_DEFAULT`, and the default `KeyUsage` value,\n`ENCRYPT_DECRYPT` to create a symmetric encryption key. No other key type is\nsupported in a custom key store.\n\nTo create a KMS key in an [CloudHSM key store](https://docs.aws.amazon.com/kms/latest/developerguide/keystore-cloudhsm.html),\nuse the `Origin` parameter with a value of `AWS_CLOUDHSM`. The CloudHSM cluster\nthat is associated with the custom key store must have at least two active HSMs\nin different Availability Zones in the Amazon Web Services Region.\n\nTo create a KMS key in an [external key store](https://docs.aws.amazon.com/kms/latest/developerguide/keystore-external.html),\nuse the `Origin` parameter with a value of `EXTERNAL_KEY_STORE` and an\n`XksKeyId` parameter that identifies an existing external key.\n\nSome external key managers provide a simpler method for creating a KMS key in an\nexternal key store. For details, see your external key manager documentation.\n\n**Cross-account use**: No. You cannot use this operation to create a KMS key in\na different Amazon Web Services account.\n\n**Required permissions**:\n[kms:CreateKey](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html) (IAM policy). To use the `Tags` parameter,\n[kms:TagResource](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html)\n(IAM policy). For examples and information about related permissions, see [Allow a user to create KMS\nkeys](https://docs.aws.amazon.com/kms/latest/developerguide/iam-policies.html#iam-policy-example-create-key)\nin the *Key Management Service Developer Guide*.","ref":"AWS.KMS.html#create_key/3-custom-key-store","title":"Custom key store - AWS.KMS.create_key/3","type":"function"},{"doc":"* `DescribeKey`\n\n  * `ListKeys`\n\n  * `ScheduleKeyDeletion`\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual consistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#create_key/3-related-operations","title":"Related operations: - AWS.KMS.create_key/3","type":"function"},{"doc":"Decrypts ciphertext that was encrypted by a KMS key using any of the following\noperations:\n\n  * `Encrypt`\n\n  * `GenerateDataKey`\n\n  * `GenerateDataKeyPair`\n\n  * `GenerateDataKeyWithoutPlaintext`\n\n  * `GenerateDataKeyPairWithoutPlaintext`\n\nYou can use this operation to decrypt ciphertext that was encrypted under a\nsymmetric encryption KMS key or an asymmetric encryption KMS key.\n\nWhen the KMS key is asymmetric, you must specify the KMS key and the encryption\nalgorithm that was used to encrypt the ciphertext. For information about\nasymmetric KMS keys, see [Asymmetric KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/symmetric-asymmetric.html)\nin the *Key Management Service Developer Guide*.\n\nThe `Decrypt` operation also decrypts ciphertext that was encrypted outside of\nKMS by the public key in an KMS asymmetric KMS key. However, it cannot decrypt\nsymmetric ciphertext produced by other libraries, such as the [Amazon Web Services Encryption\nSDK](https://docs.aws.amazon.com/encryption-sdk/latest/developer-guide/) or\n[Amazon S3 client-side encryption](https://docs.aws.amazon.com/AmazonS3/latest/dev/UsingClientSideEncryption.html).\nThese libraries return a ciphertext format that is incompatible with KMS.\n\nIf the ciphertext was encrypted under a symmetric encryption KMS key, the\n`KeyId` parameter is optional. KMS can get this information from metadata that\nit adds to the symmetric ciphertext blob. This feature adds durability to your\nimplementation by ensuring that authorized users can decrypt ciphertext decades\nafter it was encrypted, even if they've lost track of the key ID. However,\nspecifying the KMS key is always recommended as a best practice. When you use\nthe `KeyId` parameter to specify a KMS key, KMS only uses the KMS key you\nspecify. If the ciphertext was encrypted under a different KMS key, the\n`Decrypt` operation fails. This practice ensures that you use the KMS key that\nyou intend.\n\nWhenever possible, use key policies to give users permission to call the\n`Decrypt` operation on a particular KMS key, instead of using &IAM; policies.\nOtherwise, you might create an &IAM; policy that gives the user `Decrypt`\npermission on all KMS keys. This user could decrypt ciphertext that was\nencrypted by KMS keys in other accounts if the key policy for the cross-account\nKMS key permits it. If you must use an IAM policy for `Decrypt` permissions,\nlimit the user to particular KMS keys or particular trusted accounts. For\ndetails, see [Best practices for IAM policies](https://docs.aws.amazon.com/kms/latest/developerguide/iam-policies.html#iam-policies-best-practices)\nin the *Key Management Service Developer Guide*.\n\n`Decrypt` also supports [Amazon Web Services Nitro Enclaves](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/nitro-enclave.html),\nwhich provide an isolated compute environment in Amazon EC2. To call `Decrypt`\nfor a Nitro enclave, use the [Amazon Web Services Nitro Enclaves SDK](https://docs.aws.amazon.com/enclaves/latest/user/developing-applications.html#sdk)\nor any Amazon Web Services SDK. Use the `Recipient` parameter to provide the\nattestation document for the enclave. Instead of the plaintext data, the\nresponse includes the plaintext data encrypted with the public key from the\nattestation document (`CiphertextForRecipient`). For information about the\ninteraction between KMS and Amazon Web Services Nitro Enclaves, see [How Amazon Web Services Nitro Enclaves uses\nKMS](https://docs.aws.amazon.com/kms/latest/developerguide/services-nitro-enclaves.html)\nin the *Key Management Service Developer Guide*.\n\nThe KMS key that you use for this operation must be in a compatible key state.\nFor details, see [Key states of KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/key-state.html) in\nthe *Key Management Service Developer Guide*.\n\n**Cross-account use**: Yes. If you use the `KeyId` parameter to identify a KMS\nkey in a different Amazon Web Services account, specify the key ARN or the alias\nARN of the KMS key.\n\n**Required permissions**:\n[kms:Decrypt](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html) (key policy)","ref":"AWS.KMS.html#decrypt/3","title":"AWS.KMS.decrypt/3","type":"function"},{"doc":"* `Encrypt`\n\n  * `GenerateDataKey`\n\n  * `GenerateDataKeyPair`\n\n  * `ReEncrypt`\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual\nconsistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#decrypt/3-related-operations","title":"Related operations: - AWS.KMS.decrypt/3","type":"function"},{"doc":"Deletes the specified alias.\n\nAdding, deleting, or updating an alias can allow or deny permission to the KMS\nkey. For details, see [ABAC for KMS](https://docs.aws.amazon.com/kms/latest/developerguide/abac.html) in the\n*Key Management Service Developer Guide*.\n\nBecause an alias is not a property of a KMS key, you can delete and change the\naliases of a KMS key without affecting the KMS key. Also, aliases do not appear\nin the response from the `DescribeKey` operation. To get the aliases of all KMS\nkeys, use the `ListAliases` operation.\n\nEach KMS key can have multiple aliases. To change the alias of a KMS key, use\n`DeleteAlias` to delete the current alias and `CreateAlias` to create a new\nalias. To associate an existing alias with a different KMS key, call\n`UpdateAlias`.\n\n**Cross-account use**: No. You cannot perform this operation on an alias in a\ndifferent Amazon Web Services account.","ref":"AWS.KMS.html#delete_alias/3","title":"AWS.KMS.delete_alias/3","type":"function"},{"doc":"*\n[kms:DeleteAlias](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html) on the alias (IAM policy).\n\n  *\n[kms:DeleteAlias](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html)\non the KMS key (key policy).\n\nFor details, see [Controlling access to aliases](https://docs.aws.amazon.com/kms/latest/developerguide/kms-alias.html#alias-access)\nin the *Key Management Service Developer Guide*.","ref":"AWS.KMS.html#delete_alias/3-required-permissions","title":"Required permissions - AWS.KMS.delete_alias/3","type":"function"},{"doc":"* `CreateAlias`\n\n  * `ListAliases`\n\n  * `UpdateAlias`\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual consistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#delete_alias/3-related-operations","title":"Related operations: - AWS.KMS.delete_alias/3","type":"function"},{"doc":"Deletes a [custom key store](https://docs.aws.amazon.com/kms/latest/developerguide/custom-key-store-overview.html).\n\nThis operation does not affect any backing elements of the custom key store. It\ndoes not delete the CloudHSM cluster that is associated with an CloudHSM key\nstore, or affect any users or keys in the cluster. For an external key store, it\ndoes not affect the external key store proxy, external key manager, or any\nexternal keys.\n\nThis operation is part of the [custom key stores](https://docs.aws.amazon.com/kms/latest/developerguide/custom-key-store-overview.html)\nfeature in KMS, which combines the convenience and extensive integration of KMS\nwith the isolation and control of a key store that you own and manage.\n\nThe custom key store that you delete cannot contain any [KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#kms_keys).\nBefore deleting the key store, verify that you will never need to use any of the\nKMS keys in the key store for any [cryptographic operations](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#cryptographic-operations).\nThen, use `ScheduleKeyDeletion` to delete the KMS keys from the key store. After\nthe required waiting period expires and all KMS keys are deleted from the custom\nkey store, use `DisconnectCustomKeyStore` to disconnect the key store from KMS.\nThen, you can delete the custom key store.\n\nFor keys in an CloudHSM key store, the `ScheduleKeyDeletion` operation makes a\nbest effort to delete the key material from the associated cluster. However, you\nmight need to manually [delete the orphaned key material](https://docs.aws.amazon.com/kms/latest/developerguide/fix-keystore.html#fix-keystore-orphaned-key)\nfrom the cluster and its backups. KMS never creates, manages, or deletes\ncryptographic keys in the external key manager associated with an external key\nstore. You must manage them using your external key manager tools.\n\nInstead of deleting the custom key store, consider using the\n`DisconnectCustomKeyStore` operation to disconnect the custom key store from its\nbacking key store. While the key store is disconnected, you cannot create or use\nthe KMS keys in the key store. But, you do not need to delete KMS keys and you\ncan reconnect a disconnected custom key store at any time.\n\nIf the operation succeeds, it returns a JSON object with no properties.\n\n**Cross-account use**: No. You cannot perform this operation on a custom key\nstore in a different Amazon Web Services account.\n\n**Required permissions**:\n[kms:DeleteCustomKeyStore](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html) (IAM policy)","ref":"AWS.KMS.html#delete_custom_key_store/3","title":"AWS.KMS.delete_custom_key_store/3","type":"function"},{"doc":"* `ConnectCustomKeyStore`\n\n  * `CreateCustomKeyStore`\n\n  * `DescribeCustomKeyStores`\n\n  * `DisconnectCustomKeyStore`\n\n  * `UpdateCustomKeyStore`\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual\nconsistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#delete_custom_key_store/3-related-operations","title":"Related operations: - AWS.KMS.delete_custom_key_store/3","type":"function"},{"doc":"Deletes key material that was previously imported.\n\nThis operation makes the specified KMS key temporarily unusable. To restore the\nusability of the KMS key, reimport the same key material. For more information\nabout importing key material into KMS, see [Importing Key Material](https://docs.aws.amazon.com/kms/latest/developerguide/importing-keys.html)\nin the *Key Management Service Developer Guide*.\n\nWhen the specified KMS key is in the `PendingDeletion` state, this operation\ndoes not change the KMS key's state. Otherwise, it changes the KMS key's state\nto `PendingImport`.\n\nThe KMS key that you use for this operation must be in a compatible key state.\nFor details, see [Key states of KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/key-state.html) in\nthe *Key Management Service Developer Guide*.\n\n**Cross-account use**: No. You cannot perform this operation on a KMS key in a\ndifferent Amazon Web Services account.\n\n**Required permissions**:\n[kms:DeleteImportedKeyMaterial](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html) (key policy)","ref":"AWS.KMS.html#delete_imported_key_material/3","title":"AWS.KMS.delete_imported_key_material/3","type":"function"},{"doc":"* `GetParametersForImport`\n\n  * `ImportKeyMaterial`\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual\nconsistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#delete_imported_key_material/3-related-operations","title":"Related operations: - AWS.KMS.delete_imported_key_material/3","type":"function"},{"doc":"Gets information about [custom key stores](https://docs.aws.amazon.com/kms/latest/developerguide/custom-key-store-overview.html)\nin the account and Region.\n\nThis operation is part of the [custom key stores](https://docs.aws.amazon.com/kms/latest/developerguide/custom-key-store-overview.html)\nfeature in KMS, which combines the convenience and extensive integration of KMS\nwith the isolation and control of a key store that you own and manage.\n\nBy default, this operation returns information about all custom key stores in\nthe account and Region. To get only information about a particular custom key\nstore, use either the `CustomKeyStoreName` or `CustomKeyStoreId` parameter (but\nnot both).\n\nTo determine whether the custom key store is connected to its CloudHSM cluster\nor external key store proxy, use the `ConnectionState` element in the response.\nIf an attempt to connect the custom key store failed, the `ConnectionState`\nvalue is `FAILED` and the `ConnectionErrorCode` element in the response\nindicates the cause of the failure. For help interpreting the\n`ConnectionErrorCode`, see `CustomKeyStoresListEntry`.\n\nCustom key stores have a `DISCONNECTED` connection state if the key store has\nnever been connected or you used the `DisconnectCustomKeyStore` operation to\ndisconnect it. Otherwise, the connection state is CONNECTED. If your custom key\nstore connection state is `CONNECTED` but you are having trouble using it,\nverify that the backing store is active and available. For an CloudHSM key\nstore, verify that the associated CloudHSM cluster is active and contains the\nminimum number of HSMs required for the operation, if any. For an external key\nstore, verify that the external key store proxy and its associated external key\nmanager are reachable and enabled.\n\nFor help repairing your CloudHSM key store, see the [Troubleshooting CloudHSM key\nstores](https://docs.aws.amazon.com/kms/latest/developerguide/fix-keystore.html).\nFor help repairing your external key store, see the [Troubleshooting external key\nstores](https://docs.aws.amazon.com/kms/latest/developerguide/xks-troubleshooting.html).\nBoth topics are in the *Key Management Service Developer Guide*.\n\n**Cross-account use**: No. You cannot perform this operation on a custom key\nstore in a different Amazon Web Services account.\n\n**Required permissions**:\n[kms:DescribeCustomKeyStores](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html) (IAM policy)","ref":"AWS.KMS.html#describe_custom_key_stores/3","title":"AWS.KMS.describe_custom_key_stores/3","type":"function"},{"doc":"* `ConnectCustomKeyStore`\n\n  * `CreateCustomKeyStore`\n\n  * `DeleteCustomKeyStore`\n\n  * `DisconnectCustomKeyStore`\n\n  * `UpdateCustomKeyStore`\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual\nconsistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#describe_custom_key_stores/3-related-operations","title":"Related operations: - AWS.KMS.describe_custom_key_stores/3","type":"function"},{"doc":"Provides detailed information about a KMS key.\n\nYou can run `DescribeKey` on a [customer managed key](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#customer-cmk)\nor an [Amazon Web Services managed key](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#aws-managed-cmk).\n\nThis detailed information includes the key ARN, creation date (and deletion\ndate, if applicable), the key state, and the origin and expiration date (if any)\nof the key material. It includes fields, like `KeySpec`, that help you\ndistinguish different types of KMS keys. It also displays the key usage\n(encryption, signing, or generating and verifying MACs) and the algorithms that\nthe KMS key supports.\n\nFor [multi-Region keys](https://docs.aws.amazon.com/kms/latest/developerguide/multi-region-keys-overview.html),\n`DescribeKey` displays the primary key and all related replica keys. For KMS\nkeys in [CloudHSM key stores](https://docs.aws.amazon.com/kms/latest/developerguide/keystore-cloudhsm.html),\nit includes information about the key store, such as the key store ID and the\nCloudHSM cluster ID. For KMS keys in [external key stores](https://docs.aws.amazon.com/kms/latest/developerguide/keystore-external.html),\nit includes the custom key store ID and the ID of the external key.\n\n`DescribeKey` does not return the following information:\n\n  * Aliases associated with the KMS key. To get this information, use\n`ListAliases`.\n\n  * Whether automatic key rotation is enabled on the KMS key. To get\nthis information, use `GetKeyRotationStatus`. Also, some key states prevent a\nKMS key from being automatically rotated. For details, see [How Automatic Key Rotation\nWorks](https://docs.aws.amazon.com/kms/latest/developerguide/rotate-keys.html#rotate-keys-how-it-works)\nin the *Key Management Service Developer Guide*.\n\n  * Tags on the KMS key. To get this information, use\n`ListResourceTags`.\n\n  * Key policies and grants on the KMS key. To get this information,\nuse `GetKeyPolicy` and `ListGrants`.\n\nIn general, `DescribeKey` is a non-mutating operation. It returns data about KMS\nkeys, but doesn't change them. However, Amazon Web Services services use\n`DescribeKey` to create [Amazon Web Services managed keys](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#aws-managed-cmk)\nfrom a *predefined Amazon Web Services alias* with no key ID.\n\n**Cross-account use**: Yes. To perform this operation with a KMS key in a\ndifferent Amazon Web Services account, specify the key ARN or alias ARN in the\nvalue of the `KeyId` parameter.\n\n**Required permissions**:\n[kms:DescribeKey](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html) (key policy)","ref":"AWS.KMS.html#describe_key/3","title":"AWS.KMS.describe_key/3","type":"function"},{"doc":"* `GetKeyPolicy`\n\n  * `GetKeyRotationStatus`\n\n  * `ListAliases`\n\n  * `ListGrants`\n\n  * `ListKeys`\n\n  * `ListResourceTags`\n\n  * `ListRetirableGrants`\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual\nconsistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#describe_key/3-related-operations","title":"Related operations: - AWS.KMS.describe_key/3","type":"function"},{"doc":"Sets the state of a KMS key to disabled.\n\nThis change temporarily prevents use of the KMS key for [cryptographic operations](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#cryptographic-operations).\n\nFor more information about how key state affects the use of a KMS key, see [Key states of KMS\nkeys](https://docs.aws.amazon.com/kms/latest/developerguide/key-state.html) in\nthe * *Key Management Service Developer Guide* *.\n\nThe KMS key that you use for this operation must be in a compatible key state.\nFor details, see [Key states of KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/key-state.html) in\nthe *Key Management Service Developer Guide*.\n\n**Cross-account use**: No. You cannot perform this operation on a KMS key in a\ndifferent Amazon Web Services account.\n\n**Required permissions**:\n[kms:DisableKey](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html) (key policy)\n\n**Related operations**: `EnableKey`\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual\nconsistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#disable_key/3","title":"AWS.KMS.disable_key/3","type":"function"},{"doc":"Disables [automatic rotation of the key material](https://docs.aws.amazon.com/kms/latest/developerguide/rotate-keys.html)\nof the specified symmetric encryption KMS key.\n\nAutomatic key rotation is supported only on symmetric encryption KMS keys. You\ncannot enable automatic rotation of [asymmetric KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/symmetric-asymmetric.html),\n[HMAC KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/hmac.html), KMS keys\nwith [imported key material](https://docs.aws.amazon.com/kms/latest/developerguide/importing-keys.html),\nor KMS keys in a [custom key store](https://docs.aws.amazon.com/kms/latest/developerguide/custom-key-store-overview.html).\nTo enable or disable automatic rotation of a set of related [multi-Region keys](https://docs.aws.amazon.com/kms/latest/developerguide/multi-region-keys-manage.html#multi-region-rotate),\nset the property on the primary key.\n\nYou can enable (`EnableKeyRotation`) and disable automatic rotation of the key\nmaterial in [customer managed KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#customer-cmk).\nKey material rotation of [Amazon Web Services managed KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#aws-managed-cmk)\nis not configurable. KMS always rotates the key material for every year.\nRotation of [Amazon Web Services owned KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#aws-owned-cmk)\nvaries.\n\nIn May 2022, KMS changed the rotation schedule for Amazon Web Services managed\nkeys from every three years to every year. For details, see `EnableKeyRotation`.\n\nThe KMS key that you use for this operation must be in a compatible key state.\nFor details, see [Key states of KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/key-state.html) in\nthe *Key Management Service Developer Guide*.\n\n**Cross-account use**: No. You cannot perform this operation on a KMS key in a\ndifferent Amazon Web Services account.\n\n**Required permissions**:\n[kms:DisableKeyRotation](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html) (key policy)","ref":"AWS.KMS.html#disable_key_rotation/3","title":"AWS.KMS.disable_key_rotation/3","type":"function"},{"doc":"* `EnableKeyRotation`\n\n  * `GetKeyRotationStatus`\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual\nconsistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#disable_key_rotation/3-related-operations","title":"Related operations: - AWS.KMS.disable_key_rotation/3","type":"function"},{"doc":"Disconnects the [custom key store](https://docs.aws.amazon.com/kms/latest/developerguide/custom-key-store-overview.html)\nfrom its backing key store.\n\nThis operation disconnects an CloudHSM key store from its associated CloudHSM\ncluster or disconnects an external key store from the external key store proxy\nthat communicates with your external key manager.\n\nThis operation is part of the [custom key stores](https://docs.aws.amazon.com/kms/latest/developerguide/custom-key-store-overview.html)\nfeature in KMS, which combines the convenience and extensive integration of KMS\nwith the isolation and control of a key store that you own and manage.\n\nWhile a custom key store is disconnected, you can manage the custom key store\nand its KMS keys, but you cannot create or use its KMS keys. You can reconnect\nthe custom key store at any time.\n\nWhile a custom key store is disconnected, all attempts to create KMS keys in the\ncustom key store or to use existing KMS keys in [cryptographic operations](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#cryptographic-operations)\nwill fail. This action can prevent users from storing and accessing sensitive\ndata.\n\nWhen you disconnect a custom key store, its `ConnectionState` changes to\n`Disconnected`. To find the connection state of a custom key store, use the\n`DescribeCustomKeyStores` operation. To reconnect a custom key store, use the\n`ConnectCustomKeyStore` operation.\n\nIf the operation succeeds, it returns a JSON object with no properties.\n\n**Cross-account use**: No. You cannot perform this operation on a custom key\nstore in a different Amazon Web Services account.\n\n**Required permissions**:\n[kms:DisconnectCustomKeyStore](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html) (IAM policy)","ref":"AWS.KMS.html#disconnect_custom_key_store/3","title":"AWS.KMS.disconnect_custom_key_store/3","type":"function"},{"doc":"* `ConnectCustomKeyStore`\n\n  * `CreateCustomKeyStore`\n\n  * `DeleteCustomKeyStore`\n\n  * `DescribeCustomKeyStores`\n\n  * `UpdateCustomKeyStore`\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual\nconsistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#disconnect_custom_key_store/3-related-operations","title":"Related operations: - AWS.KMS.disconnect_custom_key_store/3","type":"function"},{"doc":"Sets the key state of a KMS key to enabled.\n\nThis allows you to use the KMS key for [cryptographic operations](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#cryptographic-operations).\n\nThe KMS key that you use for this operation must be in a compatible key state.\nFor details, see [Key states of KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/key-state.html) in\nthe *Key Management Service Developer Guide*.\n\n**Cross-account use**: No. You cannot perform this operation on a KMS key in a\ndifferent Amazon Web Services account.\n\n**Required permissions**:\n[kms:EnableKey](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html) (key policy)\n\n**Related operations**: `DisableKey`\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual\nconsistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#enable_key/3","title":"AWS.KMS.enable_key/3","type":"function"},{"doc":"Enables [automatic rotation of the key material](https://docs.aws.amazon.com/kms/latest/developerguide/rotate-keys.html)\nof the specified symmetric encryption KMS key.\n\nWhen you enable automatic rotation of a [customer managed KMS key](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#customer-cmk),\nKMS rotates the key material of the KMS key one year (approximately 365 days)\nfrom the enable date and every year thereafter. You can monitor rotation of the\nkey material for your KMS keys in CloudTrail and Amazon CloudWatch. To disable\nrotation of the key material in a customer managed KMS key, use the\n`DisableKeyRotation` operation.\n\nAutomatic key rotation is supported only on [symmetric encryption KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#symmetric-cmks).\nYou cannot enable automatic rotation of [asymmetric KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/symmetric-asymmetric.html),\n[HMAC KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/hmac.html), KMS keys\nwith [imported key material](https://docs.aws.amazon.com/kms/latest/developerguide/importing-keys.html),\nor KMS keys in a [custom key store](https://docs.aws.amazon.com/kms/latest/developerguide/custom-key-store-overview.html).\nTo enable or disable automatic rotation of a set of related [multi-Region keys](https://docs.aws.amazon.com/kms/latest/developerguide/multi-region-keys-manage.html#multi-region-rotate),\nset the property on the primary key.\n\nYou cannot enable or disable automatic rotation [Amazon Web Services managed KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#aws-managed-cmk).\nKMS always rotates the key material of Amazon Web Services managed keys every\nyear. Rotation of [Amazon Web Services owned KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#aws-owned-cmk)\nvaries.\n\nIn May 2022, KMS changed the rotation schedule for Amazon Web Services managed\nkeys from every three years (approximately 1,095 days) to every year\n(approximately 365 days).\n\nNew Amazon Web Services managed keys are automatically rotated one year after\nthey are created, and approximately every year thereafter.\n\nExisting Amazon Web Services managed keys are automatically rotated one year\nafter their most recent rotation, and every year thereafter.\n\nThe KMS key that you use for this operation must be in a compatible key state.\nFor details, see [Key states of KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/key-state.html) in\nthe *Key Management Service Developer Guide*.\n\n**Cross-account use**: No. You cannot perform this operation on a KMS key in a\ndifferent Amazon Web Services account.\n\n**Required permissions**:\n[kms:EnableKeyRotation](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html) (key policy)","ref":"AWS.KMS.html#enable_key_rotation/3","title":"AWS.KMS.enable_key_rotation/3","type":"function"},{"doc":"* `DisableKeyRotation`\n\n  * `GetKeyRotationStatus`\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual\nconsistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#enable_key_rotation/3-related-operations","title":"Related operations: - AWS.KMS.enable_key_rotation/3","type":"function"},{"doc":"Encrypts plaintext of up to 4,096 bytes using a KMS key.\n\nYou can use a symmetric or asymmetric KMS key with a `KeyUsage` of\n`ENCRYPT_DECRYPT`.\n\nYou can use this operation to encrypt small amounts of arbitrary data, such as a\npersonal identifier or database password, or other sensitive information. You\ndon't need to use the `Encrypt` operation to encrypt a data key. The\n`GenerateDataKey` and `GenerateDataKeyPair` operations return a plaintext data\nkey and an encrypted copy of that data key.\n\nIf you use a symmetric encryption KMS key, you can use an encryption context to\nadd additional security to your encryption operation. If you specify an\n`EncryptionContext` when encrypting data, you must specify the same encryption\ncontext (a case-sensitive exact match) when decrypting the data. Otherwise, the\nrequest to decrypt fails with an `InvalidCiphertextException`. For more\ninformation, see [Encryption Context](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#encrypt_context)\nin the *Key Management Service Developer Guide*.\n\nIf you specify an asymmetric KMS key, you must also specify the encryption\nalgorithm. The algorithm must be compatible with the KMS key spec.\n\nWhen you use an asymmetric KMS key to encrypt or reencrypt data, be sure to\nrecord the KMS key and encryption algorithm that you choose. You will be\nrequired to provide the same KMS key and encryption algorithm when you decrypt\nthe data. If the KMS key and algorithm do not match the values used to encrypt\nthe data, the decrypt operation fails.\n\nYou are not required to supply the key ID and encryption algorithm when you\ndecrypt with symmetric encryption KMS keys because KMS stores this information\nin the ciphertext blob. KMS cannot store metadata in ciphertext generated with\nasymmetric keys. The standard format for asymmetric key ciphertext does not\ninclude configurable fields.\n\nThe maximum size of the data that you can encrypt varies with the type of KMS\nkey and the encryption algorithm that you choose.\n\n  * Symmetric encryption KMS keys\n\n    * `SYMMETRIC_DEFAULT`: 4096 bytes\n\n  * `RSA_2048`\n\n    * `RSAES_OAEP_SHA_1`: 214 bytes\n\n    * `RSAES_OAEP_SHA_256`: 190 bytes\n\n  * `RSA_3072`\n\n    * `RSAES_OAEP_SHA_1`: 342 bytes\n\n    * `RSAES_OAEP_SHA_256`: 318 bytes\n\n  * `RSA_4096`\n\n    * `RSAES_OAEP_SHA_1`: 470 bytes\n\n    * `RSAES_OAEP_SHA_256`: 446 bytes\n\n  * `SM2PKE`: 1024 bytes (China Regions only)\n\nThe KMS key that you use for this operation must be in a compatible key state.\nFor details, see [Key states of KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/key-state.html) in\nthe *Key Management Service Developer Guide*.\n\n**Cross-account use**: Yes. To perform this operation with a KMS key in a\ndifferent Amazon Web Services account, specify the key ARN or alias ARN in the\nvalue of the `KeyId` parameter.\n\n**Required permissions**:\n[kms:Encrypt](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html) (key policy)","ref":"AWS.KMS.html#encrypt/3","title":"AWS.KMS.encrypt/3","type":"function"},{"doc":"* `Decrypt`\n\n  * `GenerateDataKey`\n\n  * `GenerateDataKeyPair`\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual\nconsistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#encrypt/3-related-operations","title":"Related operations: - AWS.KMS.encrypt/3","type":"function"},{"doc":"Returns a unique symmetric data key for use outside of KMS.\n\nThis operation returns a plaintext copy of the data key and a copy that is\nencrypted under a symmetric encryption KMS key that you specify. The bytes in\nthe plaintext key are random; they are not related to the caller or the KMS key.\nYou can use the plaintext key to encrypt your data outside of KMS and store the\nencrypted data key with the encrypted data.\n\nTo generate a data key, specify the symmetric encryption KMS key that will be\nused to encrypt the data key. You cannot use an asymmetric KMS key to encrypt\ndata keys. To get the type of your KMS key, use the `DescribeKey` operation.\n\nYou must also specify the length of the data key. Use either the `KeySpec` or\n`NumberOfBytes` parameters (but not both). For 128-bit and 256-bit data keys,\nuse the `KeySpec` parameter.\n\nTo generate a 128-bit SM4 data key (China Regions only), specify a `KeySpec`\nvalue of `AES_128` or a `NumberOfBytes` value of `16`. The symmetric encryption\nkey used in China Regions to encrypt your data key is an SM4 encryption key.\n\nTo get only an encrypted copy of the data key, use\n`GenerateDataKeyWithoutPlaintext`. To generate an asymmetric data key pair, use\nthe `GenerateDataKeyPair` or `GenerateDataKeyPairWithoutPlaintext` operation. To\nget a cryptographically secure random byte string, use `GenerateRandom`.\n\nYou can use an optional encryption context to add additional security to the\nencryption operation. If you specify an `EncryptionContext`, you must specify\nthe same encryption context (a case-sensitive exact match) when decrypting the\nencrypted data key. Otherwise, the request to decrypt fails with an\n`InvalidCiphertextException`. For more information, see [Encryption Context](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#encrypt_context)\nin the *Key Management Service Developer Guide*.\n\n`GenerateDataKey` also supports [Amazon Web Services Nitro Enclaves](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/nitro-enclave.html),\nwhich provide an isolated compute environment in Amazon EC2. To call\n`GenerateDataKey` for an Amazon Web Services Nitro enclave, use the [Amazon Web Services Nitro Enclaves\nSDK](https://docs.aws.amazon.com/enclaves/latest/user/developing-applications.html#sdk)\nor any Amazon Web Services SDK. Use the `Recipient` parameter to provide the\nattestation document for the enclave. `GenerateDataKey` returns a copy of the\ndata key encrypted under the specified KMS key, as usual. But instead of a\nplaintext copy of the data key, the response includes a copy of the data key\nencrypted under the public key from the attestation document\n(`CiphertextForRecipient`). For information about the interaction between KMS\nand Amazon Web Services Nitro Enclaves, see [How Amazon Web Services Nitro Enclaves uses\nKMS](https://docs.aws.amazon.com/kms/latest/developerguide/services-nitro-enclaves.html)\nin the *Key Management Service Developer Guide*..\n\nThe KMS key that you use for this operation must be in a compatible key state.\nFor details, see [Key states of KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/key-state.html) in\nthe *Key Management Service Developer Guide*.","ref":"AWS.KMS.html#generate_data_key/3","title":"AWS.KMS.generate_data_key/3","type":"function"},{"doc":"We recommend that you use the following pattern to encrypt data locally in your\napplication. You can write your own code or use a client-side encryption\nlibrary, such as the [Amazon Web Services Encryption SDK](https://docs.aws.amazon.com/encryption-sdk/latest/developer-guide/), the\n[Amazon DynamoDB Encryption Client](https://docs.aws.amazon.com/dynamodb-encryption-client/latest/devguide/),\nor [Amazon S3 client-side encryption](https://docs.aws.amazon.com/AmazonS3/latest/dev/UsingClientSideEncryption.html)\nto do these tasks for you.\n\nTo encrypt data outside of KMS:\n\n  1. Use the `GenerateDataKey` operation to get a data key.\n\n  2. Use the plaintext data key (in the `Plaintext` field of the\nresponse) to encrypt your data outside of KMS. Then erase the plaintext data key\nfrom memory.\n\n  3. Store the encrypted data key (in the `CiphertextBlob` field of\nthe response) with the encrypted data.\n\nTo decrypt data outside of KMS:\n\n  1. Use the `Decrypt` operation to decrypt the encrypted data key.\nThe operation returns a plaintext copy of the data key.\n\n  2. Use the plaintext data key to decrypt data outside of KMS, then\nerase the plaintext data key from memory.\n\n**Cross-account use**: Yes. To perform this operation with a KMS key in a\ndifferent Amazon Web Services account, specify the key ARN or alias ARN in the\nvalue of the `KeyId` parameter.\n\n**Required permissions**:\n[kms:GenerateDataKey](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html) (key policy)","ref":"AWS.KMS.html#generate_data_key/3-how-to-use-your-data-key","title":"How to use your data key - AWS.KMS.generate_data_key/3","type":"function"},{"doc":"* `Decrypt`\n\n  * `Encrypt`\n\n  * `GenerateDataKeyPair`\n\n  * `GenerateDataKeyPairWithoutPlaintext`\n\n  * `GenerateDataKeyWithoutPlaintext`\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual\nconsistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#generate_data_key/3-related-operations","title":"Related operations: - AWS.KMS.generate_data_key/3","type":"function"},{"doc":"Returns a unique asymmetric data key pair for use outside of KMS.\n\nThis operation returns a plaintext public key, a plaintext private key, and a\ncopy of the private key that is encrypted under the symmetric encryption KMS key\nyou specify. You can use the data key pair to perform asymmetric cryptography\nand implement digital signatures outside of KMS. The bytes in the keys are\nrandom; they are not related to the caller or to the KMS key that is used to\nencrypt the private key.\n\nYou can use the public key that `GenerateDataKeyPair` returns to encrypt data or\nverify a signature outside of KMS. Then, store the encrypted private key with\nthe data. When you are ready to decrypt data or sign a message, you can use the\n`Decrypt` operation to decrypt the encrypted private key.\n\nTo generate a data key pair, you must specify a symmetric encryption KMS key to\nencrypt the private key in a data key pair. You cannot use an asymmetric KMS key\nor a KMS key in a custom key store. To get the type and origin of your KMS key,\nuse the `DescribeKey` operation.\n\nUse the `KeyPairSpec` parameter to choose an RSA or Elliptic Curve (ECC) data\nkey pair. In China Regions, you can also choose an SM2 data key pair. KMS\nrecommends that you use ECC key pairs for signing, and use RSA and SM2 key pairs\nfor either encryption or signing, but not both. However, KMS cannot enforce any\nrestrictions on the use of data key pairs outside of KMS.\n\nIf you are using the data key pair to encrypt data, or for any operation where\nyou don't immediately need a private key, consider using the\n`GenerateDataKeyPairWithoutPlaintext` operation.\n`GenerateDataKeyPairWithoutPlaintext` returns a plaintext public key and an\nencrypted private key, but omits the plaintext private key that you need only to\ndecrypt ciphertext or sign a message. Later, when you need to decrypt the data\nor sign a message, use the `Decrypt` operation to decrypt the encrypted private\nkey in the data key pair.\n\n`GenerateDataKeyPair` returns a unique data key pair for each request. The bytes\nin the keys are random; they are not related to the caller or the KMS key that\nis used to encrypt the private key. The public key is a DER-encoded X.509\nSubjectPublicKeyInfo, as specified in [RFC 5280](https://tools.ietf.org/html/rfc5280). The private key is a DER-encoded\nPKCS8 PrivateKeyInfo, as specified in [RFC 5958](https://tools.ietf.org/html/rfc5958).\n\n`GenerateDataKeyPair` also supports [Amazon Web Services Nitro Enclaves](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/nitro-enclave.html),\nwhich provide an isolated compute environment in Amazon EC2. To call\n`GenerateDataKeyPair` for an Amazon Web Services Nitro enclave, use the [Amazon Web Services Nitro Enclaves\nSDK](https://docs.aws.amazon.com/enclaves/latest/user/developing-applications.html#sdk)\nor any Amazon Web Services SDK. Use the `Recipient` parameter to provide the\nattestation document for the enclave. `GenerateDataKeyPair` returns the public\ndata key and a copy of the private data key encrypted under the specified KMS\nkey, as usual. But instead of a plaintext copy of the private data key\n(`PrivateKeyPlaintext`), the response includes a copy of the private data key\nencrypted under the public key from the attestation document\n(`CiphertextForRecipient`). For information about the interaction between KMS\nand Amazon Web Services Nitro Enclaves, see [How Amazon Web Services Nitro Enclaves uses\nKMS](https://docs.aws.amazon.com/kms/latest/developerguide/services-nitro-enclaves.html)\nin the *Key Management Service Developer Guide*..\n\nYou can use an optional encryption context to add additional security to the\nencryption operation. If you specify an `EncryptionContext`, you must specify\nthe same encryption context (a case-sensitive exact match) when decrypting the\nencrypted data key. Otherwise, the request to decrypt fails with an\n`InvalidCiphertextException`. For more information, see [Encryption Context](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#encrypt_context)\nin the *Key Management Service Developer Guide*.\n\nThe KMS key that you use for this operation must be in a compatible key state.\nFor details, see [Key states of KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/key-state.html) in\nthe *Key Management Service Developer Guide*.\n\n**Cross-account use**: Yes. To perform this operation with a KMS key in a\ndifferent Amazon Web Services account, specify the key ARN or alias ARN in the\nvalue of the `KeyId` parameter.\n\n**Required permissions**:\n[kms:GenerateDataKeyPair](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html) (key policy)","ref":"AWS.KMS.html#generate_data_key_pair/3","title":"AWS.KMS.generate_data_key_pair/3","type":"function"},{"doc":"* `Decrypt`\n\n  * `Encrypt`\n\n  * `GenerateDataKey`\n\n  * `GenerateDataKeyPairWithoutPlaintext`\n\n  * `GenerateDataKeyWithoutPlaintext`\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual\nconsistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#generate_data_key_pair/3-related-operations","title":"Related operations: - AWS.KMS.generate_data_key_pair/3","type":"function"},{"doc":"Returns a unique asymmetric data key pair for use outside of KMS.\n\nThis operation returns a plaintext public key and a copy of the private key that\nis encrypted under the symmetric encryption KMS key you specify. Unlike\n`GenerateDataKeyPair`, this operation does not return a plaintext private key.\nThe bytes in the keys are random; they are not related to the caller or to the\nKMS key that is used to encrypt the private key.\n\nYou can use the public key that `GenerateDataKeyPairWithoutPlaintext` returns to\nencrypt data or verify a signature outside of KMS. Then, store the encrypted\nprivate key with the data. When you are ready to decrypt data or sign a message,\nyou can use the `Decrypt` operation to decrypt the encrypted private key.\n\nTo generate a data key pair, you must specify a symmetric encryption KMS key to\nencrypt the private key in a data key pair. You cannot use an asymmetric KMS key\nor a KMS key in a custom key store. To get the type and origin of your KMS key,\nuse the `DescribeKey` operation.\n\nUse the `KeyPairSpec` parameter to choose an RSA or Elliptic Curve (ECC) data\nkey pair. In China Regions, you can also choose an SM2 data key pair. KMS\nrecommends that you use ECC key pairs for signing, and use RSA and SM2 key pairs\nfor either encryption or signing, but not both. However, KMS cannot enforce any\nrestrictions on the use of data key pairs outside of KMS.\n\n`GenerateDataKeyPairWithoutPlaintext` returns a unique data key pair for each\nrequest. The bytes in the key are not related to the caller or KMS key that is\nused to encrypt the private key. The public key is a DER-encoded X.509\nSubjectPublicKeyInfo, as specified in [RFC 5280](https://tools.ietf.org/html/rfc5280).\n\nYou can use an optional encryption context to add additional security to the\nencryption operation. If you specify an `EncryptionContext`, you must specify\nthe same encryption context (a case-sensitive exact match) when decrypting the\nencrypted data key. Otherwise, the request to decrypt fails with an\n`InvalidCiphertextException`. For more information, see [Encryption Context](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#encrypt_context)\nin the *Key Management Service Developer Guide*.\n\nThe KMS key that you use for this operation must be in a compatible key state.\nFor details, see [Key states of KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/key-state.html) in\nthe *Key Management Service Developer Guide*.\n\n**Cross-account use**: Yes. To perform this operation with a KMS key in a\ndifferent Amazon Web Services account, specify the key ARN or alias ARN in the\nvalue of the `KeyId` parameter.\n\n**Required permissions**:\n[kms:GenerateDataKeyPairWithoutPlaintext](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html) (key policy)","ref":"AWS.KMS.html#generate_data_key_pair_without_plaintext/3","title":"AWS.KMS.generate_data_key_pair_without_plaintext/3","type":"function"},{"doc":"* `Decrypt`\n\n  * `Encrypt`\n\n  * `GenerateDataKey`\n\n  * `GenerateDataKeyPair`\n\n  * `GenerateDataKeyWithoutPlaintext`\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual\nconsistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#generate_data_key_pair_without_plaintext/3-related-operations","title":"Related operations: - AWS.KMS.generate_data_key_pair_without_plaintext/3","type":"function"},{"doc":"Returns a unique symmetric data key for use outside of KMS.\n\nThis operation returns a data key that is encrypted under a symmetric encryption\nKMS key that you specify. The bytes in the key are random; they are not related\nto the caller or to the KMS key.\n\n`GenerateDataKeyWithoutPlaintext` is identical to the `GenerateDataKey`\noperation except that it does not return a plaintext copy of the data key.\n\nThis operation is useful for systems that need to encrypt data at some point,\nbut not immediately. When you need to encrypt the data, you call the `Decrypt`\noperation on the encrypted copy of the key.\n\nIt's also useful in distributed systems with different levels of trust. For\nexample, you might store encrypted data in containers. One component of your\nsystem creates new containers and stores an encrypted data key with each\ncontainer. Then, a different component puts the data into the containers. That\ncomponent first decrypts the data key, uses the plaintext data key to encrypt\ndata, puts the encrypted data into the container, and then destroys the\nplaintext data key. In this system, the component that creates the containers\nnever sees the plaintext data key.\n\nTo request an asymmetric data key pair, use the `GenerateDataKeyPair` or\n`GenerateDataKeyPairWithoutPlaintext` operations.\n\nTo generate a data key, you must specify the symmetric encryption KMS key that\nis used to encrypt the data key. You cannot use an asymmetric KMS key or a key\nin a custom key store to generate a data key. To get the type of your KMS key,\nuse the `DescribeKey` operation.\n\nYou must also specify the length of the data key. Use either the `KeySpec` or\n`NumberOfBytes` parameters (but not both). For 128-bit and 256-bit data keys,\nuse the `KeySpec` parameter.\n\nTo generate an SM4 data key (China Regions only), specify a `KeySpec` value of\n`AES_128` or `NumberOfBytes` value of `16`. The symmetric encryption key used in\nChina Regions to encrypt your data key is an SM4 encryption key.\n\nIf the operation succeeds, you will find the encrypted copy of the data key in\nthe `CiphertextBlob` field.\n\nYou can use an optional encryption context to add additional security to the\nencryption operation. If you specify an `EncryptionContext`, you must specify\nthe same encryption context (a case-sensitive exact match) when decrypting the\nencrypted data key. Otherwise, the request to decrypt fails with an\n`InvalidCiphertextException`. For more information, see [Encryption Context](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#encrypt_context)\nin the *Key Management Service Developer Guide*.\n\nThe KMS key that you use for this operation must be in a compatible key state.\nFor details, see [Key states of KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/key-state.html) in\nthe *Key Management Service Developer Guide*.\n\n**Cross-account use**: Yes. To perform this operation with a KMS key in a\ndifferent Amazon Web Services account, specify the key ARN or alias ARN in the\nvalue of the `KeyId` parameter.\n\n**Required permissions**:\n[kms:GenerateDataKeyWithoutPlaintext](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html) (key policy)","ref":"AWS.KMS.html#generate_data_key_without_plaintext/3","title":"AWS.KMS.generate_data_key_without_plaintext/3","type":"function"},{"doc":"* `Decrypt`\n\n  * `Encrypt`\n\n  * `GenerateDataKey`\n\n  * `GenerateDataKeyPair`\n\n  * `GenerateDataKeyPairWithoutPlaintext`\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual\nconsistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#generate_data_key_without_plaintext/3-related-operations","title":"Related operations: - AWS.KMS.generate_data_key_without_plaintext/3","type":"function"},{"doc":"Generates a hash-based message authentication code (HMAC) for a message using an\nHMAC KMS key and a MAC algorithm that the key supports.\n\nHMAC KMS keys and the HMAC algorithms that KMS uses conform to industry\nstandards defined in [RFC 2104](https://datatracker.ietf.org/doc/html/rfc2104).  You can use value that GenerateMac returns in the `VerifyMac` operation to\ndemonstrate that the original message has not changed. Also, because a secret\nkey is used to create the hash, you can verify that the party that generated the\nhash has the required secret key. You can also use the raw result to implement\nHMAC-based algorithms such as key derivation functions. This operation is part\nof KMS support for HMAC KMS keys. For details, see [HMAC keys in\nKMS](https://docs.aws.amazon.com/kms/latest/developerguide/hmac.html) in the *\n*Key Management Service Developer Guide* *.\n\nBest practices recommend that you limit the time during which any signing\nmechanism, including an HMAC, is effective. This deters an attack where the\nactor uses a signed message to establish validity repeatedly or long after the\nmessage is superseded. HMAC tags do not include a timestamp, but you can include\na timestamp in the token or message to help you detect when its time to refresh\nthe HMAC.\n\nThe KMS key that you use for this operation must be in a compatible key state.\nFor details, see [Key states of KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/key-state.html) in\nthe *Key Management Service Developer Guide*.\n\n**Cross-account use**: Yes. To perform this operation with a KMS key in a\ndifferent Amazon Web Services account, specify the key ARN or alias ARN in the\nvalue of the `KeyId` parameter.\n\n**Required permissions**:\n[kms:GenerateMac](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html) (key policy)\n\n**Related operations**: `VerifyMac`\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual\nconsistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#generate_mac/3","title":"AWS.KMS.generate_mac/3","type":"function"},{"doc":"Returns a random byte string that is cryptographically secure.\n\nYou must use the `NumberOfBytes` parameter to specify the length of the random\nbyte string. There is no default value for string length.\n\nBy default, the random byte string is generated in KMS. To generate the byte\nstring in the CloudHSM cluster associated with an CloudHSM key store, use the\n`CustomKeyStoreId` parameter.\n\n`GenerateRandom` also supports [Amazon Web Services Nitro Enclaves](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/nitro-enclave.html),\nwhich provide an isolated compute environment in Amazon EC2. To call\n`GenerateRandom` for a Nitro enclave, use the [Amazon Web Services Nitro Enclaves\nSDK](https://docs.aws.amazon.com/enclaves/latest/user/developing-applications.html#sdk)\nor any Amazon Web Services SDK. Use the `Recipient` parameter to provide the\nattestation document for the enclave. Instead of plaintext bytes, the response\nincludes the plaintext bytes encrypted under the public key from the attestation\ndocument (`CiphertextForRecipient`).For information about the interaction\nbetween KMS and Amazon Web Services Nitro Enclaves, see [How Amazon Web Services Nitro Enclaves uses\nKMS](https://docs.aws.amazon.com/kms/latest/developerguide/services-nitro-enclaves.html)\nin the *Key Management Service Developer Guide*.\n\nFor more information about entropy and random number generation, see [Key Management Service Cryptographic\nDetails](https://docs.aws.amazon.com/kms/latest/cryptographic-details/).\n\n**Cross-account use**: Not applicable. `GenerateRandom` does not use any\naccount-specific resources, such as KMS keys.\n\n**Required permissions**:\n[kms:GenerateRandom](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html) (IAM policy)\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual\nconsistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#generate_random/3","title":"AWS.KMS.generate_random/3","type":"function"},{"doc":"Gets a key policy attached to the specified KMS key.\n\n**Cross-account use**: No. You cannot perform this operation on a KMS key in a\ndifferent Amazon Web Services account.\n\n**Required permissions**:\n[kms:GetKeyPolicy](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html) (key policy)\n\n**Related operations**:\n[PutKeyPolicy](https://docs.aws.amazon.com/kms/latest/APIReference/API_PutKeyPolicy.html)\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual consistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#get_key_policy/3","title":"AWS.KMS.get_key_policy/3","type":"function"},{"doc":"Gets a Boolean value that indicates whether [automatic rotation of the key material](https://docs.aws.amazon.com/kms/latest/developerguide/rotate-keys.html)\nis enabled for the specified KMS key.\n\nWhen you enable automatic rotation for [customer managed KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#customer-cmk),\nKMS rotates the key material of the KMS key one year (approximately 365 days)\nfrom the enable date and every year thereafter. You can monitor rotation of the\nkey material for your KMS keys in CloudTrail and Amazon CloudWatch.\n\nAutomatic key rotation is supported only on [symmetric encryption KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#symmetric-cmks).\nYou cannot enable automatic rotation of [asymmetric KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/symmetric-asymmetric.html),\n[HMAC KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/hmac.html), KMS keys\nwith [imported key material](https://docs.aws.amazon.com/kms/latest/developerguide/importing-keys.html),\nor KMS keys in a [custom key store](https://docs.aws.amazon.com/kms/latest/developerguide/custom-key-store-overview.html).\nTo enable or disable automatic rotation of a set of related [multi-Region keys](https://docs.aws.amazon.com/kms/latest/developerguide/multi-region-keys-manage.html#multi-region-rotate),\nset the property on the primary key..\n\nYou can enable (`EnableKeyRotation`) and disable automatic rotation\n(`DisableKeyRotation`) of the key material in customer managed KMS keys. Key\nmaterial rotation of [Amazon Web Services managed KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#aws-managed-cmk)\nis not configurable. KMS always rotates the key material in Amazon Web Services\nmanaged KMS keys every year. The key rotation status for Amazon Web Services\nmanaged KMS keys is always `true`.\n\nIn May 2022, KMS changed the rotation schedule for Amazon Web Services managed\nkeys from every three years to every year. For details, see `EnableKeyRotation`.\n\nThe KMS key that you use for this operation must be in a compatible key state.\nFor details, see [Key states of KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/key-state.html) in\nthe *Key Management Service Developer Guide*.\n\n  * Disabled: The key rotation status does not change when you disable\na KMS key. However, while the KMS key is disabled, KMS does not rotate the key\nmaterial. When you re-enable the KMS key, rotation resumes. If the key material\nin the re-enabled KMS key hasn't been rotated in one year, KMS rotates it\nimmediately, and every year thereafter. If it's been less than a year since the\nkey material in the re-enabled KMS key was rotated, the KMS key resumes its\nprior rotation schedule.\n\n  * Pending deletion: While a KMS key is pending deletion, its key\nrotation status is `false` and KMS does not rotate the key material. If you\ncancel the deletion, the original key rotation status returns to `true`.\n\n**Cross-account use**: Yes. To perform this operation on a KMS key in a\ndifferent Amazon Web Services account, specify the key ARN in the value of the\n`KeyId` parameter.\n\n**Required permissions**:\n[kms:GetKeyRotationStatus](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html) (key policy)","ref":"AWS.KMS.html#get_key_rotation_status/3","title":"AWS.KMS.get_key_rotation_status/3","type":"function"},{"doc":"* `DisableKeyRotation`\n\n  * `EnableKeyRotation`\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual\nconsistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#get_key_rotation_status/3-related-operations","title":"Related operations: - AWS.KMS.get_key_rotation_status/3","type":"function"},{"doc":"Returns the public key and an import token you need to import or reimport key\nmaterial for a KMS key.\n\nBy default, KMS keys are created with key material that KMS generates. This\noperation supports [Importing key material](https://docs.aws.amazon.com/kms/latest/developerguide/importing-keys.html),\nan advanced feature that lets you generate and import the cryptographic key\nmaterial for a KMS key. For more information about importing key material into\nKMS, see [Importing key material](https://docs.aws.amazon.com/kms/latest/developerguide/importing-keys.html)\nin the *Key Management Service Developer Guide*.\n\nBefore calling `GetParametersForImport`, use the `CreateKey` operation with an\n`Origin` value of `EXTERNAL` to create a KMS key with no key material. You can\nimport key material for a symmetric encryption KMS key, HMAC KMS key, asymmetric\nencryption KMS key, or asymmetric signing KMS key. You can also import key\nmaterial into a [multi-Region key](https://docs.aws.amazon.com/kms/latest/developerguide/multi-region-keys-overview.html)\nof any supported type. However, you can't import key material into a KMS key in\na [custom key store](https://docs.aws.amazon.com/kms/latest/developerguide/custom-key-store-overview.html).\nYou can also use `GetParametersForImport` to get a public key and import token\nto [reimport the original key material](https://docs.aws.amazon.com/kms/latest/developerguide/importing-keys.html#reimport-key-material)\ninto a KMS key whose key material expired or was deleted.\n\n`GetParametersForImport` returns the items that you need to import your key\nmaterial.\n\n  * The public key (or \"wrapping key\") of an RSA key pair that KMS\ngenerates.\n\nYou will use this public key to encrypt (\"wrap\") your key material while it's in\ntransit to KMS.\n\n  * A import token that ensures that KMS can decrypt your key material\nand associate it with the correct KMS key.\n\nThe public key and its import token are permanently linked and must be used\ntogether. Each public key and import token set is valid for 24 hours. The\nexpiration date and time appear in the `ParametersValidTo` field in the\n`GetParametersForImport` response. You cannot use an expired public key or\nimport token in an `ImportKeyMaterial` request. If your key and token expire,\nsend another `GetParametersForImport` request.\n\n`GetParametersForImport` requires the following information:\n\n  * The key ID of the KMS key for which you are importing the key\nmaterial.\n\n  * The key spec of the public key (\"wrapping key\") that you will use\nto encrypt your key material during import.\n\n  * The wrapping algorithm that you will use with the public key to\nencrypt your key material.\n\nYou can use the same or a different public key spec and wrapping algorithm each\ntime you import or reimport the same key material.\n\nThe KMS key that you use for this operation must be in a compatible key state.\nFor details, see [Key states of KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/key-state.html) in\nthe *Key Management Service Developer Guide*.\n\n**Cross-account use**: No. You cannot perform this operation on a KMS key in a\ndifferent Amazon Web Services account.\n\n**Required permissions**:\n[kms:GetParametersForImport](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html) (key policy)","ref":"AWS.KMS.html#get_parameters_for_import/3","title":"AWS.KMS.get_parameters_for_import/3","type":"function"},{"doc":"* `ImportKeyMaterial`\n\n  * `DeleteImportedKeyMaterial`\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual\nconsistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#get_parameters_for_import/3-related-operations","title":"Related operations: - AWS.KMS.get_parameters_for_import/3","type":"function"},{"doc":"Returns the public key of an asymmetric KMS key.\n\nUnlike the private key of a asymmetric KMS key, which never leaves KMS\nunencrypted, callers with `kms:GetPublicKey` permission can download the public\nkey of an asymmetric KMS key. You can share the public key to allow others to\nencrypt messages and verify signatures outside of KMS. For information about\nasymmetric KMS keys, see [Asymmetric KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/symmetric-asymmetric.html)\nin the *Key Management Service Developer Guide*.\n\nYou do not need to download the public key. Instead, you can use the public key\nwithin KMS by calling the `Encrypt`, `ReEncrypt`, or `Verify` operations with\nthe identifier of an asymmetric KMS key. When you use the public key within KMS,\nyou benefit from the authentication, authorization, and logging that are part of\nevery KMS operation. You also reduce of risk of encrypting data that cannot be\ndecrypted. These features are not effective outside of KMS.\n\nTo help you use the public key safely outside of KMS, `GetPublicKey` returns\nimportant information about the public key in the response, including:\n\n  *\n[KeySpec](https://docs.aws.amazon.com/kms/latest/APIReference/API_GetPublicKey.html#KMS-GetPublicKey-response-KeySpec): The type of key material in the public key, such as `RSA_4096` or\n`ECC_NIST_P521`.\n\n  *\n[KeyUsage](https://docs.aws.amazon.com/kms/latest/APIReference/API_GetPublicKey.html#KMS-GetPublicKey-response-KeyUsage):\nWhether the key is used for encryption or signing.\n\n  *\n[EncryptionAlgorithms](https://docs.aws.amazon.com/kms/latest/APIReference/API_GetPublicKey.html#KMS-GetPublicKey-response-EncryptionAlgorithms) or\n[SigningAlgorithms](https://docs.aws.amazon.com/kms/latest/APIReference/API_GetPublicKey.html#KMS-GetPublicKey-response-SigningAlgorithms):\nA list of the encryption algorithms or the signing algorithms for the key.\n\nAlthough KMS cannot enforce these restrictions on external operations, it is\ncrucial that you use this information to prevent the public key from being used\nimproperly. For example, you can prevent a public signing key from being used\nencrypt data, or prevent a public key from being used with an encryption\nalgorithm that is not supported by KMS. You can also avoid errors, such as using\nthe wrong signing algorithm in a verification operation.\n\nTo verify a signature outside of KMS with an SM2 public key (China Regions\nonly), you must specify the distinguishing ID. By default, KMS uses\n`1234567812345678` as the distinguishing ID. For more information, see [Offline verification with SM2 key\npairs](https://docs.aws.amazon.com/kms/latest/developerguide/asymmetric-key-specs.html#key-spec-sm-offline-verification).\n\nThe KMS key that you use for this operation must be in a compatible key state.\nFor details, see [Key states of KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/key-state.html) in\nthe *Key Management Service Developer Guide*.\n\n**Cross-account use**: Yes. To perform this operation with a KMS key in a\ndifferent Amazon Web Services account, specify the key ARN or alias ARN in the\nvalue of the `KeyId` parameter.\n\n**Required permissions**:\n[kms:GetPublicKey](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html) (key policy)\n\n**Related operations**: `CreateKey`\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual\nconsistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#get_public_key/3","title":"AWS.KMS.get_public_key/3","type":"function"},{"doc":"Imports or reimports key material into an existing KMS key that was created\nwithout key material.\n\n`ImportKeyMaterial` also sets the expiration model and expiration date of the\nimported key material.\n\nBy default, KMS keys are created with key material that KMS generates. This\noperation supports [Importing key material](https://docs.aws.amazon.com/kms/latest/developerguide/importing-keys.html),\nan advanced feature that lets you generate and import the cryptographic key\nmaterial for a KMS key. For more information about importing key material into\nKMS, see [Importing key material](https://docs.aws.amazon.com/kms/latest/developerguide/importing-keys.html)\nin the *Key Management Service Developer Guide*.\n\nAfter you successfully import key material into a KMS key, you can [reimport the same key\nmaterial](https://docs.aws.amazon.com/kms/latest/developerguide/importing-keys.html#reimport-key-material)\ninto that KMS key, but you cannot import different key material. You might\nreimport key material to replace key material that expired or key material that\nyou deleted. You might also reimport key material to change the expiration model\nor expiration date of the key material. Before reimporting key material, if\nnecessary, call `DeleteImportedKeyMaterial` to delete the current imported key\nmaterial.\n\nEach time you import key material into KMS, you can determine whether\n(`ExpirationModel`) and when (`ValidTo`) the key material expires. To change the\nexpiration of your key material, you must import it again, either by calling\n`ImportKeyMaterial` or using the [import features](kms/latest/developerguide/importing-keys-import-key-material.html#importing-keys-import-key-material-console)\nof the KMS console.\n\nBefore calling `ImportKeyMaterial`:\n\n  * Create or identify a KMS key with no key material. The KMS key\nmust have an `Origin` value of `EXTERNAL`, which indicates that the KMS key is\ndesigned for imported key material.\n\nTo create an new KMS key for imported key material, call the `CreateKey`\noperation with an `Origin` value of `EXTERNAL`. You can create a symmetric\nencryption KMS key, HMAC KMS key, asymmetric encryption KMS key, or asymmetric\nsigning KMS key. You can also import key material into a [multi-Region key](kms/latest/developerguide/multi-region-keys-overview.html) of any supported\ntype. However, you can't import key material into a KMS key in a [custom key store](kms/latest/developerguide/custom-key-store-overview.html).\n\n  * Use the `DescribeKey` operation to verify that the `KeyState` of\nthe KMS key is `PendingImport`, which indicates that the KMS key has no key\nmaterial.\n\nIf you are reimporting the same key material into an existing KMS key, you might\nneed to call the `DeleteImportedKeyMaterial` to delete its existing key\nmaterial.\n\n  * Call the `GetParametersForImport` operation to get a public key\nand import token set for importing key material.\n\n  * Use the public key in the `GetParametersForImport` response to\nencrypt your key material.\n\nThen, in an `ImportKeyMaterial` request, you submit your encrypted key material\nand import token. When calling this operation, you must specify the following\nvalues:\n\n  * The key ID or key ARN of the KMS key to associate with the\nimported key material. Its `Origin` must be `EXTERNAL` and its `KeyState` must\nbe `PendingImport`. You cannot perform this operation on a KMS key in a [custom key store](kms/latest/developerguide/custom-key-store-overview.html), or on a\nKMS key in a different Amazon Web Services account. To get the `Origin` and\n`KeyState` of a KMS key, call `DescribeKey`.\n\n  * The encrypted key material.\n\n  * The import token that `GetParametersForImport` returned. You must\nuse a public key and token from the same `GetParametersForImport` response.\n\n  * Whether the key material expires (`ExpirationModel`) and, if so,\nwhen (`ValidTo`). For help with this choice, see [Setting an expiration time](https://docs.aws.amazon.com/en_us/kms/latest/developerguide/importing-keys.html#importing-keys-expiration)\nin the *Key Management Service Developer Guide*.\n\nIf you set an expiration date, KMS deletes the key material from the KMS key on\nthe specified date, making the KMS key unusable. To use the KMS key in\ncryptographic operations again, you must reimport the same key material.\nHowever, you can delete and reimport the key material at any time, including\nbefore the key material expires. Each time you reimport, you can eliminate or\nreset the expiration time.\n\nWhen this operation is successful, the key state of the KMS key changes from\n`PendingImport` to `Enabled`, and you can use the KMS key in cryptographic\noperations.\n\nIf this operation fails, use the exception to help determine the problem. If the\nerror is related to the key material, the import token, or wrapping key, use\n`GetParametersForImport` to get a new public key and import token for the KMS\nkey and repeat the import procedure. For help, see [How To Import Key Material](https://docs.aws.amazon.com/kms/latest/developerguide/importing-keys.html#importing-keys-overview)\nin the *Key Management Service Developer Guide*.\n\nThe KMS key that you use for this operation must be in a compatible key state.\nFor details, see [Key states of KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/key-state.html) in\nthe *Key Management Service Developer Guide*.\n\n**Cross-account use**: No. You cannot perform this operation on a KMS key in a\ndifferent Amazon Web Services account.\n\n**Required permissions**:\n[kms:ImportKeyMaterial](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html) (key policy)","ref":"AWS.KMS.html#import_key_material/3","title":"AWS.KMS.import_key_material/3","type":"function"},{"doc":"* `DeleteImportedKeyMaterial`\n\n  * `GetParametersForImport`\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual\nconsistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#import_key_material/3-related-operations","title":"Related operations: - AWS.KMS.import_key_material/3","type":"function"},{"doc":"Gets a list of aliases in the caller's Amazon Web Services account and region.\n\nFor more information about aliases, see `CreateAlias`.\n\nBy default, the `ListAliases` operation returns all aliases in the account and\nregion. To get only the aliases associated with a particular KMS key, use the\n`KeyId` parameter.\n\nThe `ListAliases` response can include aliases that you created and associated\nwith your customer managed keys, and aliases that Amazon Web Services created\nand associated with Amazon Web Services managed keys in your account. You can\nrecognize Amazon Web Services aliases because their names have the format\n`aws/ `, such as `aws/dynamodb`.\n\nThe response might also include aliases that have no `TargetKeyId` field. These\nare predefined aliases that Amazon Web Services has created but has not yet\nassociated with a KMS key. Aliases that Amazon Web Services creates in your\naccount, including predefined aliases, do not count against your [KMS aliases quota](https://docs.aws.amazon.com/kms/latest/developerguide/limits.html#aliases-limit).\n\n**Cross-account use**: No. `ListAliases` does not return aliases in other Amazon\nWeb Services accounts.\n\n**Required permissions**:\n[kms:ListAliases](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html) (IAM policy)\n\nFor details, see [Controlling access to\naliases](https://docs.aws.amazon.com/kms/latest/developerguide/kms-alias.html#alias-access)\nin the *Key Management Service Developer Guide*.","ref":"AWS.KMS.html#list_aliases/3","title":"AWS.KMS.list_aliases/3","type":"function"},{"doc":"* `CreateAlias`\n\n  * `DeleteAlias`\n\n  * `UpdateAlias`\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual consistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#list_aliases/3-related-operations","title":"Related operations: - AWS.KMS.list_aliases/3","type":"function"},{"doc":"Gets a list of all grants for the specified KMS key.\n\nYou must specify the KMS key in all requests. You can filter the grant list by\ngrant ID or grantee principal.\n\nFor detailed information about grants, including grant terminology, see [Grants in KMS](https://docs.aws.amazon.com/kms/latest/developerguide/grants.html) in\nthe * *Key Management Service Developer Guide* *. For examples of working with\ngrants in several programming languages, see [Programming grants](https://docs.aws.amazon.com/kms/latest/developerguide/programming-grants.html).\n\nThe `GranteePrincipal` field in the `ListGrants` response usually contains the\nuser or role designated as the grantee principal in the grant. However, when the\ngrantee principal in the grant is an Amazon Web Services service, the\n`GranteePrincipal` field contains the [service principal](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_principal.html#principal-services),\nwhich might represent several different grantee principals.\n\n**Cross-account use**: Yes. To perform this operation on a KMS key in a\ndifferent Amazon Web Services account, specify the key ARN in the value of the\n`KeyId` parameter.\n\n**Required permissions**:\n[kms:ListGrants](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html) (key policy)","ref":"AWS.KMS.html#list_grants/3","title":"AWS.KMS.list_grants/3","type":"function"},{"doc":"* `CreateGrant`\n\n  * `ListRetirableGrants`\n\n  * `RetireGrant`\n\n  * `RevokeGrant`\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual\nconsistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#list_grants/3-related-operations","title":"Related operations: - AWS.KMS.list_grants/3","type":"function"},{"doc":"Gets the names of the key policies that are attached to a KMS key.\n\nThis operation is designed to get policy names that you can use in a\n`GetKeyPolicy` operation. However, the only valid policy name is `default`.\n\n**Cross-account use**: No. You cannot perform this operation on a KMS key in a\ndifferent Amazon Web Services account.\n\n**Required permissions**:\n[kms:ListKeyPolicies](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html) (key policy)","ref":"AWS.KMS.html#list_key_policies/3","title":"AWS.KMS.list_key_policies/3","type":"function"},{"doc":"* `GetKeyPolicy`\n\n  *\n[PutKeyPolicy](https://docs.aws.amazon.com/kms/latest/APIReference/API_PutKeyPolicy.html)\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual consistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#list_key_policies/3-related-operations","title":"Related operations: - AWS.KMS.list_key_policies/3","type":"function"},{"doc":"Gets a list of all KMS keys in the caller's Amazon Web Services account and\nRegion.\n\n**Cross-account use**: No. You cannot perform this operation on a KMS key in a\ndifferent Amazon Web Services account.\n\n**Required permissions**:\n[kms:ListKeys](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html) (IAM policy)","ref":"AWS.KMS.html#list_keys/3","title":"AWS.KMS.list_keys/3","type":"function"},{"doc":"* `CreateKey`\n\n  * `DescribeKey`\n\n  * `ListAliases`\n\n  * `ListResourceTags`\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual\nconsistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#list_keys/3-related-operations","title":"Related operations: - AWS.KMS.list_keys/3","type":"function"},{"doc":"Returns all tags on the specified KMS key.\n\nFor general information about tags, including the format and syntax, see\n[Tagging Amazon Web Services resources](https://docs.aws.amazon.com/general/latest/gr/aws_tagging.html) in\nthe *Amazon Web Services General Reference*. For information about using tags in\nKMS, see [Tagging keys](https://docs.aws.amazon.com/kms/latest/developerguide/tagging-keys.html).\n\n**Cross-account use**: No. You cannot perform this operation on a KMS key in a\ndifferent Amazon Web Services account.\n\n**Required permissions**:\n[kms:ListResourceTags](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html) (key policy)","ref":"AWS.KMS.html#list_resource_tags/3","title":"AWS.KMS.list_resource_tags/3","type":"function"},{"doc":"* `CreateKey`\n\n  * `ReplicateKey`\n\n  * `TagResource`\n\n  * `UntagResource`\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual\nconsistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#list_resource_tags/3-related-operations","title":"Related operations: - AWS.KMS.list_resource_tags/3","type":"function"},{"doc":"Returns information about all grants in the Amazon Web Services account and\nRegion that have the specified retiring principal.\n\nYou can specify any principal in your Amazon Web Services account. The grants\nthat are returned include grants for KMS keys in your Amazon Web Services\naccount and other Amazon Web Services accounts. You might use this operation to\ndetermine which grants you may retire. To retire a grant, use the `RetireGrant`\noperation.\n\nFor detailed information about grants, including grant terminology, see [Grants in KMS](https://docs.aws.amazon.com/kms/latest/developerguide/grants.html) in\nthe * *Key Management Service Developer Guide* *. For examples of working with\ngrants in several programming languages, see [Programming grants](https://docs.aws.amazon.com/kms/latest/developerguide/programming-grants.html).\n\n**Cross-account use**: You must specify a principal in your Amazon Web Services\naccount. This operation returns a list of grants where the retiring principal\nspecified in the `ListRetirableGrants` request is the same retiring principal on\nthe grant. This can include grants on KMS keys owned by other Amazon Web\nServices accounts, but you do not need `kms:ListRetirableGrants` permission (or\nany other additional permission) in any Amazon Web Services account other than\nyour own.\n\n**Required permissions**:\n[kms:ListRetirableGrants](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html) (IAM policy) in your Amazon Web Services account.\n\nKMS authorizes `ListRetirableGrants` requests by evaluating the caller account's\nkms:ListRetirableGrants permissions. The authorized resource in\n`ListRetirableGrants` calls is the retiring principal specified in the request.\nKMS does not evaluate the caller's permissions to verify their access to any KMS\nkeys or grants that might be returned by the `ListRetirableGrants` call.","ref":"AWS.KMS.html#list_retirable_grants/3","title":"AWS.KMS.list_retirable_grants/3","type":"function"},{"doc":"* `CreateGrant`\n\n  * `ListGrants`\n\n  * `RetireGrant`\n\n  * `RevokeGrant`\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual\nconsistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#list_retirable_grants/3-related-operations","title":"Related operations: - AWS.KMS.list_retirable_grants/3","type":"function"},{"doc":"","ref":"AWS.KMS.html#metadata/0","title":"AWS.KMS.metadata/0","type":"function"},{"doc":"Attaches a key policy to the specified KMS key.\n\nFor more information about key policies, see [Key Policies](https://docs.aws.amazon.com/kms/latest/developerguide/key-policies.html)\nin the *Key Management Service Developer Guide*. For help writing and formatting\na JSON policy document, see the [IAM JSON Policy Reference](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies.html)\nin the * *Identity and Access Management User Guide* *. For examples of adding a\nkey policy in multiple programming languages, see [Setting a key policy](https://docs.aws.amazon.com/kms/latest/developerguide/programming-key-policies.html#put-policy)\nin the *Key Management Service Developer Guide*.\n\n**Cross-account use**: No. You cannot perform this operation on a KMS key in a\ndifferent Amazon Web Services account.\n\n**Required permissions**:\n[kms:PutKeyPolicy](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html) (key policy)\n\n**Related operations**: `GetKeyPolicy`\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual\nconsistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#put_key_policy/3","title":"AWS.KMS.put_key_policy/3","type":"function"},{"doc":"Decrypts ciphertext and then reencrypts it entirely within KMS.\n\nYou can use this operation to change the KMS key under which data is encrypted,\nsuch as when you [manually rotate](https://docs.aws.amazon.com/kms/latest/developerguide/rotate-keys.html#rotate-keys-manually)\na KMS key or change the KMS key that protects a ciphertext. You can also use it\nto reencrypt ciphertext under the same KMS key, such as to change the\n[encryption context](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#encrypt_context)\nof a ciphertext.\n\nThe `ReEncrypt` operation can decrypt ciphertext that was encrypted by using a\nKMS key in an KMS operation, such as `Encrypt` or `GenerateDataKey`. It can also\ndecrypt ciphertext that was encrypted by using the public key of an [asymmetric KMS\nkey](https://docs.aws.amazon.com/kms/latest/developerguide/symm-asymm-concepts.html#asymmetric-cmks)\noutside of KMS. However, it cannot decrypt ciphertext produced by other\nlibraries, such as the [Amazon Web Services Encryption SDK](https://docs.aws.amazon.com/encryption-sdk/latest/developer-guide/) or\n[Amazon S3 client-side encryption](https://docs.aws.amazon.com/AmazonS3/latest/dev/UsingClientSideEncryption.html).\nThese libraries return a ciphertext format that is incompatible with KMS.\n\nWhen you use the `ReEncrypt` operation, you need to provide information for the\ndecrypt operation and the subsequent encrypt operation.\n\n  * If your ciphertext was encrypted under an asymmetric KMS key, you\nmust use the `SourceKeyId` parameter to identify the KMS key that encrypted the\nciphertext. You must also supply the encryption algorithm that was used. This\ninformation is required to decrypt the data.\n\n  * If your ciphertext was encrypted under a symmetric encryption KMS\nkey, the `SourceKeyId` parameter is optional. KMS can get this information from\nmetadata that it adds to the symmetric ciphertext blob. This feature adds\ndurability to your implementation by ensuring that authorized users can decrypt\nciphertext decades after it was encrypted, even if they've lost track of the key\nID. However, specifying the source KMS key is always recommended as a best\npractice. When you use the `SourceKeyId` parameter to specify a KMS key, KMS\nuses only the KMS key you specify. If the ciphertext was encrypted under a\ndifferent KMS key, the `ReEncrypt` operation fails. This practice ensures that\nyou use the KMS key that you intend.\n\n  * To reencrypt the data, you must use the `DestinationKeyId`\nparameter to specify the KMS key that re-encrypts the data after it is\ndecrypted. If the destination KMS key is an asymmetric KMS key, you must also\nprovide the encryption algorithm. The algorithm that you choose must be\ncompatible with the KMS key.\n\nWhen you use an asymmetric KMS key to encrypt or reencrypt data, be sure to\nrecord the KMS key and encryption algorithm that you choose. You will be\nrequired to provide the same KMS key and encryption algorithm when you decrypt\nthe data. If the KMS key and algorithm do not match the values used to encrypt\nthe data, the decrypt operation fails.\n\nYou are not required to supply the key ID and encryption algorithm when you\ndecrypt with symmetric encryption KMS keys because KMS stores this information\nin the ciphertext blob. KMS cannot store metadata in ciphertext generated with\nasymmetric keys. The standard format for asymmetric key ciphertext does not\ninclude configurable fields.\n\nThe KMS key that you use for this operation must be in a compatible key state.\nFor details, see [Key states of KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/key-state.html) in\nthe *Key Management Service Developer Guide*.\n\n**Cross-account use**: Yes. The source KMS key and destination KMS key can be in\ndifferent Amazon Web Services accounts. Either or both KMS keys can be in a\ndifferent account than the caller. To specify a KMS key in a different account,\nyou must use its key ARN or alias ARN.\n\n**Required permissions**:\n\n  *\n[kms:ReEncryptFrom](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html) permission on the source KMS key (key policy)\n\n  *\n[kms:ReEncryptTo](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html)\npermission on the destination KMS key (key policy)\n\nTo permit reencryption from or to a KMS key, include the `\"kms:ReEncrypt*\"`\npermission in your [key policy](https://docs.aws.amazon.com/kms/latest/developerguide/key-policies.html).\nThis permission is automatically included in the key policy when you use the\nconsole to create a KMS key. But you must include it manually when you create a\nKMS key programmatically or when you use the `PutKeyPolicy` operation to set a\nkey policy.","ref":"AWS.KMS.html#re_encrypt/3","title":"AWS.KMS.re_encrypt/3","type":"function"},{"doc":"* `Decrypt`\n\n  * `Encrypt`\n\n  * `GenerateDataKey`\n\n  * `GenerateDataKeyPair`\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual consistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#re_encrypt/3-related-operations","title":"Related operations: - AWS.KMS.re_encrypt/3","type":"function"},{"doc":"Replicates a multi-Region key into the specified Region.\n\nThis operation creates a multi-Region replica key based on a multi-Region\nprimary key in a different Region of the same Amazon Web Services partition. You\ncan create multiple replicas of a primary key, but each must be in a different\nRegion. To create a multi-Region primary key, use the `CreateKey` operation.\n\nThis operation supports *multi-Region keys*, an KMS feature that lets you create\nmultiple interoperable KMS keys in different Amazon Web Services Regions.\nBecause these KMS keys have the same key ID, key material, and other metadata,\nyou can use them interchangeably to encrypt data in one Amazon Web Services\nRegion and decrypt it in a different Amazon Web Services Region without\nre-encrypting the data or making a cross-Region call. For more information about\nmulti-Region keys, see [Multi-Region keys in KMS](https://docs.aws.amazon.com/kms/latest/developerguide/multi-region-keys-overview.html)\nin the *Key Management Service Developer Guide*.\n\nA *replica key* is a fully-functional KMS key that can be used independently of\nits primary and peer replica keys. A primary key and its replica keys share\nproperties that make them interoperable. They have the same [key ID](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#key-id-key-id)\nand key material. They also have the same [key spec](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#key-spec),\n[key usage](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#key-usage),\n[key material origin](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#key-origin),\nand [automatic key rotation status](https://docs.aws.amazon.com/kms/latest/developerguide/rotate-keys.html).\nKMS automatically synchronizes these shared properties among related\nmulti-Region keys. All other properties of a replica key can differ, including\nits [key policy](https://docs.aws.amazon.com/kms/latest/developerguide/key-policies.html),\n[tags](https://docs.aws.amazon.com/kms/latest/developerguide/tagging-keys.html), [aliases](https://docs.aws.amazon.com/kms/latest/developerguide/kms-alias.html),\nand [Key states of KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/key-state.html). KMS\npricing and quotas for KMS keys apply to each primary key and replica key.\n\nWhen this operation completes, the new replica key has a transient key state of\n`Creating`. This key state changes to `Enabled` (or `PendingImport`) after a few\nseconds when the process of creating the new replica key is complete. While the\nkey state is `Creating`, you can manage key, but you cannot yet use it in\ncryptographic operations. If you are creating and using the replica key\nprogrammatically, retry on `KMSInvalidStateException` or call `DescribeKey` to\ncheck its `KeyState` value before using it. For details about the `Creating` key\nstate, see [Key states of KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/key-state.html) in\nthe *Key Management Service Developer Guide*.\n\nYou cannot create more than one replica of a primary key in any Region. If the\nRegion already includes a replica of the key you're trying to replicate,\n`ReplicateKey` returns an `AlreadyExistsException` error. If the key state of\nthe existing replica is `PendingDeletion`, you can cancel the scheduled key\ndeletion (`CancelKeyDeletion`) or wait for the key to be deleted. The new\nreplica key you create will have the same [shared properties](https://docs.aws.amazon.com/kms/latest/developerguide/multi-region-keys-overview.html#mrk-sync-properties)\nas the original replica key.\n\nThe CloudTrail log of a `ReplicateKey` operation records a `ReplicateKey`\noperation in the primary key's Region and a `CreateKey` operation in the replica\nkey's Region.\n\nIf you replicate a multi-Region primary key with imported key material, the\nreplica key is created with no key material. You must import the same key\nmaterial that you imported into the primary key. For details, see [Importing key material into multi-Region\nkeys](https://docs.aws.amazon.com/kms/latest/developerguide/multi-region-keys-import.html)\nin the *Key Management Service Developer Guide*.\n\nTo convert a replica key to a primary key, use the `UpdatePrimaryRegion`\noperation.\n\n`ReplicateKey` uses different default values for the `KeyPolicy` and `Tags`\nparameters than those used in the KMS console. For details, see the parameter\ndescriptions.\n\n**Cross-account use**: No. You cannot use this operation to create a replica key\nin a different Amazon Web Services account.\n\n**Required permissions**:\n\n  * `kms:ReplicateKey` on the primary key (in the primary key's\nRegion). Include this permission in the primary key's key policy.\n\n  * `kms:CreateKey` in an IAM policy in the replica Region.\n\n  * To use the `Tags` parameter, `kms:TagResource` in an IAM policy in\nthe replica Region.","ref":"AWS.KMS.html#replicate_key/3","title":"AWS.KMS.replicate_key/3","type":"function"},{"doc":"* `CreateKey`\n\n  * `UpdatePrimaryRegion`\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual consistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#replicate_key/3-related-operations","title":"Related operations - AWS.KMS.replicate_key/3","type":"function"},{"doc":"Deletes a grant.\n\nTypically, you retire a grant when you no longer need its permissions. To\nidentify the grant to retire, use a [grant token](https://docs.aws.amazon.com/kms/latest/developerguide/grants.html#grant_token),\nor both the grant ID and a key identifier (key ID or key ARN) of the KMS key.\nThe `CreateGrant` operation returns both values.\n\nThis operation can be called by the *retiring principal* for a grant, by the\n*grantee principal* if the grant allows the `RetireGrant` operation, and by the\nAmazon Web Services account in which the grant is created. It can also be called\nby principals to whom permission for retiring a grant is delegated. For details,\nsee [Retiring and revoking grants](https://docs.aws.amazon.com/kms/latest/developerguide/grant-manage.html#grant-delete)\nin the *Key Management Service Developer Guide*.\n\nFor detailed information about grants, including grant terminology, see [Grants in KMS](https://docs.aws.amazon.com/kms/latest/developerguide/grants.html) in\nthe * *Key Management Service Developer Guide* *. For examples of working with\ngrants in several programming languages, see [Programming grants](https://docs.aws.amazon.com/kms/latest/developerguide/programming-grants.html).\n\n**Cross-account use**: Yes. You can retire a grant on a KMS key in a different\nAmazon Web Services account.\n\n**Required permissions**: Permission to retire a grant is determined primarily\nby the grant. For details, see [Retiring and revoking grants](https://docs.aws.amazon.com/kms/latest/developerguide/grant-manage.html#grant-delete)\nin the *Key Management Service Developer Guide*.","ref":"AWS.KMS.html#retire_grant/3","title":"AWS.KMS.retire_grant/3","type":"function"},{"doc":"* `CreateGrant`\n\n  * `ListGrants`\n\n  * `ListRetirableGrants`\n\n  * `RevokeGrant`\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual consistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#retire_grant/3-related-operations","title":"Related operations: - AWS.KMS.retire_grant/3","type":"function"},{"doc":"Deletes the specified grant.\n\nYou revoke a grant to terminate the permissions that the grant allows. For more\ninformation, see [Retiring and revoking grants](https://docs.aws.amazon.com/kms/latest/developerguide/managing-grants.html#grant-delete)\nin the * *Key Management Service Developer Guide* *.\n\nWhen you create, retire, or revoke a grant, there might be a brief delay,\nusually less than five minutes, until the grant is available throughout KMS.\nThis state is known as *eventual consistency*. For details, see [Eventual consistency](https://docs.aws.amazon.com/kms/latest/developerguide/grants.html#terms-eventual-consistency)\nin the * *Key Management Service Developer Guide* *.\n\nFor detailed information about grants, including grant terminology, see [Grants in KMS](https://docs.aws.amazon.com/kms/latest/developerguide/grants.html) in\nthe * *Key Management Service Developer Guide* *. For examples of working with\ngrants in several programming languages, see [Programming grants](https://docs.aws.amazon.com/kms/latest/developerguide/programming-grants.html).\n\n**Cross-account use**: Yes. To perform this operation on a KMS key in a\ndifferent Amazon Web Services account, specify the key ARN in the value of the\n`KeyId` parameter.\n\n**Required permissions**:\n[kms:RevokeGrant](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html) (key policy).","ref":"AWS.KMS.html#revoke_grant/3","title":"AWS.KMS.revoke_grant/3","type":"function"},{"doc":"* `CreateGrant`\n\n  * `ListGrants`\n\n  * `ListRetirableGrants`\n\n  * `RetireGrant`\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual\nconsistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#revoke_grant/3-related-operations","title":"Related operations: - AWS.KMS.revoke_grant/3","type":"function"},{"doc":"Schedules the deletion of a KMS key.\n\nBy default, KMS applies a waiting period of 30 days, but you can specify a\nwaiting period of 7-30 days. When this operation is successful, the key state of\nthe KMS key changes to `PendingDeletion` and the key can't be used in any\ncryptographic operations. It remains in this state for the duration of the\nwaiting period. Before the waiting period ends, you can use `CancelKeyDeletion`\nto cancel the deletion of the KMS key. After the waiting period ends, KMS\ndeletes the KMS key, its key material, and all KMS data associated with it,\nincluding all aliases that refer to it.\n\nDeleting a KMS key is a destructive and potentially dangerous operation. When a\nKMS key is deleted, all data that was encrypted under the KMS key is\nunrecoverable. (The only exception is a [multi-Region replica key](https://docs.aws.amazon.com/kms/latest/developerguide/multi-region-keys-delete.html),\nor an [asymmetric or HMAC KMS key with imported key material](kms/latest/developerguide/importing-keys-managing.html#import-delete-key).)\nTo prevent the use of a KMS key without deleting it, use `DisableKey`.\n\nYou can schedule the deletion of a multi-Region primary key and its replica keys\nat any time. However, KMS will not delete a multi-Region primary key with\nexisting replica keys. If you schedule the deletion of a primary key with\nreplicas, its key state changes to `PendingReplicaDeletion` and it cannot be\nreplicated or used in cryptographic operations. This status can continue\nindefinitely. When the last of its replicas keys is deleted (not just\nscheduled), the key state of the primary key changes to `PendingDeletion` and\nits waiting period (`PendingWindowInDays`) begins. For details, see [Deleting multi-Region\nkeys](https://docs.aws.amazon.com/kms/latest/developerguide/multi-region-keys-delete.html)\nin the *Key Management Service Developer Guide*.\n\nWhen KMS [deletes a KMS key from an CloudHSM key store](https://docs.aws.amazon.com/kms/latest/developerguide/delete-cmk-keystore.html),\nit makes a best effort to delete the associated key material from the associated\nCloudHSM cluster. However, you might need to manually [delete the orphaned key material](https://docs.aws.amazon.com/kms/latest/developerguide/fix-keystore.html#fix-keystore-orphaned-key)\nfrom the cluster and its backups. [Deleting a KMS key from an external key store](https://docs.aws.amazon.com/kms/latest/developerguide/delete-xks-key.html)\nhas no effect on the associated external key. However, for both types of custom\nkey stores, deleting a KMS key is destructive and irreversible. You cannot\ndecrypt ciphertext encrypted under the KMS key by using only its associated\nexternal key or CloudHSM key. Also, you cannot recreate a KMS key in an external\nkey store by creating a new KMS key with the same key material.\n\nFor more information about scheduling a KMS key for deletion, see [Deleting KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/deleting-keys.html)\nin the *Key Management Service Developer Guide*.\n\nThe KMS key that you use for this operation must be in a compatible key state.\nFor details, see [Key states of KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/key-state.html) in\nthe *Key Management Service Developer Guide*.\n\n**Cross-account use**: No. You cannot perform this operation on a KMS key in a\ndifferent Amazon Web Services account.\n\n**Required permissions**: kms:ScheduleKeyDeletion (key policy)","ref":"AWS.KMS.html#schedule_key_deletion/3","title":"AWS.KMS.schedule_key_deletion/3","type":"function"},{"doc":"* `CancelKeyDeletion`\n\n  * `DisableKey`\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual consistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#schedule_key_deletion/3-related-operations","title":"Related operations - AWS.KMS.schedule_key_deletion/3","type":"function"},{"doc":"Creates a [digital signature](https://en.wikipedia.org/wiki/Digital_signature) for a message or message digest by using the private key in an asymmetric\nsigning KMS key.\n\nTo verify the signature, use the `Verify` operation, or use the public key in\nthe same asymmetric KMS key outside of KMS. For information about asymmetric KMS\nkeys, see [Asymmetric KMS\nkeys](https://docs.aws.amazon.com/kms/latest/developerguide/symmetric-asymmetric.html)\nin the *Key Management Service Developer Guide*.\n\nDigital signatures are generated and verified by using asymmetric key pair, such\nas an RSA or ECC pair that is represented by an asymmetric KMS key. The key\nowner (or an authorized user) uses their private key to sign a message. Anyone\nwith the public key can verify that the message was signed with that particular\nprivate key and that the message hasn't changed since it was signed.\n\nTo use the `Sign` operation, provide the following information:\n\n  * Use the `KeyId` parameter to identify an asymmetric KMS key with a\n`KeyUsage` value of `SIGN_VERIFY`. To get the `KeyUsage` value of a KMS key, use\nthe `DescribeKey` operation. The caller must have `kms:Sign` permission on the\nKMS key.\n\n  * Use the `Message` parameter to specify the message or message\ndigest to sign. You can submit messages of up to 4096 bytes. To sign a larger\nmessage, generate a hash digest of the message, and then provide the hash digest\nin the `Message` parameter. To indicate whether the message is a full message or\na digest, use the `MessageType` parameter.\n\n  * Choose a signing algorithm that is compatible with the KMS key.\n\nWhen signing a message, be sure to record the KMS key and the signing algorithm.\nThis information is required to verify the signature.\n\nBest practices recommend that you limit the time during which any signature is\neffective. This deters an attack where the actor uses a signed message to\nestablish validity repeatedly or long after the message is superseded.\nSignatures do not include a timestamp, but you can include a timestamp in the\nsigned message to help you detect when its time to refresh the signature.\n\nTo verify the signature that this operation generates, use the `Verify`\noperation. Or use the `GetPublicKey` operation to download the public key and\nthen use the public key to verify the signature outside of KMS.\n\nThe KMS key that you use for this operation must be in a compatible key state.\nFor details, see [Key states of KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/key-state.html) in\nthe *Key Management Service Developer Guide*.\n\n**Cross-account use**: Yes. To perform this operation with a KMS key in a\ndifferent Amazon Web Services account, specify the key ARN or alias ARN in the\nvalue of the `KeyId` parameter.\n\n**Required permissions**:\n[kms:Sign](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html) (key policy)\n\n**Related operations**: `Verify`\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual\nconsistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#sign/3","title":"AWS.KMS.sign/3","type":"function"},{"doc":"Adds or edits tags on a [customer managed key](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#customer-cmk).\n\nTagging or untagging a KMS key can allow or deny permission to the KMS key. For\ndetails, see [ABAC for KMS](https://docs.aws.amazon.com/kms/latest/developerguide/abac.html) in the\n*Key Management Service Developer Guide*.\n\nEach tag consists of a tag key and a tag value, both of which are case-sensitive\nstrings. The tag value can be an empty (null) string. To add a tag, specify a\nnew tag key and a tag value. To edit a tag, specify an existing tag key and a\nnew tag value.\n\nYou can use this operation to tag a [customer managed key](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#customer-cmk),\nbut you cannot tag an [Amazon Web Services managed key](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#aws-managed-cmk),\nan [Amazon Web Services owned key](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#aws-owned-cmk),\na [custom key store](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#keystore-concept),\nor an\n[alias](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#alias-concept).  You can also add tags to a KMS key while creating it (`CreateKey`) or\nreplicating it (`ReplicateKey`).\n\nFor information about using tags in KMS, see [Tagging\nkeys](https://docs.aws.amazon.com/kms/latest/developerguide/tagging-keys.html).\nFor general information about tags, including the format and syntax, see\n[Tagging Amazon Web Services resources](https://docs.aws.amazon.com/general/latest/gr/aws_tagging.html) in\nthe *Amazon Web Services General Reference*.\n\nThe KMS key that you use for this operation must be in a compatible key state.\nFor details, see [Key states of KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/key-state.html) in\nthe *Key Management Service Developer Guide*.\n\n**Cross-account use**: No. You cannot perform this operation on a KMS key in a\ndifferent Amazon Web Services account.\n\n**Required permissions**:\n[kms:TagResource](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html) (key policy)","ref":"AWS.KMS.html#tag_resource/3","title":"AWS.KMS.tag_resource/3","type":"function"},{"doc":"* `CreateKey`\n\n  * `ListResourceTags`\n\n  * `ReplicateKey`\n\n  * `UntagResource`\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual\nconsistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#tag_resource/3-related-operations","title":"Related operations - AWS.KMS.tag_resource/3","type":"function"},{"doc":"Deletes tags from a [customer managed key](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#customer-cmk).\n\nTo delete a tag, specify the tag key and the KMS key.\n\nTagging or untagging a KMS key can allow or deny permission to the KMS key. For\ndetails, see [ABAC for KMS](https://docs.aws.amazon.com/kms/latest/developerguide/abac.html) in the\n*Key Management Service Developer Guide*.\n\nWhen it succeeds, the `UntagResource` operation doesn't return any output. Also,\nif the specified tag key isn't found on the KMS key, it doesn't throw an\nexception or return a response. To confirm that the operation worked, use the\n`ListResourceTags` operation.\n\nFor information about using tags in KMS, see [Tagging keys](https://docs.aws.amazon.com/kms/latest/developerguide/tagging-keys.html).\nFor general information about tags, including the format and syntax, see\n[Tagging Amazon Web Services resources](https://docs.aws.amazon.com/general/latest/gr/aws_tagging.html) in\nthe *Amazon Web Services General Reference*.\n\nThe KMS key that you use for this operation must be in a compatible key state.\nFor details, see [Key states of KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/key-state.html) in\nthe *Key Management Service Developer Guide*.\n\n**Cross-account use**: No. You cannot perform this operation on a KMS key in a\ndifferent Amazon Web Services account.\n\n**Required permissions**:\n[kms:UntagResource](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html) (key policy)","ref":"AWS.KMS.html#untag_resource/3","title":"AWS.KMS.untag_resource/3","type":"function"},{"doc":"* `CreateKey`\n\n  * `ListResourceTags`\n\n  * `ReplicateKey`\n\n  * `TagResource`\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual\nconsistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#untag_resource/3-related-operations","title":"Related operations - AWS.KMS.untag_resource/3","type":"function"},{"doc":"Associates an existing KMS alias with a different KMS key.\n\nEach alias is associated with only one KMS key at a time, although a KMS key can\nhave multiple aliases. The alias and the KMS key must be in the same Amazon Web\nServices account and Region.\n\nAdding, deleting, or updating an alias can allow or deny permission to the KMS\nkey. For details, see [ABAC for KMS](https://docs.aws.amazon.com/kms/latest/developerguide/abac.html) in the\n*Key Management Service Developer Guide*.\n\nThe current and new KMS key must be the same type (both symmetric or both\nasymmetric or both HMAC), and they must have the same key usage. This\nrestriction prevents errors in code that uses aliases. If you must assign an\nalias to a different type of KMS key, use `DeleteAlias` to delete the old alias\nand `CreateAlias` to create a new alias.\n\nYou cannot use `UpdateAlias` to change an alias name. To change an alias name,\nuse `DeleteAlias` to delete the old alias and `CreateAlias` to create a new\nalias.\n\nBecause an alias is not a property of a KMS key, you can create, update, and\ndelete the aliases of a KMS key without affecting the KMS key. Also, aliases do\nnot appear in the response from the `DescribeKey` operation. To get the aliases\nof all KMS keys in the account, use the `ListAliases` operation.\n\nThe KMS key that you use for this operation must be in a compatible key state.\nFor details, see [Key states of KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/key-state.html) in\nthe *Key Management Service Developer Guide*.\n\n**Cross-account use**: No. You cannot perform this operation on a KMS key in a\ndifferent Amazon Web Services account.","ref":"AWS.KMS.html#update_alias/3","title":"AWS.KMS.update_alias/3","type":"function"},{"doc":"*\n[kms:UpdateAlias](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html) on the alias (IAM policy).\n\n  *\n[kms:UpdateAlias](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html)\non the current KMS key (key policy).\n\n  *\n[kms:UpdateAlias](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html) on the new KMS key (key policy).\n\nFor details, see [Controlling access to\naliases](https://docs.aws.amazon.com/kms/latest/developerguide/kms-alias.html#alias-access)\nin the *Key Management Service Developer Guide*.","ref":"AWS.KMS.html#update_alias/3-required-permissions","title":"Required permissions - AWS.KMS.update_alias/3","type":"function"},{"doc":"* `CreateAlias`\n\n  * `DeleteAlias`\n\n  * `ListAliases`\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual consistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#update_alias/3-related-operations","title":"Related operations: - AWS.KMS.update_alias/3","type":"function"},{"doc":"Changes the properties of a custom key store.\n\nYou can use this operation to change the properties of an CloudHSM key store or\nan external key store.\n\nUse the required `CustomKeyStoreId` parameter to identify the custom key store.\nUse the remaining optional parameters to change its properties. This operation\ndoes not return any property values. To verify the updated property values, use\nthe `DescribeCustomKeyStores` operation.\n\nThis operation is part of the [custom key stores](https://docs.aws.amazon.com/kms/latest/developerguide/custom-key-store-overview.html)\nfeature in KMS, which combines the convenience and extensive integration of KMS\nwith the isolation and control of a key store that you own and manage.\n\nWhen updating the properties of an external key store, verify that the updated\nsettings connect your key store, via the external key store proxy, to the same\nexternal key manager as the previous settings, or to a backup or snapshot of the\nexternal key manager with the same cryptographic keys. If the updated connection\nsettings fail, you can fix them and retry, although an extended delay might\ndisrupt Amazon Web Services services. However, if KMS permanently loses its\naccess to cryptographic keys, ciphertext encrypted under those keys is\nunrecoverable.\n\nFor external key stores:\n\nSome external key managers provide a simpler method for updating an external key\nstore. For details, see your external key manager documentation.\n\nWhen updating an external key store in the KMS console, you can upload a\nJSON-based proxy configuration file with the desired values. You cannot upload\nthe proxy configuration file to the `UpdateCustomKeyStore` operation. However,\nyou can use the file to help you determine the correct values for the\n`UpdateCustomKeyStore` parameters.\n\nFor an CloudHSM key store, you can use this operation to change the custom key\nstore friendly name (`NewCustomKeyStoreName`), to tell KMS about a change to the\n`kmsuser` crypto user password (`KeyStorePassword`), or to associate the custom\nkey store with a different, but related, CloudHSM cluster (`CloudHsmClusterId`).\nTo update any property of an CloudHSM key store, the `ConnectionState` of the\nCloudHSM key store must be `DISCONNECTED`.\n\nFor an external key store, you can use this operation to change the custom key\nstore friendly name (`NewCustomKeyStoreName`), or to tell KMS about a change to\nthe external key store proxy authentication credentials\n(`XksProxyAuthenticationCredential`), connection method\n(`XksProxyConnectivity`), external proxy endpoint (`XksProxyUriEndpoint`) and\npath (`XksProxyUriPath`). For external key stores with an `XksProxyConnectivity`\nof `VPC_ENDPOINT_SERVICE`, you can also update the Amazon VPC endpoint service\nname (`XksProxyVpcEndpointServiceName`). To update most properties of an\nexternal key store, the `ConnectionState` of the external key store must be\n`DISCONNECTED`. However, you can update the `CustomKeyStoreName`,\n`XksProxyAuthenticationCredential`, and `XksProxyUriPath` of an external key\nstore when it is in the CONNECTED or DISCONNECTED state.\n\nIf your update requires a `DISCONNECTED` state, before using\n`UpdateCustomKeyStore`, use the `DisconnectCustomKeyStore` operation to\ndisconnect the custom key store. After the `UpdateCustomKeyStore` operation\ncompletes, use the `ConnectCustomKeyStore` to reconnect the custom key store. To\nfind the `ConnectionState` of the custom key store, use the\n`DescribeCustomKeyStores` operation.\n\nBefore updating the custom key store, verify that the new values allow KMS to\nconnect the custom key store to its backing key store. For example, before you\nchange the `XksProxyUriPath` value, verify that the external key store proxy is\nreachable at the new path.\n\nIf the operation succeeds, it returns a JSON object with no properties.\n\n**Cross-account use**: No. You cannot perform this operation on a custom key\nstore in a different Amazon Web Services account.\n\n**Required permissions**:\n[kms:UpdateCustomKeyStore](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html) (IAM policy)","ref":"AWS.KMS.html#update_custom_key_store/3","title":"AWS.KMS.update_custom_key_store/3","type":"function"},{"doc":"* `ConnectCustomKeyStore`\n\n  * `CreateCustomKeyStore`\n\n  * `DeleteCustomKeyStore`\n\n  * `DescribeCustomKeyStores`\n\n  * `DisconnectCustomKeyStore`\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual\nconsistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#update_custom_key_store/3-related-operations","title":"Related operations: - AWS.KMS.update_custom_key_store/3","type":"function"},{"doc":"Updates the description of a KMS key.\n\nTo see the description of a KMS key, use `DescribeKey`.\n\nThe KMS key that you use for this operation must be in a compatible key state.\nFor details, see [Key states of KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/key-state.html) in\nthe *Key Management Service Developer Guide*.\n\n**Cross-account use**: No. You cannot perform this operation on a KMS key in a\ndifferent Amazon Web Services account.\n\n**Required permissions**:\n[kms:UpdateKeyDescription](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html) (key policy)","ref":"AWS.KMS.html#update_key_description/3","title":"AWS.KMS.update_key_description/3","type":"function"},{"doc":"* `CreateKey`\n\n  * `DescribeKey`\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual\nconsistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#update_key_description/3-related-operations","title":"Related operations - AWS.KMS.update_key_description/3","type":"function"},{"doc":"Changes the primary key of a multi-Region key.\n\nThis operation changes the replica key in the specified Region to a primary key\nand changes the former primary key to a replica key. For example, suppose you\nhave a primary key in `us-east-1` and a replica key in `eu-west-2`. If you run\n`UpdatePrimaryRegion` with a `PrimaryRegion` value of `eu-west-2`, the primary\nkey is now the key in `eu-west-2`, and the key in `us-east-1` becomes a replica\nkey. For details, see [Updating the primary Region](https://docs.aws.amazon.com/kms/latest/developerguide/multi-region-keys-manage.html#multi-region-update)\nin the *Key Management Service Developer Guide*.\n\nThis operation supports *multi-Region keys*, an KMS feature that lets you create\nmultiple interoperable KMS keys in different Amazon Web Services Regions.\nBecause these KMS keys have the same key ID, key material, and other metadata,\nyou can use them interchangeably to encrypt data in one Amazon Web Services\nRegion and decrypt it in a different Amazon Web Services Region without\nre-encrypting the data or making a cross-Region call. For more information about\nmulti-Region keys, see [Multi-Region keys in KMS](https://docs.aws.amazon.com/kms/latest/developerguide/multi-region-keys-overview.html)\nin the *Key Management Service Developer Guide*.\n\nThe *primary key* of a multi-Region key is the source for properties that are\nalways shared by primary and replica keys, including the key material, [key ID](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#key-id-key-id),\n[key spec](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#key-spec),\n[key usage](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#key-usage),\n[key material origin](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#key-origin),\nand [automatic key rotation](https://docs.aws.amazon.com/kms/latest/developerguide/rotate-keys.html).\nIt's the only key that can be replicated. You cannot [delete the primary key](https://docs.aws.amazon.com/kms/latest/APIReference/API_ScheduleKeyDeletion.html)\nuntil all replica keys are deleted.\n\nThe key ID and primary Region that you specify uniquely identify the replica key\nthat will become the primary key. The primary Region must already have a replica\nkey. This operation does not create a KMS key in the specified Region. To find\nthe replica keys, use the `DescribeKey` operation on the primary key or any\nreplica key. To create a replica key, use the `ReplicateKey` operation.\n\nYou can run this operation while using the affected multi-Region keys in\ncryptographic operations. This operation should not delay, interrupt, or cause\nfailures in cryptographic operations.\n\nEven after this operation completes, the process of updating the primary Region\nmight still be in progress for a few more seconds. Operations such as\n`DescribeKey` might display both the old and new primary keys as replicas. The\nold and new primary keys have a transient key state of `Updating`. The original\nkey state is restored when the update is complete. While the key state is\n`Updating`, you can use the keys in cryptographic operations, but you cannot\nreplicate the new primary key or perform certain management operations, such as\nenabling or disabling these keys. For details about the `Updating` key state,\nsee [Key states of KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/key-state.html) in\nthe *Key Management Service Developer Guide*.\n\nThis operation does not return any output. To verify that primary key is\nchanged, use the `DescribeKey` operation.\n\n**Cross-account use**: No. You cannot use this operation in a different Amazon\nWeb Services account.\n\n**Required permissions**:\n\n  * `kms:UpdatePrimaryRegion` on the current primary key (in the\nprimary key's Region). Include this permission primary key's key policy.\n\n  * `kms:UpdatePrimaryRegion` on the current replica key (in the\nreplica key's Region). Include this permission in the replica key's key policy.","ref":"AWS.KMS.html#update_primary_region/3","title":"AWS.KMS.update_primary_region/3","type":"function"},{"doc":"* `CreateKey`\n\n  * `ReplicateKey`\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual consistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#update_primary_region/3-related-operations","title":"Related operations - AWS.KMS.update_primary_region/3","type":"function"},{"doc":"Verifies a digital signature that was generated by the `Sign` operation.\n\nVerification confirms that an authorized user signed the message with the\nspecified KMS key and signing algorithm, and the message hasn't changed since it\nwas signed. If the signature is verified, the value of the `SignatureValid`\nfield in the response is `True`. If the signature verification fails, the\n`Verify` operation fails with an `KMSInvalidSignatureException` exception.\n\nA digital signature is generated by using the private key in an asymmetric KMS\nkey. The signature is verified by using the public key in the same asymmetric\nKMS key. For information about asymmetric KMS keys, see [Asymmetric KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/symmetric-asymmetric.html)\nin the *Key Management Service Developer Guide*.\n\nTo use the `Verify` operation, specify the same asymmetric KMS key, message, and\nsigning algorithm that were used to produce the signature. The message type does\nnot need to be the same as the one used for signing, but it must indicate\nwhether the value of the `Message` parameter should be hashed as part of the\nverification process.\n\nYou can also verify the digital signature by using the public key of the KMS key\noutside of KMS. Use the `GetPublicKey` operation to download the public key in\nthe asymmetric KMS key and then use the public key to verify the signature\noutside of KMS. The advantage of using the `Verify` operation is that it is\nperformed within KMS. As a result, it's easy to call, the operation is performed\nwithin the FIPS boundary, it is logged in CloudTrail, and you can use key policy\nand IAM policy to determine who is authorized to use the KMS key to verify\nsignatures.\n\nTo verify a signature outside of KMS with an SM2 public key (China Regions\nonly), you must specify the distinguishing ID. By default, KMS uses\n`1234567812345678` as the distinguishing ID. For more information, see [Offline verification with SM2 key\npairs](https://docs.aws.amazon.com/kms/latest/developerguide/asymmetric-key-specs.html#key-spec-sm-offline-verification).\n\nThe KMS key that you use for this operation must be in a compatible key state.\nFor details, see [Key states of KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/key-state.html) in\nthe *Key Management Service Developer Guide*.\n\n**Cross-account use**: Yes. To perform this operation with a KMS key in a\ndifferent Amazon Web Services account, specify the key ARN or alias ARN in the\nvalue of the `KeyId` parameter.\n\n**Required permissions**:\n[kms:Verify](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html) (key policy)\n\n**Related operations**: `Sign`\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual\nconsistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#verify/3","title":"AWS.KMS.verify/3","type":"function"},{"doc":"Verifies the hash-based message authentication code (HMAC) for a specified\nmessage, HMAC KMS key, and MAC algorithm.\n\nTo verify the HMAC, `VerifyMac` computes an HMAC using the message, HMAC KMS\nkey, and MAC algorithm that you specify, and compares the computed HMAC to the\nHMAC that you specify. If the HMACs are identical, the verification succeeds;\notherwise, it fails. Verification indicates that the message hasn't changed\nsince the HMAC was calculated, and the specified key was used to generate and\nverify the HMAC.\n\nHMAC KMS keys and the HMAC algorithms that KMS uses conform to industry\nstandards defined in [RFC 2104](https://datatracker.ietf.org/doc/html/rfc2104).  This operation is part of KMS support for HMAC KMS keys. For details, see [HMAC\nkeys in KMS](https://docs.aws.amazon.com/kms/latest/developerguide/hmac.html) in\nthe *Key Management Service Developer Guide*.\n\nThe KMS key that you use for this operation must be in a compatible key state.\nFor details, see [Key states of KMS keys](https://docs.aws.amazon.com/kms/latest/developerguide/key-state.html) in\nthe *Key Management Service Developer Guide*.\n\n**Cross-account use**: Yes. To perform this operation with a KMS key in a\ndifferent Amazon Web Services account, specify the key ARN or alias ARN in the\nvalue of the `KeyId` parameter.\n\n**Required permissions**:\n[kms:VerifyMac](https://docs.aws.amazon.com/kms/latest/developerguide/kms-api-permissions-reference.html) (key policy)\n\n**Related operations**: `GenerateMac`\n\n**Eventual consistency**: The KMS API follows an eventual consistency model. For\nmore information, see [KMS eventual\nconsistency](https://docs.aws.amazon.com/kms/latest/developerguide/programming-eventual-consistency.html).","ref":"AWS.KMS.html#verify_mac/3","title":"AWS.KMS.verify_mac/3","type":"function"},{"doc":"The operations for managing an Amazon MSK cluster.","ref":"AWS.Kafka.html","title":"AWS.Kafka","type":"module"},{"doc":"Associates one or more Scram Secrets with an Amazon MSK cluster.","ref":"AWS.Kafka.html#batch_associate_scram_secret/4","title":"AWS.Kafka.batch_associate_scram_secret/4","type":"function"},{"doc":"Disassociates one or more Scram Secrets from an Amazon MSK cluster.","ref":"AWS.Kafka.html#batch_disassociate_scram_secret/4","title":"AWS.Kafka.batch_disassociate_scram_secret/4","type":"function"},{"doc":"Creates a new MSK cluster.","ref":"AWS.Kafka.html#create_cluster/3","title":"AWS.Kafka.create_cluster/3","type":"function"},{"doc":"Creates a new Amazon MSK cluster of either the provisioned or the serverless\ntype.","ref":"AWS.Kafka.html#create_cluster_v2/3","title":"AWS.Kafka.create_cluster_v2/3","type":"function"},{"doc":"Creates a new MSK configuration.","ref":"AWS.Kafka.html#create_configuration/3","title":"AWS.Kafka.create_configuration/3","type":"function"},{"doc":"Creates a new Kafka Replicator.","ref":"AWS.Kafka.html#create_replicator/3","title":"AWS.Kafka.create_replicator/3","type":"function"},{"doc":"Creates a new Amazon MSK VPC connection.","ref":"AWS.Kafka.html#create_vpc_connection/3","title":"AWS.Kafka.create_vpc_connection/3","type":"function"},{"doc":"Deletes the MSK cluster specified by the Amazon Resource Name (ARN) in the\nrequest.","ref":"AWS.Kafka.html#delete_cluster/4","title":"AWS.Kafka.delete_cluster/4","type":"function"},{"doc":"Deletes the MSK cluster policy specified by the Amazon Resource Name (ARN) in\nyour request.","ref":"AWS.Kafka.html#delete_cluster_policy/4","title":"AWS.Kafka.delete_cluster_policy/4","type":"function"},{"doc":"Deletes the specified MSK configuration.\n\nThe configuration must be in the ACTIVE or DELETE_FAILED state.","ref":"AWS.Kafka.html#delete_configuration/4","title":"AWS.Kafka.delete_configuration/4","type":"function"},{"doc":"Deletes a replicator.","ref":"AWS.Kafka.html#delete_replicator/4","title":"AWS.Kafka.delete_replicator/4","type":"function"},{"doc":"Deletes the Amazon MSK VPC connection specified in your request.","ref":"AWS.Kafka.html#delete_vpc_connection/4","title":"AWS.Kafka.delete_vpc_connection/4","type":"function"},{"doc":"Returns a description of the MSK cluster whose Amazon Resource Name (ARN) is\nspecified in the request.","ref":"AWS.Kafka.html#describe_cluster/3","title":"AWS.Kafka.describe_cluster/3","type":"function"},{"doc":"Returns a description of the cluster operation specified by the ARN.","ref":"AWS.Kafka.html#describe_cluster_operation/3","title":"AWS.Kafka.describe_cluster_operation/3","type":"function"},{"doc":"Returns a description of the cluster operation specified by the ARN.","ref":"AWS.Kafka.html#describe_cluster_operation_v2/3","title":"AWS.Kafka.describe_cluster_operation_v2/3","type":"function"},{"doc":"Returns a description of the MSK cluster of either the provisioned or the\nserverless type whose Amazon Resource Name (ARN) is specified in the request.","ref":"AWS.Kafka.html#describe_cluster_v2/3","title":"AWS.Kafka.describe_cluster_v2/3","type":"function"},{"doc":"Returns a description of this MSK configuration.","ref":"AWS.Kafka.html#describe_configuration/3","title":"AWS.Kafka.describe_configuration/3","type":"function"},{"doc":"Returns a description of this revision of the configuration.","ref":"AWS.Kafka.html#describe_configuration_revision/4","title":"AWS.Kafka.describe_configuration_revision/4","type":"function"},{"doc":"Returns a description of the Kafka Replicator whose Amazon Resource Name (ARN)\nis specified in the request.","ref":"AWS.Kafka.html#describe_replicator/3","title":"AWS.Kafka.describe_replicator/3","type":"function"},{"doc":"Displays information about the specified Amazon MSK VPC connection.","ref":"AWS.Kafka.html#describe_vpc_connection/3","title":"AWS.Kafka.describe_vpc_connection/3","type":"function"},{"doc":"A list of brokers that a client application can use to bootstrap.","ref":"AWS.Kafka.html#get_bootstrap_brokers/3","title":"AWS.Kafka.get_bootstrap_brokers/3","type":"function"},{"doc":"Retrieves the contents of the specified MSK cluster policy.","ref":"AWS.Kafka.html#get_cluster_policy/3","title":"AWS.Kafka.get_cluster_policy/3","type":"function"},{"doc":"Gets the Apache Kafka versions to which you can update the MSK cluster.","ref":"AWS.Kafka.html#get_compatible_kafka_versions/3","title":"AWS.Kafka.get_compatible_kafka_versions/3","type":"function"},{"doc":"Displays a list of client VPC connections.","ref":"AWS.Kafka.html#list_client_vpc_connections/5","title":"AWS.Kafka.list_client_vpc_connections/5","type":"function"},{"doc":"Returns a list of all the operations that have been performed on the specified\nMSK cluster.","ref":"AWS.Kafka.html#list_cluster_operations/5","title":"AWS.Kafka.list_cluster_operations/5","type":"function"},{"doc":"Returns a list of all the operations that have been performed on the specified\nMSK cluster.","ref":"AWS.Kafka.html#list_cluster_operations_v2/5","title":"AWS.Kafka.list_cluster_operations_v2/5","type":"function"},{"doc":"Returns a list of all the MSK clusters in the current Region.","ref":"AWS.Kafka.html#list_clusters/5","title":"AWS.Kafka.list_clusters/5","type":"function"},{"doc":"Returns a list of all the MSK clusters in the current Region.","ref":"AWS.Kafka.html#list_clusters_v2/6","title":"AWS.Kafka.list_clusters_v2/6","type":"function"},{"doc":"Returns a list of all the revisions of an MSK configuration.","ref":"AWS.Kafka.html#list_configuration_revisions/5","title":"AWS.Kafka.list_configuration_revisions/5","type":"function"},{"doc":"Returns a list of all the MSK configurations in this Region.","ref":"AWS.Kafka.html#list_configurations/4","title":"AWS.Kafka.list_configurations/4","type":"function"},{"doc":"Returns a list of Apache Kafka versions.","ref":"AWS.Kafka.html#list_kafka_versions/4","title":"AWS.Kafka.list_kafka_versions/4","type":"function"},{"doc":"Returns a list of the broker nodes in the cluster.","ref":"AWS.Kafka.html#list_nodes/5","title":"AWS.Kafka.list_nodes/5","type":"function"},{"doc":"Lists the replicators.","ref":"AWS.Kafka.html#list_replicators/5","title":"AWS.Kafka.list_replicators/5","type":"function"},{"doc":"Returns a list of the Scram Secrets associated with an Amazon MSK cluster.","ref":"AWS.Kafka.html#list_scram_secrets/5","title":"AWS.Kafka.list_scram_secrets/5","type":"function"},{"doc":"Returns a list of the tags associated with the specified resource.","ref":"AWS.Kafka.html#list_tags_for_resource/3","title":"AWS.Kafka.list_tags_for_resource/3","type":"function"},{"doc":"Displays a list of Amazon MSK VPC connections.","ref":"AWS.Kafka.html#list_vpc_connections/4","title":"AWS.Kafka.list_vpc_connections/4","type":"function"},{"doc":"","ref":"AWS.Kafka.html#metadata/0","title":"AWS.Kafka.metadata/0","type":"function"},{"doc":"Creates or updates the specified MSK cluster policy.\n\nIf updating the policy, the currentVersion field is required in the request\npayload.","ref":"AWS.Kafka.html#put_cluster_policy/4","title":"AWS.Kafka.put_cluster_policy/4","type":"function"},{"doc":"Executes a reboot on a broker.","ref":"AWS.Kafka.html#reboot_broker/4","title":"AWS.Kafka.reboot_broker/4","type":"function"},{"doc":"","ref":"AWS.Kafka.html#reject_client_vpc_connection/4","title":"AWS.Kafka.reject_client_vpc_connection/4","type":"function"},{"doc":"Adds tags to the specified MSK resource.","ref":"AWS.Kafka.html#tag_resource/4","title":"AWS.Kafka.tag_resource/4","type":"function"},{"doc":"Removes the tags associated with the keys that are provided in the query.","ref":"AWS.Kafka.html#untag_resource/4","title":"AWS.Kafka.untag_resource/4","type":"function"},{"doc":"Updates the number of broker nodes in the cluster.\n\nYou can use this operation to increase the number of brokers in an existing\ncluster. You can't decrease the number of brokers.","ref":"AWS.Kafka.html#update_broker_count/4","title":"AWS.Kafka.update_broker_count/4","type":"function"},{"doc":"Updates the EBS storage associated with MSK brokers.","ref":"AWS.Kafka.html#update_broker_storage/4","title":"AWS.Kafka.update_broker_storage/4","type":"function"},{"doc":"Updates all the brokers in the cluster to the specified type.","ref":"AWS.Kafka.html#update_broker_type/4","title":"AWS.Kafka.update_broker_type/4","type":"function"},{"doc":"Updates the cluster with the configuration that is specified in the request\nbody.","ref":"AWS.Kafka.html#update_cluster_configuration/4","title":"AWS.Kafka.update_cluster_configuration/4","type":"function"},{"doc":"Updates the Apache Kafka version for the cluster.","ref":"AWS.Kafka.html#update_cluster_kafka_version/4","title":"AWS.Kafka.update_cluster_kafka_version/4","type":"function"},{"doc":"Updates an existing MSK configuration.\n\nThe configuration must be in the Active state.","ref":"AWS.Kafka.html#update_configuration/4","title":"AWS.Kafka.update_configuration/4","type":"function"},{"doc":"Updates the connectivity configuration for the MSK cluster.","ref":"AWS.Kafka.html#update_connectivity/4","title":"AWS.Kafka.update_connectivity/4","type":"function"},{"doc":"Updates the monitoring settings for the cluster.\n\nYou can use this operation to specify which Apache Kafka metrics you want Amazon\nMSK to send to Amazon CloudWatch. You can also specify settings for open\nmonitoring with Prometheus.","ref":"AWS.Kafka.html#update_monitoring/4","title":"AWS.Kafka.update_monitoring/4","type":"function"},{"doc":"Updates replication info of a replicator.","ref":"AWS.Kafka.html#update_replication_info/4","title":"AWS.Kafka.update_replication_info/4","type":"function"},{"doc":"You can use this operation to update the encrypting and authentication settings\nfor an existing cluster.","ref":"AWS.Kafka.html#update_security/4","title":"AWS.Kafka.update_security/4","type":"function"},{"doc":"Updates cluster broker volume size (or) sets cluster storage mode to TIERED.","ref":"AWS.Kafka.html#update_storage/4","title":"AWS.Kafka.update_storage/4","type":"function"},{"doc":"","ref":"AWS.KafkaConnect.html","title":"AWS.KafkaConnect","type":"module"},{"doc":"Creates a connector using the specified properties.","ref":"AWS.KafkaConnect.html#create_connector/3","title":"AWS.KafkaConnect.create_connector/3","type":"function"},{"doc":"Creates a custom plugin using the specified properties.","ref":"AWS.KafkaConnect.html#create_custom_plugin/3","title":"AWS.KafkaConnect.create_custom_plugin/3","type":"function"},{"doc":"Creates a worker configuration using the specified properties.","ref":"AWS.KafkaConnect.html#create_worker_configuration/3","title":"AWS.KafkaConnect.create_worker_configuration/3","type":"function"},{"doc":"Deletes the specified connector.","ref":"AWS.KafkaConnect.html#delete_connector/4","title":"AWS.KafkaConnect.delete_connector/4","type":"function"},{"doc":"Deletes a custom plugin.","ref":"AWS.KafkaConnect.html#delete_custom_plugin/4","title":"AWS.KafkaConnect.delete_custom_plugin/4","type":"function"},{"doc":"Returns summary information about the connector.","ref":"AWS.KafkaConnect.html#describe_connector/3","title":"AWS.KafkaConnect.describe_connector/3","type":"function"},{"doc":"A summary description of the custom plugin.","ref":"AWS.KafkaConnect.html#describe_custom_plugin/3","title":"AWS.KafkaConnect.describe_custom_plugin/3","type":"function"},{"doc":"Returns information about a worker configuration.","ref":"AWS.KafkaConnect.html#describe_worker_configuration/3","title":"AWS.KafkaConnect.describe_worker_configuration/3","type":"function"},{"doc":"Returns a list of all the connectors in this account and Region.\n\nThe list is limited to connectors whose name starts with the specified prefix.\nThe response also includes a description of each of the listed connectors.","ref":"AWS.KafkaConnect.html#list_connectors/5","title":"AWS.KafkaConnect.list_connectors/5","type":"function"},{"doc":"Returns a list of all of the custom plugins in this account and Region.","ref":"AWS.KafkaConnect.html#list_custom_plugins/4","title":"AWS.KafkaConnect.list_custom_plugins/4","type":"function"},{"doc":"Returns a list of all of the worker configurations in this account and Region.","ref":"AWS.KafkaConnect.html#list_worker_configurations/4","title":"AWS.KafkaConnect.list_worker_configurations/4","type":"function"},{"doc":"","ref":"AWS.KafkaConnect.html#metadata/0","title":"AWS.KafkaConnect.metadata/0","type":"function"},{"doc":"Updates the specified connector.","ref":"AWS.KafkaConnect.html#update_connector/4","title":"AWS.KafkaConnect.update_connector/4","type":"function"},{"doc":"Amazon Kendra is a service for indexing large document sets.","ref":"AWS.Kendra.html","title":"AWS.Kendra","type":"module"},{"doc":"Grants users or groups in your IAM Identity Center identity source access to\nyour Amazon Kendra experience.\n\nYou can create an Amazon Kendra experience such as a search application. For\nmore information on creating a search application experience, see [Building a search experience with no\ncode](https://docs.aws.amazon.com/kendra/latest/dg/deploying-search-experience-no-code.html).","ref":"AWS.Kendra.html#associate_entities_to_experience/3","title":"AWS.Kendra.associate_entities_to_experience/3","type":"function"},{"doc":"Defines the specific permissions of users or groups in your IAM Identity Center\nidentity source with access to your Amazon Kendra experience.\n\nYou can create an Amazon Kendra experience such as a search application. For\nmore information on creating a search application experience, see [Building a search experience with no\ncode](https://docs.aws.amazon.com/kendra/latest/dg/deploying-search-experience-no-code.html).","ref":"AWS.Kendra.html#associate_personas_to_entities/3","title":"AWS.Kendra.associate_personas_to_entities/3","type":"function"},{"doc":"Removes one or more documents from an index.\n\nThe documents must have been added with the `BatchPutDocument` API.\n\nThe documents are deleted asynchronously. You can see the progress of the\ndeletion by using Amazon Web Services CloudWatch. Any error messages related to\nthe processing of the batch are sent to your Amazon Web Services CloudWatch log.\nYou can also use the `BatchGetDocumentStatus` API to monitor the progress of\ndeleting your documents.\n\nDeleting documents from an index using `BatchDeleteDocument` could take up to an\nhour or more, depending on the number of documents you want to delete.","ref":"AWS.Kendra.html#batch_delete_document/3","title":"AWS.Kendra.batch_delete_document/3","type":"function"},{"doc":"Removes one or more sets of featured results.\n\nFeatures results are placed above all other results for certain queries. If\nthere's an exact match of a query, then one or more specific documents are\nfeatured in the search results.","ref":"AWS.Kendra.html#batch_delete_featured_results_set/3","title":"AWS.Kendra.batch_delete_featured_results_set/3","type":"function"},{"doc":"Returns the indexing status for one or more documents submitted with the [\nBatchPutDocument](https://docs.aws.amazon.com/kendra/latest/dg/API_BatchPutDocument.html)\nAPI.\n\nWhen you use the `BatchPutDocument` API, documents are indexed asynchronously.\nYou can use the `BatchGetDocumentStatus` API to get the current status of a list\nof documents so that you can determine if they have been successfully indexed.\n\nYou can also use the `BatchGetDocumentStatus` API to check the status of the [\nBatchDeleteDocument](https://docs.aws.amazon.com/kendra/latest/dg/API_BatchDeleteDocument.html)\nAPI. When a document is deleted from the index, Amazon Kendra returns\n`NOT_FOUND` as the status.","ref":"AWS.Kendra.html#batch_get_document_status/3","title":"AWS.Kendra.batch_get_document_status/3","type":"function"},{"doc":"Adds one or more documents to an index.\n\nThe `BatchPutDocument` API enables you to ingest inline documents or a set of\ndocuments stored in an Amazon S3 bucket. Use this API to ingest your text and\nunstructured text into an index, add custom attributes to the documents, and to\nattach an access control list to the documents added to the index.\n\nThe documents are indexed asynchronously. You can see the progress of the batch\nusing Amazon Web Services CloudWatch. Any error messages related to processing\nthe batch are sent to your Amazon Web Services CloudWatch log. You can also use\nthe `BatchGetDocumentStatus` API to monitor the progress of indexing your\ndocuments.\n\nFor an example of ingesting inline documents using Python and Java SDKs, see\n[Adding files directly to an index](https://docs.aws.amazon.com/kendra/latest/dg/in-adding-binary-doc.html).","ref":"AWS.Kendra.html#batch_put_document/3","title":"AWS.Kendra.batch_put_document/3","type":"function"},{"doc":"Clears existing query suggestions from an index.\n\nThis deletes existing suggestions only, not the queries in the query log. After\nyou clear suggestions, Amazon Kendra learns new suggestions based on new queries\nadded to the query log from the time you cleared suggestions. If you do not see\nany new suggestions, then please allow Amazon Kendra to collect enough queries\nto learn new suggestions.\n\n`ClearQuerySuggestions` is currently not supported in the Amazon Web Services\nGovCloud (US-West) region.","ref":"AWS.Kendra.html#clear_query_suggestions/3","title":"AWS.Kendra.clear_query_suggestions/3","type":"function"},{"doc":"Creates an access configuration for your documents.\n\nThis includes user and group access information for your documents. This is\nuseful for user context filtering, where search results are filtered based on\nthe user or their group access to documents.\n\nYou can use this to re-configure your existing document level access control\nwithout indexing all of your documents again. For example, your index contains\ntop-secret company documents that only certain employees or users should access.\nOne of these users leaves the company or switches to a team that should be\nblocked from accessing top-secret documents. The user still has access to\ntop-secret documents because the user had access when your documents were\npreviously indexed. You can create a specific access control configuration for\nthe user with deny access. You can later update the access control configuration\nto allow access if the user returns to the company and re-joins the 'top-secret'\nteam. You can re-configure access control for your documents as circumstances\nchange.\n\nTo apply your access control configuration to certain documents, you call the\n[BatchPutDocument](https://docs.aws.amazon.com/kendra/latest/dg/API_BatchPutDocument.html) API with the `AccessControlConfigurationId` included in the\n[Document](https://docs.aws.amazon.com/kendra/latest/dg/API_Document.html)\nobject. If you use an S3 bucket as a data source, you update the\n`.metadata.json` with the `AccessControlConfigurationId` and synchronize your\ndata source. Amazon Kendra currently only supports access control configuration\nfor S3 data sources and documents indexed using the `BatchPutDocument` API.","ref":"AWS.Kendra.html#create_access_control_configuration/3","title":"AWS.Kendra.create_access_control_configuration/3","type":"function"},{"doc":"Creates a data source connector that you want to use with an Amazon Kendra\nindex.\n\nYou specify a name, data source connector type and description for your data\nsource. You also specify configuration information for the data source\nconnector.\n\n`CreateDataSource` is a synchronous operation. The operation returns 200 if the\ndata source was successfully created. Otherwise, an exception is raised.\n\nFor an example of creating an index and data source using the Python SDK, see\n[Getting started with Python SDK](https://docs.aws.amazon.com/kendra/latest/dg/gs-python.html). For an\nexample of creating an index and data source using the Java SDK, see [Getting started with Java\nSDK](https://docs.aws.amazon.com/kendra/latest/dg/gs-java.html).","ref":"AWS.Kendra.html#create_data_source/3","title":"AWS.Kendra.create_data_source/3","type":"function"},{"doc":"Creates an Amazon Kendra experience such as a search application.\n\nFor more information on creating a search application experience, including\nusing the Python and Java SDKs, see [Building a search experience with no code](https://docs.aws.amazon.com/kendra/latest/dg/deploying-search-experience-no-code.html).","ref":"AWS.Kendra.html#create_experience/3","title":"AWS.Kendra.create_experience/3","type":"function"},{"doc":"Creates a set of frequently ask questions (FAQs) using a specified FAQ file\nstored in an Amazon S3 bucket.\n\nAdding FAQs to an index is an asynchronous operation.\n\nFor an example of adding an FAQ to an index using Python and Java SDKs, see\n[Using your FAQ file](https://docs.aws.amazon.com/kendra/latest/dg/in-creating-faq.html#using-faq-file).","ref":"AWS.Kendra.html#create_faq/3","title":"AWS.Kendra.create_faq/3","type":"function"},{"doc":"Creates a set of featured results to display at the top of the search results\npage.\n\nFeatured results are placed above all other results for certain queries. You map\nspecific queries to specific documents for featuring in the results. If a query\ncontains an exact match, then one or more specific documents are featured in the\nsearch results.\n\nYou can create up to 50 sets of featured results per index. You can request to\nincrease this limit by contacting [Support](http://aws.amazon.com/contact-us/).","ref":"AWS.Kendra.html#create_featured_results_set/3","title":"AWS.Kendra.create_featured_results_set/3","type":"function"},{"doc":"Creates an Amazon Kendra index.\n\nIndex creation is an asynchronous API. To determine if index creation has\ncompleted, check the `Status` field returned from a call to `DescribeIndex`. The\n`Status` field is set to `ACTIVE` when the index is ready to use.\n\nOnce the index is active, you can index your documents using the\n`BatchPutDocument` API or using one of the supported [data sources](https://docs.aws.amazon.com/kendra/latest/dg/data-sources.html).\n\nFor an example of creating an index and data source using the Python SDK, see\n[Getting started with Python SDK](https://docs.aws.amazon.com/kendra/latest/dg/gs-python.html). For an\nexample of creating an index and data source using the Java SDK, see [Getting started with Java\nSDK](https://docs.aws.amazon.com/kendra/latest/dg/gs-java.html).","ref":"AWS.Kendra.html#create_index/3","title":"AWS.Kendra.create_index/3","type":"function"},{"doc":"Creates a block list to exlcude certain queries from suggestions.\n\nAny query that contains words or phrases specified in the block list is blocked\nor filtered out from being shown as a suggestion.\n\nYou need to provide the file location of your block list text file in your S3\nbucket. In your text file, enter each block word or phrase on a separate line.\n\nFor information on the current quota limits for block lists, see [Quotas for Amazon Kendra](https://docs.aws.amazon.com/kendra/latest/dg/quotas.html).\n\n`CreateQuerySuggestionsBlockList` is currently not supported in the Amazon Web\nServices GovCloud (US-West) region.\n\nFor an example of creating a block list for query suggestions using the Python\nSDK, see [Query suggestions block list](https://docs.aws.amazon.com/kendra/latest/dg/query-suggestions.html#query-suggestions-blocklist).","ref":"AWS.Kendra.html#create_query_suggestions_block_list/3","title":"AWS.Kendra.create_query_suggestions_block_list/3","type":"function"},{"doc":"Creates a thesaurus for an index.\n\nThe thesaurus contains a list of synonyms in Solr format.\n\nFor an example of adding a thesaurus file to an index, see [Adding custom synonyms to an\nindex](https://docs.aws.amazon.com/kendra/latest/dg/index-synonyms-adding-thesaurus-file.html).","ref":"AWS.Kendra.html#create_thesaurus/3","title":"AWS.Kendra.create_thesaurus/3","type":"function"},{"doc":"Deletes an access control configuration that you created for your documents in\nan index.\n\nThis includes user and group access information for your documents. This is\nuseful for user context filtering, where search results are filtered based on\nthe user or their group access to documents.","ref":"AWS.Kendra.html#delete_access_control_configuration/3","title":"AWS.Kendra.delete_access_control_configuration/3","type":"function"},{"doc":"Deletes an Amazon Kendra data source connector.\n\nAn exception is not thrown if the data source is already being deleted. While\nthe data source is being deleted, the `Status` field returned by a call to the\n`DescribeDataSource` API is set to `DELETING`. For more information, see\n[Deleting Data Sources](https://docs.aws.amazon.com/kendra/latest/dg/delete-data-source.html).\n\nDeleting an entire data source or re-syncing your index after deleting specific\ndocuments from a data source could take up to an hour or more, depending on the\nnumber of documents you want to delete.","ref":"AWS.Kendra.html#delete_data_source/3","title":"AWS.Kendra.delete_data_source/3","type":"function"},{"doc":"Deletes your Amazon Kendra experience such as a search application.\n\nFor more information on creating a search application experience, see [Building a search experience with no\ncode](https://docs.aws.amazon.com/kendra/latest/dg/deploying-search-experience-no-code.html).","ref":"AWS.Kendra.html#delete_experience/3","title":"AWS.Kendra.delete_experience/3","type":"function"},{"doc":"Removes an FAQ from an index.","ref":"AWS.Kendra.html#delete_faq/3","title":"AWS.Kendra.delete_faq/3","type":"function"},{"doc":"Deletes an existing Amazon Kendra index.\n\nAn exception is not thrown if the index is already being deleted. While the\nindex is being deleted, the `Status` field returned by a call to the\n`DescribeIndex` API is set to `DELETING`.","ref":"AWS.Kendra.html#delete_index/3","title":"AWS.Kendra.delete_index/3","type":"function"},{"doc":"Deletes a group so that all users and sub groups that belong to the group can no\nlonger access documents only available to that group.\n\nFor example, after deleting the group \"Summer Interns\", all interns who belonged\nto that group no longer see intern-only documents in their search results.\n\nIf you want to delete or replace users or sub groups of a group, you need to use\nthe `PutPrincipalMapping` operation. For example, if a user in the group\n\"Engineering\" leaves the engineering team and another user takes their place,\nyou provide an updated list of users or sub groups that belong to the\n\"Engineering\" group when calling `PutPrincipalMapping`. You can update your\ninternal list of users or sub groups and input this list when calling\n`PutPrincipalMapping`.\n\n`DeletePrincipalMapping` is currently not supported in the Amazon Web Services\nGovCloud (US-West) region.","ref":"AWS.Kendra.html#delete_principal_mapping/3","title":"AWS.Kendra.delete_principal_mapping/3","type":"function"},{"doc":"Deletes a block list used for query suggestions for an index.\n\nA deleted block list might not take effect right away. Amazon Kendra needs to\nrefresh the entire suggestions list to add back the queries that were previously\nblocked.\n\n`DeleteQuerySuggestionsBlockList` is currently not supported in the Amazon Web\nServices GovCloud (US-West) region.","ref":"AWS.Kendra.html#delete_query_suggestions_block_list/3","title":"AWS.Kendra.delete_query_suggestions_block_list/3","type":"function"},{"doc":"Deletes an existing Amazon Kendra thesaurus.","ref":"AWS.Kendra.html#delete_thesaurus/3","title":"AWS.Kendra.delete_thesaurus/3","type":"function"},{"doc":"Gets information about an access control configuration that you created for your\ndocuments in an index.\n\nThis includes user and group access information for your documents. This is\nuseful for user context filtering, where search results are filtered based on\nthe user or their group access to documents.","ref":"AWS.Kendra.html#describe_access_control_configuration/3","title":"AWS.Kendra.describe_access_control_configuration/3","type":"function"},{"doc":"Gets information about an Amazon Kendra data source connector.","ref":"AWS.Kendra.html#describe_data_source/3","title":"AWS.Kendra.describe_data_source/3","type":"function"},{"doc":"Gets information about your Amazon Kendra experience such as a search\napplication.\n\nFor more information on creating a search application experience, see [Building a search experience with no\ncode](https://docs.aws.amazon.com/kendra/latest/dg/deploying-search-experience-no-code.html).","ref":"AWS.Kendra.html#describe_experience/3","title":"AWS.Kendra.describe_experience/3","type":"function"},{"doc":"Gets information about an FAQ list.","ref":"AWS.Kendra.html#describe_faq/3","title":"AWS.Kendra.describe_faq/3","type":"function"},{"doc":"Gets information about a set of featured results.\n\nFeatures results are placed above all other results for certain queries. If\nthere's an exact match of a query, then one or more specific documents are\nfeatured in the search results.","ref":"AWS.Kendra.html#describe_featured_results_set/3","title":"AWS.Kendra.describe_featured_results_set/3","type":"function"},{"doc":"Gets information about an existing Amazon Kendra index.","ref":"AWS.Kendra.html#describe_index/3","title":"AWS.Kendra.describe_index/3","type":"function"},{"doc":"Describes the processing of `PUT` and `DELETE` actions for mapping users to\ntheir groups.\n\nThis includes information on the status of actions currently processing or yet\nto be processed, when actions were last updated, when actions were received by\nAmazon Kendra, the latest action that should process and apply after other\nactions, and useful error messages if an action could not be processed.\n\n`DescribePrincipalMapping` is currently not supported in the Amazon Web Services\nGovCloud (US-West) region.","ref":"AWS.Kendra.html#describe_principal_mapping/3","title":"AWS.Kendra.describe_principal_mapping/3","type":"function"},{"doc":"Gets information about a block list used for query suggestions for an index.\n\nThis is used to check the current settings that are applied to a block list.\n\n`DescribeQuerySuggestionsBlockList` is currently not supported in the Amazon Web\nServices GovCloud (US-West) region.","ref":"AWS.Kendra.html#describe_query_suggestions_block_list/3","title":"AWS.Kendra.describe_query_suggestions_block_list/3","type":"function"},{"doc":"Gets information on the settings of query suggestions for an index.\n\nThis is used to check the current settings applied to query suggestions.\n\n`DescribeQuerySuggestionsConfig` is currently not supported in the Amazon Web\nServices GovCloud (US-West) region.","ref":"AWS.Kendra.html#describe_query_suggestions_config/3","title":"AWS.Kendra.describe_query_suggestions_config/3","type":"function"},{"doc":"Gets information about an existing Amazon Kendra thesaurus.","ref":"AWS.Kendra.html#describe_thesaurus/3","title":"AWS.Kendra.describe_thesaurus/3","type":"function"},{"doc":"Prevents users or groups in your IAM Identity Center identity source from\naccessing your Amazon Kendra experience.\n\nYou can create an Amazon Kendra experience such as a search application. For\nmore information on creating a search application experience, see [Building a search experience with no\ncode](https://docs.aws.amazon.com/kendra/latest/dg/deploying-search-experience-no-code.html).","ref":"AWS.Kendra.html#disassociate_entities_from_experience/3","title":"AWS.Kendra.disassociate_entities_from_experience/3","type":"function"},{"doc":"Removes the specific permissions of users or groups in your IAM Identity Center\nidentity source with access to your Amazon Kendra experience.\n\nYou can create an Amazon Kendra experience such as a search application. For\nmore information on creating a search application experience, see [Building a search experience with no\ncode](https://docs.aws.amazon.com/kendra/latest/dg/deploying-search-experience-no-code.html).","ref":"AWS.Kendra.html#disassociate_personas_from_entities/3","title":"AWS.Kendra.disassociate_personas_from_entities/3","type":"function"},{"doc":"Fetches the queries that are suggested to your users.\n\n`GetQuerySuggestions` is currently not supported in the Amazon Web Services\nGovCloud (US-West) region.","ref":"AWS.Kendra.html#get_query_suggestions/3","title":"AWS.Kendra.get_query_suggestions/3","type":"function"},{"doc":"Retrieves search metrics data.\n\nThe data provides a snapshot of how your users interact with your search\napplication and how effective the application is.","ref":"AWS.Kendra.html#get_snapshots/3","title":"AWS.Kendra.get_snapshots/3","type":"function"},{"doc":"Lists one or more access control configurations for an index.\n\nThis includes user and group access information for your documents. This is\nuseful for user context filtering, where search results are filtered based on\nthe user or their group access to documents.","ref":"AWS.Kendra.html#list_access_control_configurations/3","title":"AWS.Kendra.list_access_control_configurations/3","type":"function"},{"doc":"Gets statistics about synchronizing a data source connector.","ref":"AWS.Kendra.html#list_data_source_sync_jobs/3","title":"AWS.Kendra.list_data_source_sync_jobs/3","type":"function"},{"doc":"Lists the data source connectors that you have created.","ref":"AWS.Kendra.html#list_data_sources/3","title":"AWS.Kendra.list_data_sources/3","type":"function"},{"doc":"Lists specific permissions of users and groups with access to your Amazon Kendra\nexperience.","ref":"AWS.Kendra.html#list_entity_personas/3","title":"AWS.Kendra.list_entity_personas/3","type":"function"},{"doc":"Lists users or groups in your IAM Identity Center identity source that are\ngranted access to your Amazon Kendra experience.\n\nYou can create an Amazon Kendra experience such as a search application. For\nmore information on creating a search application experience, see [Building a search experience with no\ncode](https://docs.aws.amazon.com/kendra/latest/dg/deploying-search-experience-no-code.html).","ref":"AWS.Kendra.html#list_experience_entities/3","title":"AWS.Kendra.list_experience_entities/3","type":"function"},{"doc":"Lists one or more Amazon Kendra experiences.\n\nYou can create an Amazon Kendra experience such as a search application. For\nmore information on creating a search application experience, see [Building a search experience with no\ncode](https://docs.aws.amazon.com/kendra/latest/dg/deploying-search-experience-no-code.html).","ref":"AWS.Kendra.html#list_experiences/3","title":"AWS.Kendra.list_experiences/3","type":"function"},{"doc":"Gets a list of FAQ lists associated with an index.","ref":"AWS.Kendra.html#list_faqs/3","title":"AWS.Kendra.list_faqs/3","type":"function"},{"doc":"Lists all your sets of featured results for a given index.\n\nFeatures results are placed above all other results for certain queries. If\nthere's an exact match of a query, then one or more specific documents are\nfeatured in the search results.","ref":"AWS.Kendra.html#list_featured_results_sets/3","title":"AWS.Kendra.list_featured_results_sets/3","type":"function"},{"doc":"Provides a list of groups that are mapped to users before a given ordering or\ntimestamp identifier.\n\n`ListGroupsOlderThanOrderingId` is currently not supported in the Amazon Web\nServices GovCloud (US-West) region.","ref":"AWS.Kendra.html#list_groups_older_than_ordering_id/3","title":"AWS.Kendra.list_groups_older_than_ordering_id/3","type":"function"},{"doc":"Lists the Amazon Kendra indexes that you created.","ref":"AWS.Kendra.html#list_indices/3","title":"AWS.Kendra.list_indices/3","type":"function"},{"doc":"Lists the block lists used for query suggestions for an index.\n\nFor information on the current quota limits for block lists, see [Quotas for Amazon Kendra](https://docs.aws.amazon.com/kendra/latest/dg/quotas.html).\n\n`ListQuerySuggestionsBlockLists` is currently not supported in the Amazon Web\nServices GovCloud (US-West) region.","ref":"AWS.Kendra.html#list_query_suggestions_block_lists/3","title":"AWS.Kendra.list_query_suggestions_block_lists/3","type":"function"},{"doc":"Gets a list of tags associated with a specified resource.\n\nIndexes, FAQs, and data sources can have tags associated with them.","ref":"AWS.Kendra.html#list_tags_for_resource/3","title":"AWS.Kendra.list_tags_for_resource/3","type":"function"},{"doc":"Lists the thesauri for an index.","ref":"AWS.Kendra.html#list_thesauri/3","title":"AWS.Kendra.list_thesauri/3","type":"function"},{"doc":"","ref":"AWS.Kendra.html#metadata/0","title":"AWS.Kendra.metadata/0","type":"function"},{"doc":"Maps users to their groups so that you only need to provide the user ID when you\nissue the query.\n\nYou can also map sub groups to groups. For example, the group \"Company\nIntellectual Property Teams\" includes sub groups \"Research\" and \"Engineering\".\nThese sub groups include their own list of users or people who work in these\nteams. Only users who work in research and engineering, and therefore belong in\nthe intellectual property group, can see top-secret company documents in their\nsearch results.\n\nThis is useful for user context filtering, where search results are filtered\nbased on the user or their group access to documents. For more information, see\n[Filtering on user context](https://docs.aws.amazon.com/kendra/latest/dg/user-context-filter.html).\n\nIf more than five `PUT` actions for a group are currently processing, a\nvalidation exception is thrown.","ref":"AWS.Kendra.html#put_principal_mapping/3","title":"AWS.Kendra.put_principal_mapping/3","type":"function"},{"doc":"Searches an index given an input query.\n\nIf you are working with large language models (LLMs) or implementing retrieval\naugmented generation (RAG) systems, you can use Amazon Kendra's\n[Retrieve](https://docs.aws.amazon.com/kendra/latest/APIReference/API_Retrieve.html)\nAPI, which can return longer semantically relevant passages. We recommend using\nthe `Retrieve` API instead of filing a service limit increase to increase the\n`Query` API document excerpt length.\n\nYou can configure boosting or relevance tuning at the query level to override\nboosting at the index level, filter based on document fields/attributes and\nfaceted search, and filter based on the user or their group access to documents.\nYou can also include certain fields in the response that might provide useful\nadditional information.\n\nA query response contains three types of results.\n\n  * Relevant suggested answers. The answers can be either a text\nexcerpt or table excerpt. The answer can be highlighted in the excerpt.\n\n  * Matching FAQs or questions-answer from your FAQ file.\n\n  * Relevant documents. This result type includes an excerpt of the\ndocument with the document title. The searched terms can be highlighted in the\nexcerpt.\n\nYou can specify that the query return only one type of result using the\n`QueryResultTypeFilter` parameter. Each query returns the 100 most relevant\nresults. If you filter result type to only question-answers, a maximum of four\nresults are returned. If you filter result type to only answers, a maximum of\nthree results are returned.","ref":"AWS.Kendra.html#query/3","title":"AWS.Kendra.query/3","type":"function"},{"doc":"Retrieves relevant passages or text excerpts given an input query.\n\nThis API is similar to the\n[Query](https://docs.aws.amazon.com/kendra/latest/APIReference/API_Query.html) API. However, by default, the `Query` API only returns excerpt passages of up to\n100 token words. With the `Retrieve` API, you can retrieve longer passages of up\nto 200 token words and up to 100 semantically relevant passages. This doesn't\ninclude question-answer or FAQ type responses from your index. The passages are\ntext excerpts that can be semantically extracted from multiple documents and\nmultiple parts of the same document. If in extreme cases your documents produce\nzero passages using the `Retrieve` API, you can alternatively use the `Query`\nAPI and its types of responses.\n\nYou can also do the following:\n\n  * Override boosting at the index level\n\n  * Filter based on document fields or attributes\n\n  * Filter based on the user or their group access to documents\n\n  * View the confidence score bucket for a retrieved passage result.\nThe confidence bucket provides a relative ranking that indicates how confident\nAmazon Kendra is that the response is relevant to the query.\n\nConfidence score buckets are currently available only for English.\n\nYou can also include certain fields in the response that might provide useful\nadditional information.\n\nThe `Retrieve` API shares the number of [query capacity\nunits](https://docs.aws.amazon.com/kendra/latest/APIReference/API_CapacityUnitsConfiguration.html)\nthat you set for your index. For more information on what's included in a single\ncapacity unit and the default base capacity for an index, see [Adjusting capacity](https://docs.aws.amazon.com/kendra/latest/dg/adjusting-capacity.html).","ref":"AWS.Kendra.html#retrieve/3","title":"AWS.Kendra.retrieve/3","type":"function"},{"doc":"Starts a synchronization job for a data source connector.\n\nIf a synchronization job is already in progress, Amazon Kendra returns a\n`ResourceInUseException` exception.\n\nRe-syncing your data source with your index after modifying, adding, or deleting\ndocuments from your data source respository could take up to an hour or more,\ndepending on the number of documents to sync.","ref":"AWS.Kendra.html#start_data_source_sync_job/3","title":"AWS.Kendra.start_data_source_sync_job/3","type":"function"},{"doc":"Stops a synchronization job that is currently running.\n\nYou can't stop a scheduled synchronization job.","ref":"AWS.Kendra.html#stop_data_source_sync_job/3","title":"AWS.Kendra.stop_data_source_sync_job/3","type":"function"},{"doc":"Enables you to provide feedback to Amazon Kendra to improve the performance of\nyour index.\n\n`SubmitFeedback` is currently not supported in the Amazon Web Services GovCloud\n(US-West) region.","ref":"AWS.Kendra.html#submit_feedback/3","title":"AWS.Kendra.submit_feedback/3","type":"function"},{"doc":"Adds the specified tag to the specified index, FAQ, or data source resource.\n\nIf the tag already exists, the existing value is replaced with the new value.","ref":"AWS.Kendra.html#tag_resource/3","title":"AWS.Kendra.tag_resource/3","type":"function"},{"doc":"Removes a tag from an index, FAQ, or a data source.","ref":"AWS.Kendra.html#untag_resource/3","title":"AWS.Kendra.untag_resource/3","type":"function"},{"doc":"Updates an access control configuration for your documents in an index.\n\nThis includes user and group access information for your documents. This is\nuseful for user context filtering, where search results are filtered based on\nthe user or their group access to documents.\n\nYou can update an access control configuration you created without indexing all\nof your documents again. For example, your index contains top-secret company\ndocuments that only certain employees or users should access. You created an\n'allow' access control configuration for one user who recently joined the\n'top-secret' team, switching from a team with 'deny' access to top-secret\ndocuments. However, the user suddenly returns to their previous team and should\nno longer have access to top secret documents. You can update the access control\nconfiguration to re-configure access control for your documents as circumstances\nchange.\n\nYou call the\n[BatchPutDocument](https://docs.aws.amazon.com/kendra/latest/dg/API_BatchPutDocument.html) API to apply the updated access control configuration, with the\n`AccessControlConfigurationId` included in the\n[Document](https://docs.aws.amazon.com/kendra/latest/dg/API_Document.html)\nobject. If you use an S3 bucket as a data source, you synchronize your data\nsource to apply the `AccessControlConfigurationId` in the `.metadata.json` file.\nAmazon Kendra currently only supports access control configuration for S3 data\nsources and documents indexed using the `BatchPutDocument` API.","ref":"AWS.Kendra.html#update_access_control_configuration/3","title":"AWS.Kendra.update_access_control_configuration/3","type":"function"},{"doc":"Updates an existing Amazon Kendra data source connector.","ref":"AWS.Kendra.html#update_data_source/3","title":"AWS.Kendra.update_data_source/3","type":"function"},{"doc":"Updates your Amazon Kendra experience such as a search application.\n\nFor more information on creating a search application experience, see [Building a search experience with no\ncode](https://docs.aws.amazon.com/kendra/latest/dg/deploying-search-experience-no-code.html).","ref":"AWS.Kendra.html#update_experience/3","title":"AWS.Kendra.update_experience/3","type":"function"},{"doc":"Updates a set of featured results.\n\nFeatures results are placed above all other results for certain queries. You map\nspecific queries to specific documents for featuring in the results. If a query\ncontains an exact match of a query, then one or more specific documents are\nfeatured in the search results.","ref":"AWS.Kendra.html#update_featured_results_set/3","title":"AWS.Kendra.update_featured_results_set/3","type":"function"},{"doc":"Updates an existing Amazon Kendra index.","ref":"AWS.Kendra.html#update_index/3","title":"AWS.Kendra.update_index/3","type":"function"},{"doc":"Updates a block list used for query suggestions for an index.\n\nUpdates to a block list might not take effect right away. Amazon Kendra needs to\nrefresh the entire suggestions list to apply any updates to the block list.\nOther changes not related to the block list apply immediately.\n\nIf a block list is updating, then you need to wait for the first update to\nfinish before submitting another update.\n\nAmazon Kendra supports partial updates, so you only need to provide the fields\nyou want to update.\n\n`UpdateQuerySuggestionsBlockList` is currently not supported in the Amazon Web\nServices GovCloud (US-West) region.","ref":"AWS.Kendra.html#update_query_suggestions_block_list/3","title":"AWS.Kendra.update_query_suggestions_block_list/3","type":"function"},{"doc":"Updates the settings of query suggestions for an index.\n\nAmazon Kendra supports partial updates, so you only need to provide the fields\nyou want to update.\n\nIf an update is currently processing, you need to wait for the update to finish\nbefore making another update.\n\nUpdates to query suggestions settings might not take effect right away. The time\nfor your updated settings to take effect depends on the updates made and the\nnumber of search queries in your index.\n\nYou can still enable/disable query suggestions at any time.\n\n`UpdateQuerySuggestionsConfig` is currently not supported in the Amazon Web\nServices GovCloud (US-West) region.","ref":"AWS.Kendra.html#update_query_suggestions_config/3","title":"AWS.Kendra.update_query_suggestions_config/3","type":"function"},{"doc":"Updates a thesaurus for an index.","ref":"AWS.Kendra.html#update_thesaurus/3","title":"AWS.Kendra.update_thesaurus/3","type":"function"},{"doc":"Amazon Kendra Intelligent Ranking uses Amazon Kendra semantic search\ncapabilities to intelligently re-rank a search service's results.","ref":"AWS.KendraRanking.html","title":"AWS.KendraRanking","type":"module"},{"doc":"Creates a rescore execution plan.\n\nA rescore execution plan is an Amazon Kendra Intelligent Ranking resource used\nfor provisioning the `Rescore` API. You set the number of capacity units that\nyou require for Amazon Kendra Intelligent Ranking to rescore or re-rank a search\nservice's results.\n\nFor an example of using the `CreateRescoreExecutionPlan` API, including using\nthe Python and Java SDKs, see [Semantically ranking a search service's results](https://docs.aws.amazon.com/kendra/latest/dg/search-service-rerank.html).","ref":"AWS.KendraRanking.html#create_rescore_execution_plan/3","title":"AWS.KendraRanking.create_rescore_execution_plan/3","type":"function"},{"doc":"Deletes a rescore execution plan.\n\nA rescore execution plan is an Amazon Kendra Intelligent Ranking resource used\nfor provisioning the `Rescore` API.","ref":"AWS.KendraRanking.html#delete_rescore_execution_plan/3","title":"AWS.KendraRanking.delete_rescore_execution_plan/3","type":"function"},{"doc":"Gets information about a rescore execution plan.\n\nA rescore execution plan is an Amazon Kendra Intelligent Ranking resource used\nfor provisioning the `Rescore` API.","ref":"AWS.KendraRanking.html#describe_rescore_execution_plan/3","title":"AWS.KendraRanking.describe_rescore_execution_plan/3","type":"function"},{"doc":"Lists your rescore execution plans.\n\nA rescore execution plan is an Amazon Kendra Intelligent Ranking resource used\nfor provisioning the `Rescore` API.","ref":"AWS.KendraRanking.html#list_rescore_execution_plans/3","title":"AWS.KendraRanking.list_rescore_execution_plans/3","type":"function"},{"doc":"Gets a list of tags associated with a specified resource.\n\nA rescore execution plan is an example of a resource that can have tags\nassociated with it.","ref":"AWS.KendraRanking.html#list_tags_for_resource/3","title":"AWS.KendraRanking.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.KendraRanking.html#metadata/0","title":"AWS.KendraRanking.metadata/0","type":"function"},{"doc":"Rescores or re-ranks search results from a search service such as OpenSearch\n(self managed).\n\nYou use the semantic search capabilities of Amazon Kendra Intelligent Ranking to\nimprove the search service's results.","ref":"AWS.KendraRanking.html#rescore/3","title":"AWS.KendraRanking.rescore/3","type":"function"},{"doc":"Adds a specified tag to a specified rescore execution plan.\n\nA rescore execution plan is an Amazon Kendra Intelligent Ranking resource used\nfor provisioning the `Rescore` API. If the tag already exists, the existing\nvalue is replaced with the new value.","ref":"AWS.KendraRanking.html#tag_resource/3","title":"AWS.KendraRanking.tag_resource/3","type":"function"},{"doc":"Removes a tag from a rescore execution plan.\n\nA rescore execution plan is an Amazon Kendra Intelligent Ranking resource used\nfor provisioning the `Rescore` operation.","ref":"AWS.KendraRanking.html#untag_resource/3","title":"AWS.KendraRanking.untag_resource/3","type":"function"},{"doc":"Updates a rescore execution plan.\n\nA rescore execution plan is an Amazon Kendra Intelligent Ranking resource used\nfor provisioning the `Rescore` API. You can update the number of capacity units\nyou require for Amazon Kendra Intelligent Ranking to rescore or re-rank a search\nservice's results.","ref":"AWS.KendraRanking.html#update_rescore_execution_plan/3","title":"AWS.KendraRanking.update_rescore_execution_plan/3","type":"function"},{"doc":"Amazon Keyspaces (for Apache Cassandra) is a scalable, highly available, and\nmanaged Apache Cassandra-compatible database service.\n\nAmazon Keyspaces makes it easy to migrate, run, and scale Cassandra workloads in\nthe Amazon Web Services Cloud. With just a few clicks on the Amazon Web Services\nManagement Console or a few lines of code, you can create keyspaces and tables\nin Amazon Keyspaces, without deploying any infrastructure or installing\nsoftware.\n\nIn addition to supporting Cassandra Query Language (CQL) requests via\nopen-source Cassandra drivers, Amazon Keyspaces supports data definition\nlanguage (DDL) operations to manage keyspaces and tables using the Amazon Web\nServices SDK and CLI, as well as infrastructure as code (IaC) services and tools\nsuch as CloudFormation and Terraform. This API reference describes the supported\nDDL operations in detail.\n\nFor the list of all supported CQL APIs, see [Supported Cassandra APIs, operations, and data types in Amazon\nKeyspaces](https://docs.aws.amazon.com/keyspaces/latest/devguide/cassandra-apis.html)\nin the *Amazon Keyspaces Developer Guide*.\n\nTo learn how Amazon Keyspaces API actions are recorded with CloudTrail, see\n[Amazon Keyspaces information in CloudTrail](https://docs.aws.amazon.com/keyspaces/latest/devguide/logging-using-cloudtrail.html#service-name-info-in-cloudtrail)\nin the *Amazon Keyspaces Developer Guide*.\n\nFor more information about Amazon Web Services APIs, for example how to\nimplement retry logic or how to sign Amazon Web Services API requests, see\n[Amazon Web Services APIs](https://docs.aws.amazon.com/general/latest/gr/aws-apis.html) in the\n*General Reference*.","ref":"AWS.Keyspaces.html","title":"AWS.Keyspaces","type":"module"},{"doc":"The `CreateKeyspace` operation adds a new keyspace to your account.\n\nIn an Amazon Web Services account, keyspace names must be unique within each\nRegion.\n\n`CreateKeyspace` is an asynchronous operation. You can monitor the creation\nstatus of the new keyspace by using the `GetKeyspace` operation.\n\nFor more information, see [Creating keyspaces](https://docs.aws.amazon.com/keyspaces/latest/devguide/working-with-keyspaces.html#keyspaces-create)\nin the *Amazon Keyspaces Developer Guide*.","ref":"AWS.Keyspaces.html#create_keyspace/3","title":"AWS.Keyspaces.create_keyspace/3","type":"function"},{"doc":"The `CreateTable` operation adds a new table to the specified keyspace.\n\nWithin a keyspace, table names must be unique.\n\n`CreateTable` is an asynchronous operation. When the request is received, the\nstatus of the table is set to `CREATING`. You can monitor the creation status of\nthe new table by using the `GetTable` operation, which returns the current\n`status` of the table. You can start using a table when the status is `ACTIVE`.\n\nFor more information, see [Creating tables](https://docs.aws.amazon.com/keyspaces/latest/devguide/working-with-tables.html#tables-create)\nin the *Amazon Keyspaces Developer Guide*.","ref":"AWS.Keyspaces.html#create_table/3","title":"AWS.Keyspaces.create_table/3","type":"function"},{"doc":"The `DeleteKeyspace` operation deletes a keyspace and all of its tables.","ref":"AWS.Keyspaces.html#delete_keyspace/3","title":"AWS.Keyspaces.delete_keyspace/3","type":"function"},{"doc":"The `DeleteTable` operation deletes a table and all of its data.\n\nAfter a `DeleteTable` request is received, the specified table is in the\n`DELETING` state until Amazon Keyspaces completes the deletion. If the table is\nin the `ACTIVE` state, you can delete it. If a table is either in the `CREATING`\nor `UPDATING` states, then Amazon Keyspaces returns a `ResourceInUseException`.\nIf the specified table does not exist, Amazon Keyspaces returns a\n`ResourceNotFoundException`. If the table is already in the `DELETING` state, no\nerror is returned.","ref":"AWS.Keyspaces.html#delete_table/3","title":"AWS.Keyspaces.delete_table/3","type":"function"},{"doc":"Returns the name and the Amazon Resource Name (ARN) of the specified table.","ref":"AWS.Keyspaces.html#get_keyspace/3","title":"AWS.Keyspaces.get_keyspace/3","type":"function"},{"doc":"Returns information about the table, including the table's name and current\nstatus, the keyspace name, configuration settings, and metadata.\n\nTo read table metadata using `GetTable`, `Select` action permissions for the\ntable and system tables are required to complete the operation.","ref":"AWS.Keyspaces.html#get_table/3","title":"AWS.Keyspaces.get_table/3","type":"function"},{"doc":"Returns auto scaling related settings of the specified table in JSON format.\n\nIf the table is a multi-Region table, the Amazon Web Services Region specific\nauto scaling settings of the table are included.\n\nAmazon Keyspaces auto scaling helps you provision throughput capacity for\nvariable workloads efficiently by increasing and decreasing your table's read\nand write capacity automatically in response to application traffic. For more\ninformation, see [Managing throughput capacity automatically with Amazon Keyspaces auto\nscaling](https://docs.aws.amazon.com/keyspaces/latest/devguide/autoscaling.html)\nin the *Amazon Keyspaces Developer Guide*.","ref":"AWS.Keyspaces.html#get_table_auto_scaling_settings/3","title":"AWS.Keyspaces.get_table_auto_scaling_settings/3","type":"function"},{"doc":"Returns a list of keyspaces.","ref":"AWS.Keyspaces.html#list_keyspaces/3","title":"AWS.Keyspaces.list_keyspaces/3","type":"function"},{"doc":"Returns a list of tables for a specified keyspace.","ref":"AWS.Keyspaces.html#list_tables/3","title":"AWS.Keyspaces.list_tables/3","type":"function"},{"doc":"Returns a list of all tags associated with the specified Amazon Keyspaces\nresource.","ref":"AWS.Keyspaces.html#list_tags_for_resource/3","title":"AWS.Keyspaces.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.Keyspaces.html#metadata/0","title":"AWS.Keyspaces.metadata/0","type":"function"},{"doc":"Restores the table to the specified point in time within the\n`earliest_restorable_timestamp` and the current time.\n\nFor more information about restore points, see [ Time window for PITR continuous backups](https://docs.aws.amazon.com/keyspaces/latest/devguide/PointInTimeRecovery_HowItWorks.html#howitworks_backup_window)\nin the *Amazon Keyspaces Developer Guide*.\n\nAny number of users can execute up to 4 concurrent restores (any type of\nrestore) in a given account.\n\nWhen you restore using point in time recovery, Amazon Keyspaces restores your\nsource table's schema and data to the state based on the selected timestamp\n`(day:hour:minute:second)` to a new table. The Time to Live (TTL) settings are\nalso restored to the state based on the selected timestamp.\n\nIn addition to the table's schema, data, and TTL settings, `RestoreTable`\nrestores the capacity mode, auto scaling settings, encryption settings, and\npoint-in-time recovery settings from the source table. Unlike the table's schema\ndata and TTL settings, which are restored based on the selected timestamp, these\nsettings are always restored based on the table's settings as of the current\ntime or when the table was deleted.\n\nYou can also overwrite these settings during restore:\n\n  * Read/write capacity mode\n\n  * Provisioned throughput capacity units\n\n  * Auto scaling settings\n\n  * Point-in-time (PITR) settings\n\n  * Tags\n\nFor more information, see [PITR restore settings](https://docs.aws.amazon.com/keyspaces/latest/devguide/PointInTimeRecovery_HowItWorks.html#howitworks_backup_settings)\nin the *Amazon Keyspaces Developer Guide*.\n\nNote that the following settings are not restored, and you must configure them\nmanually for the new table:\n\n  * Identity and Access Management (IAM) policies\n\n  * Amazon CloudWatch metrics and alarms","ref":"AWS.Keyspaces.html#restore_table/3","title":"AWS.Keyspaces.restore_table/3","type":"function"},{"doc":"Associates a set of tags with a Amazon Keyspaces resource.\n\nYou can then activate these user-defined tags so that they appear on the Cost\nManagement Console for cost allocation tracking. For more information, see\n[Adding tags and labels to Amazon Keyspaces resources](https://docs.aws.amazon.com/keyspaces/latest/devguide/tagging-keyspaces.html)\nin the *Amazon Keyspaces Developer Guide*.\n\nFor IAM policy examples that show how to control access to Amazon Keyspaces\nresources based on tags, see [Amazon Keyspaces resource access based on tags](https://docs.aws.amazon.com/keyspaces/latest/devguide/security_iam_id-based-policy-examples.html#security_iam_id-based-policy-examples-tags)\nin the *Amazon Keyspaces Developer Guide*.","ref":"AWS.Keyspaces.html#tag_resource/3","title":"AWS.Keyspaces.tag_resource/3","type":"function"},{"doc":"Removes the association of tags from a Amazon Keyspaces resource.","ref":"AWS.Keyspaces.html#untag_resource/3","title":"AWS.Keyspaces.untag_resource/3","type":"function"},{"doc":"Adds new columns to the table or updates one of the table's settings, for\nexample capacity mode, auto scaling, encryption, point-in-time recovery, or ttl\nsettings.\n\nNote that you can only update one specific table setting per update operation.","ref":"AWS.Keyspaces.html#update_table/3","title":"AWS.Keyspaces.update_table/3","type":"function"},{"doc":"Amazon Kinesis Data Streams Service API Reference\n\nAmazon Kinesis Data Streams is a managed service that scales elastically for\nreal-time processing of streaming big data.","ref":"AWS.Kinesis.html","title":"AWS.Kinesis","type":"module"},{"doc":"Adds or updates tags for the specified Kinesis data stream.\n\nYou can assign up to 50 tags to a data stream.\n\nWhen invoking this API, you must use either the `StreamARN` or the `StreamName`\nparameter, or both. It is recommended that you use the `StreamARN` input\nparameter when you invoke this API.\n\nIf tags have already been assigned to the stream, `AddTagsToStream` overwrites\nany existing tags that correspond to the specified tag keys.\n\n`AddTagsToStream` has a limit of five transactions per second per account.","ref":"AWS.Kinesis.html#add_tags_to_stream/3","title":"AWS.Kinesis.add_tags_to_stream/3","type":"function"},{"doc":"Creates a Kinesis data stream.\n\nA stream captures and transports data records that are continuously emitted from\ndifferent data sources or *producers*. Scale-out within a stream is explicitly\nsupported by means of shards, which are uniquely identified groups of data\nrecords in a stream.\n\nYou can create your data stream using either on-demand or provisioned capacity\nmode. Data streams with an on-demand mode require no capacity planning and\nautomatically scale to handle gigabytes of write and read throughput per minute.\nWith the on-demand mode, Kinesis Data Streams automatically manages the shards\nin order to provide the necessary throughput. For the data streams with a\nprovisioned mode, you must specify the number of shards for the data stream.\nEach shard can support reads up to five transactions per second, up to a maximum\ndata read total of 2 MiB per second. Each shard can support writes up to 1,000\nrecords per second, up to a maximum data write total of 1 MiB per second. If the\namount of data input increases or decreases, you can add or remove shards.\n\nThe stream name identifies the stream. The name is scoped to the Amazon Web\nServices account used by the application. It is also scoped by Amazon Web\nServices Region. That is, two streams in two different accounts can have the\nsame name, and two streams in the same account, but in two different Regions,\ncan have the same name.\n\n`CreateStream` is an asynchronous operation. Upon receiving a `CreateStream`\nrequest, Kinesis Data Streams immediately returns and sets the stream status to\n`CREATING`. After the stream is created, Kinesis Data Streams sets the stream\nstatus to `ACTIVE`. You should perform read and write operations only on an\n`ACTIVE` stream.\n\nYou receive a `LimitExceededException` when making a `CreateStream` request when\nyou try to do one of the following:\n\n  * Have more than five streams in the `CREATING` state at any point\nin time.\n\n  * Create more shards than are authorized for your account.\n\nFor the default shard limit for an Amazon Web Services account, see [Amazon Kinesis Data Streams\nLimits](https://docs.aws.amazon.com/kinesis/latest/dev/service-sizes-and-limits.html)\nin the *Amazon Kinesis Data Streams Developer Guide*. To increase this limit,\n[contact Amazon Web Services Support](https://docs.aws.amazon.com/general/latest/gr/aws_service_limits.html).\n\nYou can use `DescribeStreamSummary` to check the stream status, which is\nreturned in `StreamStatus`.\n\n`CreateStream` has a limit of five transactions per second per account.","ref":"AWS.Kinesis.html#create_stream/3","title":"AWS.Kinesis.create_stream/3","type":"function"},{"doc":"Decreases the Kinesis data stream's retention period, which is the length of\ntime data records are accessible after they are added to the stream.\n\nThe minimum value of a stream's retention period is 24 hours.\n\nWhen invoking this API, you must use either the `StreamARN` or the `StreamName`\nparameter, or both. It is recommended that you use the `StreamARN` input\nparameter when you invoke this API.\n\nThis operation may result in lost data. For example, if the stream's retention\nperiod is 48 hours and is decreased to 24 hours, any data already in the stream\nthat is older than 24 hours is inaccessible.","ref":"AWS.Kinesis.html#decrease_stream_retention_period/3","title":"AWS.Kinesis.decrease_stream_retention_period/3","type":"function"},{"doc":"Delete a policy for the specified data stream or consumer.\n\nRequest patterns can be one of the following:\n\n  * Data stream pattern: `arn:aws.*:kinesis:.*:{12}:.*stream/S+`\n\n  * Consumer pattern:\n`^(arn):aws.*:kinesis:.*:{12}:.*stream/[a-zA-Z0-9_.-]+/consumer/[a-zA-Z0-9_.-]+:[0-9]+`","ref":"AWS.Kinesis.html#delete_resource_policy/3","title":"AWS.Kinesis.delete_resource_policy/3","type":"function"},{"doc":"Deletes a Kinesis data stream and all its shards and data.\n\nYou must shut down any applications that are operating on the stream before you\ndelete the stream. If an application attempts to operate on a deleted stream, it\nreceives the exception `ResourceNotFoundException`.\n\nWhen invoking this API, you must use either the `StreamARN` or the `StreamName`\nparameter, or both. It is recommended that you use the `StreamARN` input\nparameter when you invoke this API.\n\nIf the stream is in the `ACTIVE` state, you can delete it. After a\n`DeleteStream` request, the specified stream is in the `DELETING` state until\nKinesis Data Streams completes the deletion.\n\n**Note:** Kinesis Data Streams might continue to accept data read and write\noperations, such as `PutRecord`, `PutRecords`, and `GetRecords`, on a stream in\nthe `DELETING` state until the stream deletion is complete.\n\nWhen you delete a stream, any shards in that stream are also deleted, and any\ntags are dissociated from the stream.\n\nYou can use the `DescribeStreamSummary` operation to check the state of the\nstream, which is returned in `StreamStatus`.\n\n`DeleteStream` has a limit of five transactions per second per account.","ref":"AWS.Kinesis.html#delete_stream/3","title":"AWS.Kinesis.delete_stream/3","type":"function"},{"doc":"To deregister a consumer, provide its ARN.\n\nAlternatively, you can provide the ARN of the data stream and the name you gave\nthe consumer when you registered it. You may also provide all three parameters,\nas long as they don't conflict with each other. If you don't know the name or\nARN of the consumer that you want to deregister, you can use the\n`ListStreamConsumers` operation to get a list of the descriptions of all the\nconsumers that are currently registered with a given data stream. The\ndescription of a consumer contains its name and ARN.\n\nThis operation has a limit of five transactions per second per stream.","ref":"AWS.Kinesis.html#deregister_stream_consumer/3","title":"AWS.Kinesis.deregister_stream_consumer/3","type":"function"},{"doc":"Describes the shard limits and usage for the account.\n\nIf you update your account limits, the old limits might be returned for a few\nminutes.\n\nThis operation has a limit of one transaction per second per account.","ref":"AWS.Kinesis.html#describe_limits/3","title":"AWS.Kinesis.describe_limits/3","type":"function"},{"doc":"Describes the specified Kinesis data stream.\n\nThis API has been revised. It's highly recommended that you use the\n`DescribeStreamSummary` API to get a summarized description of the specified\nKinesis data stream and the `ListShards` API to list the shards in a specified\ndata stream and obtain information about each shard.\n\nWhen invoking this API, you must use either the `StreamARN` or the `StreamName`\nparameter, or both. It is recommended that you use the `StreamARN` input\nparameter when you invoke this API.\n\nThe information returned includes the stream name, Amazon Resource Name (ARN),\ncreation time, enhanced metric configuration, and shard map. The shard map is an\narray of shard objects. For each shard object, there is the hash key and\nsequence number ranges that the shard spans, and the IDs of any earlier shards\nthat played in a role in creating the shard. Every record ingested in the stream\nis identified by a sequence number, which is assigned when the record is put\ninto the stream.\n\nYou can limit the number of shards returned by each call. For more information,\nsee [Retrieving Shards from a Stream](https://docs.aws.amazon.com/kinesis/latest/dev/kinesis-using-sdk-java-retrieve-shards.html)\nin the *Amazon Kinesis Data Streams Developer Guide*.\n\nThere are no guarantees about the chronological order shards returned. To\nprocess shards in chronological order, use the ID of the parent shard to track\nthe lineage to the oldest shard.\n\nThis operation has a limit of 10 transactions per second per account.","ref":"AWS.Kinesis.html#describe_stream/3","title":"AWS.Kinesis.describe_stream/3","type":"function"},{"doc":"To get the description of a registered consumer, provide the ARN of the\nconsumer.\n\nAlternatively, you can provide the ARN of the data stream and the name you gave\nthe consumer when you registered it. You may also provide all three parameters,\nas long as they don't conflict with each other. If you don't know the name or\nARN of the consumer that you want to describe, you can use the\n`ListStreamConsumers` operation to get a list of the descriptions of all the\nconsumers that are currently registered with a given data stream.\n\nThis operation has a limit of 20 transactions per second per stream.\n\nWhen making a cross-account call with `DescribeStreamConsumer`, make sure to\nprovide the ARN of the consumer.","ref":"AWS.Kinesis.html#describe_stream_consumer/3","title":"AWS.Kinesis.describe_stream_consumer/3","type":"function"},{"doc":"Provides a summarized description of the specified Kinesis data stream without\nthe shard list.\n\nWhen invoking this API, you must use either the `StreamARN` or the `StreamName`\nparameter, or both. It is recommended that you use the `StreamARN` input\nparameter when you invoke this API.\n\nThe information returned includes the stream name, Amazon Resource Name (ARN),\nstatus, record retention period, approximate creation time, monitoring,\nencryption details, and open shard count.\n\n`DescribeStreamSummary` has a limit of 20 transactions per second per account.","ref":"AWS.Kinesis.html#describe_stream_summary/3","title":"AWS.Kinesis.describe_stream_summary/3","type":"function"},{"doc":"Disables enhanced monitoring.\n\nWhen invoking this API, you must use either the `StreamARN` or the `StreamName`\nparameter, or both. It is recommended that you use the `StreamARN` input\nparameter when you invoke this API.","ref":"AWS.Kinesis.html#disable_enhanced_monitoring/3","title":"AWS.Kinesis.disable_enhanced_monitoring/3","type":"function"},{"doc":"Enables enhanced Kinesis data stream monitoring for shard-level metrics.\n\nWhen invoking this API, you must use either the `StreamARN` or the `StreamName`\nparameter, or both. It is recommended that you use the `StreamARN` input\nparameter when you invoke this API.","ref":"AWS.Kinesis.html#enable_enhanced_monitoring/3","title":"AWS.Kinesis.enable_enhanced_monitoring/3","type":"function"},{"doc":"Gets data records from a Kinesis data stream's shard.\n\nWhen invoking this API, you must use either the `StreamARN` or the `StreamName`\nparameter, or both. It is recommended that you use the `StreamARN` input\nparameter when you invoke this API.\n\nSpecify a shard iterator using the `ShardIterator` parameter. The shard iterator\nspecifies the position in the shard from which you want to start reading data\nrecords sequentially. If there are no records available in the portion of the\nshard that the iterator points to, `GetRecords` returns an empty list. It might\ntake multiple calls to get to a portion of the shard that contains records.\n\nYou can scale by provisioning multiple shards per stream while considering\nservice limits (for more information, see [Amazon Kinesis Data Streams Limits](https://docs.aws.amazon.com/kinesis/latest/dev/service-sizes-and-limits.html)\nin the *Amazon Kinesis Data Streams Developer Guide*). Your application should\nhave one thread per shard, each reading continuously from its stream. To read\nfrom a stream continually, call `GetRecords` in a loop. Use `GetShardIterator`\nto get the shard iterator to specify in the first `GetRecords` call.\n`GetRecords` returns a new shard iterator in `NextShardIterator`. Specify the\nshard iterator returned in `NextShardIterator` in subsequent calls to\n`GetRecords`. If the shard has been closed, the shard iterator can't return more\ndata and `GetRecords` returns `null` in `NextShardIterator`. You can terminate\nthe loop when the shard is closed, or when the shard iterator reaches the record\nwith the sequence number or other attribute that marks it as the last record to\nprocess.\n\nEach data record can be up to 1 MiB in size, and each shard can read up to 2 MiB\nper second. You can ensure that your calls don't exceed the maximum supported\nsize or throughput by using the `Limit` parameter to specify the maximum number\nof records that `GetRecords` can return. Consider your average record size when\ndetermining this limit. The maximum number of records that can be returned per\ncall is 10,000.\n\nThe size of the data returned by `GetRecords` varies depending on the\nutilization of the shard. It is recommended that consumer applications retrieve\nrecords via the `GetRecords` command using the 5 TPS limit to remain caught up.\nRetrieving records less frequently can lead to consumer applications falling\nbehind. The maximum size of data that `GetRecords` can return is 10 MiB. If a\ncall returns this amount of data, subsequent calls made within the next 5\nseconds throw `ProvisionedThroughputExceededException`. If there is insufficient\nprovisioned throughput on the stream, subsequent calls made within the next 1\nsecond throw `ProvisionedThroughputExceededException`. `GetRecords` doesn't\nreturn any data when it throws an exception. For this reason, we recommend that\nyou wait 1 second between calls to `GetRecords`. However, it's possible that the\napplication will get exceptions for longer than 1 second.\n\nTo detect whether the application is falling behind in processing, you can use\nthe `MillisBehindLatest` response attribute. You can also monitor the stream\nusing CloudWatch metrics and other mechanisms (see\n[Monitoring](https://docs.aws.amazon.com/kinesis/latest/dev/monitoring.html) in\nthe *Amazon Kinesis Data Streams Developer Guide*).\n\nEach Amazon Kinesis record includes a value, `ApproximateArrivalTimestamp`, that\nis set when a stream successfully receives and stores a record. This is commonly\nreferred to as a server-side time stamp, whereas a client-side time stamp is set\nwhen a data producer creates or sends the record to a stream (a data producer is\nany data source putting data records into a stream, for example with\n`PutRecords`). The time stamp has millisecond precision. There are no guarantees\nabout the time stamp accuracy, or that the time stamp is always increasing. For\nexample, records in a shard or across a stream might have time stamps that are\nout of order.\n\nThis operation has a limit of five transactions per second per shard.","ref":"AWS.Kinesis.html#get_records/3","title":"AWS.Kinesis.get_records/3","type":"function"},{"doc":"Returns a policy attached to the specified data stream or consumer.\n\nRequest patterns can be one of the following:\n\n  * Data stream pattern: `arn:aws.*:kinesis:.*:{12}:.*stream/S+`\n\n  * Consumer pattern:\n`^(arn):aws.*:kinesis:.*:{12}:.*stream/[a-zA-Z0-9_.-]+/consumer/[a-zA-Z0-9_.-]+:[0-9]+`","ref":"AWS.Kinesis.html#get_resource_policy/3","title":"AWS.Kinesis.get_resource_policy/3","type":"function"},{"doc":"Gets an Amazon Kinesis shard iterator.\n\nA shard iterator expires 5 minutes after it is returned to the requester.\n\nWhen invoking this API, you must use either the `StreamARN` or the `StreamName`\nparameter, or both. It is recommended that you use the `StreamARN` input\nparameter when you invoke this API.\n\nA shard iterator specifies the shard position from which to start reading data\nrecords sequentially. The position is specified using the sequence number of a\ndata record in a shard. A sequence number is the identifier associated with\nevery record ingested in the stream, and is assigned when a record is put into\nthe stream. Each stream has one or more shards.\n\nYou must specify the shard iterator type. For example, you can set the\n`ShardIteratorType` parameter to read exactly from the position denoted by a\nspecific sequence number by using the `AT_SEQUENCE_NUMBER` shard iterator type.\nAlternatively, the parameter can read right after the sequence number by using\nthe `AFTER_SEQUENCE_NUMBER` shard iterator type, using sequence numbers returned\nby earlier calls to `PutRecord`, `PutRecords`, `GetRecords`, or\n`DescribeStream`. In the request, you can specify the shard iterator type\n`AT_TIMESTAMP` to read records from an arbitrary point in time, `TRIM_HORIZON`\nto cause `ShardIterator` to point to the last untrimmed record in the shard in\nthe system (the oldest data record in the shard), or `LATEST` so that you always\nread the most recent data in the shard.\n\nWhen you read repeatedly from a stream, use a `GetShardIterator` request to get\nthe first shard iterator for use in your first `GetRecords` request and for\nsubsequent reads use the shard iterator returned by the `GetRecords` request in\n`NextShardIterator`. A new shard iterator is returned by every `GetRecords`\nrequest in `NextShardIterator`, which you use in the `ShardIterator` parameter\nof the next `GetRecords` request.\n\nIf a `GetShardIterator` request is made too often, you receive a\n`ProvisionedThroughputExceededException`. For more information about throughput\nlimits, see `GetRecords`, and [Streams Limits](https://docs.aws.amazon.com/kinesis/latest/dev/service-sizes-and-limits.html)\nin the *Amazon Kinesis Data Streams Developer Guide*.\n\nIf the shard is closed, `GetShardIterator` returns a valid iterator for the last\nsequence number of the shard. A shard can be closed as a result of using\n`SplitShard` or `MergeShards`.\n\n`GetShardIterator` has a limit of five transactions per second per account per\nopen shard.","ref":"AWS.Kinesis.html#get_shard_iterator/3","title":"AWS.Kinesis.get_shard_iterator/3","type":"function"},{"doc":"Increases the Kinesis data stream's retention period, which is the length of\ntime data records are accessible after they are added to the stream.\n\nThe maximum value of a stream's retention period is 8760 hours (365 days).\n\nWhen invoking this API, you must use either the `StreamARN` or the `StreamName`\nparameter, or both. It is recommended that you use the `StreamARN` input\nparameter when you invoke this API.\n\nIf you choose a longer stream retention period, this operation increases the\ntime period during which records that have not yet expired are accessible.\nHowever, it does not make previous, expired data (older than the stream's\nprevious retention period) accessible after the operation has been called. For\nexample, if a stream's retention period is set to 24 hours and is increased to\n168 hours, any data that is older than 24 hours remains inaccessible to consumer\napplications.","ref":"AWS.Kinesis.html#increase_stream_retention_period/3","title":"AWS.Kinesis.increase_stream_retention_period/3","type":"function"},{"doc":"Lists the shards in a stream and provides information about each shard.\n\nThis operation has a limit of 1000 transactions per second per data stream.\n\nWhen invoking this API, you must use either the `StreamARN` or the `StreamName`\nparameter, or both. It is recommended that you use the `StreamARN` input\nparameter when you invoke this API.\n\nThis action does not list expired shards. For information about expired shards,\nsee [Data Routing, Data Persistence, and Shard State after a Reshard](https://docs.aws.amazon.com/streams/latest/dev/kinesis-using-sdk-java-after-resharding.html#kinesis-using-sdk-java-resharding-data-routing).\n\nThis API is a new operation that is used by the Amazon Kinesis Client Library\n(KCL). If you have a fine-grained IAM policy that only allows specific\noperations, you must update your policy to allow calls to this API. For more\ninformation, see [Controlling Access to Amazon Kinesis Data Streams Resources Using\nIAM](https://docs.aws.amazon.com/streams/latest/dev/controlling-access.html).","ref":"AWS.Kinesis.html#list_shards/3","title":"AWS.Kinesis.list_shards/3","type":"function"},{"doc":"Lists the consumers registered to receive data from a stream using enhanced\nfan-out, and provides information about each consumer.\n\nThis operation has a limit of 5 transactions per second per stream.","ref":"AWS.Kinesis.html#list_stream_consumers/3","title":"AWS.Kinesis.list_stream_consumers/3","type":"function"},{"doc":"Lists your Kinesis data streams.\n\nThe number of streams may be too large to return from a single call to\n`ListStreams`. You can limit the number of returned streams using the `Limit`\nparameter. If you do not specify a value for the `Limit` parameter, Kinesis Data\nStreams uses the default limit, which is currently 100.\n\nYou can detect if there are more streams available to list by using the\n`HasMoreStreams` flag from the returned output. If there are more streams\navailable, you can request more streams by using the name of the last stream\nreturned by the `ListStreams` request in the `ExclusiveStartStreamName`\nparameter in a subsequent request to `ListStreams`. The group of stream names\nreturned by the subsequent request is then added to the list. You can continue\nthis process until all the stream names have been collected in the list.\n\n`ListStreams` has a limit of five transactions per second per account.","ref":"AWS.Kinesis.html#list_streams/3","title":"AWS.Kinesis.list_streams/3","type":"function"},{"doc":"Lists the tags for the specified Kinesis data stream.\n\nThis operation has a limit of five transactions per second per account.\n\nWhen invoking this API, you must use either the `StreamARN` or the `StreamName`\nparameter, or both. It is recommended that you use the `StreamARN` input\nparameter when you invoke this API.","ref":"AWS.Kinesis.html#list_tags_for_stream/3","title":"AWS.Kinesis.list_tags_for_stream/3","type":"function"},{"doc":"Merges two adjacent shards in a Kinesis data stream and combines them into a\nsingle shard to reduce the stream's capacity to ingest and transport data.\n\nThis API is only supported for the data streams with the provisioned capacity\nmode. Two shards are considered adjacent if the union of the hash key ranges for\nthe two shards form a contiguous set with no gaps. For example, if you have two\nshards, one with a hash key range of 276...381 and the other with a hash key\nrange of 382...454, then you could merge these two shards into a single shard\nthat would have a hash key range of 276...454. After the merge, the single child\nshard receives data for all hash key values covered by the two parent shards.\n\nWhen invoking this API, you must use either the `StreamARN` or the `StreamName`\nparameter, or both. It is recommended that you use the `StreamARN` input\nparameter when you invoke this API.\n\n`MergeShards` is called when there is a need to reduce the overall capacity of a\nstream because of excess capacity that is not being used. You must specify the\nshard to be merged and the adjacent shard for a stream. For more information\nabout merging shards, see [Merge Two Shards](https://docs.aws.amazon.com/kinesis/latest/dev/kinesis-using-sdk-java-resharding-merge.html)\nin the *Amazon Kinesis Data Streams Developer Guide*.\n\nIf the stream is in the `ACTIVE` state, you can call `MergeShards`. If a stream\nis in the `CREATING`, `UPDATING`, or `DELETING` state, `MergeShards` returns a\n`ResourceInUseException`. If the specified stream does not exist, `MergeShards`\nreturns a `ResourceNotFoundException`.\n\nYou can use `DescribeStreamSummary` to check the state of the stream, which is\nreturned in `StreamStatus`.\n\n`MergeShards` is an asynchronous operation. Upon receiving a `MergeShards`\nrequest, Amazon Kinesis Data Streams immediately returns a response and sets the\n`StreamStatus` to `UPDATING`. After the operation is completed, Kinesis Data\nStreams sets the `StreamStatus` to `ACTIVE`. Read and write operations continue\nto work while the stream is in the `UPDATING` state.\n\nYou use `DescribeStreamSummary` and the `ListShards` APIs to determine the shard\nIDs that are specified in the `MergeShards` request.\n\nIf you try to operate on too many streams in parallel using `CreateStream`,\n`DeleteStream`, `MergeShards`, or `SplitShard`, you receive a\n`LimitExceededException`.\n\n`MergeShards` has a limit of five transactions per second per account.","ref":"AWS.Kinesis.html#merge_shards/3","title":"AWS.Kinesis.merge_shards/3","type":"function"},{"doc":"","ref":"AWS.Kinesis.html#metadata/0","title":"AWS.Kinesis.metadata/0","type":"function"},{"doc":"Writes a single data record into an Amazon Kinesis data stream.\n\nCall `PutRecord` to send data into the stream for real-time ingestion and\nsubsequent processing, one record at a time. Each shard can support writes up to\n1,000 records per second, up to a maximum data write total of 1 MiB per second.\n\nWhen invoking this API, you must use either the `StreamARN` or the `StreamName`\nparameter, or both. It is recommended that you use the `StreamARN` input\nparameter when you invoke this API.\n\nYou must specify the name of the stream that captures, stores, and transports\nthe data; a partition key; and the data blob itself.\n\nThe data blob can be any type of data; for example, a segment from a log file,\ngeographic/location data, website clickstream data, and so on.\n\nThe partition key is used by Kinesis Data Streams to distribute data across\nshards. Kinesis Data Streams segregates the data records that belong to a stream\ninto multiple shards, using the partition key associated with each data record\nto determine the shard to which a given data record belongs.\n\nPartition keys are Unicode strings, with a maximum length limit of 256\ncharacters for each key. An MD5 hash function is used to map partition keys to\n128-bit integer values and to map associated data records to shards using the\nhash key ranges of the shards. You can override hashing the partition key to\ndetermine the shard by explicitly specifying a hash value using the\n`ExplicitHashKey` parameter. For more information, see [Adding Data to a Stream](https://docs.aws.amazon.com/kinesis/latest/dev/developing-producers-with-sdk.html#kinesis-using-sdk-java-add-data-to-stream)\nin the *Amazon Kinesis Data Streams Developer Guide*.\n\n`PutRecord` returns the shard ID of where the data record was placed and the\nsequence number that was assigned to the data record.\n\nSequence numbers increase over time and are specific to a shard within a stream,\nnot across all shards within a stream. To guarantee strictly increasing\nordering, write serially to a shard and use the `SequenceNumberForOrdering`\nparameter. For more information, see [Adding Data to a Stream](https://docs.aws.amazon.com/kinesis/latest/dev/developing-producers-with-sdk.html#kinesis-using-sdk-java-add-data-to-stream)\nin the *Amazon Kinesis Data Streams Developer Guide*.\n\nAfter you write a record to a stream, you cannot modify that record or its order\nwithin the stream.\n\nIf a `PutRecord` request cannot be processed because of insufficient provisioned\nthroughput on the shard involved in the request, `PutRecord` throws\n`ProvisionedThroughputExceededException`.\n\nBy default, data records are accessible for 24 hours from the time that they are\nadded to a stream. You can use `IncreaseStreamRetentionPeriod` or\n`DecreaseStreamRetentionPeriod` to modify this retention period.","ref":"AWS.Kinesis.html#put_record/3","title":"AWS.Kinesis.put_record/3","type":"function"},{"doc":"Writes multiple data records into a Kinesis data stream in a single call (also\nreferred to as a `PutRecords` request).\n\nUse this operation to send data into the stream for data ingestion and\nprocessing.\n\nWhen invoking this API, you must use either the `StreamARN` or the `StreamName`\nparameter, or both. It is recommended that you use the `StreamARN` input\nparameter when you invoke this API.\n\nEach `PutRecords` request can support up to 500 records. Each record in the\nrequest can be as large as 1 MiB, up to a limit of 5 MiB for the entire request,\nincluding partition keys. Each shard can support writes up to 1,000 records per\nsecond, up to a maximum data write total of 1 MiB per second.\n\nYou must specify the name of the stream that captures, stores, and transports\nthe data; and an array of request `Records`, with each record in the array\nrequiring a partition key and data blob. The record size limit applies to the\ntotal size of the partition key and data blob.\n\nThe data blob can be any type of data; for example, a segment from a log file,\ngeographic/location data, website clickstream data, and so on.\n\nThe partition key is used by Kinesis Data Streams as input to a hash function\nthat maps the partition key and associated data to a specific shard. An MD5 hash\nfunction is used to map partition keys to 128-bit integer values and to map\nassociated data records to shards. As a result of this hashing mechanism, all\ndata records with the same partition key map to the same shard within the\nstream. For more information, see [Adding Data to a Stream](https://docs.aws.amazon.com/kinesis/latest/dev/developing-producers-with-sdk.html#kinesis-using-sdk-java-add-data-to-stream)\nin the *Amazon Kinesis Data Streams Developer Guide*.\n\nEach record in the `Records` array may include an optional parameter,\n`ExplicitHashKey`, which overrides the partition key to shard mapping. This\nparameter allows a data producer to determine explicitly the shard where the\nrecord is stored. For more information, see [Adding Multiple Records with PutRecords](https://docs.aws.amazon.com/kinesis/latest/dev/developing-producers-with-sdk.html#kinesis-using-sdk-java-putrecords)\nin the *Amazon Kinesis Data Streams Developer Guide*.\n\nThe `PutRecords` response includes an array of response `Records`. Each record\nin the response array directly correlates with a record in the request array\nusing natural ordering, from the top to the bottom of the request and response.\nThe response `Records` array always includes the same number of records as the\nrequest array.\n\nThe response `Records` array includes both successfully and unsuccessfully\nprocessed records. Kinesis Data Streams attempts to process all records in each\n`PutRecords` request. A single record failure does not stop the processing of\nsubsequent records. As a result, PutRecords doesn't guarantee the ordering of\nrecords. If you need to read records in the same order they are written to the\nstream, use `PutRecord` instead of `PutRecords`, and write to the same shard.\n\nA successfully processed record includes `ShardId` and `SequenceNumber` values.\nThe `ShardId` parameter identifies the shard in the stream where the record is\nstored. The `SequenceNumber` parameter is an identifier assigned to the put\nrecord, unique to all records in the stream.\n\nAn unsuccessfully processed record includes `ErrorCode` and `ErrorMessage`\nvalues. `ErrorCode` reflects the type of error and can be one of the following\nvalues: `ProvisionedThroughputExceededException` or `InternalFailure`.\n`ErrorMessage` provides more detailed information about the\n`ProvisionedThroughputExceededException` exception including the account ID,\nstream name, and shard ID of the record that was throttled. For more information\nabout partially successful responses, see [Adding Multiple Records with PutRecords](https://docs.aws.amazon.com/kinesis/latest/dev/kinesis-using-sdk-java-add-data-to-stream.html#kinesis-using-sdk-java-putrecords)\nin the *Amazon Kinesis Data Streams Developer Guide*.\n\nAfter you write a record to a stream, you cannot modify that record or its order\nwithin the stream.\n\nBy default, data records are accessible for 24 hours from the time that they are\nadded to a stream. You can use `IncreaseStreamRetentionPeriod` or\n`DecreaseStreamRetentionPeriod` to modify this retention period.","ref":"AWS.Kinesis.html#put_records/3","title":"AWS.Kinesis.put_records/3","type":"function"},{"doc":"Attaches a resource-based policy to a data stream or registered consumer.\n\nIf you are using an identity other than the root user of the Amazon Web Services\naccount that owns the resource, the calling identity must have the\n`PutResourcePolicy` permissions on the specified Kinesis Data Streams resource\nand belong to the owner's account in order to use this operation. If you don't\nhave `PutResourcePolicy` permissions, Amazon Kinesis Data Streams returns a `403\nAccess Denied error`. If you receive a `ResourceNotFoundException`, check to see\nif you passed a valid stream or consumer resource.\n\nRequest patterns can be one of the following:\n\n  * Data stream pattern: `arn:aws.*:kinesis:.*:{12}:.*stream/S+`\n\n  * Consumer pattern:\n`^(arn):aws.*:kinesis:.*:{12}:.*stream/[a-zA-Z0-9_.-]+/consumer/[a-zA-Z0-9_.-]+:[0-9]+` \n\nFor more information, see [Controlling Access to Amazon Kinesis Data Streams\nResources Using\nIAM](https://docs.aws.amazon.com/streams/latest/dev/controlling-access.html).","ref":"AWS.Kinesis.html#put_resource_policy/3","title":"AWS.Kinesis.put_resource_policy/3","type":"function"},{"doc":"Registers a consumer with a Kinesis data stream.\n\nWhen you use this operation, the consumer you register can then call\n`SubscribeToShard` to receive data from the stream using enhanced fan-out, at a\nrate of up to 2 MiB per second for every shard you subscribe to. This rate is\nunaffected by the total number of consumers that read from the same stream.\n\nYou can register up to 20 consumers per stream. A given consumer can only be\nregistered with one stream at a time.\n\nFor an example of how to use this operations, see [Enhanced Fan-Out Using the Kinesis Data Streams\nAPI](/streams/latest/dev/building-enhanced-consumers-api.html).\n\nThe use of this operation has a limit of five transactions per second per\naccount. Also, only 5 consumers can be created simultaneously. In other words,\nyou cannot have more than 5 consumers in a `CREATING` status at the same time.\nRegistering a 6th consumer while there are 5 in a `CREATING` status results in a\n`LimitExceededException`.","ref":"AWS.Kinesis.html#register_stream_consumer/3","title":"AWS.Kinesis.register_stream_consumer/3","type":"function"},{"doc":"Removes tags from the specified Kinesis data stream.\n\nRemoved tags are deleted and cannot be recovered after this operation\nsuccessfully completes.\n\nWhen invoking this API, you must use either the `StreamARN` or the `StreamName`\nparameter, or both. It is recommended that you use the `StreamARN` input\nparameter when you invoke this API.\n\nIf you specify a tag that does not exist, it is ignored.\n\n`RemoveTagsFromStream` has a limit of five transactions per second per account.","ref":"AWS.Kinesis.html#remove_tags_from_stream/3","title":"AWS.Kinesis.remove_tags_from_stream/3","type":"function"},{"doc":"Splits a shard into two new shards in the Kinesis data stream, to increase the\nstream's capacity to ingest and transport data.\n\n`SplitShard` is called when there is a need to increase the overall capacity of\na stream because of an expected increase in the volume of data records being\ningested. This API is only supported for the data streams with the provisioned\ncapacity mode.\n\nWhen invoking this API, you must use either the `StreamARN` or the `StreamName`\nparameter, or both. It is recommended that you use the `StreamARN` input\nparameter when you invoke this API.\n\nYou can also use `SplitShard` when a shard appears to be approaching its maximum\nutilization; for example, the producers sending data into the specific shard are\nsuddenly sending more than previously anticipated. You can also call\n`SplitShard` to increase stream capacity, so that more Kinesis Data Streams\napplications can simultaneously read data from the stream for real-time\nprocessing.\n\nYou must specify the shard to be split and the new hash key, which is the\nposition in the shard where the shard gets split in two. In many cases, the new\nhash key might be the average of the beginning and ending hash key, but it can\nbe any hash key value in the range being mapped into the shard. For more\ninformation, see [Split a Shard](https://docs.aws.amazon.com/kinesis/latest/dev/kinesis-using-sdk-java-resharding-split.html)\nin the *Amazon Kinesis Data Streams Developer Guide*.\n\nYou can use `DescribeStreamSummary` and the `ListShards` APIs to determine the\nshard ID and hash key values for the `ShardToSplit` and `NewStartingHashKey`\nparameters that are specified in the `SplitShard` request.\n\n`SplitShard` is an asynchronous operation. Upon receiving a `SplitShard`\nrequest, Kinesis Data Streams immediately returns a response and sets the stream\nstatus to `UPDATING`. After the operation is completed, Kinesis Data Streams\nsets the stream status to `ACTIVE`. Read and write operations continue to work\nwhile the stream is in the `UPDATING` state.\n\nYou can use `DescribeStreamSummary` to check the status of the stream, which is\nreturned in `StreamStatus`. If the stream is in the `ACTIVE` state, you can call\n`SplitShard`.\n\nIf the specified stream does not exist, `DescribeStreamSummary` returns a\n`ResourceNotFoundException`. If you try to create more shards than are\nauthorized for your account, you receive a `LimitExceededException`.\n\nFor the default shard limit for an Amazon Web Services account, see [Kinesis Data Streams\nLimits](https://docs.aws.amazon.com/kinesis/latest/dev/service-sizes-and-limits.html)\nin the *Amazon Kinesis Data Streams Developer Guide*. To increase this limit,\n[contact Amazon Web Services Support](https://docs.aws.amazon.com/general/latest/gr/aws_service_limits.html).\n\nIf you try to operate on too many streams simultaneously using `CreateStream`,\n`DeleteStream`, `MergeShards`, and/or `SplitShard`, you receive a\n`LimitExceededException`.\n\n`SplitShard` has a limit of five transactions per second per account.","ref":"AWS.Kinesis.html#split_shard/3","title":"AWS.Kinesis.split_shard/3","type":"function"},{"doc":"Enables or updates server-side encryption using an Amazon Web Services KMS key\nfor a specified stream.\n\nWhen invoking this API, you must use either the `StreamARN` or the `StreamName`\nparameter, or both. It is recommended that you use the `StreamARN` input\nparameter when you invoke this API.\n\nStarting encryption is an asynchronous operation. Upon receiving the request,\nKinesis Data Streams returns immediately and sets the status of the stream to\n`UPDATING`. After the update is complete, Kinesis Data Streams sets the status\nof the stream back to `ACTIVE`. Updating or applying encryption normally takes a\nfew seconds to complete, but it can take minutes. You can continue to read and\nwrite data to your stream while its status is `UPDATING`. Once the status of the\nstream is `ACTIVE`, encryption begins for records written to the stream.\n\nAPI Limits: You can successfully apply a new Amazon Web Services KMS key for\nserver-side encryption 25 times in a rolling 24-hour period.\n\nNote: It can take up to 5 seconds after the stream is in an `ACTIVE` status\nbefore all records written to the stream are encrypted. After you enable\nencryption, you can verify that encryption is applied by inspecting the API\nresponse from `PutRecord` or `PutRecords`.","ref":"AWS.Kinesis.html#start_stream_encryption/3","title":"AWS.Kinesis.start_stream_encryption/3","type":"function"},{"doc":"Disables server-side encryption for a specified stream.\n\nWhen invoking this API, you must use either the `StreamARN` or the `StreamName`\nparameter, or both. It is recommended that you use the `StreamARN` input\nparameter when you invoke this API.\n\nStopping encryption is an asynchronous operation. Upon receiving the request,\nKinesis Data Streams returns immediately and sets the status of the stream to\n`UPDATING`. After the update is complete, Kinesis Data Streams sets the status\nof the stream back to `ACTIVE`. Stopping encryption normally takes a few seconds\nto complete, but it can take minutes. You can continue to read and write data to\nyour stream while its status is `UPDATING`. Once the status of the stream is\n`ACTIVE`, records written to the stream are no longer encrypted by Kinesis Data\nStreams.\n\nAPI Limits: You can successfully disable server-side encryption 25 times in a\nrolling 24-hour period.\n\nNote: It can take up to 5 seconds after the stream is in an `ACTIVE` status\nbefore all records written to the stream are no longer subject to encryption.\nAfter you disabled encryption, you can verify that encryption is not applied by\ninspecting the API response from `PutRecord` or `PutRecords`.","ref":"AWS.Kinesis.html#stop_stream_encryption/3","title":"AWS.Kinesis.stop_stream_encryption/3","type":"function"},{"doc":"This operation establishes an HTTP/2 connection between the consumer you specify\nin the `ConsumerARN` parameter and the shard you specify in the `ShardId`\nparameter.\n\nAfter the connection is successfully established, Kinesis Data Streams pushes\nrecords from the shard to the consumer over this connection. Before you call\nthis operation, call `RegisterStreamConsumer` to register the consumer with\nKinesis Data Streams.\n\nWhen the `SubscribeToShard` call succeeds, your consumer starts receiving events\nof type `SubscribeToShardEvent` over the HTTP/2 connection for up to 5 minutes,\nafter which time you need to call `SubscribeToShard` again to renew the\nsubscription if you want to continue to receive records.\n\nYou can make one call to `SubscribeToShard` per second per registered consumer\nper shard. For example, if you have a 4000 shard stream and two registered\nstream consumers, you can make one `SubscribeToShard` request per second for\neach combination of shard and registered consumer, allowing you to subscribe\nboth consumers to all 4000 shards in one second.\n\nIf you call `SubscribeToShard` again with the same `ConsumerARN` and `ShardId`\nwithin 5 seconds of a successful call, you'll get a `ResourceInUseException`. If\nyou call `SubscribeToShard` 5 seconds or more after a successful call, the\nsecond call takes over the subscription and the previous connection expires or\nfails with a `ResourceInUseException`.\n\nFor an example of how to use this operations, see [Enhanced Fan-Out Using the Kinesis Data Streams\nAPI](/streams/latest/dev/building-enhanced-consumers-api.html).","ref":"AWS.Kinesis.html#subscribe_to_shard/3","title":"AWS.Kinesis.subscribe_to_shard/3","type":"function"},{"doc":"Updates the shard count of the specified stream to the specified number of\nshards.\n\nThis API is only supported for the data streams with the provisioned capacity\nmode.\n\nWhen invoking this API, you must use either the `StreamARN` or the `StreamName`\nparameter, or both. It is recommended that you use the `StreamARN` input\nparameter when you invoke this API.\n\nUpdating the shard count is an asynchronous operation. Upon receiving the\nrequest, Kinesis Data Streams returns immediately and sets the status of the\nstream to `UPDATING`. After the update is complete, Kinesis Data Streams sets\nthe status of the stream back to `ACTIVE`. Depending on the size of the stream,\nthe scaling action could take a few minutes to complete. You can continue to\nread and write data to your stream while its status is `UPDATING`.\n\nTo update the shard count, Kinesis Data Streams performs splits or merges on\nindividual shards. This can cause short-lived shards to be created, in addition\nto the final shards. These short-lived shards count towards your total shard\nlimit for your account in the Region.\n\nWhen using this operation, we recommend that you specify a target shard count\nthat is a multiple of 25% (25%, 50%, 75%, 100%). You can specify any target\nvalue within your shard limit. However, if you specify a target that isn't a\nmultiple of 25%, the scaling action might take longer to complete.\n\nThis operation has the following default limits. By default, you cannot do the\nfollowing:\n\n  * Scale more than ten times per rolling 24-hour period per stream\n\n  * Scale up to more than double your current shard count for a stream\n\n  * Scale down below half your current shard count for a stream\n\n  * Scale up to more than 10000 shards in a stream\n\n  * Scale a stream with more than 10000 shards down unless the result\nis less than 10000 shards\n\n  * Scale up to more than the shard limit for your account\n\n  * Make over 10 TPS. TPS over 10 will trigger the\nLimitExceededException\n\nFor the default limits for an Amazon Web Services account, see [Streams Limits](https://docs.aws.amazon.com/kinesis/latest/dev/service-sizes-and-limits.html)\nin the *Amazon Kinesis Data Streams Developer Guide*. To request an increase in\nthe call rate limit, the shard limit for this API, or your overall shard limit,\nuse the [limits form](https://console.aws.amazon.com/support/v1#/case/create?issueType=service-limit-increase&limitType=service-code-kinesis).","ref":"AWS.Kinesis.html#update_shard_count/3","title":"AWS.Kinesis.update_shard_count/3","type":"function"},{"doc":"Updates the capacity mode of the data stream.\n\nCurrently, in Kinesis Data Streams, you can choose between an","ref":"AWS.Kinesis.html#update_stream_mode/3","title":"AWS.Kinesis.update_stream_mode/3","type":"function"},{"doc":"capacity mode and a **provisioned** capacity mode for your data stream.","ref":"AWS.Kinesis.html#update_stream_mode/3-on-demand","title":"on-demand - AWS.Kinesis.update_stream_mode/3","type":"function"},{"doc":"Amazon Kinesis Analytics","ref":"AWS.KinesisAnalytics.html","title":"AWS.KinesisAnalytics","type":"module"},{"doc":"This documentation is for version 1 of the Amazon Kinesis Data Analytics API,\nwhich only supports SQL applications.\n\nVersion 2 of the API supports SQL and Java applications. For more information\nabout version 2, see [Amazon Kinesis Data Analytics API V2 Documentation](/kinesisanalytics/latest/apiv2/Welcome.html).\n\nThis is the *Amazon Kinesis Analytics v1 API Reference*. The Amazon Kinesis\nAnalytics Developer Guide provides additional information.","ref":"AWS.KinesisAnalytics.html#module-overview","title":"Overview - AWS.KinesisAnalytics","type":"module"},{"doc":"This documentation is for version 1 of the Amazon Kinesis Data Analytics API,\nwhich only supports SQL applications.\n\nVersion 2 of the API supports SQL and Java applications. For more information\nabout version 2, see [Amazon Kinesis Data Analytics API V2 Documentation](/kinesisanalytics/latest/apiv2/Welcome.html).\n\nAdds a CloudWatch log stream to monitor application configuration errors. For\nmore information about using CloudWatch log streams with Amazon Kinesis\nAnalytics applications, see [Working with Amazon CloudWatch Logs](https://docs.aws.amazon.com/kinesisanalytics/latest/dev/cloudwatch-logs.html).","ref":"AWS.KinesisAnalytics.html#add_application_cloud_watch_logging_option/3","title":"AWS.KinesisAnalytics.add_application_cloud_watch_logging_option/3","type":"function"},{"doc":"This documentation is for version 1 of the Amazon Kinesis Data Analytics API,\nwhich only supports SQL applications.\n\nVersion 2 of the API supports SQL and Java applications. For more information\nabout version 2, see [Amazon Kinesis Data Analytics API V2 Documentation](/kinesisanalytics/latest/apiv2/Welcome.html).\n\nAdds a streaming source to your Amazon Kinesis application. For conceptual\ninformation, see [Configuring Application Input](https://docs.aws.amazon.com/kinesisanalytics/latest/dev/how-it-works-input.html).\n\nYou can add a streaming source either when you create an application or you can\nuse this operation to add a streaming source after you create an application.\nFor more information, see\n[CreateApplication](https://docs.aws.amazon.com/kinesisanalytics/latest/dev/API_CreateApplication.html).  Any configuration update, including adding a streaming source using this\noperation, results in a new version of the application. You can use the\n[DescribeApplication](https://docs.aws.amazon.com/kinesisanalytics/latest/dev/API_DescribeApplication.html)\noperation to find the current application version.\n\nThis operation requires permissions to perform the\n`kinesisanalytics:AddApplicationInput` action.","ref":"AWS.KinesisAnalytics.html#add_application_input/3","title":"AWS.KinesisAnalytics.add_application_input/3","type":"function"},{"doc":"This documentation is for version 1 of the Amazon Kinesis Data Analytics API,\nwhich only supports SQL applications.\n\nVersion 2 of the API supports SQL and Java applications. For more information\nabout version 2, see [Amazon Kinesis Data Analytics API V2 Documentation](/kinesisanalytics/latest/apiv2/Welcome.html).\n\nAdds an\n[InputProcessingConfiguration](https://docs.aws.amazon.com/kinesisanalytics/latest/dev/API_InputProcessingConfiguration.html) to an application. An input processor preprocesses records on the input stream\nbefore the application's SQL code executes. Currently, the only input processor\navailable is [AWS Lambda](https://docs.aws.amazon.com/lambda/).","ref":"AWS.KinesisAnalytics.html#add_application_input_processing_configuration/3","title":"AWS.KinesisAnalytics.add_application_input_processing_configuration/3","type":"function"},{"doc":"This documentation is for version 1 of the Amazon Kinesis Data Analytics API,\nwhich only supports SQL applications.\n\nVersion 2 of the API supports SQL and Java applications. For more information\nabout version 2, see [Amazon Kinesis Data Analytics API V2 Documentation](/kinesisanalytics/latest/apiv2/Welcome.html).\n\nAdds an external destination to your Amazon Kinesis Analytics application.\n\nIf you want Amazon Kinesis Analytics to deliver data from an in-application\nstream within your application to an external destination (such as an Amazon\nKinesis stream, an Amazon Kinesis Firehose delivery stream, or an AWS Lambda\nfunction), you add the relevant configuration to your application using this\noperation. You can configure one or more outputs for your application. Each\noutput configuration maps an in-application stream and an external destination.\n\nYou can use one of the output configurations to deliver data from your\nin-application error stream to an external destination so that you can analyze\nthe errors. For more information, see [Understanding Application Output (Destination)](https://docs.aws.amazon.com/kinesisanalytics/latest/dev/how-it-works-output.html).\n\nAny configuration update, including adding a streaming source using this\noperation, results in a new version of the application. You can use the\n[DescribeApplication](https://docs.aws.amazon.com/kinesisanalytics/latest/dev/API_DescribeApplication.html) operation to find the current application version.\n\nFor the limits on the number of application inputs and outputs you can\nconfigure, see\n[Limits](https://docs.aws.amazon.com/kinesisanalytics/latest/dev/limits.html).\n\nThis operation requires permissions to perform the\n`kinesisanalytics:AddApplicationOutput` action.","ref":"AWS.KinesisAnalytics.html#add_application_output/3","title":"AWS.KinesisAnalytics.add_application_output/3","type":"function"},{"doc":"This documentation is for version 1 of the Amazon Kinesis Data Analytics API,\nwhich only supports SQL applications.\n\nVersion 2 of the API supports SQL and Java applications. For more information\nabout version 2, see [Amazon Kinesis Data Analytics API V2 Documentation](/kinesisanalytics/latest/apiv2/Welcome.html).\n\nAdds a reference data source to an existing application.\n\nAmazon Kinesis Analytics reads reference data (that is, an Amazon S3 object) and\ncreates an in-application table within your application. In the request, you\nprovide the source (S3 bucket name and object key name), name of the\nin-application table to create, and the necessary mapping information that\ndescribes how data in Amazon S3 object maps to columns in the resulting\nin-application table.\n\nFor conceptual information, see [Configuring Application Input](https://docs.aws.amazon.com/kinesisanalytics/latest/dev/how-it-works-input.html).\nFor the limits on data sources you can add to your application, see\n[Limits](https://docs.aws.amazon.com/kinesisanalytics/latest/dev/limits.html).\n\nThis operation requires permissions to perform the\n`kinesisanalytics:AddApplicationOutput` action.","ref":"AWS.KinesisAnalytics.html#add_application_reference_data_source/3","title":"AWS.KinesisAnalytics.add_application_reference_data_source/3","type":"function"},{"doc":"This documentation is for version 1 of the Amazon Kinesis Data Analytics API,\nwhich only supports SQL applications.\n\nVersion 2 of the API supports SQL and Java applications. For more information\nabout version 2, see [Amazon Kinesis Data Analytics API V2 Documentation](/kinesisanalytics/latest/apiv2/Welcome.html).\n\nCreates an Amazon Kinesis Analytics application. You can configure each\napplication with one streaming source as input, application code to process the\ninput, and up to three destinations where you want Amazon Kinesis Analytics to\nwrite the output data from your application. For an overview, see [How it Works](https://docs.aws.amazon.com/kinesisanalytics/latest/dev/how-it-works.html).\n\nIn the input configuration, you map the streaming source to an in-application\nstream, which you can think of as a constantly updating table. In the mapping,\nyou must provide a schema for the in-application stream and map each data column\nin the in-application stream to a data element in the streaming source.\n\nYour application code is one or more SQL statements that read input data,\ntransform it, and generate output. Your application code can create one or more\nSQL artifacts like SQL streams or pumps.\n\nIn the output configuration, you can configure the application to write data\nfrom in-application streams created in your applications to up to three\ndestinations.\n\nTo read data from your source stream or write data to destination streams,\nAmazon Kinesis Analytics needs your permissions. You grant these permissions by\ncreating IAM roles. This operation requires permissions to perform the\n`kinesisanalytics:CreateApplication` action.\n\nFor introductory exercises to create an Amazon Kinesis Analytics application,\nsee [Getting Started](https://docs.aws.amazon.com/kinesisanalytics/latest/dev/getting-started.html).","ref":"AWS.KinesisAnalytics.html#create_application/3","title":"AWS.KinesisAnalytics.create_application/3","type":"function"},{"doc":"This documentation is for version 1 of the Amazon Kinesis Data Analytics API,\nwhich only supports SQL applications.\n\nVersion 2 of the API supports SQL and Java applications. For more information\nabout version 2, see [Amazon Kinesis Data Analytics API V2 Documentation](/kinesisanalytics/latest/apiv2/Welcome.html).\n\nDeletes the specified application. Amazon Kinesis Analytics halts application\nexecution and deletes the application, including any application artifacts (such\nas in-application streams, reference table, and application code).\n\nThis operation requires permissions to perform the\n`kinesisanalytics:DeleteApplication` action.","ref":"AWS.KinesisAnalytics.html#delete_application/3","title":"AWS.KinesisAnalytics.delete_application/3","type":"function"},{"doc":"This documentation is for version 1 of the Amazon Kinesis Data Analytics API,\nwhich only supports SQL applications.\n\nVersion 2 of the API supports SQL and Java applications. For more information\nabout version 2, see [Amazon Kinesis Data Analytics API V2 Documentation](/kinesisanalytics/latest/apiv2/Welcome.html).\n\nDeletes a CloudWatch log stream from an application. For more information about\nusing CloudWatch log streams with Amazon Kinesis Analytics applications, see\n[Working with Amazon CloudWatch Logs](https://docs.aws.amazon.com/kinesisanalytics/latest/dev/cloudwatch-logs.html).","ref":"AWS.KinesisAnalytics.html#delete_application_cloud_watch_logging_option/3","title":"AWS.KinesisAnalytics.delete_application_cloud_watch_logging_option/3","type":"function"},{"doc":"This documentation is for version 1 of the Amazon Kinesis Data Analytics API,\nwhich only supports SQL applications.\n\nVersion 2 of the API supports SQL and Java applications. For more information\nabout version 2, see [Amazon Kinesis Data Analytics API V2 Documentation](/kinesisanalytics/latest/apiv2/Welcome.html).\n\nDeletes an\n[InputProcessingConfiguration](https://docs.aws.amazon.com/kinesisanalytics/latest/dev/API_InputProcessingConfiguration.html)\nfrom an input.","ref":"AWS.KinesisAnalytics.html#delete_application_input_processing_configuration/3","title":"AWS.KinesisAnalytics.delete_application_input_processing_configuration/3","type":"function"},{"doc":"This documentation is for version 1 of the Amazon Kinesis Data Analytics API,\nwhich only supports SQL applications.\n\nVersion 2 of the API supports SQL and Java applications. For more information\nabout version 2, see [Amazon Kinesis Data Analytics API V2 Documentation](/kinesisanalytics/latest/apiv2/Welcome.html).\n\nDeletes output destination configuration from your application configuration.\nAmazon Kinesis Analytics will no longer write data from the corresponding\nin-application stream to the external output destination.\n\nThis operation requires permissions to perform the\n`kinesisanalytics:DeleteApplicationOutput` action.","ref":"AWS.KinesisAnalytics.html#delete_application_output/3","title":"AWS.KinesisAnalytics.delete_application_output/3","type":"function"},{"doc":"This documentation is for version 1 of the Amazon Kinesis Data Analytics API,\nwhich only supports SQL applications.\n\nVersion 2 of the API supports SQL and Java applications. For more information\nabout version 2, see [Amazon Kinesis Data Analytics API V2 Documentation](/kinesisanalytics/latest/apiv2/Welcome.html).\n\nDeletes a reference data source configuration from the specified application\nconfiguration.\n\nIf the application is running, Amazon Kinesis Analytics immediately removes the\nin-application table that you created using the\n[AddApplicationReferenceDataSource](https://docs.aws.amazon.com/kinesisanalytics/latest/dev/API_AddApplicationReferenceDataSource.html)\noperation.\n\nThis operation requires permissions to perform the\n`kinesisanalytics.DeleteApplicationReferenceDataSource` action.","ref":"AWS.KinesisAnalytics.html#delete_application_reference_data_source/3","title":"AWS.KinesisAnalytics.delete_application_reference_data_source/3","type":"function"},{"doc":"This documentation is for version 1 of the Amazon Kinesis Data Analytics API,\nwhich only supports SQL applications.\n\nVersion 2 of the API supports SQL and Java applications. For more information\nabout version 2, see [Amazon Kinesis Data Analytics API V2 Documentation](/kinesisanalytics/latest/apiv2/Welcome.html).\n\nReturns information about a specific Amazon Kinesis Analytics application.\n\nIf you want to retrieve a list of all applications in your account, use the\n[ListApplications](https://docs.aws.amazon.com/kinesisanalytics/latest/dev/API_ListApplications.html)\noperation.\n\nThis operation requires permissions to perform the\n`kinesisanalytics:DescribeApplication` action. You can use `DescribeApplication`\nto get the current application versionId, which you need to call other\noperations such as `Update`.","ref":"AWS.KinesisAnalytics.html#describe_application/3","title":"AWS.KinesisAnalytics.describe_application/3","type":"function"},{"doc":"This documentation is for version 1 of the Amazon Kinesis Data Analytics API,\nwhich only supports SQL applications.\n\nVersion 2 of the API supports SQL and Java applications. For more information\nabout version 2, see [Amazon Kinesis Data Analytics API V2 Documentation](/kinesisanalytics/latest/apiv2/Welcome.html).\n\nInfers a schema by evaluating sample records on the specified streaming source\n(Amazon Kinesis stream or Amazon Kinesis Firehose delivery stream) or S3 object.\nIn the response, the operation returns the inferred schema and also the sample\nrecords that the operation used to infer the schema.\n\nYou can use the inferred schema when configuring a streaming source for your\napplication. For conceptual information, see [Configuring Application Input](https://docs.aws.amazon.com/kinesisanalytics/latest/dev/how-it-works-input.html).\nNote that when you create an application using the Amazon Kinesis Analytics\nconsole, the console uses this operation to infer a schema and show it in the\nconsole user interface.\n\nThis operation requires permissions to perform the\n`kinesisanalytics:DiscoverInputSchema` action.","ref":"AWS.KinesisAnalytics.html#discover_input_schema/3","title":"AWS.KinesisAnalytics.discover_input_schema/3","type":"function"},{"doc":"This documentation is for version 1 of the Amazon Kinesis Data Analytics API,\nwhich only supports SQL applications.\n\nVersion 2 of the API supports SQL and Java applications. For more information\nabout version 2, see [Amazon Kinesis Data Analytics API V2 Documentation](/kinesisanalytics/latest/apiv2/Welcome.html).\n\nReturns a list of Amazon Kinesis Analytics applications in your account. For\neach application, the response includes the application name, Amazon Resource\nName (ARN), and status. If the response returns the `HasMoreApplications` value\nas true, you can send another request by adding the\n`ExclusiveStartApplicationName` in the request body, and set the value of this\nto the last application name from the previous response.\n\nIf you want detailed information about a specific application, use\n[DescribeApplication](https://docs.aws.amazon.com/kinesisanalytics/latest/dev/API_DescribeApplication.html).\n\nThis operation requires permissions to perform the\n`kinesisanalytics:ListApplications` action.","ref":"AWS.KinesisAnalytics.html#list_applications/3","title":"AWS.KinesisAnalytics.list_applications/3","type":"function"},{"doc":"Retrieves the list of key-value tags assigned to the application.\n\nFor more information, see [Using Tagging](https://docs.aws.amazon.com/kinesisanalytics/latest/dev/how-tagging.html).","ref":"AWS.KinesisAnalytics.html#list_tags_for_resource/3","title":"AWS.KinesisAnalytics.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.KinesisAnalytics.html#metadata/0","title":"AWS.KinesisAnalytics.metadata/0","type":"function"},{"doc":"This documentation is for version 1 of the Amazon Kinesis Data Analytics API,\nwhich only supports SQL applications.\n\nVersion 2 of the API supports SQL and Java applications. For more information\nabout version 2, see [Amazon Kinesis Data Analytics API V2 Documentation](/kinesisanalytics/latest/apiv2/Welcome.html).\n\nStarts the specified Amazon Kinesis Analytics application. After creating an\napplication, you must exclusively call this operation to start your application.\n\nAfter the application starts, it begins consuming the input data, processes it,\nand writes the output to the configured destination.\n\nThe application status must be `READY` for you to start an application. You can\nget the application status in the console or using the\n[DescribeApplication](https://docs.aws.amazon.com/kinesisanalytics/latest/dev/API_DescribeApplication.html) operation.\n\nAfter you start the application, you can stop the application from processing\nthe input by calling the\n[StopApplication](https://docs.aws.amazon.com/kinesisanalytics/latest/dev/API_StopApplication.html)\noperation.\n\nThis operation requires permissions to perform the\n`kinesisanalytics:StartApplication` action.","ref":"AWS.KinesisAnalytics.html#start_application/3","title":"AWS.KinesisAnalytics.start_application/3","type":"function"},{"doc":"This documentation is for version 1 of the Amazon Kinesis Data Analytics API,\nwhich only supports SQL applications.\n\nVersion 2 of the API supports SQL and Java applications. For more information\nabout version 2, see [Amazon Kinesis Data Analytics API V2 Documentation](/kinesisanalytics/latest/apiv2/Welcome.html).\n\nStops the application from processing input data. You can stop an application\nonly if it is in the running state. You can use the\n[DescribeApplication](https://docs.aws.amazon.com/kinesisanalytics/latest/dev/API_DescribeApplication.html)\noperation to find the application state. After the application is stopped,\nAmazon Kinesis Analytics stops reading data from the input, the application\nstops processing data, and there is no output written to the destination.\n\nThis operation requires permissions to perform the\n`kinesisanalytics:StopApplication` action.","ref":"AWS.KinesisAnalytics.html#stop_application/3","title":"AWS.KinesisAnalytics.stop_application/3","type":"function"},{"doc":"Adds one or more key-value tags to a Kinesis Analytics application.\n\nNote that the maximum number of application tags includes system tags. The\nmaximum number of user-defined application tags is 50. For more information, see\n[Using Tagging](https://docs.aws.amazon.com/kinesisanalytics/latest/dev/how-tagging.html).","ref":"AWS.KinesisAnalytics.html#tag_resource/3","title":"AWS.KinesisAnalytics.tag_resource/3","type":"function"},{"doc":"Removes one or more tags from a Kinesis Analytics application.\n\nFor more information, see [Using Tagging](https://docs.aws.amazon.com/kinesisanalytics/latest/dev/how-tagging.html).","ref":"AWS.KinesisAnalytics.html#untag_resource/3","title":"AWS.KinesisAnalytics.untag_resource/3","type":"function"},{"doc":"This documentation is for version 1 of the Amazon Kinesis Data Analytics API,\nwhich only supports SQL applications.\n\nVersion 2 of the API supports SQL and Java applications. For more information\nabout version 2, see [Amazon Kinesis Data Analytics API V2 Documentation](/kinesisanalytics/latest/apiv2/Welcome.html).\n\nUpdates an existing Amazon Kinesis Analytics application. Using this API, you\ncan update application code, input configuration, and output configuration.\n\nNote that Amazon Kinesis Analytics updates the `CurrentApplicationVersionId`\neach time you update your application.\n\nThis operation requires permission for the `kinesisanalytics:UpdateApplication`\naction.","ref":"AWS.KinesisAnalytics.html#update_application/3","title":"AWS.KinesisAnalytics.update_application/3","type":"function"},{"doc":"Amazon Kinesis Data Analytics is a fully managed service that you can use to\nprocess and analyze streaming data using Java, SQL, or Scala.\n\nThe service enables you to quickly author and run Java, SQL, or Scala code\nagainst streaming sources to perform time series analytics, feed real-time\ndashboards, and create real-time metrics.","ref":"AWS.KinesisAnalyticsV2.html","title":"AWS.KinesisAnalyticsV2","type":"module"},{"doc":"Adds an Amazon CloudWatch log stream to monitor application configuration\nerrors.","ref":"AWS.KinesisAnalyticsV2.html#add_application_cloud_watch_logging_option/3","title":"AWS.KinesisAnalyticsV2.add_application_cloud_watch_logging_option/3","type":"function"},{"doc":"Adds a streaming source to your SQL-based Kinesis Data Analytics application.\n\nYou can add a streaming source when you create an application, or you can use\nthis operation to add a streaming source after you create an application. For\nmore information, see `CreateApplication`.\n\nAny configuration update, including adding a streaming source using this\noperation, results in a new version of the application. You can use the\n`DescribeApplication` operation to find the current application version.","ref":"AWS.KinesisAnalyticsV2.html#add_application_input/3","title":"AWS.KinesisAnalyticsV2.add_application_input/3","type":"function"},{"doc":"Adds an `InputProcessingConfiguration` to a SQL-based Kinesis Data Analytics\napplication.\n\nAn input processor pre-processes records on the input stream before the\napplication's SQL code executes. Currently, the only input processor available\nis [Amazon Lambda](https://docs.aws.amazon.com/lambda/).","ref":"AWS.KinesisAnalyticsV2.html#add_application_input_processing_configuration/3","title":"AWS.KinesisAnalyticsV2.add_application_input_processing_configuration/3","type":"function"},{"doc":"Adds an external destination to your SQL-based Kinesis Data Analytics\napplication.\n\nIf you want Kinesis Data Analytics to deliver data from an in-application stream\nwithin your application to an external destination (such as an Kinesis data\nstream, a Kinesis Data Firehose delivery stream, or an Amazon Lambda function),\nyou add the relevant configuration to your application using this operation. You\ncan configure one or more outputs for your application. Each output\nconfiguration maps an in-application stream and an external destination.\n\nYou can use one of the output configurations to deliver data from your\nin-application error stream to an external destination so that you can analyze\nthe errors.\n\nAny configuration update, including adding a streaming source using this\noperation, results in a new version of the application. You can use the\n`DescribeApplication` operation to find the current application version.","ref":"AWS.KinesisAnalyticsV2.html#add_application_output/3","title":"AWS.KinesisAnalyticsV2.add_application_output/3","type":"function"},{"doc":"Adds a reference data source to an existing SQL-based Kinesis Data Analytics\napplication.\n\nKinesis Data Analytics reads reference data (that is, an Amazon S3 object) and\ncreates an in-application table within your application. In the request, you\nprovide the source (S3 bucket name and object key name), name of the\nin-application table to create, and the necessary mapping information that\ndescribes how data in an Amazon S3 object maps to columns in the resulting\nin-application table.","ref":"AWS.KinesisAnalyticsV2.html#add_application_reference_data_source/3","title":"AWS.KinesisAnalyticsV2.add_application_reference_data_source/3","type":"function"},{"doc":"Adds a Virtual Private Cloud (VPC) configuration to the application.\n\nApplications can use VPCs to store and access resources securely.\n\nNote the following about VPC configurations for Kinesis Data Analytics\napplications:\n\n  * VPC configurations are not supported for SQL applications.\n\n  * When a VPC is added to a Kinesis Data Analytics application, the\napplication can no longer be accessed from the Internet directly. To enable\nInternet access to the application, add an Internet gateway to your VPC.","ref":"AWS.KinesisAnalyticsV2.html#add_application_vpc_configuration/3","title":"AWS.KinesisAnalyticsV2.add_application_vpc_configuration/3","type":"function"},{"doc":"Creates a Kinesis Data Analytics application.\n\nFor information about creating a Kinesis Data Analytics application, see\n[Creating an Application](https://docs.aws.amazon.com/kinesisanalytics/latest/java/getting-started.html).","ref":"AWS.KinesisAnalyticsV2.html#create_application/3","title":"AWS.KinesisAnalyticsV2.create_application/3","type":"function"},{"doc":"Creates and returns a URL that you can use to connect to an application's\nextension.\n\nThe IAM role or user used to call this API defines the permissions to access the\nextension. After the presigned URL is created, no additional permission is\nrequired to access this URL. IAM authorization policies for this API are also\nenforced for every HTTP request that attempts to connect to the extension.\n\nYou control the amount of time that the URL will be valid using the\n`SessionExpirationDurationInSeconds` parameter. If you do not provide this\nparameter, the returned URL is valid for twelve hours.\n\nThe URL that you get from a call to CreateApplicationPresignedUrl must be used\nwithin 3 minutes to be valid. If you first try to use the URL after the 3-minute\nlimit expires, the service returns an HTTP 403 Forbidden error.","ref":"AWS.KinesisAnalyticsV2.html#create_application_presigned_url/3","title":"AWS.KinesisAnalyticsV2.create_application_presigned_url/3","type":"function"},{"doc":"Creates a snapshot of the application's state data.","ref":"AWS.KinesisAnalyticsV2.html#create_application_snapshot/3","title":"AWS.KinesisAnalyticsV2.create_application_snapshot/3","type":"function"},{"doc":"Deletes the specified application.\n\nKinesis Data Analytics halts application execution and deletes the application.","ref":"AWS.KinesisAnalyticsV2.html#delete_application/3","title":"AWS.KinesisAnalyticsV2.delete_application/3","type":"function"},{"doc":"Deletes an Amazon CloudWatch log stream from an Kinesis Data Analytics\napplication.","ref":"AWS.KinesisAnalyticsV2.html#delete_application_cloud_watch_logging_option/3","title":"AWS.KinesisAnalyticsV2.delete_application_cloud_watch_logging_option/3","type":"function"},{"doc":"Deletes an `InputProcessingConfiguration` from an input.","ref":"AWS.KinesisAnalyticsV2.html#delete_application_input_processing_configuration/3","title":"AWS.KinesisAnalyticsV2.delete_application_input_processing_configuration/3","type":"function"},{"doc":"Deletes the output destination configuration from your SQL-based Kinesis Data\nAnalytics application's configuration.\n\nKinesis Data Analytics will no longer write data from the corresponding\nin-application stream to the external output destination.","ref":"AWS.KinesisAnalyticsV2.html#delete_application_output/3","title":"AWS.KinesisAnalyticsV2.delete_application_output/3","type":"function"},{"doc":"Deletes a reference data source configuration from the specified SQL-based\nKinesis Data Analytics application's configuration.\n\nIf the application is running, Kinesis Data Analytics immediately removes the\nin-application table that you created using the\n`AddApplicationReferenceDataSource` operation.","ref":"AWS.KinesisAnalyticsV2.html#delete_application_reference_data_source/3","title":"AWS.KinesisAnalyticsV2.delete_application_reference_data_source/3","type":"function"},{"doc":"Deletes a snapshot of application state.","ref":"AWS.KinesisAnalyticsV2.html#delete_application_snapshot/3","title":"AWS.KinesisAnalyticsV2.delete_application_snapshot/3","type":"function"},{"doc":"Removes a VPC configuration from a Kinesis Data Analytics application.","ref":"AWS.KinesisAnalyticsV2.html#delete_application_vpc_configuration/3","title":"AWS.KinesisAnalyticsV2.delete_application_vpc_configuration/3","type":"function"},{"doc":"Returns information about a specific Kinesis Data Analytics application.\n\nIf you want to retrieve a list of all applications in your account, use the\n`ListApplications` operation.","ref":"AWS.KinesisAnalyticsV2.html#describe_application/3","title":"AWS.KinesisAnalyticsV2.describe_application/3","type":"function"},{"doc":"Returns information about a snapshot of application state data.","ref":"AWS.KinesisAnalyticsV2.html#describe_application_snapshot/3","title":"AWS.KinesisAnalyticsV2.describe_application_snapshot/3","type":"function"},{"doc":"Provides a detailed description of a specified version of the application.\n\nTo see a list of all the versions of an application, invoke the\n`ListApplicationVersions` operation.\n\nThis operation is supported only for Amazon Kinesis Data Analytics for Apache\nFlink.","ref":"AWS.KinesisAnalyticsV2.html#describe_application_version/3","title":"AWS.KinesisAnalyticsV2.describe_application_version/3","type":"function"},{"doc":"Infers a schema for a SQL-based Kinesis Data Analytics application by evaluating\nsample records on the specified streaming source (Kinesis data stream or Kinesis\nData Firehose delivery stream) or Amazon S3 object.\n\nIn the response, the operation returns the inferred schema and also the sample\nrecords that the operation used to infer the schema.\n\nYou can use the inferred schema when configuring a streaming source for your\napplication. When you create an application using the Kinesis Data Analytics\nconsole, the console uses this operation to infer a schema and show it in the\nconsole user interface.","ref":"AWS.KinesisAnalyticsV2.html#discover_input_schema/3","title":"AWS.KinesisAnalyticsV2.discover_input_schema/3","type":"function"},{"doc":"Lists information about the current application snapshots.","ref":"AWS.KinesisAnalyticsV2.html#list_application_snapshots/3","title":"AWS.KinesisAnalyticsV2.list_application_snapshots/3","type":"function"},{"doc":"Lists all the versions for the specified application, including versions that\nwere rolled back.\n\nThe response also includes a summary of the configuration associated with each\nversion.\n\nTo get the complete description of a specific application version, invoke the\n`DescribeApplicationVersion` operation.\n\nThis operation is supported only for Amazon Kinesis Data Analytics for Apache\nFlink.","ref":"AWS.KinesisAnalyticsV2.html#list_application_versions/3","title":"AWS.KinesisAnalyticsV2.list_application_versions/3","type":"function"},{"doc":"Returns a list of Kinesis Data Analytics applications in your account.\n\nFor each application, the response includes the application name, Amazon\nResource Name (ARN), and status.\n\nIf you want detailed information about a specific application, use\n`DescribeApplication`.","ref":"AWS.KinesisAnalyticsV2.html#list_applications/3","title":"AWS.KinesisAnalyticsV2.list_applications/3","type":"function"},{"doc":"Retrieves the list of key-value tags assigned to the application.\n\nFor more information, see [Using Tagging](https://docs.aws.amazon.com/kinesisanalytics/latest/java/how-tagging.html).","ref":"AWS.KinesisAnalyticsV2.html#list_tags_for_resource/3","title":"AWS.KinesisAnalyticsV2.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.KinesisAnalyticsV2.html#metadata/0","title":"AWS.KinesisAnalyticsV2.metadata/0","type":"function"},{"doc":"Reverts the application to the previous running version.\n\nYou can roll back an application if you suspect it is stuck in a transient\nstatus.\n\nYou can roll back an application only if it is in the `UPDATING` or\n`AUTOSCALING` status.\n\nWhen you rollback an application, it loads state data from the last successful\nsnapshot. If the application has no snapshots, Kinesis Data Analytics rejects\nthe rollback request.\n\nThis action is not supported for Kinesis Data Analytics for SQL applications.","ref":"AWS.KinesisAnalyticsV2.html#rollback_application/3","title":"AWS.KinesisAnalyticsV2.rollback_application/3","type":"function"},{"doc":"Starts the specified Kinesis Data Analytics application.\n\nAfter creating an application, you must exclusively call this operation to start\nyour application.","ref":"AWS.KinesisAnalyticsV2.html#start_application/3","title":"AWS.KinesisAnalyticsV2.start_application/3","type":"function"},{"doc":"Stops the application from processing data.\n\nYou can stop an application only if it is in the running status, unless you set\nthe `Force` parameter to `true`.\n\nYou can use the `DescribeApplication` operation to find the application status.\n\nKinesis Data Analytics takes a snapshot when the application is stopped, unless\n`Force` is set to `true`.","ref":"AWS.KinesisAnalyticsV2.html#stop_application/3","title":"AWS.KinesisAnalyticsV2.stop_application/3","type":"function"},{"doc":"Adds one or more key-value tags to a Kinesis Data Analytics application.\n\nNote that the maximum number of application tags includes system tags. The\nmaximum number of user-defined application tags is 50. For more information, see\n[Using Tagging](https://docs.aws.amazon.com/kinesisanalytics/latest/java/how-tagging.html).","ref":"AWS.KinesisAnalyticsV2.html#tag_resource/3","title":"AWS.KinesisAnalyticsV2.tag_resource/3","type":"function"},{"doc":"Removes one or more tags from a Kinesis Data Analytics application.\n\nFor more information, see [Using Tagging](https://docs.aws.amazon.com/kinesisanalytics/latest/java/how-tagging.html).","ref":"AWS.KinesisAnalyticsV2.html#untag_resource/3","title":"AWS.KinesisAnalyticsV2.untag_resource/3","type":"function"},{"doc":"Updates an existing Kinesis Data Analytics application.\n\nUsing this operation, you can update application code, input configuration, and\noutput configuration.\n\nKinesis Data Analytics updates the `ApplicationVersionId` each time you update\nyour application.\n\nYou cannot update the `RuntimeEnvironment` of an existing application. If you\nneed to update an application's `RuntimeEnvironment`, you must delete the\napplication and create it again.","ref":"AWS.KinesisAnalyticsV2.html#update_application/3","title":"AWS.KinesisAnalyticsV2.update_application/3","type":"function"},{"doc":"Updates the maintenance configuration of the Kinesis Data Analytics application.\n\nYou can invoke this operation on an application that is in one of the two\nfollowing states: `READY` or `RUNNING`. If you invoke it when the application is\nin a state other than these two states, it throws a `ResourceInUseException`.\nThe service makes use of the updated configuration the next time it schedules\nmaintenance for the application. If you invoke this operation after the service\nschedules maintenance, the service will apply the configuration update the next\ntime it schedules maintenance for the application. This means that you might not\nsee the maintenance configuration update applied to the maintenance process that\nfollows a successful invocation of this operation, but to the following\nmaintenance process instead.\n\nTo see the current maintenance configuration of your application, invoke the\n`DescribeApplication` operation.\n\nFor information about application maintenance, see [Kinesis Data Analytics for Apache Flink\nMaintenance](https://docs.aws.amazon.com/kinesisanalytics/latest/java/maintenance.html).\n\nThis operation is supported only for Amazon Kinesis Data Analytics for Apache\nFlink.","ref":"AWS.KinesisAnalyticsV2.html#update_application_maintenance_configuration/3","title":"AWS.KinesisAnalyticsV2.update_application_maintenance_configuration/3","type":"function"},{"doc":"","ref":"AWS.KinesisVideo.html","title":"AWS.KinesisVideo","type":"module"},{"doc":"Creates a signaling channel.\n\n`CreateSignalingChannel` is an asynchronous operation.","ref":"AWS.KinesisVideo.html#create_signaling_channel/3","title":"AWS.KinesisVideo.create_signaling_channel/3","type":"function"},{"doc":"Creates a new Kinesis video stream.\n\nWhen you create a new stream, Kinesis Video Streams assigns it a version number.\nWhen you change the stream's metadata, Kinesis Video Streams updates the\nversion.\n\n`CreateStream` is an asynchronous operation.\n\nFor information about how the service works, see [How it Works](https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/how-it-works.html).\n\nYou must have permissions for the `KinesisVideo:CreateStream` action.","ref":"AWS.KinesisVideo.html#create_stream/3","title":"AWS.KinesisVideo.create_stream/3","type":"function"},{"doc":"An asynchronous API that deletes a stream’s existing edge configuration, as well\nas the corresponding media from the Edge Agent.\n\nWhen you invoke this API, the sync status is set to `DELETING`. A deletion\nprocess starts, in which active edge jobs are stopped and all media is deleted\nfrom the edge device. The time to delete varies, depending on the total amount\nof stored media. If the deletion process fails, the sync status changes to\n`DELETE_FAILED`. You will need to re-try the deletion.\n\nWhen the deletion process has completed successfully, the edge configuration is\nno longer accessible.","ref":"AWS.KinesisVideo.html#delete_edge_configuration/3","title":"AWS.KinesisVideo.delete_edge_configuration/3","type":"function"},{"doc":"Deletes a specified signaling channel.\n\n`DeleteSignalingChannel` is an asynchronous operation. If you don't specify the\nchannel's current version, the most recent version is deleted.","ref":"AWS.KinesisVideo.html#delete_signaling_channel/3","title":"AWS.KinesisVideo.delete_signaling_channel/3","type":"function"},{"doc":"Deletes a Kinesis video stream and the data contained in the stream.\n\nThis method marks the stream for deletion, and makes the data in the stream\ninaccessible immediately.\n\nTo ensure that you have the latest version of the stream before deleting it, you\ncan specify the stream version. Kinesis Video Streams assigns a version to each\nstream. When you update a stream, Kinesis Video Streams assigns a new version\nnumber. To get the latest stream version, use the `DescribeStream` API.\n\nThis operation requires permission for the `KinesisVideo:DeleteStream` action.","ref":"AWS.KinesisVideo.html#delete_stream/3","title":"AWS.KinesisVideo.delete_stream/3","type":"function"},{"doc":"Describes a stream’s edge configuration that was set using the\n`StartEdgeConfigurationUpdate` API and the latest status of the edge agent's\nrecorder and uploader jobs.\n\nUse this API to get the status of the configuration to determine if the\nconfiguration is in sync with the Edge Agent. Use this API to evaluate the\nhealth of the Edge Agent.","ref":"AWS.KinesisVideo.html#describe_edge_configuration/3","title":"AWS.KinesisVideo.describe_edge_configuration/3","type":"function"},{"doc":"Gets the `ImageGenerationConfiguration` for a given Kinesis video stream.","ref":"AWS.KinesisVideo.html#describe_image_generation_configuration/3","title":"AWS.KinesisVideo.describe_image_generation_configuration/3","type":"function"},{"doc":"Returns the most current information about the stream.\n\nThe `streamName` or `streamARN` should be provided in the input.","ref":"AWS.KinesisVideo.html#describe_mapped_resource_configuration/3","title":"AWS.KinesisVideo.describe_mapped_resource_configuration/3","type":"function"},{"doc":"Returns the most current information about the channel.\n\nSpecify the `ChannelName` or `ChannelARN` in the input.","ref":"AWS.KinesisVideo.html#describe_media_storage_configuration/3","title":"AWS.KinesisVideo.describe_media_storage_configuration/3","type":"function"},{"doc":"Gets the `NotificationConfiguration` for a given Kinesis video stream.","ref":"AWS.KinesisVideo.html#describe_notification_configuration/3","title":"AWS.KinesisVideo.describe_notification_configuration/3","type":"function"},{"doc":"Returns the most current information about the signaling channel.\n\nYou must specify either the name or the Amazon Resource Name (ARN) of the\nchannel that you want to describe.","ref":"AWS.KinesisVideo.html#describe_signaling_channel/3","title":"AWS.KinesisVideo.describe_signaling_channel/3","type":"function"},{"doc":"Returns the most current information about the specified stream.\n\nYou must specify either the `StreamName` or the `StreamARN`.","ref":"AWS.KinesisVideo.html#describe_stream/3","title":"AWS.KinesisVideo.describe_stream/3","type":"function"},{"doc":"Gets an endpoint for a specified stream for either reading or writing.\n\nUse this endpoint in your application to read from the specified stream (using\nthe `GetMedia` or `GetMediaForFragmentList` operations) or write to it (using\nthe `PutMedia` operation).\n\nThe returned endpoint does not have the API name appended. The client needs to\nadd the API name to the returned endpoint.\n\nIn the request, specify the stream either by `StreamName` or `StreamARN`.","ref":"AWS.KinesisVideo.html#get_data_endpoint/3","title":"AWS.KinesisVideo.get_data_endpoint/3","type":"function"},{"doc":"Provides an endpoint for the specified signaling channel to send and receive\nmessages.\n\nThis API uses the `SingleMasterChannelEndpointConfiguration` input parameter,\nwhich consists of the `Protocols` and `Role` properties.\n\n`Protocols` is used to determine the communication mechanism. For example, if\nyou specify `WSS` as the protocol, this API produces a secure websocket\nendpoint. If you specify `HTTPS` as the protocol, this API generates an HTTPS\nendpoint.\n\n`Role` determines the messaging permissions. A `MASTER` role results in this API\ngenerating an endpoint that a client can use to communicate with any of the\nviewers on the channel. A `VIEWER` role results in this API generating an\nendpoint that a client can use to communicate only with a `MASTER`.","ref":"AWS.KinesisVideo.html#get_signaling_channel_endpoint/3","title":"AWS.KinesisVideo.get_signaling_channel_endpoint/3","type":"function"},{"doc":"Returns an array of edge configurations associated with the specified Edge\nAgent.\n\nIn the request, you must specify the Edge Agent `HubDeviceArn`.","ref":"AWS.KinesisVideo.html#list_edge_agent_configurations/3","title":"AWS.KinesisVideo.list_edge_agent_configurations/3","type":"function"},{"doc":"Returns an array of `ChannelInfo` objects.\n\nEach object describes a signaling channel. To retrieve only those channels that\nsatisfy a specific condition, you can specify a `ChannelNameCondition`.","ref":"AWS.KinesisVideo.html#list_signaling_channels/3","title":"AWS.KinesisVideo.list_signaling_channels/3","type":"function"},{"doc":"Returns an array of `StreamInfo` objects.\n\nEach object describes a stream. To retrieve only streams that satisfy a specific\ncondition, you can specify a `StreamNameCondition`.","ref":"AWS.KinesisVideo.html#list_streams/3","title":"AWS.KinesisVideo.list_streams/3","type":"function"},{"doc":"Returns a list of tags associated with the specified signaling channel.","ref":"AWS.KinesisVideo.html#list_tags_for_resource/3","title":"AWS.KinesisVideo.list_tags_for_resource/3","type":"function"},{"doc":"Returns a list of tags associated with the specified stream.\n\nIn the request, you must specify either the `StreamName` or the `StreamARN`.","ref":"AWS.KinesisVideo.html#list_tags_for_stream/3","title":"AWS.KinesisVideo.list_tags_for_stream/3","type":"function"},{"doc":"","ref":"AWS.KinesisVideo.html#metadata/0","title":"AWS.KinesisVideo.metadata/0","type":"function"},{"doc":"An asynchronous API that updates a stream’s existing edge configuration.\n\nThe Kinesis Video Stream will sync the stream’s edge configuration with the Edge\nAgent IoT Greengrass component that runs on an IoT Hub Device, setup at your\npremise. The time to sync can vary and depends on the connectivity of the Hub\nDevice. The `SyncStatus` will be updated as the edge configuration is\nacknowledged, and synced with the Edge Agent.\n\nIf this API is invoked for the first time, a new edge configuration will be\ncreated for the stream, and the sync status will be set to `SYNCING`. You will\nhave to wait for the sync status to reach a terminal state such as: `IN_SYNC`,\nor `SYNC_FAILED`, before using this API again. If you invoke this API during the\nsyncing process, a `ResourceInUseException` will be thrown. The connectivity of\nthe stream’s edge configuration and the Edge Agent will be retried for 15\nminutes. After 15 minutes, the status will transition into the `SYNC_FAILED`\nstate.\n\nTo move an edge configuration from one device to another, use\n`DeleteEdgeConfiguration` to delete the current edge configuration. You can then\ninvoke StartEdgeConfigurationUpdate with an updated Hub Device ARN.","ref":"AWS.KinesisVideo.html#start_edge_configuration_update/3","title":"AWS.KinesisVideo.start_edge_configuration_update/3","type":"function"},{"doc":"Adds one or more tags to a signaling channel.\n\nA *tag* is a key-value pair (the value is optional) that you can define and\nassign to Amazon Web Services resources. If you specify a tag that already\nexists, the tag value is replaced with the value that you specify in the\nrequest. For more information, see [Using Cost Allocation Tags](https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/cost-alloc-tags.html)\nin the *Billing and Cost Management and Cost Management User Guide*.","ref":"AWS.KinesisVideo.html#tag_resource/3","title":"AWS.KinesisVideo.tag_resource/3","type":"function"},{"doc":"Adds one or more tags to a stream.\n\nA *tag* is a key-value pair (the value is optional) that you can define and\nassign to Amazon Web Services resources. If you specify a tag that already\nexists, the tag value is replaced with the value that you specify in the\nrequest. For more information, see [Using Cost Allocation Tags](https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/cost-alloc-tags.html)\nin the *Billing and Cost Management and Cost Management User Guide*.\n\nYou must provide either the `StreamName` or the `StreamARN`.\n\nThis operation requires permission for the `KinesisVideo:TagStream` action.\n\nA Kinesis video stream can support up to 50 tags.","ref":"AWS.KinesisVideo.html#tag_stream/3","title":"AWS.KinesisVideo.tag_stream/3","type":"function"},{"doc":"Removes one or more tags from a signaling channel.\n\nIn the request, specify only a tag key or keys; don't specify the value. If you\nspecify a tag key that does not exist, it's ignored.","ref":"AWS.KinesisVideo.html#untag_resource/3","title":"AWS.KinesisVideo.untag_resource/3","type":"function"},{"doc":"Removes one or more tags from a stream.\n\nIn the request, specify only a tag key or keys; don't specify the value. If you\nspecify a tag key that does not exist, it's ignored.\n\nIn the request, you must provide the `StreamName` or `StreamARN`.","ref":"AWS.KinesisVideo.html#untag_stream/3","title":"AWS.KinesisVideo.untag_stream/3","type":"function"},{"doc":"Increases or decreases the stream's data retention period by the value that you\nspecify.\n\nTo indicate whether you want to increase or decrease the data retention period,\nspecify the `Operation` parameter in the request body. In the request, you must\nspecify either the `StreamName` or the `StreamARN`.\n\nThis operation requires permission for the `KinesisVideo:UpdateDataRetention`\naction.\n\nChanging the data retention period affects the data in the stream as follows:\n\n  * If the data retention period is increased, existing data is\nretained for the new retention period. For example, if the data retention period\nis increased from one hour to seven hours, all existing data is retained for\nseven hours.\n\n  * If the data retention period is decreased, existing data is\nretained for the new retention period. For example, if the data retention period\nis decreased from seven hours to one hour, all existing data is retained for one\nhour, and any data older than one hour is deleted immediately.","ref":"AWS.KinesisVideo.html#update_data_retention/3","title":"AWS.KinesisVideo.update_data_retention/3","type":"function"},{"doc":"Updates the `StreamInfo` and `ImageProcessingConfiguration` fields.","ref":"AWS.KinesisVideo.html#update_image_generation_configuration/3","title":"AWS.KinesisVideo.update_image_generation_configuration/3","type":"function"},{"doc":"Associates a `SignalingChannel` to a stream to store the media.\n\nThere are two signaling modes that you can specify :\n\n  * If `StorageStatus` is enabled, the data will be stored in the\n`StreamARN` provided. In order for WebRTC Ingestion to work, the stream must\nhave data retention enabled.\n\n  * If `StorageStatus` is disabled, no data will be stored, and the\n`StreamARN` parameter will not be needed.\n\nIf `StorageStatus` is enabled, direct peer-to-peer (master-viewer) connections\nno longer occur. Peers connect directly to the storage session. You must call\nthe `JoinStorageSession` API to trigger an SDP offer send and establish a\nconnection between a peer and the storage session.","ref":"AWS.KinesisVideo.html#update_media_storage_configuration/3","title":"AWS.KinesisVideo.update_media_storage_configuration/3","type":"function"},{"doc":"Updates the notification information for a stream.","ref":"AWS.KinesisVideo.html#update_notification_configuration/3","title":"AWS.KinesisVideo.update_notification_configuration/3","type":"function"},{"doc":"Updates the existing signaling channel.\n\nThis is an asynchronous operation and takes time to complete.\n\nIf the `MessageTtlSeconds` value is updated (either increased or reduced), it\nonly applies to new messages sent via this channel after it's been updated.\nExisting messages are still expired as per the previous `MessageTtlSeconds`\nvalue.","ref":"AWS.KinesisVideo.html#update_signaling_channel/3","title":"AWS.KinesisVideo.update_signaling_channel/3","type":"function"},{"doc":"Updates stream metadata, such as the device name and media type.\n\nYou must provide the stream name or the Amazon Resource Name (ARN) of the\nstream.\n\nTo make sure that you have the latest version of the stream before updating it,\nyou can specify the stream version. Kinesis Video Streams assigns a version to\neach stream. When you update a stream, Kinesis Video Streams assigns a new\nversion number. To get the latest stream version, use the `DescribeStream` API.\n\n`UpdateStream` is an asynchronous operation, and takes time to complete.","ref":"AWS.KinesisVideo.html#update_stream/3","title":"AWS.KinesisVideo.update_stream/3","type":"function"},{"doc":"","ref":"AWS.KinesisVideoArchivedMedia.html","title":"AWS.KinesisVideoArchivedMedia","type":"module"},{"doc":"Downloads an MP4 file (clip) containing the archived, on-demand media from the\nspecified video stream over the specified time range.\n\nBoth the StreamName and the StreamARN parameters are optional, but you must\nspecify either the StreamName or the StreamARN when invoking this API operation.\n\nAs a prerequisite to using GetCLip API, you must obtain an endpoint using\n`GetDataEndpoint`, specifying GET_CLIP for` the `APIName` parameter. `\n\n```\nAn Amazon Kinesis video stream has the following requirements for providing data\nthrough MP4:\n\n   The media must contain h.264 or h.265 encoded video and,\noptionally, AAC or G.711 encoded audio. Specifically, the codec ID of track 1\nshould be `V_MPEG/ISO/AVC` (for h.264) or V_MPEGH/ISO/HEVC (for H.265).\nOptionally, the codec ID of track 2 should be `A_AAC` (for AAC) or A_MS/ACM (for\nG.711).\n\n   Data retention must be greater than 0.\n\n   The video track of each fragment must contain codec private data in\nthe Advanced Video Coding (AVC) for H.264 format and HEVC for H.265 format. For\nmore information, see [MPEG-4 specification ISO/IEC 14496-15](https://www.iso.org/standard/55980.html). For information about\nadapting stream data to a given format, see [NAL Adaptation Flags](http://docs.aws.amazon.com/kinesisvideostreams/latest/dg/producer-reference-nal.html).\n\n   The audio track (if present) of each fragment must contain codec\nprivate data in the AAC format ([AAC specification ISO/IEC 13818-7](https://www.iso.org/standard/43345.html)) or the [MS Wave format](http://www-mmsp.ece.mcgill.ca/Documents/AudioFormats/WAVE/WAVE.html).\n\nYou can monitor the amount of outgoing data by monitoring the\n`GetClip.OutgoingBytes` Amazon CloudWatch metric. For information about using\nCloudWatch to monitor Kinesis Video Streams, see [Monitoring Kinesis Video Streams](http://docs.aws.amazon.com/kinesisvideostreams/latest/dg/monitoring.html).\nFor pricing information, see [Amazon Kinesis Video Streams Pricing](https://aws.amazon.com/kinesis/video-streams/pricing/) and [ Amazon Web Services Pricing](https://aws.amazon.com/pricing/). Charges for outgoing Amazon\nWeb Services data apply.\n\n```","ref":"AWS.KinesisVideoArchivedMedia.html#get_clip/3","title":"AWS.KinesisVideoArchivedMedia.get_clip/3","type":"function"},{"doc":"Retrieves an MPEG Dynamic Adaptive Streaming over HTTP (DASH) URL for the\nstream.\n\nYou can then open the URL in a media player to view the stream contents.\n\nBoth the `StreamName` and the `StreamARN` parameters are optional, but you must\nspecify either the `StreamName` or the `StreamARN` when invoking this API\noperation.\n\nAn Amazon Kinesis video stream has the following requirements for providing data\nthrough MPEG-DASH:\n\n  * The media must contain h.264 or h.265 encoded video and,\noptionally, AAC or G.711 encoded audio. Specifically, the codec ID of track 1\nshould be `V_MPEG/ISO/AVC` (for h.264) or V_MPEGH/ISO/HEVC (for H.265).\nOptionally, the codec ID of track 2 should be `A_AAC` (for AAC) or A_MS/ACM (for\nG.711).\n\n  * Data retention must be greater than 0.\n\n  * The video track of each fragment must contain codec private data\nin the Advanced Video Coding (AVC) for H.264 format and HEVC for H.265 format.\nFor more information, see [MPEG-4 specification ISO/IEC 14496-15](https://www.iso.org/standard/55980.html). For information about\nadapting stream data to a given format, see [NAL Adaptation Flags](http://docs.aws.amazon.com/kinesisvideostreams/latest/dg/producer-reference-nal.html).\n\n  * The audio track (if present) of each fragment must contain codec\nprivate data in the AAC format ([AAC specification ISO/IEC 13818-7](https://www.iso.org/standard/43345.html)) or the [MS Wave format](http://www-mmsp.ece.mcgill.ca/Documents/AudioFormats/WAVE/WAVE.html).\n\nThe following procedure shows how to use MPEG-DASH with Kinesis Video Streams:\n\n  1. Get an endpoint using\n[GetDataEndpoint](http://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_GetDataEndpoint.html), specifying `GET_DASH_STREAMING_SESSION_URL` for the `APIName` parameter.\n\n  2. Retrieve the MPEG-DASH URL using `GetDASHStreamingSessionURL`.\nKinesis Video Streams creates an MPEG-DASH streaming session to be used for\naccessing content in a stream using the MPEG-DASH protocol.\n`GetDASHStreamingSessionURL` returns an authenticated URL (that includes an\nencrypted session token) for the session's MPEG-DASH *manifest* (the root\nresource needed for streaming with MPEG-DASH).\n\nDon't share or store this token where an unauthorized entity can access it. The\ntoken provides access to the content of the stream. Safeguard the token with the\nsame measures that you use with your Amazon Web Services credentials.\n\nThe media that is made available through the manifest consists only of the\nrequested stream, time range, and format. No other media data (such as frames\noutside the requested window or alternate bitrates) is made available.\n\n  3. Provide the URL (containing the encrypted session token) for the\nMPEG-DASH manifest to a media player that supports the MPEG-DASH protocol.\nKinesis Video Streams makes the initialization fragment and media fragments\navailable through the manifest URL. The initialization fragment contains the\ncodec private data for the stream, and other data needed to set up the video or\naudio decoder and renderer. The media fragments contain encoded video frames or\nencoded audio samples.\n\n  4. The media player receives the authenticated URL and requests\nstream metadata and media data normally. When the media player requests data, it\ncalls the following actions:\n\n    * **GetDASHManifest:** Retrieves an MPEG DASH manifest,\nwhich contains the metadata for the media that you want to playback.\n\n    * **GetMP4InitFragment:** Retrieves the MP4\ninitialization fragment. The media player typically loads the initialization\nfragment before loading any media fragments. This fragment contains the \"`fytp`\"\nand \"`moov`\" MP4 atoms, and the child atoms that are needed to initialize the\nmedia player decoder.\n\nThe initialization fragment does not correspond to a fragment in a Kinesis video\nstream. It contains only the codec private data for the stream and respective\ntrack, which the media player needs to decode the media frames.\n\n    * **GetMP4MediaFragment:** Retrieves MP4 media\nfragments. These fragments contain the \"`moof`\" and \"`mdat`\" MP4 atoms and their\nchild atoms, containing the encoded fragment's media frames and their\ntimestamps.\n\nAfter the first media fragment is made available in a streaming session, any\nfragments that don't contain the same codec private data cause an error to be\nreturned when those different media fragments are loaded. Therefore, the codec\nprivate data should not change between fragments in a session. This also means\nthat the session fails if the fragments in a stream change from having only\nvideo to having both audio and video.\n\nData retrieved with this action is billable. See\n[Pricing](https://aws.amazon.com/kinesis/video-streams/pricing/) for details.\n\nFor restrictions that apply to MPEG-DASH sessions, see [Kinesis Video Streams Limits](http://docs.aws.amazon.com/kinesisvideostreams/latest/dg/limits.html).\n\nYou can monitor the amount of data that the media player consumes by monitoring\nthe `GetMP4MediaFragment.OutgoingBytes` Amazon CloudWatch metric. For\ninformation about using CloudWatch to monitor Kinesis Video Streams, see\n[Monitoring Kinesis Video Streams](http://docs.aws.amazon.com/kinesisvideostreams/latest/dg/monitoring.html).\nFor pricing information, see [Amazon Kinesis Video Streams Pricing](https://aws.amazon.com/kinesis/video-streams/pricing/) and [Amazon Web Services Pricing](https://aws.amazon.com/pricing/). Charges for both HLS\nsessions and outgoing Amazon Web Services data apply.\n\nFor more information about HLS, see [HTTP Live Streaming](https://developer.apple.com/streaming/) on the [Apple Developer site](https://developer.apple.com).\n\nIf an error is thrown after invoking a Kinesis Video Streams archived media API,\nin addition to the HTTP status code and the response body, it includes the\nfollowing pieces of information:\n\n   `x-amz-ErrorType` HTTP header – contains a more specific error type\nin addition to what the HTTP status code provides.\n\n   `x-amz-RequestId` HTTP header – if you want to report an issue to\nAmazon Web Services the support team can better diagnose the problem if given\nthe Request Id.\n\nBoth the HTTP status code and the ErrorType header can be utilized to make\nprogrammatic decisions about whether errors are retry-able and under what\nconditions, as well as provide information on what actions the client programmer\nmight need to take in order to successfully try again.\n\nFor more information, see the **Errors** section at the bottom of this topic, as\nwell as [Common Errors](https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/CommonErrors.html).","ref":"AWS.KinesisVideoArchivedMedia.html#get_dash_streaming_session_url/3","title":"AWS.KinesisVideoArchivedMedia.get_dash_streaming_session_url/3","type":"function"},{"doc":"Retrieves an HTTP Live Streaming (HLS) URL for the stream.\n\nYou can then open the URL in a browser or media player to view the stream\ncontents.\n\nBoth the `StreamName` and the `StreamARN` parameters are optional, but you must\nspecify either the `StreamName` or the `StreamARN` when invoking this API\noperation.\n\nAn Amazon Kinesis video stream has the following requirements for providing data\nthrough HLS:\n\n  * For streaming video, the media must contain H.264 or H.265 encoded\nvideo and, optionally, AAC encoded audio. Specifically, the codec ID of track 1\nshould be `V_MPEG/ISO/AVC` (for H.264) or `V_MPEG/ISO/HEVC` (for H.265).\nOptionally, the codec ID of track 2 should be `A_AAC`. For audio only streaming,\nthe codec ID of track 1 should be `A_AAC`.\n\n  * Data retention must be greater than 0.\n\n  * The video track of each fragment must contain codec private data\nin the Advanced Video Coding (AVC) for H.264 format or HEVC for H.265 format\n([MPEG-4 specification ISO/IEC 14496-15](https://www.iso.org/standard/55980.html)). For information about\nadapting stream data to a given format, see [NAL Adaptation Flags](http://docs.aws.amazon.com/kinesisvideostreams/latest/dg/producer-reference-nal.html).\n\n  * The audio track (if present) of each fragment must contain codec\nprivate data in the AAC format ([AAC specification ISO/IEC 13818-7](https://www.iso.org/standard/43345.html)).\n\nKinesis Video Streams HLS sessions contain fragments in the fragmented MPEG-4\nform (also called fMP4 or CMAF) or the MPEG-2 form (also called TS chunks, which\nthe HLS specification also supports). For more information about HLS fragment\ntypes, see the [HLS specification](https://tools.ietf.org/html/draft-pantos-http-live-streaming-23).\n\nThe following procedure shows how to use HLS with Kinesis Video Streams:\n\n  1. Get an endpoint using\n[GetDataEndpoint](http://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_GetDataEndpoint.html), specifying `GET_HLS_STREAMING_SESSION_URL` for the `APIName` parameter.\n\n  2. Retrieve the HLS URL using `GetHLSStreamingSessionURL`. Kinesis\nVideo Streams creates an HLS streaming session to be used for accessing content\nin a stream using the HLS protocol. `GetHLSStreamingSessionURL` returns an\nauthenticated URL (that includes an encrypted session token) for the session's\nHLS *master playlist* (the root resource needed for streaming with HLS).\n\nDon't share or store this token where an unauthorized entity could access it.\nThe token provides access to the content of the stream. Safeguard the token with\nthe same measures that you would use with your Amazon Web Services credentials.\n\nThe media that is made available through the playlist consists only of the\nrequested stream, time range, and format. No other media data (such as frames\noutside the requested window or alternate bitrates) is made available.\n\n  3. Provide the URL (containing the encrypted session token) for the\nHLS master playlist to a media player that supports the HLS protocol. Kinesis\nVideo Streams makes the HLS media playlist, initialization fragment, and media\nfragments available through the master playlist URL. The initialization fragment\ncontains the codec private data for the stream, and other data needed to set up\nthe video or audio decoder and renderer. The media fragments contain\nH.264-encoded video frames or AAC-encoded audio samples.\n\n  4. The media player receives the authenticated URL and requests\nstream metadata and media data normally. When the media player requests data, it\ncalls the following actions:\n\n    * **GetHLSMasterPlaylist:** Retrieves an HLS master\nplaylist, which contains a URL for the `GetHLSMediaPlaylist` action for each\ntrack, and additional metadata for the media player, including estimated bitrate\nand resolution.\n\n    * **GetHLSMediaPlaylist:** Retrieves an HLS media\nplaylist, which contains a URL to access the MP4 initialization fragment with\nthe `GetMP4InitFragment` action, and URLs to access the MP4 media fragments with\nthe `GetMP4MediaFragment` actions. The HLS media playlist also contains metadata\nabout the stream that the player needs to play it, such as whether the\n`PlaybackMode` is `LIVE` or `ON_DEMAND`. The HLS media playlist is typically\nstatic for sessions with a `PlaybackType` of `ON_DEMAND`. The HLS media playlist\nis continually updated with new fragments for sessions with a `PlaybackType` of\n`LIVE`. There is a distinct HLS media playlist for the video track and the audio\ntrack (if applicable) that contains MP4 media URLs for the specific track.\n\n    * **GetMP4InitFragment:** Retrieves the MP4\ninitialization fragment. The media player typically loads the initialization\nfragment before loading any media fragments. This fragment contains the \"`fytp`\"\nand \"`moov`\" MP4 atoms, and the child atoms that are needed to initialize the\nmedia player decoder.\n\nThe initialization fragment does not correspond to a fragment in a Kinesis video\nstream. It contains only the codec private data for the stream and respective\ntrack, which the media player needs to decode the media frames.\n\n    * **GetMP4MediaFragment:** Retrieves MP4 media\nfragments. These fragments contain the \"`moof`\" and \"`mdat`\" MP4 atoms and their\nchild atoms, containing the encoded fragment's media frames and their\ntimestamps.\n\nFor the HLS streaming session, in-track codec private data (CPD) changes are\nsupported. After the first media fragment is made available in a streaming\nsession, fragments can contain CPD changes for each track. Therefore, the\nfragments in a session can have a different resolution, bit rate, or other\ninformation in the CPD without interrupting playback. However, any change made\nin the track number or track codec format can return an error when those\ndifferent media fragments are loaded. For example, streaming will fail if the\nfragments in the stream change from having only video to having both audio and\nvideo, or if an AAC audio track is changed to an ALAW audio track. For each\nstreaming session, only 500 CPD changes are allowed.\n\nData retrieved with this action is billable. For information, see\n[Pricing](https://aws.amazon.com/kinesis/video-streams/pricing/).\n\n    * **GetTSFragment:** Retrieves MPEG TS fragments\ncontaining both initialization and media data for all tracks in the stream.\n\nIf the `ContainerFormat` is `MPEG_TS`, this API is used instead of\n`GetMP4InitFragment` and `GetMP4MediaFragment` to retrieve stream media.\n\nData retrieved with this action is billable. For more information, see [Kinesis Video Streams pricing](https://aws.amazon.com/kinesis/video-streams/pricing/).\n\nA streaming session URL must not be shared between players. The service might\nthrottle a session if multiple media players are sharing it. For connection\nlimits, see [Kinesis Video Streams Limits](http://docs.aws.amazon.com/kinesisvideostreams/latest/dg/limits.html).\n\nYou can monitor the amount of data that the media player consumes by monitoring\nthe `GetMP4MediaFragment.OutgoingBytes` Amazon CloudWatch metric. For\ninformation about using CloudWatch to monitor Kinesis Video Streams, see\n[Monitoring Kinesis Video Streams](http://docs.aws.amazon.com/kinesisvideostreams/latest/dg/monitoring.html).\nFor pricing information, see [Amazon Kinesis Video Streams Pricing](https://aws.amazon.com/kinesis/video-streams/pricing/) and [Amazon Web Services Pricing](https://aws.amazon.com/pricing/). Charges for both HLS\nsessions and outgoing Amazon Web Services data apply.\n\nFor more information about HLS, see [HTTP Live Streaming](https://developer.apple.com/streaming/) on the [Apple Developer site](https://developer.apple.com).\n\nIf an error is thrown after invoking a Kinesis Video Streams archived media API,\nin addition to the HTTP status code and the response body, it includes the\nfollowing pieces of information:\n\n   `x-amz-ErrorType` HTTP header – contains a more specific error type\nin addition to what the HTTP status code provides.\n\n   `x-amz-RequestId` HTTP header – if you want to report an issue to\nAmazon Web Services, the support team can better diagnose the problem if given\nthe Request Id.\n\nBoth the HTTP status code and the ErrorType header can be utilized to make\nprogrammatic decisions about whether errors are retry-able and under what\nconditions, as well as provide information on what actions the client programmer\nmight need to take in order to successfully try again.\n\nFor more information, see the **Errors** section at the bottom of this topic, as\nwell as [Common Errors](https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/CommonErrors.html).","ref":"AWS.KinesisVideoArchivedMedia.html#get_hls_streaming_session_url/3","title":"AWS.KinesisVideoArchivedMedia.get_hls_streaming_session_url/3","type":"function"},{"doc":"Retrieves a list of images corresponding to each timestamp for a given time\nrange, sampling interval, and image format configuration.","ref":"AWS.KinesisVideoArchivedMedia.html#get_images/3","title":"AWS.KinesisVideoArchivedMedia.get_images/3","type":"function"},{"doc":"Gets media for a list of fragments (specified by fragment number) from the\narchived data in an Amazon Kinesis video stream.\n\nYou must first call the `GetDataEndpoint` API to get an endpoint. Then send the\n`GetMediaForFragmentList` requests to this endpoint using the [--endpoint-url parameter](https://docs.aws.amazon.com/cli/latest/reference/).\n\nFor limits, see [Kinesis Video Streams Limits](http://docs.aws.amazon.com/kinesisvideostreams/latest/dg/limits.html).\n\nIf an error is thrown after invoking a Kinesis Video Streams archived media API,\nin addition to the HTTP status code and the response body, it includes the\nfollowing pieces of information:\n\n   `x-amz-ErrorType` HTTP header – contains a more specific error type\nin addition to what the HTTP status code provides.\n\n   `x-amz-RequestId` HTTP header – if you want to report an issue to\nAmazon Web Services, the support team can better diagnose the problem if given\nthe Request Id.\n\nBoth the HTTP status code and the ErrorType header can be utilized to make\nprogrammatic decisions about whether errors are retry-able and under what\nconditions, as well as provide information on what actions the client programmer\nmight need to take in order to successfully try again.\n\nFor more information, see the **Errors** section at the bottom of this topic, as\nwell as [Common Errors](https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/CommonErrors.html).","ref":"AWS.KinesisVideoArchivedMedia.html#get_media_for_fragment_list/3","title":"AWS.KinesisVideoArchivedMedia.get_media_for_fragment_list/3","type":"function"},{"doc":"Returns a list of `Fragment` objects from the specified stream and timestamp\nrange within the archived data.\n\nListing fragments is eventually consistent. This means that even if the producer\nreceives an acknowledgment that a fragment is persisted, the result might not be\nreturned immediately from a request to `ListFragments`. However, results are\ntypically available in less than one second.\n\nYou must first call the `GetDataEndpoint` API to get an endpoint. Then send the\n`ListFragments` requests to this endpoint using the [--endpoint-url parameter](https://docs.aws.amazon.com/cli/latest/reference/).\n\nIf an error is thrown after invoking a Kinesis Video Streams archived media API,\nin addition to the HTTP status code and the response body, it includes the\nfollowing pieces of information:\n\n   `x-amz-ErrorType` HTTP header – contains a more specific error type\nin addition to what the HTTP status code provides.\n\n   `x-amz-RequestId` HTTP header – if you want to report an issue to\nAmazon Web Services, the support team can better diagnose the problem if given\nthe Request Id.\n\nBoth the HTTP status code and the ErrorType header can be utilized to make\nprogrammatic decisions about whether errors are retry-able and under what\nconditions, as well as provide information on what actions the client programmer\nmight need to take in order to successfully try again.\n\nFor more information, see the **Errors** section at the bottom of this topic, as\nwell as [Common Errors](https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/CommonErrors.html).","ref":"AWS.KinesisVideoArchivedMedia.html#list_fragments/3","title":"AWS.KinesisVideoArchivedMedia.list_fragments/3","type":"function"},{"doc":"","ref":"AWS.KinesisVideoArchivedMedia.html#metadata/0","title":"AWS.KinesisVideoArchivedMedia.metadata/0","type":"function"},{"doc":"","ref":"AWS.KinesisVideoMedia.html","title":"AWS.KinesisVideoMedia","type":"module"},{"doc":"Use this API to retrieve media content from a Kinesis video stream.\n\nIn the request, you identify the stream name or stream Amazon Resource Name\n(ARN), and the starting chunk. Kinesis Video Streams then returns a stream of\nchunks in order by fragment number.\n\nYou must first call the `GetDataEndpoint` API to get an endpoint. Then send the\n`GetMedia` requests to this endpoint using the [--endpoint-url parameter](https://docs.aws.amazon.com/cli/latest/reference/).\n\nWhen you put media data (fragments) on a stream, Kinesis Video Streams stores\neach incoming fragment and related metadata in what is called a \"chunk.\" For\nmore information, see\n[PutMedia](https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_dataplane_PutMedia.html). The `GetMedia` API returns a stream of these chunks starting from the chunk that\nyou specify in the request.\n\nThe following limits apply when using the `GetMedia` API:\n\n  * A client can call `GetMedia` up to five times per second per\nstream.\n\n  * Kinesis Video Streams sends media data at a rate of up to 25\nmegabytes per second (or 200 megabits per second) during a `GetMedia` session.\n\nIf an error is thrown after invoking a Kinesis Video Streams media API, in\naddition to the HTTP status code and the response body, it includes the\nfollowing pieces of information:\n\n   `x-amz-ErrorType` HTTP header – contains a more specific error type\nin addition to what the HTTP status code provides.\n\n   `x-amz-RequestId` HTTP header – if you want to report an issue to\nAWS, the support team can better diagnose the problem if given the Request Id.\n\nBoth the HTTP status code and the ErrorType header can be utilized to make\nprogrammatic decisions about whether errors are retry-able and under what\nconditions, as well as provide information on what actions the client programmer\nmight need to take in order to successfully try again.\n\nFor more information, see the **Errors** section at the bottom of this topic, as\nwell as [Common\nErrors](https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/CommonErrors.html).","ref":"AWS.KinesisVideoMedia.html#get_media/3","title":"AWS.KinesisVideoMedia.get_media/3","type":"function"},{"doc":"","ref":"AWS.KinesisVideoMedia.html#metadata/0","title":"AWS.KinesisVideoMedia.metadata/0","type":"function"},{"doc":"Kinesis Video Streams Signaling Service is a intermediate service that\nestablishes a communication channel for discovering peers, transmitting offers\nand answers in order to establish peer-to-peer connection in webRTC technology.","ref":"AWS.KinesisVideoSignaling.html","title":"AWS.KinesisVideoSignaling","type":"module"},{"doc":"Gets the Interactive Connectivity Establishment (ICE) server configuration\ninformation, including URIs, username, and password which can be used to\nconfigure the WebRTC connection.\n\nThe ICE component uses this configuration information to setup the WebRTC\nconnection, including authenticating with the Traversal Using Relays around NAT\n(TURN) relay server.\n\nTURN is a protocol that is used to improve the connectivity of peer-to-peer\napplications. By providing a cloud-based relay service, TURN ensures that a\nconnection can be established even when one or more peers are incapable of a\ndirect peer-to-peer connection. For more information, see [A REST API For Access To TURN Services](https://tools.ietf.org/html/draft-uberti-rtcweb-turn-rest-00).\n\nYou can invoke this API to establish a fallback mechanism in case either of the\npeers is unable to establish a direct peer-to-peer connection over a signaling\nchannel. You must specify either a signaling channel ARN or the client ID in\norder to invoke this API.","ref":"AWS.KinesisVideoSignaling.html#get_ice_server_config/3","title":"AWS.KinesisVideoSignaling.get_ice_server_config/3","type":"function"},{"doc":"","ref":"AWS.KinesisVideoSignaling.html#metadata/0","title":"AWS.KinesisVideoSignaling.metadata/0","type":"function"},{"doc":"This API allows you to connect WebRTC-enabled devices with Alexa display\ndevices.\n\nWhen invoked, it sends the Alexa Session Description Protocol (SDP) offer to the\nmaster peer. The offer is delivered as soon as the master is connected to the\nspecified signaling channel. This API returns the SDP answer from the connected\nmaster. If the master is not connected to the signaling channel, redelivery\nrequests are made until the message expires.","ref":"AWS.KinesisVideoSignaling.html#send_alexa_offer_to_master/3","title":"AWS.KinesisVideoSignaling.send_alexa_offer_to_master/3","type":"function"},{"doc":"","ref":"AWS.KinesisVideoWebRTCStorage.html","title":"AWS.KinesisVideoWebRTCStorage","type":"module"},{"doc":"Join the ongoing one way-video and/or multi-way audio WebRTC session as a video\nproducing device for an input channel.\n\nIf there’s no existing session for the channel, a new streaming session needs to\nbe created, and the Amazon Resource Name (ARN) of the signaling channel must be\nprovided.\n\nCurrently for the `SINGLE_MASTER` type, a video producing device is able to\ningest both audio and video media into a stream, while viewers can only ingest\naudio. Both a video producing device and viewers can join the session first, and\nwait for other participants.\n\nWhile participants are having peer to peer conversations through webRTC, the\ningested media session will be stored into the Kinesis Video Stream. Multiple\nviewers are able to playback real-time media.\n\nCustomers can also use existing Kinesis Video Streams features like `HLS` or\n`DASH` playback, Image generation, and more with ingested WebRTC media.\n\nAssume that only one video producing device client can be associated with a\nsession for the channel. If more than one client joins the session of a specific\nchannel as a video producing device, the most recent client request takes\nprecedence.","ref":"AWS.KinesisVideoWebRTCStorage.html#join_storage_session/3","title":"AWS.KinesisVideoWebRTCStorage.join_storage_session/3","type":"function"},{"doc":"","ref":"AWS.KinesisVideoWebRTCStorage.html#metadata/0","title":"AWS.KinesisVideoWebRTCStorage.metadata/0","type":"function"},{"doc":"Lake Formation\n\nDefines the public endpoint for the Lake Formation service.","ref":"AWS.LakeFormation.html","title":"AWS.LakeFormation","type":"module"},{"doc":"Attaches one or more LF-tags to an existing resource.","ref":"AWS.LakeFormation.html#add_l_f_tags_to_resource/3","title":"AWS.LakeFormation.add_l_f_tags_to_resource/3","type":"function"},{"doc":"Allows a caller to assume an IAM role decorated as the SAML user specified in\nthe SAML assertion included in the request.\n\nThis decoration allows Lake Formation to enforce access policies against the\nSAML users and groups. This API operation requires SAML federation setup in the\ncaller’s account as it can only be called with valid SAML assertions. Lake\nFormation does not scope down the permission of the assumed role. All\npermissions attached to the role via the SAML federation setup will be included\nin the role session.\n\nThis decorated role is expected to access data in Amazon S3 by getting temporary\naccess from Lake Formation which is authorized via the virtual API\n`GetDataAccess`. Therefore, all SAML roles that can be assumed via\n`AssumeDecoratedRoleWithSAML` must at a minimum include\n`lakeformation:GetDataAccess` in their role policies. A typical IAM policy\nattached to such a role would look as follows:","ref":"AWS.LakeFormation.html#assume_decorated_role_with_saml/3","title":"AWS.LakeFormation.assume_decorated_role_with_saml/3","type":"function"},{"doc":"Batch operation to grant permissions to the principal.","ref":"AWS.LakeFormation.html#batch_grant_permissions/3","title":"AWS.LakeFormation.batch_grant_permissions/3","type":"function"},{"doc":"Batch operation to revoke permissions from the principal.","ref":"AWS.LakeFormation.html#batch_revoke_permissions/3","title":"AWS.LakeFormation.batch_revoke_permissions/3","type":"function"},{"doc":"Attempts to cancel the specified transaction.\n\nReturns an exception if the transaction was previously committed.","ref":"AWS.LakeFormation.html#cancel_transaction/3","title":"AWS.LakeFormation.cancel_transaction/3","type":"function"},{"doc":"Attempts to commit the specified transaction.\n\nReturns an exception if the transaction was previously aborted. This API action\nis idempotent if called multiple times for the same transaction.","ref":"AWS.LakeFormation.html#commit_transaction/3","title":"AWS.LakeFormation.commit_transaction/3","type":"function"},{"doc":"Creates a data cell filter to allow one to grant access to certain columns on\ncertain rows.","ref":"AWS.LakeFormation.html#create_data_cells_filter/3","title":"AWS.LakeFormation.create_data_cells_filter/3","type":"function"},{"doc":"Creates an LF-tag with the specified name and values.","ref":"AWS.LakeFormation.html#create_l_f_tag/3","title":"AWS.LakeFormation.create_l_f_tag/3","type":"function"},{"doc":"Creates an IAM Identity Center connection with Lake Formation to allow IAM\nIdentity Center users and groups to access Data Catalog resources.","ref":"AWS.LakeFormation.html#create_lake_formation_identity_center_configuration/3","title":"AWS.LakeFormation.create_lake_formation_identity_center_configuration/3","type":"function"},{"doc":"Enforce Lake Formation permissions for the given databases, tables, and\nprincipals.","ref":"AWS.LakeFormation.html#create_lake_formation_opt_in/3","title":"AWS.LakeFormation.create_lake_formation_opt_in/3","type":"function"},{"doc":"Deletes a data cell filter.","ref":"AWS.LakeFormation.html#delete_data_cells_filter/3","title":"AWS.LakeFormation.delete_data_cells_filter/3","type":"function"},{"doc":"Deletes the specified LF-tag given a key name.\n\nIf the input parameter tag key was not found, then the operation will throw an\nexception. When you delete an LF-tag, the `LFTagPolicy` attached to the LF-tag\nbecomes invalid. If the deleted LF-tag was still assigned to any resource, the\ntag policy attach to the deleted LF-tag will no longer be applied to the\nresource.","ref":"AWS.LakeFormation.html#delete_l_f_tag/3","title":"AWS.LakeFormation.delete_l_f_tag/3","type":"function"},{"doc":"Deletes an IAM Identity Center connection with Lake Formation.","ref":"AWS.LakeFormation.html#delete_lake_formation_identity_center_configuration/3","title":"AWS.LakeFormation.delete_lake_formation_identity_center_configuration/3","type":"function"},{"doc":"Remove the Lake Formation permissions enforcement of the given databases,\ntables, and principals.","ref":"AWS.LakeFormation.html#delete_lake_formation_opt_in/3","title":"AWS.LakeFormation.delete_lake_formation_opt_in/3","type":"function"},{"doc":"For a specific governed table, provides a list of Amazon S3 objects that will be\nwritten during the current transaction and that can be automatically deleted if\nthe transaction is canceled.\n\nWithout this call, no Amazon S3 objects are automatically deleted when a\ntransaction cancels.\n\nThe Glue ETL library function `write_dynamic_frame.from_catalog()` includes an\noption to automatically call `DeleteObjectsOnCancel` before writes. For more\ninformation, see [Rolling Back Amazon S3 Writes](https://docs.aws.amazon.com/lake-formation/latest/dg/transactions-data-operations.html#rolling-back-writes).","ref":"AWS.LakeFormation.html#delete_objects_on_cancel/3","title":"AWS.LakeFormation.delete_objects_on_cancel/3","type":"function"},{"doc":"Deregisters the resource as managed by the Data Catalog.\n\nWhen you deregister a path, Lake Formation removes the path from the inline\npolicy attached to your service-linked role.","ref":"AWS.LakeFormation.html#deregister_resource/3","title":"AWS.LakeFormation.deregister_resource/3","type":"function"},{"doc":"Retrieves the instance ARN and application ARN for the connection.","ref":"AWS.LakeFormation.html#describe_lake_formation_identity_center_configuration/3","title":"AWS.LakeFormation.describe_lake_formation_identity_center_configuration/3","type":"function"},{"doc":"Retrieves the current data access role for the given resource registered in Lake\nFormation.","ref":"AWS.LakeFormation.html#describe_resource/3","title":"AWS.LakeFormation.describe_resource/3","type":"function"},{"doc":"Returns the details of a single transaction.","ref":"AWS.LakeFormation.html#describe_transaction/3","title":"AWS.LakeFormation.describe_transaction/3","type":"function"},{"doc":"Indicates to the service that the specified transaction is still active and\nshould not be treated as idle and aborted.\n\nWrite transactions that remain idle for a long period are automatically aborted\nunless explicitly extended.","ref":"AWS.LakeFormation.html#extend_transaction/3","title":"AWS.LakeFormation.extend_transaction/3","type":"function"},{"doc":"Returns a data cells filter.","ref":"AWS.LakeFormation.html#get_data_cells_filter/3","title":"AWS.LakeFormation.get_data_cells_filter/3","type":"function"},{"doc":"Retrieves the list of the data lake administrators of a Lake Formation-managed\ndata lake.","ref":"AWS.LakeFormation.html#get_data_lake_settings/3","title":"AWS.LakeFormation.get_data_lake_settings/3","type":"function"},{"doc":"Returns the Lake Formation permissions for a specified table or database\nresource located at a path in Amazon S3.\n\n`GetEffectivePermissionsForPath` will not return databases and tables if the\ncatalog is encrypted.","ref":"AWS.LakeFormation.html#get_effective_permissions_for_path/3","title":"AWS.LakeFormation.get_effective_permissions_for_path/3","type":"function"},{"doc":"Returns an LF-tag definition.","ref":"AWS.LakeFormation.html#get_l_f_tag/3","title":"AWS.LakeFormation.get_l_f_tag/3","type":"function"},{"doc":"Returns the state of a query previously submitted.\n\nClients are expected to poll `GetQueryState` to monitor the current state of the\nplanning before retrieving the work units. A query state is only visible to the\nprincipal that made the initial call to `StartQueryPlanning`.","ref":"AWS.LakeFormation.html#get_query_state/3","title":"AWS.LakeFormation.get_query_state/3","type":"function"},{"doc":"Retrieves statistics on the planning and execution of a query.","ref":"AWS.LakeFormation.html#get_query_statistics/3","title":"AWS.LakeFormation.get_query_statistics/3","type":"function"},{"doc":"Returns the LF-tags applied to a resource.","ref":"AWS.LakeFormation.html#get_resource_l_f_tags/3","title":"AWS.LakeFormation.get_resource_l_f_tags/3","type":"function"},{"doc":"Returns the set of Amazon S3 objects that make up the specified governed table.\n\nA transaction ID or timestamp can be specified for time-travel queries.","ref":"AWS.LakeFormation.html#get_table_objects/3","title":"AWS.LakeFormation.get_table_objects/3","type":"function"},{"doc":"This API is identical to `GetTemporaryTableCredentials` except that this is used\nwhen the target Data Catalog resource is of type Partition.\n\nLake Formation restricts the permission of the vended credentials with the same\nscope down policy which restricts access to a single Amazon S3 prefix.","ref":"AWS.LakeFormation.html#get_temporary_glue_partition_credentials/3","title":"AWS.LakeFormation.get_temporary_glue_partition_credentials/3","type":"function"},{"doc":"Allows a caller in a secure environment to assume a role with permission to\naccess Amazon S3.\n\nIn order to vend such credentials, Lake Formation assumes the role associated\nwith a registered location, for example an Amazon S3 bucket, with a scope down\npolicy which restricts the access to a single prefix.","ref":"AWS.LakeFormation.html#get_temporary_glue_table_credentials/3","title":"AWS.LakeFormation.get_temporary_glue_table_credentials/3","type":"function"},{"doc":"Returns the work units resulting from the query.\n\nWork units can be executed in any order and in parallel.","ref":"AWS.LakeFormation.html#get_work_unit_results/3","title":"AWS.LakeFormation.get_work_unit_results/3","type":"function"},{"doc":"Retrieves the work units generated by the `StartQueryPlanning` operation.","ref":"AWS.LakeFormation.html#get_work_units/3","title":"AWS.LakeFormation.get_work_units/3","type":"function"},{"doc":"Grants permissions to the principal to access metadata in the Data Catalog and\ndata organized in underlying data storage such as Amazon S3.\n\nFor information about permissions, see [Security and Access Control to Metadata and\nData](https://docs.aws.amazon.com/lake-formation/latest/dg/security-data-access.html).","ref":"AWS.LakeFormation.html#grant_permissions/3","title":"AWS.LakeFormation.grant_permissions/3","type":"function"},{"doc":"Lists all the data cell filters on a table.","ref":"AWS.LakeFormation.html#list_data_cells_filter/3","title":"AWS.LakeFormation.list_data_cells_filter/3","type":"function"},{"doc":"Lists LF-tags that the requester has permission to view.","ref":"AWS.LakeFormation.html#list_l_f_tags/3","title":"AWS.LakeFormation.list_l_f_tags/3","type":"function"},{"doc":"Retrieve the current list of resources and principals that are opt in to enforce\nLake Formation permissions.","ref":"AWS.LakeFormation.html#list_lake_formation_opt_ins/3","title":"AWS.LakeFormation.list_lake_formation_opt_ins/3","type":"function"},{"doc":"Returns a list of the principal permissions on the resource, filtered by the\npermissions of the caller.\n\nFor example, if you are granted an ALTER permission, you are able to see only\nthe principal permissions for ALTER.\n\nThis operation returns only those permissions that have been explicitly granted.\n\nFor information about permissions, see [Security and Access Control to Metadata and\nData](https://docs.aws.amazon.com/lake-formation/latest/dg/security-data-access.html).","ref":"AWS.LakeFormation.html#list_permissions/3","title":"AWS.LakeFormation.list_permissions/3","type":"function"},{"doc":"Lists the resources registered to be managed by the Data Catalog.","ref":"AWS.LakeFormation.html#list_resources/3","title":"AWS.LakeFormation.list_resources/3","type":"function"},{"doc":"Returns the configuration of all storage optimizers associated with a specified\ntable.","ref":"AWS.LakeFormation.html#list_table_storage_optimizers/3","title":"AWS.LakeFormation.list_table_storage_optimizers/3","type":"function"},{"doc":"Returns metadata about transactions and their status.\n\nTo prevent the response from growing indefinitely, only uncommitted transactions\nand those available for time-travel queries are returned.\n\nThis operation can help you identify uncommitted transactions or to get\ninformation about transactions.","ref":"AWS.LakeFormation.html#list_transactions/3","title":"AWS.LakeFormation.list_transactions/3","type":"function"},{"doc":"","ref":"AWS.LakeFormation.html#metadata/0","title":"AWS.LakeFormation.metadata/0","type":"function"},{"doc":"Sets the list of data lake administrators who have admin privileges on all\nresources managed by Lake Formation.\n\nFor more information on admin privileges, see [Granting Lake Formation Permissions](https://docs.aws.amazon.com/lake-formation/latest/dg/lake-formation-permissions.html).\n\nThis API replaces the current list of data lake admins with the new list being\npassed. To add an admin, fetch the current list and add the new admin to that\nlist and pass that list in this API.","ref":"AWS.LakeFormation.html#put_data_lake_settings/3","title":"AWS.LakeFormation.put_data_lake_settings/3","type":"function"},{"doc":"Registers the resource as managed by the Data Catalog.\n\nTo add or update data, Lake Formation needs read/write access to the chosen\nAmazon S3 path. Choose a role that you know has permission to do this, or choose\nthe AWSServiceRoleForLakeFormationDataAccess service-linked role. When you\nregister the first Amazon S3 path, the service-linked role and a new inline\npolicy are created on your behalf. Lake Formation adds the first path to the\ninline policy and attaches it to the service-linked role. When you register\nsubsequent paths, Lake Formation adds the path to the existing policy.\n\nThe following request registers a new location and gives Lake Formation\npermission to use the service-linked role to access that location.\n\n`ResourceArn = arn:aws:s3:::my-bucket UseServiceLinkedRole = true`\n\nIf `UseServiceLinkedRole` is not set to true, you must provide or set the\n`RoleArn`:\n\n`arn:aws:iam::12345:role/my-data-access-role`","ref":"AWS.LakeFormation.html#register_resource/3","title":"AWS.LakeFormation.register_resource/3","type":"function"},{"doc":"Removes an LF-tag from the resource.\n\nOnly database, table, or tableWithColumns resource are allowed. To tag columns,\nuse the column inclusion list in `tableWithColumns` to specify column input.","ref":"AWS.LakeFormation.html#remove_l_f_tags_from_resource/3","title":"AWS.LakeFormation.remove_l_f_tags_from_resource/3","type":"function"},{"doc":"Revokes permissions to the principal to access metadata in the Data Catalog and\ndata organized in underlying data storage such as Amazon S3.","ref":"AWS.LakeFormation.html#revoke_permissions/3","title":"AWS.LakeFormation.revoke_permissions/3","type":"function"},{"doc":"This operation allows a search on `DATABASE` resources by `TagCondition`.\n\nThis operation is used by admins who want to grant user permissions on certain\n`TagConditions`. Before making a grant, the admin can use\n`SearchDatabasesByTags` to find all resources where the given `TagConditions`\nare valid to verify whether the returned resources can be shared.","ref":"AWS.LakeFormation.html#search_databases_by_l_f_tags/3","title":"AWS.LakeFormation.search_databases_by_l_f_tags/3","type":"function"},{"doc":"This operation allows a search on `TABLE` resources by `LFTag`s.\n\nThis will be used by admins who want to grant user permissions on certain\nLF-tags. Before making a grant, the admin can use `SearchTablesByLFTags` to find\nall resources where the given `LFTag`s are valid to verify whether the returned\nresources can be shared.","ref":"AWS.LakeFormation.html#search_tables_by_l_f_tags/3","title":"AWS.LakeFormation.search_tables_by_l_f_tags/3","type":"function"},{"doc":"Submits a request to process a query statement.\n\nThis operation generates work units that can be retrieved with the\n`GetWorkUnits` operation as soon as the query state is WORKUNITS_AVAILABLE or\nFINISHED.","ref":"AWS.LakeFormation.html#start_query_planning/3","title":"AWS.LakeFormation.start_query_planning/3","type":"function"},{"doc":"Starts a new transaction and returns its transaction ID.\n\nTransaction IDs are opaque objects that you can use to identify a transaction.","ref":"AWS.LakeFormation.html#start_transaction/3","title":"AWS.LakeFormation.start_transaction/3","type":"function"},{"doc":"Updates a data cell filter.","ref":"AWS.LakeFormation.html#update_data_cells_filter/3","title":"AWS.LakeFormation.update_data_cells_filter/3","type":"function"},{"doc":"Updates the list of possible values for the specified LF-tag key.\n\nIf the LF-tag does not exist, the operation throws an EntityNotFoundException.\nThe values in the delete key values will be deleted from list of possible\nvalues. If any value in the delete key values is attached to a resource, then\nAPI errors out with a 400 Exception - \"Update not allowed\". Untag the attribute\nbefore deleting the LF-tag key's value.","ref":"AWS.LakeFormation.html#update_l_f_tag/3","title":"AWS.LakeFormation.update_l_f_tag/3","type":"function"},{"doc":"Updates the IAM Identity Center connection parameters.","ref":"AWS.LakeFormation.html#update_lake_formation_identity_center_configuration/3","title":"AWS.LakeFormation.update_lake_formation_identity_center_configuration/3","type":"function"},{"doc":"Updates the data access role used for vending access to the given (registered)\nresource in Lake Formation.","ref":"AWS.LakeFormation.html#update_resource/3","title":"AWS.LakeFormation.update_resource/3","type":"function"},{"doc":"Updates the manifest of Amazon S3 objects that make up the specified governed\ntable.","ref":"AWS.LakeFormation.html#update_table_objects/3","title":"AWS.LakeFormation.update_table_objects/3","type":"function"},{"doc":"Updates the configuration of the storage optimizers for a table.","ref":"AWS.LakeFormation.html#update_table_storage_optimizer/3","title":"AWS.LakeFormation.update_table_storage_optimizer/3","type":"function"},{"doc":"Lambda","ref":"AWS.Lambda.html","title":"AWS.Lambda","type":"module"},{"doc":"Lambda is a compute service that lets you run code without provisioning or\nmanaging servers.\n\nLambda runs your code on a high-availability compute infrastructure and performs\nall of the administration of the compute resources, including server and\noperating system maintenance, capacity provisioning and automatic scaling, code\nmonitoring and logging. With Lambda, you can run code for virtually any type of\napplication or backend service. For more information about the Lambda service,\nsee [What is Lambda](https://docs.aws.amazon.com/lambda/latest/dg/welcome.html) in the **Lambda Developer Guide**.\n\nThe *Lambda API Reference* provides information about each of the API methods,\nincluding details about the parameters in each API request and response.\n\nYou can use Software Development Kits (SDKs), Integrated Development Environment\n(IDE) Toolkits, and command line tools to access the API. For installation\ninstructions, see [Tools for Amazon Web Services](http://aws.amazon.com/tools/).\n\nFor a list of Region-specific endpoints that Lambda supports, see [Lambda endpoints and quotas\n](https://docs.aws.amazon.com/general/latest/gr/lambda-service.html/) in the\n*Amazon Web Services General Reference.*.\n\nWhen making the API calls, you will need to authenticate your request by\nproviding a signature. Lambda supports signature version 4. For more\ninformation, see [Signature Version 4 signing process](https://docs.aws.amazon.com/general/latest/gr/signature-version-4.html)\nin the *Amazon Web Services General Reference.*.","ref":"AWS.Lambda.html#module-overview","title":"Overview - AWS.Lambda","type":"module"},{"doc":"Because Amazon Web Services SDKs use the CA certificates from your computer,\nchanges to the certificates on the Amazon Web Services servers can cause\nconnection failures when you attempt to use an SDK. You can prevent these\nfailures by keeping your computer's CA certificates and operating system\nup-to-date. If you encounter this issue in a corporate environment and do not\nmanage your own computer, you might need to ask an administrator to assist with\nthe update process. The following list shows minimum operating system and Java\nversions:\n\n  * Microsoft Windows versions that have updates from January 2005 or\nlater installed contain at least one of the required CAs in their trust list.\n\n  * Mac OS X 10.4 with Java for Mac OS X 10.4 Release 5 (February\n2007), Mac OS X 10.5 (October 2007), and later versions contain at least one of\nthe required CAs in their trust list.\n\n  * Red Hat Enterprise Linux 5 (March 2007), 6, and 7 and CentOS 5, 6,\nand 7 all contain at least one of the required CAs in their default trusted CA\nlist.\n\n  * Java 1.4.2_12 (May 2006), 5 Update 2 (March 2005), and all later\nversions, including Java 6 (December 2006), 7, and 8, contain at least one of\nthe required CAs in their default trusted CA list.\n\nWhen accessing the Lambda management console or Lambda API endpoints, whether\nthrough browsers or programmatically, you will need to ensure your client\nmachines support any of the following CAs:\n\n  * Amazon Root CA 1\n\n  * Starfield Services Root Certificate Authority - G2\n\n  * Starfield Class 2 Certification Authority\n\nRoot certificates from the first two authorities are available from [Amazon trust services](https://www.amazontrust.com/repository/), but keeping your\ncomputer up-to-date is the more straightforward solution. To learn more about\nACM-provided certificates, see [Amazon Web Services Certificate Manager FAQs.](http://aws.amazon.com/certificate-manager/faqs/#certificates)","ref":"AWS.Lambda.html#module-ca-certificates","title":"CA certificates - AWS.Lambda","type":"module"},{"doc":"Adds permissions to the resource-based policy of a version of an [Lambda layer](https://docs.aws.amazon.com/lambda/latest/dg/configuration-layers.html).\n\nUse this action to grant layer usage permission to other accounts. You can grant\npermission to a single account, all accounts in an organization, or all Amazon\nWeb Services accounts.\n\nTo revoke permission, call `RemoveLayerVersionPermission` with the statement ID\nthat you specified when you added it.","ref":"AWS.Lambda.html#add_layer_version_permission/5","title":"AWS.Lambda.add_layer_version_permission/5","type":"function"},{"doc":"Grants an Amazon Web Service, Amazon Web Services account, or Amazon Web\nServices organization permission to use a function.\n\nYou can apply the policy at the function level, or specify a qualifier to\nrestrict access to a single version or alias. If you use a qualifier, the\ninvoker must use the full Amazon Resource Name (ARN) of that version or alias to\ninvoke the function. Note: Lambda does not support adding policies to version\n$LATEST.\n\nTo grant permission to another account, specify the account ID as the\n`Principal`. To grant permission to an organization defined in Organizations,\nspecify the organization ID as the `PrincipalOrgID`. For Amazon Web Services,\nthe principal is a domain-style identifier that the service defines, such as\n`s3.amazonaws.com` or `sns.amazonaws.com`. For Amazon Web Services, you can also\nspecify the ARN of the associated resource as the `SourceArn`. If you grant\npermission to a service principal without specifying the source, other accounts\ncould potentially configure resources in their account to invoke your Lambda\nfunction.\n\nThis operation adds a statement to a resource-based permissions policy for the\nfunction. For more information about function policies, see [Using resource-based policies for\nLambda](https://docs.aws.amazon.com/lambda/latest/dg/access-control-resource-based.html).","ref":"AWS.Lambda.html#add_permission/4","title":"AWS.Lambda.add_permission/4","type":"function"},{"doc":"Creates an\n[alias](https://docs.aws.amazon.com/lambda/latest/dg/configuration-aliases.html)\nfor a Lambda function version.\n\nUse aliases to provide clients with a function identifier that you can update to\ninvoke a different version.\n\nYou can also map an alias to split invocation requests between two versions. Use\nthe `RoutingConfig` parameter to specify a second version and the percentage of\ninvocation requests that it receives.","ref":"AWS.Lambda.html#create_alias/4","title":"AWS.Lambda.create_alias/4","type":"function"},{"doc":"Creates a code signing configuration.\n\nA [code signing configuration](https://docs.aws.amazon.com/lambda/latest/dg/configuration-codesigning.html)\ndefines a list of allowed signing profiles and defines the code-signing\nvalidation policy (action to be taken if deployment validation checks fail).","ref":"AWS.Lambda.html#create_code_signing_config/3","title":"AWS.Lambda.create_code_signing_config/3","type":"function"},{"doc":"Creates a mapping between an event source and an Lambda function.\n\nLambda reads items from the event source and invokes the function.\n\nFor details about how to configure different event sources, see the following\ntopics.\n\n  * [ Amazon DynamoDB Streams](https://docs.aws.amazon.com/lambda/latest/dg/with-ddb.html#services-dynamodb-eventsourcemapping)\n\n  * [ Amazon Kinesis](https://docs.aws.amazon.com/lambda/latest/dg/with-kinesis.html#services-kinesis-eventsourcemapping)\n\n  * [ Amazon SQS](https://docs.aws.amazon.com/lambda/latest/dg/with-sqs.html#events-sqs-eventsource)\n\n  * [ Amazon MQ and RabbitMQ](https://docs.aws.amazon.com/lambda/latest/dg/with-mq.html#services-mq-eventsourcemapping)\n\n  * [ Amazon MSK](https://docs.aws.amazon.com/lambda/latest/dg/with-msk.html)\n\n  * [ Apache Kafka](https://docs.aws.amazon.com/lambda/latest/dg/kafka-smaa.html)\n\n  * [ Amazon DocumentDB](https://docs.aws.amazon.com/lambda/latest/dg/with-documentdb.html)\n\nThe following error handling options are available only for stream sources\n(DynamoDB and Kinesis):\n\n  * `BisectBatchOnFunctionError` – If the function returns an error,\nsplit the batch in two and retry.\n\n  * `DestinationConfig` – Send discarded records to an Amazon SQS\nqueue or Amazon SNS topic.\n\n  * `MaximumRecordAgeInSeconds` – Discard records older than the\nspecified age. The default value is infinite (-1). When set to infinite (-1),\nfailed records are retried until the record expires\n\n  * `MaximumRetryAttempts` – Discard records after the specified\nnumber of retries. The default value is infinite (-1). When set to infinite\n(-1), failed records are retried until the record expires.\n\n  * `ParallelizationFactor` – Process multiple batches from each shard\nconcurrently.\n\nFor information about which configuration parameters apply to each event source,\nsee the following topics.\n\n  * [ Amazon DynamoDB Streams](https://docs.aws.amazon.com/lambda/latest/dg/with-ddb.html#services-ddb-params)\n\n  * [ Amazon Kinesis](https://docs.aws.amazon.com/lambda/latest/dg/with-kinesis.html#services-kinesis-params)\n\n  * [ Amazon SQS](https://docs.aws.amazon.com/lambda/latest/dg/with-sqs.html#services-sqs-params)\n\n  * [ Amazon MQ and RabbitMQ](https://docs.aws.amazon.com/lambda/latest/dg/with-mq.html#services-mq-params)\n\n  * [ Amazon MSK](https://docs.aws.amazon.com/lambda/latest/dg/with-msk.html#services-msk-parms)\n\n  * [ Apache Kafka](https://docs.aws.amazon.com/lambda/latest/dg/with-kafka.html#services-kafka-parms)\n\n  * [ Amazon DocumentDB](https://docs.aws.amazon.com/lambda/latest/dg/with-documentdb.html#docdb-configuration)","ref":"AWS.Lambda.html#create_event_source_mapping/3","title":"AWS.Lambda.create_event_source_mapping/3","type":"function"},{"doc":"Creates a Lambda function.\n\nTo create a function, you need a [deployment package](https://docs.aws.amazon.com/lambda/latest/dg/gettingstarted-package.html)\nand an [execution role](https://docs.aws.amazon.com/lambda/latest/dg/intro-permission-model.html#lambda-intro-execution-role).\nThe deployment package is a .zip file archive or container image that contains\nyour function code. The execution role grants the function permission to use\nAmazon Web Services, such as Amazon CloudWatch Logs for log streaming and X-Ray\nfor request tracing.\n\nIf the deployment package is a [container image](https://docs.aws.amazon.com/lambda/latest/dg/lambda-images.html), then\nyou set the package type to `Image`. For a container image, the code property\nmust include the URI of a container image in the Amazon ECR registry. You do not\nneed to specify the handler and runtime properties.\n\nIf the deployment package is a [.zip file archive](https://docs.aws.amazon.com/lambda/latest/dg/gettingstarted-package.html#gettingstarted-package-zip),\nthen you set the package type to `Zip`. For a .zip file archive, the code\nproperty specifies the location of the .zip file. You must also specify the\nhandler and runtime properties. The code in the deployment package must be\ncompatible with the target instruction set architecture of the function\n(`x86-64` or `arm64`). If you do not specify the architecture, then the default\nvalue is `x86-64`.\n\nWhen you create a function, Lambda provisions an instance of the function and\nits supporting resources. If your function connects to a VPC, this process can\ntake a minute or so. During this time, you can't invoke or modify the function.\nThe `State`, `StateReason`, and `StateReasonCode` fields in the response from\n`GetFunctionConfiguration` indicate when the function is ready to invoke. For\nmore information, see [Lambda function states](https://docs.aws.amazon.com/lambda/latest/dg/functions-states.html).\n\nA function has an unpublished version, and can have published versions and\naliases. The unpublished version changes when you update your function's code\nand configuration. A published version is a snapshot of your function code and\nconfiguration that can't be changed. An alias is a named resource that maps to a\nversion, and can be changed to map to a different version. Use the `Publish`\nparameter to create version `1` of your function from its initial configuration.\n\nThe other parameters let you configure version-specific and function-level\nsettings. You can modify version-specific settings later with\n`UpdateFunctionConfiguration`. Function-level settings apply to both the\nunpublished and published versions of the function, and include tags\n(`TagResource`) and per-function concurrency limits (`PutFunctionConcurrency`).\n\nYou can use code signing if your deployment package is a .zip file archive. To\nenable code signing for this function, specify the ARN of a code-signing\nconfiguration. When a user attempts to deploy a code package with\n`UpdateFunctionCode`, Lambda checks that the code package has a valid signature\nfrom a trusted publisher. The code-signing configuration includes set of signing\nprofiles, which define the trusted publishers for this function.\n\nIf another Amazon Web Services account or an Amazon Web Service invokes your\nfunction, use `AddPermission` to grant permission by creating a resource-based\nIdentity and Access Management (IAM) policy. You can grant permissions at the\nfunction level, on a version, or on an alias.\n\nTo invoke your function directly, use `Invoke`. To invoke your function in\nresponse to events in other Amazon Web Services, create an event source mapping\n(`CreateEventSourceMapping`), or configure a function trigger in the other\nservice. For more information, see [Invoking Lambda functions](https://docs.aws.amazon.com/lambda/latest/dg/lambda-invocation.html).","ref":"AWS.Lambda.html#create_function/3","title":"AWS.Lambda.create_function/3","type":"function"},{"doc":"Creates a Lambda function URL with the specified configuration parameters.\n\nA function URL is a dedicated HTTP(S) endpoint that you can use to invoke your\nfunction.","ref":"AWS.Lambda.html#create_function_url_config/4","title":"AWS.Lambda.create_function_url_config/4","type":"function"},{"doc":"Deletes a Lambda function\n[alias](https://docs.aws.amazon.com/lambda/latest/dg/configuration-aliases.html).","ref":"AWS.Lambda.html#delete_alias/5","title":"AWS.Lambda.delete_alias/5","type":"function"},{"doc":"Deletes the code signing configuration.\n\nYou can delete the code signing configuration only if no function is using it.","ref":"AWS.Lambda.html#delete_code_signing_config/4","title":"AWS.Lambda.delete_code_signing_config/4","type":"function"},{"doc":"Deletes an [event source mapping](https://docs.aws.amazon.com/lambda/latest/dg/intro-invocation-modes.html).\n\nYou can get the identifier of a mapping from the output of\n`ListEventSourceMappings`.\n\nWhen you delete an event source mapping, it enters a `Deleting` state and might\nnot be completely deleted for several seconds.","ref":"AWS.Lambda.html#delete_event_source_mapping/4","title":"AWS.Lambda.delete_event_source_mapping/4","type":"function"},{"doc":"Deletes a Lambda function.\n\nTo delete a specific function version, use the `Qualifier` parameter. Otherwise,\nall versions and aliases are deleted. This doesn't require the user to have\nexplicit permissions for `DeleteAlias`.\n\nTo delete Lambda event source mappings that invoke a function, use\n`DeleteEventSourceMapping`. For Amazon Web Services and resources that invoke\nyour function directly, delete the trigger in the service where you originally\nconfigured it.","ref":"AWS.Lambda.html#delete_function/4","title":"AWS.Lambda.delete_function/4","type":"function"},{"doc":"Removes the code signing configuration from the function.","ref":"AWS.Lambda.html#delete_function_code_signing_config/4","title":"AWS.Lambda.delete_function_code_signing_config/4","type":"function"},{"doc":"Removes a concurrent execution limit from a function.","ref":"AWS.Lambda.html#delete_function_concurrency/4","title":"AWS.Lambda.delete_function_concurrency/4","type":"function"},{"doc":"Deletes the configuration for asynchronous invocation for a function, version,\nor alias.\n\nTo configure options for asynchronous invocation, use\n`PutFunctionEventInvokeConfig`.","ref":"AWS.Lambda.html#delete_function_event_invoke_config/4","title":"AWS.Lambda.delete_function_event_invoke_config/4","type":"function"},{"doc":"Deletes a Lambda function URL.\n\nWhen you delete a function URL, you can't recover it. Creating a new function\nURL results in a different URL address.","ref":"AWS.Lambda.html#delete_function_url_config/4","title":"AWS.Lambda.delete_function_url_config/4","type":"function"},{"doc":"Deletes a version of an [Lambda layer](https://docs.aws.amazon.com/lambda/latest/dg/configuration-layers.html).\n\nDeleted versions can no longer be viewed or added to functions. To avoid\nbreaking functions, a copy of the version remains in Lambda until no functions\nrefer to it.","ref":"AWS.Lambda.html#delete_layer_version/5","title":"AWS.Lambda.delete_layer_version/5","type":"function"},{"doc":"Deletes the provisioned concurrency configuration for a function.","ref":"AWS.Lambda.html#delete_provisioned_concurrency_config/4","title":"AWS.Lambda.delete_provisioned_concurrency_config/4","type":"function"},{"doc":"Retrieves details about your account's\n[limits](https://docs.aws.amazon.com/lambda/latest/dg/limits.html) and usage in\nan Amazon Web Services Region.","ref":"AWS.Lambda.html#get_account_settings/2","title":"AWS.Lambda.get_account_settings/2","type":"function"},{"doc":"Returns details about a Lambda function\n[alias](https://docs.aws.amazon.com/lambda/latest/dg/configuration-aliases.html).","ref":"AWS.Lambda.html#get_alias/4","title":"AWS.Lambda.get_alias/4","type":"function"},{"doc":"Returns information about the specified code signing configuration.","ref":"AWS.Lambda.html#get_code_signing_config/3","title":"AWS.Lambda.get_code_signing_config/3","type":"function"},{"doc":"Returns details about an event source mapping.\n\nYou can get the identifier of a mapping from the output of\n`ListEventSourceMappings`.","ref":"AWS.Lambda.html#get_event_source_mapping/3","title":"AWS.Lambda.get_event_source_mapping/3","type":"function"},{"doc":"Returns information about the function or function version, with a link to\ndownload the deployment package that's valid for 10 minutes.\n\nIf you specify a function version, only details that are specific to that\nversion are returned.","ref":"AWS.Lambda.html#get_function/4","title":"AWS.Lambda.get_function/4","type":"function"},{"doc":"Returns the code signing configuration for the specified function.","ref":"AWS.Lambda.html#get_function_code_signing_config/3","title":"AWS.Lambda.get_function_code_signing_config/3","type":"function"},{"doc":"Returns details about the reserved concurrency configuration for a function.\n\nTo set a concurrency limit for a function, use `PutFunctionConcurrency`.","ref":"AWS.Lambda.html#get_function_concurrency/3","title":"AWS.Lambda.get_function_concurrency/3","type":"function"},{"doc":"Returns the version-specific settings of a Lambda function or version.\n\nThe output includes only options that can vary between versions of a function.\nTo modify these settings, use `UpdateFunctionConfiguration`.\n\nTo get all of a function's details, including function-level settings, use\n`GetFunction`.","ref":"AWS.Lambda.html#get_function_configuration/4","title":"AWS.Lambda.get_function_configuration/4","type":"function"},{"doc":"Retrieves the configuration for asynchronous invocation for a function, version,\nor alias.\n\nTo configure options for asynchronous invocation, use\n`PutFunctionEventInvokeConfig`.","ref":"AWS.Lambda.html#get_function_event_invoke_config/4","title":"AWS.Lambda.get_function_event_invoke_config/4","type":"function"},{"doc":"Returns details about a Lambda function URL.","ref":"AWS.Lambda.html#get_function_url_config/4","title":"AWS.Lambda.get_function_url_config/4","type":"function"},{"doc":"Returns information about a version of an [Lambda layer](https://docs.aws.amazon.com/lambda/latest/dg/configuration-layers.html),\nwith a link to download the layer archive that's valid for 10 minutes.","ref":"AWS.Lambda.html#get_layer_version/4","title":"AWS.Lambda.get_layer_version/4","type":"function"},{"doc":"Returns information about a version of an [Lambda layer](https://docs.aws.amazon.com/lambda/latest/dg/configuration-layers.html),\nwith a link to download the layer archive that's valid for 10 minutes.","ref":"AWS.Lambda.html#get_layer_version_by_arn/3","title":"AWS.Lambda.get_layer_version_by_arn/3","type":"function"},{"doc":"Returns the permission policy for a version of an [Lambda layer](https://docs.aws.amazon.com/lambda/latest/dg/configuration-layers.html).\n\nFor more information, see `AddLayerVersionPermission`.","ref":"AWS.Lambda.html#get_layer_version_policy/4","title":"AWS.Lambda.get_layer_version_policy/4","type":"function"},{"doc":"Returns the [resource-based IAM policy](https://docs.aws.amazon.com/lambda/latest/dg/access-control-resource-based.html)\nfor a function, version, or alias.","ref":"AWS.Lambda.html#get_policy/4","title":"AWS.Lambda.get_policy/4","type":"function"},{"doc":"Retrieves the provisioned concurrency configuration for a function's alias or\nversion.","ref":"AWS.Lambda.html#get_provisioned_concurrency_config/4","title":"AWS.Lambda.get_provisioned_concurrency_config/4","type":"function"},{"doc":"Retrieves the runtime management configuration for a function's version.\n\nIf the runtime update mode is **Manual**, this includes the ARN of the runtime\nversion and the runtime update mode. If the runtime update mode is **Auto** or\n**Function update**, this includes the runtime update mode and `null` is\nreturned for the ARN. For more information, see [Runtime updates](https://docs.aws.amazon.com/lambda/latest/dg/runtimes-update.html).","ref":"AWS.Lambda.html#get_runtime_management_config/4","title":"AWS.Lambda.get_runtime_management_config/4","type":"function"},{"doc":"Invokes a Lambda function.\n\nYou can invoke a function synchronously (and wait for the response), or\nasynchronously. By default, Lambda invokes your function synchronously (i.e.\nthe`InvocationType` is `RequestResponse`). To invoke a function asynchronously,\nset `InvocationType` to `Event`. Lambda passes the `ClientContext` object to\nyour function for synchronous invocations only.\n\nFor [synchronous invocation](https://docs.aws.amazon.com/lambda/latest/dg/invocation-sync.html),\ndetails about the function response, including errors, are included in the\nresponse body and headers. For either invocation type, you can find more\ninformation in the [execution log](https://docs.aws.amazon.com/lambda/latest/dg/monitoring-functions.html) and\n[trace](https://docs.aws.amazon.com/lambda/latest/dg/lambda-x-ray.html).  When an error occurs, your function may be invoked multiple times. Retry\nbehavior varies by error type, client, event source, and invocation type. For\nexample, if you invoke a function asynchronously and it returns an error, Lambda\nexecutes the function up to two more times. For more information, see [Error\nhandling and automatic retries in\nLambda](https://docs.aws.amazon.com/lambda/latest/dg/invocation-retries.html).\n\nFor [asynchronous invocation](https://docs.aws.amazon.com/lambda/latest/dg/invocation-async.html),\nLambda adds events to a queue before sending them to your function. If your\nfunction does not have enough capacity to keep up with the queue, events may be\nlost. Occasionally, your function may receive the same event multiple times,\neven if no error occurs. To retain events that were not processed, configure\nyour function with a [dead-letter queue](https://docs.aws.amazon.com/lambda/latest/dg/invocation-async.html#invocation-dlq).\n\nThe status code in the API response doesn't reflect function errors. Error codes\nare reserved for errors that prevent your function from executing, such as\npermissions errors,\n[quota](https://docs.aws.amazon.com/lambda/latest/dg/gettingstarted-limits.html) errors, or issues with your function's code and configuration. For example,\nLambda returns `TooManyRequestsException` if running the function would cause\nyou to exceed a concurrency limit at either the account level\n(`ConcurrentInvocationLimitExceeded`) or function level\n(`ReservedFunctionConcurrentInvocationLimitExceeded`).\n\nFor functions with a long timeout, your client might disconnect during\nsynchronous invocation while it waits for a response. Configure your HTTP\nclient, SDK, firewall, proxy, or operating system to allow for long connections\nwith timeout or keep-alive settings.\n\nThis operation requires permission for the\n[lambda:InvokeFunction](https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awslambda.html)\naction. For details on how to set up permissions for cross-account invocations,\nsee [Granting function access to other accounts](https://docs.aws.amazon.com/lambda/latest/dg/access-control-resource-based.html#permissions-resource-xaccountinvoke).","ref":"AWS.Lambda.html#invoke/4","title":"AWS.Lambda.invoke/4","type":"function"},{"doc":"For asynchronous function invocation, use `Invoke`.\n\nInvokes a function asynchronously.","ref":"AWS.Lambda.html#invoke_async/4","title":"AWS.Lambda.invoke_async/4","type":"function"},{"doc":"Configure your Lambda functions to stream response payloads back to clients.\n\nFor more information, see [Configuring a Lambda function to stream responses](https://docs.aws.amazon.com/lambda/latest/dg/configuration-response-streaming.html).\n\nThis operation requires permission for the\n[lambda:InvokeFunction](https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awslambda.html) action. For details on how to set up permissions for cross-account invocations,\nsee [Granting function access to other\naccounts](https://docs.aws.amazon.com/lambda/latest/dg/access-control-resource-based.html#permissions-resource-xaccountinvoke).","ref":"AWS.Lambda.html#invoke_with_response_stream/4","title":"AWS.Lambda.invoke_with_response_stream/4","type":"function"},{"doc":"Returns a list of\n[aliases](https://docs.aws.amazon.com/lambda/latest/dg/configuration-aliases.html)\nfor a Lambda function.","ref":"AWS.Lambda.html#list_aliases/6","title":"AWS.Lambda.list_aliases/6","type":"function"},{"doc":"Returns a list of [code signing configurations](https://docs.aws.amazon.com/lambda/latest/dg/configuring-codesigning.html).\n\nA request returns up to 10,000 configurations per call. You can use the\n`MaxItems` parameter to return fewer configurations per call.","ref":"AWS.Lambda.html#list_code_signing_configs/4","title":"AWS.Lambda.list_code_signing_configs/4","type":"function"},{"doc":"Lists event source mappings.\n\nSpecify an `EventSourceArn` to show only event source mappings for a single\nevent source.","ref":"AWS.Lambda.html#list_event_source_mappings/6","title":"AWS.Lambda.list_event_source_mappings/6","type":"function"},{"doc":"Retrieves a list of configurations for asynchronous invocation for a function.\n\nTo configure options for asynchronous invocation, use\n`PutFunctionEventInvokeConfig`.","ref":"AWS.Lambda.html#list_function_event_invoke_configs/5","title":"AWS.Lambda.list_function_event_invoke_configs/5","type":"function"},{"doc":"Returns a list of Lambda function URLs for the specified function.","ref":"AWS.Lambda.html#list_function_url_configs/5","title":"AWS.Lambda.list_function_url_configs/5","type":"function"},{"doc":"Returns a list of Lambda functions, with the version-specific configuration of\neach.\n\nLambda returns up to 50 functions per call.\n\nSet `FunctionVersion` to `ALL` to include all published versions of each\nfunction in addition to the unpublished version.\n\nThe `ListFunctions` operation returns a subset of the `FunctionConfiguration`\nfields. To get the additional fields (State, StateReasonCode, StateReason,\nLastUpdateStatus, LastUpdateStatusReason, LastUpdateStatusReasonCode,\nRuntimeVersionConfig) for a function or version, use `GetFunction`.","ref":"AWS.Lambda.html#list_functions/6","title":"AWS.Lambda.list_functions/6","type":"function"},{"doc":"List the functions that use the specified code signing configuration.\n\nYou can use this method prior to deleting a code signing configuration, to\nverify that no functions are using it.","ref":"AWS.Lambda.html#list_functions_by_code_signing_config/5","title":"AWS.Lambda.list_functions_by_code_signing_config/5","type":"function"},{"doc":"Lists the versions of an [Lambda layer](https://docs.aws.amazon.com/lambda/latest/dg/configuration-layers.html).\n\nVersions that have been deleted aren't listed. Specify a [runtime identifier](https://docs.aws.amazon.com/lambda/latest/dg/lambda-runtimes.html)\nto list only versions that indicate that they're compatible with that runtime.\nSpecify a compatible architecture to include only layer versions that are\ncompatible with that architecture.","ref":"AWS.Lambda.html#list_layer_versions/7","title":"AWS.Lambda.list_layer_versions/7","type":"function"},{"doc":"Lists [Lambda layers](https://docs.aws.amazon.com/lambda/latest/dg/invocation-layers.html) and\nshows information about the latest version of each.\n\nSpecify a [runtime identifier](https://docs.aws.amazon.com/lambda/latest/dg/lambda-runtimes.html)\nto list only layers that indicate that they're compatible with that runtime.\nSpecify a compatible architecture to include only layers that are compatible\nwith that [instruction set architecture](https://docs.aws.amazon.com/lambda/latest/dg/foundation-arch.html).","ref":"AWS.Lambda.html#list_layers/6","title":"AWS.Lambda.list_layers/6","type":"function"},{"doc":"Retrieves a list of provisioned concurrency configurations for a function.","ref":"AWS.Lambda.html#list_provisioned_concurrency_configs/5","title":"AWS.Lambda.list_provisioned_concurrency_configs/5","type":"function"},{"doc":"Returns a function's\n[tags](https://docs.aws.amazon.com/lambda/latest/dg/tagging.html).\n\nYou can also view tags with `GetFunction`.","ref":"AWS.Lambda.html#list_tags/3","title":"AWS.Lambda.list_tags/3","type":"function"},{"doc":"Returns a list of\n[versions](https://docs.aws.amazon.com/lambda/latest/dg/versioning-aliases.html),\nwith the version-specific configuration of each.\n\nLambda returns up to 50 versions per call.","ref":"AWS.Lambda.html#list_versions_by_function/5","title":"AWS.Lambda.list_versions_by_function/5","type":"function"},{"doc":"","ref":"AWS.Lambda.html#metadata/0","title":"AWS.Lambda.metadata/0","type":"function"},{"doc":"Creates an [Lambda layer](https://docs.aws.amazon.com/lambda/latest/dg/configuration-layers.html)\nfrom a ZIP archive.\n\nEach time you call `PublishLayerVersion` with the same layer name, a new version\nis created.\n\nAdd layers to your function with `CreateFunction` or\n`UpdateFunctionConfiguration`.","ref":"AWS.Lambda.html#publish_layer_version/4","title":"AWS.Lambda.publish_layer_version/4","type":"function"},{"doc":"Creates a\n[version](https://docs.aws.amazon.com/lambda/latest/dg/versioning-aliases.html)\nfrom the current code and configuration of a function.\n\nUse versions to create a snapshot of your function code and configuration that\ndoesn't change.\n\nLambda doesn't publish a version if the function's configuration and code\nhaven't changed since the last version. Use `UpdateFunctionCode` or\n`UpdateFunctionConfiguration` to update the function before publishing a\nversion.\n\nClients can invoke versions directly or with an alias. To create an alias, use\n`CreateAlias`.","ref":"AWS.Lambda.html#publish_version/4","title":"AWS.Lambda.publish_version/4","type":"function"},{"doc":"Update the code signing configuration for the function.\n\nChanges to the code signing configuration take effect the next time a user tries\nto deploy a code package to the function.","ref":"AWS.Lambda.html#put_function_code_signing_config/4","title":"AWS.Lambda.put_function_code_signing_config/4","type":"function"},{"doc":"Sets the maximum number of simultaneous executions for a function, and reserves\ncapacity for that concurrency level.\n\nConcurrency settings apply to the function as a whole, including all published\nversions and the unpublished version. Reserving concurrency both ensures that\nyour function has capacity to process the specified number of events\nsimultaneously, and prevents it from scaling beyond that level. Use\n`GetFunction` to see the current setting for a function.\n\nUse `GetAccountSettings` to see your Regional concurrency limit. You can reserve\nconcurrency for as many functions as you like, as long as you leave at least 100\nsimultaneous executions unreserved for functions that aren't configured with a\nper-function limit. For more information, see [Lambda function scaling](https://docs.aws.amazon.com/lambda/latest/dg/invocation-scaling.html).","ref":"AWS.Lambda.html#put_function_concurrency/4","title":"AWS.Lambda.put_function_concurrency/4","type":"function"},{"doc":"Configures options for [asynchronous invocation](https://docs.aws.amazon.com/lambda/latest/dg/invocation-async.html)\non a function, version, or alias.\n\nIf a configuration already exists for a function, version, or alias, this\noperation overwrites it. If you exclude any settings, they are removed. To set\none option without affecting existing settings for other options, use\n`UpdateFunctionEventInvokeConfig`.\n\nBy default, Lambda retries an asynchronous invocation twice if the function\nreturns an error. It retains events in a queue for up to six hours. When an\nevent fails all processing attempts or stays in the asynchronous invocation\nqueue for too long, Lambda discards it. To retain discarded events, configure a\ndead-letter queue with `UpdateFunctionConfiguration`.\n\nTo send an invocation record to a queue, topic, function, or event bus, specify\na\n[destination](https://docs.aws.amazon.com/lambda/latest/dg/invocation-async.html#invocation-async-destinations).\nYou can configure separate destinations for successful invocations (on-success)\nand events that fail all processing attempts (on-failure). You can configure\ndestinations in addition to or instead of a dead-letter queue.","ref":"AWS.Lambda.html#put_function_event_invoke_config/4","title":"AWS.Lambda.put_function_event_invoke_config/4","type":"function"},{"doc":"Adds a provisioned concurrency configuration to a function's alias or version.","ref":"AWS.Lambda.html#put_provisioned_concurrency_config/4","title":"AWS.Lambda.put_provisioned_concurrency_config/4","type":"function"},{"doc":"Sets the runtime management configuration for a function's version.\n\nFor more information, see [Runtime updates](https://docs.aws.amazon.com/lambda/latest/dg/runtimes-update.html).","ref":"AWS.Lambda.html#put_runtime_management_config/4","title":"AWS.Lambda.put_runtime_management_config/4","type":"function"},{"doc":"Removes a statement from the permissions policy for a version of an [Lambda layer](https://docs.aws.amazon.com/lambda/latest/dg/configuration-layers.html).\n\nFor more information, see `AddLayerVersionPermission`.","ref":"AWS.Lambda.html#remove_layer_version_permission/6","title":"AWS.Lambda.remove_layer_version_permission/6","type":"function"},{"doc":"Revokes function-use permission from an Amazon Web Service or another Amazon Web\nServices account.\n\nYou can get the ID of the statement from the output of `GetPolicy`.","ref":"AWS.Lambda.html#remove_permission/5","title":"AWS.Lambda.remove_permission/5","type":"function"},{"doc":"Adds [tags](https://docs.aws.amazon.com/lambda/latest/dg/tagging.html) to a\nfunction.","ref":"AWS.Lambda.html#tag_resource/4","title":"AWS.Lambda.tag_resource/4","type":"function"},{"doc":"Removes [tags](https://docs.aws.amazon.com/lambda/latest/dg/tagging.html) from a\nfunction.","ref":"AWS.Lambda.html#untag_resource/4","title":"AWS.Lambda.untag_resource/4","type":"function"},{"doc":"Updates the configuration of a Lambda function\n[alias](https://docs.aws.amazon.com/lambda/latest/dg/configuration-aliases.html).","ref":"AWS.Lambda.html#update_alias/5","title":"AWS.Lambda.update_alias/5","type":"function"},{"doc":"Update the code signing configuration.\n\nChanges to the code signing configuration take effect the next time a user tries\nto deploy a code package to the function.","ref":"AWS.Lambda.html#update_code_signing_config/4","title":"AWS.Lambda.update_code_signing_config/4","type":"function"},{"doc":"Updates an event source mapping.\n\nYou can change the function that Lambda invokes, or pause invocation and resume\nlater from the same location.\n\nFor details about how to configure different event sources, see the following\ntopics.\n\n  * [ Amazon DynamoDB Streams](https://docs.aws.amazon.com/lambda/latest/dg/with-ddb.html#services-dynamodb-eventsourcemapping)\n\n  * [ Amazon Kinesis](https://docs.aws.amazon.com/lambda/latest/dg/with-kinesis.html#services-kinesis-eventsourcemapping)\n\n  * [ Amazon SQS](https://docs.aws.amazon.com/lambda/latest/dg/with-sqs.html#events-sqs-eventsource)\n\n  * [ Amazon MQ and RabbitMQ](https://docs.aws.amazon.com/lambda/latest/dg/with-mq.html#services-mq-eventsourcemapping)\n\n  * [ Amazon MSK](https://docs.aws.amazon.com/lambda/latest/dg/with-msk.html)\n\n  * [ Apache Kafka](https://docs.aws.amazon.com/lambda/latest/dg/kafka-smaa.html)\n\n  * [ Amazon DocumentDB](https://docs.aws.amazon.com/lambda/latest/dg/with-documentdb.html)\n\nThe following error handling options are available only for stream sources\n(DynamoDB and Kinesis):\n\n  * `BisectBatchOnFunctionError` – If the function returns an error,\nsplit the batch in two and retry.\n\n  * `DestinationConfig` – Send discarded records to an Amazon SQS\nqueue or Amazon SNS topic.\n\n  * `MaximumRecordAgeInSeconds` – Discard records older than the\nspecified age. The default value is infinite (-1). When set to infinite (-1),\nfailed records are retried until the record expires\n\n  * `MaximumRetryAttempts` – Discard records after the specified\nnumber of retries. The default value is infinite (-1). When set to infinite\n(-1), failed records are retried until the record expires.\n\n  * `ParallelizationFactor` – Process multiple batches from each shard\nconcurrently.\n\nFor information about which configuration parameters apply to each event source,\nsee the following topics.\n\n  * [ Amazon DynamoDB Streams](https://docs.aws.amazon.com/lambda/latest/dg/with-ddb.html#services-ddb-params)\n\n  * [ Amazon Kinesis](https://docs.aws.amazon.com/lambda/latest/dg/with-kinesis.html#services-kinesis-params)\n\n  * [ Amazon SQS](https://docs.aws.amazon.com/lambda/latest/dg/with-sqs.html#services-sqs-params)\n\n  * [ Amazon MQ and RabbitMQ](https://docs.aws.amazon.com/lambda/latest/dg/with-mq.html#services-mq-params)\n\n  * [ Amazon MSK](https://docs.aws.amazon.com/lambda/latest/dg/with-msk.html#services-msk-parms)\n\n  * [ Apache Kafka](https://docs.aws.amazon.com/lambda/latest/dg/with-kafka.html#services-kafka-parms)\n\n  * [ Amazon DocumentDB](https://docs.aws.amazon.com/lambda/latest/dg/with-documentdb.html#docdb-configuration)","ref":"AWS.Lambda.html#update_event_source_mapping/4","title":"AWS.Lambda.update_event_source_mapping/4","type":"function"},{"doc":"Updates a Lambda function's code.\n\nIf code signing is enabled for the function, the code package must be signed by\na trusted publisher. For more information, see [Configuring code signing for Lambda](https://docs.aws.amazon.com/lambda/latest/dg/configuration-codesigning.html).\n\nIf the function's package type is `Image`, then you must specify the code\npackage in `ImageUri` as the URI of a [container image](https://docs.aws.amazon.com/lambda/latest/dg/lambda-images.html) in the\nAmazon ECR registry.\n\nIf the function's package type is `Zip`, then you must specify the deployment\npackage as a [.zip file archive](https://docs.aws.amazon.com/lambda/latest/dg/gettingstarted-package.html#gettingstarted-package-zip).\nEnter the Amazon S3 bucket and key of the code .zip file location. You can also\nprovide the function code inline using the `ZipFile` field.\n\nThe code in the deployment package must be compatible with the target\ninstruction set architecture of the function (`x86-64` or `arm64`).\n\nThe function's code is locked when you publish a version. You can't modify the\ncode of a published version, only the unpublished version.\n\nFor a function defined as a container image, Lambda resolves the image tag to an\nimage digest. In Amazon ECR, if you update the image tag to a new image, Lambda\ndoes not automatically update the function.","ref":"AWS.Lambda.html#update_function_code/4","title":"AWS.Lambda.update_function_code/4","type":"function"},{"doc":"Modify the version-specific settings of a Lambda function.\n\nWhen you update a function, Lambda provisions an instance of the function and\nits supporting resources. If your function connects to a VPC, this process can\ntake a minute. During this time, you can't modify the function, but you can\nstill invoke it. The `LastUpdateStatus`, `LastUpdateStatusReason`, and\n`LastUpdateStatusReasonCode` fields in the response from\n`GetFunctionConfiguration` indicate when the update is complete and the function\nis processing events with the new configuration. For more information, see\n[Lambda function states](https://docs.aws.amazon.com/lambda/latest/dg/functions-states.html).\n\nThese settings can vary between versions of a function and are locked when you\npublish a version. You can't modify the configuration of a published version,\nonly the unpublished version.\n\nTo configure function concurrency, use `PutFunctionConcurrency`. To grant invoke\npermissions to an Amazon Web Services account or Amazon Web Service, use\n`AddPermission`.","ref":"AWS.Lambda.html#update_function_configuration/4","title":"AWS.Lambda.update_function_configuration/4","type":"function"},{"doc":"Updates the configuration for asynchronous invocation for a function, version,\nor alias.\n\nTo configure options for asynchronous invocation, use\n`PutFunctionEventInvokeConfig`.","ref":"AWS.Lambda.html#update_function_event_invoke_config/4","title":"AWS.Lambda.update_function_event_invoke_config/4","type":"function"},{"doc":"Updates the configuration for a Lambda function URL.","ref":"AWS.Lambda.html#update_function_url_config/4","title":"AWS.Lambda.update_function_url_config/4","type":"function"},{"doc":"Launch Wizard offers a guided way of sizing, configuring, and deploying Amazon\nWeb Services resources for third party applications, such as Microsoft SQL\nServer Always On and HANA based SAP systems, without the need to manually\nidentify and provision individual Amazon Web Services resources.","ref":"AWS.LaunchWizard.html","title":"AWS.LaunchWizard","type":"module"},{"doc":"Creates a deployment for the given workload.\n\nDeployments created by this operation are not available in the Launch Wizard\nconsole to use the `Clone deployment` action on.","ref":"AWS.LaunchWizard.html#create_deployment/3","title":"AWS.LaunchWizard.create_deployment/3","type":"function"},{"doc":"Deletes a deployment.","ref":"AWS.LaunchWizard.html#delete_deployment/3","title":"AWS.LaunchWizard.delete_deployment/3","type":"function"},{"doc":"Returns information about the deployment.","ref":"AWS.LaunchWizard.html#get_deployment/3","title":"AWS.LaunchWizard.get_deployment/3","type":"function"},{"doc":"Returns information about a workload.","ref":"AWS.LaunchWizard.html#get_workload/3","title":"AWS.LaunchWizard.get_workload/3","type":"function"},{"doc":"Lists the events of a deployment.","ref":"AWS.LaunchWizard.html#list_deployment_events/3","title":"AWS.LaunchWizard.list_deployment_events/3","type":"function"},{"doc":"Lists the deployments that have been created.","ref":"AWS.LaunchWizard.html#list_deployments/3","title":"AWS.LaunchWizard.list_deployments/3","type":"function"},{"doc":"Lists the workload deployment patterns.","ref":"AWS.LaunchWizard.html#list_workload_deployment_patterns/3","title":"AWS.LaunchWizard.list_workload_deployment_patterns/3","type":"function"},{"doc":"Lists the workloads.","ref":"AWS.LaunchWizard.html#list_workloads/3","title":"AWS.LaunchWizard.list_workloads/3","type":"function"},{"doc":"","ref":"AWS.LaunchWizard.html#metadata/0","title":"AWS.LaunchWizard.metadata/0","type":"function"},{"doc":"Amazon Lex Build-Time Actions\n\nAmazon Lex is an AWS service for building conversational voice and text\ninterfaces.\n\nUse these actions to create, update, and delete conversational bots for new and\nexisting client applications.","ref":"AWS.LexModelBuilding.html","title":"AWS.LexModelBuilding","type":"module"},{"doc":"Creates a new version of the bot based on the `$LATEST` version.\n\nIf the `$LATEST` version of this resource hasn't changed since you created the\nlast version, Amazon Lex doesn't create a new version. It returns the last\ncreated version.\n\nYou can update only the `$LATEST` version of the bot. You can't update the\nnumbered versions that you create with the `CreateBotVersion` operation.\n\nWhen you create the first version of a bot, Amazon Lex sets the version to 1.\nSubsequent versions increment by 1. For more information, see\n`versioning-intro`.\n\nThis operation requires permission for the `lex:CreateBotVersion` action.","ref":"AWS.LexModelBuilding.html#create_bot_version/4","title":"AWS.LexModelBuilding.create_bot_version/4","type":"function"},{"doc":"Creates a new version of an intent based on the `$LATEST` version of the intent.\n\nIf the `$LATEST` version of this intent hasn't changed since you last updated\nit, Amazon Lex doesn't create a new version. It returns the last version you\ncreated.\n\nYou can update only the `$LATEST` version of the intent. You can't update the\nnumbered versions that you create with the `CreateIntentVersion` operation.\n\nWhen you create a version of an intent, Amazon Lex sets the version to 1.\nSubsequent versions increment by 1. For more information, see\n`versioning-intro`.\n\nThis operation requires permissions to perform the `lex:CreateIntentVersion`\naction.","ref":"AWS.LexModelBuilding.html#create_intent_version/4","title":"AWS.LexModelBuilding.create_intent_version/4","type":"function"},{"doc":"Creates a new version of a slot type based on the `$LATEST` version of the\nspecified slot type.\n\nIf the `$LATEST` version of this resource has not changed since the last version\nthat you created, Amazon Lex doesn't create a new version. It returns the last\nversion that you created.\n\nYou can update only the `$LATEST` version of a slot type. You can't update the\nnumbered versions that you create with the `CreateSlotTypeVersion` operation.\n\nWhen you create a version of a slot type, Amazon Lex sets the version to 1.\nSubsequent versions increment by 1. For more information, see\n`versioning-intro`.\n\nThis operation requires permissions for the `lex:CreateSlotTypeVersion` action.","ref":"AWS.LexModelBuilding.html#create_slot_type_version/4","title":"AWS.LexModelBuilding.create_slot_type_version/4","type":"function"},{"doc":"Deletes all versions of the bot, including the `$LATEST` version.\n\nTo delete a specific version of the bot, use the `DeleteBotVersion` operation.\nThe `DeleteBot` operation doesn't immediately remove the bot schema. Instead, it\nis marked for deletion and removed later.\n\nAmazon Lex stores utterances indefinitely for improving the ability of your bot\nto respond to user inputs. These utterances are not removed when the bot is\ndeleted. To remove the utterances, use the `DeleteUtterances` operation.\n\nIf a bot has an alias, you can't delete it. Instead, the `DeleteBot` operation\nreturns a `ResourceInUseException` exception that includes a reference to the\nalias that refers to the bot. To remove the reference to the bot, delete the\nalias. If you get the same exception again, delete the referring alias until the\n`DeleteBot` operation is successful.\n\nThis operation requires permissions for the `lex:DeleteBot` action.","ref":"AWS.LexModelBuilding.html#delete_bot/4","title":"AWS.LexModelBuilding.delete_bot/4","type":"function"},{"doc":"Deletes an alias for the specified bot.\n\nYou can't delete an alias that is used in the association between a bot and a\nmessaging channel. If an alias is used in a channel association, the `DeleteBot`\noperation returns a `ResourceInUseException` exception that includes a reference\nto the channel association that refers to the bot. You can remove the reference\nto the alias by deleting the channel association. If you get the same exception\nagain, delete the referring association until the `DeleteBotAlias` operation is\nsuccessful.","ref":"AWS.LexModelBuilding.html#delete_bot_alias/5","title":"AWS.LexModelBuilding.delete_bot_alias/5","type":"function"},{"doc":"Deletes the association between an Amazon Lex bot and a messaging platform.\n\nThis operation requires permission for the `lex:DeleteBotChannelAssociation`\naction.","ref":"AWS.LexModelBuilding.html#delete_bot_channel_association/6","title":"AWS.LexModelBuilding.delete_bot_channel_association/6","type":"function"},{"doc":"Deletes a specific version of a bot.\n\nTo delete all versions of a bot, use the `DeleteBot` operation.\n\nThis operation requires permissions for the `lex:DeleteBotVersion` action.","ref":"AWS.LexModelBuilding.html#delete_bot_version/5","title":"AWS.LexModelBuilding.delete_bot_version/5","type":"function"},{"doc":"Deletes all versions of the intent, including the `$LATEST` version.\n\nTo delete a specific version of the intent, use the `DeleteIntentVersion`\noperation.\n\nYou can delete a version of an intent only if it is not referenced. To delete an\nintent that is referred to in one or more bots (see `how-it-works`), you must\nremove those references first.\n\nIf you get the `ResourceInUseException` exception, it provides an example\nreference that shows where the intent is referenced. To remove the reference to\nthe intent, either update the bot or delete it. If you get the same exception\nwhen you attempt to delete the intent again, repeat until the intent has no\nreferences and the call to `DeleteIntent` is successful.\n\nThis operation requires permission for the `lex:DeleteIntent` action.","ref":"AWS.LexModelBuilding.html#delete_intent/4","title":"AWS.LexModelBuilding.delete_intent/4","type":"function"},{"doc":"Deletes a specific version of an intent.\n\nTo delete all versions of a intent, use the `DeleteIntent` operation.\n\nThis operation requires permissions for the `lex:DeleteIntentVersion` action.","ref":"AWS.LexModelBuilding.html#delete_intent_version/5","title":"AWS.LexModelBuilding.delete_intent_version/5","type":"function"},{"doc":"Deletes all versions of the slot type, including the `$LATEST` version.\n\nTo delete a specific version of the slot type, use the `DeleteSlotTypeVersion`\noperation.\n\nYou can delete a version of a slot type only if it is not referenced. To delete\na slot type that is referred to in one or more intents, you must remove those\nreferences first.\n\nIf you get the `ResourceInUseException` exception, the exception provides an\nexample reference that shows the intent where the slot type is referenced. To\nremove the reference to the slot type, either update the intent or delete it. If\nyou get the same exception when you attempt to delete the slot type again,\nrepeat until the slot type has no references and the `DeleteSlotType` call is\nsuccessful.\n\nThis operation requires permission for the `lex:DeleteSlotType` action.","ref":"AWS.LexModelBuilding.html#delete_slot_type/4","title":"AWS.LexModelBuilding.delete_slot_type/4","type":"function"},{"doc":"Deletes a specific version of a slot type.\n\nTo delete all versions of a slot type, use the `DeleteSlotType` operation.\n\nThis operation requires permissions for the `lex:DeleteSlotTypeVersion` action.","ref":"AWS.LexModelBuilding.html#delete_slot_type_version/5","title":"AWS.LexModelBuilding.delete_slot_type_version/5","type":"function"},{"doc":"Deletes stored utterances.\n\nAmazon Lex stores the utterances that users send to your bot. Utterances are\nstored for 15 days for use with the `GetUtterancesView` operation, and then\nstored indefinitely for use in improving the ability of your bot to respond to\nuser input.\n\nUse the `DeleteUtterances` operation to manually delete stored utterances for a\nspecific user. When you use the `DeleteUtterances` operation, utterances stored\nfor improving your bot's ability to respond to user input are deleted\nimmediately. Utterances stored for use with the `GetUtterancesView` operation\nare deleted after 15 days.\n\nThis operation requires permissions for the `lex:DeleteUtterances` action.","ref":"AWS.LexModelBuilding.html#delete_utterances/5","title":"AWS.LexModelBuilding.delete_utterances/5","type":"function"},{"doc":"Returns metadata information for a specific bot.\n\nYou must provide the bot name and the bot version or alias.\n\nThis operation requires permissions for the `lex:GetBot` action.","ref":"AWS.LexModelBuilding.html#get_bot/4","title":"AWS.LexModelBuilding.get_bot/4","type":"function"},{"doc":"Returns information about an Amazon Lex bot alias.\n\nFor more information about aliases, see `versioning-aliases`.\n\nThis operation requires permissions for the `lex:GetBotAlias` action.","ref":"AWS.LexModelBuilding.html#get_bot_alias/4","title":"AWS.LexModelBuilding.get_bot_alias/4","type":"function"},{"doc":"Returns a list of aliases for a specified Amazon Lex bot.\n\nThis operation requires permissions for the `lex:GetBotAliases` action.","ref":"AWS.LexModelBuilding.html#get_bot_aliases/6","title":"AWS.LexModelBuilding.get_bot_aliases/6","type":"function"},{"doc":"Returns information about the association between an Amazon Lex bot and a\nmessaging platform.\n\nThis operation requires permissions for the `lex:GetBotChannelAssociation`\naction.","ref":"AWS.LexModelBuilding.html#get_bot_channel_association/5","title":"AWS.LexModelBuilding.get_bot_channel_association/5","type":"function"},{"doc":"Returns a list of all of the channels associated with the specified bot.\n\nThe `GetBotChannelAssociations` operation requires permissions for the\n`lex:GetBotChannelAssociations` action.","ref":"AWS.LexModelBuilding.html#get_bot_channel_associations/7","title":"AWS.LexModelBuilding.get_bot_channel_associations/7","type":"function"},{"doc":"Gets information about all of the versions of a bot.\n\nThe `GetBotVersions` operation returns a `BotMetadata` object for each version\nof a bot. For example, if a bot has three numbered versions, the\n`GetBotVersions` operation returns four `BotMetadata` objects in the response,\none for each numbered version and one for the `$LATEST` version.\n\nThe `GetBotVersions` operation always returns at least one version, the\n`$LATEST` version.\n\nThis operation requires permissions for the `lex:GetBotVersions` action.","ref":"AWS.LexModelBuilding.html#get_bot_versions/5","title":"AWS.LexModelBuilding.get_bot_versions/5","type":"function"},{"doc":"Returns bot information as follows:\n\n  * If you provide the `nameContains` field, the response includes\ninformation for the `$LATEST` version of all bots whose name contains the\nspecified string.\n\n  * If you don't specify the `nameContains` field, the operation\nreturns information about the `$LATEST` version of all of your bots.\n\nThis operation requires permission for the `lex:GetBots` action.","ref":"AWS.LexModelBuilding.html#get_bots/5","title":"AWS.LexModelBuilding.get_bots/5","type":"function"},{"doc":"Returns information about a built-in intent.\n\nThis operation requires permission for the `lex:GetBuiltinIntent` action.","ref":"AWS.LexModelBuilding.html#get_builtin_intent/3","title":"AWS.LexModelBuilding.get_builtin_intent/3","type":"function"},{"doc":"Gets a list of built-in intents that meet the specified criteria.\n\nThis operation requires permission for the `lex:GetBuiltinIntents` action.","ref":"AWS.LexModelBuilding.html#get_builtin_intents/6","title":"AWS.LexModelBuilding.get_builtin_intents/6","type":"function"},{"doc":"Gets a list of built-in slot types that meet the specified criteria.\n\nFor a list of built-in slot types, see [Slot Type Reference](https://developer.amazon.com/public/solutions/alexa/alexa-skills-kit/docs/built-in-intent-ref/slot-type-reference)\nin the *Alexa Skills Kit*.\n\nThis operation requires permission for the `lex:GetBuiltInSlotTypes` action.","ref":"AWS.LexModelBuilding.html#get_builtin_slot_types/6","title":"AWS.LexModelBuilding.get_builtin_slot_types/6","type":"function"},{"doc":"Exports the contents of a Amazon Lex resource in a specified format.","ref":"AWS.LexModelBuilding.html#get_export/6","title":"AWS.LexModelBuilding.get_export/6","type":"function"},{"doc":"Gets information about an import job started with the `StartImport` operation.","ref":"AWS.LexModelBuilding.html#get_import/3","title":"AWS.LexModelBuilding.get_import/3","type":"function"},{"doc":"Returns information about an intent.\n\nIn addition to the intent name, you must specify the intent version.\n\nThis operation requires permissions to perform the `lex:GetIntent` action.","ref":"AWS.LexModelBuilding.html#get_intent/4","title":"AWS.LexModelBuilding.get_intent/4","type":"function"},{"doc":"Gets information about all of the versions of an intent.\n\nThe `GetIntentVersions` operation returns an `IntentMetadata` object for each\nversion of an intent. For example, if an intent has three numbered versions, the\n`GetIntentVersions` operation returns four `IntentMetadata` objects in the\nresponse, one for each numbered version and one for the `$LATEST` version.\n\nThe `GetIntentVersions` operation always returns at least one version, the\n`$LATEST` version.\n\nThis operation requires permissions for the `lex:GetIntentVersions` action.","ref":"AWS.LexModelBuilding.html#get_intent_versions/5","title":"AWS.LexModelBuilding.get_intent_versions/5","type":"function"},{"doc":"Returns intent information as follows:\n\n  * If you specify the `nameContains` field, returns the `$LATEST`\nversion of all intents that contain the specified string.\n\n  * If you don't specify the `nameContains` field, returns information\nabout the `$LATEST` version of all intents.\n\nThe operation requires permission for the `lex:GetIntents` action.","ref":"AWS.LexModelBuilding.html#get_intents/5","title":"AWS.LexModelBuilding.get_intents/5","type":"function"},{"doc":"Provides details about an ongoing or complete migration from an Amazon Lex V1\nbot to an Amazon Lex V2 bot.\n\nUse this operation to view the migration alerts and warnings related to the\nmigration.","ref":"AWS.LexModelBuilding.html#get_migration/3","title":"AWS.LexModelBuilding.get_migration/3","type":"function"},{"doc":"Gets a list of migrations between Amazon Lex V1 and Amazon Lex V2.","ref":"AWS.LexModelBuilding.html#get_migrations/8","title":"AWS.LexModelBuilding.get_migrations/8","type":"function"},{"doc":"Returns information about a specific version of a slot type.\n\nIn addition to specifying the slot type name, you must specify the slot type\nversion.\n\nThis operation requires permissions for the `lex:GetSlotType` action.","ref":"AWS.LexModelBuilding.html#get_slot_type/4","title":"AWS.LexModelBuilding.get_slot_type/4","type":"function"},{"doc":"Gets information about all versions of a slot type.\n\nThe `GetSlotTypeVersions` operation returns a `SlotTypeMetadata` object for each\nversion of a slot type. For example, if a slot type has three numbered versions,\nthe `GetSlotTypeVersions` operation returns four `SlotTypeMetadata` objects in\nthe response, one for each numbered version and one for the `$LATEST` version.\n\nThe `GetSlotTypeVersions` operation always returns at least one version, the\n`$LATEST` version.\n\nThis operation requires permissions for the `lex:GetSlotTypeVersions` action.","ref":"AWS.LexModelBuilding.html#get_slot_type_versions/5","title":"AWS.LexModelBuilding.get_slot_type_versions/5","type":"function"},{"doc":"Returns slot type information as follows:\n\n  * If you specify the `nameContains` field, returns the `$LATEST`\nversion of all slot types that contain the specified string.\n\n  * If you don't specify the `nameContains` field, returns information\nabout the `$LATEST` version of all slot types.\n\nThe operation requires permission for the `lex:GetSlotTypes` action.","ref":"AWS.LexModelBuilding.html#get_slot_types/5","title":"AWS.LexModelBuilding.get_slot_types/5","type":"function"},{"doc":"Use the `GetUtterancesView` operation to get information about the utterances\nthat your users have made to your bot.\n\nYou can use this list to tune the utterances that your bot responds to.\n\nFor example, say that you have created a bot to order flowers. After your users\nhave used your bot for a while, use the `GetUtterancesView` operation to see the\nrequests that they have made and whether they have been successful. You might\nfind that the utterance \"I want flowers\" is not being recognized. You could add\nthis utterance to the `OrderFlowers` intent so that your bot recognizes that\nutterance.\n\nAfter you publish a new version of a bot, you can get information about the old\nversion and the new so that you can compare the performance across the two\nversions.\n\nUtterance statistics are generated once a day. Data is available for the last 15\ndays. You can request information for up to 5 versions of your bot in each\nrequest. Amazon Lex returns the most frequent utterances received by the bot in\nthe last 15 days. The response contains information about a maximum of 100\nutterances for each version.\n\nIf you set `childDirected` field to true when you created your bot, if you are\nusing slot obfuscation with one or more slots, or if you opted out of\nparticipating in improving Amazon Lex, utterances are not available.\n\nThis operation requires permissions for the `lex:GetUtterancesView` action.","ref":"AWS.LexModelBuilding.html#get_utterances_view/5","title":"AWS.LexModelBuilding.get_utterances_view/5","type":"function"},{"doc":"Gets a list of tags associated with the specified resource.\n\nOnly bots, bot aliases, and bot channels can have tags associated with them.","ref":"AWS.LexModelBuilding.html#list_tags_for_resource/3","title":"AWS.LexModelBuilding.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.LexModelBuilding.html#metadata/0","title":"AWS.LexModelBuilding.metadata/0","type":"function"},{"doc":"Creates an Amazon Lex conversational bot or replaces an existing bot.\n\nWhen you create or update a bot you are only required to specify a name, a\nlocale, and whether the bot is directed toward children under age 13. You can\nuse this to add intents later, or to remove intents from an existing bot. When\nyou create a bot with the minimum information, the bot is created or updated but\nAmazon Lex returns the ` response `FAILED`. You can build the bot after you add\none or more intents. For more information about Amazon Lex bots, see\n`how-it-works`. `\n\n```\nIf you specify the name of an existing bot, the fields in the request replace\nthe existing values in the `$LATEST` version of the bot. Amazon Lex removes any\nfields that you don't provide values for in the request, except for the\n`idleTTLInSeconds` and `privacySettings` fields, which are set to their default\nvalues. If you don't specify values for required fields, Amazon Lex throws an\nexception.\n\nThis operation requires permissions for the `lex:PutBot` action. For more\ninformation, see `security-iam`.\n\n```","ref":"AWS.LexModelBuilding.html#put_bot/4","title":"AWS.LexModelBuilding.put_bot/4","type":"function"},{"doc":"Creates an alias for the specified version of the bot or replaces an alias for\nthe specified bot.\n\nTo change the version of the bot that the alias points to, replace the alias.\nFor more information about aliases, see `versioning-aliases`.\n\nThis operation requires permissions for the `lex:PutBotAlias` action.","ref":"AWS.LexModelBuilding.html#put_bot_alias/5","title":"AWS.LexModelBuilding.put_bot_alias/5","type":"function"},{"doc":"Creates an intent or replaces an existing intent.\n\nTo define the interaction between the user and your bot, you use one or more\nintents. For a pizza ordering bot, for example, you would create an `OrderPizza`\nintent.\n\nTo create an intent or replace an existing intent, you must provide the\nfollowing:\n\n  * Intent name. For example, `OrderPizza`.\n\n  * Sample utterances. For example, \"Can I order a pizza, please.\" and\n\"I want to order a pizza.\"\n\n  * Information to be gathered. You specify slot types for the\ninformation that your bot will request from the user. You can specify standard\nslot types, such as a date or a time, or custom slot types such as the size and\ncrust of a pizza.\n\n  * How the intent will be fulfilled. You can provide a Lambda\nfunction or configure the intent to return the intent information to the client\napplication. If you use a Lambda function, when all of the intent information is\navailable, Amazon Lex invokes your Lambda function. If you configure your intent\nto return the intent information to the client application.\n\nYou can specify other optional information in the request, such as:\n\n  * A confirmation prompt to ask the user to confirm an intent. For\nexample, \"Shall I order your pizza?\"\n\n  * A conclusion statement to send to the user after the intent has\nbeen fulfilled. For example, \"I placed your pizza order.\"\n\n  * A follow-up prompt that asks the user for additional activity. For\nexample, asking \"Do you want to order a drink with your pizza?\"\n\nIf you specify an existing intent name to update the intent, Amazon Lex replaces\nthe values in the `$LATEST` version of the intent with the values in the\nrequest. Amazon Lex removes fields that you don't provide in the request. If you\ndon't specify the required fields, Amazon Lex throws an exception. When you\nupdate the `$LATEST` version of an intent, the `status` field of any bot that\nuses the `$LATEST` version of the intent is set to `NOT_BUILT`.\n\nFor more information, see `how-it-works`.\n\nThis operation requires permissions for the `lex:PutIntent` action.","ref":"AWS.LexModelBuilding.html#put_intent/4","title":"AWS.LexModelBuilding.put_intent/4","type":"function"},{"doc":"Creates a custom slot type or replaces an existing custom slot type.\n\nTo create a custom slot type, specify a name for the slot type and a set of\nenumeration values, which are the values that a slot of this type can assume.\nFor more information, see `how-it-works`.\n\nIf you specify the name of an existing slot type, the fields in the request\nreplace the existing values in the `$LATEST` version of the slot type. Amazon\nLex removes the fields that you don't provide in the request. If you don't\nspecify required fields, Amazon Lex throws an exception. When you update the\n`$LATEST` version of a slot type, if a bot uses the `$LATEST` version of an\nintent that contains the slot type, the bot's `status` field is set to\n`NOT_BUILT`.\n\nThis operation requires permissions for the `lex:PutSlotType` action.","ref":"AWS.LexModelBuilding.html#put_slot_type/4","title":"AWS.LexModelBuilding.put_slot_type/4","type":"function"},{"doc":"Starts a job to import a resource to Amazon Lex.","ref":"AWS.LexModelBuilding.html#start_import/3","title":"AWS.LexModelBuilding.start_import/3","type":"function"},{"doc":"Starts migrating a bot from Amazon Lex V1 to Amazon Lex V2.\n\nMigrate your bot when you want to take advantage of the new features of Amazon\nLex V2.\n\nFor more information, see [Migrating a bot](https://docs.aws.amazon.com/lex/latest/dg/migrate.html) in the *Amazon Lex\ndeveloper guide*.","ref":"AWS.LexModelBuilding.html#start_migration/3","title":"AWS.LexModelBuilding.start_migration/3","type":"function"},{"doc":"Adds the specified tags to the specified resource.\n\nIf a tag key already exists, the existing value is replaced with the new value.","ref":"AWS.LexModelBuilding.html#tag_resource/4","title":"AWS.LexModelBuilding.tag_resource/4","type":"function"},{"doc":"Removes tags from a bot, bot alias or bot channel.","ref":"AWS.LexModelBuilding.html#untag_resource/4","title":"AWS.LexModelBuilding.untag_resource/4","type":"function"},{"doc":"","ref":"AWS.LexModelsV2.html","title":"AWS.LexModelsV2","type":"module"},{"doc":"Create a batch of custom vocabulary items for a given bot locale's custom\nvocabulary.","ref":"AWS.LexModelsV2.html#batch_create_custom_vocabulary_item/6","title":"AWS.LexModelsV2.batch_create_custom_vocabulary_item/6","type":"function"},{"doc":"Delete a batch of custom vocabulary items for a given bot locale's custom\nvocabulary.","ref":"AWS.LexModelsV2.html#batch_delete_custom_vocabulary_item/6","title":"AWS.LexModelsV2.batch_delete_custom_vocabulary_item/6","type":"function"},{"doc":"Update a batch of custom vocabulary items for a given bot locale's custom\nvocabulary.","ref":"AWS.LexModelsV2.html#batch_update_custom_vocabulary_item/6","title":"AWS.LexModelsV2.batch_update_custom_vocabulary_item/6","type":"function"},{"doc":"Builds a bot, its intents, and its slot types into a specific locale.\n\nA bot can be built into multiple locales. At runtime the locale is used to\nchoose a specific build of the bot.","ref":"AWS.LexModelsV2.html#build_bot_locale/6","title":"AWS.LexModelsV2.build_bot_locale/6","type":"function"},{"doc":"Creates an Amazon Lex conversational bot.","ref":"AWS.LexModelsV2.html#create_bot/3","title":"AWS.LexModelsV2.create_bot/3","type":"function"},{"doc":"Creates an alias for the specified version of a bot.\n\nUse an alias to enable you to change the version of a bot without updating\napplications that use the bot.\n\nFor example, you can create an alias called \"PROD\" that your applications use to\ncall the Amazon Lex bot.","ref":"AWS.LexModelsV2.html#create_bot_alias/4","title":"AWS.LexModelsV2.create_bot_alias/4","type":"function"},{"doc":"Creates a locale in the bot.\n\nThe locale contains the intents and slot types that the bot uses in\nconversations with users in the specified language and locale. You must add a\nlocale to a bot before you can add intents and slot types to the bot.","ref":"AWS.LexModelsV2.html#create_bot_locale/5","title":"AWS.LexModelsV2.create_bot_locale/5","type":"function"},{"doc":"Action to create a replication of the source bot in the secondary region.","ref":"AWS.LexModelsV2.html#create_bot_replica/4","title":"AWS.LexModelsV2.create_bot_replica/4","type":"function"},{"doc":"Creates an immutable version of the bot.\n\nWhen you create the first version of a bot, Amazon Lex sets the version number\nto 1. Subsequent bot versions increase in an increment of 1. The version number\nwill always represent the total number of versions created of the bot, not the\ncurrent number of versions. If a bot version is deleted, that bot version number\nwill not be reused.","ref":"AWS.LexModelsV2.html#create_bot_version/4","title":"AWS.LexModelsV2.create_bot_version/4","type":"function"},{"doc":"Creates a zip archive containing the contents of a bot or a bot locale.\n\nThe archive contains a directory structure that contains JSON files that define\nthe bot.\n\nYou can create an archive that contains the complete definition of a bot, or you\ncan specify that the archive contain only the definition of a single bot locale.\n\nFor more information about exporting bots, and about the structure of the export\narchive, see [ Importing and exporting bots\n](https://docs.aws.amazon.com/lexv2/latest/dg/importing-exporting.html)","ref":"AWS.LexModelsV2.html#create_export/3","title":"AWS.LexModelsV2.create_export/3","type":"function"},{"doc":"Creates an intent.\n\nTo define the interaction between the user and your bot, you define one or more\nintents. For example, for a pizza ordering bot you would create an `OrderPizza`\nintent.\n\nWhen you create an intent, you must provide a name. You can optionally provide\nthe following:\n\n  * Sample utterances. For example, \"I want to order a pizza\" and \"Can\nI order a pizza.\" You can't provide utterances for built-in intents.\n\n  * Information to be gathered. You specify slots for the information\nthat you bot requests from the user. You can specify standard slot types, such\nas date and time, or custom slot types for your application.\n\n  * How the intent is fulfilled. You can provide a Lambda function or\nconfigure the intent to return the intent information to your client\napplication. If you use a Lambda function, Amazon Lex invokes the function when\nall of the intent information is available.\n\n  * A confirmation prompt to send to the user to confirm an intent.\nFor example, \"Shall I order your pizza?\"\n\n  * A conclusion statement to send to the user after the intent is\nfulfilled. For example, \"I ordered your pizza.\"\n\n  * A follow-up prompt that asks the user for additional activity. For\nexample, \"Do you want a drink with your pizza?\"","ref":"AWS.LexModelsV2.html#create_intent/6","title":"AWS.LexModelsV2.create_intent/6","type":"function"},{"doc":"Creates a new resource policy with the specified policy statements.","ref":"AWS.LexModelsV2.html#create_resource_policy/4","title":"AWS.LexModelsV2.create_resource_policy/4","type":"function"},{"doc":"Adds a new resource policy statement to a bot or bot alias.\n\nIf a resource policy exists, the statement is added to the current resource\npolicy. If a policy doesn't exist, a new policy is created.\n\nYou can't create a resource policy statement that allows cross-account access.","ref":"AWS.LexModelsV2.html#create_resource_policy_statement/4","title":"AWS.LexModelsV2.create_resource_policy_statement/4","type":"function"},{"doc":"Creates a slot in an intent.\n\nA slot is a variable needed to fulfill an intent. For example, an `OrderPizza`\nintent might need slots for size, crust, and number of pizzas. For each slot,\nyou define one or more utterances that Amazon Lex uses to elicit a response from\nthe user.","ref":"AWS.LexModelsV2.html#create_slot/7","title":"AWS.LexModelsV2.create_slot/7","type":"function"},{"doc":"Creates a custom slot type\n\nTo create a custom slot type, specify a name for the slot type and a set of\nenumeration values, the values that a slot of this type can assume.","ref":"AWS.LexModelsV2.html#create_slot_type/6","title":"AWS.LexModelsV2.create_slot_type/6","type":"function"},{"doc":"Create a report that describes the differences between the bot and the test set.","ref":"AWS.LexModelsV2.html#create_test_set_discrepancy_report/4","title":"AWS.LexModelsV2.create_test_set_discrepancy_report/4","type":"function"},{"doc":"Gets a pre-signed S3 write URL that you use to upload the zip archive when\nimporting a bot or a bot locale.","ref":"AWS.LexModelsV2.html#create_upload_url/3","title":"AWS.LexModelsV2.create_upload_url/3","type":"function"},{"doc":"Deletes all versions of a bot, including the `Draft` version.\n\nTo delete a specific version, use the `DeleteBotVersion` operation.\n\nWhen you delete a bot, all of the resources contained in the bot are also\ndeleted. Deleting a bot removes all locales, intents, slot, and slot types\ndefined for the bot.\n\nIf a bot has an alias, the `DeleteBot` operation returns a\n`ResourceInUseException` exception. If you want to delete the bot and the alias,\nset the `skipResourceInUseCheck` parameter to `true`.","ref":"AWS.LexModelsV2.html#delete_bot/4","title":"AWS.LexModelsV2.delete_bot/4","type":"function"},{"doc":"Deletes the specified bot alias.","ref":"AWS.LexModelsV2.html#delete_bot_alias/5","title":"AWS.LexModelsV2.delete_bot_alias/5","type":"function"},{"doc":"Removes a locale from a bot.\n\nWhen you delete a locale, all intents, slots, and slot types defined for the\nlocale are also deleted.","ref":"AWS.LexModelsV2.html#delete_bot_locale/6","title":"AWS.LexModelsV2.delete_bot_locale/6","type":"function"},{"doc":"The action to delete the replicated bot in the secondary region.","ref":"AWS.LexModelsV2.html#delete_bot_replica/5","title":"AWS.LexModelsV2.delete_bot_replica/5","type":"function"},{"doc":"Deletes a specific version of a bot.\n\nTo delete all versions of a bot, use the\n[DeleteBot](https://docs.aws.amazon.com/lexv2/latest/APIReference/API_DeleteBot.html)\noperation.","ref":"AWS.LexModelsV2.html#delete_bot_version/5","title":"AWS.LexModelsV2.delete_bot_version/5","type":"function"},{"doc":"Removes a custom vocabulary from the specified locale in the specified bot.","ref":"AWS.LexModelsV2.html#delete_custom_vocabulary/6","title":"AWS.LexModelsV2.delete_custom_vocabulary/6","type":"function"},{"doc":"Removes a previous export and the associated files stored in an S3 bucket.","ref":"AWS.LexModelsV2.html#delete_export/4","title":"AWS.LexModelsV2.delete_export/4","type":"function"},{"doc":"Removes a previous import and the associated file stored in an S3 bucket.","ref":"AWS.LexModelsV2.html#delete_import/4","title":"AWS.LexModelsV2.delete_import/4","type":"function"},{"doc":"Removes the specified intent.\n\nDeleting an intent also deletes the slots associated with the intent.","ref":"AWS.LexModelsV2.html#delete_intent/7","title":"AWS.LexModelsV2.delete_intent/7","type":"function"},{"doc":"Removes an existing policy from a bot or bot alias.\n\nIf the resource doesn't have a policy attached, Amazon Lex returns an exception.","ref":"AWS.LexModelsV2.html#delete_resource_policy/4","title":"AWS.LexModelsV2.delete_resource_policy/4","type":"function"},{"doc":"Deletes a policy statement from a resource policy.\n\nIf you delete the last statement from a policy, the policy is deleted. If you\nspecify a statement ID that doesn't exist in the policy, or if the bot or bot\nalias doesn't have a policy attached, Amazon Lex returns an exception.","ref":"AWS.LexModelsV2.html#delete_resource_policy_statement/5","title":"AWS.LexModelsV2.delete_resource_policy_statement/5","type":"function"},{"doc":"Deletes the specified slot from an intent.","ref":"AWS.LexModelsV2.html#delete_slot/8","title":"AWS.LexModelsV2.delete_slot/8","type":"function"},{"doc":"Deletes a slot type from a bot locale.\n\nIf a slot is using the slot type, Amazon Lex throws a `ResourceInUseException`\nexception. To avoid the exception, set the `skipResourceInUseCheck` parameter to\n`true`.","ref":"AWS.LexModelsV2.html#delete_slot_type/7","title":"AWS.LexModelsV2.delete_slot_type/7","type":"function"},{"doc":"The action to delete the selected test set.","ref":"AWS.LexModelsV2.html#delete_test_set/4","title":"AWS.LexModelsV2.delete_test_set/4","type":"function"},{"doc":"Deletes stored utterances.\n\nAmazon Lex stores the utterances that users send to your bot. Utterances are\nstored for 15 days for use with the\n[ListAggregatedUtterances](https://docs.aws.amazon.com/lexv2/latest/APIReference/API_ListAggregatedUtterances.html)\noperation, and then stored indefinitely for use in improving the ability of your\nbot to respond to user input..\n\nUse the `DeleteUtterances` operation to manually delete utterances for a\nspecific session. When you use the `DeleteUtterances` operation, utterances\nstored for improving your bot's ability to respond to user input are deleted\nimmediately. Utterances stored for use with the `ListAggregatedUtterances`\noperation are deleted after 15 days.","ref":"AWS.LexModelsV2.html#delete_utterances/4","title":"AWS.LexModelsV2.delete_utterances/4","type":"function"},{"doc":"Provides metadata information about a bot.","ref":"AWS.LexModelsV2.html#describe_bot/3","title":"AWS.LexModelsV2.describe_bot/3","type":"function"},{"doc":"Get information about a specific bot alias.","ref":"AWS.LexModelsV2.html#describe_bot_alias/4","title":"AWS.LexModelsV2.describe_bot_alias/4","type":"function"},{"doc":"Describes the settings that a bot has for a specific locale.","ref":"AWS.LexModelsV2.html#describe_bot_locale/5","title":"AWS.LexModelsV2.describe_bot_locale/5","type":"function"},{"doc":"Provides metadata information about a bot recommendation.\n\nThis information will enable you to get a description on the request inputs, to\ndownload associated transcripts after processing is complete, and to download\nintents and slot-types generated by the bot recommendation.","ref":"AWS.LexModelsV2.html#describe_bot_recommendation/6","title":"AWS.LexModelsV2.describe_bot_recommendation/6","type":"function"},{"doc":"Monitors the bot replication status through the UI console.","ref":"AWS.LexModelsV2.html#describe_bot_replica/4","title":"AWS.LexModelsV2.describe_bot_replica/4","type":"function"},{"doc":"Returns information about a request to generate a bot through natural language\ndescription, made through the `StartBotResource` API.\n\nUse the `generatedBotLocaleUrl` to retrieve the Amazon S3 object containing the\nbot locale configuration. You can then modify and import this configuration.","ref":"AWS.LexModelsV2.html#describe_bot_resource_generation/6","title":"AWS.LexModelsV2.describe_bot_resource_generation/6","type":"function"},{"doc":"Provides metadata about a version of a bot.","ref":"AWS.LexModelsV2.html#describe_bot_version/4","title":"AWS.LexModelsV2.describe_bot_version/4","type":"function"},{"doc":"Provides metadata information about a custom vocabulary.","ref":"AWS.LexModelsV2.html#describe_custom_vocabulary_metadata/5","title":"AWS.LexModelsV2.describe_custom_vocabulary_metadata/5","type":"function"},{"doc":"Gets information about a specific export.","ref":"AWS.LexModelsV2.html#describe_export/3","title":"AWS.LexModelsV2.describe_export/3","type":"function"},{"doc":"Gets information about a specific import.","ref":"AWS.LexModelsV2.html#describe_import/3","title":"AWS.LexModelsV2.describe_import/3","type":"function"},{"doc":"Returns metadata about an intent.","ref":"AWS.LexModelsV2.html#describe_intent/6","title":"AWS.LexModelsV2.describe_intent/6","type":"function"},{"doc":"Gets the resource policy and policy revision for a bot or bot alias.","ref":"AWS.LexModelsV2.html#describe_resource_policy/3","title":"AWS.LexModelsV2.describe_resource_policy/3","type":"function"},{"doc":"Gets metadata information about a slot.","ref":"AWS.LexModelsV2.html#describe_slot/7","title":"AWS.LexModelsV2.describe_slot/7","type":"function"},{"doc":"Gets metadata information about a slot type.","ref":"AWS.LexModelsV2.html#describe_slot_type/6","title":"AWS.LexModelsV2.describe_slot_type/6","type":"function"},{"doc":"Gets metadata information about the test execution.","ref":"AWS.LexModelsV2.html#describe_test_execution/3","title":"AWS.LexModelsV2.describe_test_execution/3","type":"function"},{"doc":"Gets metadata information about the test set.","ref":"AWS.LexModelsV2.html#describe_test_set/3","title":"AWS.LexModelsV2.describe_test_set/3","type":"function"},{"doc":"Gets metadata information about the test set discrepancy report.","ref":"AWS.LexModelsV2.html#describe_test_set_discrepancy_report/3","title":"AWS.LexModelsV2.describe_test_set_discrepancy_report/3","type":"function"},{"doc":"Gets metadata information about the test set generation.","ref":"AWS.LexModelsV2.html#describe_test_set_generation/3","title":"AWS.LexModelsV2.describe_test_set_generation/3","type":"function"},{"doc":"Generates sample utterances for an intent.","ref":"AWS.LexModelsV2.html#generate_bot_element/6","title":"AWS.LexModelsV2.generate_bot_element/6","type":"function"},{"doc":"The pre-signed Amazon S3 URL to download the test execution result artifacts.","ref":"AWS.LexModelsV2.html#get_test_execution_artifacts_url/3","title":"AWS.LexModelsV2.get_test_execution_artifacts_url/3","type":"function"},{"doc":"Provides a list of utterances that users have sent to the bot.\n\nUtterances are aggregated by the text of the utterance. For example, all\ninstances where customers used the phrase \"I want to order pizza\" are aggregated\ninto the same line in the response.\n\nYou can see both detected utterances and missed utterances. A detected utterance\nis where the bot properly recognized the utterance and activated the associated\nintent. A missed utterance was not recognized by the bot and didn't activate an\nintent.\n\nUtterances can be aggregated for a bot alias or for a bot version, but not both\nat the same time.\n\nUtterances statistics are not generated under the following conditions:\n\n  * The `childDirected` field was set to true when the bot was\ncreated.\n\n  * You are using slot obfuscation with one or more slots.\n\n  * You opted out of participating in improving Amazon Lex.","ref":"AWS.LexModelsV2.html#list_aggregated_utterances/4","title":"AWS.LexModelsV2.list_aggregated_utterances/4","type":"function"},{"doc":"The action to list the replicated bots created from the source bot alias.","ref":"AWS.LexModelsV2.html#list_bot_alias_replicas/5","title":"AWS.LexModelsV2.list_bot_alias_replicas/5","type":"function"},{"doc":"Gets a list of aliases for the specified bot.","ref":"AWS.LexModelsV2.html#list_bot_aliases/4","title":"AWS.LexModelsV2.list_bot_aliases/4","type":"function"},{"doc":"Gets a list of locales for the specified bot.","ref":"AWS.LexModelsV2.html#list_bot_locales/5","title":"AWS.LexModelsV2.list_bot_locales/5","type":"function"},{"doc":"Get a list of bot recommendations that meet the specified criteria.","ref":"AWS.LexModelsV2.html#list_bot_recommendations/6","title":"AWS.LexModelsV2.list_bot_recommendations/6","type":"function"},{"doc":"The action to list the replicated bots.","ref":"AWS.LexModelsV2.html#list_bot_replicas/4","title":"AWS.LexModelsV2.list_bot_replicas/4","type":"function"},{"doc":"Lists the generation requests made for a bot locale.","ref":"AWS.LexModelsV2.html#list_bot_resource_generations/6","title":"AWS.LexModelsV2.list_bot_resource_generations/6","type":"function"},{"doc":"Contains information about all the versions replication statuses applicable for\nGlobal Resiliency.","ref":"AWS.LexModelsV2.html#list_bot_version_replicas/5","title":"AWS.LexModelsV2.list_bot_version_replicas/5","type":"function"},{"doc":"Gets information about all of the versions of a bot.\n\nThe `ListBotVersions` operation returns a summary of each version of a bot. For\nexample, if a bot has three numbered versions, the `ListBotVersions` operation\nreturns for summaries, one for each numbered version and one for the `DRAFT`\nversion.\n\nThe `ListBotVersions` operation always returns at least one version, the `DRAFT`\nversion.","ref":"AWS.LexModelsV2.html#list_bot_versions/4","title":"AWS.LexModelsV2.list_bot_versions/4","type":"function"},{"doc":"Gets a list of available bots.","ref":"AWS.LexModelsV2.html#list_bots/3","title":"AWS.LexModelsV2.list_bots/3","type":"function"},{"doc":"Gets a list of built-in intents provided by Amazon Lex that you can use in your\nbot.\n\nTo use a built-in intent as a the base for your own intent, include the built-in\nintent signature in the `parentIntentSignature` parameter when you call the\n`CreateIntent` operation. For more information, see\n[CreateIntent](https://docs.aws.amazon.com/lexv2/latest/APIReference/API_CreateIntent.html).","ref":"AWS.LexModelsV2.html#list_built_in_intents/4","title":"AWS.LexModelsV2.list_built_in_intents/4","type":"function"},{"doc":"Gets a list of built-in slot types that meet the specified criteria.","ref":"AWS.LexModelsV2.html#list_built_in_slot_types/4","title":"AWS.LexModelsV2.list_built_in_slot_types/4","type":"function"},{"doc":"Paginated list of custom vocabulary items for a given bot locale's custom\nvocabulary.","ref":"AWS.LexModelsV2.html#list_custom_vocabulary_items/6","title":"AWS.LexModelsV2.list_custom_vocabulary_items/6","type":"function"},{"doc":"Lists the exports for a bot, bot locale, or custom vocabulary.\n\nExports are kept in the list for 7 days.","ref":"AWS.LexModelsV2.html#list_exports/3","title":"AWS.LexModelsV2.list_exports/3","type":"function"},{"doc":"Lists the imports for a bot, bot locale, or custom vocabulary.\n\nImports are kept in the list for 7 days.","ref":"AWS.LexModelsV2.html#list_imports/3","title":"AWS.LexModelsV2.list_imports/3","type":"function"},{"doc":"Retrieves summary metrics for the intents in your bot.\n\nThe following fields are required:\n\n  * `metrics` – A list of\n[AnalyticsIntentMetric](https://docs.aws.amazon.com/lexv2/latest/APIReference/API_AnalyticsIntentMetric.html)\nobjects. In each object, use the `name` field to specify the metric to\ncalculate, the `statistic` field to specify whether to calculate the `Sum`,\n`Average`, or `Max` number, and the `order` field to specify whether to sort the\nresults in `Ascending` or `Descending` order.\n\n  * `startDateTime` and `endDateTime` – Define a time range for which\nyou want to retrieve results.\n\nOf the optional fields, you can organize the results in the following ways:\n\n  * Use the `filters` field to filter the results, the `groupBy` field\nto specify categories by which to group the results, and the `binBy` field to\nspecify time intervals by which to group the results.\n\n  * Use the `maxResults` field to limit the number of results to\nreturn in a single response and the `nextToken` field to return the next batch\nof results if the response does not return the full set of results.\n\nNote that an `order` field exists in both `binBy` and `metrics`. You can specify\nonly one `order` in a given request.","ref":"AWS.LexModelsV2.html#list_intent_metrics/4","title":"AWS.LexModelsV2.list_intent_metrics/4","type":"function"},{"doc":"Retrieves summary statistics for a path of intents that users take over sessions\nwith your bot.\n\nThe following fields are required:\n\n  * `startDateTime` and `endDateTime` – Define a time range for which\nyou want to retrieve results.\n\n  * `intentPath` – Define an order of intents for which you want to\nretrieve metrics. Separate intents in the path with a forward slash. For\nexample, populate the `intentPath` field with `/BookCar/BookHotel` to see\ndetails about how many times users invoked the `BookCar` and `BookHotel` intents\nin that order.\n\nUse the optional `filters` field to filter the results.","ref":"AWS.LexModelsV2.html#list_intent_paths/4","title":"AWS.LexModelsV2.list_intent_paths/4","type":"function"},{"doc":"Retrieves summary metrics for the stages within intents in your bot.\n\nThe following fields are required:\n\n  * `metrics` – A list of\n[AnalyticsIntentStageMetric](https://docs.aws.amazon.com/lexv2/latest/APIReference/API_AnalyticsIntentStageMetric.html)\nobjects. In each object, use the `name` field to specify the metric to\ncalculate, the `statistic` field to specify whether to calculate the `Sum`,\n`Average`, or `Max` number, and the `order` field to specify whether to sort the\nresults in `Ascending` or `Descending` order.\n\n  * `startDateTime` and `endDateTime` – Define a time range for which\nyou want to retrieve results.\n\nOf the optional fields, you can organize the results in the following ways:\n\n  * Use the `filters` field to filter the results, the `groupBy` field\nto specify categories by which to group the results, and the `binBy` field to\nspecify time intervals by which to group the results.\n\n  * Use the `maxResults` field to limit the number of results to\nreturn in a single response and the `nextToken` field to return the next batch\nof results if the response does not return the full set of results.\n\nNote that an `order` field exists in both `binBy` and `metrics`. You can only\nspecify one `order` in a given request.","ref":"AWS.LexModelsV2.html#list_intent_stage_metrics/4","title":"AWS.LexModelsV2.list_intent_stage_metrics/4","type":"function"},{"doc":"Get a list of intents that meet the specified criteria.","ref":"AWS.LexModelsV2.html#list_intents/6","title":"AWS.LexModelsV2.list_intents/6","type":"function"},{"doc":"Gets a list of recommended intents provided by the bot recommendation that you\ncan use in your bot.\n\nIntents in the response are ordered by relevance.","ref":"AWS.LexModelsV2.html#list_recommended_intents/7","title":"AWS.LexModelsV2.list_recommended_intents/7","type":"function"},{"doc":"Retrieves a list of metadata for individual user sessions with your bot.\n\nThe `startDateTime` and `endDateTime` fields are required. These fields define a\ntime range for which you want to retrieve results. Of the optional fields, you\ncan organize the results in the following ways:\n\n  * Use the `filters` field to filter the results and the `sortBy`\nfield to specify the values by which to sort the results.\n\n  * Use the `maxResults` field to limit the number of results to\nreturn in a single response and the `nextToken` field to return the next batch\nof results if the response does not return the full set of results.","ref":"AWS.LexModelsV2.html#list_session_analytics_data/4","title":"AWS.LexModelsV2.list_session_analytics_data/4","type":"function"},{"doc":"Retrieves summary metrics for the user sessions with your bot.\n\nThe following fields are required:\n\n  * `metrics` – A list of\n[AnalyticsSessionMetric](https://docs.aws.amazon.com/lexv2/latest/APIReference/API_AnalyticsSessionMetric.html)\nobjects. In each object, use the `name` field to specify the metric to\ncalculate, the `statistic` field to specify whether to calculate the `Sum`,\n`Average`, or `Max` number, and the `order` field to specify whether to sort the\nresults in `Ascending` or `Descending` order.\n\n  * `startDateTime` and `endDateTime` – Define a time range for which\nyou want to retrieve results.\n\nOf the optional fields, you can organize the results in the following ways:\n\n  * Use the `filters` field to filter the results, the `groupBy` field\nto specify categories by which to group the results, and the `binBy` field to\nspecify time intervals by which to group the results.\n\n  * Use the `maxResults` field to limit the number of results to\nreturn in a single response and the `nextToken` field to return the next batch\nof results if the response does not return the full set of results.\n\nNote that an `order` field exists in both `binBy` and `metrics`. Currently, you\ncan specify it in either field, but not in both.","ref":"AWS.LexModelsV2.html#list_session_metrics/4","title":"AWS.LexModelsV2.list_session_metrics/4","type":"function"},{"doc":"Gets a list of slot types that match the specified criteria.","ref":"AWS.LexModelsV2.html#list_slot_types/6","title":"AWS.LexModelsV2.list_slot_types/6","type":"function"},{"doc":"Gets a list of slots that match the specified criteria.","ref":"AWS.LexModelsV2.html#list_slots/7","title":"AWS.LexModelsV2.list_slots/7","type":"function"},{"doc":"Gets a list of tags associated with a resource.\n\nOnly bots, bot aliases, and bot channels can have tags associated with them.","ref":"AWS.LexModelsV2.html#list_tags_for_resource/3","title":"AWS.LexModelsV2.list_tags_for_resource/3","type":"function"},{"doc":"Gets a list of test execution result items.","ref":"AWS.LexModelsV2.html#list_test_execution_result_items/4","title":"AWS.LexModelsV2.list_test_execution_result_items/4","type":"function"},{"doc":"The list of test set executions.","ref":"AWS.LexModelsV2.html#list_test_executions/3","title":"AWS.LexModelsV2.list_test_executions/3","type":"function"},{"doc":"The list of test set records.","ref":"AWS.LexModelsV2.html#list_test_set_records/4","title":"AWS.LexModelsV2.list_test_set_records/4","type":"function"},{"doc":"The list of the test sets","ref":"AWS.LexModelsV2.html#list_test_sets/3","title":"AWS.LexModelsV2.list_test_sets/3","type":"function"},{"doc":"To use this API operation, your IAM role must have permissions to perform the\n[ListAggregatedUtterances](https://docs.aws.amazon.com/lexv2/latest/APIReference/API_ListAggregatedUtterances.html) operation, which provides access to utterance-related analytics.\n\nSee [Viewing utterance\nstatistics](https://docs.aws.amazon.com/lexv2/latest/dg/monitoring-utterances.html)\nfor the IAM policy to apply to the IAM role.\n\nRetrieves a list of metadata for individual user utterances to your bot. The\nfollowing fields are required:\n\n  * `startDateTime` and `endDateTime` – Define a time range for which\nyou want to retrieve results.\n\nOf the optional fields, you can organize the results in the following ways:\n\n  * Use the `filters` field to filter the results and the `sortBy`\nfield to specify the values by which to sort the results.\n\n  * Use the `maxResults` field to limit the number of results to\nreturn in a single response and the `nextToken` field to return the next batch\nof results if the response does not return the full set of results.","ref":"AWS.LexModelsV2.html#list_utterance_analytics_data/4","title":"AWS.LexModelsV2.list_utterance_analytics_data/4","type":"function"},{"doc":"To use this API operation, your IAM role must have permissions to perform the\n[ListAggregatedUtterances](https://docs.aws.amazon.com/lexv2/latest/APIReference/API_ListAggregatedUtterances.html) operation, which provides access to utterance-related analytics.\n\nSee [Viewing utterance\nstatistics](https://docs.aws.amazon.com/lexv2/latest/dg/monitoring-utterances.html)\nfor the IAM policy to apply to the IAM role.\n\nRetrieves summary metrics for the utterances in your bot. The following fields\nare required:\n\n  * `metrics` – A list of\n[AnalyticsUtteranceMetric](https://docs.aws.amazon.com/lexv2/latest/APIReference/API_AnalyticsUtteranceMetric.html)\nobjects. In each object, use the `name` field to specify the metric to\ncalculate, the `statistic` field to specify whether to calculate the `Sum`,\n`Average`, or `Max` number, and the `order` field to specify whether to sort the\nresults in `Ascending` or `Descending` order.\n\n  * `startDateTime` and `endDateTime` – Define a time range for which\nyou want to retrieve results.\n\nOf the optional fields, you can organize the results in the following ways:\n\n  * Use the `filters` field to filter the results, the `groupBy` field\nto specify categories by which to group the results, and the `binBy` field to\nspecify time intervals by which to group the results.\n\n  * Use the `maxResults` field to limit the number of results to\nreturn in a single response and the `nextToken` field to return the next batch\nof results if the response does not return the full set of results.\n\nNote that an `order` field exists in both `binBy` and `metrics`. Currently, you\ncan specify it in either field, but not in both.","ref":"AWS.LexModelsV2.html#list_utterance_metrics/4","title":"AWS.LexModelsV2.list_utterance_metrics/4","type":"function"},{"doc":"","ref":"AWS.LexModelsV2.html#metadata/0","title":"AWS.LexModelsV2.metadata/0","type":"function"},{"doc":"Search for associated transcripts that meet the specified criteria.","ref":"AWS.LexModelsV2.html#search_associated_transcripts/7","title":"AWS.LexModelsV2.search_associated_transcripts/7","type":"function"},{"doc":"Use this to provide your transcript data, and to start the bot recommendation\nprocess.","ref":"AWS.LexModelsV2.html#start_bot_recommendation/6","title":"AWS.LexModelsV2.start_bot_recommendation/6","type":"function"},{"doc":"Starts a request for the descriptive bot builder to generate a bot locale\nconfiguration based on the prompt you provide it.\n\nAfter you make this call, use the `DescribeBotResourceGeneration` operation to\ncheck on the status of the generation and for the `generatedBotLocaleUrl` when\nthe generation is complete. Use that value to retrieve the Amazon S3 object\ncontaining the bot locale configuration. You can then modify and import this\nconfiguration.","ref":"AWS.LexModelsV2.html#start_bot_resource_generation/6","title":"AWS.LexModelsV2.start_bot_resource_generation/6","type":"function"},{"doc":"Starts importing a bot, bot locale, or custom vocabulary from a zip archive that\nyou uploaded to an S3 bucket.","ref":"AWS.LexModelsV2.html#start_import/3","title":"AWS.LexModelsV2.start_import/3","type":"function"},{"doc":"The action to start test set execution.","ref":"AWS.LexModelsV2.html#start_test_execution/4","title":"AWS.LexModelsV2.start_test_execution/4","type":"function"},{"doc":"The action to start the generation of test set.","ref":"AWS.LexModelsV2.html#start_test_set_generation/3","title":"AWS.LexModelsV2.start_test_set_generation/3","type":"function"},{"doc":"Stop an already running Bot Recommendation request.","ref":"AWS.LexModelsV2.html#stop_bot_recommendation/7","title":"AWS.LexModelsV2.stop_bot_recommendation/7","type":"function"},{"doc":"Adds the specified tags to the specified resource.\n\nIf a tag key already exists, the existing value is replaced with the new value.","ref":"AWS.LexModelsV2.html#tag_resource/4","title":"AWS.LexModelsV2.tag_resource/4","type":"function"},{"doc":"Removes tags from a bot, bot alias, or bot channel.","ref":"AWS.LexModelsV2.html#untag_resource/4","title":"AWS.LexModelsV2.untag_resource/4","type":"function"},{"doc":"Updates the configuration of an existing bot.","ref":"AWS.LexModelsV2.html#update_bot/4","title":"AWS.LexModelsV2.update_bot/4","type":"function"},{"doc":"Updates the configuration of an existing bot alias.","ref":"AWS.LexModelsV2.html#update_bot_alias/5","title":"AWS.LexModelsV2.update_bot_alias/5","type":"function"},{"doc":"Updates the settings that a bot has for a specific locale.","ref":"AWS.LexModelsV2.html#update_bot_locale/6","title":"AWS.LexModelsV2.update_bot_locale/6","type":"function"},{"doc":"Updates an existing bot recommendation request.","ref":"AWS.LexModelsV2.html#update_bot_recommendation/7","title":"AWS.LexModelsV2.update_bot_recommendation/7","type":"function"},{"doc":"Updates the password used to protect an export zip archive.\n\nThe password is not required. If you don't supply a password, Amazon Lex\ngenerates a zip file that is not protected by a password. This is the archive\nthat is available at the pre-signed S3 URL provided by the\n[DescribeExport](https://docs.aws.amazon.com/lexv2/latest/APIReference/API_DescribeExport.html)\noperation.","ref":"AWS.LexModelsV2.html#update_export/4","title":"AWS.LexModelsV2.update_export/4","type":"function"},{"doc":"Updates the settings for an intent.","ref":"AWS.LexModelsV2.html#update_intent/7","title":"AWS.LexModelsV2.update_intent/7","type":"function"},{"doc":"Replaces the existing resource policy for a bot or bot alias with a new one.\n\nIf the policy doesn't exist, Amazon Lex returns an exception.","ref":"AWS.LexModelsV2.html#update_resource_policy/4","title":"AWS.LexModelsV2.update_resource_policy/4","type":"function"},{"doc":"Updates the settings for a slot.","ref":"AWS.LexModelsV2.html#update_slot/8","title":"AWS.LexModelsV2.update_slot/8","type":"function"},{"doc":"Updates the configuration of an existing slot type.","ref":"AWS.LexModelsV2.html#update_slot_type/7","title":"AWS.LexModelsV2.update_slot_type/7","type":"function"},{"doc":"The action to update the test set.","ref":"AWS.LexModelsV2.html#update_test_set/4","title":"AWS.LexModelsV2.update_test_set/4","type":"function"},{"doc":"Amazon Lex provides both build and runtime endpoints.\n\nEach endpoint provides a set of operations (API). Your conversational bot uses\nthe runtime API to understand user utterances (user input text or voice). For\nexample, suppose a user says \"I want pizza\", your bot sends this input to Amazon\nLex using the runtime API. Amazon Lex recognizes that the user request is for\nthe OrderPizza intent (one of the intents defined in the bot). Then Amazon Lex\nengages in user conversation on behalf of the bot to elicit required information\n(slot values, such as pizza size and crust type), and then performs fulfillment\nactivity (that you configured when you created the bot). You use the build-time\nAPI to create and manage your Amazon Lex bot. For a list of build-time\noperations, see the build-time API, .","ref":"AWS.LexRuntime.html","title":"AWS.LexRuntime","type":"module"},{"doc":"Removes session information for a specified bot, alias, and user ID.","ref":"AWS.LexRuntime.html#delete_session/6","title":"AWS.LexRuntime.delete_session/6","type":"function"},{"doc":"Returns session information for a specified bot, alias, and user ID.","ref":"AWS.LexRuntime.html#get_session/6","title":"AWS.LexRuntime.get_session/6","type":"function"},{"doc":"","ref":"AWS.LexRuntime.html#metadata/0","title":"AWS.LexRuntime.metadata/0","type":"function"},{"doc":"Sends user input (text or speech) to Amazon Lex.\n\nClients use this API to send text and audio requests to Amazon Lex at runtime.\nAmazon Lex interprets the user input using the machine learning model that it\nbuilt for the bot.\n\nThe `PostContent` operation supports audio input at 8kHz and 16kHz. You can use\n8kHz audio to achieve higher speech recognition accuracy in telephone audio\napplications.\n\nIn response, Amazon Lex returns the next message to convey to the user. Consider\nthe following example messages:\n\n  * For a user input \"I would like a pizza,\" Amazon Lex might return a\nresponse with a message eliciting slot data (for example, `PizzaSize`): \"What\nsize pizza would you like?\".\n\n  * After the user provides all of the pizza order information, Amazon\nLex might return a response with a message to get user confirmation: \"Order the\npizza?\".\n\n  * After the user replies \"Yes\" to the confirmation prompt, Amazon\nLex might return a conclusion statement: \"Thank you, your cheese pizza has been\nordered.\".\n\nNot all Amazon Lex messages require a response from the user. For example,\nconclusion statements do not require a response. Some messages require only a\nyes or no response. In addition to the `message`, Amazon Lex provides additional\ncontext about the message in the response that you can use to enhance client\nbehavior, such as displaying the appropriate client user interface. Consider the\nfollowing examples:\n\n  * If the message is to elicit slot data, Amazon Lex returns the\nfollowing context information:\n\n    * `x-amz-lex-dialog-state` header set to `ElicitSlot`\n\n    * `x-amz-lex-intent-name` header set to the intent name\nin the current context\n\n    * `x-amz-lex-slot-to-elicit` header set to the slot name\nfor which the `message` is eliciting information\n\n    * `x-amz-lex-slots` header set to a map of slots\nconfigured for the intent with their current values\n\n  * If the message is a confirmation prompt, the\n`x-amz-lex-dialog-state` header is set to `Confirmation` and the\n`x-amz-lex-slot-to-elicit` header is omitted.\n\n  * If the message is a clarification prompt configured for the\nintent, indicating that the user intent is not understood, the\n`x-amz-dialog-state` header is set to `ElicitIntent` and the\n`x-amz-slot-to-elicit` header is omitted.\n\nIn addition, Amazon Lex also returns your application-specific\n`sessionAttributes`. For more information, see [Managing Conversation Context](https://docs.aws.amazon.com/lex/latest/dg/context-mgmt.html).","ref":"AWS.LexRuntime.html#post_content/6","title":"AWS.LexRuntime.post_content/6","type":"function"},{"doc":"Sends user input to Amazon Lex.\n\nClient applications can use this API to send requests to Amazon Lex at runtime.\nAmazon Lex then interprets the user input using the machine learning model it\nbuilt for the bot.\n\nIn response, Amazon Lex returns the next `message` to convey to the user an\noptional `responseCard` to display. Consider the following example messages:\n\n  * For a user input \"I would like a pizza\", Amazon Lex might return a\nresponse with a message eliciting slot data (for example, PizzaSize): \"What size\npizza would you like?\"\n\n  * After the user provides all of the pizza order information, Amazon\nLex might return a response with a message to obtain user confirmation \"Proceed\nwith the pizza order?\".\n\n  * After the user replies to a confirmation prompt with a \"yes\",\nAmazon Lex might return a conclusion statement: \"Thank you, your cheese pizza\nhas been ordered.\".\n\nNot all Amazon Lex messages require a user response. For example, a conclusion\nstatement does not require a response. Some messages require only a \"yes\" or\n\"no\" user response. In addition to the `message`, Amazon Lex provides additional\ncontext about the message in the response that you might use to enhance client\nbehavior, for example, to display the appropriate client user interface. These\nare the `slotToElicit`, `dialogState`, `intentName`, and `slots` fields in the\nresponse. Consider the following examples:\n\n  * If the message is to elicit slot data, Amazon Lex returns the\nfollowing context information:\n\n    * `dialogState` set to ElicitSlot\n\n    * `intentName` set to the intent name in the current\ncontext\n\n    * `slotToElicit` set to the slot name for which the\n`message` is eliciting information\n\n    * `slots` set to a map of slots, configured for the\nintent, with currently known values\n\n  * If the message is a confirmation prompt, the `dialogState` is set\nto ConfirmIntent and `SlotToElicit` is set to null.\n\n  * If the message is a clarification prompt (configured for the\nintent) that indicates that user intent is not understood, the `dialogState` is\nset to ElicitIntent and `slotToElicit` is set to null.\n\nIn addition, Amazon Lex also returns your application-specific\n`sessionAttributes`. For more information, see [Managing Conversation Context](https://docs.aws.amazon.com/lex/latest/dg/context-mgmt.html).","ref":"AWS.LexRuntime.html#post_text/6","title":"AWS.LexRuntime.post_text/6","type":"function"},{"doc":"Creates a new session or modifies an existing session with an Amazon Lex bot.\n\nUse this operation to enable your application to set the state of the bot.\n\nFor more information, see [Managing Sessions](https://docs.aws.amazon.com/lex/latest/dg/how-session-api.html).","ref":"AWS.LexRuntime.html#put_session/6","title":"AWS.LexRuntime.put_session/6","type":"function"},{"doc":"This section contains documentation for the Amazon Lex V2 Runtime V2 API\noperations.","ref":"AWS.LexRuntimeV2.html","title":"AWS.LexRuntimeV2","type":"module"},{"doc":"Removes session information for a specified bot, alias, and user ID.\n\nYou can use this operation to restart a conversation with a bot. When you remove\na session, the entire history of the session is removed so that you can start\nagain.\n\nYou don't need to delete a session. Sessions have a time limit and will expire.\nSet the session time limit when you create the bot. The default is 5 minutes,\nbut you can specify anything between 1 minute and 24 hours.\n\nIf you specify a bot or alias ID that doesn't exist, you receive a\n`BadRequestException.`\n\nIf the locale doesn't exist in the bot, or if the locale hasn't been enables for\nthe alias, you receive a `BadRequestException`.","ref":"AWS.LexRuntimeV2.html#delete_session/7","title":"AWS.LexRuntimeV2.delete_session/7","type":"function"},{"doc":"Returns session information for a specified bot, alias, and user.\n\nFor example, you can use this operation to retrieve session information for a\nuser that has left a long-running session in use.\n\nIf the bot, alias, or session identifier doesn't exist, Amazon Lex V2 returns a\n`BadRequestException`. If the locale doesn't exist or is not enabled for the\nalias, you receive a `BadRequestException`.","ref":"AWS.LexRuntimeV2.html#get_session/6","title":"AWS.LexRuntimeV2.get_session/6","type":"function"},{"doc":"","ref":"AWS.LexRuntimeV2.html#metadata/0","title":"AWS.LexRuntimeV2.metadata/0","type":"function"},{"doc":"Creates a new session or modifies an existing session with an Amazon Lex V2 bot.\n\nUse this operation to enable your application to set the state of the bot.","ref":"AWS.LexRuntimeV2.html#put_session/7","title":"AWS.LexRuntimeV2.put_session/7","type":"function"},{"doc":"Sends user input to Amazon Lex V2.\n\nClient applications use this API to send requests to Amazon Lex V2 at runtime.\nAmazon Lex V2 then interprets the user input using the machine learning model\nthat it build for the bot.\n\nIn response, Amazon Lex V2 returns the next message to convey to the user and an\noptional response card to display.\n\nIf the optional post-fulfillment response is specified, the messages are\nreturned as follows. For more information, see\n[PostFulfillmentStatusSpecification](https://docs.aws.amazon.com/lexv2/latest/dg/API_PostFulfillmentStatusSpecification.html).    * **Success message** - Returned if the Lambda function completes\nsuccessfully and the intent state is fulfilled or ready fulfillment if the\nmessage is present.\n\n  * **Failed message** - The failed message is returned if the Lambda\nfunction throws an exception or if the Lambda function returns a failed intent\nstate without a message.\n\n  * **Timeout message** - If you don't configure a timeout message and\na timeout, and the Lambda function doesn't return within 30 seconds, the timeout\nmessage is returned. If you configure a timeout, the timeout message is returned\nwhen the period times out.\n\nFor more information, see [Completion\nmessage](https://docs.aws.amazon.com/lexv2/latest/dg/streaming-progress.html#progress-complete.html).","ref":"AWS.LexRuntimeV2.html#recognize_text/7","title":"AWS.LexRuntimeV2.recognize_text/7","type":"function"},{"doc":"Sends user input to Amazon Lex V2.\n\nYou can send text or speech. Clients use this API to send text and audio\nrequests to Amazon Lex V2 at runtime. Amazon Lex V2 interprets the user input\nusing the machine learning model built for the bot.\n\nThe following request fields must be compressed with gzip and then base64\nencoded before you send them to Amazon Lex V2.\n\n  * requestAttributes\n\n  * sessionState\n\nThe following response fields are compressed using gzip and then base64 encoded\nby Amazon Lex V2. Before you can use these fields, you must decode and\ndecompress them.\n\n  * inputTranscript\n\n  * interpretations\n\n  * messages\n\n  * requestAttributes\n\n  * sessionState\n\nThe example contains a Java application that compresses and encodes a Java\nobject to send to Amazon Lex V2, and a second that decodes and decompresses a\nresponse from Amazon Lex V2.\n\nIf the optional post-fulfillment response is specified, the messages are\nreturned as follows. For more information, see\n[PostFulfillmentStatusSpecification](https://docs.aws.amazon.com/lexv2/latest/dg/API_PostFulfillmentStatusSpecification.html).    * **Success message** - Returned if the Lambda function completes\nsuccessfully and the intent state is fulfilled or ready fulfillment if the\nmessage is present.\n\n  * **Failed message** - The failed message is returned if the Lambda\nfunction throws an exception or if the Lambda function returns a failed intent\nstate without a message.\n\n  * **Timeout message** - If you don't configure a timeout message and\na timeout, and the Lambda function doesn't return within 30 seconds, the timeout\nmessage is returned. If you configure a timeout, the timeout message is returned\nwhen the period times out.\n\nFor more information, see [Completion\nmessage](https://docs.aws.amazon.com/lexv2/latest/dg/streaming-progress.html#progress-complete.html).","ref":"AWS.LexRuntimeV2.html#recognize_utterance/7","title":"AWS.LexRuntimeV2.recognize_utterance/7","type":"function"},{"doc":"Starts an HTTP/2 bidirectional event stream that enables you to send audio,\ntext, or DTMF input in real time.\n\nAfter your application starts a conversation, users send input to Amazon Lex V2\nas a stream of events. Amazon Lex V2 processes the incoming events and responds\nwith streaming text or audio events.\n\nAudio input must be in the following format: `audio/lpcm sample-rate=8000\nsample-size-bits=16 channel-count=1; is-big-endian=false`.\n\nIf the optional post-fulfillment response is specified, the messages are\nreturned as follows. For more information, see\n[PostFulfillmentStatusSpecification](https://docs.aws.amazon.com/lexv2/latest/dg/API_PostFulfillmentStatusSpecification.html).    * **Success message** - Returned if the Lambda function completes\nsuccessfully and the intent state is fulfilled or ready fulfillment if the\nmessage is present.\n\n  * **Failed message** - The failed message is returned if the Lambda\nfunction throws an exception or if the Lambda function returns a failed intent\nstate without a message.\n\n  * **Timeout message** - If you don't configure a timeout message and\na timeout, and the Lambda function doesn't return within 30 seconds, the timeout\nmessage is returned. If you configure a timeout, the timeout message is returned\nwhen the period times out.\n\nFor more information, see [Completion\nmessage](https://docs.aws.amazon.com/lexv2/latest/dg/streaming-progress.html#progress-complete.html).\n\nIf the optional update message is configured, it is played at the specified\nfrequency while the Lambda function is running and the update message state is\nactive. If the fulfillment update message is not active, the Lambda function\nruns with a 30 second timeout.\n\nFor more information, see [Update message\n](https://docs.aws.amazon.com/lexv2/latest/dg/streaming-progress.html#progress-update.html)\n\nThe `StartConversation` operation is supported only in the following SDKs:\n\n  * [AWS SDK for C++](https://docs.aws.amazon.com/goto/SdkForCpp/runtime.lex.v2-2020-08-07/StartConversation)\n\n  * [AWS SDK for Java V2](https://docs.aws.amazon.com/goto/SdkForJavaV2/runtime.lex.v2-2020-08-07/StartConversation)\n\n  * [AWS SDK for Ruby V3](https://docs.aws.amazon.com/goto/SdkForRubyV3/runtime.lex.v2-2020-08-07/StartConversation)","ref":"AWS.LexRuntimeV2.html#start_conversation/7","title":"AWS.LexRuntimeV2.start_conversation/7","type":"function"},{"doc":"License Manager makes it easier to manage licenses from software vendors across\nmultiple Amazon Web Services accounts and on-premises servers.","ref":"AWS.LicenseManager.html","title":"AWS.LicenseManager","type":"module"},{"doc":"Accepts the specified grant.","ref":"AWS.LicenseManager.html#accept_grant/3","title":"AWS.LicenseManager.accept_grant/3","type":"function"},{"doc":"Checks in the specified license.\n\nCheck in a license when it is no longer in use.","ref":"AWS.LicenseManager.html#check_in_license/3","title":"AWS.LicenseManager.check_in_license/3","type":"function"},{"doc":"Checks out the specified license for offline use.","ref":"AWS.LicenseManager.html#checkout_borrow_license/3","title":"AWS.LicenseManager.checkout_borrow_license/3","type":"function"},{"doc":"Checks out the specified license.\n\nIf the account that created the license is the same that is performing the check\nout, you must specify the account as the beneficiary.","ref":"AWS.LicenseManager.html#checkout_license/3","title":"AWS.LicenseManager.checkout_license/3","type":"function"},{"doc":"Creates a grant for the specified license.\n\nA grant shares the use of license entitlements with a specific Amazon Web\nServices account, an organization, or an organizational unit (OU). For more\ninformation, see [Granted licenses in License Manager](https://docs.aws.amazon.com/license-manager/latest/userguide/granted-licenses.html)\nin the *License Manager User Guide*.","ref":"AWS.LicenseManager.html#create_grant/3","title":"AWS.LicenseManager.create_grant/3","type":"function"},{"doc":"Creates a new version of the specified grant.\n\nFor more information, see [Granted licenses in License Manager](https://docs.aws.amazon.com/license-manager/latest/userguide/granted-licenses.html)\nin the *License Manager User Guide*.","ref":"AWS.LicenseManager.html#create_grant_version/3","title":"AWS.LicenseManager.create_grant_version/3","type":"function"},{"doc":"Creates a license.","ref":"AWS.LicenseManager.html#create_license/3","title":"AWS.LicenseManager.create_license/3","type":"function"},{"doc":"Creates a license configuration.\n\nA license configuration is an abstraction of a customer license agreement that\ncan be consumed and enforced by License Manager. Components include\nspecifications for the license type (licensing by instance, socket, CPU, or\nvCPU), allowed tenancy (shared tenancy, Dedicated Instance, Dedicated Host, or\nall of these), license affinity to host (how long a license must be associated\nwith a host), and the number of licenses purchased and used.","ref":"AWS.LicenseManager.html#create_license_configuration/3","title":"AWS.LicenseManager.create_license_configuration/3","type":"function"},{"doc":"Creates a new license conversion task.","ref":"AWS.LicenseManager.html#create_license_conversion_task_for_resource/3","title":"AWS.LicenseManager.create_license_conversion_task_for_resource/3","type":"function"},{"doc":"Creates a report generator.","ref":"AWS.LicenseManager.html#create_license_manager_report_generator/3","title":"AWS.LicenseManager.create_license_manager_report_generator/3","type":"function"},{"doc":"Creates a new version of the specified license.","ref":"AWS.LicenseManager.html#create_license_version/3","title":"AWS.LicenseManager.create_license_version/3","type":"function"},{"doc":"Creates a long-lived token.\n\nA refresh token is a JWT token used to get an access token. With an access\ntoken, you can call AssumeRoleWithWebIdentity to get role credentials that you\ncan use to call License Manager to manage the specified license.","ref":"AWS.LicenseManager.html#create_token/3","title":"AWS.LicenseManager.create_token/3","type":"function"},{"doc":"Deletes the specified grant.","ref":"AWS.LicenseManager.html#delete_grant/3","title":"AWS.LicenseManager.delete_grant/3","type":"function"},{"doc":"Deletes the specified license.","ref":"AWS.LicenseManager.html#delete_license/3","title":"AWS.LicenseManager.delete_license/3","type":"function"},{"doc":"Deletes the specified license configuration.\n\nYou cannot delete a license configuration that is in use.","ref":"AWS.LicenseManager.html#delete_license_configuration/3","title":"AWS.LicenseManager.delete_license_configuration/3","type":"function"},{"doc":"Deletes the specified report generator.\n\nThis action deletes the report generator, which stops it from generating future\nreports. The action cannot be reversed. It has no effect on the previous reports\nfrom this generator.","ref":"AWS.LicenseManager.html#delete_license_manager_report_generator/3","title":"AWS.LicenseManager.delete_license_manager_report_generator/3","type":"function"},{"doc":"Deletes the specified token.\n\nMust be called in the license home Region.","ref":"AWS.LicenseManager.html#delete_token/3","title":"AWS.LicenseManager.delete_token/3","type":"function"},{"doc":"Extends the expiration date for license consumption.","ref":"AWS.LicenseManager.html#extend_license_consumption/3","title":"AWS.LicenseManager.extend_license_consumption/3","type":"function"},{"doc":"Gets a temporary access token to use with AssumeRoleWithWebIdentity.\n\nAccess tokens are valid for one hour.","ref":"AWS.LicenseManager.html#get_access_token/3","title":"AWS.LicenseManager.get_access_token/3","type":"function"},{"doc":"Gets detailed information about the specified grant.","ref":"AWS.LicenseManager.html#get_grant/3","title":"AWS.LicenseManager.get_grant/3","type":"function"},{"doc":"Gets detailed information about the specified license.","ref":"AWS.LicenseManager.html#get_license/3","title":"AWS.LicenseManager.get_license/3","type":"function"},{"doc":"Gets detailed information about the specified license configuration.","ref":"AWS.LicenseManager.html#get_license_configuration/3","title":"AWS.LicenseManager.get_license_configuration/3","type":"function"},{"doc":"Gets information about the specified license type conversion task.","ref":"AWS.LicenseManager.html#get_license_conversion_task/3","title":"AWS.LicenseManager.get_license_conversion_task/3","type":"function"},{"doc":"Gets information about the specified report generator.","ref":"AWS.LicenseManager.html#get_license_manager_report_generator/3","title":"AWS.LicenseManager.get_license_manager_report_generator/3","type":"function"},{"doc":"Gets detailed information about the usage of the specified license.","ref":"AWS.LicenseManager.html#get_license_usage/3","title":"AWS.LicenseManager.get_license_usage/3","type":"function"},{"doc":"Gets the License Manager settings for the current Region.","ref":"AWS.LicenseManager.html#get_service_settings/3","title":"AWS.LicenseManager.get_service_settings/3","type":"function"},{"doc":"Lists the resource associations for the specified license configuration.\n\nResource associations need not consume licenses from a license configuration.\nFor example, an AMI or a stopped instance might not consume a license (depending\non the license rules).","ref":"AWS.LicenseManager.html#list_associations_for_license_configuration/3","title":"AWS.LicenseManager.list_associations_for_license_configuration/3","type":"function"},{"doc":"Lists the grants distributed for the specified license.","ref":"AWS.LicenseManager.html#list_distributed_grants/3","title":"AWS.LicenseManager.list_distributed_grants/3","type":"function"},{"doc":"Lists the license configuration operations that failed.","ref":"AWS.LicenseManager.html#list_failures_for_license_configuration_operations/3","title":"AWS.LicenseManager.list_failures_for_license_configuration_operations/3","type":"function"},{"doc":"Lists the license configurations for your account.","ref":"AWS.LicenseManager.html#list_license_configurations/3","title":"AWS.LicenseManager.list_license_configurations/3","type":"function"},{"doc":"Lists the license type conversion tasks for your account.","ref":"AWS.LicenseManager.html#list_license_conversion_tasks/3","title":"AWS.LicenseManager.list_license_conversion_tasks/3","type":"function"},{"doc":"Lists the report generators for your account.","ref":"AWS.LicenseManager.html#list_license_manager_report_generators/3","title":"AWS.LicenseManager.list_license_manager_report_generators/3","type":"function"},{"doc":"Describes the license configurations for the specified resource.","ref":"AWS.LicenseManager.html#list_license_specifications_for_resource/3","title":"AWS.LicenseManager.list_license_specifications_for_resource/3","type":"function"},{"doc":"Lists all versions of the specified license.","ref":"AWS.LicenseManager.html#list_license_versions/3","title":"AWS.LicenseManager.list_license_versions/3","type":"function"},{"doc":"Lists the licenses for your account.","ref":"AWS.LicenseManager.html#list_licenses/3","title":"AWS.LicenseManager.list_licenses/3","type":"function"},{"doc":"Lists grants that are received.\n\nReceived grants are grants created while specifying the recipient as this Amazon\nWeb Services account, your organization, or an organizational unit (OU) to which\nthis member account belongs.","ref":"AWS.LicenseManager.html#list_received_grants/3","title":"AWS.LicenseManager.list_received_grants/3","type":"function"},{"doc":"Lists the grants received for all accounts in the organization.","ref":"AWS.LicenseManager.html#list_received_grants_for_organization/3","title":"AWS.LicenseManager.list_received_grants_for_organization/3","type":"function"},{"doc":"Lists received licenses.","ref":"AWS.LicenseManager.html#list_received_licenses/3","title":"AWS.LicenseManager.list_received_licenses/3","type":"function"},{"doc":"Lists the licenses received for all accounts in the organization.","ref":"AWS.LicenseManager.html#list_received_licenses_for_organization/3","title":"AWS.LicenseManager.list_received_licenses_for_organization/3","type":"function"},{"doc":"Lists resources managed using Systems Manager inventory.","ref":"AWS.LicenseManager.html#list_resource_inventory/3","title":"AWS.LicenseManager.list_resource_inventory/3","type":"function"},{"doc":"Lists the tags for the specified license configuration.","ref":"AWS.LicenseManager.html#list_tags_for_resource/3","title":"AWS.LicenseManager.list_tags_for_resource/3","type":"function"},{"doc":"Lists your tokens.","ref":"AWS.LicenseManager.html#list_tokens/3","title":"AWS.LicenseManager.list_tokens/3","type":"function"},{"doc":"Lists all license usage records for a license configuration, displaying license\nconsumption details by resource at a selected point in time.\n\nUse this action to audit the current license consumption for any license\ninventory and configuration.","ref":"AWS.LicenseManager.html#list_usage_for_license_configuration/3","title":"AWS.LicenseManager.list_usage_for_license_configuration/3","type":"function"},{"doc":"","ref":"AWS.LicenseManager.html#metadata/0","title":"AWS.LicenseManager.metadata/0","type":"function"},{"doc":"Rejects the specified grant.","ref":"AWS.LicenseManager.html#reject_grant/3","title":"AWS.LicenseManager.reject_grant/3","type":"function"},{"doc":"Adds the specified tags to the specified license configuration.","ref":"AWS.LicenseManager.html#tag_resource/3","title":"AWS.LicenseManager.tag_resource/3","type":"function"},{"doc":"Removes the specified tags from the specified license configuration.","ref":"AWS.LicenseManager.html#untag_resource/3","title":"AWS.LicenseManager.untag_resource/3","type":"function"},{"doc":"Modifies the attributes of an existing license configuration.","ref":"AWS.LicenseManager.html#update_license_configuration/3","title":"AWS.LicenseManager.update_license_configuration/3","type":"function"},{"doc":"Updates a report generator.\n\nAfter you make changes to a report generator, it starts generating new reports\nwithin 60 minutes of being updated.","ref":"AWS.LicenseManager.html#update_license_manager_report_generator/3","title":"AWS.LicenseManager.update_license_manager_report_generator/3","type":"function"},{"doc":"Adds or removes the specified license configurations for the specified Amazon\nWeb Services resource.\n\nYou can update the license specifications of AMIs, instances, and hosts. You\ncannot update the license specifications for launch templates and CloudFormation\ntemplates, as they send license configurations to the operation that creates the\nresource.","ref":"AWS.LicenseManager.html#update_license_specifications_for_resource/3","title":"AWS.LicenseManager.update_license_specifications_for_resource/3","type":"function"},{"doc":"Updates License Manager settings for the current Region.","ref":"AWS.LicenseManager.html#update_service_settings/3","title":"AWS.LicenseManager.update_service_settings/3","type":"function"},{"doc":"With License Manager, you can discover and track your commercial Linux\nsubscriptions on running Amazon EC2 instances.","ref":"AWS.LicenseManagerLinuxSubscriptions.html","title":"AWS.LicenseManagerLinuxSubscriptions","type":"module"},{"doc":"Lists the Linux subscriptions service settings.","ref":"AWS.LicenseManagerLinuxSubscriptions.html#get_service_settings/3","title":"AWS.LicenseManagerLinuxSubscriptions.get_service_settings/3","type":"function"},{"doc":"Lists the running Amazon EC2 instances that were discovered with commercial\nLinux subscriptions.","ref":"AWS.LicenseManagerLinuxSubscriptions.html#list_linux_subscription_instances/3","title":"AWS.LicenseManagerLinuxSubscriptions.list_linux_subscription_instances/3","type":"function"},{"doc":"Lists the Linux subscriptions that have been discovered.\n\nIf you have linked your organization, the returned results will include data\naggregated across your accounts in Organizations.","ref":"AWS.LicenseManagerLinuxSubscriptions.html#list_linux_subscriptions/3","title":"AWS.LicenseManagerLinuxSubscriptions.list_linux_subscriptions/3","type":"function"},{"doc":"","ref":"AWS.LicenseManagerLinuxSubscriptions.html#metadata/0","title":"AWS.LicenseManagerLinuxSubscriptions.metadata/0","type":"function"},{"doc":"Updates the service settings for Linux subscriptions.","ref":"AWS.LicenseManagerLinuxSubscriptions.html#update_service_settings/3","title":"AWS.LicenseManagerLinuxSubscriptions.update_service_settings/3","type":"function"},{"doc":"With License Manager, you can create user-based subscriptions to utilize\nlicensed software with a per user subscription fee on Amazon EC2 instances.","ref":"AWS.LicenseManagerUserSubscriptions.html","title":"AWS.LicenseManagerUserSubscriptions","type":"module"},{"doc":"Associates the user to an EC2 instance to utilize user-based subscriptions.\n\nYour estimated bill for charges on the number of users and related costs will\ntake 48 hours to appear for billing periods that haven't closed (marked as\n**Pending** billing status) in Amazon Web Services Billing. For more\ninformation, see [Viewing your monthly charges](https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/invoice.html)\nin the *Amazon Web Services Billing User Guide*.","ref":"AWS.LicenseManagerUserSubscriptions.html#associate_user/3","title":"AWS.LicenseManagerUserSubscriptions.associate_user/3","type":"function"},{"doc":"Deregisters the identity provider from providing user-based subscriptions.","ref":"AWS.LicenseManagerUserSubscriptions.html#deregister_identity_provider/3","title":"AWS.LicenseManagerUserSubscriptions.deregister_identity_provider/3","type":"function"},{"doc":"Disassociates the user from an EC2 instance providing user-based subscriptions.","ref":"AWS.LicenseManagerUserSubscriptions.html#disassociate_user/3","title":"AWS.LicenseManagerUserSubscriptions.disassociate_user/3","type":"function"},{"doc":"Lists the identity providers for user-based subscriptions.","ref":"AWS.LicenseManagerUserSubscriptions.html#list_identity_providers/3","title":"AWS.LicenseManagerUserSubscriptions.list_identity_providers/3","type":"function"},{"doc":"Lists the EC2 instances providing user-based subscriptions.","ref":"AWS.LicenseManagerUserSubscriptions.html#list_instances/3","title":"AWS.LicenseManagerUserSubscriptions.list_instances/3","type":"function"},{"doc":"Lists the user-based subscription products available from an identity provider.","ref":"AWS.LicenseManagerUserSubscriptions.html#list_product_subscriptions/3","title":"AWS.LicenseManagerUserSubscriptions.list_product_subscriptions/3","type":"function"},{"doc":"Lists user associations for an identity provider.","ref":"AWS.LicenseManagerUserSubscriptions.html#list_user_associations/3","title":"AWS.LicenseManagerUserSubscriptions.list_user_associations/3","type":"function"},{"doc":"","ref":"AWS.LicenseManagerUserSubscriptions.html#metadata/0","title":"AWS.LicenseManagerUserSubscriptions.metadata/0","type":"function"},{"doc":"Registers an identity provider for user-based subscriptions.","ref":"AWS.LicenseManagerUserSubscriptions.html#register_identity_provider/3","title":"AWS.LicenseManagerUserSubscriptions.register_identity_provider/3","type":"function"},{"doc":"Starts a product subscription for a user with the specified identity provider.\n\nYour estimated bill for charges on the number of users and related costs will\ntake 48 hours to appear for billing periods that haven't closed (marked as\n**Pending** billing status) in Amazon Web Services Billing. For more\ninformation, see [Viewing your monthly charges](https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/invoice.html)\nin the *Amazon Web Services Billing User Guide*.","ref":"AWS.LicenseManagerUserSubscriptions.html#start_product_subscription/3","title":"AWS.LicenseManagerUserSubscriptions.start_product_subscription/3","type":"function"},{"doc":"Stops a product subscription for a user with the specified identity provider.","ref":"AWS.LicenseManagerUserSubscriptions.html#stop_product_subscription/3","title":"AWS.LicenseManagerUserSubscriptions.stop_product_subscription/3","type":"function"},{"doc":"Updates additional product configuration settings for the registered identity\nprovider.","ref":"AWS.LicenseManagerUserSubscriptions.html#update_identity_provider_settings/3","title":"AWS.LicenseManagerUserSubscriptions.update_identity_provider_settings/3","type":"function"},{"doc":"Amazon Lightsail is the easiest way to get started with Amazon Web Services\n(Amazon Web Services) for developers who need to build websites or web\napplications.\n\nIt includes everything you need to launch your project quickly - instances\n(virtual private servers), container services, storage buckets, managed\ndatabases, SSD-based block storage, static IP addresses, load balancers, content\ndelivery network (CDN) distributions, DNS management of registered domains, and\nresource snapshots (backups) - for a low, predictable monthly price.\n\nYou can manage your Lightsail resources using the Lightsail console, Lightsail\nAPI, Command Line Interface (CLI), or SDKs. For more information about Lightsail\nconcepts and tasks, see the [Amazon Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/lightsail-how-to-set-up-access-keys-to-use-sdk-api-cli).\n\nThis API Reference provides detailed information about the actions, data types,\nparameters, and errors of the Lightsail service. For more information about the\nsupported Amazon Web Services Regions, endpoints, and service quotas of the\nLightsail service, see [Amazon Lightsail Endpoints and Quotas](https://docs.aws.amazon.com/general/latest/gr/lightsail.html) in the\n*Amazon Web Services General Reference*.","ref":"AWS.Lightsail.html","title":"AWS.Lightsail","type":"module"},{"doc":"Allocates a static IP address.","ref":"AWS.Lightsail.html#allocate_static_ip/3","title":"AWS.Lightsail.allocate_static_ip/3","type":"function"},{"doc":"Attaches an SSL/TLS certificate to your Amazon Lightsail content delivery\nnetwork (CDN) distribution.\n\nAfter the certificate is attached, your distribution accepts HTTPS traffic for\nall of the domains that are associated with the certificate.\n\nUse the `CreateCertificate` action to create a certificate that you can attach\nto your distribution.\n\nOnly certificates created in the `us-east-1` Amazon Web Services Region can be\nattached to Lightsail distributions. Lightsail distributions are global\nresources that can reference an origin in any Amazon Web Services Region, and\ndistribute its content globally. However, all distributions are located in the\n`us-east-1` Region.","ref":"AWS.Lightsail.html#attach_certificate_to_distribution/3","title":"AWS.Lightsail.attach_certificate_to_distribution/3","type":"function"},{"doc":"Attaches a block storage disk to a running or stopped Lightsail instance and\nexposes it to the instance with the specified disk name.\n\nThe `attach disk` operation supports tag-based access control via resource tags\napplied to the resource identified by `disk name`. For more information, see the\n[Amazon Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-controlling-access-using-tags).","ref":"AWS.Lightsail.html#attach_disk/3","title":"AWS.Lightsail.attach_disk/3","type":"function"},{"doc":"Attaches one or more Lightsail instances to a load balancer.\n\nAfter some time, the instances are attached to the load balancer and the health\ncheck status is available.\n\nThe `attach instances to load balancer` operation supports tag-based access\ncontrol via resource tags applied to the resource identified by `load balancer\nname`. For more information, see the [Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-controlling-access-using-tags).","ref":"AWS.Lightsail.html#attach_instances_to_load_balancer/3","title":"AWS.Lightsail.attach_instances_to_load_balancer/3","type":"function"},{"doc":"Attaches a Transport Layer Security (TLS) certificate to your load balancer.\n\nTLS is just an updated, more secure version of Secure Socket Layer (SSL).\n\nOnce you create and validate your certificate, you can attach it to your load\nbalancer. You can also use this API to rotate the certificates on your account.\nUse the `AttachLoadBalancerTlsCertificate` action with the non-attached\ncertificate, and it will replace the existing one and become the attached\ncertificate.\n\nThe `AttachLoadBalancerTlsCertificate` operation supports tag-based access\ncontrol via resource tags applied to the resource identified by `load balancer\nname`. For more information, see the [Amazon Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-controlling-access-using-tags).","ref":"AWS.Lightsail.html#attach_load_balancer_tls_certificate/3","title":"AWS.Lightsail.attach_load_balancer_tls_certificate/3","type":"function"},{"doc":"Attaches a static IP address to a specific Amazon Lightsail instance.","ref":"AWS.Lightsail.html#attach_static_ip/3","title":"AWS.Lightsail.attach_static_ip/3","type":"function"},{"doc":"Closes ports for a specific Amazon Lightsail instance.\n\nThe `CloseInstancePublicPorts` action supports tag-based access control via\nresource tags applied to the resource identified by `instanceName`. For more\ninformation, see the [Amazon Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-controlling-access-using-tags).","ref":"AWS.Lightsail.html#close_instance_public_ports/3","title":"AWS.Lightsail.close_instance_public_ports/3","type":"function"},{"doc":"Copies a manual snapshot of an instance or disk as another manual snapshot, or\ncopies an automatic snapshot of an instance or disk as a manual snapshot.\n\nThis operation can also be used to copy a manual or automatic snapshot of an\ninstance or a disk from one Amazon Web Services Region to another in Amazon\nLightsail.\n\nWhen copying a *manual snapshot*, be sure to define the `source region`, `source\nsnapshot name`, and `target snapshot name` parameters.\n\nWhen copying an *automatic snapshot*, be sure to define the `source region`,\n`source resource name`, `target snapshot name`, and either the `restore date` or\nthe `use latest restorable auto snapshot` parameters.","ref":"AWS.Lightsail.html#copy_snapshot/3","title":"AWS.Lightsail.copy_snapshot/3","type":"function"},{"doc":"Creates an Amazon Lightsail bucket.\n\nA bucket is a cloud storage resource available in the Lightsail object storage\nservice. Use buckets to store objects such as data and its descriptive metadata.\nFor more information about buckets, see [Buckets in Amazon Lightsail](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/buckets-in-amazon-lightsail)\nin the *Amazon Lightsail Developer Guide*.","ref":"AWS.Lightsail.html#create_bucket/3","title":"AWS.Lightsail.create_bucket/3","type":"function"},{"doc":"Creates a new access key for the specified Amazon Lightsail bucket.\n\nAccess keys consist of an access key ID and corresponding secret access key.\n\nAccess keys grant full programmatic access to the specified bucket and its\nobjects. You can have a maximum of two access keys per bucket. Use the\n[GetBucketAccessKeys](https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetBucketAccessKeys.html) action to get a list of current access keys for a specific bucket. For more\ninformation about access keys, see [Creating access keys for a bucket in Amazon\nLightsail](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-creating-bucket-access-keys)\nin the *Amazon Lightsail Developer Guide*.\n\nThe `secretAccessKey` value is returned only in response to the\n`CreateBucketAccessKey` action. You can get a secret access key only when you\nfirst create an access key; you cannot get the secret access key later. If you\nlose the secret access key, you must create a new access key.","ref":"AWS.Lightsail.html#create_bucket_access_key/3","title":"AWS.Lightsail.create_bucket_access_key/3","type":"function"},{"doc":"Creates an SSL/TLS certificate for an Amazon Lightsail content delivery network\n(CDN) distribution and a container service.\n\nAfter the certificate is valid, use the `AttachCertificateToDistribution` action\nto use the certificate and its domains with your distribution. Or use the\n`UpdateContainerService` action to use the certificate and its domains with your\ncontainer service.\n\nOnly certificates created in the `us-east-1` Amazon Web Services Region can be\nattached to Lightsail distributions. Lightsail distributions are global\nresources that can reference an origin in any Amazon Web Services Region, and\ndistribute its content globally. However, all distributions are located in the\n`us-east-1` Region.","ref":"AWS.Lightsail.html#create_certificate/3","title":"AWS.Lightsail.create_certificate/3","type":"function"},{"doc":"Creates an AWS CloudFormation stack, which creates a new Amazon EC2 instance\nfrom an exported Amazon Lightsail snapshot.\n\nThis operation results in a CloudFormation stack record that can be used to\ntrack the AWS CloudFormation stack created. Use the `get cloud formation stack\nrecords` operation to get a list of the CloudFormation stacks created.\n\nWait until after your new Amazon EC2 instance is created before running the\n`create cloud formation stack` operation again with the same export snapshot\nrecord.","ref":"AWS.Lightsail.html#create_cloud_formation_stack/3","title":"AWS.Lightsail.create_cloud_formation_stack/3","type":"function"},{"doc":"Creates an email or SMS text message contact method.\n\nA contact method is used to send you notifications about your Amazon Lightsail\nresources. You can add one email address and one mobile phone number contact\nmethod in each Amazon Web Services Region. However, SMS text messaging is not\nsupported in some Amazon Web Services Regions, and SMS text messages cannot be\nsent to some countries/regions. For more information, see [Notifications in Amazon\nLightsail](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-notifications).","ref":"AWS.Lightsail.html#create_contact_method/3","title":"AWS.Lightsail.create_contact_method/3","type":"function"},{"doc":"Creates an Amazon Lightsail container service.\n\nA Lightsail container service is a compute resource to which you can deploy\ncontainers. For more information, see [Container services in Amazon Lightsail](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-container-services)\nin the *Lightsail Dev Guide*.","ref":"AWS.Lightsail.html#create_container_service/3","title":"AWS.Lightsail.create_container_service/3","type":"function"},{"doc":"Creates a deployment for your Amazon Lightsail container service.\n\nA deployment specifies the containers that will be launched on the container\nservice and their settings, such as the ports to open, the environment variables\nto apply, and the launch command to run. It also specifies the container that\nwill serve as the public endpoint of the deployment and its settings, such as\nthe HTTP or HTTPS port to use, and the health check configuration.\n\nYou can deploy containers to your container service using container images from\na public registry such as Amazon ECR Public, or from your local machine. For\nmore information, see [Creating container images for your Amazon Lightsail container\nservices](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-creating-container-images)\nin the *Amazon Lightsail Developer Guide*.","ref":"AWS.Lightsail.html#create_container_service_deployment/3","title":"AWS.Lightsail.create_container_service_deployment/3","type":"function"},{"doc":"Creates a temporary set of log in credentials that you can use to log in to the\nDocker process on your local machine.\n\nAfter you're logged in, you can use the native Docker commands to push your\nlocal container images to the container image registry of your Amazon Lightsail\naccount so that you can use them with your Lightsail container service. The log\nin credentials expire 12 hours after they are created, at which point you will\nneed to create a new set of log in credentials.\n\nYou can only push container images to the container service registry of your\nLightsail account. You cannot pull container images or perform any other\ncontainer image management actions on the container service registry.\n\nAfter you push your container images to the container image registry of your\nLightsail account, use the `RegisterContainerImage` action to register the\npushed images to a specific Lightsail container service.\n\nThis action is not required if you install and use the Lightsail Control\n(lightsailctl) plugin to push container images to your Lightsail container\nservice. For more information, see [Pushing and managing container images on your Amazon Lightsail container\nservices](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-pushing-container-images)\nin the *Amazon Lightsail Developer Guide*.","ref":"AWS.Lightsail.html#create_container_service_registry_login/3","title":"AWS.Lightsail.create_container_service_registry_login/3","type":"function"},{"doc":"Creates a block storage disk that can be attached to an Amazon Lightsail\ninstance in the same Availability Zone (`us-east-2a`).\n\nThe `create disk` operation supports tag-based access control via request tags.\nFor more information, see the [Amazon Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-controlling-access-using-tags).","ref":"AWS.Lightsail.html#create_disk/3","title":"AWS.Lightsail.create_disk/3","type":"function"},{"doc":"Creates a block storage disk from a manual or automatic snapshot of a disk.\n\nThe resulting disk can be attached to an Amazon Lightsail instance in the same\nAvailability Zone (`us-east-2a`).\n\nThe `create disk from snapshot` operation supports tag-based access control via\nrequest tags and resource tags applied to the resource identified by `disk\nsnapshot name`. For more information, see the [Amazon Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-controlling-access-using-tags).","ref":"AWS.Lightsail.html#create_disk_from_snapshot/3","title":"AWS.Lightsail.create_disk_from_snapshot/3","type":"function"},{"doc":"Creates a snapshot of a block storage disk.\n\nYou can use snapshots for backups, to make copies of disks, and to save data\nbefore shutting down a Lightsail instance.\n\nYou can take a snapshot of an attached disk that is in use; however, snapshots\nonly capture data that has been written to your disk at the time the snapshot\ncommand is issued. This may exclude any data that has been cached by any\napplications or the operating system. If you can pause any file systems on the\ndisk long enough to take a snapshot, your snapshot should be complete.\nNevertheless, if you cannot pause all file writes to the disk, you should\nunmount the disk from within the Lightsail instance, issue the create disk\nsnapshot command, and then remount the disk to ensure a consistent and complete\nsnapshot. You may remount and use your disk while the snapshot status is\npending.\n\nYou can also use this operation to create a snapshot of an instance's system\nvolume. You might want to do this, for example, to recover data from the system\nvolume of a botched instance or to create a backup of the system volume like you\nwould for a block storage disk. To create a snapshot of a system volume, just\ndefine the `instance name` parameter when issuing the snapshot command, and a\nsnapshot of the defined instance's system volume will be created. After the\nsnapshot is available, you can create a block storage disk from the snapshot and\nattach it to a running instance to access the data on the disk.\n\nThe `create disk snapshot` operation supports tag-based access control via\nrequest tags. For more information, see the [Amazon Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-controlling-access-using-tags).","ref":"AWS.Lightsail.html#create_disk_snapshot/3","title":"AWS.Lightsail.create_disk_snapshot/3","type":"function"},{"doc":"Creates an Amazon Lightsail content delivery network (CDN) distribution.\n\nA distribution is a globally distributed network of caching servers that improve\nthe performance of your website or web application hosted on a Lightsail\ninstance. For more information, see [Content delivery networks in Amazon Lightsail](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-content-delivery-network-distributions).","ref":"AWS.Lightsail.html#create_distribution/3","title":"AWS.Lightsail.create_distribution/3","type":"function"},{"doc":"Creates a domain resource for the specified domain (example.com).\n\nThe `create domain` operation supports tag-based access control via request\ntags. For more information, see the [Amazon Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-controlling-access-using-tags).","ref":"AWS.Lightsail.html#create_domain/3","title":"AWS.Lightsail.create_domain/3","type":"function"},{"doc":"Creates one of the following domain name system (DNS) records in a domain DNS\nzone: Address (A), canonical name (CNAME), mail exchanger (MX), name server\n(NS), start of authority (SOA), service locator (SRV), or text (TXT).\n\nThe `create domain entry` operation supports tag-based access control via\nresource tags applied to the resource identified by `domain name`. For more\ninformation, see the [Amazon Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-controlling-access-using-tags).","ref":"AWS.Lightsail.html#create_domain_entry/3","title":"AWS.Lightsail.create_domain_entry/3","type":"function"},{"doc":"Creates two URLs that are used to access a virtual computer’s graphical user\ninterface (GUI) session.\n\nThe primary URL initiates a web-based NICE DCV session to the virtual computer's\napplication. The secondary URL initiates a web-based NICE DCV session to the\nvirtual computer's operating session.\n\nUse `StartGUISession` to open the session.","ref":"AWS.Lightsail.html#create_g_ui_session_access_details/3","title":"AWS.Lightsail.create_g_ui_session_access_details/3","type":"function"},{"doc":"Creates a snapshot of a specific virtual private server, or *instance*.\n\nYou can use a snapshot to create a new instance that is based on that snapshot.\n\nThe `create instance snapshot` operation supports tag-based access control via\nrequest tags. For more information, see the [Amazon Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-controlling-access-using-tags).","ref":"AWS.Lightsail.html#create_instance_snapshot/3","title":"AWS.Lightsail.create_instance_snapshot/3","type":"function"},{"doc":"Creates one or more Amazon Lightsail instances.\n\nThe `create instances` operation supports tag-based access control via request\ntags. For more information, see the [Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-controlling-access-using-tags).","ref":"AWS.Lightsail.html#create_instances/3","title":"AWS.Lightsail.create_instances/3","type":"function"},{"doc":"Creates one or more new instances from a manual or automatic snapshot of an\ninstance.\n\nThe `create instances from snapshot` operation supports tag-based access control\nvia request tags and resource tags applied to the resource identified by\n`instance snapshot name`. For more information, see the [Amazon Lightsail Developer\nGuide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-controlling-access-using-tags).","ref":"AWS.Lightsail.html#create_instances_from_snapshot/3","title":"AWS.Lightsail.create_instances_from_snapshot/3","type":"function"},{"doc":"Creates a custom SSH key pair that you can use with an Amazon Lightsail\ninstance.\n\nUse the\n[DownloadDefaultKeyPair](https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DownloadDefaultKeyPair.html) action to create a Lightsail default key pair in an Amazon Web Services Region\nwhere a default key pair does not currently exist.\n\nThe `create key pair` operation supports tag-based access control via request\ntags. For more information, see the [Amazon Lightsail Developer\nGuide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-controlling-access-using-tags).","ref":"AWS.Lightsail.html#create_key_pair/3","title":"AWS.Lightsail.create_key_pair/3","type":"function"},{"doc":"Creates a Lightsail load balancer.\n\nTo learn more about deciding whether to load balance your application, see\n[Configure your Lightsail instances for load balancing](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/configure-lightsail-instances-for-load-balancing).\nYou can create up to 5 load balancers per AWS Region in your account.\n\nWhen you create a load balancer, you can specify a unique name and port\nsettings. To change additional load balancer settings, use the\n`UpdateLoadBalancerAttribute` operation.\n\nThe `create load balancer` operation supports tag-based access control via\nrequest tags. For more information, see the [Amazon Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-controlling-access-using-tags).","ref":"AWS.Lightsail.html#create_load_balancer/3","title":"AWS.Lightsail.create_load_balancer/3","type":"function"},{"doc":"Creates an SSL/TLS certificate for an Amazon Lightsail load balancer.\n\nTLS is just an updated, more secure version of Secure Socket Layer (SSL).\n\nThe `CreateLoadBalancerTlsCertificate` operation supports tag-based access\ncontrol via resource tags applied to the resource identified by `load balancer\nname`. For more information, see the [Amazon Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-controlling-access-using-tags).","ref":"AWS.Lightsail.html#create_load_balancer_tls_certificate/3","title":"AWS.Lightsail.create_load_balancer_tls_certificate/3","type":"function"},{"doc":"Creates a new database in Amazon Lightsail.\n\nThe `create relational database` operation supports tag-based access control via\nrequest tags. For more information, see the [Amazon Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-controlling-access-using-tags).","ref":"AWS.Lightsail.html#create_relational_database/3","title":"AWS.Lightsail.create_relational_database/3","type":"function"},{"doc":"Creates a new database from an existing database snapshot in Amazon Lightsail.\n\nYou can create a new database from a snapshot in if something goes wrong with\nyour original database, or to change it to a different plan, such as a high\navailability or standard plan.\n\nThe `create relational database from snapshot` operation supports tag-based\naccess control via request tags and resource tags applied to the resource\nidentified by relationalDatabaseSnapshotName. For more information, see the\n[Amazon Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-controlling-access-using-tags).","ref":"AWS.Lightsail.html#create_relational_database_from_snapshot/3","title":"AWS.Lightsail.create_relational_database_from_snapshot/3","type":"function"},{"doc":"Creates a snapshot of your database in Amazon Lightsail.\n\nYou can use snapshots for backups, to make copies of a database, and to save\ndata before deleting a database.\n\nThe `create relational database snapshot` operation supports tag-based access\ncontrol via request tags. For more information, see the [Amazon Lightsail Developer\nGuide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-controlling-access-using-tags).","ref":"AWS.Lightsail.html#create_relational_database_snapshot/3","title":"AWS.Lightsail.create_relational_database_snapshot/3","type":"function"},{"doc":"Deletes an alarm.\n\nAn alarm is used to monitor a single metric for one of your resources. When a\nmetric condition is met, the alarm can notify you by email, SMS text message,\nand a banner displayed on the Amazon Lightsail console. For more information,\nsee [Alarms in Amazon Lightsail](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-alarms).","ref":"AWS.Lightsail.html#delete_alarm/3","title":"AWS.Lightsail.delete_alarm/3","type":"function"},{"doc":"Deletes an automatic snapshot of an instance or disk.\n\nFor more information, see the [Amazon Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-configuring-automatic-snapshots).","ref":"AWS.Lightsail.html#delete_auto_snapshot/3","title":"AWS.Lightsail.delete_auto_snapshot/3","type":"function"},{"doc":"Deletes a Amazon Lightsail bucket.\n\nWhen you delete your bucket, the bucket name is released and can be reused for a\nnew bucket in your account or another Amazon Web Services account.","ref":"AWS.Lightsail.html#delete_bucket/3","title":"AWS.Lightsail.delete_bucket/3","type":"function"},{"doc":"Deletes an access key for the specified Amazon Lightsail bucket.\n\nWe recommend that you delete an access key if the secret access key is\ncompromised.\n\nFor more information about access keys, see [Creating access keys for a bucket in Amazon\nLightsail](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-creating-bucket-access-keys)\nin the *Amazon Lightsail Developer Guide*.","ref":"AWS.Lightsail.html#delete_bucket_access_key/3","title":"AWS.Lightsail.delete_bucket_access_key/3","type":"function"},{"doc":"Deletes an SSL/TLS certificate for your Amazon Lightsail content delivery\nnetwork (CDN) distribution.\n\nCertificates that are currently attached to a distribution cannot be deleted.\nUse the `DetachCertificateFromDistribution` action to detach a certificate from\na distribution.","ref":"AWS.Lightsail.html#delete_certificate/3","title":"AWS.Lightsail.delete_certificate/3","type":"function"},{"doc":"Deletes a contact method.\n\nA contact method is used to send you notifications about your Amazon Lightsail\nresources. You can add one email address and one mobile phone number contact\nmethod in each Amazon Web Services Region. However, SMS text messaging is not\nsupported in some Amazon Web Services Regions, and SMS text messages cannot be\nsent to some countries/regions. For more information, see [Notifications in Amazon\nLightsail](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-notifications).","ref":"AWS.Lightsail.html#delete_contact_method/3","title":"AWS.Lightsail.delete_contact_method/3","type":"function"},{"doc":"Deletes a container image that is registered to your Amazon Lightsail container\nservice.","ref":"AWS.Lightsail.html#delete_container_image/3","title":"AWS.Lightsail.delete_container_image/3","type":"function"},{"doc":"Deletes your Amazon Lightsail container service.","ref":"AWS.Lightsail.html#delete_container_service/3","title":"AWS.Lightsail.delete_container_service/3","type":"function"},{"doc":"Deletes the specified block storage disk.\n\nThe disk must be in the `available` state (not attached to a Lightsail\ninstance).\n\nThe disk may remain in the `deleting` state for several minutes.\n\nThe `delete disk` operation supports tag-based access control via resource tags\napplied to the resource identified by `disk name`. For more information, see the\n[Amazon Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-controlling-access-using-tags).","ref":"AWS.Lightsail.html#delete_disk/3","title":"AWS.Lightsail.delete_disk/3","type":"function"},{"doc":"Deletes the specified disk snapshot.\n\nWhen you make periodic snapshots of a disk, the snapshots are incremental, and\nonly the blocks on the device that have changed since your last snapshot are\nsaved in the new snapshot. When you delete a snapshot, only the data not needed\nfor any other snapshot is removed. So regardless of which prior snapshots have\nbeen deleted, all active snapshots will have access to all the information\nneeded to restore the disk.\n\nThe `delete disk snapshot` operation supports tag-based access control via\nresource tags applied to the resource identified by `disk snapshot name`. For\nmore information, see the [Amazon Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-controlling-access-using-tags).","ref":"AWS.Lightsail.html#delete_disk_snapshot/3","title":"AWS.Lightsail.delete_disk_snapshot/3","type":"function"},{"doc":"Deletes your Amazon Lightsail content delivery network (CDN) distribution.","ref":"AWS.Lightsail.html#delete_distribution/3","title":"AWS.Lightsail.delete_distribution/3","type":"function"},{"doc":"Deletes the specified domain recordset and all of its domain records.\n\nThe `delete domain` operation supports tag-based access control via resource\ntags applied to the resource identified by `domain name`. For more information,\nsee the [Amazon Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-controlling-access-using-tags).","ref":"AWS.Lightsail.html#delete_domain/3","title":"AWS.Lightsail.delete_domain/3","type":"function"},{"doc":"Deletes a specific domain entry.\n\nThe `delete domain entry` operation supports tag-based access control via\nresource tags applied to the resource identified by `domain name`. For more\ninformation, see the [Amazon Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-controlling-access-using-tags).","ref":"AWS.Lightsail.html#delete_domain_entry/3","title":"AWS.Lightsail.delete_domain_entry/3","type":"function"},{"doc":"Deletes an Amazon Lightsail instance.\n\nThe `delete instance` operation supports tag-based access control via resource\ntags applied to the resource identified by `instance name`. For more\ninformation, see the [Amazon Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-controlling-access-using-tags).","ref":"AWS.Lightsail.html#delete_instance/3","title":"AWS.Lightsail.delete_instance/3","type":"function"},{"doc":"Deletes a specific snapshot of a virtual private server (or *instance*).\n\nThe `delete instance snapshot` operation supports tag-based access control via\nresource tags applied to the resource identified by `instance snapshot name`.\nFor more information, see the [Amazon Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-controlling-access-using-tags).","ref":"AWS.Lightsail.html#delete_instance_snapshot/3","title":"AWS.Lightsail.delete_instance_snapshot/3","type":"function"},{"doc":"Deletes the specified key pair by removing the public key from Amazon Lightsail.\n\nYou can delete key pairs that were created using the\n[ImportKeyPair](https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_ImportKeyPair.html) and\n[CreateKeyPair](https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_CreateKeyPair.html)\nactions, as well as the Lightsail default key pair. A new default key pair will\nnot be created unless you launch an instance without specifying a custom key\npair, or you call the\n[DownloadDefaultKeyPair](https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DownloadDefaultKeyPair.html) API.\n\nThe `delete key pair` operation supports tag-based access control via resource\ntags applied to the resource identified by `key pair name`. For more\ninformation, see the [Amazon Lightsail Developer\nGuide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-controlling-access-using-tags).","ref":"AWS.Lightsail.html#delete_key_pair/3","title":"AWS.Lightsail.delete_key_pair/3","type":"function"},{"doc":"Deletes the known host key or certificate used by the Amazon Lightsail\nbrowser-based SSH or RDP clients to authenticate an instance.\n\nThis operation enables the Lightsail browser-based SSH or RDP clients to connect\nto the instance after a host key mismatch.\n\nPerform this operation only if you were expecting the host key or certificate\nmismatch or if you are familiar with the new host key or certificate on the\ninstance. For more information, see [Troubleshooting connection issues when using the Amazon Lightsail browser-based SSH or RDP\nclient](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-troubleshooting-browser-based-ssh-rdp-client-connection).","ref":"AWS.Lightsail.html#delete_known_host_keys/3","title":"AWS.Lightsail.delete_known_host_keys/3","type":"function"},{"doc":"Deletes a Lightsail load balancer and all its associated SSL/TLS certificates.\n\nOnce the load balancer is deleted, you will need to create a new load balancer,\ncreate a new certificate, and verify domain ownership again.\n\nThe `delete load balancer` operation supports tag-based access control via\nresource tags applied to the resource identified by `load balancer name`. For\nmore information, see the [Amazon Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-controlling-access-using-tags).","ref":"AWS.Lightsail.html#delete_load_balancer/3","title":"AWS.Lightsail.delete_load_balancer/3","type":"function"},{"doc":"Deletes an SSL/TLS certificate associated with a Lightsail load balancer.\n\nThe `DeleteLoadBalancerTlsCertificate` operation supports tag-based access\ncontrol via resource tags applied to the resource identified by `load balancer\nname`. For more information, see the [Amazon Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-controlling-access-using-tags).","ref":"AWS.Lightsail.html#delete_load_balancer_tls_certificate/3","title":"AWS.Lightsail.delete_load_balancer_tls_certificate/3","type":"function"},{"doc":"Deletes a database in Amazon Lightsail.\n\nThe `delete relational database` operation supports tag-based access control via\nresource tags applied to the resource identified by relationalDatabaseName. For\nmore information, see the [Amazon Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-controlling-access-using-tags).","ref":"AWS.Lightsail.html#delete_relational_database/3","title":"AWS.Lightsail.delete_relational_database/3","type":"function"},{"doc":"Deletes a database snapshot in Amazon Lightsail.\n\nThe `delete relational database snapshot` operation supports tag-based access\ncontrol via resource tags applied to the resource identified by\nrelationalDatabaseName. For more information, see the [Amazon Lightsail Developer\nGuide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-controlling-access-using-tags).","ref":"AWS.Lightsail.html#delete_relational_database_snapshot/3","title":"AWS.Lightsail.delete_relational_database_snapshot/3","type":"function"},{"doc":"Detaches an SSL/TLS certificate from your Amazon Lightsail content delivery\nnetwork (CDN) distribution.\n\nAfter the certificate is detached, your distribution stops accepting traffic for\nall of the domains that are associated with the certificate.","ref":"AWS.Lightsail.html#detach_certificate_from_distribution/3","title":"AWS.Lightsail.detach_certificate_from_distribution/3","type":"function"},{"doc":"Detaches a stopped block storage disk from a Lightsail instance.\n\nMake sure to unmount any file systems on the device within your operating system\nbefore stopping the instance and detaching the disk.\n\nThe `detach disk` operation supports tag-based access control via resource tags\napplied to the resource identified by `disk name`. For more information, see the\n[Amazon Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-controlling-access-using-tags).","ref":"AWS.Lightsail.html#detach_disk/3","title":"AWS.Lightsail.detach_disk/3","type":"function"},{"doc":"Detaches the specified instances from a Lightsail load balancer.\n\nThis operation waits until the instances are no longer needed before they are\ndetached from the load balancer.\n\nThe `detach instances from load balancer` operation supports tag-based access\ncontrol via resource tags applied to the resource identified by `load balancer\nname`. For more information, see the [Amazon Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-controlling-access-using-tags).","ref":"AWS.Lightsail.html#detach_instances_from_load_balancer/3","title":"AWS.Lightsail.detach_instances_from_load_balancer/3","type":"function"},{"doc":"Detaches a static IP from the Amazon Lightsail instance to which it is attached.","ref":"AWS.Lightsail.html#detach_static_ip/3","title":"AWS.Lightsail.detach_static_ip/3","type":"function"},{"doc":"Disables an add-on for an Amazon Lightsail resource.\n\nFor more information, see the [Amazon Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-configuring-automatic-snapshots).","ref":"AWS.Lightsail.html#disable_add_on/3","title":"AWS.Lightsail.disable_add_on/3","type":"function"},{"doc":"Downloads the regional Amazon Lightsail default key pair.\n\nThis action also creates a Lightsail default key pair if a default key pair does\nnot currently exist in the Amazon Web Services Region.","ref":"AWS.Lightsail.html#download_default_key_pair/3","title":"AWS.Lightsail.download_default_key_pair/3","type":"function"},{"doc":"Enables or modifies an add-on for an Amazon Lightsail resource.\n\nFor more information, see the [Amazon Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-configuring-automatic-snapshots).","ref":"AWS.Lightsail.html#enable_add_on/3","title":"AWS.Lightsail.enable_add_on/3","type":"function"},{"doc":"Exports an Amazon Lightsail instance or block storage disk snapshot to Amazon\nElastic Compute Cloud (Amazon EC2).\n\nThis operation results in an export snapshot record that can be used with the\n`create cloud formation stack` operation to create new Amazon EC2 instances.\n\nExported instance snapshots appear in Amazon EC2 as Amazon Machine Images\n(AMIs), and the instance system disk appears as an Amazon Elastic Block Store\n(Amazon EBS) volume. Exported disk snapshots appear in Amazon EC2 as Amazon EBS\nvolumes. Snapshots are exported to the same Amazon Web Services Region in Amazon\nEC2 as the source Lightsail snapshot.\n\nThe `export snapshot` operation supports tag-based access control via resource\ntags applied to the resource identified by `source snapshot name`. For more\ninformation, see the [Amazon Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-controlling-access-using-tags).\n\nUse the `get instance snapshots` or `get disk snapshots` operations to get a\nlist of snapshots that you can export to Amazon EC2.","ref":"AWS.Lightsail.html#export_snapshot/3","title":"AWS.Lightsail.export_snapshot/3","type":"function"},{"doc":"Returns the names of all active (not deleted) resources.","ref":"AWS.Lightsail.html#get_active_names/3","title":"AWS.Lightsail.get_active_names/3","type":"function"},{"doc":"Returns information about the configured alarms.\n\nSpecify an alarm name in your request to return information about a specific\nalarm, or specify a monitored resource name to return information about all\nalarms for a specific resource.\n\nAn alarm is used to monitor a single metric for one of your resources. When a\nmetric condition is met, the alarm can notify you by email, SMS text message,\nand a banner displayed on the Amazon Lightsail console. For more information,\nsee [Alarms in Amazon Lightsail](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-alarms).","ref":"AWS.Lightsail.html#get_alarms/3","title":"AWS.Lightsail.get_alarms/3","type":"function"},{"doc":"Returns the available automatic snapshots for an instance or disk.\n\nFor more information, see the [Amazon Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-configuring-automatic-snapshots).","ref":"AWS.Lightsail.html#get_auto_snapshots/3","title":"AWS.Lightsail.get_auto_snapshots/3","type":"function"},{"doc":"Returns the list of available instance images, or *blueprints*.\n\nYou can use a blueprint to create a new instance already running a specific\noperating system, as well as a preinstalled app or development stack. The\nsoftware each instance is running depends on the blueprint image you choose.\n\nUse active blueprints when creating new instances. Inactive blueprints are\nlisted to support customers with existing instances and are not necessarily\navailable to create new instances. Blueprints are marked inactive when they\nbecome outdated due to operating system updates or new application releases.","ref":"AWS.Lightsail.html#get_blueprints/3","title":"AWS.Lightsail.get_blueprints/3","type":"function"},{"doc":"Returns the existing access key IDs for the specified Amazon Lightsail bucket.\n\nThis action does not return the secret access key value of an access key. You\ncan get a secret access key only when you create it from the response of the\n[CreateBucketAccessKey](https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_CreateBucketAccessKey.html)\naction. If you lose the secret access key, you must create a new access key.","ref":"AWS.Lightsail.html#get_bucket_access_keys/3","title":"AWS.Lightsail.get_bucket_access_keys/3","type":"function"},{"doc":"Returns the bundles that you can apply to a Amazon Lightsail bucket.\n\nThe bucket bundle specifies the monthly cost, storage quota, and data transfer\nquota for a bucket.\n\nUse the\n[UpdateBucketBundle](https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_UpdateBucketBundle.html)\naction to update the bundle for a bucket.","ref":"AWS.Lightsail.html#get_bucket_bundles/3","title":"AWS.Lightsail.get_bucket_bundles/3","type":"function"},{"doc":"Returns the data points of a specific metric for an Amazon Lightsail bucket.\n\nMetrics report the utilization of a bucket. View and collect metric data\nregularly to monitor the number of objects stored in a bucket (including object\nversions) and the storage space used by those objects.","ref":"AWS.Lightsail.html#get_bucket_metric_data/3","title":"AWS.Lightsail.get_bucket_metric_data/3","type":"function"},{"doc":"Returns information about one or more Amazon Lightsail buckets.\n\nThe information returned includes the synchronization status of the Amazon\nSimple Storage Service (Amazon S3) account-level block public access feature for\nyour Lightsail buckets.\n\nFor more information about buckets, see [Buckets in Amazon Lightsail](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/buckets-in-amazon-lightsail)\nin the *Amazon Lightsail Developer Guide*.","ref":"AWS.Lightsail.html#get_buckets/3","title":"AWS.Lightsail.get_buckets/3","type":"function"},{"doc":"Returns the bundles that you can apply to an Amazon Lightsail instance when you\ncreate it.\n\nA bundle describes the specifications of an instance, such as the monthly cost,\namount of memory, the number of vCPUs, amount of storage space, and monthly\nnetwork data transfer quota.\n\nBundles are referred to as *instance plans* in the Lightsail console.","ref":"AWS.Lightsail.html#get_bundles/3","title":"AWS.Lightsail.get_bundles/3","type":"function"},{"doc":"Returns information about one or more Amazon Lightsail SSL/TLS certificates.\n\nTo get a summary of a certificate, omit `includeCertificateDetails` from your\nrequest. The response will include only the certificate Amazon Resource Name\n(ARN), certificate name, domain name, and tags.","ref":"AWS.Lightsail.html#get_certificates/3","title":"AWS.Lightsail.get_certificates/3","type":"function"},{"doc":"Returns the CloudFormation stack record created as a result of the `create cloud\nformation stack` operation.\n\nAn AWS CloudFormation stack is used to create a new Amazon EC2 instance from an\nexported Lightsail snapshot.","ref":"AWS.Lightsail.html#get_cloud_formation_stack_records/3","title":"AWS.Lightsail.get_cloud_formation_stack_records/3","type":"function"},{"doc":"Returns information about the configured contact methods.\n\nSpecify a protocol in your request to return information about a specific\ncontact method.\n\nA contact method is used to send you notifications about your Amazon Lightsail\nresources. You can add one email address and one mobile phone number contact\nmethod in each Amazon Web Services Region. However, SMS text messaging is not\nsupported in some Amazon Web Services Regions, and SMS text messages cannot be\nsent to some countries/regions. For more information, see [Notifications in Amazon\nLightsail](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-notifications).","ref":"AWS.Lightsail.html#get_contact_methods/3","title":"AWS.Lightsail.get_contact_methods/3","type":"function"},{"doc":"Returns information about Amazon Lightsail containers, such as the current\nversion of the Lightsail Control (lightsailctl) plugin.","ref":"AWS.Lightsail.html#get_container_api_metadata/3","title":"AWS.Lightsail.get_container_api_metadata/3","type":"function"},{"doc":"Returns the container images that are registered to your Amazon Lightsail\ncontainer service.\n\nIf you created a deployment on your Lightsail container service that uses\ncontainer images from a public registry like Docker Hub, those images are not\nreturned as part of this action. Those images are not registered to your\nLightsail container service.","ref":"AWS.Lightsail.html#get_container_images/3","title":"AWS.Lightsail.get_container_images/3","type":"function"},{"doc":"Returns the log events of a container of your Amazon Lightsail container\nservice.\n\nIf your container service has more than one node (i.e., a scale greater than 1),\nthen the log events that are returned for the specified container are merged\nfrom all nodes on your container service.\n\nContainer logs are retained for a certain amount of time. For more information,\nsee [Amazon Lightsail endpoints and quotas](https://docs.aws.amazon.com/general/latest/gr/lightsail.html) in the\n*Amazon Web Services General Reference*.","ref":"AWS.Lightsail.html#get_container_log/3","title":"AWS.Lightsail.get_container_log/3","type":"function"},{"doc":"Returns the deployments for your Amazon Lightsail container service\n\nA deployment specifies the settings, such as the ports and launch command, of\ncontainers that are deployed to your container service.\n\nThe deployments are ordered by version in ascending order. The newest version is\nlisted at the top of the response.\n\nA set number of deployments are kept before the oldest one is replaced with the\nnewest one. For more information, see [Amazon Lightsail endpoints and quotas](https://docs.aws.amazon.com/general/latest/gr/lightsail.html) in the\n*Amazon Web Services General Reference*.","ref":"AWS.Lightsail.html#get_container_service_deployments/3","title":"AWS.Lightsail.get_container_service_deployments/3","type":"function"},{"doc":"Returns the data points of a specific metric of your Amazon Lightsail container\nservice.\n\nMetrics report the utilization of your resources. Monitor and collect metric\ndata regularly to maintain the reliability, availability, and performance of\nyour resources.","ref":"AWS.Lightsail.html#get_container_service_metric_data/3","title":"AWS.Lightsail.get_container_service_metric_data/3","type":"function"},{"doc":"Returns the list of powers that can be specified for your Amazon Lightsail\ncontainer services.\n\nThe power specifies the amount of memory, the number of vCPUs, and the base\nprice of the container service.","ref":"AWS.Lightsail.html#get_container_service_powers/3","title":"AWS.Lightsail.get_container_service_powers/3","type":"function"},{"doc":"Returns information about one or more of your Amazon Lightsail container\nservices.","ref":"AWS.Lightsail.html#get_container_services/3","title":"AWS.Lightsail.get_container_services/3","type":"function"},{"doc":"Retrieves information about the cost estimate for a specified resource.\n\nA cost estimate will not generate for a resource that has been deleted.","ref":"AWS.Lightsail.html#get_cost_estimate/3","title":"AWS.Lightsail.get_cost_estimate/3","type":"function"},{"doc":"Returns information about a specific block storage disk.","ref":"AWS.Lightsail.html#get_disk/3","title":"AWS.Lightsail.get_disk/3","type":"function"},{"doc":"Returns information about a specific block storage disk snapshot.","ref":"AWS.Lightsail.html#get_disk_snapshot/3","title":"AWS.Lightsail.get_disk_snapshot/3","type":"function"},{"doc":"Returns information about all block storage disk snapshots in your AWS account\nand region.","ref":"AWS.Lightsail.html#get_disk_snapshots/3","title":"AWS.Lightsail.get_disk_snapshots/3","type":"function"},{"doc":"Returns information about all block storage disks in your AWS account and\nregion.","ref":"AWS.Lightsail.html#get_disks/3","title":"AWS.Lightsail.get_disks/3","type":"function"},{"doc":"Returns the bundles that can be applied to your Amazon Lightsail content\ndelivery network (CDN) distributions.\n\nA distribution bundle specifies the monthly network transfer quota and monthly\ncost of your distribution.","ref":"AWS.Lightsail.html#get_distribution_bundles/3","title":"AWS.Lightsail.get_distribution_bundles/3","type":"function"},{"doc":"Returns the timestamp and status of the last cache reset of a specific Amazon\nLightsail content delivery network (CDN) distribution.","ref":"AWS.Lightsail.html#get_distribution_latest_cache_reset/3","title":"AWS.Lightsail.get_distribution_latest_cache_reset/3","type":"function"},{"doc":"Returns the data points of a specific metric for an Amazon Lightsail content\ndelivery network (CDN) distribution.\n\nMetrics report the utilization of your resources, and the error counts generated\nby them. Monitor and collect metric data regularly to maintain the reliability,\navailability, and performance of your resources.","ref":"AWS.Lightsail.html#get_distribution_metric_data/3","title":"AWS.Lightsail.get_distribution_metric_data/3","type":"function"},{"doc":"Returns information about one or more of your Amazon Lightsail content delivery\nnetwork (CDN) distributions.","ref":"AWS.Lightsail.html#get_distributions/3","title":"AWS.Lightsail.get_distributions/3","type":"function"},{"doc":"Returns information about a specific domain recordset.","ref":"AWS.Lightsail.html#get_domain/3","title":"AWS.Lightsail.get_domain/3","type":"function"},{"doc":"Returns a list of all domains in the user's account.","ref":"AWS.Lightsail.html#get_domains/3","title":"AWS.Lightsail.get_domains/3","type":"function"},{"doc":"Returns all export snapshot records created as a result of the `export snapshot`\noperation.\n\nAn export snapshot record can be used to create a new Amazon EC2 instance and\nits related resources with the\n[CreateCloudFormationStack](https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_CreateCloudFormationStack.html)\naction.","ref":"AWS.Lightsail.html#get_export_snapshot_records/3","title":"AWS.Lightsail.get_export_snapshot_records/3","type":"function"},{"doc":"Returns information about a specific Amazon Lightsail instance, which is a\nvirtual private server.","ref":"AWS.Lightsail.html#get_instance/3","title":"AWS.Lightsail.get_instance/3","type":"function"},{"doc":"Returns temporary SSH keys you can use to connect to a specific virtual private\nserver, or *instance*.\n\nThe `get instance access details` operation supports tag-based access control\nvia resource tags applied to the resource identified by `instance name`. For\nmore information, see the [Amazon Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-controlling-access-using-tags).","ref":"AWS.Lightsail.html#get_instance_access_details/3","title":"AWS.Lightsail.get_instance_access_details/3","type":"function"},{"doc":"Returns the data points for the specified Amazon Lightsail instance metric,\ngiven an instance name.\n\nMetrics report the utilization of your resources, and the error counts generated\nby them. Monitor and collect metric data regularly to maintain the reliability,\navailability, and performance of your resources.","ref":"AWS.Lightsail.html#get_instance_metric_data/3","title":"AWS.Lightsail.get_instance_metric_data/3","type":"function"},{"doc":"Returns the firewall port states for a specific Amazon Lightsail instance, the\nIP addresses allowed to connect to the instance through the ports, and the\nprotocol.","ref":"AWS.Lightsail.html#get_instance_port_states/3","title":"AWS.Lightsail.get_instance_port_states/3","type":"function"},{"doc":"Returns information about a specific instance snapshot.","ref":"AWS.Lightsail.html#get_instance_snapshot/3","title":"AWS.Lightsail.get_instance_snapshot/3","type":"function"},{"doc":"Returns all instance snapshots for the user's account.","ref":"AWS.Lightsail.html#get_instance_snapshots/3","title":"AWS.Lightsail.get_instance_snapshots/3","type":"function"},{"doc":"Returns the state of a specific instance.\n\nWorks on one instance at a time.","ref":"AWS.Lightsail.html#get_instance_state/3","title":"AWS.Lightsail.get_instance_state/3","type":"function"},{"doc":"Returns information about all Amazon Lightsail virtual private servers, or\n*instances*.","ref":"AWS.Lightsail.html#get_instances/3","title":"AWS.Lightsail.get_instances/3","type":"function"},{"doc":"Returns information about a specific key pair.","ref":"AWS.Lightsail.html#get_key_pair/3","title":"AWS.Lightsail.get_key_pair/3","type":"function"},{"doc":"Returns information about all key pairs in the user's account.","ref":"AWS.Lightsail.html#get_key_pairs/3","title":"AWS.Lightsail.get_key_pairs/3","type":"function"},{"doc":"Returns information about the specified Lightsail load balancer.","ref":"AWS.Lightsail.html#get_load_balancer/3","title":"AWS.Lightsail.get_load_balancer/3","type":"function"},{"doc":"Returns information about health metrics for your Lightsail load balancer.\n\nMetrics report the utilization of your resources, and the error counts generated\nby them. Monitor and collect metric data regularly to maintain the reliability,\navailability, and performance of your resources.","ref":"AWS.Lightsail.html#get_load_balancer_metric_data/3","title":"AWS.Lightsail.get_load_balancer_metric_data/3","type":"function"},{"doc":"Returns information about the TLS certificates that are associated with the\nspecified Lightsail load balancer.\n\nTLS is just an updated, more secure version of Secure Socket Layer (SSL).\n\nYou can have a maximum of 2 certificates associated with a Lightsail load\nbalancer. One is active and the other is inactive.","ref":"AWS.Lightsail.html#get_load_balancer_tls_certificates/3","title":"AWS.Lightsail.get_load_balancer_tls_certificates/3","type":"function"},{"doc":"Returns a list of TLS security policies that you can apply to Lightsail load\nbalancers.\n\nFor more information about load balancer TLS security policies, see [Configuring TLS security policies on your Amazon Lightsail load\nbalancers](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-configure-load-balancer-tls-security-policy)\nin the *Amazon Lightsail Developer Guide*.","ref":"AWS.Lightsail.html#get_load_balancer_tls_policies/3","title":"AWS.Lightsail.get_load_balancer_tls_policies/3","type":"function"},{"doc":"Returns information about all load balancers in an account.","ref":"AWS.Lightsail.html#get_load_balancers/3","title":"AWS.Lightsail.get_load_balancers/3","type":"function"},{"doc":"Returns information about a specific operation.\n\nOperations include events such as when you create an instance, allocate a static\nIP, attach a static IP, and so on.","ref":"AWS.Lightsail.html#get_operation/3","title":"AWS.Lightsail.get_operation/3","type":"function"},{"doc":"Returns information about all operations.\n\nResults are returned from oldest to newest, up to a maximum of 200. Results can\nbe paged by making each subsequent call to `GetOperations` use the maximum\n(last) `statusChangedAt` value from the previous request.","ref":"AWS.Lightsail.html#get_operations/3","title":"AWS.Lightsail.get_operations/3","type":"function"},{"doc":"Gets operations for a specific resource (an instance or a static IP).","ref":"AWS.Lightsail.html#get_operations_for_resource/3","title":"AWS.Lightsail.get_operations_for_resource/3","type":"function"},{"doc":"Returns a list of all valid regions for Amazon Lightsail.\n\nUse the `include availability zones` parameter to also return the Availability\nZones in a region.","ref":"AWS.Lightsail.html#get_regions/3","title":"AWS.Lightsail.get_regions/3","type":"function"},{"doc":"Returns information about a specific database in Amazon Lightsail.","ref":"AWS.Lightsail.html#get_relational_database/3","title":"AWS.Lightsail.get_relational_database/3","type":"function"},{"doc":"Returns a list of available database blueprints in Amazon Lightsail.\n\nA blueprint describes the major engine version of a database.\n\nYou can use a blueprint ID to create a new database that runs a specific\ndatabase engine.","ref":"AWS.Lightsail.html#get_relational_database_blueprints/3","title":"AWS.Lightsail.get_relational_database_blueprints/3","type":"function"},{"doc":"Returns the list of bundles that are available in Amazon Lightsail.\n\nA bundle describes the performance specifications for a database.\n\nYou can use a bundle ID to create a new database with explicit performance\nspecifications.","ref":"AWS.Lightsail.html#get_relational_database_bundles/3","title":"AWS.Lightsail.get_relational_database_bundles/3","type":"function"},{"doc":"Returns a list of events for a specific database in Amazon Lightsail.","ref":"AWS.Lightsail.html#get_relational_database_events/3","title":"AWS.Lightsail.get_relational_database_events/3","type":"function"},{"doc":"Returns a list of log events for a database in Amazon Lightsail.","ref":"AWS.Lightsail.html#get_relational_database_log_events/3","title":"AWS.Lightsail.get_relational_database_log_events/3","type":"function"},{"doc":"Returns a list of available log streams for a specific database in Amazon\nLightsail.","ref":"AWS.Lightsail.html#get_relational_database_log_streams/3","title":"AWS.Lightsail.get_relational_database_log_streams/3","type":"function"},{"doc":"Returns the current, previous, or pending versions of the master user password\nfor a Lightsail database.\n\nThe `GetRelationalDatabaseMasterUserPassword` operation supports tag-based\naccess control via resource tags applied to the resource identified by\nrelationalDatabaseName.","ref":"AWS.Lightsail.html#get_relational_database_master_user_password/3","title":"AWS.Lightsail.get_relational_database_master_user_password/3","type":"function"},{"doc":"Returns the data points of the specified metric for a database in Amazon\nLightsail.\n\nMetrics report the utilization of your resources, and the error counts generated\nby them. Monitor and collect metric data regularly to maintain the reliability,\navailability, and performance of your resources.","ref":"AWS.Lightsail.html#get_relational_database_metric_data/3","title":"AWS.Lightsail.get_relational_database_metric_data/3","type":"function"},{"doc":"Returns all of the runtime parameters offered by the underlying database\nsoftware, or engine, for a specific database in Amazon Lightsail.\n\nIn addition to the parameter names and values, this operation returns other\ninformation about each parameter. This information includes whether changes\nrequire a reboot, whether the parameter is modifiable, the allowed values, and\nthe data types.","ref":"AWS.Lightsail.html#get_relational_database_parameters/3","title":"AWS.Lightsail.get_relational_database_parameters/3","type":"function"},{"doc":"Returns information about a specific database snapshot in Amazon Lightsail.","ref":"AWS.Lightsail.html#get_relational_database_snapshot/3","title":"AWS.Lightsail.get_relational_database_snapshot/3","type":"function"},{"doc":"Returns information about all of your database snapshots in Amazon Lightsail.","ref":"AWS.Lightsail.html#get_relational_database_snapshots/3","title":"AWS.Lightsail.get_relational_database_snapshots/3","type":"function"},{"doc":"Returns information about all of your databases in Amazon Lightsail.","ref":"AWS.Lightsail.html#get_relational_databases/3","title":"AWS.Lightsail.get_relational_databases/3","type":"function"},{"doc":"Returns detailed information for five of the most recent `SetupInstanceHttps`\nrequests that were ran on the target instance.","ref":"AWS.Lightsail.html#get_setup_history/3","title":"AWS.Lightsail.get_setup_history/3","type":"function"},{"doc":"Returns information about an Amazon Lightsail static IP.","ref":"AWS.Lightsail.html#get_static_ip/3","title":"AWS.Lightsail.get_static_ip/3","type":"function"},{"doc":"Returns information about all static IPs in the user's account.","ref":"AWS.Lightsail.html#get_static_ips/3","title":"AWS.Lightsail.get_static_ips/3","type":"function"},{"doc":"Imports a public SSH key from a specific key pair.","ref":"AWS.Lightsail.html#import_key_pair/3","title":"AWS.Lightsail.import_key_pair/3","type":"function"},{"doc":"Returns a Boolean value indicating whether your Lightsail VPC is peered.","ref":"AWS.Lightsail.html#is_vpc_peered/3","title":"AWS.Lightsail.is_vpc_peered/3","type":"function"},{"doc":"","ref":"AWS.Lightsail.html#metadata/0","title":"AWS.Lightsail.metadata/0","type":"function"},{"doc":"Opens ports for a specific Amazon Lightsail instance, and specifies the IP\naddresses allowed to connect to the instance through the ports, and the\nprotocol.\n\nThe `OpenInstancePublicPorts` action supports tag-based access control via\nresource tags applied to the resource identified by `instanceName`. For more\ninformation, see the [Amazon Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-controlling-access-using-tags).","ref":"AWS.Lightsail.html#open_instance_public_ports/3","title":"AWS.Lightsail.open_instance_public_ports/3","type":"function"},{"doc":"Peers the Lightsail VPC with the user's default VPC.","ref":"AWS.Lightsail.html#peer_vpc/3","title":"AWS.Lightsail.peer_vpc/3","type":"function"},{"doc":"Creates or updates an alarm, and associates it with the specified metric.\n\nAn alarm is used to monitor a single metric for one of your resources. When a\nmetric condition is met, the alarm can notify you by email, SMS text message,\nand a banner displayed on the Amazon Lightsail console. For more information,\nsee [Alarms in Amazon Lightsail](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-alarms).\n\nWhen this action creates an alarm, the alarm state is immediately set to\n`INSUFFICIENT_DATA`. The alarm is then evaluated and its state is set\nappropriately. Any actions associated with the new state are then executed.\n\nWhen you update an existing alarm, its state is left unchanged, but the update\ncompletely overwrites the previous configuration of the alarm. The alarm is then\nevaluated with the updated configuration.","ref":"AWS.Lightsail.html#put_alarm/3","title":"AWS.Lightsail.put_alarm/3","type":"function"},{"doc":"Opens ports for a specific Amazon Lightsail instance, and specifies the IP\naddresses allowed to connect to the instance through the ports, and the\nprotocol.\n\nThis action also closes all currently open ports that are not included in the\nrequest. Include all of the ports and the protocols you want to open in your\n`PutInstancePublicPorts`request. Or use the `OpenInstancePublicPorts` action to\nopen ports without closing currently open ports.\n\nThe `PutInstancePublicPorts` action supports tag-based access control via\nresource tags applied to the resource identified by `instanceName`. For more\ninformation, see the [Amazon Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-controlling-access-using-tags).","ref":"AWS.Lightsail.html#put_instance_public_ports/3","title":"AWS.Lightsail.put_instance_public_ports/3","type":"function"},{"doc":"Restarts a specific instance.\n\nThe `reboot instance` operation supports tag-based access control via resource\ntags applied to the resource identified by `instance name`. For more\ninformation, see the [Amazon Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-controlling-access-using-tags).","ref":"AWS.Lightsail.html#reboot_instance/3","title":"AWS.Lightsail.reboot_instance/3","type":"function"},{"doc":"Restarts a specific database in Amazon Lightsail.\n\nThe `reboot relational database` operation supports tag-based access control via\nresource tags applied to the resource identified by relationalDatabaseName. For\nmore information, see the [Amazon Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-controlling-access-using-tags).","ref":"AWS.Lightsail.html#reboot_relational_database/3","title":"AWS.Lightsail.reboot_relational_database/3","type":"function"},{"doc":"Registers a container image to your Amazon Lightsail container service.\n\nThis action is not required if you install and use the Lightsail Control\n(lightsailctl) plugin to push container images to your Lightsail container\nservice. For more information, see [Pushing and managing container images on your Amazon Lightsail container\nservices](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-pushing-container-images)\nin the *Amazon Lightsail Developer Guide*.","ref":"AWS.Lightsail.html#register_container_image/3","title":"AWS.Lightsail.register_container_image/3","type":"function"},{"doc":"Deletes a specific static IP from your account.","ref":"AWS.Lightsail.html#release_static_ip/3","title":"AWS.Lightsail.release_static_ip/3","type":"function"},{"doc":"Deletes currently cached content from your Amazon Lightsail content delivery\nnetwork (CDN) distribution.\n\nAfter resetting the cache, the next time a content request is made, your\ndistribution pulls, serves, and caches it from the origin.","ref":"AWS.Lightsail.html#reset_distribution_cache/3","title":"AWS.Lightsail.reset_distribution_cache/3","type":"function"},{"doc":"Sends a verification request to an email contact method to ensure it's owned by\nthe requester.\n\nSMS contact methods don't need to be verified.\n\nA contact method is used to send you notifications about your Amazon Lightsail\nresources. You can add one email address and one mobile phone number contact\nmethod in each Amazon Web Services Region. However, SMS text messaging is not\nsupported in some Amazon Web Services Regions, and SMS text messages cannot be\nsent to some countries/regions. For more information, see [Notifications in Amazon\nLightsail](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-notifications).\n\nA verification request is sent to the contact method when you initially create\nit. Use this action to send another verification request if a previous\nverification request was deleted, or has expired.\n\nNotifications are not sent to an email contact method until after it is\nverified, and confirmed as valid.","ref":"AWS.Lightsail.html#send_contact_method_verification/3","title":"AWS.Lightsail.send_contact_method_verification/3","type":"function"},{"doc":"Sets the IP address type for an Amazon Lightsail resource.\n\nUse this action to enable dual-stack for a resource, which enables IPv4 and IPv6\nfor the specified resource. Alternately, you can use this action to disable\ndual-stack, and enable IPv4 only.","ref":"AWS.Lightsail.html#set_ip_address_type/3","title":"AWS.Lightsail.set_ip_address_type/3","type":"function"},{"doc":"Sets the Amazon Lightsail resources that can access the specified Lightsail\nbucket.\n\nLightsail buckets currently support setting access for Lightsail instances in\nthe same Amazon Web Services Region.","ref":"AWS.Lightsail.html#set_resource_access_for_bucket/3","title":"AWS.Lightsail.set_resource_access_for_bucket/3","type":"function"},{"doc":"Creates an SSL/TLS certificate that secures traffic for your website.\n\nAfter the certificate is created, it is installed on the specified Lightsail\ninstance.\n\nIf you provide more than one domain name in the request, at least one name must\nbe less than or equal to 63 characters in length.","ref":"AWS.Lightsail.html#setup_instance_https/3","title":"AWS.Lightsail.setup_instance_https/3","type":"function"},{"doc":"Initiates a graphical user interface (GUI) session that’s used to access a\nvirtual computer’s operating system and application.\n\nThe session will be active for 1 hour. Use this action to resume the session\nafter it expires.","ref":"AWS.Lightsail.html#start_g_ui_session/3","title":"AWS.Lightsail.start_g_ui_session/3","type":"function"},{"doc":"Starts a specific Amazon Lightsail instance from a stopped state.\n\nTo restart an instance, use the `reboot instance` operation.\n\nWhen you start a stopped instance, Lightsail assigns a new public IP address to\nthe instance. To use the same IP address after stopping and starting an\ninstance, create a static IP address and attach it to the instance. For more\ninformation, see the [Amazon Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/lightsail-create-static-ip).\n\nThe `start instance` operation supports tag-based access control via resource\ntags applied to the resource identified by `instance name`. For more\ninformation, see the [Amazon Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-controlling-access-using-tags).","ref":"AWS.Lightsail.html#start_instance/3","title":"AWS.Lightsail.start_instance/3","type":"function"},{"doc":"Starts a specific database from a stopped state in Amazon Lightsail.\n\nTo restart a database, use the `reboot relational database` operation.\n\nThe `start relational database` operation supports tag-based access control via\nresource tags applied to the resource identified by relationalDatabaseName. For\nmore information, see the [Amazon Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-controlling-access-using-tags).","ref":"AWS.Lightsail.html#start_relational_database/3","title":"AWS.Lightsail.start_relational_database/3","type":"function"},{"doc":"Terminates a web-based NICE DCV session that’s used to access a virtual\ncomputer’s operating system or application.\n\nThe session will close and any unsaved data will be lost.","ref":"AWS.Lightsail.html#stop_g_ui_session/3","title":"AWS.Lightsail.stop_g_ui_session/3","type":"function"},{"doc":"Stops a specific Amazon Lightsail instance that is currently running.\n\nWhen you start a stopped instance, Lightsail assigns a new public IP address to\nthe instance. To use the same IP address after stopping and starting an\ninstance, create a static IP address and attach it to the instance. For more\ninformation, see the [Amazon Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/lightsail-create-static-ip).\n\nThe `stop instance` operation supports tag-based access control via resource\ntags applied to the resource identified by `instance name`. For more\ninformation, see the [Amazon Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-controlling-access-using-tags).","ref":"AWS.Lightsail.html#stop_instance/3","title":"AWS.Lightsail.stop_instance/3","type":"function"},{"doc":"Stops a specific database that is currently running in Amazon Lightsail.\n\nThe `stop relational database` operation supports tag-based access control via\nresource tags applied to the resource identified by relationalDatabaseName. For\nmore information, see the [Amazon Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-controlling-access-using-tags).","ref":"AWS.Lightsail.html#stop_relational_database/3","title":"AWS.Lightsail.stop_relational_database/3","type":"function"},{"doc":"Adds one or more tags to the specified Amazon Lightsail resource.\n\nEach resource can have a maximum of 50 tags. Each tag consists of a key and an\noptional value. Tag keys must be unique per resource. For more information about\ntags, see the [Amazon Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-tags).\n\nThe `tag resource` operation supports tag-based access control via request tags\nand resource tags applied to the resource identified by `resource name`. For\nmore information, see the [Amazon Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-controlling-access-using-tags).","ref":"AWS.Lightsail.html#tag_resource/3","title":"AWS.Lightsail.tag_resource/3","type":"function"},{"doc":"Tests an alarm by displaying a banner on the Amazon Lightsail console.\n\nIf a notification trigger is configured for the specified alarm, the test also\nsends a notification to the notification protocol (`Email` and/or `SMS`)\nconfigured for the alarm.\n\nAn alarm is used to monitor a single metric for one of your resources. When a\nmetric condition is met, the alarm can notify you by email, SMS text message,\nand a banner displayed on the Amazon Lightsail console. For more information,\nsee [Alarms in Amazon Lightsail](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-alarms).","ref":"AWS.Lightsail.html#test_alarm/3","title":"AWS.Lightsail.test_alarm/3","type":"function"},{"doc":"Unpeers the Lightsail VPC from the user's default VPC.","ref":"AWS.Lightsail.html#unpeer_vpc/3","title":"AWS.Lightsail.unpeer_vpc/3","type":"function"},{"doc":"Deletes the specified set of tag keys and their values from the specified Amazon\nLightsail resource.\n\nThe `untag resource` operation supports tag-based access control via request\ntags and resource tags applied to the resource identified by `resource name`.\nFor more information, see the [Amazon Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-controlling-access-using-tags).","ref":"AWS.Lightsail.html#untag_resource/3","title":"AWS.Lightsail.untag_resource/3","type":"function"},{"doc":"Updates an existing Amazon Lightsail bucket.\n\nUse this action to update the configuration of an existing bucket, such as\nversioning, public accessibility, and the Amazon Web Services accounts that can\naccess the bucket.","ref":"AWS.Lightsail.html#update_bucket/3","title":"AWS.Lightsail.update_bucket/3","type":"function"},{"doc":"Updates the bundle, or storage plan, of an existing Amazon Lightsail bucket.\n\nA bucket bundle specifies the monthly cost, storage space, and data transfer\nquota for a bucket. You can update a bucket's bundle only one time within a\nmonthly Amazon Web Services billing cycle. To determine if you can update a\nbucket's bundle, use the\n[GetBuckets](https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetBuckets.html)\naction. The `ableToUpdateBundle` parameter in the response will indicate whether\nyou can currently update a bucket's bundle.\n\nUpdate a bucket's bundle if it's consistently going over its storage space or\ndata transfer quota, or if a bucket's usage is consistently in the lower range\nof its storage space or data transfer quota. Due to the unpredictable usage\nfluctuations that a bucket might experience, we strongly recommend that you\nupdate a bucket's bundle only as a long-term strategy, instead of as a\nshort-term, monthly cost-cutting measure. Choose a bucket bundle that will\nprovide the bucket with ample storage space and data transfer for a long time to\ncome.","ref":"AWS.Lightsail.html#update_bucket_bundle/3","title":"AWS.Lightsail.update_bucket_bundle/3","type":"function"},{"doc":"Updates the configuration of your Amazon Lightsail container service, such as\nits power, scale, and public domain names.","ref":"AWS.Lightsail.html#update_container_service/3","title":"AWS.Lightsail.update_container_service/3","type":"function"},{"doc":"Updates an existing Amazon Lightsail content delivery network (CDN)\ndistribution.\n\nUse this action to update the configuration of your existing distribution.","ref":"AWS.Lightsail.html#update_distribution/3","title":"AWS.Lightsail.update_distribution/3","type":"function"},{"doc":"Updates the bundle of your Amazon Lightsail content delivery network (CDN)\ndistribution.\n\nA distribution bundle specifies the monthly network transfer quota and monthly\ncost of your distribution.\n\nUpdate your distribution's bundle if your distribution is going over its monthly\nnetwork transfer quota and is incurring an overage fee.\n\nYou can update your distribution's bundle only one time within your monthly\nAmazon Web Services billing cycle. To determine if you can update your\ndistribution's bundle, use the `GetDistributions` action. The\n`ableToUpdateBundle` parameter in the result will indicate whether you can\ncurrently update your distribution's bundle.","ref":"AWS.Lightsail.html#update_distribution_bundle/3","title":"AWS.Lightsail.update_distribution_bundle/3","type":"function"},{"doc":"Updates a domain recordset after it is created.\n\nThe `update domain entry` operation supports tag-based access control via\nresource tags applied to the resource identified by `domain name`. For more\ninformation, see the [Amazon Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-controlling-access-using-tags).","ref":"AWS.Lightsail.html#update_domain_entry/3","title":"AWS.Lightsail.update_domain_entry/3","type":"function"},{"doc":"Modifies the Amazon Lightsail instance metadata parameters on a running or\nstopped instance.\n\nWhen you modify the parameters on a running instance, the `GetInstance` or\n`GetInstances` API operation initially responds with a state of `pending`. After\nthe parameter modifications are successfully applied, the state changes to\n`applied` in subsequent `GetInstance` or `GetInstances` API calls. For more\ninformation, see [Use IMDSv2 with an Amazon Lightsail instance](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-configuring-instance-metadata-service)\nin the *Amazon Lightsail Developer Guide*.","ref":"AWS.Lightsail.html#update_instance_metadata_options/3","title":"AWS.Lightsail.update_instance_metadata_options/3","type":"function"},{"doc":"Updates the specified attribute for a load balancer.\n\nYou can only update one attribute at a time.\n\nThe `update load balancer attribute` operation supports tag-based access control\nvia resource tags applied to the resource identified by `load balancer name`.\nFor more information, see the [Amazon Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-controlling-access-using-tags).","ref":"AWS.Lightsail.html#update_load_balancer_attribute/3","title":"AWS.Lightsail.update_load_balancer_attribute/3","type":"function"},{"doc":"Allows the update of one or more attributes of a database in Amazon Lightsail.\n\nUpdates are applied immediately, or in cases where the updates could result in\nan outage, are applied during the database's predefined maintenance window.\n\nThe `update relational database` operation supports tag-based access control via\nresource tags applied to the resource identified by relationalDatabaseName. For\nmore information, see the [Amazon Lightsail Developer Guide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-controlling-access-using-tags).","ref":"AWS.Lightsail.html#update_relational_database/3","title":"AWS.Lightsail.update_relational_database/3","type":"function"},{"doc":"Allows the update of one or more parameters of a database in Amazon Lightsail.\n\nParameter updates don't cause outages; therefore, their application is not\nsubject to the preferred maintenance window. However, there are two ways in\nwhich parameter updates are applied: `dynamic` or `pending-reboot`. Parameters\nmarked with a `dynamic` apply type are applied immediately. Parameters marked\nwith a `pending-reboot` apply type are applied only after the database is\nrebooted using the `reboot relational database` operation.\n\nThe `update relational database parameters` operation supports tag-based access\ncontrol via resource tags applied to the resource identified by\nrelationalDatabaseName. For more information, see the [Amazon Lightsail Developer\nGuide](https://lightsail.aws.amazon.com/ls/docs/en_us/articles/amazon-lightsail-controlling-access-using-tags).","ref":"AWS.Lightsail.html#update_relational_database_parameters/3","title":"AWS.Lightsail.update_relational_database_parameters/3","type":"function"},{"doc":"\"Suite of geospatial services including Maps, Places, Routes, Tracking, and\nGeofencing\"","ref":"AWS.Location.html","title":"AWS.Location","type":"module"},{"doc":"Creates an association between a geofence collection and a tracker resource.\n\nThis allows the tracker resource to communicate location data to the linked\ngeofence collection.\n\nYou can associate up to five geofence collections to each tracker resource.\n\nCurrently not supported — Cross-account configurations, such as creating\nassociations between a tracker resource in one account and a geofence collection\nin another account.","ref":"AWS.Location.html#associate_tracker_consumer/4","title":"AWS.Location.associate_tracker_consumer/4","type":"function"},{"doc":"Deletes the position history of one or more devices from a tracker resource.","ref":"AWS.Location.html#batch_delete_device_position_history/4","title":"AWS.Location.batch_delete_device_position_history/4","type":"function"},{"doc":"Deletes a batch of geofences from a geofence collection.\n\nThis operation deletes the resource permanently.","ref":"AWS.Location.html#batch_delete_geofence/4","title":"AWS.Location.batch_delete_geofence/4","type":"function"},{"doc":"Evaluates device positions against the geofence geometries from a given geofence\ncollection.\n\nThis operation always returns an empty response because geofences are\nasynchronously evaluated. The evaluation determines if the device has entered or\nexited a geofenced area, and then publishes one of the following events to\nAmazon EventBridge:\n\n  * `ENTER` if Amazon Location determines that the tracked device has\nentered a geofenced area.\n\n  * `EXIT` if Amazon Location determines that the tracked device has\nexited a geofenced area.\n\nThe last geofence that a device was observed within is tracked for 30 days after\nthe most recent device position update.\n\nGeofence evaluation uses the given device position. It does not account for the\noptional `Accuracy` of a `DevicePositionUpdate`.\n\nThe `DeviceID` is used as a string to represent the device. You do not need to\nhave a `Tracker` associated with the `DeviceID`.","ref":"AWS.Location.html#batch_evaluate_geofences/4","title":"AWS.Location.batch_evaluate_geofences/4","type":"function"},{"doc":"Lists the latest device positions for requested devices.","ref":"AWS.Location.html#batch_get_device_position/4","title":"AWS.Location.batch_get_device_position/4","type":"function"},{"doc":"A batch request for storing geofence geometries into a given geofence\ncollection, or updates the geometry of an existing geofence if a geofence ID is\nincluded in the request.","ref":"AWS.Location.html#batch_put_geofence/4","title":"AWS.Location.batch_put_geofence/4","type":"function"},{"doc":"Uploads position update data for one or more devices to a tracker resource (up\nto 10 devices per batch).\n\nAmazon Location uses the data when it reports the last known device position and\nposition history. Amazon Location retains location data for 30 days.\n\nPosition updates are handled based on the `PositionFiltering` property of the\ntracker. When `PositionFiltering` is set to `TimeBased`, updates are evaluated\nagainst linked geofence collections, and location data is stored at a maximum of\none position per 30 second interval. If your update frequency is more often than\nevery 30 seconds, only one update per 30 seconds is stored for each unique\ndevice ID.\n\nWhen `PositionFiltering` is set to `DistanceBased` filtering, location data is\nstored and evaluated against linked geofence collections only if the device has\nmoved more than 30 m (98.4 ft).\n\nWhen `PositionFiltering` is set to `AccuracyBased` filtering, location data is\nstored and evaluated against linked geofence collections only if the device has\nmoved more than the measured accuracy. For example, if two consecutive updates\nfrom a device have a horizontal accuracy of 5 m and 10 m, the second update is\nneither stored or evaluated if the device has moved less than 15 m. If\n`PositionFiltering` is set to `AccuracyBased` filtering, Amazon Location uses\nthe default value `{ \"Horizontal\": 0}` when accuracy is not provided on a\n`DevicePositionUpdate`.","ref":"AWS.Location.html#batch_update_device_position/4","title":"AWS.Location.batch_update_device_position/4","type":"function"},{"doc":"[Calculates a route](https://docs.aws.amazon.com/location/latest/developerguide/calculate-route.html)\ngiven the following required parameters: `DeparturePosition` and\n`DestinationPosition`.\n\nRequires that you first [create a route calculator resource](https://docs.aws.amazon.com/location-routes/latest/APIReference/API_CreateRouteCalculator.html).\n\nBy default, a request that doesn't specify a departure time uses the best time\nof day to travel with the best traffic conditions when calculating the route.\n\nAdditional options include:\n\n  * [Specifying a departure time](https://docs.aws.amazon.com/location/latest/developerguide/departure-time.html)\nusing either `DepartureTime` or `DepartNow`. This calculates a route based on\npredictive traffic data at the given time.\n\nYou can't specify both `DepartureTime` and `DepartNow` in a single request.\nSpecifying both parameters returns a validation error.\n\n  * [Specifying a travel mode](https://docs.aws.amazon.com/location/latest/developerguide/travel-mode.html)\nusing TravelMode sets the transportation mode used to calculate the routes. This\nalso lets you specify additional route preferences in `CarModeOptions` if\ntraveling by `Car`, or `TruckModeOptions` if traveling by `Truck`.\n\nIf you specify `walking` for the travel mode and your data provider is Esri, the\nstart and destination must be within 40km.","ref":"AWS.Location.html#calculate_route/4","title":"AWS.Location.calculate_route/4","type":"function"},{"doc":"[ Calculates a route matrix](https://docs.aws.amazon.com/location/latest/developerguide/calculate-route-matrix.html)\ngiven the following required parameters: `DeparturePositions` and\n`DestinationPositions`.\n\n`CalculateRouteMatrix` calculates routes and returns the travel time and travel\ndistance from each departure position to each destination position in the\nrequest. For example, given departure positions A and B, and destination\npositions X and Y, `CalculateRouteMatrix` will return time and distance for\nroutes from A to X, A to Y, B to X, and B to Y (in that order). The number of\nresults returned (and routes calculated) will be the number of\n`DeparturePositions` times the number of `DestinationPositions`.\n\nYour account is charged for each route calculated, not the number of requests.\n\nRequires that you first [create a route calculator resource](https://docs.aws.amazon.com/location-routes/latest/APIReference/API_CreateRouteCalculator.html).\n\nBy default, a request that doesn't specify a departure time uses the best time\nof day to travel with the best traffic conditions when calculating routes.\n\nAdditional options include:\n\n  * [ Specifying a departure time](https://docs.aws.amazon.com/location/latest/developerguide/departure-time.html)\nusing either `DepartureTime` or `DepartNow`. This calculates routes based on\npredictive traffic data at the given time.\n\nYou can't specify both `DepartureTime` and `DepartNow` in a single request.\nSpecifying both parameters returns a validation error.\n\n  * [Specifying a travel mode](https://docs.aws.amazon.com/location/latest/developerguide/travel-mode.html)\nusing TravelMode sets the transportation mode used to calculate the routes. This\nalso lets you specify additional route preferences in `CarModeOptions` if\ntraveling by `Car`, or `TruckModeOptions` if traveling by `Truck`.","ref":"AWS.Location.html#calculate_route_matrix/4","title":"AWS.Location.calculate_route_matrix/4","type":"function"},{"doc":"Creates a geofence collection, which manages and stores geofences.","ref":"AWS.Location.html#create_geofence_collection/3","title":"AWS.Location.create_geofence_collection/3","type":"function"},{"doc":"Creates an API key resource in your Amazon Web Services account, which lets you\ngrant actions for Amazon Location resources to the API key bearer.\n\nFor more information, see [Using API keys](https://docs.aws.amazon.com/location/latest/developerguide/using-apikeys.html).","ref":"AWS.Location.html#create_key/3","title":"AWS.Location.create_key/3","type":"function"},{"doc":"Creates a map resource in your Amazon Web Services account, which provides map\ntiles of different styles sourced from global location data providers.\n\nIf your application is tracking or routing assets you use in your business, such\nas delivery vehicles or employees, you must not use Esri as your geolocation\nprovider. See section 82 of the [Amazon Web Services service terms](http://aws.amazon.com/service-terms) for more details.","ref":"AWS.Location.html#create_map/3","title":"AWS.Location.create_map/3","type":"function"},{"doc":"Creates a place index resource in your Amazon Web Services account.\n\nUse a place index resource to geocode addresses and other text queries by using\nthe `SearchPlaceIndexForText` operation, and reverse geocode coordinates by\nusing the `SearchPlaceIndexForPosition` operation, and enable autosuggestions by\nusing the `SearchPlaceIndexForSuggestions` operation.\n\nIf your application is tracking or routing assets you use in your business, such\nas delivery vehicles or employees, you must not use Esri as your geolocation\nprovider. See section 82 of the [Amazon Web Services service terms](http://aws.amazon.com/service-terms) for more details.","ref":"AWS.Location.html#create_place_index/3","title":"AWS.Location.create_place_index/3","type":"function"},{"doc":"Creates a route calculator resource in your Amazon Web Services account.\n\nYou can send requests to a route calculator resource to estimate travel time,\ndistance, and get directions. A route calculator sources traffic and road\nnetwork data from your chosen data provider.\n\nIf your application is tracking or routing assets you use in your business, such\nas delivery vehicles or employees, you must not use Esri as your geolocation\nprovider. See section 82 of the [Amazon Web Services service terms](http://aws.amazon.com/service-terms) for more details.","ref":"AWS.Location.html#create_route_calculator/3","title":"AWS.Location.create_route_calculator/3","type":"function"},{"doc":"Creates a tracker resource in your Amazon Web Services account, which lets you\nretrieve current and historical location of devices.","ref":"AWS.Location.html#create_tracker/3","title":"AWS.Location.create_tracker/3","type":"function"},{"doc":"Deletes a geofence collection from your Amazon Web Services account.\n\nThis operation deletes the resource permanently. If the geofence collection is\nthe target of a tracker resource, the devices will no longer be monitored.","ref":"AWS.Location.html#delete_geofence_collection/4","title":"AWS.Location.delete_geofence_collection/4","type":"function"},{"doc":"Deletes the specified API key.\n\nThe API key must have been deactivated more than 90 days previously.","ref":"AWS.Location.html#delete_key/4","title":"AWS.Location.delete_key/4","type":"function"},{"doc":"Deletes a map resource from your Amazon Web Services account.\n\nThis operation deletes the resource permanently. If the map is being used in an\napplication, the map may not render.","ref":"AWS.Location.html#delete_map/4","title":"AWS.Location.delete_map/4","type":"function"},{"doc":"Deletes a place index resource from your Amazon Web Services account.\n\nThis operation deletes the resource permanently.","ref":"AWS.Location.html#delete_place_index/4","title":"AWS.Location.delete_place_index/4","type":"function"},{"doc":"Deletes a route calculator resource from your Amazon Web Services account.\n\nThis operation deletes the resource permanently.","ref":"AWS.Location.html#delete_route_calculator/4","title":"AWS.Location.delete_route_calculator/4","type":"function"},{"doc":"Deletes a tracker resource from your Amazon Web Services account.\n\nThis operation deletes the resource permanently. If the tracker resource is in\nuse, you may encounter an error. Make sure that the target resource isn't a\ndependency for your applications.","ref":"AWS.Location.html#delete_tracker/4","title":"AWS.Location.delete_tracker/4","type":"function"},{"doc":"Retrieves the geofence collection details.","ref":"AWS.Location.html#describe_geofence_collection/3","title":"AWS.Location.describe_geofence_collection/3","type":"function"},{"doc":"Retrieves the API key resource details.","ref":"AWS.Location.html#describe_key/3","title":"AWS.Location.describe_key/3","type":"function"},{"doc":"Retrieves the map resource details.","ref":"AWS.Location.html#describe_map/3","title":"AWS.Location.describe_map/3","type":"function"},{"doc":"Retrieves the place index resource details.","ref":"AWS.Location.html#describe_place_index/3","title":"AWS.Location.describe_place_index/3","type":"function"},{"doc":"Retrieves the route calculator resource details.","ref":"AWS.Location.html#describe_route_calculator/3","title":"AWS.Location.describe_route_calculator/3","type":"function"},{"doc":"Retrieves the tracker resource details.","ref":"AWS.Location.html#describe_tracker/3","title":"AWS.Location.describe_tracker/3","type":"function"},{"doc":"Removes the association between a tracker resource and a geofence collection.\n\nOnce you unlink a tracker resource from a geofence collection, the tracker\npositions will no longer be automatically evaluated against geofences.","ref":"AWS.Location.html#disassociate_tracker_consumer/5","title":"AWS.Location.disassociate_tracker_consumer/5","type":"function"},{"doc":"Retrieves a device's most recent position according to its sample time.\n\nDevice positions are deleted after 30 days.","ref":"AWS.Location.html#get_device_position/4","title":"AWS.Location.get_device_position/4","type":"function"},{"doc":"Retrieves the device position history from a tracker resource within a specified\nrange of time.\n\nDevice positions are deleted after 30 days.","ref":"AWS.Location.html#get_device_position_history/5","title":"AWS.Location.get_device_position_history/5","type":"function"},{"doc":"Retrieves the geofence details from a geofence collection.","ref":"AWS.Location.html#get_geofence/4","title":"AWS.Location.get_geofence/4","type":"function"},{"doc":"Retrieves glyphs used to display labels on a map.","ref":"AWS.Location.html#get_map_glyphs/6","title":"AWS.Location.get_map_glyphs/6","type":"function"},{"doc":"Retrieves the sprite sheet corresponding to a map resource.\n\nThe sprite sheet is a PNG image paired with a JSON document describing the\noffsets of individual icons that will be displayed on a rendered map.","ref":"AWS.Location.html#get_map_sprites/5","title":"AWS.Location.get_map_sprites/5","type":"function"},{"doc":"Retrieves the map style descriptor from a map resource.\n\nThe style descriptor contains speciﬁcations on how features render on a map. For\nexample, what data to display, what order to display the data in, and the style\nfor the data. Style descriptors follow the Mapbox Style Specification.","ref":"AWS.Location.html#get_map_style_descriptor/4","title":"AWS.Location.get_map_style_descriptor/4","type":"function"},{"doc":"Retrieves a vector data tile from the map resource.\n\nMap tiles are used by clients to render a map. they're addressed using a grid\narrangement with an X coordinate, Y coordinate, and Z (zoom) level.\n\nThe origin (0, 0) is the top left of the map. Increasing the zoom level by 1\ndoubles both the X and Y dimensions, so a tile containing data for the entire\nworld at (0/0/0) will be split into 4 tiles at zoom 1 (1/0/0, 1/0/1, 1/1/0,\n1/1/1).","ref":"AWS.Location.html#get_map_tile/7","title":"AWS.Location.get_map_tile/7","type":"function"},{"doc":"Finds a place by its unique ID.\n\nA `PlaceId` is returned by other search operations.\n\nA PlaceId is valid only if all of the following are the same in the original\nsearch request and the call to `GetPlace`.\n\n   Customer Amazon Web Services account\n\n   Amazon Web Services Region\n\n   Data provider specified in the place index resource","ref":"AWS.Location.html#get_place/6","title":"AWS.Location.get_place/6","type":"function"},{"doc":"A batch request to retrieve all device positions.","ref":"AWS.Location.html#list_device_positions/4","title":"AWS.Location.list_device_positions/4","type":"function"},{"doc":"Lists geofence collections in your Amazon Web Services account.","ref":"AWS.Location.html#list_geofence_collections/3","title":"AWS.Location.list_geofence_collections/3","type":"function"},{"doc":"Lists geofences stored in a given geofence collection.","ref":"AWS.Location.html#list_geofences/4","title":"AWS.Location.list_geofences/4","type":"function"},{"doc":"Lists API key resources in your Amazon Web Services account.","ref":"AWS.Location.html#list_keys/3","title":"AWS.Location.list_keys/3","type":"function"},{"doc":"Lists map resources in your Amazon Web Services account.","ref":"AWS.Location.html#list_maps/3","title":"AWS.Location.list_maps/3","type":"function"},{"doc":"Lists place index resources in your Amazon Web Services account.","ref":"AWS.Location.html#list_place_indexes/3","title":"AWS.Location.list_place_indexes/3","type":"function"},{"doc":"Lists route calculator resources in your Amazon Web Services account.","ref":"AWS.Location.html#list_route_calculators/3","title":"AWS.Location.list_route_calculators/3","type":"function"},{"doc":"Returns a list of tags that are applied to the specified Amazon Location\nresource.","ref":"AWS.Location.html#list_tags_for_resource/3","title":"AWS.Location.list_tags_for_resource/3","type":"function"},{"doc":"Lists geofence collections currently associated to the given tracker resource.","ref":"AWS.Location.html#list_tracker_consumers/4","title":"AWS.Location.list_tracker_consumers/4","type":"function"},{"doc":"Lists tracker resources in your Amazon Web Services account.","ref":"AWS.Location.html#list_trackers/3","title":"AWS.Location.list_trackers/3","type":"function"},{"doc":"","ref":"AWS.Location.html#metadata/0","title":"AWS.Location.metadata/0","type":"function"},{"doc":"Stores a geofence geometry in a given geofence collection, or updates the\ngeometry of an existing geofence if a geofence ID is included in the request.","ref":"AWS.Location.html#put_geofence/5","title":"AWS.Location.put_geofence/5","type":"function"},{"doc":"Reverse geocodes a given coordinate and returns a legible address.\n\nAllows you to search for Places or points of interest near a given position.","ref":"AWS.Location.html#search_place_index_for_position/4","title":"AWS.Location.search_place_index_for_position/4","type":"function"},{"doc":"Generates suggestions for addresses and points of interest based on partial or\nmisspelled free-form text.\n\nThis operation is also known as autocomplete, autosuggest, or fuzzy matching.\n\nOptional parameters let you narrow your search results by bounding box or\ncountry, or bias your search toward a specific position on the globe.\n\nYou can search for suggested place names near a specified position by using\n`BiasPosition`, or filter results within a bounding box by using `FilterBBox`.\nThese parameters are mutually exclusive; using both `BiasPosition` and\n`FilterBBox` in the same command returns an error.","ref":"AWS.Location.html#search_place_index_for_suggestions/4","title":"AWS.Location.search_place_index_for_suggestions/4","type":"function"},{"doc":"Geocodes free-form text, such as an address, name, city, or region to allow you\nto search for Places or points of interest.\n\nOptional parameters let you narrow your search results by bounding box or\ncountry, or bias your search toward a specific position on the globe.\n\nYou can search for places near a given position using `BiasPosition`, or filter\nresults within a bounding box using `FilterBBox`. Providing both parameters\nsimultaneously returns an error.\n\nSearch results are returned in order of highest to lowest relevance.","ref":"AWS.Location.html#search_place_index_for_text/4","title":"AWS.Location.search_place_index_for_text/4","type":"function"},{"doc":"Assigns one or more tags (key-value pairs) to the specified Amazon Location\nService resource.\n\nTags can help you organize and categorize your resources. You can also use them\nto scope user permissions, by granting a user permission to access or change\nonly resources with certain tag values.\n\nYou can use the `TagResource` operation with an Amazon Location Service resource\nthat already has tags. If you specify a new tag key for the resource, this tag\nis appended to the tags already associated with the resource. If you specify a\ntag key that's already associated with the resource, the new tag value that you\nspecify replaces the previous value for that tag.\n\nYou can associate up to 50 tags with a resource.","ref":"AWS.Location.html#tag_resource/4","title":"AWS.Location.tag_resource/4","type":"function"},{"doc":"Removes one or more tags from the specified Amazon Location resource.","ref":"AWS.Location.html#untag_resource/4","title":"AWS.Location.untag_resource/4","type":"function"},{"doc":"Updates the specified properties of a given geofence collection.","ref":"AWS.Location.html#update_geofence_collection/4","title":"AWS.Location.update_geofence_collection/4","type":"function"},{"doc":"Updates the specified properties of a given API key resource.","ref":"AWS.Location.html#update_key/4","title":"AWS.Location.update_key/4","type":"function"},{"doc":"Updates the specified properties of a given map resource.","ref":"AWS.Location.html#update_map/4","title":"AWS.Location.update_map/4","type":"function"},{"doc":"Updates the specified properties of a given place index resource.","ref":"AWS.Location.html#update_place_index/4","title":"AWS.Location.update_place_index/4","type":"function"},{"doc":"Updates the specified properties for a given route calculator resource.","ref":"AWS.Location.html#update_route_calculator/4","title":"AWS.Location.update_route_calculator/4","type":"function"},{"doc":"Updates the specified properties of a given tracker resource.","ref":"AWS.Location.html#update_tracker/4","title":"AWS.Location.update_tracker/4","type":"function"},{"doc":"Amazon Lookout for Equipment is a machine learning service that uses advanced\nanalytics to identify anomalies in machines from sensor data for use in\npredictive maintenance.","ref":"AWS.LookoutEquipment.html","title":"AWS.LookoutEquipment","type":"module"},{"doc":"Creates a container for a collection of data being ingested for analysis.\n\nThe dataset contains the metadata describing where the data is and what the data\nactually looks like. For example, it contains the location of the data source,\nthe data schema, and other information. A dataset also contains any tags\nassociated with the ingested data.","ref":"AWS.LookoutEquipment.html#create_dataset/3","title":"AWS.LookoutEquipment.create_dataset/3","type":"function"},{"doc":"Creates a scheduled inference.\n\nScheduling an inference is setting up a continuous real-time inference plan to\nanalyze new measurement data. When setting up the schedule, you provide an S3\nbucket location for the input data, assign it a delimiter between separate\nentries in the data, set an offset delay if desired, and set the frequency of\ninferencing. You must also provide an S3 bucket location for the output data.","ref":"AWS.LookoutEquipment.html#create_inference_scheduler/3","title":"AWS.LookoutEquipment.create_inference_scheduler/3","type":"function"},{"doc":"Creates a label for an event.","ref":"AWS.LookoutEquipment.html#create_label/3","title":"AWS.LookoutEquipment.create_label/3","type":"function"},{"doc":"Creates a group of labels.","ref":"AWS.LookoutEquipment.html#create_label_group/3","title":"AWS.LookoutEquipment.create_label_group/3","type":"function"},{"doc":"Creates a machine learning model for data inference.\n\nA machine-learning (ML) model is a mathematical model that finds patterns in\nyour data. In Amazon Lookout for Equipment, the model learns the patterns of\nnormal behavior and detects abnormal behavior that could be potential equipment\nfailure (or maintenance events). The models are made by analyzing normal data\nand abnormalities in machine behavior that have already occurred.\n\nYour model is trained using a portion of the data from your dataset and uses\nthat data to learn patterns of normal behavior and abnormal patterns that lead\nto equipment failure. Another portion of the data is used to evaluate the\nmodel's accuracy.","ref":"AWS.LookoutEquipment.html#create_model/3","title":"AWS.LookoutEquipment.create_model/3","type":"function"},{"doc":"Creates a retraining scheduler on the specified model.","ref":"AWS.LookoutEquipment.html#create_retraining_scheduler/3","title":"AWS.LookoutEquipment.create_retraining_scheduler/3","type":"function"},{"doc":"Deletes a dataset and associated artifacts.\n\nThe operation will check to see if any inference scheduler or data ingestion job\nis currently using the dataset, and if there isn't, the dataset, its metadata,\nand any associated data stored in S3 will be deleted. This does not affect any\nmodels that used this dataset for training and evaluation, but does prevent it\nfrom being used in the future.","ref":"AWS.LookoutEquipment.html#delete_dataset/3","title":"AWS.LookoutEquipment.delete_dataset/3","type":"function"},{"doc":"Deletes an inference scheduler that has been set up.\n\nPrior inference results will not be deleted.","ref":"AWS.LookoutEquipment.html#delete_inference_scheduler/3","title":"AWS.LookoutEquipment.delete_inference_scheduler/3","type":"function"},{"doc":"Deletes a label.","ref":"AWS.LookoutEquipment.html#delete_label/3","title":"AWS.LookoutEquipment.delete_label/3","type":"function"},{"doc":"Deletes a group of labels.","ref":"AWS.LookoutEquipment.html#delete_label_group/3","title":"AWS.LookoutEquipment.delete_label_group/3","type":"function"},{"doc":"Deletes a machine learning model currently available for Amazon Lookout for\nEquipment.\n\nThis will prevent it from being used with an inference scheduler, even one that\nis already set up.","ref":"AWS.LookoutEquipment.html#delete_model/3","title":"AWS.LookoutEquipment.delete_model/3","type":"function"},{"doc":"Deletes the resource policy attached to the resource.","ref":"AWS.LookoutEquipment.html#delete_resource_policy/3","title":"AWS.LookoutEquipment.delete_resource_policy/3","type":"function"},{"doc":"Deletes a retraining scheduler from a model.\n\nThe retraining scheduler must be in the `STOPPED` status.","ref":"AWS.LookoutEquipment.html#delete_retraining_scheduler/3","title":"AWS.LookoutEquipment.delete_retraining_scheduler/3","type":"function"},{"doc":"Provides information on a specific data ingestion job such as creation time,\ndataset ARN, and status.","ref":"AWS.LookoutEquipment.html#describe_data_ingestion_job/3","title":"AWS.LookoutEquipment.describe_data_ingestion_job/3","type":"function"},{"doc":"Provides a JSON description of the data in each time series dataset, including\nnames, column names, and data types.","ref":"AWS.LookoutEquipment.html#describe_dataset/3","title":"AWS.LookoutEquipment.describe_dataset/3","type":"function"},{"doc":"Specifies information about the inference scheduler being used, including name,\nmodel, status, and associated metadata","ref":"AWS.LookoutEquipment.html#describe_inference_scheduler/3","title":"AWS.LookoutEquipment.describe_inference_scheduler/3","type":"function"},{"doc":"Returns the name of the label.","ref":"AWS.LookoutEquipment.html#describe_label/3","title":"AWS.LookoutEquipment.describe_label/3","type":"function"},{"doc":"Returns information about the label group.","ref":"AWS.LookoutEquipment.html#describe_label_group/3","title":"AWS.LookoutEquipment.describe_label_group/3","type":"function"},{"doc":"Provides a JSON containing the overall information about a specific machine\nlearning model, including model name and ARN, dataset, training and evaluation\ninformation, status, and so on.","ref":"AWS.LookoutEquipment.html#describe_model/3","title":"AWS.LookoutEquipment.describe_model/3","type":"function"},{"doc":"Retrieves information about a specific machine learning model version.","ref":"AWS.LookoutEquipment.html#describe_model_version/3","title":"AWS.LookoutEquipment.describe_model_version/3","type":"function"},{"doc":"Provides the details of a resource policy attached to a resource.","ref":"AWS.LookoutEquipment.html#describe_resource_policy/3","title":"AWS.LookoutEquipment.describe_resource_policy/3","type":"function"},{"doc":"Provides a description of the retraining scheduler, including information such\nas the model name and retraining parameters.","ref":"AWS.LookoutEquipment.html#describe_retraining_scheduler/3","title":"AWS.LookoutEquipment.describe_retraining_scheduler/3","type":"function"},{"doc":"Imports a dataset.","ref":"AWS.LookoutEquipment.html#import_dataset/3","title":"AWS.LookoutEquipment.import_dataset/3","type":"function"},{"doc":"Imports a model that has been trained successfully.","ref":"AWS.LookoutEquipment.html#import_model_version/3","title":"AWS.LookoutEquipment.import_model_version/3","type":"function"},{"doc":"Provides a list of all data ingestion jobs, including dataset name and ARN, S3\nlocation of the input data, status, and so on.","ref":"AWS.LookoutEquipment.html#list_data_ingestion_jobs/3","title":"AWS.LookoutEquipment.list_data_ingestion_jobs/3","type":"function"},{"doc":"Lists all datasets currently available in your account, filtering on the dataset\nname.","ref":"AWS.LookoutEquipment.html#list_datasets/3","title":"AWS.LookoutEquipment.list_datasets/3","type":"function"},{"doc":"Lists all inference events that have been found for the specified inference\nscheduler.","ref":"AWS.LookoutEquipment.html#list_inference_events/3","title":"AWS.LookoutEquipment.list_inference_events/3","type":"function"},{"doc":"Lists all inference executions that have been performed by the specified\ninference scheduler.","ref":"AWS.LookoutEquipment.html#list_inference_executions/3","title":"AWS.LookoutEquipment.list_inference_executions/3","type":"function"},{"doc":"Retrieves a list of all inference schedulers currently available for your\naccount.","ref":"AWS.LookoutEquipment.html#list_inference_schedulers/3","title":"AWS.LookoutEquipment.list_inference_schedulers/3","type":"function"},{"doc":"Returns a list of the label groups.","ref":"AWS.LookoutEquipment.html#list_label_groups/3","title":"AWS.LookoutEquipment.list_label_groups/3","type":"function"},{"doc":"Provides a list of labels.","ref":"AWS.LookoutEquipment.html#list_labels/3","title":"AWS.LookoutEquipment.list_labels/3","type":"function"},{"doc":"Generates a list of all model versions for a given model, including the model\nversion, model version ARN, and status.\n\nTo list a subset of versions, use the `MaxModelVersion` and `MinModelVersion`\nfields.","ref":"AWS.LookoutEquipment.html#list_model_versions/3","title":"AWS.LookoutEquipment.list_model_versions/3","type":"function"},{"doc":"Generates a list of all models in the account, including model name and ARN,\ndataset, and status.","ref":"AWS.LookoutEquipment.html#list_models/3","title":"AWS.LookoutEquipment.list_models/3","type":"function"},{"doc":"Lists all retraining schedulers in your account, filtering by model name prefix\nand status.","ref":"AWS.LookoutEquipment.html#list_retraining_schedulers/3","title":"AWS.LookoutEquipment.list_retraining_schedulers/3","type":"function"},{"doc":"Lists statistics about the data collected for each of the sensors that have been\nsuccessfully ingested in the particular dataset.\n\nCan also be used to retreive Sensor Statistics for a previous ingestion job.","ref":"AWS.LookoutEquipment.html#list_sensor_statistics/3","title":"AWS.LookoutEquipment.list_sensor_statistics/3","type":"function"},{"doc":"Lists all the tags for a specified resource, including key and value.","ref":"AWS.LookoutEquipment.html#list_tags_for_resource/3","title":"AWS.LookoutEquipment.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.LookoutEquipment.html#metadata/0","title":"AWS.LookoutEquipment.metadata/0","type":"function"},{"doc":"Creates a resource control policy for a given resource.","ref":"AWS.LookoutEquipment.html#put_resource_policy/3","title":"AWS.LookoutEquipment.put_resource_policy/3","type":"function"},{"doc":"Starts a data ingestion job.\n\nAmazon Lookout for Equipment returns the job status.","ref":"AWS.LookoutEquipment.html#start_data_ingestion_job/3","title":"AWS.LookoutEquipment.start_data_ingestion_job/3","type":"function"},{"doc":"Starts an inference scheduler.","ref":"AWS.LookoutEquipment.html#start_inference_scheduler/3","title":"AWS.LookoutEquipment.start_inference_scheduler/3","type":"function"},{"doc":"Starts a retraining scheduler.","ref":"AWS.LookoutEquipment.html#start_retraining_scheduler/3","title":"AWS.LookoutEquipment.start_retraining_scheduler/3","type":"function"},{"doc":"Stops an inference scheduler.","ref":"AWS.LookoutEquipment.html#stop_inference_scheduler/3","title":"AWS.LookoutEquipment.stop_inference_scheduler/3","type":"function"},{"doc":"Stops a retraining scheduler.","ref":"AWS.LookoutEquipment.html#stop_retraining_scheduler/3","title":"AWS.LookoutEquipment.stop_retraining_scheduler/3","type":"function"},{"doc":"Associates a given tag to a resource in your account.\n\nA tag is a key-value pair which can be added to an Amazon Lookout for Equipment\nresource as metadata. Tags can be used for organizing your resources as well as\nhelping you to search and filter by tag. Multiple tags can be added to a\nresource, either when you create it, or later. Up to 50 tags can be associated\nwith each resource.","ref":"AWS.LookoutEquipment.html#tag_resource/3","title":"AWS.LookoutEquipment.tag_resource/3","type":"function"},{"doc":"Removes a specific tag from a given resource.\n\nThe tag is specified by its key.","ref":"AWS.LookoutEquipment.html#untag_resource/3","title":"AWS.LookoutEquipment.untag_resource/3","type":"function"},{"doc":"Sets the active model version for a given machine learning model.","ref":"AWS.LookoutEquipment.html#update_active_model_version/3","title":"AWS.LookoutEquipment.update_active_model_version/3","type":"function"},{"doc":"Updates an inference scheduler.","ref":"AWS.LookoutEquipment.html#update_inference_scheduler/3","title":"AWS.LookoutEquipment.update_inference_scheduler/3","type":"function"},{"doc":"Updates the label group.","ref":"AWS.LookoutEquipment.html#update_label_group/3","title":"AWS.LookoutEquipment.update_label_group/3","type":"function"},{"doc":"Updates a model in the account.","ref":"AWS.LookoutEquipment.html#update_model/3","title":"AWS.LookoutEquipment.update_model/3","type":"function"},{"doc":"Updates a retraining scheduler.","ref":"AWS.LookoutEquipment.html#update_retraining_scheduler/3","title":"AWS.LookoutEquipment.update_retraining_scheduler/3","type":"function"},{"doc":"This is the *Amazon Lookout for Metrics API Reference*.\n\nFor an introduction to the service with tutorials for getting started, visit\n[Amazon Lookout for Metrics Developer Guide](https://docs.aws.amazon.com/lookoutmetrics/latest/dev).","ref":"AWS.LookoutMetrics.html","title":"AWS.LookoutMetrics","type":"module"},{"doc":"Activates an anomaly detector.","ref":"AWS.LookoutMetrics.html#activate_anomaly_detector/3","title":"AWS.LookoutMetrics.activate_anomaly_detector/3","type":"function"},{"doc":"Runs a backtest for anomaly detection for the specified resource.","ref":"AWS.LookoutMetrics.html#back_test_anomaly_detector/3","title":"AWS.LookoutMetrics.back_test_anomaly_detector/3","type":"function"},{"doc":"Creates an alert for an anomaly detector.","ref":"AWS.LookoutMetrics.html#create_alert/3","title":"AWS.LookoutMetrics.create_alert/3","type":"function"},{"doc":"Creates an anomaly detector.","ref":"AWS.LookoutMetrics.html#create_anomaly_detector/3","title":"AWS.LookoutMetrics.create_anomaly_detector/3","type":"function"},{"doc":"Creates a dataset.","ref":"AWS.LookoutMetrics.html#create_metric_set/3","title":"AWS.LookoutMetrics.create_metric_set/3","type":"function"},{"doc":"Deactivates an anomaly detector.","ref":"AWS.LookoutMetrics.html#deactivate_anomaly_detector/3","title":"AWS.LookoutMetrics.deactivate_anomaly_detector/3","type":"function"},{"doc":"Deletes an alert.","ref":"AWS.LookoutMetrics.html#delete_alert/3","title":"AWS.LookoutMetrics.delete_alert/3","type":"function"},{"doc":"Deletes a detector.\n\nDeleting an anomaly detector will delete all of its corresponding resources\nincluding any configured datasets and alerts.","ref":"AWS.LookoutMetrics.html#delete_anomaly_detector/3","title":"AWS.LookoutMetrics.delete_anomaly_detector/3","type":"function"},{"doc":"Describes an alert.\n\nAmazon Lookout for Metrics API actions are eventually consistent. If you do a\nread operation on a resource immediately after creating or modifying it, use\nretries to allow time for the write operation to complete.","ref":"AWS.LookoutMetrics.html#describe_alert/3","title":"AWS.LookoutMetrics.describe_alert/3","type":"function"},{"doc":"Returns information about the status of the specified anomaly detection jobs.","ref":"AWS.LookoutMetrics.html#describe_anomaly_detection_executions/3","title":"AWS.LookoutMetrics.describe_anomaly_detection_executions/3","type":"function"},{"doc":"Describes a detector.\n\nAmazon Lookout for Metrics API actions are eventually consistent. If you do a\nread operation on a resource immediately after creating or modifying it, use\nretries to allow time for the write operation to complete.","ref":"AWS.LookoutMetrics.html#describe_anomaly_detector/3","title":"AWS.LookoutMetrics.describe_anomaly_detector/3","type":"function"},{"doc":"Describes a dataset.\n\nAmazon Lookout for Metrics API actions are eventually consistent. If you do a\nread operation on a resource immediately after creating or modifying it, use\nretries to allow time for the write operation to complete.","ref":"AWS.LookoutMetrics.html#describe_metric_set/3","title":"AWS.LookoutMetrics.describe_metric_set/3","type":"function"},{"doc":"Detects an Amazon S3 dataset's file format, interval, and offset.","ref":"AWS.LookoutMetrics.html#detect_metric_set_config/3","title":"AWS.LookoutMetrics.detect_metric_set_config/3","type":"function"},{"doc":"Returns details about a group of anomalous metrics.","ref":"AWS.LookoutMetrics.html#get_anomaly_group/3","title":"AWS.LookoutMetrics.get_anomaly_group/3","type":"function"},{"doc":"Returns details about the requested data quality metrics.","ref":"AWS.LookoutMetrics.html#get_data_quality_metrics/3","title":"AWS.LookoutMetrics.get_data_quality_metrics/3","type":"function"},{"doc":"Get feedback for an anomaly group.","ref":"AWS.LookoutMetrics.html#get_feedback/3","title":"AWS.LookoutMetrics.get_feedback/3","type":"function"},{"doc":"Returns a selection of sample records from an Amazon S3 datasource.","ref":"AWS.LookoutMetrics.html#get_sample_data/3","title":"AWS.LookoutMetrics.get_sample_data/3","type":"function"},{"doc":"Lists the alerts attached to a detector.\n\nAmazon Lookout for Metrics API actions are eventually consistent. If you do a\nread operation on a resource immediately after creating or modifying it, use\nretries to allow time for the write operation to complete.","ref":"AWS.LookoutMetrics.html#list_alerts/3","title":"AWS.LookoutMetrics.list_alerts/3","type":"function"},{"doc":"Lists the detectors in the current AWS Region.\n\nAmazon Lookout for Metrics API actions are eventually consistent. If you do a\nread operation on a resource immediately after creating or modifying it, use\nretries to allow time for the write operation to complete.","ref":"AWS.LookoutMetrics.html#list_anomaly_detectors/3","title":"AWS.LookoutMetrics.list_anomaly_detectors/3","type":"function"},{"doc":"Returns a list of measures that are potential causes or effects of an anomaly\ngroup.","ref":"AWS.LookoutMetrics.html#list_anomaly_group_related_metrics/3","title":"AWS.LookoutMetrics.list_anomaly_group_related_metrics/3","type":"function"},{"doc":"Returns a list of anomaly groups.","ref":"AWS.LookoutMetrics.html#list_anomaly_group_summaries/3","title":"AWS.LookoutMetrics.list_anomaly_group_summaries/3","type":"function"},{"doc":"Gets a list of anomalous metrics for a measure in an anomaly group.","ref":"AWS.LookoutMetrics.html#list_anomaly_group_time_series/3","title":"AWS.LookoutMetrics.list_anomaly_group_time_series/3","type":"function"},{"doc":"Lists the datasets in the current AWS Region.\n\nAmazon Lookout for Metrics API actions are eventually consistent. If you do a\nread operation on a resource immediately after creating or modifying it, use\nretries to allow time for the write operation to complete.","ref":"AWS.LookoutMetrics.html#list_metric_sets/3","title":"AWS.LookoutMetrics.list_metric_sets/3","type":"function"},{"doc":"Gets a list of\n[tags](https://docs.aws.amazon.com/lookoutmetrics/latest/dev/detectors-tags.html)\nfor a detector, dataset, or alert.","ref":"AWS.LookoutMetrics.html#list_tags_for_resource/3","title":"AWS.LookoutMetrics.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.LookoutMetrics.html#metadata/0","title":"AWS.LookoutMetrics.metadata/0","type":"function"},{"doc":"Add feedback for an anomalous metric.","ref":"AWS.LookoutMetrics.html#put_feedback/3","title":"AWS.LookoutMetrics.put_feedback/3","type":"function"},{"doc":"Adds\n[tags](https://docs.aws.amazon.com/lookoutmetrics/latest/dev/detectors-tags.html)\nto a detector, dataset, or alert.","ref":"AWS.LookoutMetrics.html#tag_resource/4","title":"AWS.LookoutMetrics.tag_resource/4","type":"function"},{"doc":"Removes\n[tags](https://docs.aws.amazon.com/lookoutmetrics/latest/dev/detectors-tags.html)\nfrom a detector, dataset, or alert.","ref":"AWS.LookoutMetrics.html#untag_resource/4","title":"AWS.LookoutMetrics.untag_resource/4","type":"function"},{"doc":"Make changes to an existing alert.","ref":"AWS.LookoutMetrics.html#update_alert/3","title":"AWS.LookoutMetrics.update_alert/3","type":"function"},{"doc":"Updates a detector.\n\nAfter activation, you can only change a detector's ingestion delay and\ndescription.","ref":"AWS.LookoutMetrics.html#update_anomaly_detector/3","title":"AWS.LookoutMetrics.update_anomaly_detector/3","type":"function"},{"doc":"Updates a dataset.","ref":"AWS.LookoutMetrics.html#update_metric_set/3","title":"AWS.LookoutMetrics.update_metric_set/3","type":"function"},{"doc":"This is the Amazon Lookout for Vision API Reference.\n\nIt provides descriptions of actions, data types, common parameters, and common\nerrors.\n\nAmazon Lookout for Vision enables you to find visual defects in industrial\nproducts, accurately and at scale. It uses computer vision to identify missing\ncomponents in an industrial product, damage to vehicles or structures,\nirregularities in production lines, and even minuscule defects in silicon wafers\n— or any other physical item where quality is important such as a missing\ncapacitor on printed circuit boards.","ref":"AWS.LookoutVision.html","title":"AWS.LookoutVision","type":"module"},{"doc":"Creates a new dataset in an Amazon Lookout for Vision project.\n\n`CreateDataset` can create a training or a test dataset from a valid dataset\nsource (`DatasetSource`).\n\nIf you want a single dataset project, specify `train` for the value of\n`DatasetType`.\n\nTo have a project with separate training and test datasets, call `CreateDataset`\ntwice. On the first call, specify `train` for the value of `DatasetType`. On the\nsecond call, specify `test` for the value of `DatasetType`.\n\nThis operation requires permissions to perform the `lookoutvision:CreateDataset`\noperation.","ref":"AWS.LookoutVision.html#create_dataset/4","title":"AWS.LookoutVision.create_dataset/4","type":"function"},{"doc":"Creates a new version of a model within an an Amazon Lookout for Vision project.\n\n`CreateModel` is an asynchronous operation in which Amazon Lookout for Vision\ntrains, tests, and evaluates a new version of a model.\n\nTo get the current status, check the `Status` field returned in the response\nfrom `DescribeModel`.\n\nIf the project has a single dataset, Amazon Lookout for Vision internally splits\nthe dataset to create a training and a test dataset. If the project has a\ntraining and a test dataset, Lookout for Vision uses the respective datasets to\ntrain and test the model.\n\nAfter training completes, the evaluation metrics are stored at the location\nspecified in `OutputConfig`.\n\nThis operation requires permissions to perform the `lookoutvision:CreateModel`\noperation. If you want to tag your model, you also require permission to the\n`lookoutvision:TagResource` operation.","ref":"AWS.LookoutVision.html#create_model/4","title":"AWS.LookoutVision.create_model/4","type":"function"},{"doc":"Creates an empty Amazon Lookout for Vision project.\n\nAfter you create the project, add a dataset by calling `CreateDataset`.\n\nThis operation requires permissions to perform the `lookoutvision:CreateProject`\noperation.","ref":"AWS.LookoutVision.html#create_project/3","title":"AWS.LookoutVision.create_project/3","type":"function"},{"doc":"Deletes an existing Amazon Lookout for Vision `dataset`.\n\nIf your the project has a single dataset, you must create a new dataset before\nyou can create a model.\n\nIf you project has a training dataset and a test dataset consider the following.\n\n  * If you delete the test dataset, your project reverts to a single\ndataset project. If you then train the model, Amazon Lookout for Vision\ninternally splits the remaining dataset into a training and test dataset.\n\n  * If you delete the training dataset, you must create a training\ndataset before you can create a model.\n\nThis operation requires permissions to perform the `lookoutvision:DeleteDataset`\noperation.","ref":"AWS.LookoutVision.html#delete_dataset/5","title":"AWS.LookoutVision.delete_dataset/5","type":"function"},{"doc":"Deletes an Amazon Lookout for Vision model.\n\nYou can't delete a running model. To stop a running model, use the `StopModel`\noperation.\n\nIt might take a few seconds to delete a model. To determine if a model has been\ndeleted, call `ListModels` and check if the version of the model\n(`ModelVersion`) is in the `Models` array.\n\nThis operation requires permissions to perform the `lookoutvision:DeleteModel`\noperation.","ref":"AWS.LookoutVision.html#delete_model/5","title":"AWS.LookoutVision.delete_model/5","type":"function"},{"doc":"Deletes an Amazon Lookout for Vision project.\n\nTo delete a project, you must first delete each version of the model associated\nwith the project. To delete a model use the `DeleteModel` operation.\n\nYou also have to delete the dataset(s) associated with the model. For more\ninformation, see `DeleteDataset`. The images referenced by the training and test\ndatasets aren't deleted.\n\nThis operation requires permissions to perform the `lookoutvision:DeleteProject`\noperation.","ref":"AWS.LookoutVision.html#delete_project/4","title":"AWS.LookoutVision.delete_project/4","type":"function"},{"doc":"Describe an Amazon Lookout for Vision dataset.\n\nThis operation requires permissions to perform the\n`lookoutvision:DescribeDataset` operation.","ref":"AWS.LookoutVision.html#describe_dataset/4","title":"AWS.LookoutVision.describe_dataset/4","type":"function"},{"doc":"Describes a version of an Amazon Lookout for Vision model.\n\nThis operation requires permissions to perform the `lookoutvision:DescribeModel`\noperation.","ref":"AWS.LookoutVision.html#describe_model/4","title":"AWS.LookoutVision.describe_model/4","type":"function"},{"doc":"Describes an Amazon Lookout for Vision model packaging job.\n\nThis operation requires permissions to perform the\n`lookoutvision:DescribeModelPackagingJob` operation.\n\nFor more information, see *Using your Amazon Lookout for Vision model on an edge\ndevice* in the Amazon Lookout for Vision Developer Guide.","ref":"AWS.LookoutVision.html#describe_model_packaging_job/4","title":"AWS.LookoutVision.describe_model_packaging_job/4","type":"function"},{"doc":"Describes an Amazon Lookout for Vision project.\n\nThis operation requires permissions to perform the\n`lookoutvision:DescribeProject` operation.","ref":"AWS.LookoutVision.html#describe_project/3","title":"AWS.LookoutVision.describe_project/3","type":"function"},{"doc":"Detects anomalies in an image that you supply.\n\nThe response from `DetectAnomalies` includes a boolean prediction that the image\ncontains one or more anomalies and a confidence value for the prediction. If the\nmodel is an image segmentation model, the response also includes segmentation\ninformation for each type of anomaly found in the image.\n\nBefore calling `DetectAnomalies`, you must first start your model with the\n`StartModel` operation. You are charged for the amount of time, in minutes, that\na model runs and for the number of anomaly detection units that your model uses.\nIf you are not using a model, use the `StopModel` operation to stop your model.\n\nFor more information, see *Detecting anomalies in an image* in the Amazon\nLookout for Vision developer guide.\n\nThis operation requires permissions to perform the\n`lookoutvision:DetectAnomalies` operation.","ref":"AWS.LookoutVision.html#detect_anomalies/5","title":"AWS.LookoutVision.detect_anomalies/5","type":"function"},{"doc":"Lists the JSON Lines within a dataset.\n\nAn Amazon Lookout for Vision JSON Line contains the anomaly information for a\nsingle image, including the image location and the assigned label.\n\nThis operation requires permissions to perform the\n`lookoutvision:ListDatasetEntries` operation.","ref":"AWS.LookoutVision.html#list_dataset_entries/11","title":"AWS.LookoutVision.list_dataset_entries/11","type":"function"},{"doc":"Lists the model packaging jobs created for an Amazon Lookout for Vision project.\n\nThis operation requires permissions to perform the\n`lookoutvision:ListModelPackagingJobs` operation.\n\nFor more information, see *Using your Amazon Lookout for Vision model on an edge\ndevice* in the Amazon Lookout for Vision Developer Guide.","ref":"AWS.LookoutVision.html#list_model_packaging_jobs/5","title":"AWS.LookoutVision.list_model_packaging_jobs/5","type":"function"},{"doc":"Lists the versions of a model in an Amazon Lookout for Vision project.\n\nThe `ListModels` operation is eventually consistent. Recent calls to\n`CreateModel` might take a while to appear in the response from `ListProjects`.\n\nThis operation requires permissions to perform the `lookoutvision:ListModels`\noperation.","ref":"AWS.LookoutVision.html#list_models/5","title":"AWS.LookoutVision.list_models/5","type":"function"},{"doc":"Lists the Amazon Lookout for Vision projects in your AWS account that are in the\nAWS Region in which you call `ListProjects`.\n\nThe `ListProjects` operation is eventually consistent. Recent calls to\n`CreateProject` and `DeleteProject` might take a while to appear in the response\nfrom `ListProjects`.\n\nThis operation requires permissions to perform the `lookoutvision:ListProjects`\noperation.","ref":"AWS.LookoutVision.html#list_projects/4","title":"AWS.LookoutVision.list_projects/4","type":"function"},{"doc":"Returns a list of tags attached to the specified Amazon Lookout for Vision\nmodel.\n\nThis operation requires permissions to perform the\n`lookoutvision:ListTagsForResource` operation.","ref":"AWS.LookoutVision.html#list_tags_for_resource/3","title":"AWS.LookoutVision.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.LookoutVision.html#metadata/0","title":"AWS.LookoutVision.metadata/0","type":"function"},{"doc":"Starts the running of the version of an Amazon Lookout for Vision model.\n\nStarting a model takes a while to complete. To check the current state of the\nmodel, use `DescribeModel`.\n\nA model is ready to use when its status is `HOSTED`.\n\nOnce the model is running, you can detect custom labels in new images by calling\n`DetectAnomalies`.\n\nYou are charged for the amount of time that the model is running. To stop a\nrunning model, call `StopModel`.\n\nThis operation requires permissions to perform the `lookoutvision:StartModel`\noperation.","ref":"AWS.LookoutVision.html#start_model/5","title":"AWS.LookoutVision.start_model/5","type":"function"},{"doc":"Starts an Amazon Lookout for Vision model packaging job.\n\nA model packaging job creates an AWS IoT Greengrass component for a Lookout for\nVision model. You can use the component to deploy your model to an edge device\nmanaged by Greengrass.\n\nUse the `DescribeModelPackagingJob` API to determine the current status of the\njob. The model packaging job is complete if the value of `Status` is\n`SUCCEEDED`.\n\nTo deploy the component to the target device, use the component name and\ncomponent version with the AWS IoT Greengrass\n[CreateDeployment](https://docs.aws.amazon.com/greengrass/v2/APIReference/API_CreateDeployment.html)\nAPI.\n\nThis operation requires the following permissions:\n\n  * `lookoutvision:StartModelPackagingJob`\n\n  * `s3:PutObject`\n\n  * `s3:GetBucketLocation`\n\n  * `kms:GenerateDataKey`\n\n  * `greengrass:CreateComponentVersion`\n\n  * `greengrass:DescribeComponent`\n\n  * (Optional) `greengrass:TagResource`. Only required if you want to\ntag the component.\n\nFor more information, see *Using your Amazon Lookout for Vision model on an edge\ndevice* in the Amazon Lookout for Vision Developer Guide.","ref":"AWS.LookoutVision.html#start_model_packaging_job/4","title":"AWS.LookoutVision.start_model_packaging_job/4","type":"function"},{"doc":"Stops the hosting of a running model.\n\nThe operation might take a while to complete. To check the current status, call\n`DescribeModel`.\n\nAfter the model hosting stops, the `Status` of the model is `TRAINED`.\n\nThis operation requires permissions to perform the `lookoutvision:StopModel`\noperation.","ref":"AWS.LookoutVision.html#stop_model/5","title":"AWS.LookoutVision.stop_model/5","type":"function"},{"doc":"Adds one or more key-value tags to an Amazon Lookout for Vision model.\n\nFor more information, see *Tagging a model* in the *Amazon Lookout for Vision\nDeveloper Guide*.\n\nThis operation requires permissions to perform the `lookoutvision:TagResource`\noperation.","ref":"AWS.LookoutVision.html#tag_resource/4","title":"AWS.LookoutVision.tag_resource/4","type":"function"},{"doc":"Removes one or more tags from an Amazon Lookout for Vision model.\n\nFor more information, see *Tagging a model* in the *Amazon Lookout for Vision\nDeveloper Guide*.\n\nThis operation requires permissions to perform the `lookoutvision:UntagResource`\noperation.","ref":"AWS.LookoutVision.html#untag_resource/4","title":"AWS.LookoutVision.untag_resource/4","type":"function"},{"doc":"Adds or updates one or more JSON Line entries in a dataset.\n\nA JSON Line includes information about an image used for training or testing an\nAmazon Lookout for Vision model.\n\nTo update an existing JSON Line, use the `source-ref` field to identify the JSON\nLine. The JSON line that you supply replaces the existing JSON line. Any\nexisting annotations that are not in the new JSON line are removed from the\ndataset.\n\nFor more information, see *Defining JSON lines for anomaly classification* in\nthe Amazon Lookout for Vision Developer Guide.\n\nThe images you reference in the `source-ref` field of a JSON line, must be in\nthe same S3 bucket as the existing images in the dataset.\n\nUpdating a dataset might take a while to complete. To check the current status,\ncall `DescribeDataset` and check the `Status` field in the response.\n\nThis operation requires permissions to perform the\n`lookoutvision:UpdateDatasetEntries` operation.","ref":"AWS.LookoutVision.html#update_dataset_entries/5","title":"AWS.LookoutVision.update_dataset_entries/5","type":"function"},{"doc":"Amazon Web Services Mainframe Modernization provides tools and resources to help\nyou plan and implement migration and modernization from mainframes to Amazon Web\nServices managed runtime environments.\n\nIt provides tools for analyzing existing mainframe applications, developing or\nupdating mainframe applications using COBOL or PL/I, and implementing an\nautomated pipeline for continuous integration and continuous delivery (CI/CD) of\nthe applications.","ref":"AWS.M2.html","title":"AWS.M2","type":"module"},{"doc":"Cancels the running of a specific batch job execution.","ref":"AWS.M2.html#cancel_batch_job_execution/5","title":"AWS.M2.cancel_batch_job_execution/5","type":"function"},{"doc":"Creates a new application with given parameters.\n\nRequires an existing runtime environment and application definition file.","ref":"AWS.M2.html#create_application/3","title":"AWS.M2.create_application/3","type":"function"},{"doc":"Starts a data set import task for a specific application.","ref":"AWS.M2.html#create_data_set_import_task/4","title":"AWS.M2.create_data_set_import_task/4","type":"function"},{"doc":"Creates and starts a deployment to deploy an application into a runtime\nenvironment.","ref":"AWS.M2.html#create_deployment/4","title":"AWS.M2.create_deployment/4","type":"function"},{"doc":"Creates a runtime environment for a given runtime engine.","ref":"AWS.M2.html#create_environment/3","title":"AWS.M2.create_environment/3","type":"function"},{"doc":"Deletes a specific application.\n\nYou cannot delete a running application.","ref":"AWS.M2.html#delete_application/4","title":"AWS.M2.delete_application/4","type":"function"},{"doc":"Deletes a specific application from the specific runtime environment where it\nwas previously deployed.\n\nYou cannot delete a runtime environment using DeleteEnvironment if any\napplication has ever been deployed to it. This API removes the association of\nthe application with the runtime environment so you can delete the environment\nsmoothly.","ref":"AWS.M2.html#delete_application_from_environment/5","title":"AWS.M2.delete_application_from_environment/5","type":"function"},{"doc":"Deletes a specific runtime environment.\n\nThe environment cannot contain deployed applications. If it does, you must\ndelete those applications before you delete the environment.","ref":"AWS.M2.html#delete_environment/4","title":"AWS.M2.delete_environment/4","type":"function"},{"doc":"Describes the details of a specific application.","ref":"AWS.M2.html#get_application/3","title":"AWS.M2.get_application/3","type":"function"},{"doc":"Returns details about a specific version of a specific application.","ref":"AWS.M2.html#get_application_version/4","title":"AWS.M2.get_application_version/4","type":"function"},{"doc":"Gets the details of a specific batch job execution for a specific application.","ref":"AWS.M2.html#get_batch_job_execution/4","title":"AWS.M2.get_batch_job_execution/4","type":"function"},{"doc":"Gets the details of a specific data set.","ref":"AWS.M2.html#get_data_set_details/4","title":"AWS.M2.get_data_set_details/4","type":"function"},{"doc":"Gets the status of a data set import task initiated with the\n`CreateDataSetImportTask` operation.","ref":"AWS.M2.html#get_data_set_import_task/4","title":"AWS.M2.get_data_set_import_task/4","type":"function"},{"doc":"Gets details of a specific deployment with a given deployment identifier.","ref":"AWS.M2.html#get_deployment/4","title":"AWS.M2.get_deployment/4","type":"function"},{"doc":"Describes a specific runtime environment.","ref":"AWS.M2.html#get_environment/3","title":"AWS.M2.get_environment/3","type":"function"},{"doc":"Gets a single sign-on URL that can be used to connect to AWS Blu Insights.","ref":"AWS.M2.html#get_signed_bluinsights_url/2","title":"AWS.M2.get_signed_bluinsights_url/2","type":"function"},{"doc":"Returns a list of the application versions for a specific application.","ref":"AWS.M2.html#list_application_versions/5","title":"AWS.M2.list_application_versions/5","type":"function"},{"doc":"Lists the applications associated with a specific Amazon Web Services account.\n\nYou can provide the unique identifier of a specific runtime environment in a\nquery parameter to see all applications associated with that environment.","ref":"AWS.M2.html#list_applications/6","title":"AWS.M2.list_applications/6","type":"function"},{"doc":"Lists all the available batch job definitions based on the batch job resources\nuploaded during the application creation.\n\nYou can use the batch job definitions in the list to start a batch job.","ref":"AWS.M2.html#list_batch_job_definitions/6","title":"AWS.M2.list_batch_job_definitions/6","type":"function"},{"doc":"Lists historical, current, and scheduled batch job executions for a specific\napplication.","ref":"AWS.M2.html#list_batch_job_executions/10","title":"AWS.M2.list_batch_job_executions/10","type":"function"},{"doc":"Lists the data set imports for the specified application.","ref":"AWS.M2.html#list_data_set_import_history/5","title":"AWS.M2.list_data_set_import_history/5","type":"function"},{"doc":"Lists the data sets imported for a specific application.\n\nIn Amazon Web Services Mainframe Modernization, data sets are associated with\napplications deployed on runtime environments. This is known as importing data\nsets. Currently, Amazon Web Services Mainframe Modernization can import data\nsets into catalogs using\n[CreateDataSetImportTask](https://docs.aws.amazon.com/m2/latest/APIReference/API_CreateDataSetImportTask.html).","ref":"AWS.M2.html#list_data_sets/7","title":"AWS.M2.list_data_sets/7","type":"function"},{"doc":"Returns a list of all deployments of a specific application.\n\nA deployment is a combination of a specific application and a specific version\nof that application. Each deployment is mapped to a particular application\nversion.","ref":"AWS.M2.html#list_deployments/5","title":"AWS.M2.list_deployments/5","type":"function"},{"doc":"Lists the available engine versions.","ref":"AWS.M2.html#list_engine_versions/5","title":"AWS.M2.list_engine_versions/5","type":"function"},{"doc":"Lists the runtime environments.","ref":"AWS.M2.html#list_environments/6","title":"AWS.M2.list_environments/6","type":"function"},{"doc":"Lists the tags for the specified resource.","ref":"AWS.M2.html#list_tags_for_resource/3","title":"AWS.M2.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.M2.html#metadata/0","title":"AWS.M2.metadata/0","type":"function"},{"doc":"Starts an application that is currently stopped.","ref":"AWS.M2.html#start_application/4","title":"AWS.M2.start_application/4","type":"function"},{"doc":"Starts a batch job and returns the unique identifier of this execution of the\nbatch job.\n\nThe associated application must be running in order to start the batch job.","ref":"AWS.M2.html#start_batch_job/4","title":"AWS.M2.start_batch_job/4","type":"function"},{"doc":"Stops a running application.","ref":"AWS.M2.html#stop_application/4","title":"AWS.M2.stop_application/4","type":"function"},{"doc":"Adds one or more tags to the specified resource.","ref":"AWS.M2.html#tag_resource/4","title":"AWS.M2.tag_resource/4","type":"function"},{"doc":"Removes one or more tags from the specified resource.","ref":"AWS.M2.html#untag_resource/4","title":"AWS.M2.untag_resource/4","type":"function"},{"doc":"Updates an application and creates a new version.","ref":"AWS.M2.html#update_application/4","title":"AWS.M2.update_application/4","type":"function"},{"doc":"Updates the configuration details for a specific runtime environment.","ref":"AWS.M2.html#update_environment/4","title":"AWS.M2.update_environment/4","type":"function"},{"doc":"Amazon Mechanical Turk API Reference","ref":"AWS.MTurk.html","title":"AWS.MTurk","type":"module"},{"doc":"The `AcceptQualificationRequest` operation approves a Worker's request for a\nQualification.\n\nOnly the owner of the Qualification type can grant a Qualification request for\nthat type.\n\nA successful request for the `AcceptQualificationRequest` operation returns with\nno errors and an empty body.","ref":"AWS.MTurk.html#accept_qualification_request/3","title":"AWS.MTurk.accept_qualification_request/3","type":"function"},{"doc":"The `ApproveAssignment` operation approves the results of a completed\nassignment.\n\nApproving an assignment initiates two payments from the Requester's Amazon.com\naccount\n\n  * The Worker who submitted the results is paid the reward specified\nin the HIT.\n\n  * Amazon Mechanical Turk fees are debited.\n\nIf the Requester's account does not have adequate funds for these payments, the\ncall to ApproveAssignment returns an exception, and the approval is not\nprocessed. You can include an optional feedback message with the approval, which\nthe Worker can see in the Status section of the web site.\n\nYou can also call this operation for assignments that were previous rejected and\napprove them by explicitly overriding the previous rejection. This only works on\nrejected assignments that were submitted within the previous 30 days and only if\nthe assignment's related HIT has not been deleted.","ref":"AWS.MTurk.html#approve_assignment/3","title":"AWS.MTurk.approve_assignment/3","type":"function"},{"doc":"The `AssociateQualificationWithWorker` operation gives a Worker a Qualification.\n\n`AssociateQualificationWithWorker` does not require that the Worker submit a\nQualification request. It gives the Qualification directly to the Worker.\n\nYou can only assign a Qualification of a Qualification type that you created\n(using the `CreateQualificationType` operation).\n\nNote: `AssociateQualificationWithWorker` does not affect any pending\nQualification requests for the Qualification by the Worker. If you assign a\nQualification to a Worker, then later grant a Qualification request made by the\nWorker, the granting of the request may modify the Qualification score. To\nresolve a pending Qualification request without affecting the Qualification the\nWorker already has, reject the request with the `RejectQualificationRequest`\noperation.","ref":"AWS.MTurk.html#associate_qualification_with_worker/3","title":"AWS.MTurk.associate_qualification_with_worker/3","type":"function"},{"doc":"The `CreateAdditionalAssignmentsForHIT` operation increases the maximum number\nof assignments of an existing HIT.\n\nTo extend the maximum number of assignments, specify the number of additional\nassignments.\n\n   HITs created with fewer than 10 assignments cannot be extended to\nhave 10 or more assignments. Attempting to add assignments in a way that brings\nthe total number of assignments for a HIT from fewer than 10 assignments to 10\nor more assignments will result in an\n`AWS.MechanicalTurk.InvalidMaximumAssignmentsIncrease` exception.\n\n   HITs that were created before July 22, 2015 cannot be extended.\nAttempting to extend HITs that were created before July 22, 2015 will result in\nan `AWS.MechanicalTurk.HITTooOldForExtension` exception.","ref":"AWS.MTurk.html#create_additional_assignments_for_hit/3","title":"AWS.MTurk.create_additional_assignments_for_hit/3","type":"function"},{"doc":"The `CreateHIT` operation creates a new Human Intelligence Task (HIT).\n\nThe new HIT is made available for Workers to find and accept on the Amazon\nMechanical Turk website.\n\nThis operation allows you to specify a new HIT by passing in values for the\nproperties of the HIT, such as its title, reward amount and number of\nassignments. When you pass these values to `CreateHIT`, a new HIT is created for\nyou, with a new `HITTypeID`. The HITTypeID can be used to create additional HITs\nin the future without needing to specify common parameters such as the title,\ndescription and reward amount each time.\n\nAn alternative way to create HITs is to first generate a HITTypeID using the\n`CreateHITType` operation and then call the `CreateHITWithHITType` operation.\nThis is the recommended best practice for Requesters who are creating large\nnumbers of HITs.\n\nCreateHIT also supports several ways to provide question data: by providing a\nvalue for the `Question` parameter that fully specifies the contents of the HIT,\nor by providing a `HitLayoutId` and associated `HitLayoutParameters`.\n\nIf a HIT is created with 10 or more maximum assignments, there is an additional\nfee. For more information, see [Amazon Mechanical Turk Pricing](https://requester.mturk.com/pricing).","ref":"AWS.MTurk.html#create_hit/3","title":"AWS.MTurk.create_hit/3","type":"function"},{"doc":"The `CreateHITType` operation creates a new HIT type.\n\nThis operation allows you to define a standard set of HIT properties to use when\ncreating HITs. If you register a HIT type with values that match an existing HIT\ntype, the HIT type ID of the existing type will be returned.","ref":"AWS.MTurk.html#create_hit_type/3","title":"AWS.MTurk.create_hit_type/3","type":"function"},{"doc":"The `CreateHITWithHITType` operation creates a new Human Intelligence Task (HIT)\nusing an existing HITTypeID generated by the `CreateHITType` operation.\n\nThis is an alternative way to create HITs from the `CreateHIT` operation. This\nis the recommended best practice for Requesters who are creating large numbers\nof HITs.\n\nCreateHITWithHITType also supports several ways to provide question data: by\nproviding a value for the `Question` parameter that fully specifies the contents\nof the HIT, or by providing a `HitLayoutId` and associated\n`HitLayoutParameters`.\n\nIf a HIT is created with 10 or more maximum assignments, there is an additional\nfee. For more information, see [Amazon Mechanical Turk Pricing](https://requester.mturk.com/pricing).","ref":"AWS.MTurk.html#create_hit_with_hit_type/3","title":"AWS.MTurk.create_hit_with_hit_type/3","type":"function"},{"doc":"The `CreateQualificationType` operation creates a new Qualification type, which\nis represented by a `QualificationType` data structure.","ref":"AWS.MTurk.html#create_qualification_type/3","title":"AWS.MTurk.create_qualification_type/3","type":"function"},{"doc":"The `CreateWorkerBlock` operation allows you to prevent a Worker from working on\nyour HITs.\n\nFor example, you can block a Worker who is producing poor quality work. You can\nblock up to 100,000 Workers.","ref":"AWS.MTurk.html#create_worker_block/3","title":"AWS.MTurk.create_worker_block/3","type":"function"},{"doc":"The `DeleteHIT` operation is used to delete HIT that is no longer needed.\n\nOnly the Requester who created the HIT can delete it.\n\nYou can only dispose of HITs that are in the `Reviewable` state, with all of\ntheir submitted assignments already either approved or rejected. If you call the\nDeleteHIT operation on a HIT that is not in the `Reviewable` state (for example,\nthat has not expired, or still has active assignments), or on a HIT that is\nReviewable but without all of its submitted assignments already approved or\nrejected, the service will return an error.\n\n   HITs are automatically disposed of after 120 days.\n\n   After you dispose of a HIT, you can no longer approve the HIT's\nrejected assignments.\n\n   Disposed HITs are not returned in results for the ListHITs\noperation.\n\n   Disposing HITs can improve the performance of operations such as\nListReviewableHITs and ListHITs.","ref":"AWS.MTurk.html#delete_hit/3","title":"AWS.MTurk.delete_hit/3","type":"function"},{"doc":"The `DeleteQualificationType` deletes a Qualification type and deletes any HIT\ntypes that are associated with the Qualification type.\n\nThis operation does not revoke Qualifications already assigned to Workers\nbecause the Qualifications might be needed for active HITs. If there are any\npending requests for the Qualification type, Amazon Mechanical Turk rejects\nthose requests. After you delete a Qualification type, you can no longer use it\nto create HITs or HIT types.\n\nDeleteQualificationType must wait for all the HITs that use the deleted\nQualification type to be deleted before completing. It may take up to 48 hours\nbefore DeleteQualificationType completes and the unique name of the\nQualification type is available for reuse with CreateQualificationType.","ref":"AWS.MTurk.html#delete_qualification_type/3","title":"AWS.MTurk.delete_qualification_type/3","type":"function"},{"doc":"The `DeleteWorkerBlock` operation allows you to reinstate a blocked Worker to\nwork on your HITs.\n\nThis operation reverses the effects of the CreateWorkerBlock operation. You need\nthe Worker ID to use this operation. If the Worker ID is missing or invalid,\nthis operation fails and returns the message “WorkerId is invalid.” If the\nspecified Worker is not blocked, this operation returns successfully.","ref":"AWS.MTurk.html#delete_worker_block/3","title":"AWS.MTurk.delete_worker_block/3","type":"function"},{"doc":"The `DisassociateQualificationFromWorker` revokes a previously granted\nQualification from a user.\n\nYou can provide a text message explaining why the Qualification was revoked. The\nuser who had the Qualification can see this message.","ref":"AWS.MTurk.html#disassociate_qualification_from_worker/3","title":"AWS.MTurk.disassociate_qualification_from_worker/3","type":"function"},{"doc":"The `GetAccountBalance` operation retrieves the Prepaid HITs balance in your\nAmazon Mechanical Turk account if you are a Prepaid Requester.\n\nAlternatively, this operation will retrieve the remaining available AWS Billing\nusage if you have enabled AWS Billing. Note: If you have enabled AWS Billing and\nstill have a remaining Prepaid HITs balance, this balance can be viewed on the\nMy Account page in the Requester console.","ref":"AWS.MTurk.html#get_account_balance/3","title":"AWS.MTurk.get_account_balance/3","type":"function"},{"doc":"The `GetAssignment` operation retrieves the details of the specified Assignment.","ref":"AWS.MTurk.html#get_assignment/3","title":"AWS.MTurk.get_assignment/3","type":"function"},{"doc":"The `GetFileUploadURL` operation generates and returns a temporary URL.\n\nYou use the temporary URL to retrieve a file uploaded by a Worker as an answer\nto a FileUploadAnswer question for a HIT. The temporary URL is generated the\ninstant the GetFileUploadURL operation is called, and is valid for 60 seconds.\nYou can get a temporary file upload URL any time until the HIT is disposed.\nAfter the HIT is disposed, any uploaded files are deleted, and cannot be\nretrieved. Pending Deprecation on December 12, 2017. The Answer Specification\nstructure will no longer support the `FileUploadAnswer` element to be used for\nthe QuestionForm data structure. Instead, we recommend that Requesters who want\nto create HITs asking Workers to upload files to use Amazon S3.","ref":"AWS.MTurk.html#get_file_upload_url/3","title":"AWS.MTurk.get_file_upload_url/3","type":"function"},{"doc":"The `GetHIT` operation retrieves the details of the specified HIT.","ref":"AWS.MTurk.html#get_hit/3","title":"AWS.MTurk.get_hit/3","type":"function"},{"doc":"The `GetQualificationScore` operation returns the value of a Worker's\nQualification for a given Qualification type.\n\nTo get a Worker's Qualification, you must know the Worker's ID. The Worker's ID\nis included in the assignment data returned by the `ListAssignmentsForHIT`\noperation.\n\nOnly the owner of a Qualification type can query the value of a Worker's\nQualification of that type.","ref":"AWS.MTurk.html#get_qualification_score/3","title":"AWS.MTurk.get_qualification_score/3","type":"function"},{"doc":"The `GetQualificationType`operation retrieves information about a Qualification\ntype using its ID.","ref":"AWS.MTurk.html#get_qualification_type/3","title":"AWS.MTurk.get_qualification_type/3","type":"function"},{"doc":"The `ListAssignmentsForHIT` operation retrieves completed assignments for a HIT.\n\nYou can use this operation to retrieve the results for a HIT.\n\nYou can get assignments for a HIT at any time, even if the HIT is not yet\nReviewable. If a HIT requested multiple assignments, and has received some\nresults but has not yet become Reviewable, you can still retrieve the partial\nresults with this operation.\n\nUse the AssignmentStatus parameter to control which set of assignments for a HIT\nare returned. The ListAssignmentsForHIT operation can return submitted\nassignments awaiting approval, or it can return assignments that have already\nbeen approved or rejected. You can set AssignmentStatus=Approved,Rejected to get\nassignments that have already been approved and rejected together in one result\nset.\n\nOnly the Requester who created the HIT can retrieve the assignments for that\nHIT.\n\nResults are sorted and divided into numbered pages and the operation returns a\nsingle page of results. You can use the parameters of the operation to control\nsorting and pagination.","ref":"AWS.MTurk.html#list_assignments_for_hit/3","title":"AWS.MTurk.list_assignments_for_hit/3","type":"function"},{"doc":"The `ListBonusPayments` operation retrieves the amounts of bonuses you have paid\nto Workers for a given HIT or assignment.","ref":"AWS.MTurk.html#list_bonus_payments/3","title":"AWS.MTurk.list_bonus_payments/3","type":"function"},{"doc":"The `ListHITs` operation returns all of a Requester's HITs.\n\nThe operation returns HITs of any status, except for HITs that have been deleted\nof with the DeleteHIT operation or that have been auto-deleted.","ref":"AWS.MTurk.html#list_hits/3","title":"AWS.MTurk.list_hits/3","type":"function"},{"doc":"The `ListHITsForQualificationType` operation returns the HITs that use the given\nQualification type for a Qualification requirement.\n\nThe operation returns HITs of any status, except for HITs that have been deleted\nwith the `DeleteHIT` operation or that have been auto-deleted.","ref":"AWS.MTurk.html#list_hits_for_qualification_type/3","title":"AWS.MTurk.list_hits_for_qualification_type/3","type":"function"},{"doc":"The `ListQualificationRequests` operation retrieves requests for Qualifications\nof a particular Qualification type.\n\nThe owner of the Qualification type calls this operation to poll for pending\nrequests, and accepts them using the AcceptQualification operation.","ref":"AWS.MTurk.html#list_qualification_requests/3","title":"AWS.MTurk.list_qualification_requests/3","type":"function"},{"doc":"The `ListQualificationTypes` operation returns a list of Qualification types,\nfiltered by an optional search term.","ref":"AWS.MTurk.html#list_qualification_types/3","title":"AWS.MTurk.list_qualification_types/3","type":"function"},{"doc":"The `ListReviewPolicyResultsForHIT` operation retrieves the computed results and\nthe actions taken in the course of executing your Review Policies for a given\nHIT.\n\nFor information about how to specify Review Policies when you call CreateHIT,\nsee Review Policies. The ListReviewPolicyResultsForHIT operation can return\nresults for both Assignment-level and HIT-level review results.","ref":"AWS.MTurk.html#list_review_policy_results_for_hit/3","title":"AWS.MTurk.list_review_policy_results_for_hit/3","type":"function"},{"doc":"The `ListReviewableHITs` operation retrieves the HITs with Status equal to\nReviewable or Status equal to Reviewing that belong to the Requester calling the\noperation.","ref":"AWS.MTurk.html#list_reviewable_hits/3","title":"AWS.MTurk.list_reviewable_hits/3","type":"function"},{"doc":"The `ListWorkersBlocks` operation retrieves a list of Workers who are blocked\nfrom working on your HITs.","ref":"AWS.MTurk.html#list_worker_blocks/3","title":"AWS.MTurk.list_worker_blocks/3","type":"function"},{"doc":"The `ListWorkersWithQualificationType` operation returns all of the Workers that\nhave been associated with a given Qualification type.","ref":"AWS.MTurk.html#list_workers_with_qualification_type/3","title":"AWS.MTurk.list_workers_with_qualification_type/3","type":"function"},{"doc":"","ref":"AWS.MTurk.html#metadata/0","title":"AWS.MTurk.metadata/0","type":"function"},{"doc":"The `NotifyWorkers` operation sends an email to one or more Workers that you\nspecify with the Worker ID.\n\nYou can specify up to 100 Worker IDs to send the same message with a single call\nto the NotifyWorkers operation. The NotifyWorkers operation will send a\nnotification email to a Worker only if you have previously approved or rejected\nwork from the Worker.","ref":"AWS.MTurk.html#notify_workers/3","title":"AWS.MTurk.notify_workers/3","type":"function"},{"doc":"The `RejectAssignment` operation rejects the results of a completed assignment.\n\nYou can include an optional feedback message with the rejection, which the\nWorker can see in the Status section of the web site. When you include a\nfeedback message with the rejection, it helps the Worker understand why the\nassignment was rejected, and can improve the quality of the results the Worker\nsubmits in the future.\n\nOnly the Requester who created the HIT can reject an assignment for the HIT.","ref":"AWS.MTurk.html#reject_assignment/3","title":"AWS.MTurk.reject_assignment/3","type":"function"},{"doc":"The `RejectQualificationRequest` operation rejects a user's request for a\nQualification.\n\nYou can provide a text message explaining why the request was rejected. The\nWorker who made the request can see this message.","ref":"AWS.MTurk.html#reject_qualification_request/3","title":"AWS.MTurk.reject_qualification_request/3","type":"function"},{"doc":"The `SendBonus` operation issues a payment of money from your account to a\nWorker.\n\nThis payment happens separately from the reward you pay to the Worker when you\napprove the Worker's assignment. The SendBonus operation requires the Worker's\nID and the assignment ID as parameters to initiate payment of the bonus. You\nmust include a message that explains the reason for the bonus payment, as the\nWorker may not be expecting the payment. Amazon Mechanical Turk collects a fee\nfor bonus payments, similar to the HIT listing fee. This operation fails if your\naccount does not have enough funds to pay for both the bonus and the fees.","ref":"AWS.MTurk.html#send_bonus/3","title":"AWS.MTurk.send_bonus/3","type":"function"},{"doc":"The `SendTestEventNotification` operation causes Amazon Mechanical Turk to send\na notification message as if a HIT event occurred, according to the provided\nnotification specification.\n\nThis allows you to test notifications without setting up notifications for a\nreal HIT type and trying to trigger them using the website. When you call this\noperation, the service attempts to send the test notification immediately.","ref":"AWS.MTurk.html#send_test_event_notification/3","title":"AWS.MTurk.send_test_event_notification/3","type":"function"},{"doc":"The `UpdateExpirationForHIT` operation allows you update the expiration time of\na HIT.\n\nIf you update it to a time in the past, the HIT will be immediately expired.","ref":"AWS.MTurk.html#update_expiration_for_hit/3","title":"AWS.MTurk.update_expiration_for_hit/3","type":"function"},{"doc":"The `UpdateHITReviewStatus` operation updates the status of a HIT.\n\nIf the status is Reviewable, this operation can update the status to Reviewing,\nor it can revert a Reviewing HIT back to the Reviewable status.","ref":"AWS.MTurk.html#update_hit_review_status/3","title":"AWS.MTurk.update_hit_review_status/3","type":"function"},{"doc":"The `UpdateHITTypeOfHIT` operation allows you to change the HITType properties\nof a HIT.\n\nThis operation disassociates the HIT from its old HITType properties and\nassociates it with the new HITType properties. The HIT takes on the properties\nof the new HITType in place of the old ones.","ref":"AWS.MTurk.html#update_hit_type_of_hit/3","title":"AWS.MTurk.update_hit_type_of_hit/3","type":"function"},{"doc":"The `UpdateNotificationSettings` operation creates, updates, disables or\nre-enables notifications for a HIT type.\n\nIf you call the UpdateNotificationSettings operation for a HIT type that already\nhas a notification specification, the operation replaces the old specification\nwith a new one. You can call the UpdateNotificationSettings operation to enable\nor disable notifications for the HIT type, without having to modify the\nnotification specification itself by providing updates to the Active status\nwithout specifying a new notification specification. To change the Active status\nof a HIT type's notifications, the HIT type must already have a notification\nspecification, or one must be provided in the same call to\n`UpdateNotificationSettings`.","ref":"AWS.MTurk.html#update_notification_settings/3","title":"AWS.MTurk.update_notification_settings/3","type":"function"},{"doc":"The `UpdateQualificationType` operation modifies the attributes of an existing\nQualification type, which is represented by a QualificationType data structure.\n\nOnly the owner of a Qualification type can modify its attributes.\n\nMost attributes of a Qualification type can be changed after the type has been\ncreated. However, the Name and Keywords fields cannot be modified. The\nRetryDelayInSeconds parameter can be modified or added to change the delay or to\nenable retries, but RetryDelayInSeconds cannot be used to disable retries.\n\nYou can use this operation to update the test for a Qualification type. The test\nis updated based on the values specified for the Test, TestDurationInSeconds and\nAnswerKey parameters. All three parameters specify the updated test. If you are\nupdating the test for a type, you must specify the Test and\nTestDurationInSeconds parameters. The AnswerKey parameter is optional; omitting\nit specifies that the updated test does not have an answer key.\n\nIf you omit the Test parameter, the test for the Qualification type is\nunchanged. There is no way to remove a test from a Qualification type that has\none. If the type already has a test, you cannot update it to be AutoGranted. If\nthe Qualification type does not have a test and one is provided by an update,\nthe type will henceforth have a test.\n\nIf you want to update the test duration or answer key for an existing test\nwithout changing the questions, you must specify a Test parameter with the\noriginal questions, along with the updated values.\n\nIf you provide an updated Test but no AnswerKey, the new test will not have an\nanswer key. Requests for such Qualifications must be granted manually.\n\nYou can also update the AutoGranted and AutoGrantedValue attributes of the\nQualification type.","ref":"AWS.MTurk.html#update_qualification_type/3","title":"AWS.MTurk.update_qualification_type/3","type":"function"},{"doc":"Amazon Managed Workflows for Apache Airflow\n\nThis section contains the Amazon Managed Workflows for Apache Airflow (MWAA) API\nreference documentation.\n\nFor more information, see [What is Amazon MWAA?](https://docs.aws.amazon.com/mwaa/latest/userguide/what-is-mwaa.html).","ref":"AWS.MWAA.html","title":"AWS.MWAA","type":"module"},{"doc":"* `api.airflow.{region}.amazonaws.com` - This endpoint is used for\nenvironment management.\n\n    *\n[CreateEnvironment](https://docs.aws.amazon.com/mwaa/latest/API/API_CreateEnvironment.html)       *\n[DeleteEnvironment](https://docs.aws.amazon.com/mwaa/latest/API/API_DeleteEnvironment.html)\n\n    *\n[GetEnvironment](https://docs.aws.amazon.com/mwaa/latest/API/API_GetEnvironment.html)       *\n[ListEnvironments](https://docs.aws.amazon.com/mwaa/latest/API/API_ListEnvironments.html)\n\n    *\n[ListTagsForResource](https://docs.aws.amazon.com/mwaa/latest/API/API_ListTagsForResource.html)       *\n[TagResource](https://docs.aws.amazon.com/mwaa/latest/API/API_TagResource.html)\n\n    *\n[UntagResource](https://docs.aws.amazon.com/mwaa/latest/API/API_UntagResource.html)       *\n[UpdateEnvironment](https://docs.aws.amazon.com/mwaa/latest/API/API_UpdateEnvironment.html)\n\n  * `env.airflow.{region}.amazonaws.com` - This endpoint is used to\noperate the Airflow environment.\n\n    *\n[CreateCliToken](https://docs.aws.amazon.com/mwaa/latest/API/API_CreateCliToken.html )\n\n    *\n[CreateWebLoginToken](https://docs.aws.amazon.com/mwaa/latest/API/API_CreateWebLoginToken.html)","ref":"AWS.MWAA.html#module-endpoints","title":"Endpoints - AWS.MWAA","type":"module"},{"doc":"For a list of supported regions, see [Amazon MWAA endpoints and quotas](https://docs.aws.amazon.com/general/latest/gr/mwaa.html) in the *Amazon\nWeb Services General Reference*.","ref":"AWS.MWAA.html#module-regions","title":"Regions - AWS.MWAA","type":"module"},{"doc":"Creates a CLI token for the Airflow CLI.\n\nTo learn more, see [Creating an Apache Airflow CLI token](https://docs.aws.amazon.com/mwaa/latest/userguide/call-mwaa-apis-cli.html).","ref":"AWS.MWAA.html#create_cli_token/4","title":"AWS.MWAA.create_cli_token/4","type":"function"},{"doc":"Creates an Amazon Managed Workflows for Apache Airflow (MWAA) environment.","ref":"AWS.MWAA.html#create_environment/4","title":"AWS.MWAA.create_environment/4","type":"function"},{"doc":"Creates a web login token for the Airflow Web UI.\n\nTo learn more, see [Creating an Apache Airflow web login token](https://docs.aws.amazon.com/mwaa/latest/userguide/call-mwaa-apis-web.html).","ref":"AWS.MWAA.html#create_web_login_token/4","title":"AWS.MWAA.create_web_login_token/4","type":"function"},{"doc":"Deletes an Amazon Managed Workflows for Apache Airflow (MWAA) environment.","ref":"AWS.MWAA.html#delete_environment/4","title":"AWS.MWAA.delete_environment/4","type":"function"},{"doc":"Describes an Amazon Managed Workflows for Apache Airflow (MWAA) environment.","ref":"AWS.MWAA.html#get_environment/3","title":"AWS.MWAA.get_environment/3","type":"function"},{"doc":"Lists the Amazon Managed Workflows for Apache Airflow (MWAA) environments.","ref":"AWS.MWAA.html#list_environments/4","title":"AWS.MWAA.list_environments/4","type":"function"},{"doc":"Lists the key-value tag pairs associated to the Amazon Managed Workflows for\nApache Airflow (MWAA) environment.\n\nFor example, `\"Environment\": \"Staging\"`.","ref":"AWS.MWAA.html#list_tags_for_resource/3","title":"AWS.MWAA.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.MWAA.html#metadata/0","title":"AWS.MWAA.metadata/0","type":"function"},{"doc":"**Internal only**.\n\nPublishes environment health metrics to Amazon CloudWatch.","ref":"AWS.MWAA.html#publish_metrics/4","title":"AWS.MWAA.publish_metrics/4","type":"function"},{"doc":"Associates key-value tag pairs to your Amazon Managed Workflows for Apache\nAirflow (MWAA) environment.","ref":"AWS.MWAA.html#tag_resource/4","title":"AWS.MWAA.tag_resource/4","type":"function"},{"doc":"Removes key-value tag pairs associated to your Amazon Managed Workflows for\nApache Airflow (MWAA) environment.\n\nFor example, `\"Environment\": \"Staging\"`.","ref":"AWS.MWAA.html#untag_resource/4","title":"AWS.MWAA.untag_resource/4","type":"function"},{"doc":"Updates an Amazon Managed Workflows for Apache Airflow (MWAA) environment.","ref":"AWS.MWAA.html#update_environment/4","title":"AWS.MWAA.update_environment/4","type":"function"},{"doc":"Definition of the public APIs exposed by Amazon Machine Learning","ref":"AWS.MachineLearning.html","title":"AWS.MachineLearning","type":"module"},{"doc":"Adds one or more tags to an object, up to a limit of 10.\n\nEach tag consists of a key and an optional value. If you add a tag using a key\nthat is already associated with the ML object, `AddTags` updates the tag's\nvalue.","ref":"AWS.MachineLearning.html#add_tags/3","title":"AWS.MachineLearning.add_tags/3","type":"function"},{"doc":"Generates predictions for a group of observations.\n\nThe observations to process exist in one or more data files referenced by a\n`DataSource`. This operation creates a new `BatchPrediction`, and uses an\n`MLModel` and the data files referenced by the `DataSource` as information\nsources.\n\n`CreateBatchPrediction` is an asynchronous operation. In response to\n`CreateBatchPrediction`, Amazon Machine Learning (Amazon ML) immediately returns\nand sets the `BatchPrediction` status to `PENDING`. After the `BatchPrediction`\ncompletes, Amazon ML sets the status to `COMPLETED`.\n\nYou can poll for status updates by using the `GetBatchPrediction` operation and\nchecking the `Status` parameter of the result. After the `COMPLETED` status\nappears, the results are available in the location specified by the `OutputUri`\nparameter.","ref":"AWS.MachineLearning.html#create_batch_prediction/3","title":"AWS.MachineLearning.create_batch_prediction/3","type":"function"},{"doc":"Creates a `DataSource` object from an [ Amazon Relational Database Service](http://aws.amazon.com/rds/) (Amazon RDS).\n\nA `DataSource` references data that can be used to perform `CreateMLModel`,\n`CreateEvaluation`, or `CreateBatchPrediction` operations.\n\n`CreateDataSourceFromRDS` is an asynchronous operation. In response to\n`CreateDataSourceFromRDS`, Amazon Machine Learning (Amazon ML) immediately\nreturns and sets the `DataSource` status to `PENDING`. After the `DataSource` is\ncreated and ready for use, Amazon ML sets the `Status` parameter to `COMPLETED`.\n`DataSource` in the `COMPLETED` or `PENDING` state can be used only to perform\n`>CreateMLModel`>, `CreateEvaluation`, or `CreateBatchPrediction` operations.\n\nIf Amazon ML cannot accept the input source, it sets the `Status` parameter to\n`FAILED` and includes an error message in the `Message` attribute of the\n`GetDataSource` operation response.","ref":"AWS.MachineLearning.html#create_data_source_from_rds/3","title":"AWS.MachineLearning.create_data_source_from_rds/3","type":"function"},{"doc":"Creates a `DataSource` from a database hosted on an Amazon Redshift cluster.\n\nA `DataSource` references data that can be used to perform either\n`CreateMLModel`, `CreateEvaluation`, or `CreateBatchPrediction` operations.\n\n`CreateDataSourceFromRedshift` is an asynchronous operation. In response to\n`CreateDataSourceFromRedshift`, Amazon Machine Learning (Amazon ML) immediately\nreturns and sets the `DataSource` status to `PENDING`. After the `DataSource` is\ncreated and ready for use, Amazon ML sets the `Status` parameter to `COMPLETED`.\n`DataSource` in `COMPLETED` or `PENDING` states can be used to perform only\n`CreateMLModel`, `CreateEvaluation`, or `CreateBatchPrediction` operations.\n\nIf Amazon ML can't accept the input source, it sets the `Status` parameter to\n`FAILED` and includes an error message in the `Message` attribute of the\n`GetDataSource` operation response.\n\nThe observations should be contained in the database hosted on an Amazon\nRedshift cluster and should be specified by a `SelectSqlQuery` query. Amazon ML\nexecutes an `Unload` command in Amazon Redshift to transfer the result set of\nthe `SelectSqlQuery` query to `S3StagingLocation`.\n\nAfter the `DataSource` has been created, it's ready for use in evaluations and\nbatch predictions. If you plan to use the `DataSource` to train an `MLModel`,\nthe `DataSource` also requires a recipe. A recipe describes how each input\nvariable will be used in training an `MLModel`. Will the variable be included or\nexcluded from training? Will the variable be manipulated; for example, will it\nbe combined with another variable or will it be split apart into word\ncombinations? The recipe provides answers to these questions.\n\nYou can't change an existing datasource, but you can copy and modify the\nsettings from an existing Amazon Redshift datasource to create a new datasource.\nTo do so, call `GetDataSource` for an existing datasource and copy the values to\na `CreateDataSource` call. Change the settings that you want to change and make\nsure that all required fields have the appropriate values.","ref":"AWS.MachineLearning.html#create_data_source_from_redshift/3","title":"AWS.MachineLearning.create_data_source_from_redshift/3","type":"function"},{"doc":"Creates a `DataSource` object.\n\nA `DataSource` references data that can be used to perform `CreateMLModel`,\n`CreateEvaluation`, or `CreateBatchPrediction` operations.\n\n`CreateDataSourceFromS3` is an asynchronous operation. In response to\n`CreateDataSourceFromS3`, Amazon Machine Learning (Amazon ML) immediately\nreturns and sets the `DataSource` status to `PENDING`. After the `DataSource`\nhas been created and is ready for use, Amazon ML sets the `Status` parameter to\n`COMPLETED`. `DataSource` in the `COMPLETED` or `PENDING` state can be used to\nperform only `CreateMLModel`, `CreateEvaluation` or `CreateBatchPrediction`\noperations.\n\nIf Amazon ML can't accept the input source, it sets the `Status` parameter to\n`FAILED` and includes an error message in the `Message` attribute of the\n`GetDataSource` operation response.\n\nThe observation data used in a `DataSource` should be ready to use; that is, it\nshould have a consistent structure, and missing data values should be kept to a\nminimum. The observation data must reside in one or more .csv files in an Amazon\nSimple Storage Service (Amazon S3) location, along with a schema that describes\nthe data items by name and type. The same schema must be used for all of the\ndata files referenced by the `DataSource`.\n\nAfter the `DataSource` has been created, it's ready to use in evaluations and\nbatch predictions. If you plan to use the `DataSource` to train an `MLModel`,\nthe `DataSource` also needs a recipe. A recipe describes how each input variable\nwill be used in training an `MLModel`. Will the variable be included or excluded\nfrom training? Will the variable be manipulated; for example, will it be\ncombined with another variable or will it be split apart into word combinations?\nThe recipe provides answers to these questions.","ref":"AWS.MachineLearning.html#create_data_source_from_s3/3","title":"AWS.MachineLearning.create_data_source_from_s3/3","type":"function"},{"doc":"Creates a new `Evaluation` of an `MLModel`.\n\nAn `MLModel` is evaluated on a set of observations associated to a `DataSource`.\nLike a `DataSource` for an `MLModel`, the `DataSource` for an `Evaluation`\ncontains values for the `Target Variable`. The `Evaluation` compares the\npredicted result for each observation to the actual outcome and provides a\nsummary so that you know how effective the `MLModel` functions on the test data.\nEvaluation generates a relevant performance metric, such as BinaryAUC,\nRegressionRMSE or MulticlassAvgFScore based on the corresponding `MLModelType`:\n`BINARY`, `REGRESSION` or `MULTICLASS`.\n\n`CreateEvaluation` is an asynchronous operation. In response to\n`CreateEvaluation`, Amazon Machine Learning (Amazon ML) immediately returns and\nsets the evaluation status to `PENDING`. After the `Evaluation` is created and\nready for use, Amazon ML sets the status to `COMPLETED`.\n\nYou can use the `GetEvaluation` operation to check progress of the evaluation\nduring the creation operation.","ref":"AWS.MachineLearning.html#create_evaluation/3","title":"AWS.MachineLearning.create_evaluation/3","type":"function"},{"doc":"Creates a new `MLModel` using the `DataSource` and the recipe as information\nsources.\n\nAn `MLModel` is nearly immutable. Users can update only the `MLModelName` and\nthe `ScoreThreshold` in an `MLModel` without creating a new `MLModel`.\n\n`CreateMLModel` is an asynchronous operation. In response to `CreateMLModel`,\nAmazon Machine Learning (Amazon ML) immediately returns and sets the `MLModel`\nstatus to `PENDING`. After the `MLModel` has been created and ready is for use,\nAmazon ML sets the status to `COMPLETED`.\n\nYou can use the `GetMLModel` operation to check the progress of the `MLModel`\nduring the creation operation.\n\n`CreateMLModel` requires a `DataSource` with computed statistics, which can be\ncreated by setting `ComputeStatistics` to `true` in `CreateDataSourceFromRDS`,\n`CreateDataSourceFromS3`, or `CreateDataSourceFromRedshift` operations.","ref":"AWS.MachineLearning.html#create_ml_model/3","title":"AWS.MachineLearning.create_ml_model/3","type":"function"},{"doc":"Creates a real-time endpoint for the `MLModel`.\n\nThe endpoint contains the URI of the `MLModel`; that is, the location to send\nreal-time prediction requests for the specified `MLModel`.","ref":"AWS.MachineLearning.html#create_realtime_endpoint/3","title":"AWS.MachineLearning.create_realtime_endpoint/3","type":"function"},{"doc":"Assigns the DELETED status to a `BatchPrediction`, rendering it unusable.\n\nAfter using the `DeleteBatchPrediction` operation, you can use the\n`GetBatchPrediction` operation to verify that the status of the\n`BatchPrediction` changed to DELETED.\n\n**Caution:** The result of the `DeleteBatchPrediction` operation is\nirreversible.","ref":"AWS.MachineLearning.html#delete_batch_prediction/3","title":"AWS.MachineLearning.delete_batch_prediction/3","type":"function"},{"doc":"Assigns the DELETED status to a `DataSource`, rendering it unusable.\n\nAfter using the `DeleteDataSource` operation, you can use the `GetDataSource`\noperation to verify that the status of the `DataSource` changed to DELETED.\n\n**Caution:** The results of the `DeleteDataSource` operation are irreversible.","ref":"AWS.MachineLearning.html#delete_data_source/3","title":"AWS.MachineLearning.delete_data_source/3","type":"function"},{"doc":"Assigns the `DELETED` status to an `Evaluation`, rendering it unusable.\n\nAfter invoking the `DeleteEvaluation` operation, you can use the `GetEvaluation`\noperation to verify that the status of the `Evaluation` changed to `DELETED`.\n\n**Caution:** The results of the `DeleteEvaluation` operation are irreversible.","ref":"AWS.MachineLearning.html#delete_evaluation/3","title":"AWS.MachineLearning.delete_evaluation/3","type":"function"},{"doc":"Assigns the `DELETED` status to an `MLModel`, rendering it unusable.\n\nAfter using the `DeleteMLModel` operation, you can use the `GetMLModel`\noperation to verify that the status of the `MLModel` changed to DELETED.\n\n**Caution:** The result of the `DeleteMLModel` operation is irreversible.","ref":"AWS.MachineLearning.html#delete_ml_model/3","title":"AWS.MachineLearning.delete_ml_model/3","type":"function"},{"doc":"Deletes a real time endpoint of an `MLModel`.","ref":"AWS.MachineLearning.html#delete_realtime_endpoint/3","title":"AWS.MachineLearning.delete_realtime_endpoint/3","type":"function"},{"doc":"Deletes the specified tags associated with an ML object.\n\nAfter this operation is complete, you can't recover deleted tags.\n\nIf you specify a tag that doesn't exist, Amazon ML ignores it.","ref":"AWS.MachineLearning.html#delete_tags/3","title":"AWS.MachineLearning.delete_tags/3","type":"function"},{"doc":"Returns a list of `BatchPrediction` operations that match the search criteria in\nthe request.","ref":"AWS.MachineLearning.html#describe_batch_predictions/3","title":"AWS.MachineLearning.describe_batch_predictions/3","type":"function"},{"doc":"Returns a list of `DataSource` that match the search criteria in the request.","ref":"AWS.MachineLearning.html#describe_data_sources/3","title":"AWS.MachineLearning.describe_data_sources/3","type":"function"},{"doc":"Returns a list of `DescribeEvaluations` that match the search criteria in the\nrequest.","ref":"AWS.MachineLearning.html#describe_evaluations/3","title":"AWS.MachineLearning.describe_evaluations/3","type":"function"},{"doc":"Returns a list of `MLModel` that match the search criteria in the request.","ref":"AWS.MachineLearning.html#describe_ml_models/3","title":"AWS.MachineLearning.describe_ml_models/3","type":"function"},{"doc":"Describes one or more of the tags for your Amazon ML object.","ref":"AWS.MachineLearning.html#describe_tags/3","title":"AWS.MachineLearning.describe_tags/3","type":"function"},{"doc":"Returns a `BatchPrediction` that includes detailed metadata, status, and data\nfile information for a `Batch Prediction` request.","ref":"AWS.MachineLearning.html#get_batch_prediction/3","title":"AWS.MachineLearning.get_batch_prediction/3","type":"function"},{"doc":"Returns a `DataSource` that includes metadata and data file information, as well\nas the current status of the `DataSource`.\n\n`GetDataSource` provides results in normal or verbose format. The verbose format\nadds the schema description and the list of files pointed to by the DataSource\nto the normal format.","ref":"AWS.MachineLearning.html#get_data_source/3","title":"AWS.MachineLearning.get_data_source/3","type":"function"},{"doc":"Returns an `Evaluation` that includes metadata as well as the current status of\nthe `Evaluation`.","ref":"AWS.MachineLearning.html#get_evaluation/3","title":"AWS.MachineLearning.get_evaluation/3","type":"function"},{"doc":"Returns an `MLModel` that includes detailed metadata, data source information,\nand the current status of the `MLModel`.\n\n`GetMLModel` provides results in normal or verbose format.","ref":"AWS.MachineLearning.html#get_ml_model/3","title":"AWS.MachineLearning.get_ml_model/3","type":"function"},{"doc":"","ref":"AWS.MachineLearning.html#metadata/0","title":"AWS.MachineLearning.metadata/0","type":"function"},{"doc":"Generates a prediction for the observation using the specified `ML Model`.\n\n**Note:** Not all response parameters will be populated. Whether a response\nparameter is populated depends on the type of model requested.","ref":"AWS.MachineLearning.html#predict/3","title":"AWS.MachineLearning.predict/3","type":"function"},{"doc":"Updates the `BatchPredictionName` of a `BatchPrediction`.\n\nYou can use the `GetBatchPrediction` operation to view the contents of the\nupdated data element.","ref":"AWS.MachineLearning.html#update_batch_prediction/3","title":"AWS.MachineLearning.update_batch_prediction/3","type":"function"},{"doc":"Updates the `DataSourceName` of a `DataSource`.\n\nYou can use the `GetDataSource` operation to view the contents of the updated\ndata element.","ref":"AWS.MachineLearning.html#update_data_source/3","title":"AWS.MachineLearning.update_data_source/3","type":"function"},{"doc":"Updates the `EvaluationName` of an `Evaluation`.\n\nYou can use the `GetEvaluation` operation to view the contents of the updated\ndata element.","ref":"AWS.MachineLearning.html#update_evaluation/3","title":"AWS.MachineLearning.update_evaluation/3","type":"function"},{"doc":"Updates the `MLModelName` and the `ScoreThreshold` of an `MLModel`.\n\nYou can use the `GetMLModel` operation to view the contents of the updated data\nelement.","ref":"AWS.MachineLearning.html#update_ml_model/3","title":"AWS.MachineLearning.update_ml_model/3","type":"function"},{"doc":"Amazon Macie is a fully managed data security and data privacy service that uses\nmachine learning and pattern matching to help you discover and protect your\nsensitive data in AWS.\n\nMacie automates the discovery of sensitive data, such as PII and intellectual\nproperty, to provide you with insight into the data that your organization\nstores in AWS. Macie also provides an inventory of your Amazon S3 buckets, which\nit continually monitors for you. If Macie detects sensitive data or potential\ndata access issues, it generates detailed findings for you to review and act\nupon as necessary.","ref":"AWS.Macie2.html","title":"AWS.Macie2","type":"module"},{"doc":"Accepts an Amazon Macie membership invitation that was received from a specific\naccount.","ref":"AWS.Macie2.html#accept_invitation/3","title":"AWS.Macie2.accept_invitation/3","type":"function"},{"doc":"Retrieves information about one or more custom data identifiers.","ref":"AWS.Macie2.html#batch_get_custom_data_identifiers/3","title":"AWS.Macie2.batch_get_custom_data_identifiers/3","type":"function"},{"doc":"Creates and defines the settings for an allow list.","ref":"AWS.Macie2.html#create_allow_list/3","title":"AWS.Macie2.create_allow_list/3","type":"function"},{"doc":"Creates and defines the settings for a classification job.","ref":"AWS.Macie2.html#create_classification_job/3","title":"AWS.Macie2.create_classification_job/3","type":"function"},{"doc":"Creates and defines the criteria and other settings for a custom data\nidentifier.","ref":"AWS.Macie2.html#create_custom_data_identifier/3","title":"AWS.Macie2.create_custom_data_identifier/3","type":"function"},{"doc":"Creates and defines the criteria and other settings for a findings filter.","ref":"AWS.Macie2.html#create_findings_filter/3","title":"AWS.Macie2.create_findings_filter/3","type":"function"},{"doc":"Sends an Amazon Macie membership invitation to one or more accounts.","ref":"AWS.Macie2.html#create_invitations/3","title":"AWS.Macie2.create_invitations/3","type":"function"},{"doc":"Associates an account with an Amazon Macie administrator account.","ref":"AWS.Macie2.html#create_member/3","title":"AWS.Macie2.create_member/3","type":"function"},{"doc":"Creates sample findings.","ref":"AWS.Macie2.html#create_sample_findings/3","title":"AWS.Macie2.create_sample_findings/3","type":"function"},{"doc":"Declines Amazon Macie membership invitations that were received from specific\naccounts.","ref":"AWS.Macie2.html#decline_invitations/3","title":"AWS.Macie2.decline_invitations/3","type":"function"},{"doc":"Deletes an allow list.","ref":"AWS.Macie2.html#delete_allow_list/4","title":"AWS.Macie2.delete_allow_list/4","type":"function"},{"doc":"Soft deletes a custom data identifier.","ref":"AWS.Macie2.html#delete_custom_data_identifier/4","title":"AWS.Macie2.delete_custom_data_identifier/4","type":"function"},{"doc":"Deletes a findings filter.","ref":"AWS.Macie2.html#delete_findings_filter/4","title":"AWS.Macie2.delete_findings_filter/4","type":"function"},{"doc":"Deletes Amazon Macie membership invitations that were received from specific\naccounts.","ref":"AWS.Macie2.html#delete_invitations/3","title":"AWS.Macie2.delete_invitations/3","type":"function"},{"doc":"Deletes the association between an Amazon Macie administrator account and an\naccount.","ref":"AWS.Macie2.html#delete_member/4","title":"AWS.Macie2.delete_member/4","type":"function"},{"doc":"Retrieves (queries) statistical data and other information about one or more S3\nbuckets that Amazon Macie monitors and analyzes for an account.","ref":"AWS.Macie2.html#describe_buckets/3","title":"AWS.Macie2.describe_buckets/3","type":"function"},{"doc":"Retrieves the status and settings for a classification job.","ref":"AWS.Macie2.html#describe_classification_job/3","title":"AWS.Macie2.describe_classification_job/3","type":"function"},{"doc":"Retrieves the Amazon Macie configuration settings for an organization in\nOrganizations.","ref":"AWS.Macie2.html#describe_organization_configuration/2","title":"AWS.Macie2.describe_organization_configuration/2","type":"function"},{"doc":"Disables Amazon Macie and deletes all settings and resources for a Macie\naccount.","ref":"AWS.Macie2.html#disable_macie/3","title":"AWS.Macie2.disable_macie/3","type":"function"},{"doc":"Disables an account as the delegated Amazon Macie administrator account for an\norganization in Organizations.","ref":"AWS.Macie2.html#disable_organization_admin_account/3","title":"AWS.Macie2.disable_organization_admin_account/3","type":"function"},{"doc":"Disassociates a member account from its Amazon Macie administrator account.","ref":"AWS.Macie2.html#disassociate_from_administrator_account/3","title":"AWS.Macie2.disassociate_from_administrator_account/3","type":"function"},{"doc":"(Deprecated) Disassociates a member account from its Amazon Macie administrator\naccount.\n\nThis operation has been replaced by the DisassociateFromAdministratorAccount\noperation.","ref":"AWS.Macie2.html#disassociate_from_master_account/3","title":"AWS.Macie2.disassociate_from_master_account/3","type":"function"},{"doc":"Disassociates an Amazon Macie administrator account from a member account.","ref":"AWS.Macie2.html#disassociate_member/4","title":"AWS.Macie2.disassociate_member/4","type":"function"},{"doc":"Enables Amazon Macie and specifies the configuration settings for a Macie\naccount.","ref":"AWS.Macie2.html#enable_macie/3","title":"AWS.Macie2.enable_macie/3","type":"function"},{"doc":"Designates an account as the delegated Amazon Macie administrator account for an\norganization in Organizations.","ref":"AWS.Macie2.html#enable_organization_admin_account/3","title":"AWS.Macie2.enable_organization_admin_account/3","type":"function"},{"doc":"Retrieves information about the Amazon Macie administrator account for an\naccount.","ref":"AWS.Macie2.html#get_administrator_account/2","title":"AWS.Macie2.get_administrator_account/2","type":"function"},{"doc":"Retrieves the settings and status of an allow list.","ref":"AWS.Macie2.html#get_allow_list/3","title":"AWS.Macie2.get_allow_list/3","type":"function"},{"doc":"Retrieves the configuration settings and status of automated sensitive data\ndiscovery for an account.","ref":"AWS.Macie2.html#get_automated_discovery_configuration/2","title":"AWS.Macie2.get_automated_discovery_configuration/2","type":"function"},{"doc":"Retrieves (queries) aggregated statistical data about all the S3 buckets that\nAmazon Macie monitors and analyzes for an account.","ref":"AWS.Macie2.html#get_bucket_statistics/3","title":"AWS.Macie2.get_bucket_statistics/3","type":"function"},{"doc":"Retrieves the configuration settings for storing data classification results.","ref":"AWS.Macie2.html#get_classification_export_configuration/2","title":"AWS.Macie2.get_classification_export_configuration/2","type":"function"},{"doc":"Retrieves the classification scope settings for an account.","ref":"AWS.Macie2.html#get_classification_scope/3","title":"AWS.Macie2.get_classification_scope/3","type":"function"},{"doc":"Retrieves the criteria and other settings for a custom data identifier.","ref":"AWS.Macie2.html#get_custom_data_identifier/3","title":"AWS.Macie2.get_custom_data_identifier/3","type":"function"},{"doc":"Retrieves (queries) aggregated statistical data about findings.","ref":"AWS.Macie2.html#get_finding_statistics/3","title":"AWS.Macie2.get_finding_statistics/3","type":"function"},{"doc":"Retrieves the details of one or more findings.","ref":"AWS.Macie2.html#get_findings/3","title":"AWS.Macie2.get_findings/3","type":"function"},{"doc":"Retrieves the criteria and other settings for a findings filter.","ref":"AWS.Macie2.html#get_findings_filter/3","title":"AWS.Macie2.get_findings_filter/3","type":"function"},{"doc":"Retrieves the configuration settings for publishing findings to Security Hub.","ref":"AWS.Macie2.html#get_findings_publication_configuration/2","title":"AWS.Macie2.get_findings_publication_configuration/2","type":"function"},{"doc":"Retrieves the count of Amazon Macie membership invitations that were received by\nan account.","ref":"AWS.Macie2.html#get_invitations_count/2","title":"AWS.Macie2.get_invitations_count/2","type":"function"},{"doc":"Retrieves the status and configuration settings for an Amazon Macie account.","ref":"AWS.Macie2.html#get_macie_session/2","title":"AWS.Macie2.get_macie_session/2","type":"function"},{"doc":"(Deprecated) Retrieves information about the Amazon Macie administrator account\nfor an account.\n\nThis operation has been replaced by the GetAdministratorAccount operation.","ref":"AWS.Macie2.html#get_master_account/2","title":"AWS.Macie2.get_master_account/2","type":"function"},{"doc":"Retrieves information about an account that's associated with an Amazon Macie\nadministrator account.","ref":"AWS.Macie2.html#get_member/3","title":"AWS.Macie2.get_member/3","type":"function"},{"doc":"Retrieves (queries) sensitive data discovery statistics and the sensitivity\nscore for an S3 bucket.","ref":"AWS.Macie2.html#get_resource_profile/3","title":"AWS.Macie2.get_resource_profile/3","type":"function"},{"doc":"Retrieves the status and configuration settings for retrieving occurrences of\nsensitive data reported by findings.","ref":"AWS.Macie2.html#get_reveal_configuration/2","title":"AWS.Macie2.get_reveal_configuration/2","type":"function"},{"doc":"Retrieves occurrences of sensitive data reported by a finding.","ref":"AWS.Macie2.html#get_sensitive_data_occurrences/3","title":"AWS.Macie2.get_sensitive_data_occurrences/3","type":"function"},{"doc":"Checks whether occurrences of sensitive data can be retrieved for a finding.","ref":"AWS.Macie2.html#get_sensitive_data_occurrences_availability/3","title":"AWS.Macie2.get_sensitive_data_occurrences_availability/3","type":"function"},{"doc":"Retrieves the settings for the sensitivity inspection template for an account.","ref":"AWS.Macie2.html#get_sensitivity_inspection_template/3","title":"AWS.Macie2.get_sensitivity_inspection_template/3","type":"function"},{"doc":"Retrieves (queries) quotas and aggregated usage data for one or more accounts.","ref":"AWS.Macie2.html#get_usage_statistics/3","title":"AWS.Macie2.get_usage_statistics/3","type":"function"},{"doc":"Retrieves (queries) aggregated usage data for an account.","ref":"AWS.Macie2.html#get_usage_totals/3","title":"AWS.Macie2.get_usage_totals/3","type":"function"},{"doc":"Retrieves a subset of information about all the allow lists for an account.","ref":"AWS.Macie2.html#list_allow_lists/4","title":"AWS.Macie2.list_allow_lists/4","type":"function"},{"doc":"Retrieves a subset of information about one or more classification jobs.","ref":"AWS.Macie2.html#list_classification_jobs/3","title":"AWS.Macie2.list_classification_jobs/3","type":"function"},{"doc":"Retrieves a subset of information about the classification scope for an account.","ref":"AWS.Macie2.html#list_classification_scopes/4","title":"AWS.Macie2.list_classification_scopes/4","type":"function"},{"doc":"Retrieves a subset of information about all the custom data identifiers for an\naccount.","ref":"AWS.Macie2.html#list_custom_data_identifiers/3","title":"AWS.Macie2.list_custom_data_identifiers/3","type":"function"},{"doc":"Retrieves a subset of information about one or more findings.","ref":"AWS.Macie2.html#list_findings/3","title":"AWS.Macie2.list_findings/3","type":"function"},{"doc":"Retrieves a subset of information about all the findings filters for an account.","ref":"AWS.Macie2.html#list_findings_filters/4","title":"AWS.Macie2.list_findings_filters/4","type":"function"},{"doc":"Retrieves information about the Amazon Macie membership invitations that were\nreceived by an account.","ref":"AWS.Macie2.html#list_invitations/4","title":"AWS.Macie2.list_invitations/4","type":"function"},{"doc":"Retrieves information about all the managed data identifiers that Amazon Macie\ncurrently provides.","ref":"AWS.Macie2.html#list_managed_data_identifiers/3","title":"AWS.Macie2.list_managed_data_identifiers/3","type":"function"},{"doc":"Retrieves information about the accounts that are associated with an Amazon\nMacie administrator account.","ref":"AWS.Macie2.html#list_members/5","title":"AWS.Macie2.list_members/5","type":"function"},{"doc":"Retrieves information about the delegated Amazon Macie administrator account for\nan organization in Organizations.","ref":"AWS.Macie2.html#list_organization_admin_accounts/4","title":"AWS.Macie2.list_organization_admin_accounts/4","type":"function"},{"doc":"Retrieves information about objects that were selected from an S3 bucket for\nautomated sensitive data discovery.","ref":"AWS.Macie2.html#list_resource_profile_artifacts/4","title":"AWS.Macie2.list_resource_profile_artifacts/4","type":"function"},{"doc":"Retrieves information about the types and amount of sensitive data that Amazon\nMacie found in an S3 bucket.","ref":"AWS.Macie2.html#list_resource_profile_detections/5","title":"AWS.Macie2.list_resource_profile_detections/5","type":"function"},{"doc":"Retrieves a subset of information about the sensitivity inspection template for\nan account.","ref":"AWS.Macie2.html#list_sensitivity_inspection_templates/4","title":"AWS.Macie2.list_sensitivity_inspection_templates/4","type":"function"},{"doc":"Retrieves the tags (keys and values) that are associated with an Amazon Macie\nresource.","ref":"AWS.Macie2.html#list_tags_for_resource/3","title":"AWS.Macie2.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.Macie2.html#metadata/0","title":"AWS.Macie2.metadata/0","type":"function"},{"doc":"Creates or updates the configuration settings for storing data classification\nresults.","ref":"AWS.Macie2.html#put_classification_export_configuration/3","title":"AWS.Macie2.put_classification_export_configuration/3","type":"function"},{"doc":"Updates the configuration settings for publishing findings to Security Hub.","ref":"AWS.Macie2.html#put_findings_publication_configuration/3","title":"AWS.Macie2.put_findings_publication_configuration/3","type":"function"},{"doc":"Retrieves (queries) statistical data and other information about Amazon Web\nServices resources that Amazon Macie monitors and analyzes.","ref":"AWS.Macie2.html#search_resources/3","title":"AWS.Macie2.search_resources/3","type":"function"},{"doc":"Adds or updates one or more tags (keys and values) that are associated with an\nAmazon Macie resource.","ref":"AWS.Macie2.html#tag_resource/4","title":"AWS.Macie2.tag_resource/4","type":"function"},{"doc":"Tests a custom data identifier.","ref":"AWS.Macie2.html#test_custom_data_identifier/3","title":"AWS.Macie2.test_custom_data_identifier/3","type":"function"},{"doc":"Removes one or more tags (keys and values) from an Amazon Macie resource.","ref":"AWS.Macie2.html#untag_resource/4","title":"AWS.Macie2.untag_resource/4","type":"function"},{"doc":"Updates the settings for an allow list.","ref":"AWS.Macie2.html#update_allow_list/4","title":"AWS.Macie2.update_allow_list/4","type":"function"},{"doc":"Enables or disables automated sensitive data discovery for an account.","ref":"AWS.Macie2.html#update_automated_discovery_configuration/3","title":"AWS.Macie2.update_automated_discovery_configuration/3","type":"function"},{"doc":"Changes the status of a classification job.","ref":"AWS.Macie2.html#update_classification_job/4","title":"AWS.Macie2.update_classification_job/4","type":"function"},{"doc":"Updates the classification scope settings for an account.","ref":"AWS.Macie2.html#update_classification_scope/4","title":"AWS.Macie2.update_classification_scope/4","type":"function"},{"doc":"Updates the criteria and other settings for a findings filter.","ref":"AWS.Macie2.html#update_findings_filter/4","title":"AWS.Macie2.update_findings_filter/4","type":"function"},{"doc":"Suspends or re-enables Amazon Macie, or updates the configuration settings for a\nMacie account.","ref":"AWS.Macie2.html#update_macie_session/3","title":"AWS.Macie2.update_macie_session/3","type":"function"},{"doc":"Enables an Amazon Macie administrator to suspend or re-enable Macie for a member\naccount.","ref":"AWS.Macie2.html#update_member_session/4","title":"AWS.Macie2.update_member_session/4","type":"function"},{"doc":"Updates the Amazon Macie configuration settings for an organization in\nOrganizations.","ref":"AWS.Macie2.html#update_organization_configuration/3","title":"AWS.Macie2.update_organization_configuration/3","type":"function"},{"doc":"Updates the sensitivity score for an S3 bucket.","ref":"AWS.Macie2.html#update_resource_profile/3","title":"AWS.Macie2.update_resource_profile/3","type":"function"},{"doc":"Updates the sensitivity scoring settings for an S3 bucket.","ref":"AWS.Macie2.html#update_resource_profile_detections/3","title":"AWS.Macie2.update_resource_profile_detections/3","type":"function"},{"doc":"Updates the status and configuration settings for retrieving occurrences of\nsensitive data reported by findings.","ref":"AWS.Macie2.html#update_reveal_configuration/3","title":"AWS.Macie2.update_reveal_configuration/3","type":"function"},{"doc":"Updates the settings for the sensitivity inspection template for an account.","ref":"AWS.Macie2.html#update_sensitivity_inspection_template/4","title":"AWS.Macie2.update_sensitivity_inspection_template/4","type":"function"},{"doc":"Amazon Managed Blockchain is a fully managed service for creating and managing\nblockchain networks using open-source frameworks.\n\nBlockchain allows you to build applications where multiple parties can securely\nand transparently run transactions and share data without the need for a\ntrusted, central authority.\n\nManaged Blockchain supports the Hyperledger Fabric and Ethereum open-source\nframeworks. Because of fundamental differences between the frameworks, some API\nactions or data types may only apply in the context of one framework and not the\nother. For example, actions related to Hyperledger Fabric network members such\nas `CreateMember` and `DeleteMember` don't apply to Ethereum.\n\nThe description for each action indicates the framework or frameworks to which\nit applies. Data types and properties that apply only in the context of a\nparticular framework are similarly indicated.","ref":"AWS.ManagedBlockchain.html","title":"AWS.ManagedBlockchain","type":"module"},{"doc":"Creates a new accessor for use with Amazon Managed Blockchain service that\nsupports token based access.\n\nThe accessor contains information required for token based access.","ref":"AWS.ManagedBlockchain.html#create_accessor/3","title":"AWS.ManagedBlockchain.create_accessor/3","type":"function"},{"doc":"Creates a member within a Managed Blockchain network.\n\nApplies only to Hyperledger Fabric.","ref":"AWS.ManagedBlockchain.html#create_member/4","title":"AWS.ManagedBlockchain.create_member/4","type":"function"},{"doc":"Creates a new blockchain network using Amazon Managed Blockchain.\n\nApplies only to Hyperledger Fabric.","ref":"AWS.ManagedBlockchain.html#create_network/3","title":"AWS.ManagedBlockchain.create_network/3","type":"function"},{"doc":"Creates a node on the specified blockchain network.\n\nApplies to Hyperledger Fabric and Ethereum.","ref":"AWS.ManagedBlockchain.html#create_node/4","title":"AWS.ManagedBlockchain.create_node/4","type":"function"},{"doc":"Creates a proposal for a change to the network that other members of the network\ncan vote on, for example, a proposal to add a new member to the network.\n\nAny member can create a proposal.\n\nApplies only to Hyperledger Fabric.","ref":"AWS.ManagedBlockchain.html#create_proposal/4","title":"AWS.ManagedBlockchain.create_proposal/4","type":"function"},{"doc":"Deletes an accessor that your Amazon Web Services account owns.\n\nAn accessor object is a container that has the information required for token\nbased access to your Ethereum nodes including, the `BILLING_TOKEN`. After an\naccessor is deleted, the status of the accessor changes from `AVAILABLE` to\n`PENDING_DELETION`. An accessor in the `PENDING_DELETION` state can’t be used\nfor new WebSocket requests or HTTP requests. However, WebSocket connections that\nwere initiated while the accessor was in the `AVAILABLE` state remain open until\nthey expire (up to 2 hours).","ref":"AWS.ManagedBlockchain.html#delete_accessor/4","title":"AWS.ManagedBlockchain.delete_accessor/4","type":"function"},{"doc":"Deletes a member.\n\nDeleting a member removes the member and all associated resources from the\nnetwork. `DeleteMember` can only be called for a specified `MemberId` if the\nprincipal performing the action is associated with the Amazon Web Services\naccount that owns the member. In all other cases, the `DeleteMember` action is\ncarried out as the result of an approved proposal to remove a member. If\n`MemberId` is the last member in a network specified by the last Amazon Web\nServices account, the network is deleted also.\n\nApplies only to Hyperledger Fabric.","ref":"AWS.ManagedBlockchain.html#delete_member/5","title":"AWS.ManagedBlockchain.delete_member/5","type":"function"},{"doc":"Deletes a node that your Amazon Web Services account owns.\n\nAll data on the node is lost and cannot be recovered.\n\nApplies to Hyperledger Fabric and Ethereum.","ref":"AWS.ManagedBlockchain.html#delete_node/5","title":"AWS.ManagedBlockchain.delete_node/5","type":"function"},{"doc":"Returns detailed information about an accessor.\n\nAn accessor object is a container that has the information required for token\nbased access to your Ethereum nodes.","ref":"AWS.ManagedBlockchain.html#get_accessor/3","title":"AWS.ManagedBlockchain.get_accessor/3","type":"function"},{"doc":"Returns detailed information about a member.\n\nApplies only to Hyperledger Fabric.","ref":"AWS.ManagedBlockchain.html#get_member/4","title":"AWS.ManagedBlockchain.get_member/4","type":"function"},{"doc":"Returns detailed information about a network.\n\nApplies to Hyperledger Fabric and Ethereum.","ref":"AWS.ManagedBlockchain.html#get_network/3","title":"AWS.ManagedBlockchain.get_network/3","type":"function"},{"doc":"Returns detailed information about a node.\n\nApplies to Hyperledger Fabric and Ethereum.","ref":"AWS.ManagedBlockchain.html#get_node/5","title":"AWS.ManagedBlockchain.get_node/5","type":"function"},{"doc":"Returns detailed information about a proposal.\n\nApplies only to Hyperledger Fabric.","ref":"AWS.ManagedBlockchain.html#get_proposal/4","title":"AWS.ManagedBlockchain.get_proposal/4","type":"function"},{"doc":"Returns a list of the accessors and their properties.\n\nAccessor objects are containers that have the information required for token\nbased access to your Ethereum nodes.","ref":"AWS.ManagedBlockchain.html#list_accessors/5","title":"AWS.ManagedBlockchain.list_accessors/5","type":"function"},{"doc":"Returns a list of all invitations for the current Amazon Web Services account.\n\nApplies only to Hyperledger Fabric.","ref":"AWS.ManagedBlockchain.html#list_invitations/4","title":"AWS.ManagedBlockchain.list_invitations/4","type":"function"},{"doc":"Returns a list of the members in a network and properties of their\nconfigurations.\n\nApplies only to Hyperledger Fabric.","ref":"AWS.ManagedBlockchain.html#list_members/8","title":"AWS.ManagedBlockchain.list_members/8","type":"function"},{"doc":"Returns information about the networks in which the current Amazon Web Services\naccount participates.\n\nApplies to Hyperledger Fabric and Ethereum.","ref":"AWS.ManagedBlockchain.html#list_networks/7","title":"AWS.ManagedBlockchain.list_networks/7","type":"function"},{"doc":"Returns information about the nodes within a network.\n\nApplies to Hyperledger Fabric and Ethereum.","ref":"AWS.ManagedBlockchain.html#list_nodes/7","title":"AWS.ManagedBlockchain.list_nodes/7","type":"function"},{"doc":"Returns the list of votes for a specified proposal, including the value of each\nvote and the unique identifier of the member that cast the vote.\n\nApplies only to Hyperledger Fabric.","ref":"AWS.ManagedBlockchain.html#list_proposal_votes/6","title":"AWS.ManagedBlockchain.list_proposal_votes/6","type":"function"},{"doc":"Returns a list of proposals for the network.\n\nApplies only to Hyperledger Fabric.","ref":"AWS.ManagedBlockchain.html#list_proposals/5","title":"AWS.ManagedBlockchain.list_proposals/5","type":"function"},{"doc":"Returns a list of tags for the specified resource.\n\nEach tag consists of a key and optional value.\n\nFor more information about tags, see [Tagging Resources](https://docs.aws.amazon.com/managed-blockchain/latest/ethereum-dev/tagging-resources.html)\nin the *Amazon Managed Blockchain Ethereum Developer Guide*, or [Tagging Resources](https://docs.aws.amazon.com/managed-blockchain/latest/hyperledger-fabric-dev/tagging-resources.html)\nin the *Amazon Managed Blockchain Hyperledger Fabric Developer Guide*.","ref":"AWS.ManagedBlockchain.html#list_tags_for_resource/3","title":"AWS.ManagedBlockchain.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.ManagedBlockchain.html#metadata/0","title":"AWS.ManagedBlockchain.metadata/0","type":"function"},{"doc":"Rejects an invitation to join a network.\n\nThis action can be called by a principal in an Amazon Web Services account that\nhas received an invitation to create a member and join a network.\n\nApplies only to Hyperledger Fabric.","ref":"AWS.ManagedBlockchain.html#reject_invitation/4","title":"AWS.ManagedBlockchain.reject_invitation/4","type":"function"},{"doc":"Adds or overwrites the specified tags for the specified Amazon Managed\nBlockchain resource.\n\nEach tag consists of a key and optional value.\n\nWhen you specify a tag key that already exists, the tag value is overwritten\nwith the new value. Use `UntagResource` to remove tag keys.\n\nA resource can have up to 50 tags. If you try to create more than 50 tags for a\nresource, your request fails and returns an error.\n\nFor more information about tags, see [Tagging Resources](https://docs.aws.amazon.com/managed-blockchain/latest/ethereum-dev/tagging-resources.html)\nin the *Amazon Managed Blockchain Ethereum Developer Guide*, or [Tagging Resources](https://docs.aws.amazon.com/managed-blockchain/latest/hyperledger-fabric-dev/tagging-resources.html)\nin the *Amazon Managed Blockchain Hyperledger Fabric Developer Guide*.","ref":"AWS.ManagedBlockchain.html#tag_resource/4","title":"AWS.ManagedBlockchain.tag_resource/4","type":"function"},{"doc":"Removes the specified tags from the Amazon Managed Blockchain resource.\n\nFor more information about tags, see [Tagging Resources](https://docs.aws.amazon.com/managed-blockchain/latest/ethereum-dev/tagging-resources.html)\nin the *Amazon Managed Blockchain Ethereum Developer Guide*, or [Tagging Resources](https://docs.aws.amazon.com/managed-blockchain/latest/hyperledger-fabric-dev/tagging-resources.html)\nin the *Amazon Managed Blockchain Hyperledger Fabric Developer Guide*.","ref":"AWS.ManagedBlockchain.html#untag_resource/4","title":"AWS.ManagedBlockchain.untag_resource/4","type":"function"},{"doc":"Updates a member configuration with new parameters.\n\nApplies only to Hyperledger Fabric.","ref":"AWS.ManagedBlockchain.html#update_member/5","title":"AWS.ManagedBlockchain.update_member/5","type":"function"},{"doc":"Updates a node configuration with new parameters.\n\nApplies only to Hyperledger Fabric.","ref":"AWS.ManagedBlockchain.html#update_node/5","title":"AWS.ManagedBlockchain.update_node/5","type":"function"},{"doc":"Casts a vote for a specified `ProposalId` on behalf of a member.\n\nThe member to vote as, specified by `VoterMemberId`, must be in the same Amazon\nWeb Services account as the principal that calls the action.\n\nApplies only to Hyperledger Fabric.","ref":"AWS.ManagedBlockchain.html#vote_on_proposal/5","title":"AWS.ManagedBlockchain.vote_on_proposal/5","type":"function"},{"doc":"Amazon Managed Blockchain (AMB) Query provides you with convenient access to\nmulti-blockchain network data, which makes it easier for you to extract\ncontextual data related to blockchain activity.\n\nYou can use AMB Query to read data from public blockchain networks, such as\nBitcoin Mainnet and Ethereum Mainnet. You can also get information such as the\ncurrent and historical balances of addresses, or you can get a list of\nblockchain transactions for a given time period. Additionally, you can get\ndetails of a given transaction, such as transaction events, which you can\nfurther analyze or use in business logic for your applications.","ref":"AWS.ManagedBlockchainQuery.html","title":"AWS.ManagedBlockchainQuery","type":"module"},{"doc":"Gets the token balance for a batch of tokens by using the `BatchGetTokenBalance`\naction for every token in the request.\n\nOnly the native tokens BTC and ETH, and the ERC-20, ERC-721, and ERC 1155 token\nstandards are supported.","ref":"AWS.ManagedBlockchainQuery.html#batch_get_token_balance/3","title":"AWS.ManagedBlockchainQuery.batch_get_token_balance/3","type":"function"},{"doc":"Gets the information about a specific contract deployed on the blockchain.\n\n   The Bitcoin blockchain networks do not support this operation.\n\n   Metadata is currently only available for some `ERC-20` contracts.\nMetadata will be available for additional contracts in the future.","ref":"AWS.ManagedBlockchainQuery.html#get_asset_contract/3","title":"AWS.ManagedBlockchainQuery.get_asset_contract/3","type":"function"},{"doc":"Gets the balance of a specific token, including native tokens, for a given\naddress (wallet or contract) on the blockchain.\n\nOnly the native tokens BTC and ETH, and the ERC-20, ERC-721, and ERC 1155 token\nstandards are supported.","ref":"AWS.ManagedBlockchainQuery.html#get_token_balance/3","title":"AWS.ManagedBlockchainQuery.get_token_balance/3","type":"function"},{"doc":"Gets the details of a transaction.\n\nThis action will return transaction details for all transactions that are\n*confirmed* on the blockchain, even if they have not reached\n[finality](https://docs.aws.amazon.com/managed-blockchain/latest/ambq-dg/key-concepts.html#finality).","ref":"AWS.ManagedBlockchainQuery.html#get_transaction/3","title":"AWS.ManagedBlockchainQuery.get_transaction/3","type":"function"},{"doc":"Lists all the contracts for a given contract type deployed by an address (either\na contract address or a wallet address).\n\nThe Bitcoin blockchain networks do not support this operation.","ref":"AWS.ManagedBlockchainQuery.html#list_asset_contracts/3","title":"AWS.ManagedBlockchainQuery.list_asset_contracts/3","type":"function"},{"doc":"This action returns the following for a given blockchain network:\n\n  * Lists all token balances owned by an address (either a contract\naddress or a wallet address).\n\n  * Lists all token balances for all tokens created by a contract.\n\n  * Lists all token balances for a given token.\n\nYou must always specify the network property of the `tokenFilter` when using\nthis operation.","ref":"AWS.ManagedBlockchainQuery.html#list_token_balances/3","title":"AWS.ManagedBlockchainQuery.list_token_balances/3","type":"function"},{"doc":"An array of `TransactionEvent` objects.\n\nEach object contains details about the transaction event.\n\nThis action will return transaction details for all transactions that are\n*confirmed* on the blockchain, even if they have not reached\n[finality](https://docs.aws.amazon.com/managed-blockchain/latest/ambq-dg/key-concepts.html#finality).","ref":"AWS.ManagedBlockchainQuery.html#list_transaction_events/3","title":"AWS.ManagedBlockchainQuery.list_transaction_events/3","type":"function"},{"doc":"Lists all of the transactions on a given wallet address or to a specific\ncontract.","ref":"AWS.ManagedBlockchainQuery.html#list_transactions/3","title":"AWS.ManagedBlockchainQuery.list_transactions/3","type":"function"},{"doc":"","ref":"AWS.ManagedBlockchainQuery.html#metadata/0","title":"AWS.ManagedBlockchainQuery.metadata/0","type":"function"},{"doc":"AWS Marketplace is a curated digital catalog that customers can use to find,\nbuy, deploy, and manage third-party software, data, and services to build\nsolutions and run their businesses.\n\nThe AWS Marketplace Agreement Service provides an API interface that helps AWS\nMarketplace sellers manage their product-related agreements, including listing,\nsearching, and filtering agreements.\n\nTo manage agreements in AWS Marketplace, you must ensure that your AWS Identity\nand Access Management (IAM) policies and roles are set up. The user must have\nthe required policies/permissions that allow them to carry out the actions in\nAWS:\n\n  * `DescribeAgreement` – Grants permission to users to obtain\ndetailed meta data about any of their agreements.\n\n  * `GetAgreementTerms` – Grants permission to users to obtain details\nabout the terms of an agreement.\n\n  * `SearchAgreements` – Grants permission to users to search through\nall their agreements.","ref":"AWS.MarketplaceAgreement.html","title":"AWS.MarketplaceAgreement","type":"module"},{"doc":"Provides details about an agreement, such as the proposer, acceptor, start date,\nand end date.","ref":"AWS.MarketplaceAgreement.html#describe_agreement/3","title":"AWS.MarketplaceAgreement.describe_agreement/3","type":"function"},{"doc":"Obtains details about the terms in an agreement that you participated in as\nproposer or acceptor.\n\nThe details include:\n\n  * `TermType` – The type of term, such as `LegalTerm`, `RenewalTerm`,\nor `ConfigurableUpfrontPricingTerm`.\n\n  * `TermID` – The ID of the particular term, which is common between\noffer and agreement.\n\n  * `TermPayload` – The key information contained in the term, such as\nthe EULA for `LegalTerm` or pricing and dimensions for various pricing terms,\nsuch as `ConfigurableUpfrontPricingTerm` or `UsageBasedPricingTerm`.\n\n  * `Configuration` – The buyer/acceptor's selection at the time of\nagreement creation, such as the number of units purchased for a dimension or\nsetting the `EnableAutoRenew` flag.","ref":"AWS.MarketplaceAgreement.html#get_agreement_terms/3","title":"AWS.MarketplaceAgreement.get_agreement_terms/3","type":"function"},{"doc":"","ref":"AWS.MarketplaceAgreement.html#metadata/0","title":"AWS.MarketplaceAgreement.metadata/0","type":"function"},{"doc":"Searches across all agreements that a proposer or an acceptor has in AWS\nMarketplace.\n\nThe search returns a list of agreements with basic agreement information.\n\nThe following filter combinations are supported:\n\n  * `PartyType` as `Proposer` + `AgreementType` + `ResourceIdentifier`\n\n  * `PartyType` as `Proposer` + `AgreementType` + `OfferId`\n\n  * `PartyType` as `Proposer` + `AgreementType` + `AcceptorAccountId`\n\n  * `PartyType` as `Proposer` + `AgreementType` + `Status`\n\n  * `PartyType` as `Proposer` + `AgreementType` + `ResourceIdentifier`\n+ `Status`\n\n  * `PartyType` as `Proposer` + `AgreementType` + `OfferId` + `Status`\n\n  * `PartyType` as `Proposer` + `AgreementType` + `AcceptorAccountId`\n+ `Status`\n\n  * `PartyType` as `Proposer` + `AgreementType` + `ResourceType` +\n`Status`\n\n  * `PartyType` as `Proposer` + `AgreementType` + `AcceptorAccountId`\n+ `ResourceType` + `Status`\n\n  * `PartyType` as `Proposer` + `AgreementType` + `AcceptorAccountId`\n+ `OfferId`\n\n  * `PartyType` as `Proposer` + `AgreementType` + `AcceptorAccountId`\n+ `OfferId` + `Status`\n\n  * `PartyType` as `Proposer` + `AgreementType` + `AcceptorAccountId`\n+ `ResourceIdentifier`\n\n  * `PartyType` as `Proposer` + `AgreementType` + `AcceptorAccountId`\n+ `ResourceIdentifier` + `Status`\n\n  * `PartyType` as `Proposer` + `AgreementType` + `AcceptorAccountId`\n+ `ResourceType`","ref":"AWS.MarketplaceAgreement.html#search_agreements/3","title":"AWS.MarketplaceAgreement.search_agreements/3","type":"function"},{"doc":"Catalog API actions allow you to manage your entities through list, describe,\nand update capabilities.\n\nAn entity can be a product or an offer on AWS Marketplace.\n\nYou can automate your entity update process by integrating the AWS Marketplace\nCatalog API with your AWS Marketplace product build or deployment pipelines. You\ncan also create your own applications on top of the Catalog API to manage your\nproducts on AWS Marketplace.","ref":"AWS.MarketplaceCatalog.html","title":"AWS.MarketplaceCatalog","type":"module"},{"doc":"Returns metadata and content for multiple entities.\n\nThis is the Batch version of the `DescribeEntity` API and uses the same IAM\npermission action as `DescribeEntity` API.","ref":"AWS.MarketplaceCatalog.html#batch_describe_entities/3","title":"AWS.MarketplaceCatalog.batch_describe_entities/3","type":"function"},{"doc":"Used to cancel an open change request.\n\nMust be sent before the status of the request changes to `APPLYING`, the final\nstage of completing your change request. You can describe a change during the\n60-day request history retention period for API calls.","ref":"AWS.MarketplaceCatalog.html#cancel_change_set/3","title":"AWS.MarketplaceCatalog.cancel_change_set/3","type":"function"},{"doc":"Deletes a resource-based policy on an entity that is identified by its resource\nARN.","ref":"AWS.MarketplaceCatalog.html#delete_resource_policy/3","title":"AWS.MarketplaceCatalog.delete_resource_policy/3","type":"function"},{"doc":"Provides information about a given change set.","ref":"AWS.MarketplaceCatalog.html#describe_change_set/4","title":"AWS.MarketplaceCatalog.describe_change_set/4","type":"function"},{"doc":"Returns the metadata and content of the entity.","ref":"AWS.MarketplaceCatalog.html#describe_entity/4","title":"AWS.MarketplaceCatalog.describe_entity/4","type":"function"},{"doc":"Gets a resource-based policy of an entity that is identified by its resource\nARN.","ref":"AWS.MarketplaceCatalog.html#get_resource_policy/3","title":"AWS.MarketplaceCatalog.get_resource_policy/3","type":"function"},{"doc":"Returns the list of change sets owned by the account being used to make the\ncall.\n\nYou can filter this list by providing any combination of `entityId`,\n`ChangeSetName`, and status. If you provide more than one filter, the API\noperation applies a logical AND between the filters.\n\nYou can describe a change during the 60-day request history retention period for\nAPI calls.","ref":"AWS.MarketplaceCatalog.html#list_change_sets/3","title":"AWS.MarketplaceCatalog.list_change_sets/3","type":"function"},{"doc":"Provides the list of entities of a given type.","ref":"AWS.MarketplaceCatalog.html#list_entities/3","title":"AWS.MarketplaceCatalog.list_entities/3","type":"function"},{"doc":"Lists all tags that have been added to a resource (either an\n[entity](https://docs.aws.amazon.com/marketplace-catalog/latest/api-reference/welcome.html#catalog-api-entities) or [change\nset](https://docs.aws.amazon.com/marketplace-catalog/latest/api-reference/welcome.html#working-with-change-sets)).","ref":"AWS.MarketplaceCatalog.html#list_tags_for_resource/3","title":"AWS.MarketplaceCatalog.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.MarketplaceCatalog.html#metadata/0","title":"AWS.MarketplaceCatalog.metadata/0","type":"function"},{"doc":"Attaches a resource-based policy to an entity.\n\nExamples of an entity include: `AmiProduct` and `ContainerProduct`.","ref":"AWS.MarketplaceCatalog.html#put_resource_policy/3","title":"AWS.MarketplaceCatalog.put_resource_policy/3","type":"function"},{"doc":"Allows you to request changes for your entities.\n\nWithin a single `ChangeSet`, you can't start the same change type against the\nsame entity multiple times. Additionally, when a `ChangeSet` is running, all the\nentities targeted by the different changes are locked until the change set has\ncompleted (either succeeded, cancelled, or failed). If you try to start a change\nset containing a change against an entity that is already locked, you will\nreceive a `ResourceInUseException` error.\n\nFor example, you can't start the `ChangeSet` described in the\n[example](https://docs.aws.amazon.com/marketplace-catalog/latest/api-reference/API_StartChangeSet.html#API_StartChangeSet_Examples) later in this topic because it contains two changes to run the same change type\n(`AddRevisions`) against the same entity (`entity-id@1`).\n\nFor more information about working with change sets, see [ Working with change\nsets](https://docs.aws.amazon.com/marketplace-catalog/latest/api-reference/welcome.html#working-with-change-sets).\nFor information about change types for single-AMI products, see [Working with single-AMI\nproducts](https://docs.aws.amazon.com/marketplace-catalog/latest/api-reference/ami-products.html#working-with-single-AMI-products).\nAlso, for more information about change types available for container-based\nproducts, see [Working with container products](https://docs.aws.amazon.com/marketplace-catalog/latest/api-reference/container-products.html#working-with-container-products).","ref":"AWS.MarketplaceCatalog.html#start_change_set/3","title":"AWS.MarketplaceCatalog.start_change_set/3","type":"function"},{"doc":"Tags a resource (either an\n[entity](https://docs.aws.amazon.com/marketplace-catalog/latest/api-reference/welcome.html#catalog-api-entities) or [change\nset](https://docs.aws.amazon.com/marketplace-catalog/latest/api-reference/welcome.html#working-with-change-sets)).","ref":"AWS.MarketplaceCatalog.html#tag_resource/3","title":"AWS.MarketplaceCatalog.tag_resource/3","type":"function"},{"doc":"Removes a tag or list of tags from a resource (either an\n[entity](https://docs.aws.amazon.com/marketplace-catalog/latest/api-reference/welcome.html#catalog-api-entities) or [change\nset](https://docs.aws.amazon.com/marketplace-catalog/latest/api-reference/welcome.html#working-with-change-sets)).","ref":"AWS.MarketplaceCatalog.html#untag_resource/3","title":"AWS.MarketplaceCatalog.untag_resource/3","type":"function"},{"doc":"Provides AWS Marketplace business intelligence data on-demand.","ref":"AWS.MarketplaceCommerceAnalytics.html","title":"AWS.MarketplaceCommerceAnalytics","type":"module"},{"doc":"Given a data set type and data set publication date, asynchronously publishes\nthe requested data set to the specified S3 bucket and notifies the specified SNS\ntopic once the data is available.\n\nReturns a unique request identifier that can be used to correlate requests with\nnotifications from the SNS topic. Data sets will be published in comma-separated\nvalues (CSV) format with the file name {data_set_type}_YYYY-MM-DD.csv. If a file\nwith the same name already exists (e.g. if the same data set is requested\ntwice), the original file will be overwritten by the new file. Requires a Role\nwith an attached permissions policy providing Allow permissions for the\nfollowing actions: s3:PutObject, s3:GetBucketLocation, sns:GetTopicAttributes,\nsns:Publish, iam:GetRolePolicy.","ref":"AWS.MarketplaceCommerceAnalytics.html#generate_data_set/3","title":"AWS.MarketplaceCommerceAnalytics.generate_data_set/3","type":"function"},{"doc":"","ref":"AWS.MarketplaceCommerceAnalytics.html#metadata/0","title":"AWS.MarketplaceCommerceAnalytics.metadata/0","type":"function"},{"doc":"*This target has been deprecated.* Given a data set type and a from date,\nasynchronously publishes the requested customer support data to the specified S3\nbucket and notifies the specified SNS topic once the data is available.\n\nReturns a unique request identifier that can be used to correlate requests with\nnotifications from the SNS topic. Data sets will be published in comma-separated\nvalues (CSV) format with the file name\n{data_set_type}_YYYY-MM-DD'T'HH-mm-ss'Z'.csv. If a file with the same name\nalready exists (e.g. if the same data set is requested twice), the original file\nwill be overwritten by the new file. Requires a Role with an attached\npermissions policy providing Allow permissions for the following actions:\ns3:PutObject, s3:GetBucketLocation, sns:GetTopicAttributes, sns:Publish,\niam:GetRolePolicy.","ref":"AWS.MarketplaceCommerceAnalytics.html#start_support_data_export/3","title":"AWS.MarketplaceCommerceAnalytics.start_support_data_export/3","type":"function"},{"doc":"The AWS Marketplace Deployment Service supports the Quick Launch experience,\nwhich is a deployment option for software as a service (SaaS) products.\n\nQuick Launch simplifies and reduces the time, resources, and steps required to\nconfigure, deploy, and launch a products. The AWS Marketplace Deployment Service\nprovides sellers with a secure method for passing deployment parameters (for\nexample, API keys and external IDs) to buyers during the Quick Launch\nexperience.","ref":"AWS.MarketplaceDeployment.html","title":"AWS.MarketplaceDeployment","type":"module"},{"doc":"Lists all tags that have been added to a deployment parameter resource.","ref":"AWS.MarketplaceDeployment.html#list_tags_for_resource/3","title":"AWS.MarketplaceDeployment.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.MarketplaceDeployment.html#metadata/0","title":"AWS.MarketplaceDeployment.metadata/0","type":"function"},{"doc":"Creates or updates a deployment parameter and is targeted by `catalog` and\n`agreementId`.","ref":"AWS.MarketplaceDeployment.html#put_deployment_parameter/5","title":"AWS.MarketplaceDeployment.put_deployment_parameter/5","type":"function"},{"doc":"Tags a resource.","ref":"AWS.MarketplaceDeployment.html#tag_resource/4","title":"AWS.MarketplaceDeployment.tag_resource/4","type":"function"},{"doc":"Removes a tag or list of tags from a resource.","ref":"AWS.MarketplaceDeployment.html#untag_resource/4","title":"AWS.MarketplaceDeployment.untag_resource/4","type":"function"},{"doc":"AWS Marketplace Entitlement Service\n\nThis reference provides descriptions of the AWS Marketplace Entitlement Service\nAPI.\n\nAWS Marketplace Entitlement Service is used to determine the entitlement of a\ncustomer to a given product. An entitlement represents capacity in a product\nowned by the customer. For example, a customer might own some number of users or\nseats in an SaaS application or some amount of data capacity in a multi-tenant\ndatabase.","ref":"AWS.MarketplaceEntitlement.html","title":"AWS.MarketplaceEntitlement","type":"module"},{"doc":"* *GetEntitlements*- Gets the entitlements for a Marketplace\nproduct.","ref":"AWS.MarketplaceEntitlement.html#module-getting-entitlement-records","title":"Getting Entitlement Records - AWS.MarketplaceEntitlement","type":"module"},{"doc":"GetEntitlements retrieves entitlement values for a given product.\n\nThe results can be filtered based on customer identifier or product dimensions.","ref":"AWS.MarketplaceEntitlement.html#get_entitlements/3","title":"AWS.MarketplaceEntitlement.get_entitlements/3","type":"function"},{"doc":"","ref":"AWS.MarketplaceEntitlement.html#metadata/0","title":"AWS.MarketplaceEntitlement.metadata/0","type":"function"},{"doc":"AWS Marketplace Metering Service\n\nThis reference provides descriptions of the low-level AWS Marketplace Metering\nService API.\n\nAWS Marketplace sellers can use this API to submit usage data for custom usage\ndimensions.\n\nFor information on the permissions you need to use this API, see [AWS Marketplace metering and entitlement API\npermissions](https://docs.aws.amazon.com/marketplace/latest/userguide/iam-user-policy-for-aws-marketplace-actions.html)\nin the *AWS Marketplace Seller Guide.*","ref":"AWS.MarketplaceMetering.html","title":"AWS.MarketplaceMetering","type":"module"},{"doc":"* *MeterUsage* - Submits the metering record for an AWS Marketplace\nproduct. `MeterUsage` is called from an EC2 instance or a container running on\nEKS or ECS.\n\n  * *BatchMeterUsage* - Submits the metering record for a set of\ncustomers. `BatchMeterUsage` is called from a software-as-a-service (SaaS)\napplication.","ref":"AWS.MarketplaceMetering.html#module-submitting-metering-records","title":"Submitting Metering Records - AWS.MarketplaceMetering","type":"module"},{"doc":"* *ResolveCustomer* - Called by a SaaS application during the\nregistration process. When a buyer visits your website during the registration\nprocess, the buyer submits a Registration Token through the browser. The\nRegistration Token is resolved through this API to obtain a `CustomerIdentifier`\nalong with the `CustomerAWSAccountId` and `ProductCode`.","ref":"AWS.MarketplaceMetering.html#module-accepting-new-customers","title":"Accepting New Customers - AWS.MarketplaceMetering","type":"module"},{"doc":"* Paid container software products sold through AWS Marketplace must\nintegrate with the AWS Marketplace Metering Service and call the `RegisterUsage`\noperation for software entitlement and metering. Free and BYOL products for\nAmazon ECS or Amazon EKS aren't required to call `RegisterUsage`, but you can do\nso if you want to receive usage data in your seller reports. For more\ninformation on using the `RegisterUsage` operation, see [Container-Based Products](https://docs.aws.amazon.com/marketplace/latest/userguide/container-based-products.html).\n\n`BatchMeterUsage` API calls are captured by AWS CloudTrail. You can use\nCloudtrail to verify that the SaaS metering records that you sent are accurate\nby searching for records with the `eventName` of `BatchMeterUsage`. You can also\nuse CloudTrail to audit records over time. For more information, see the * [AWS CloudTrail User\nGuide](http://docs.aws.amazon.com/awscloudtrail/latest/userguide/cloudtrail-concepts.html).*","ref":"AWS.MarketplaceMetering.html#module-entitlement-and-metering-for-paid-container-products","title":"Entitlement and Metering for Paid Container Products - AWS.MarketplaceMetering","type":"module"},{"doc":"`BatchMeterUsage` is called from a SaaS application listed on AWS Marketplace to\npost metering records for a set of customers.\n\nFor identical requests, the API is idempotent; requests can be retried with the\nsame records or a subset of the input records.\n\nEvery request to `BatchMeterUsage` is for one product. If you need to meter\nusage for multiple products, you must make multiple calls to `BatchMeterUsage`.\n\nUsage records are expected to be submitted as quickly as possible after the\nevent that is being recorded, and are not accepted more than 6 hours after the\nevent.\n\n`BatchMeterUsage` can process up to 25 `UsageRecords` at a time.\n\nA `UsageRecord` can optionally include multiple usage allocations, to provide\ncustomers with usage data split into buckets by tags that you define (or allow\nthe customer to define).\n\n`BatchMeterUsage` returns a list of `UsageRecordResult` objects, showing the\nresult for each `UsageRecord`, as well as a list of `UnprocessedRecords`,\nindicating errors in the service side that you should retry.\n\n`BatchMeterUsage` requests must be less than 1MB in size.\n\nFor an example of using `BatchMeterUsage`, see [ BatchMeterUsage code example](https://docs.aws.amazon.com/marketplace/latest/userguide/saas-code-examples.html#saas-batchmeterusage-example)\nin the *AWS Marketplace Seller Guide*.","ref":"AWS.MarketplaceMetering.html#batch_meter_usage/3","title":"AWS.MarketplaceMetering.batch_meter_usage/3","type":"function"},{"doc":"","ref":"AWS.MarketplaceMetering.html#metadata/0","title":"AWS.MarketplaceMetering.metadata/0","type":"function"},{"doc":"API to emit metering records.\n\nFor identical requests, the API is idempotent. It simply returns the metering\nrecord ID.\n\n`MeterUsage` is authenticated on the buyer's AWS account using credentials from\nthe EC2 instance, ECS task, or EKS pod.\n\n`MeterUsage` can optionally include multiple usage allocations, to provide\ncustomers with usage data split into buckets by tags that you define (or allow\nthe customer to define).\n\nUsage records are expected to be submitted as quickly as possible after the\nevent that is being recorded, and are not accepted more than 6 hours after the\nevent.","ref":"AWS.MarketplaceMetering.html#meter_usage/3","title":"AWS.MarketplaceMetering.meter_usage/3","type":"function"},{"doc":"Paid container software products sold through AWS Marketplace must integrate\nwith the AWS Marketplace Metering Service and call the `RegisterUsage` operation\nfor software entitlement and metering.\n\nFree and BYOL products for Amazon ECS or Amazon EKS aren't required to call\n`RegisterUsage`, but you may choose to do so if you would like to receive usage\ndata in your seller reports. The sections below explain the behavior of\n`RegisterUsage`. `RegisterUsage` performs two primary functions: metering and\nentitlement.\n\n  * *Entitlement*: `RegisterUsage` allows you to verify that the\ncustomer running your paid software is subscribed to your product on AWS\nMarketplace, enabling you to guard against unauthorized use. Your container\nimage that integrates with `RegisterUsage` is only required to guard against\nunauthorized use at container startup, as such a\n`CustomerNotSubscribedException` or `PlatformNotSupportedException` will only be\nthrown on the initial call to `RegisterUsage`. Subsequent calls from the same\nAmazon ECS task instance (e.g. task-id) or Amazon EKS pod will not throw a\n`CustomerNotSubscribedException`, even if the customer unsubscribes while the\nAmazon ECS task or Amazon EKS pod is still running.\n\n  * *Metering*: `RegisterUsage` meters software use per ECS task, per\nhour, or per pod for Amazon EKS with usage prorated to the second. A minimum of\n1 minute of usage applies to tasks that are short lived. For example, if a\ncustomer has a 10 node Amazon ECS or Amazon EKS cluster and a service configured\nas a Daemon Set, then Amazon ECS or Amazon EKS will launch a task on all 10\ncluster nodes and the customer will be charged: (10 * hourly_rate). Metering for\nsoftware use is automatically handled by the AWS Marketplace Metering Control\nPlane -- your software is not required to perform any metering specific actions,\nother than call `RegisterUsage` once for metering of software use to commence.\nThe AWS Marketplace Metering Control Plane will also continue to bill customers\nfor running ECS tasks and Amazon EKS pods, regardless of the customers\nsubscription state, removing the need for your software to perform entitlement\nchecks at runtime.","ref":"AWS.MarketplaceMetering.html#register_usage/3","title":"AWS.MarketplaceMetering.register_usage/3","type":"function"},{"doc":"`ResolveCustomer` is called by a SaaS application during the registration\nprocess.\n\nWhen a buyer visits your website during the registration process, the buyer\nsubmits a registration token through their browser. The registration token is\nresolved through this API to obtain a `CustomerIdentifier` along with the\n`CustomerAWSAccountId` and `ProductCode`.\n\nThe API needs to called from the seller account id used to publish the SaaS\napplication to successfully resolve the token.\n\nFor an example of using `ResolveCustomer`, see [ ResolveCustomer code example](https://docs.aws.amazon.com/marketplace/latest/userguide/saas-code-examples.html#saas-resolvecustomer-example)\nin the *AWS Marketplace Seller Guide*.","ref":"AWS.MarketplaceMetering.html#resolve_customer/3","title":"AWS.MarketplaceMetering.resolve_customer/3","type":"function"},{"doc":"API for AWS Elemental MediaConnect","ref":"AWS.MediaConnect.html","title":"AWS.MediaConnect","type":"module"},{"doc":"Adds outputs to an existing bridge.","ref":"AWS.MediaConnect.html#add_bridge_outputs/4","title":"AWS.MediaConnect.add_bridge_outputs/4","type":"function"},{"doc":"Adds sources to an existing bridge.","ref":"AWS.MediaConnect.html#add_bridge_sources/4","title":"AWS.MediaConnect.add_bridge_sources/4","type":"function"},{"doc":"Adds media streams to an existing flow.\n\nAfter you add a media stream to a flow, you can associate it with a source\nand/or an output that uses the ST 2110 JPEG XS or CDI protocol.","ref":"AWS.MediaConnect.html#add_flow_media_streams/4","title":"AWS.MediaConnect.add_flow_media_streams/4","type":"function"},{"doc":"Adds outputs to an existing flow.\n\nYou can create up to 50 outputs per flow.","ref":"AWS.MediaConnect.html#add_flow_outputs/4","title":"AWS.MediaConnect.add_flow_outputs/4","type":"function"},{"doc":"Adds Sources to flow","ref":"AWS.MediaConnect.html#add_flow_sources/4","title":"AWS.MediaConnect.add_flow_sources/4","type":"function"},{"doc":"Adds VPC interfaces to flow","ref":"AWS.MediaConnect.html#add_flow_vpc_interfaces/4","title":"AWS.MediaConnect.add_flow_vpc_interfaces/4","type":"function"},{"doc":"Creates a new bridge.\n\nThe request must include one source.","ref":"AWS.MediaConnect.html#create_bridge/3","title":"AWS.MediaConnect.create_bridge/3","type":"function"},{"doc":"Creates a new flow.\n\nThe request must include one source. The request optionally can include outputs\n(up to 50) and entitlements (up to 50).","ref":"AWS.MediaConnect.html#create_flow/3","title":"AWS.MediaConnect.create_flow/3","type":"function"},{"doc":"Creates a new gateway.\n\nThe request must include at least one network (up to 4).","ref":"AWS.MediaConnect.html#create_gateway/3","title":"AWS.MediaConnect.create_gateway/3","type":"function"},{"doc":"Deletes a bridge.\n\nBefore you can delete a bridge, you must stop the bridge.","ref":"AWS.MediaConnect.html#delete_bridge/4","title":"AWS.MediaConnect.delete_bridge/4","type":"function"},{"doc":"Deletes a flow.\n\nBefore you can delete a flow, you must stop the flow.","ref":"AWS.MediaConnect.html#delete_flow/4","title":"AWS.MediaConnect.delete_flow/4","type":"function"},{"doc":"Deletes a gateway.\n\nBefore you can delete a gateway, you must deregister its instances and delete\nits bridges.","ref":"AWS.MediaConnect.html#delete_gateway/4","title":"AWS.MediaConnect.delete_gateway/4","type":"function"},{"doc":"Deregisters an instance.\n\nBefore you deregister an instance, all bridges running on the instance must be\nstopped. If you want to deregister an instance without stopping the bridges, you\nmust use the --force option.","ref":"AWS.MediaConnect.html#deregister_gateway_instance/4","title":"AWS.MediaConnect.deregister_gateway_instance/4","type":"function"},{"doc":"Displays the details of a bridge.","ref":"AWS.MediaConnect.html#describe_bridge/3","title":"AWS.MediaConnect.describe_bridge/3","type":"function"},{"doc":"Displays the details of a flow.\n\nThe response includes the flow ARN, name, and Availability Zone, as well as\ndetails about the source, outputs, and entitlements.","ref":"AWS.MediaConnect.html#describe_flow/3","title":"AWS.MediaConnect.describe_flow/3","type":"function"},{"doc":"Displays details of the flow's source stream.\n\nThe response contains information about the contents of the stream and its\nprograms.","ref":"AWS.MediaConnect.html#describe_flow_source_metadata/3","title":"AWS.MediaConnect.describe_flow_source_metadata/3","type":"function"},{"doc":"Displays the details of a gateway.\n\nThe response includes the gateway ARN, name, and CIDR blocks, as well as details\nabout the networks.","ref":"AWS.MediaConnect.html#describe_gateway/3","title":"AWS.MediaConnect.describe_gateway/3","type":"function"},{"doc":"Displays the details of an instance.","ref":"AWS.MediaConnect.html#describe_gateway_instance/3","title":"AWS.MediaConnect.describe_gateway_instance/3","type":"function"},{"doc":"Displays the details of an offering.\n\nThe response includes the offering description, duration, outbound bandwidth,\nprice, and Amazon Resource Name (ARN).","ref":"AWS.MediaConnect.html#describe_offering/3","title":"AWS.MediaConnect.describe_offering/3","type":"function"},{"doc":"Displays the details of a reservation.\n\nThe response includes the reservation name, state, start date and time, and the\ndetails of the offering that make up the rest of the reservation (such as price,\nduration, and outbound bandwidth).","ref":"AWS.MediaConnect.html#describe_reservation/3","title":"AWS.MediaConnect.describe_reservation/3","type":"function"},{"doc":"Grants entitlements to an existing flow.","ref":"AWS.MediaConnect.html#grant_flow_entitlements/4","title":"AWS.MediaConnect.grant_flow_entitlements/4","type":"function"},{"doc":"Displays a list of bridges that are associated with this account and an\noptionally specified Arn.\n\nThis request returns a paginated result.","ref":"AWS.MediaConnect.html#list_bridges/5","title":"AWS.MediaConnect.list_bridges/5","type":"function"},{"doc":"Displays a list of all entitlements that have been granted to this account.\n\nThis request returns 20 results per page.","ref":"AWS.MediaConnect.html#list_entitlements/4","title":"AWS.MediaConnect.list_entitlements/4","type":"function"},{"doc":"Displays a list of flows that are associated with this account.\n\nThis request returns a paginated result.","ref":"AWS.MediaConnect.html#list_flows/4","title":"AWS.MediaConnect.list_flows/4","type":"function"},{"doc":"Displays a list of instances associated with the AWS account.\n\nThis request returns a paginated result. You can use the filterArn property to\ndisplay only the instances associated with the selected Gateway Amazon Resource\nName (ARN).","ref":"AWS.MediaConnect.html#list_gateway_instances/5","title":"AWS.MediaConnect.list_gateway_instances/5","type":"function"},{"doc":"Displays a list of gateways that are associated with this account.\n\nThis request returns a paginated result.","ref":"AWS.MediaConnect.html#list_gateways/4","title":"AWS.MediaConnect.list_gateways/4","type":"function"},{"doc":"Displays a list of all offerings that are available to this account in the\ncurrent AWS Region.\n\nIf you have an active reservation (which means you've purchased an offering that\nhas already started and hasn't expired yet), your account isn't eligible for\nother offerings.","ref":"AWS.MediaConnect.html#list_offerings/4","title":"AWS.MediaConnect.list_offerings/4","type":"function"},{"doc":"Displays a list of all reservations that have been purchased by this account in\nthe current AWS Region.\n\nThis list includes all reservations in all states (such as active and expired).","ref":"AWS.MediaConnect.html#list_reservations/4","title":"AWS.MediaConnect.list_reservations/4","type":"function"},{"doc":"List all tags on an AWS Elemental MediaConnect resource","ref":"AWS.MediaConnect.html#list_tags_for_resource/3","title":"AWS.MediaConnect.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.MediaConnect.html#metadata/0","title":"AWS.MediaConnect.metadata/0","type":"function"},{"doc":"Submits a request to purchase an offering.\n\nIf you already have an active reservation, you can't purchase another offering.","ref":"AWS.MediaConnect.html#purchase_offering/4","title":"AWS.MediaConnect.purchase_offering/4","type":"function"},{"doc":"Removes an output from a bridge.","ref":"AWS.MediaConnect.html#remove_bridge_output/5","title":"AWS.MediaConnect.remove_bridge_output/5","type":"function"},{"doc":"Removes a source from a bridge.","ref":"AWS.MediaConnect.html#remove_bridge_source/5","title":"AWS.MediaConnect.remove_bridge_source/5","type":"function"},{"doc":"Removes a media stream from a flow.\n\nThis action is only available if the media stream is not associated with a\nsource or output.","ref":"AWS.MediaConnect.html#remove_flow_media_stream/5","title":"AWS.MediaConnect.remove_flow_media_stream/5","type":"function"},{"doc":"Removes an output from an existing flow.\n\nThis request can be made only on an output that does not have an entitlement\nassociated with it. If the output has an entitlement, you must revoke the\nentitlement instead. When an entitlement is revoked from a flow, the service\nautomatically removes the associated output.","ref":"AWS.MediaConnect.html#remove_flow_output/5","title":"AWS.MediaConnect.remove_flow_output/5","type":"function"},{"doc":"Removes a source from an existing flow.\n\nThis request can be made only if there is more than one source on the flow.","ref":"AWS.MediaConnect.html#remove_flow_source/5","title":"AWS.MediaConnect.remove_flow_source/5","type":"function"},{"doc":"Removes a VPC Interface from an existing flow.\n\nThis request can be made only on a VPC interface that does not have a Source or\nOutput associated with it. If the VPC interface is referenced by a Source or\nOutput, you must first delete or update the Source or Output to no longer\nreference the VPC interface.","ref":"AWS.MediaConnect.html#remove_flow_vpc_interface/5","title":"AWS.MediaConnect.remove_flow_vpc_interface/5","type":"function"},{"doc":"Revokes an entitlement from a flow.\n\nOnce an entitlement is revoked, the content becomes unavailable to the\nsubscriber and the associated output is removed.","ref":"AWS.MediaConnect.html#revoke_flow_entitlement/5","title":"AWS.MediaConnect.revoke_flow_entitlement/5","type":"function"},{"doc":"Starts a flow.","ref":"AWS.MediaConnect.html#start_flow/4","title":"AWS.MediaConnect.start_flow/4","type":"function"},{"doc":"Stops a flow.","ref":"AWS.MediaConnect.html#stop_flow/4","title":"AWS.MediaConnect.stop_flow/4","type":"function"},{"doc":"Associates the specified tags to a resource with the specified resourceArn.\n\nIf existing tags on a resource are not specified in the request parameters, they\nare not changed. When a resource is deleted, the tags associated with that\nresource are deleted as well.","ref":"AWS.MediaConnect.html#tag_resource/4","title":"AWS.MediaConnect.tag_resource/4","type":"function"},{"doc":"Deletes specified tags from a resource.","ref":"AWS.MediaConnect.html#untag_resource/4","title":"AWS.MediaConnect.untag_resource/4","type":"function"},{"doc":"Updates the bridge","ref":"AWS.MediaConnect.html#update_bridge/4","title":"AWS.MediaConnect.update_bridge/4","type":"function"},{"doc":"Updates an existing bridge output.","ref":"AWS.MediaConnect.html#update_bridge_output/5","title":"AWS.MediaConnect.update_bridge_output/5","type":"function"},{"doc":"Updates an existing bridge source.","ref":"AWS.MediaConnect.html#update_bridge_source/5","title":"AWS.MediaConnect.update_bridge_source/5","type":"function"},{"doc":"Updates the bridge state","ref":"AWS.MediaConnect.html#update_bridge_state/4","title":"AWS.MediaConnect.update_bridge_state/4","type":"function"},{"doc":"Updates flow","ref":"AWS.MediaConnect.html#update_flow/4","title":"AWS.MediaConnect.update_flow/4","type":"function"},{"doc":"You can change an entitlement's description, subscribers, and encryption.\n\nIf you change the subscribers, the service will remove the outputs that are are\nused by the subscribers that are removed.","ref":"AWS.MediaConnect.html#update_flow_entitlement/5","title":"AWS.MediaConnect.update_flow_entitlement/5","type":"function"},{"doc":"Updates an existing media stream.","ref":"AWS.MediaConnect.html#update_flow_media_stream/5","title":"AWS.MediaConnect.update_flow_media_stream/5","type":"function"},{"doc":"Updates an existing flow output.","ref":"AWS.MediaConnect.html#update_flow_output/5","title":"AWS.MediaConnect.update_flow_output/5","type":"function"},{"doc":"Updates the source of a flow.","ref":"AWS.MediaConnect.html#update_flow_source/5","title":"AWS.MediaConnect.update_flow_source/5","type":"function"},{"doc":"Updates the configuration of an existing Gateway Instance.","ref":"AWS.MediaConnect.html#update_gateway_instance/4","title":"AWS.MediaConnect.update_gateway_instance/4","type":"function"},{"doc":"AWS Elemental MediaConvert","ref":"AWS.MediaConvert.html","title":"AWS.MediaConvert","type":"module"},{"doc":"Associates an AWS Certificate Manager (ACM) Amazon Resource Name (ARN) with AWS\nElemental MediaConvert.","ref":"AWS.MediaConvert.html#associate_certificate/3","title":"AWS.MediaConvert.associate_certificate/3","type":"function"},{"doc":"Permanently cancel a job.\n\nOnce you have canceled a job, you can't start it again.","ref":"AWS.MediaConvert.html#cancel_job/4","title":"AWS.MediaConvert.cancel_job/4","type":"function"},{"doc":"Create a new transcoding job.\n\nFor information about jobs and job settings, see the User Guide at\nhttp://docs.aws.amazon.com/mediaconvert/latest/ug/what-is.html","ref":"AWS.MediaConvert.html#create_job/3","title":"AWS.MediaConvert.create_job/3","type":"function"},{"doc":"Create a new job template.\n\nFor information about job templates see the User Guide at\nhttp://docs.aws.amazon.com/mediaconvert/latest/ug/what-is.html","ref":"AWS.MediaConvert.html#create_job_template/3","title":"AWS.MediaConvert.create_job_template/3","type":"function"},{"doc":"Create a new preset.\n\nFor information about job templates see the User Guide at\nhttp://docs.aws.amazon.com/mediaconvert/latest/ug/what-is.html","ref":"AWS.MediaConvert.html#create_preset/3","title":"AWS.MediaConvert.create_preset/3","type":"function"},{"doc":"Create a new transcoding queue.\n\nFor information about queues, see Working With Queues in the User Guide at\nhttps://docs.aws.amazon.com/mediaconvert/latest/ug/working-with-queues.html","ref":"AWS.MediaConvert.html#create_queue/3","title":"AWS.MediaConvert.create_queue/3","type":"function"},{"doc":"Permanently delete a job template you have created.","ref":"AWS.MediaConvert.html#delete_job_template/4","title":"AWS.MediaConvert.delete_job_template/4","type":"function"},{"doc":"Permanently delete a policy that you created.","ref":"AWS.MediaConvert.html#delete_policy/3","title":"AWS.MediaConvert.delete_policy/3","type":"function"},{"doc":"Permanently delete a preset you have created.","ref":"AWS.MediaConvert.html#delete_preset/4","title":"AWS.MediaConvert.delete_preset/4","type":"function"},{"doc":"Permanently delete a queue you have created.","ref":"AWS.MediaConvert.html#delete_queue/4","title":"AWS.MediaConvert.delete_queue/4","type":"function"},{"doc":"Send an request with an empty body to the regional API endpoint to get your\naccount API endpoint.","ref":"AWS.MediaConvert.html#describe_endpoints/3","title":"AWS.MediaConvert.describe_endpoints/3","type":"function"},{"doc":"Removes an association between the Amazon Resource Name (ARN) of an AWS\nCertificate Manager (ACM) certificate and an AWS Elemental MediaConvert\nresource.","ref":"AWS.MediaConvert.html#disassociate_certificate/4","title":"AWS.MediaConvert.disassociate_certificate/4","type":"function"},{"doc":"Retrieve the JSON for a specific transcoding job.","ref":"AWS.MediaConvert.html#get_job/3","title":"AWS.MediaConvert.get_job/3","type":"function"},{"doc":"Retrieve the JSON for a specific job template.","ref":"AWS.MediaConvert.html#get_job_template/3","title":"AWS.MediaConvert.get_job_template/3","type":"function"},{"doc":"Retrieve the JSON for your policy.","ref":"AWS.MediaConvert.html#get_policy/2","title":"AWS.MediaConvert.get_policy/2","type":"function"},{"doc":"Retrieve the JSON for a specific preset.","ref":"AWS.MediaConvert.html#get_preset/3","title":"AWS.MediaConvert.get_preset/3","type":"function"},{"doc":"Retrieve the JSON for a specific queue.","ref":"AWS.MediaConvert.html#get_queue/3","title":"AWS.MediaConvert.get_queue/3","type":"function"},{"doc":"Retrieve a JSON array of up to twenty of your job templates.\n\nThis will return the templates themselves, not just a list of them. To retrieve\nthe next twenty templates, use the nextToken string returned with the array","ref":"AWS.MediaConvert.html#list_job_templates/7","title":"AWS.MediaConvert.list_job_templates/7","type":"function"},{"doc":"Retrieve a JSON array of up to twenty of your most recently created jobs.\n\nThis array includes in-process, completed, and errored jobs. This will return\nthe jobs themselves, not just a list of the jobs. To retrieve the twenty next\nmost recent jobs, use the nextToken string returned with the array.","ref":"AWS.MediaConvert.html#list_jobs/7","title":"AWS.MediaConvert.list_jobs/7","type":"function"},{"doc":"Retrieve a JSON array of up to twenty of your presets.\n\nThis will return the presets themselves, not just a list of them. To retrieve\nthe next twenty presets, use the nextToken string returned with the array.","ref":"AWS.MediaConvert.html#list_presets/7","title":"AWS.MediaConvert.list_presets/7","type":"function"},{"doc":"Retrieve a JSON array of up to twenty of your queues.\n\nThis will return the queues themselves, not just a list of them. To retrieve the\nnext twenty queues, use the nextToken string returned with the array.","ref":"AWS.MediaConvert.html#list_queues/6","title":"AWS.MediaConvert.list_queues/6","type":"function"},{"doc":"Retrieve the tags for a MediaConvert resource.","ref":"AWS.MediaConvert.html#list_tags_for_resource/3","title":"AWS.MediaConvert.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.MediaConvert.html#metadata/0","title":"AWS.MediaConvert.metadata/0","type":"function"},{"doc":"Create or change your policy.\n\nFor more information about policies, see the user guide at\nhttp://docs.aws.amazon.com/mediaconvert/latest/ug/what-is.html","ref":"AWS.MediaConvert.html#put_policy/3","title":"AWS.MediaConvert.put_policy/3","type":"function"},{"doc":"Add tags to a MediaConvert queue, preset, or job template.\n\nFor information about tagging, see the User Guide at\nhttps://docs.aws.amazon.com/mediaconvert/latest/ug/tagging-resources.html","ref":"AWS.MediaConvert.html#tag_resource/3","title":"AWS.MediaConvert.tag_resource/3","type":"function"},{"doc":"Remove tags from a MediaConvert queue, preset, or job template.\n\nFor information about tagging, see the User Guide at\nhttps://docs.aws.amazon.com/mediaconvert/latest/ug/tagging-resources.html","ref":"AWS.MediaConvert.html#untag_resource/4","title":"AWS.MediaConvert.untag_resource/4","type":"function"},{"doc":"Modify one of your existing job templates.","ref":"AWS.MediaConvert.html#update_job_template/4","title":"AWS.MediaConvert.update_job_template/4","type":"function"},{"doc":"Modify one of your existing presets.","ref":"AWS.MediaConvert.html#update_preset/4","title":"AWS.MediaConvert.update_preset/4","type":"function"},{"doc":"Modify one of your existing queues.","ref":"AWS.MediaConvert.html#update_queue/4","title":"AWS.MediaConvert.update_queue/4","type":"function"},{"doc":"API for AWS Elemental MediaLive","ref":"AWS.MediaLive.html","title":"AWS.MediaLive","type":"module"},{"doc":"Accept an incoming input device transfer.\n\nThe ownership of the device will transfer to your AWS account.","ref":"AWS.MediaLive.html#accept_input_device_transfer/4","title":"AWS.MediaLive.accept_input_device_transfer/4","type":"function"},{"doc":"Starts delete of resources.","ref":"AWS.MediaLive.html#batch_delete/3","title":"AWS.MediaLive.batch_delete/3","type":"function"},{"doc":"Starts existing resources","ref":"AWS.MediaLive.html#batch_start/3","title":"AWS.MediaLive.batch_start/3","type":"function"},{"doc":"Stops running resources","ref":"AWS.MediaLive.html#batch_stop/3","title":"AWS.MediaLive.batch_stop/3","type":"function"},{"doc":"Update a channel schedule","ref":"AWS.MediaLive.html#batch_update_schedule/4","title":"AWS.MediaLive.batch_update_schedule/4","type":"function"},{"doc":"Cancel an input device transfer that you have requested.","ref":"AWS.MediaLive.html#cancel_input_device_transfer/4","title":"AWS.MediaLive.cancel_input_device_transfer/4","type":"function"},{"doc":"Send a request to claim an AWS Elemental device that you have purchased from a\nthird-party vendor.\n\nAfter the request succeeds, you will own the device.","ref":"AWS.MediaLive.html#claim_device/3","title":"AWS.MediaLive.claim_device/3","type":"function"},{"doc":"Creates a new channel","ref":"AWS.MediaLive.html#create_channel/3","title":"AWS.MediaLive.create_channel/3","type":"function"},{"doc":"Create an input","ref":"AWS.MediaLive.html#create_input/3","title":"AWS.MediaLive.create_input/3","type":"function"},{"doc":"Creates a Input Security Group","ref":"AWS.MediaLive.html#create_input_security_group/3","title":"AWS.MediaLive.create_input_security_group/3","type":"function"},{"doc":"Create a new multiplex.","ref":"AWS.MediaLive.html#create_multiplex/3","title":"AWS.MediaLive.create_multiplex/3","type":"function"},{"doc":"Create a new program in the multiplex.","ref":"AWS.MediaLive.html#create_multiplex_program/4","title":"AWS.MediaLive.create_multiplex_program/4","type":"function"},{"doc":"Create a partner input","ref":"AWS.MediaLive.html#create_partner_input/4","title":"AWS.MediaLive.create_partner_input/4","type":"function"},{"doc":"Create tags for a resource","ref":"AWS.MediaLive.html#create_tags/4","title":"AWS.MediaLive.create_tags/4","type":"function"},{"doc":"Starts deletion of channel.\n\nThe associated outputs are also deleted.","ref":"AWS.MediaLive.html#delete_channel/4","title":"AWS.MediaLive.delete_channel/4","type":"function"},{"doc":"Deletes the input end point","ref":"AWS.MediaLive.html#delete_input/4","title":"AWS.MediaLive.delete_input/4","type":"function"},{"doc":"Deletes an Input Security Group","ref":"AWS.MediaLive.html#delete_input_security_group/4","title":"AWS.MediaLive.delete_input_security_group/4","type":"function"},{"doc":"Delete a multiplex.\n\nThe multiplex must be idle.","ref":"AWS.MediaLive.html#delete_multiplex/4","title":"AWS.MediaLive.delete_multiplex/4","type":"function"},{"doc":"Delete a program from a multiplex.","ref":"AWS.MediaLive.html#delete_multiplex_program/5","title":"AWS.MediaLive.delete_multiplex_program/5","type":"function"},{"doc":"Delete an expired reservation.","ref":"AWS.MediaLive.html#delete_reservation/4","title":"AWS.MediaLive.delete_reservation/4","type":"function"},{"doc":"Delete all schedule actions on a channel.","ref":"AWS.MediaLive.html#delete_schedule/4","title":"AWS.MediaLive.delete_schedule/4","type":"function"},{"doc":"Removes tags for a resource","ref":"AWS.MediaLive.html#delete_tags/4","title":"AWS.MediaLive.delete_tags/4","type":"function"},{"doc":"Describe account configuration","ref":"AWS.MediaLive.html#describe_account_configuration/2","title":"AWS.MediaLive.describe_account_configuration/2","type":"function"},{"doc":"Gets details about a channel","ref":"AWS.MediaLive.html#describe_channel/3","title":"AWS.MediaLive.describe_channel/3","type":"function"},{"doc":"Produces details about an input","ref":"AWS.MediaLive.html#describe_input/3","title":"AWS.MediaLive.describe_input/3","type":"function"},{"doc":"Gets the details for the input device","ref":"AWS.MediaLive.html#describe_input_device/3","title":"AWS.MediaLive.describe_input_device/3","type":"function"},{"doc":"Get the latest thumbnail data for the input device.","ref":"AWS.MediaLive.html#describe_input_device_thumbnail/4","title":"AWS.MediaLive.describe_input_device_thumbnail/4","type":"function"},{"doc":"Produces a summary of an Input Security Group","ref":"AWS.MediaLive.html#describe_input_security_group/3","title":"AWS.MediaLive.describe_input_security_group/3","type":"function"},{"doc":"Gets details about a multiplex.","ref":"AWS.MediaLive.html#describe_multiplex/3","title":"AWS.MediaLive.describe_multiplex/3","type":"function"},{"doc":"Get the details for a program in a multiplex.","ref":"AWS.MediaLive.html#describe_multiplex_program/4","title":"AWS.MediaLive.describe_multiplex_program/4","type":"function"},{"doc":"Get details for an offering.","ref":"AWS.MediaLive.html#describe_offering/3","title":"AWS.MediaLive.describe_offering/3","type":"function"},{"doc":"Get details for a reservation.","ref":"AWS.MediaLive.html#describe_reservation/3","title":"AWS.MediaLive.describe_reservation/3","type":"function"},{"doc":"Get a channel schedule","ref":"AWS.MediaLive.html#describe_schedule/5","title":"AWS.MediaLive.describe_schedule/5","type":"function"},{"doc":"Describe the latest thumbnails data.","ref":"AWS.MediaLive.html#describe_thumbnails/5","title":"AWS.MediaLive.describe_thumbnails/5","type":"function"},{"doc":"Produces list of channels that have been created","ref":"AWS.MediaLive.html#list_channels/4","title":"AWS.MediaLive.list_channels/4","type":"function"},{"doc":"List input devices that are currently being transferred.\n\nList input devices that you are transferring from your AWS account or input\ndevices that another AWS account is transferring to you.","ref":"AWS.MediaLive.html#list_input_device_transfers/5","title":"AWS.MediaLive.list_input_device_transfers/5","type":"function"},{"doc":"List input devices","ref":"AWS.MediaLive.html#list_input_devices/4","title":"AWS.MediaLive.list_input_devices/4","type":"function"},{"doc":"Produces a list of Input Security Groups for an account","ref":"AWS.MediaLive.html#list_input_security_groups/4","title":"AWS.MediaLive.list_input_security_groups/4","type":"function"},{"doc":"Produces list of inputs that have been created","ref":"AWS.MediaLive.html#list_inputs/4","title":"AWS.MediaLive.list_inputs/4","type":"function"},{"doc":"List the programs that currently exist for a specific multiplex.","ref":"AWS.MediaLive.html#list_multiplex_programs/5","title":"AWS.MediaLive.list_multiplex_programs/5","type":"function"},{"doc":"Retrieve a list of the existing multiplexes.","ref":"AWS.MediaLive.html#list_multiplexes/4","title":"AWS.MediaLive.list_multiplexes/4","type":"function"},{"doc":"List offerings available for purchase.","ref":"AWS.MediaLive.html#list_offerings/14","title":"AWS.MediaLive.list_offerings/14","type":"function"},{"doc":"List purchased reservations.","ref":"AWS.MediaLive.html#list_reservations/12","title":"AWS.MediaLive.list_reservations/12","type":"function"},{"doc":"Produces list of tags that have been created for a resource","ref":"AWS.MediaLive.html#list_tags_for_resource/3","title":"AWS.MediaLive.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.MediaLive.html#metadata/0","title":"AWS.MediaLive.metadata/0","type":"function"},{"doc":"Purchase an offering and create a reservation.","ref":"AWS.MediaLive.html#purchase_offering/4","title":"AWS.MediaLive.purchase_offering/4","type":"function"},{"doc":"Send a reboot command to the specified input device.\n\nThe device will begin rebooting within a few seconds of sending the command.\nWhen the reboot is complete, the device’s connection status will change to\nconnected.","ref":"AWS.MediaLive.html#reboot_input_device/4","title":"AWS.MediaLive.reboot_input_device/4","type":"function"},{"doc":"Reject the transfer of the specified input device to your AWS account.","ref":"AWS.MediaLive.html#reject_input_device_transfer/4","title":"AWS.MediaLive.reject_input_device_transfer/4","type":"function"},{"doc":"Starts an existing channel","ref":"AWS.MediaLive.html#start_channel/4","title":"AWS.MediaLive.start_channel/4","type":"function"},{"doc":"Start an input device that is attached to a MediaConnect flow.\n\n(There is no need to start a device that is attached to a MediaLive input;\nMediaLive starts the device when the channel starts.)","ref":"AWS.MediaLive.html#start_input_device/4","title":"AWS.MediaLive.start_input_device/4","type":"function"},{"doc":"Start a maintenance window for the specified input device.\n\nStarting a maintenance window will give the device up to two hours to install\nsoftware. If the device was streaming prior to the maintenance, it will resume\nstreaming when the software is fully installed. Devices automatically install\nupdates while they are powered on and their MediaLive channels are stopped. A\nmaintenance window allows you to update a device without having to stop\nMediaLive channels that use the device. The device must remain powered on and\nconnected to the internet for the duration of the maintenance.","ref":"AWS.MediaLive.html#start_input_device_maintenance_window/4","title":"AWS.MediaLive.start_input_device_maintenance_window/4","type":"function"},{"doc":"Start (run) the multiplex.\n\nStarting the multiplex does not start the channels. You must explicitly start\neach channel.","ref":"AWS.MediaLive.html#start_multiplex/4","title":"AWS.MediaLive.start_multiplex/4","type":"function"},{"doc":"Stops a running channel","ref":"AWS.MediaLive.html#stop_channel/4","title":"AWS.MediaLive.stop_channel/4","type":"function"},{"doc":"Stop an input device that is attached to a MediaConnect flow.\n\n(There is no need to stop a device that is attached to a MediaLive input;\nMediaLive automatically stops the device when the channel stops.)","ref":"AWS.MediaLive.html#stop_input_device/4","title":"AWS.MediaLive.stop_input_device/4","type":"function"},{"doc":"Stops a running multiplex.\n\nIf the multiplex isn't running, this action has no effect.","ref":"AWS.MediaLive.html#stop_multiplex/4","title":"AWS.MediaLive.stop_multiplex/4","type":"function"},{"doc":"Start an input device transfer to another AWS account.\n\nAfter you make the request, the other account must accept or reject the\ntransfer.","ref":"AWS.MediaLive.html#transfer_input_device/4","title":"AWS.MediaLive.transfer_input_device/4","type":"function"},{"doc":"Update account configuration","ref":"AWS.MediaLive.html#update_account_configuration/3","title":"AWS.MediaLive.update_account_configuration/3","type":"function"},{"doc":"Updates a channel.","ref":"AWS.MediaLive.html#update_channel/4","title":"AWS.MediaLive.update_channel/4","type":"function"},{"doc":"Changes the class of the channel.","ref":"AWS.MediaLive.html#update_channel_class/4","title":"AWS.MediaLive.update_channel_class/4","type":"function"},{"doc":"Updates an input.","ref":"AWS.MediaLive.html#update_input/4","title":"AWS.MediaLive.update_input/4","type":"function"},{"doc":"Updates the parameters for the input device.","ref":"AWS.MediaLive.html#update_input_device/4","title":"AWS.MediaLive.update_input_device/4","type":"function"},{"doc":"Update an Input Security Group's Whilelists.","ref":"AWS.MediaLive.html#update_input_security_group/4","title":"AWS.MediaLive.update_input_security_group/4","type":"function"},{"doc":"Updates a multiplex.","ref":"AWS.MediaLive.html#update_multiplex/4","title":"AWS.MediaLive.update_multiplex/4","type":"function"},{"doc":"Update a program in a multiplex.","ref":"AWS.MediaLive.html#update_multiplex_program/5","title":"AWS.MediaLive.update_multiplex_program/5","type":"function"},{"doc":"Update reservation.","ref":"AWS.MediaLive.html#update_reservation/4","title":"AWS.MediaLive.update_reservation/4","type":"function"},{"doc":"AWS Elemental MediaPackage","ref":"AWS.MediaPackage.html","title":"AWS.MediaPackage","type":"module"},{"doc":"Changes the Channel's properities to configure log subscription","ref":"AWS.MediaPackage.html#configure_logs/4","title":"AWS.MediaPackage.configure_logs/4","type":"function"},{"doc":"Creates a new Channel.","ref":"AWS.MediaPackage.html#create_channel/3","title":"AWS.MediaPackage.create_channel/3","type":"function"},{"doc":"Creates a new HarvestJob record.","ref":"AWS.MediaPackage.html#create_harvest_job/3","title":"AWS.MediaPackage.create_harvest_job/3","type":"function"},{"doc":"Creates a new OriginEndpoint record.","ref":"AWS.MediaPackage.html#create_origin_endpoint/3","title":"AWS.MediaPackage.create_origin_endpoint/3","type":"function"},{"doc":"Deletes an existing Channel.","ref":"AWS.MediaPackage.html#delete_channel/4","title":"AWS.MediaPackage.delete_channel/4","type":"function"},{"doc":"Deletes an existing OriginEndpoint.","ref":"AWS.MediaPackage.html#delete_origin_endpoint/4","title":"AWS.MediaPackage.delete_origin_endpoint/4","type":"function"},{"doc":"Gets details about a Channel.","ref":"AWS.MediaPackage.html#describe_channel/3","title":"AWS.MediaPackage.describe_channel/3","type":"function"},{"doc":"Gets details about an existing HarvestJob.","ref":"AWS.MediaPackage.html#describe_harvest_job/3","title":"AWS.MediaPackage.describe_harvest_job/3","type":"function"},{"doc":"Gets details about an existing OriginEndpoint.","ref":"AWS.MediaPackage.html#describe_origin_endpoint/3","title":"AWS.MediaPackage.describe_origin_endpoint/3","type":"function"},{"doc":"Returns a collection of Channels.","ref":"AWS.MediaPackage.html#list_channels/4","title":"AWS.MediaPackage.list_channels/4","type":"function"},{"doc":"Returns a collection of HarvestJob records.","ref":"AWS.MediaPackage.html#list_harvest_jobs/6","title":"AWS.MediaPackage.list_harvest_jobs/6","type":"function"},{"doc":"Returns a collection of OriginEndpoint records.","ref":"AWS.MediaPackage.html#list_origin_endpoints/5","title":"AWS.MediaPackage.list_origin_endpoints/5","type":"function"},{"doc":"","ref":"AWS.MediaPackage.html#list_tags_for_resource/3","title":"AWS.MediaPackage.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.MediaPackage.html#metadata/0","title":"AWS.MediaPackage.metadata/0","type":"function"},{"doc":"Changes the Channel's first IngestEndpoint's username and password.\n\nWARNING - This API is deprecated. Please use RotateIngestEndpointCredentials\ninstead","ref":"AWS.MediaPackage.html#rotate_channel_credentials/4","title":"AWS.MediaPackage.rotate_channel_credentials/4","type":"function"},{"doc":"Rotate the IngestEndpoint's username and password, as specified by the\nIngestEndpoint's id.","ref":"AWS.MediaPackage.html#rotate_ingest_endpoint_credentials/5","title":"AWS.MediaPackage.rotate_ingest_endpoint_credentials/5","type":"function"},{"doc":"","ref":"AWS.MediaPackage.html#tag_resource/4","title":"AWS.MediaPackage.tag_resource/4","type":"function"},{"doc":"","ref":"AWS.MediaPackage.html#untag_resource/4","title":"AWS.MediaPackage.untag_resource/4","type":"function"},{"doc":"Updates an existing Channel.","ref":"AWS.MediaPackage.html#update_channel/4","title":"AWS.MediaPackage.update_channel/4","type":"function"},{"doc":"Updates an existing OriginEndpoint.","ref":"AWS.MediaPackage.html#update_origin_endpoint/4","title":"AWS.MediaPackage.update_origin_endpoint/4","type":"function"},{"doc":"This guide is intended for creating AWS Elemental MediaPackage resources in\nMediaPackage Version 2 (v2) starting from May 2023.\n\nTo get started with MediaPackage v2, create your MediaPackage resources. There\nisn't an automated process to migrate your resources from MediaPackage v1 to\nMediaPackage v2.\n\nThe names of the entities that you use to access this API, like URLs and ARNs,\nall have the versioning information added, like \"v2\", to distinguish from the\nprior version. If you used MediaPackage prior to this release, you can't use the\nMediaPackage v2 CLI or the MediaPackage v2 API to access any MediaPackage v1\nresources.\n\nIf you created resources in MediaPackage v1, use video on demand (VOD)\nworkflows, and aren't looking to migrate to MediaPackage v2 yet, see the\n[MediaPackage v1 Live API Reference](https://docs.aws.amazon.com/mediapackage/latest/apireference/what-is.html).\n\nThis is the AWS Elemental MediaPackage v2 Live REST API Reference. It describes\nall the MediaPackage API operations for live content in detail, and provides\nsample requests, responses, and errors for the supported web services protocols.\n\nWe assume that you have the IAM permissions that you need to use MediaPackage\nvia the REST API. We also assume that you are familiar with the features and\noperations of MediaPackage, as described in the AWS Elemental MediaPackage User\nGuide.","ref":"AWS.MediaPackageV2.html","title":"AWS.MediaPackageV2","type":"module"},{"doc":"Create a channel to start receiving content streams.\n\nThe channel represents the input to MediaPackage for incoming live content from\nan encoder such as AWS Elemental MediaLive. The channel receives content, and\nafter packaging it, outputs it through an origin endpoint to downstream devices\n(such as video players or CDNs) that request the content. You can create only\none channel with each request. We recommend that you spread out channels between\nchannel groups, such as putting redundant channels in the same AWS Region in\ndifferent channel groups.","ref":"AWS.MediaPackageV2.html#create_channel/4","title":"AWS.MediaPackageV2.create_channel/4","type":"function"},{"doc":"Create a channel group to group your channels and origin endpoints.\n\nA channel group is the top-level resource that consists of channels and origin\nendpoints that are associated with it and that provides predictable URLs for\nstream delivery. All channels and origin endpoints within the channel group are\nguaranteed to share the DNS. You can create only one channel group with each\nrequest.","ref":"AWS.MediaPackageV2.html#create_channel_group/3","title":"AWS.MediaPackageV2.create_channel_group/3","type":"function"},{"doc":"The endpoint is attached to a channel, and represents the output of the live\ncontent.\n\nYou can associate multiple endpoints to a single channel. Each endpoint gives\nplayers and downstream CDNs (such as Amazon CloudFront) access to the content\nfor playback. Content can't be served from a channel until it has an endpoint.\nYou can create only one endpoint with each request.","ref":"AWS.MediaPackageV2.html#create_origin_endpoint/5","title":"AWS.MediaPackageV2.create_origin_endpoint/5","type":"function"},{"doc":"Delete a channel to stop AWS Elemental MediaPackage from receiving further\ncontent.\n\nYou must delete the channel's origin endpoints before you can delete the\nchannel.","ref":"AWS.MediaPackageV2.html#delete_channel/5","title":"AWS.MediaPackageV2.delete_channel/5","type":"function"},{"doc":"Delete a channel group.\n\nYou must delete the channel group's channels and origin endpoints before you can\ndelete the channel group. If you delete a channel group, you'll lose access to\nthe egress domain and will have to create a new channel group to replace it.","ref":"AWS.MediaPackageV2.html#delete_channel_group/4","title":"AWS.MediaPackageV2.delete_channel_group/4","type":"function"},{"doc":"Delete a channel policy.","ref":"AWS.MediaPackageV2.html#delete_channel_policy/5","title":"AWS.MediaPackageV2.delete_channel_policy/5","type":"function"},{"doc":"Origin endpoints can serve content until they're deleted.\n\nDelete the endpoint if it should no longer respond to playback requests. You\nmust delete all endpoints from a channel before you can delete the channel.","ref":"AWS.MediaPackageV2.html#delete_origin_endpoint/6","title":"AWS.MediaPackageV2.delete_origin_endpoint/6","type":"function"},{"doc":"Delete an origin endpoint policy.","ref":"AWS.MediaPackageV2.html#delete_origin_endpoint_policy/6","title":"AWS.MediaPackageV2.delete_origin_endpoint_policy/6","type":"function"},{"doc":"Retrieves the specified channel that's configured in AWS Elemental MediaPackage,\nincluding the origin endpoints that are associated with it.","ref":"AWS.MediaPackageV2.html#get_channel/4","title":"AWS.MediaPackageV2.get_channel/4","type":"function"},{"doc":"Retrieves the specified channel group that's configured in AWS Elemental\nMediaPackage, including the channels and origin endpoints that are associated\nwith it.","ref":"AWS.MediaPackageV2.html#get_channel_group/3","title":"AWS.MediaPackageV2.get_channel_group/3","type":"function"},{"doc":"Retrieves the specified channel policy that's configured in AWS Elemental\nMediaPackage.\n\nWith policies, you can specify who has access to AWS resources and what actions\nthey can perform on those resources.","ref":"AWS.MediaPackageV2.html#get_channel_policy/4","title":"AWS.MediaPackageV2.get_channel_policy/4","type":"function"},{"doc":"Retrieves the specified origin endpoint that's configured in AWS Elemental\nMediaPackage to obtain its playback URL and to view the packaging settings that\nit's currently using.","ref":"AWS.MediaPackageV2.html#get_origin_endpoint/5","title":"AWS.MediaPackageV2.get_origin_endpoint/5","type":"function"},{"doc":"Retrieves the specified origin endpoint policy that's configured in AWS\nElemental MediaPackage.","ref":"AWS.MediaPackageV2.html#get_origin_endpoint_policy/5","title":"AWS.MediaPackageV2.get_origin_endpoint_policy/5","type":"function"},{"doc":"Retrieves all channel groups that are configured in AWS Elemental MediaPackage,\nincluding the channels and origin endpoints that are associated with it.","ref":"AWS.MediaPackageV2.html#list_channel_groups/4","title":"AWS.MediaPackageV2.list_channel_groups/4","type":"function"},{"doc":"Retrieves all channels in a specific channel group that are configured in AWS\nElemental MediaPackage, including the origin endpoints that are associated with\nit.","ref":"AWS.MediaPackageV2.html#list_channels/5","title":"AWS.MediaPackageV2.list_channels/5","type":"function"},{"doc":"Retrieves all origin endpoints in a specific channel that are configured in AWS\nElemental MediaPackage.","ref":"AWS.MediaPackageV2.html#list_origin_endpoints/6","title":"AWS.MediaPackageV2.list_origin_endpoints/6","type":"function"},{"doc":"Lists the tags assigned to a resource.","ref":"AWS.MediaPackageV2.html#list_tags_for_resource/3","title":"AWS.MediaPackageV2.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.MediaPackageV2.html#metadata/0","title":"AWS.MediaPackageV2.metadata/0","type":"function"},{"doc":"Attaches an IAM policy to the specified channel.\n\nWith policies, you can specify who has access to AWS resources and what actions\nthey can perform on those resources. You can attach only one policy with each\nrequest.","ref":"AWS.MediaPackageV2.html#put_channel_policy/5","title":"AWS.MediaPackageV2.put_channel_policy/5","type":"function"},{"doc":"Attaches an IAM policy to the specified origin endpoint.\n\nYou can attach only one policy with each request.","ref":"AWS.MediaPackageV2.html#put_origin_endpoint_policy/6","title":"AWS.MediaPackageV2.put_origin_endpoint_policy/6","type":"function"},{"doc":"Assigns one of more tags (key-value pairs) to the specified MediaPackage\nresource.\n\nTags can help you organize and categorize your resources. You can also use them\nto scope user permissions, by granting a user permission to access or change\nonly resources with certain tag values. You can use the TagResource operation\nwith a resource that already has tags. If you specify a new tag key for the\nresource, this tag is appended to the list of tags associated with the resource.\nIf you specify a tag key that is already associated with the resource, the new\ntag value that you specify replaces the previous value for that tag.","ref":"AWS.MediaPackageV2.html#tag_resource/4","title":"AWS.MediaPackageV2.tag_resource/4","type":"function"},{"doc":"Removes one or more tags from the specified resource.","ref":"AWS.MediaPackageV2.html#untag_resource/4","title":"AWS.MediaPackageV2.untag_resource/4","type":"function"},{"doc":"Update the specified channel.\n\nYou can edit if MediaPackage sends ingest or egress access logs to the\nCloudWatch log group, if content will be encrypted, the description on a\nchannel, and your channel's policy settings. You can't edit the name of the\nchannel or CloudFront distribution details.\n\nAny edits you make that impact the video output may not be reflected for a few\nminutes.","ref":"AWS.MediaPackageV2.html#update_channel/5","title":"AWS.MediaPackageV2.update_channel/5","type":"function"},{"doc":"Update the specified channel group.\n\nYou can edit the description on a channel group for easier identification later\nfrom the AWS Elemental MediaPackage console. You can't edit the name of the\nchannel group.\n\nAny edits you make that impact the video output may not be reflected for a few\nminutes.","ref":"AWS.MediaPackageV2.html#update_channel_group/4","title":"AWS.MediaPackageV2.update_channel_group/4","type":"function"},{"doc":"Update the specified origin endpoint.\n\nEdit the packaging preferences on an endpoint to optimize the viewing\nexperience. You can't edit the name of the endpoint.\n\nAny edits you make that impact the video output may not be reflected for a few\nminutes.","ref":"AWS.MediaPackageV2.html#update_origin_endpoint/6","title":"AWS.MediaPackageV2.update_origin_endpoint/6","type":"function"},{"doc":"AWS Elemental MediaPackage VOD","ref":"AWS.MediaPackageVod.html","title":"AWS.MediaPackageVod","type":"module"},{"doc":"Changes the packaging group's properities to configure log subscription","ref":"AWS.MediaPackageVod.html#configure_logs/4","title":"AWS.MediaPackageVod.configure_logs/4","type":"function"},{"doc":"Creates a new MediaPackage VOD Asset resource.","ref":"AWS.MediaPackageVod.html#create_asset/3","title":"AWS.MediaPackageVod.create_asset/3","type":"function"},{"doc":"Creates a new MediaPackage VOD PackagingConfiguration resource.","ref":"AWS.MediaPackageVod.html#create_packaging_configuration/3","title":"AWS.MediaPackageVod.create_packaging_configuration/3","type":"function"},{"doc":"Creates a new MediaPackage VOD PackagingGroup resource.","ref":"AWS.MediaPackageVod.html#create_packaging_group/3","title":"AWS.MediaPackageVod.create_packaging_group/3","type":"function"},{"doc":"Deletes an existing MediaPackage VOD Asset resource.","ref":"AWS.MediaPackageVod.html#delete_asset/4","title":"AWS.MediaPackageVod.delete_asset/4","type":"function"},{"doc":"Deletes a MediaPackage VOD PackagingConfiguration resource.","ref":"AWS.MediaPackageVod.html#delete_packaging_configuration/4","title":"AWS.MediaPackageVod.delete_packaging_configuration/4","type":"function"},{"doc":"Deletes a MediaPackage VOD PackagingGroup resource.","ref":"AWS.MediaPackageVod.html#delete_packaging_group/4","title":"AWS.MediaPackageVod.delete_packaging_group/4","type":"function"},{"doc":"Returns a description of a MediaPackage VOD Asset resource.","ref":"AWS.MediaPackageVod.html#describe_asset/3","title":"AWS.MediaPackageVod.describe_asset/3","type":"function"},{"doc":"Returns a description of a MediaPackage VOD PackagingConfiguration resource.","ref":"AWS.MediaPackageVod.html#describe_packaging_configuration/3","title":"AWS.MediaPackageVod.describe_packaging_configuration/3","type":"function"},{"doc":"Returns a description of a MediaPackage VOD PackagingGroup resource.","ref":"AWS.MediaPackageVod.html#describe_packaging_group/3","title":"AWS.MediaPackageVod.describe_packaging_group/3","type":"function"},{"doc":"Returns a collection of MediaPackage VOD Asset resources.","ref":"AWS.MediaPackageVod.html#list_assets/5","title":"AWS.MediaPackageVod.list_assets/5","type":"function"},{"doc":"Returns a collection of MediaPackage VOD PackagingConfiguration resources.","ref":"AWS.MediaPackageVod.html#list_packaging_configurations/5","title":"AWS.MediaPackageVod.list_packaging_configurations/5","type":"function"},{"doc":"Returns a collection of MediaPackage VOD PackagingGroup resources.","ref":"AWS.MediaPackageVod.html#list_packaging_groups/4","title":"AWS.MediaPackageVod.list_packaging_groups/4","type":"function"},{"doc":"Returns a list of the tags assigned to the specified resource.","ref":"AWS.MediaPackageVod.html#list_tags_for_resource/3","title":"AWS.MediaPackageVod.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.MediaPackageVod.html#metadata/0","title":"AWS.MediaPackageVod.metadata/0","type":"function"},{"doc":"Adds tags to the specified resource.\n\nYou can specify one or more tags to add.","ref":"AWS.MediaPackageVod.html#tag_resource/4","title":"AWS.MediaPackageVod.tag_resource/4","type":"function"},{"doc":"Removes tags from the specified resource.\n\nYou can specify one or more tags to remove.","ref":"AWS.MediaPackageVod.html#untag_resource/4","title":"AWS.MediaPackageVod.untag_resource/4","type":"function"},{"doc":"Updates a specific packaging group.\n\nYou can't change the id attribute or any other system-generated attributes.","ref":"AWS.MediaPackageVod.html#update_packaging_group/4","title":"AWS.MediaPackageVod.update_packaging_group/4","type":"function"},{"doc":"An AWS Elemental MediaStore container is a namespace that holds folders and\nobjects.\n\nYou use a container endpoint to create, read, and delete objects.","ref":"AWS.MediaStore.html","title":"AWS.MediaStore","type":"module"},{"doc":"Creates a storage container to hold objects.\n\nA container is similar to a bucket in the Amazon S3 service.","ref":"AWS.MediaStore.html#create_container/3","title":"AWS.MediaStore.create_container/3","type":"function"},{"doc":"Deletes the specified container.\n\nBefore you make a `DeleteContainer` request, delete any objects in the container\nor in any folders in the container. You can delete only empty containers.","ref":"AWS.MediaStore.html#delete_container/3","title":"AWS.MediaStore.delete_container/3","type":"function"},{"doc":"Deletes the access policy that is associated with the specified container.","ref":"AWS.MediaStore.html#delete_container_policy/3","title":"AWS.MediaStore.delete_container_policy/3","type":"function"},{"doc":"Deletes the cross-origin resource sharing (CORS) configuration information that\nis set for the container.\n\nTo use this operation, you must have permission to perform the\n`MediaStore:DeleteCorsPolicy` action. The container owner has this permission by\ndefault and can grant this permission to others.","ref":"AWS.MediaStore.html#delete_cors_policy/3","title":"AWS.MediaStore.delete_cors_policy/3","type":"function"},{"doc":"Removes an object lifecycle policy from a container.\n\nIt takes up to 20 minutes for the change to take effect.","ref":"AWS.MediaStore.html#delete_lifecycle_policy/3","title":"AWS.MediaStore.delete_lifecycle_policy/3","type":"function"},{"doc":"Deletes the metric policy that is associated with the specified container.\n\nIf there is no metric policy associated with the container, MediaStore doesn't\nsend metrics to CloudWatch.","ref":"AWS.MediaStore.html#delete_metric_policy/3","title":"AWS.MediaStore.delete_metric_policy/3","type":"function"},{"doc":"Retrieves the properties of the requested container.\n\nThis request is commonly used to retrieve the endpoint of a container. An\nendpoint is a value assigned by the service when a new container is created. A\ncontainer's endpoint does not change after it has been assigned. The\n`DescribeContainer` request returns a single `Container` object based on\n`ContainerName`. To return all `Container` objects that are associated with a\nspecified AWS account, use `ListContainers`.","ref":"AWS.MediaStore.html#describe_container/3","title":"AWS.MediaStore.describe_container/3","type":"function"},{"doc":"Retrieves the access policy for the specified container.\n\nFor information about the data that is included in an access policy, see the\n[AWS Identity and Access Management User Guide](https://aws.amazon.com/documentation/iam/).","ref":"AWS.MediaStore.html#get_container_policy/3","title":"AWS.MediaStore.get_container_policy/3","type":"function"},{"doc":"Returns the cross-origin resource sharing (CORS) configuration information that\nis set for the container.\n\nTo use this operation, you must have permission to perform the\n`MediaStore:GetCorsPolicy` action. By default, the container owner has this\npermission and can grant it to others.","ref":"AWS.MediaStore.html#get_cors_policy/3","title":"AWS.MediaStore.get_cors_policy/3","type":"function"},{"doc":"Retrieves the object lifecycle policy that is assigned to a container.","ref":"AWS.MediaStore.html#get_lifecycle_policy/3","title":"AWS.MediaStore.get_lifecycle_policy/3","type":"function"},{"doc":"Returns the metric policy for the specified container.","ref":"AWS.MediaStore.html#get_metric_policy/3","title":"AWS.MediaStore.get_metric_policy/3","type":"function"},{"doc":"Lists the properties of all containers in AWS Elemental MediaStore.\n\nYou can query to receive all the containers in one response. Or you can include\nthe `MaxResults` parameter to receive a limited number of containers in each\nresponse. In this case, the response includes a token. To get the next set of\ncontainers, send the command again, this time with the `NextToken` parameter\n(with the returned token as its value). The next set of responses appears, with\na token if there are still more containers to receive.\n\nSee also `DescribeContainer`, which gets the properties of one container.","ref":"AWS.MediaStore.html#list_containers/3","title":"AWS.MediaStore.list_containers/3","type":"function"},{"doc":"Returns a list of the tags assigned to the specified container.","ref":"AWS.MediaStore.html#list_tags_for_resource/3","title":"AWS.MediaStore.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.MediaStore.html#metadata/0","title":"AWS.MediaStore.metadata/0","type":"function"},{"doc":"Creates an access policy for the specified container to restrict the users and\nclients that can access it.\n\nFor information about the data that is included in an access policy, see the\n[AWS Identity and Access Management User Guide](https://aws.amazon.com/documentation/iam/).\n\nFor this release of the REST API, you can create only one policy for a\ncontainer. If you enter `PutContainerPolicy` twice, the second command modifies\nthe existing policy.","ref":"AWS.MediaStore.html#put_container_policy/3","title":"AWS.MediaStore.put_container_policy/3","type":"function"},{"doc":"Sets the cross-origin resource sharing (CORS) configuration on a container so\nthat the container can service cross-origin requests.\n\nFor example, you might want to enable a request whose origin is\nhttp://www.example.com to access your AWS Elemental MediaStore container at\nmy.example.container.com by using the browser's XMLHttpRequest capability.\n\nTo enable CORS on a container, you attach a CORS policy to the container. In the\nCORS policy, you configure rules that identify origins and the HTTP methods that\ncan be executed on your container. The policy can contain up to 398,000\ncharacters. You can add up to 100 rules to a CORS policy. If more than one rule\napplies, the service uses the first applicable rule listed.\n\nTo learn more about CORS, see [Cross-Origin Resource Sharing (CORS) in AWS Elemental\nMediaStore](https://docs.aws.amazon.com/mediastore/latest/ug/cors-policy.html).","ref":"AWS.MediaStore.html#put_cors_policy/3","title":"AWS.MediaStore.put_cors_policy/3","type":"function"},{"doc":"Writes an object lifecycle policy to a container.\n\nIf the container already has an object lifecycle policy, the service replaces\nthe existing policy with the new policy. It takes up to 20 minutes for the\nchange to take effect.\n\nFor information about how to construct an object lifecycle policy, see\n[Components of an Object Lifecycle Policy](https://docs.aws.amazon.com/mediastore/latest/ug/policies-object-lifecycle-components.html).","ref":"AWS.MediaStore.html#put_lifecycle_policy/3","title":"AWS.MediaStore.put_lifecycle_policy/3","type":"function"},{"doc":"The metric policy that you want to add to the container.\n\nA metric policy allows AWS Elemental MediaStore to send metrics to Amazon\nCloudWatch. It takes up to 20 minutes for the new policy to take effect.","ref":"AWS.MediaStore.html#put_metric_policy/3","title":"AWS.MediaStore.put_metric_policy/3","type":"function"},{"doc":"Starts access logging on the specified container.\n\nWhen you enable access logging on a container, MediaStore delivers access logs\nfor objects stored in that container to Amazon CloudWatch Logs.","ref":"AWS.MediaStore.html#start_access_logging/3","title":"AWS.MediaStore.start_access_logging/3","type":"function"},{"doc":"Stops access logging on the specified container.\n\nWhen you stop access logging on a container, MediaStore stops sending access\nlogs to Amazon CloudWatch Logs. These access logs are not saved and are not\nretrievable.","ref":"AWS.MediaStore.html#stop_access_logging/3","title":"AWS.MediaStore.stop_access_logging/3","type":"function"},{"doc":"Adds tags to the specified AWS Elemental MediaStore container.\n\nTags are key:value pairs that you can associate with AWS resources. For example,\nthe tag key might be \"customer\" and the tag value might be \"companyA.\" You can\nspecify one or more tags to add to each container. You can add up to 50 tags to\neach container. For more information about tagging, including naming and usage\nconventions, see [Tagging Resources in MediaStore](https://docs.aws.amazon.com/mediastore/latest/ug/tagging.html).","ref":"AWS.MediaStore.html#tag_resource/3","title":"AWS.MediaStore.tag_resource/3","type":"function"},{"doc":"Removes tags from the specified container.\n\nYou can specify one or more tags to remove.","ref":"AWS.MediaStore.html#untag_resource/3","title":"AWS.MediaStore.untag_resource/3","type":"function"},{"doc":"An AWS Elemental MediaStore asset is an object, similar to an object in the\nAmazon S3 service.\n\nObjects are the fundamental entities that are stored in AWS Elemental\nMediaStore.","ref":"AWS.MediaStoreData.html","title":"AWS.MediaStoreData","type":"module"},{"doc":"Deletes an object at the specified path.","ref":"AWS.MediaStoreData.html#delete_object/4","title":"AWS.MediaStoreData.delete_object/4","type":"function"},{"doc":"Gets the headers for an object at the specified path.","ref":"AWS.MediaStoreData.html#describe_object/4","title":"AWS.MediaStoreData.describe_object/4","type":"function"},{"doc":"Downloads the object at the specified path.\n\nIf the object’s upload availability is set to `streaming`, AWS Elemental\nMediaStore downloads the object even if it’s still uploading the object.","ref":"AWS.MediaStoreData.html#get_object/4","title":"AWS.MediaStoreData.get_object/4","type":"function"},{"doc":"Provides a list of metadata entries about folders and objects in the specified\nfolder.","ref":"AWS.MediaStoreData.html#list_items/5","title":"AWS.MediaStoreData.list_items/5","type":"function"},{"doc":"","ref":"AWS.MediaStoreData.html#metadata/0","title":"AWS.MediaStoreData.metadata/0","type":"function"},{"doc":"Uploads an object to the specified path.\n\nObject sizes are limited to 25 MB for standard upload availability and 10 MB for\nstreaming upload availability.","ref":"AWS.MediaStoreData.html#put_object/4","title":"AWS.MediaStoreData.put_object/4","type":"function"},{"doc":"Use the AWS Elemental MediaTailor SDKs and CLI to configure scalable ad\ninsertion and linear channels.\n\nWith MediaTailor, you can assemble existing content into a linear stream and\nserve targeted ads to viewers while maintaining broadcast quality in\nover-the-top (OTT) video applications. For information about using the service,\nincluding detailed information about the settings covered in this guide, see the\n[AWS Elemental MediaTailor User Guide](https://docs.aws.amazon.com/mediatailor/latest/ug/).\n\nThrough the SDKs and the CLI you manage AWS Elemental MediaTailor configurations\nand channels the same as you do through the console. For example, you specify ad\ninsertion behavior and mapping information for the origin server and the ad\ndecision server (ADS).","ref":"AWS.MediaTailor.html","title":"AWS.MediaTailor","type":"module"},{"doc":"Configures Amazon CloudWatch log settings for a channel.","ref":"AWS.MediaTailor.html#configure_logs_for_channel/3","title":"AWS.MediaTailor.configure_logs_for_channel/3","type":"function"},{"doc":"Amazon CloudWatch log settings for a playback configuration.","ref":"AWS.MediaTailor.html#configure_logs_for_playback_configuration/3","title":"AWS.MediaTailor.configure_logs_for_playback_configuration/3","type":"function"},{"doc":"Creates a channel.\n\nFor information about MediaTailor channels, see [Working with channels](https://docs.aws.amazon.com/mediatailor/latest/ug/channel-assembly-channels.html)\nin the *MediaTailor User Guide*.","ref":"AWS.MediaTailor.html#create_channel/4","title":"AWS.MediaTailor.create_channel/4","type":"function"},{"doc":"The live source configuration.","ref":"AWS.MediaTailor.html#create_live_source/5","title":"AWS.MediaTailor.create_live_source/5","type":"function"},{"doc":"Creates a prefetch schedule for a playback configuration.\n\nA prefetch schedule allows you to tell MediaTailor to fetch and prepare certain\nads before an ad break happens. For more information about ad prefetching, see\n[Using ad prefetching](https://docs.aws.amazon.com/mediatailor/latest/ug/prefetching-ads.html)\nin the *MediaTailor User Guide*.","ref":"AWS.MediaTailor.html#create_prefetch_schedule/5","title":"AWS.MediaTailor.create_prefetch_schedule/5","type":"function"},{"doc":"Creates a program within a channel.\n\nFor information about programs, see [Working with programs](https://docs.aws.amazon.com/mediatailor/latest/ug/channel-assembly-programs.html)\nin the *MediaTailor User Guide*.","ref":"AWS.MediaTailor.html#create_program/5","title":"AWS.MediaTailor.create_program/5","type":"function"},{"doc":"Creates a source location.\n\nA source location is a container for sources. For more information about source\nlocations, see [Working with source locations](https://docs.aws.amazon.com/mediatailor/latest/ug/channel-assembly-source-locations.html)\nin the *MediaTailor User Guide*.","ref":"AWS.MediaTailor.html#create_source_location/4","title":"AWS.MediaTailor.create_source_location/4","type":"function"},{"doc":"The VOD source configuration parameters.","ref":"AWS.MediaTailor.html#create_vod_source/5","title":"AWS.MediaTailor.create_vod_source/5","type":"function"},{"doc":"Deletes a channel.\n\nFor information about MediaTailor channels, see [Working with channels](https://docs.aws.amazon.com/mediatailor/latest/ug/channel-assembly-channels.html)\nin the *MediaTailor User Guide*.","ref":"AWS.MediaTailor.html#delete_channel/4","title":"AWS.MediaTailor.delete_channel/4","type":"function"},{"doc":"The channel policy to delete.","ref":"AWS.MediaTailor.html#delete_channel_policy/4","title":"AWS.MediaTailor.delete_channel_policy/4","type":"function"},{"doc":"The live source to delete.","ref":"AWS.MediaTailor.html#delete_live_source/5","title":"AWS.MediaTailor.delete_live_source/5","type":"function"},{"doc":"Deletes a playback configuration.\n\nFor information about MediaTailor configurations, see [Working with configurations in AWS Elemental\nMediaTailor](https://docs.aws.amazon.com/mediatailor/latest/ug/configurations.html).","ref":"AWS.MediaTailor.html#delete_playback_configuration/4","title":"AWS.MediaTailor.delete_playback_configuration/4","type":"function"},{"doc":"Deletes a prefetch schedule for a specific playback configuration.\n\nIf you call `DeletePrefetchSchedule` on an expired prefetch schedule,\nMediaTailor returns an HTTP 404 status code. For more information about ad\nprefetching, see [Using ad prefetching](https://docs.aws.amazon.com/mediatailor/latest/ug/prefetching-ads.html)\nin the *MediaTailor User Guide*.","ref":"AWS.MediaTailor.html#delete_prefetch_schedule/5","title":"AWS.MediaTailor.delete_prefetch_schedule/5","type":"function"},{"doc":"Deletes a program within a channel.\n\nFor information about programs, see [Working with programs](https://docs.aws.amazon.com/mediatailor/latest/ug/channel-assembly-programs.html)\nin the *MediaTailor User Guide*.","ref":"AWS.MediaTailor.html#delete_program/5","title":"AWS.MediaTailor.delete_program/5","type":"function"},{"doc":"Deletes a source location.\n\nA source location is a container for sources. For more information about source\nlocations, see [Working with source locations](https://docs.aws.amazon.com/mediatailor/latest/ug/channel-assembly-source-locations.html)\nin the *MediaTailor User Guide*.","ref":"AWS.MediaTailor.html#delete_source_location/4","title":"AWS.MediaTailor.delete_source_location/4","type":"function"},{"doc":"The video on demand (VOD) source to delete.","ref":"AWS.MediaTailor.html#delete_vod_source/5","title":"AWS.MediaTailor.delete_vod_source/5","type":"function"},{"doc":"Describes a channel.\n\nFor information about MediaTailor channels, see [Working with channels](https://docs.aws.amazon.com/mediatailor/latest/ug/channel-assembly-channels.html)\nin the *MediaTailor User Guide*.","ref":"AWS.MediaTailor.html#describe_channel/3","title":"AWS.MediaTailor.describe_channel/3","type":"function"},{"doc":"The live source to describe.","ref":"AWS.MediaTailor.html#describe_live_source/4","title":"AWS.MediaTailor.describe_live_source/4","type":"function"},{"doc":"Describes a program within a channel.\n\nFor information about programs, see [Working with programs](https://docs.aws.amazon.com/mediatailor/latest/ug/channel-assembly-programs.html)\nin the *MediaTailor User Guide*.","ref":"AWS.MediaTailor.html#describe_program/4","title":"AWS.MediaTailor.describe_program/4","type":"function"},{"doc":"Describes a source location.\n\nA source location is a container for sources. For more information about source\nlocations, see [Working with source locations](https://docs.aws.amazon.com/mediatailor/latest/ug/channel-assembly-source-locations.html)\nin the *MediaTailor User Guide*.","ref":"AWS.MediaTailor.html#describe_source_location/3","title":"AWS.MediaTailor.describe_source_location/3","type":"function"},{"doc":"Provides details about a specific video on demand (VOD) source in a specific\nsource location.","ref":"AWS.MediaTailor.html#describe_vod_source/4","title":"AWS.MediaTailor.describe_vod_source/4","type":"function"},{"doc":"Returns the channel's IAM policy.\n\nIAM policies are used to control access to your channel.","ref":"AWS.MediaTailor.html#get_channel_policy/3","title":"AWS.MediaTailor.get_channel_policy/3","type":"function"},{"doc":"Retrieves information about your channel's schedule.","ref":"AWS.MediaTailor.html#get_channel_schedule/6","title":"AWS.MediaTailor.get_channel_schedule/6","type":"function"},{"doc":"Retrieves a playback configuration.\n\nFor information about MediaTailor configurations, see [Working with configurations in AWS Elemental\nMediaTailor](https://docs.aws.amazon.com/mediatailor/latest/ug/configurations.html).","ref":"AWS.MediaTailor.html#get_playback_configuration/3","title":"AWS.MediaTailor.get_playback_configuration/3","type":"function"},{"doc":"Retrieves a prefetch schedule for a playback configuration.\n\nA prefetch schedule allows you to tell MediaTailor to fetch and prepare certain\nads before an ad break happens. For more information about ad prefetching, see\n[Using ad prefetching](https://docs.aws.amazon.com/mediatailor/latest/ug/prefetching-ads.html)\nin the *MediaTailor User Guide*.","ref":"AWS.MediaTailor.html#get_prefetch_schedule/4","title":"AWS.MediaTailor.get_prefetch_schedule/4","type":"function"},{"doc":"Lists the alerts that are associated with a MediaTailor channel assembly\nresource.","ref":"AWS.MediaTailor.html#list_alerts/5","title":"AWS.MediaTailor.list_alerts/5","type":"function"},{"doc":"Retrieves information about the channels that are associated with the current\nAWS account.","ref":"AWS.MediaTailor.html#list_channels/4","title":"AWS.MediaTailor.list_channels/4","type":"function"},{"doc":"Lists the live sources contained in a source location.\n\nA source represents a piece of content.","ref":"AWS.MediaTailor.html#list_live_sources/5","title":"AWS.MediaTailor.list_live_sources/5","type":"function"},{"doc":"Retrieves existing playback configurations.\n\nFor information about MediaTailor configurations, see [Working with Configurations in AWS Elemental\nMediaTailor](https://docs.aws.amazon.com/mediatailor/latest/ug/configurations.html).","ref":"AWS.MediaTailor.html#list_playback_configurations/4","title":"AWS.MediaTailor.list_playback_configurations/4","type":"function"},{"doc":"Lists the prefetch schedules for a playback configuration.","ref":"AWS.MediaTailor.html#list_prefetch_schedules/4","title":"AWS.MediaTailor.list_prefetch_schedules/4","type":"function"},{"doc":"Lists the source locations for a channel.\n\nA source location defines the host server URL, and contains a list of sources.","ref":"AWS.MediaTailor.html#list_source_locations/4","title":"AWS.MediaTailor.list_source_locations/4","type":"function"},{"doc":"A list of tags that are associated with this resource.\n\nTags are key-value pairs that you can associate with Amazon resources to help\nwith organization, access control, and cost tracking. For more information, see\n[Tagging AWS Elemental MediaTailor Resources](https://docs.aws.amazon.com/mediatailor/latest/ug/tagging.html).","ref":"AWS.MediaTailor.html#list_tags_for_resource/3","title":"AWS.MediaTailor.list_tags_for_resource/3","type":"function"},{"doc":"Lists the VOD sources contained in a source location.\n\nA source represents a piece of content.","ref":"AWS.MediaTailor.html#list_vod_sources/5","title":"AWS.MediaTailor.list_vod_sources/5","type":"function"},{"doc":"","ref":"AWS.MediaTailor.html#metadata/0","title":"AWS.MediaTailor.metadata/0","type":"function"},{"doc":"Creates an IAM policy for the channel.\n\nIAM policies are used to control access to your channel.","ref":"AWS.MediaTailor.html#put_channel_policy/4","title":"AWS.MediaTailor.put_channel_policy/4","type":"function"},{"doc":"Creates a playback configuration.\n\nFor information about MediaTailor configurations, see [Working with configurations in AWS Elemental\nMediaTailor](https://docs.aws.amazon.com/mediatailor/latest/ug/configurations.html).","ref":"AWS.MediaTailor.html#put_playback_configuration/3","title":"AWS.MediaTailor.put_playback_configuration/3","type":"function"},{"doc":"Starts a channel.\n\nFor information about MediaTailor channels, see [Working with channels](https://docs.aws.amazon.com/mediatailor/latest/ug/channel-assembly-channels.html)\nin the *MediaTailor User Guide*.","ref":"AWS.MediaTailor.html#start_channel/4","title":"AWS.MediaTailor.start_channel/4","type":"function"},{"doc":"Stops a channel.\n\nFor information about MediaTailor channels, see [Working with channels](https://docs.aws.amazon.com/mediatailor/latest/ug/channel-assembly-channels.html)\nin the *MediaTailor User Guide*.","ref":"AWS.MediaTailor.html#stop_channel/4","title":"AWS.MediaTailor.stop_channel/4","type":"function"},{"doc":"The resource to tag.\n\nTags are key-value pairs that you can associate with Amazon resources to help\nwith organization, access control, and cost tracking. For more information, see\n[Tagging AWS Elemental MediaTailor Resources](https://docs.aws.amazon.com/mediatailor/latest/ug/tagging.html).","ref":"AWS.MediaTailor.html#tag_resource/4","title":"AWS.MediaTailor.tag_resource/4","type":"function"},{"doc":"The resource to untag.","ref":"AWS.MediaTailor.html#untag_resource/4","title":"AWS.MediaTailor.untag_resource/4","type":"function"},{"doc":"Updates a channel.\n\nFor information about MediaTailor channels, see [Working with channels](https://docs.aws.amazon.com/mediatailor/latest/ug/channel-assembly-channels.html)\nin the *MediaTailor User Guide*.","ref":"AWS.MediaTailor.html#update_channel/4","title":"AWS.MediaTailor.update_channel/4","type":"function"},{"doc":"Updates a live source's configuration.","ref":"AWS.MediaTailor.html#update_live_source/5","title":"AWS.MediaTailor.update_live_source/5","type":"function"},{"doc":"Updates a program within a channel.","ref":"AWS.MediaTailor.html#update_program/5","title":"AWS.MediaTailor.update_program/5","type":"function"},{"doc":"Updates a source location.\n\nA source location is a container for sources. For more information about source\nlocations, see [Working with source locations](https://docs.aws.amazon.com/mediatailor/latest/ug/channel-assembly-source-locations.html)\nin the *MediaTailor User Guide*.","ref":"AWS.MediaTailor.html#update_source_location/4","title":"AWS.MediaTailor.update_source_location/4","type":"function"},{"doc":"Updates a VOD source's configuration.","ref":"AWS.MediaTailor.html#update_vod_source/5","title":"AWS.MediaTailor.update_vod_source/5","type":"function"},{"doc":"This is the *AWS HealthImaging API Reference*.\n\nAWS HealthImaging is a HIPAA-eligible service that helps health care providers\nand their medical imaging ISV partners store, transform, and apply machine\nlearning to medical images. For an introduction to the service, see the [ *AWS HealthImaging Developer Guide*\n](https://docs.aws.amazon.com/healthimaging/latest/devguide/what-is.html).\n\nWe recommend using one of the AWS Software Development Kits (SDKs) for your\nprogramming language, as they take care of request authentication,\nserialization, and connection management. For more information, see [Tools to build on AWS](http://aws.amazon.com/developer/tools).\n\nFor information about using HealthImaging API actions in one of the\nlanguage-specific AWS SDKs, refer to the *See Also* link at the end of each\nsection that describes an API action or data type.\n\nThe following sections list AWS HealthImaging API actions categorized according\nto functionality. Links are provided to actions within this Reference, along\nwith links back to corresponding sections in the *AWS HealthImaging Developer\nGuide* where you can view console procedures and CLI/SDK code examples.","ref":"AWS.MedicalImaging.html","title":"AWS.MedicalImaging","type":"module"},{"doc":"*\n[CreateDatastore](https://docs.aws.amazon.com/healthimaging/latest/APIReference/API_CreateDatastore.html) – See [Creating a data\nstore](https://docs.aws.amazon.com/healthimaging/latest/devguide/create-data-store.html).\n\n  *\n[GetDatastore](https://docs.aws.amazon.com/healthimaging/latest/APIReference/API_GetDatastore.html) – See [Getting data store\nproperties](https://docs.aws.amazon.com/healthimaging/latest/devguide/get-data-store.html).\n\n  *\n[ListDatastores](https://docs.aws.amazon.com/healthimaging/latest/APIReference/API_ListDatastores.html) – See [Listing data\nstores](https://docs.aws.amazon.com/healthimaging/latest/devguide/list-data-stores.html).\n\n  *\n[DeleteDatastore](https://docs.aws.amazon.com/healthimaging/latest/APIReference/API_DeleteDatastore.html) – See [Deleting a data\nstore](https://docs.aws.amazon.com/healthimaging/latest/devguide/delete-data-store.html).","ref":"AWS.MedicalImaging.html#module-data-store-actions","title":"Data store actions - AWS.MedicalImaging","type":"module"},{"doc":"*\n[StartDICOMImportJob](https://docs.aws.amazon.com/healthimaging/latest/APIReference/API_StartDICOMImportJob.html) – See [Starting an import\njob](https://docs.aws.amazon.com/healthimaging/latest/devguide/start-dicom-import-job.html).\n\n  *\n[GetDICOMImportJob](https://docs.aws.amazon.com/healthimaging/latest/APIReference/API_GetDICOMImportJob.html) – See [Getting import job\nproperties](https://docs.aws.amazon.com/healthimaging/latest/devguide/get-dicom-import-job.html).\n\n  *\n[ListDICOMImportJobs](https://docs.aws.amazon.com/healthimaging/latest/APIReference/API_ListDICOMImportJobs.html) – See [Listing import\njobs](https://docs.aws.amazon.com/healthimaging/latest/devguide/list-dicom-import-jobs.html).","ref":"AWS.MedicalImaging.html#module-import-job-actions","title":"Import job actions - AWS.MedicalImaging","type":"module"},{"doc":"*\n[SearchImageSets](https://docs.aws.amazon.com/healthimaging/latest/APIReference/API_SearchImageSets.html) – See [Searching image\nsets](https://docs.aws.amazon.com/healthimaging/latest/devguide/search-image-sets.html).\n\n  *\n[GetImageSet](https://docs.aws.amazon.com/healthimaging/latest/APIReference/API_GetImageSet.html) – See [Getting image set\nproperties](https://docs.aws.amazon.com/healthimaging/latest/devguide/get-image-set-properties.html).\n\n  *\n[GetImageSetMetadata](https://docs.aws.amazon.com/healthimaging/latest/APIReference/API_GetImageSetMetadata.html) – See [Getting image set\nmetadata](https://docs.aws.amazon.com/healthimaging/latest/devguide/get-image-set-metadata.html).\n\n  *\n[GetImageFrame](https://docs.aws.amazon.com/healthimaging/latest/APIReference/API_GetImageFrame.html) – See [Getting image set pixel\ndata](https://docs.aws.amazon.com/healthimaging/latest/devguide/get-image-frame.html).","ref":"AWS.MedicalImaging.html#module-image-set-access-actions","title":"Image set access actions - AWS.MedicalImaging","type":"module"},{"doc":"*\n[ListImageSetVersions](https://docs.aws.amazon.com/healthimaging/latest/APIReference/API_ListImageSetVersions.html) – See [Listing image set\nversions](https://docs.aws.amazon.com/healthimaging/latest/devguide/list-image-set-versions.html).\n\n  *\n[UpdateImageSetMetadata](https://docs.aws.amazon.com/healthimaging/latest/APIReference/API_UpdateImageSetMetadata.html) – See [Updating image set\nmetadata](https://docs.aws.amazon.com/healthimaging/latest/devguide/update-image-set-metadata.html).\n\n  *\n[CopyImageSet](https://docs.aws.amazon.com/healthimaging/latest/APIReference/API_CopyImageSet.html) – See [Copying an image\nset](https://docs.aws.amazon.com/healthimaging/latest/devguide/copy-image-set.html).\n\n  *\n[DeleteImageSet](https://docs.aws.amazon.com/healthimaging/latest/APIReference/API_DeleteImageSet.html) – See [Deleting an image\nset](https://docs.aws.amazon.com/healthimaging/latest/devguide/delete-image-set.html).","ref":"AWS.MedicalImaging.html#module-image-set-modification-actions","title":"Image set modification actions - AWS.MedicalImaging","type":"module"},{"doc":"*\n[TagResource](https://docs.aws.amazon.com/healthimaging/latest/APIReference/API_TagResource.html) – See [Tagging a data\nstore](https://docs.aws.amazon.com/healthimaging/latest/devguide/tag-list-untag-data-store.html)\nand [Tagging an image set](https://docs.aws.amazon.com/healthimaging/latest/devguide/tag-list-untag-image-set.html).\n\n  *\n[ListTagsForResource](https://docs.aws.amazon.com/healthimaging/latest/APIReference/API_ListTagsForResource.html) – See [Tagging a data\nstore](https://docs.aws.amazon.com/healthimaging/latest/devguide/tag-list-untag-data-store.html)\nand [Tagging an image set](https://docs.aws.amazon.com/healthimaging/latest/devguide/tag-list-untag-image-set.html).\n\n  *\n[UntagResource](https://docs.aws.amazon.com/healthimaging/latest/APIReference/API_UntagResource.html) – See [Tagging a data\nstore](https://docs.aws.amazon.com/healthimaging/latest/devguide/tag-list-untag-data-store.html)\nand [Tagging an image set](https://docs.aws.amazon.com/healthimaging/latest/devguide/tag-list-untag-image-set.html).","ref":"AWS.MedicalImaging.html#module-tagging-actions","title":"Tagging actions - AWS.MedicalImaging","type":"module"},{"doc":"Copy an image set.","ref":"AWS.MedicalImaging.html#copy_image_set/5","title":"AWS.MedicalImaging.copy_image_set/5","type":"function"},{"doc":"Create a data store.","ref":"AWS.MedicalImaging.html#create_datastore/3","title":"AWS.MedicalImaging.create_datastore/3","type":"function"},{"doc":"Delete a data store.\n\nBefore a data store can be deleted, you must first delete all image sets within\nit.","ref":"AWS.MedicalImaging.html#delete_datastore/4","title":"AWS.MedicalImaging.delete_datastore/4","type":"function"},{"doc":"Delete an image set.","ref":"AWS.MedicalImaging.html#delete_image_set/5","title":"AWS.MedicalImaging.delete_image_set/5","type":"function"},{"doc":"Get the import job properties to learn more about the job or job progress.","ref":"AWS.MedicalImaging.html#get_d_i_c_o_m_import_job/4","title":"AWS.MedicalImaging.get_d_i_c_o_m_import_job/4","type":"function"},{"doc":"Get data store properties.","ref":"AWS.MedicalImaging.html#get_datastore/3","title":"AWS.MedicalImaging.get_datastore/3","type":"function"},{"doc":"Get an image frame (pixel data) for an image set.","ref":"AWS.MedicalImaging.html#get_image_frame/5","title":"AWS.MedicalImaging.get_image_frame/5","type":"function"},{"doc":"Get image set properties.","ref":"AWS.MedicalImaging.html#get_image_set/5","title":"AWS.MedicalImaging.get_image_set/5","type":"function"},{"doc":"Get metadata attributes for an image set.","ref":"AWS.MedicalImaging.html#get_image_set_metadata/5","title":"AWS.MedicalImaging.get_image_set_metadata/5","type":"function"},{"doc":"List import jobs created for a specific data store.","ref":"AWS.MedicalImaging.html#list_d_i_c_o_m_import_jobs/6","title":"AWS.MedicalImaging.list_d_i_c_o_m_import_jobs/6","type":"function"},{"doc":"List data stores.","ref":"AWS.MedicalImaging.html#list_datastores/5","title":"AWS.MedicalImaging.list_datastores/5","type":"function"},{"doc":"List image set versions.","ref":"AWS.MedicalImaging.html#list_image_set_versions/5","title":"AWS.MedicalImaging.list_image_set_versions/5","type":"function"},{"doc":"Lists all tags associated with a medical imaging resource.","ref":"AWS.MedicalImaging.html#list_tags_for_resource/3","title":"AWS.MedicalImaging.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.MedicalImaging.html#metadata/0","title":"AWS.MedicalImaging.metadata/0","type":"function"},{"doc":"Search image sets based on defined input attributes.\n\n`SearchImageSets` accepts a single search query parameter and returns a\npaginated response of all image sets that have the matching criteria. All range\nqueries must be input as `(lowerBound, upperBound)`.\n\n`SearchImageSets` uses the `updatedAt` field for sorting in decreasing order\nfrom latest to oldest.","ref":"AWS.MedicalImaging.html#search_image_sets/4","title":"AWS.MedicalImaging.search_image_sets/4","type":"function"},{"doc":"Start importing bulk data into an `ACTIVE` data store.\n\nThe import job imports DICOM P10 files found in the S3 prefix specified by the\n`inputS3Uri` parameter. The import job stores processing results in the file\nspecified by the `outputS3Uri` parameter.","ref":"AWS.MedicalImaging.html#start_d_i_c_o_m_import_job/4","title":"AWS.MedicalImaging.start_d_i_c_o_m_import_job/4","type":"function"},{"doc":"Adds a user-specifed key and value tag to a medical imaging resource.","ref":"AWS.MedicalImaging.html#tag_resource/4","title":"AWS.MedicalImaging.tag_resource/4","type":"function"},{"doc":"Removes tags from a medical imaging resource.","ref":"AWS.MedicalImaging.html#untag_resource/4","title":"AWS.MedicalImaging.untag_resource/4","type":"function"},{"doc":"Update image set metadata attributes.","ref":"AWS.MedicalImaging.html#update_image_set_metadata/5","title":"AWS.MedicalImaging.update_image_set_metadata/5","type":"function"},{"doc":"MemoryDB for Redis is a fully managed, Redis-compatible, in-memory database that\ndelivers ultra-fast performance and Multi-AZ durability for modern applications\nbuilt using microservices architectures.\n\nMemoryDB stores the entire database in-memory, enabling low latency and high\nthroughput data access. It is compatible with Redis, a popular open source data\nstore, enabling you to leverage Redis’ flexible and friendly data structures,\nAPIs, and commands.","ref":"AWS.MemoryDB.html","title":"AWS.MemoryDB","type":"module"},{"doc":"Apply the service update to a list of clusters supplied.\n\nFor more information on service updates and applying them, see [Applying the service\nupdates](https://docs.aws.amazon.com/MemoryDB/latest/devguide/managing-updates.html#applying-updates).","ref":"AWS.MemoryDB.html#batch_update_cluster/3","title":"AWS.MemoryDB.batch_update_cluster/3","type":"function"},{"doc":"Makes a copy of an existing snapshot.","ref":"AWS.MemoryDB.html#copy_snapshot/3","title":"AWS.MemoryDB.copy_snapshot/3","type":"function"},{"doc":"Creates an Access Control List.\n\nFor more information, see [Authenticating users with Access Contol Lists (ACLs)](https://docs.aws.amazon.com/MemoryDB/latest/devguide/clusters.acls.html).","ref":"AWS.MemoryDB.html#create_acl/3","title":"AWS.MemoryDB.create_acl/3","type":"function"},{"doc":"Creates a cluster.\n\nAll nodes in the cluster run the same protocol-compliant engine software.","ref":"AWS.MemoryDB.html#create_cluster/3","title":"AWS.MemoryDB.create_cluster/3","type":"function"},{"doc":"Creates a new MemoryDB parameter group.\n\nA parameter group is a collection of parameters and their values that are\napplied to all of the nodes in any cluster. For more information, see\n[Configuring engine parameters using parameter groups](https://docs.aws.amazon.com/MemoryDB/latest/devguide/parametergroups.html).","ref":"AWS.MemoryDB.html#create_parameter_group/3","title":"AWS.MemoryDB.create_parameter_group/3","type":"function"},{"doc":"Creates a copy of an entire cluster at a specific moment in time.","ref":"AWS.MemoryDB.html#create_snapshot/3","title":"AWS.MemoryDB.create_snapshot/3","type":"function"},{"doc":"Creates a subnet group.\n\nA subnet group is a collection of subnets (typically private) that you can\ndesignate for your clusters running in an Amazon Virtual Private Cloud (VPC)\nenvironment. When you create a cluster in an Amazon VPC, you must specify a\nsubnet group. MemoryDB uses that subnet group to choose a subnet and IP\naddresses within that subnet to associate with your nodes. For more information,\nsee [Subnets and subnet groups](https://docs.aws.amazon.com/MemoryDB/latest/devguide/subnetgroups.html).","ref":"AWS.MemoryDB.html#create_subnet_group/3","title":"AWS.MemoryDB.create_subnet_group/3","type":"function"},{"doc":"Creates a MemoryDB user.\n\nFor more information, see [Authenticating users with Access Contol Lists (ACLs)](https://docs.aws.amazon.com/MemoryDB/latest/devguide/clusters.acls.html).","ref":"AWS.MemoryDB.html#create_user/3","title":"AWS.MemoryDB.create_user/3","type":"function"},{"doc":"Deletes an Access Control List.\n\nThe ACL must first be disassociated from the cluster before it can be deleted.\nFor more information, see [Authenticating users with Access Contol Lists (ACLs)](https://docs.aws.amazon.com/MemoryDB/latest/devguide/clusters.acls.html).","ref":"AWS.MemoryDB.html#delete_acl/3","title":"AWS.MemoryDB.delete_acl/3","type":"function"},{"doc":"Deletes a cluster.\n\nIt also deletes all associated nodes and node endpoints","ref":"AWS.MemoryDB.html#delete_cluster/3","title":"AWS.MemoryDB.delete_cluster/3","type":"function"},{"doc":"Deletes the specified parameter group.\n\nYou cannot delete a parameter group if it is associated with any clusters. You\ncannot delete the default parameter groups in your account.","ref":"AWS.MemoryDB.html#delete_parameter_group/3","title":"AWS.MemoryDB.delete_parameter_group/3","type":"function"},{"doc":"Deletes an existing snapshot.\n\nWhen you receive a successful response from this operation, MemoryDB immediately\nbegins deleting the snapshot; you cannot cancel or revert this operation.","ref":"AWS.MemoryDB.html#delete_snapshot/3","title":"AWS.MemoryDB.delete_snapshot/3","type":"function"},{"doc":"Deletes a subnet group.\n\nYou cannot delete a default subnet group or one that is associated with any\nclusters.","ref":"AWS.MemoryDB.html#delete_subnet_group/3","title":"AWS.MemoryDB.delete_subnet_group/3","type":"function"},{"doc":"Deletes a user.\n\nThe user will be removed from all ACLs and in turn removed from all clusters.","ref":"AWS.MemoryDB.html#delete_user/3","title":"AWS.MemoryDB.delete_user/3","type":"function"},{"doc":"Returns a list of ACLs","ref":"AWS.MemoryDB.html#describe_acls/3","title":"AWS.MemoryDB.describe_acls/3","type":"function"},{"doc":"Returns information about all provisioned clusters if no cluster identifier is\nspecified, or about a specific cluster if a cluster name is supplied.","ref":"AWS.MemoryDB.html#describe_clusters/3","title":"AWS.MemoryDB.describe_clusters/3","type":"function"},{"doc":"Returns a list of the available Redis engine versions.","ref":"AWS.MemoryDB.html#describe_engine_versions/3","title":"AWS.MemoryDB.describe_engine_versions/3","type":"function"},{"doc":"Returns events related to clusters, security groups, and parameter groups.\n\nYou can obtain events specific to a particular cluster, security group, or\nparameter group by providing the name as a parameter. By default, only the\nevents occurring within the last hour are returned; however, you can retrieve up\nto 14 days' worth of events if necessary.","ref":"AWS.MemoryDB.html#describe_events/3","title":"AWS.MemoryDB.describe_events/3","type":"function"},{"doc":"Returns a list of parameter group descriptions.\n\nIf a parameter group name is specified, the list contains only the descriptions\nfor that group.","ref":"AWS.MemoryDB.html#describe_parameter_groups/3","title":"AWS.MemoryDB.describe_parameter_groups/3","type":"function"},{"doc":"Returns the detailed parameter list for a particular parameter group.","ref":"AWS.MemoryDB.html#describe_parameters/3","title":"AWS.MemoryDB.describe_parameters/3","type":"function"},{"doc":"Returns information about reserved nodes for this account, or about a specified\nreserved node.","ref":"AWS.MemoryDB.html#describe_reserved_nodes/3","title":"AWS.MemoryDB.describe_reserved_nodes/3","type":"function"},{"doc":"Lists available reserved node offerings.","ref":"AWS.MemoryDB.html#describe_reserved_nodes_offerings/3","title":"AWS.MemoryDB.describe_reserved_nodes_offerings/3","type":"function"},{"doc":"Returns details of the service updates","ref":"AWS.MemoryDB.html#describe_service_updates/3","title":"AWS.MemoryDB.describe_service_updates/3","type":"function"},{"doc":"Returns information about cluster snapshots.\n\nBy default, DescribeSnapshots lists all of your snapshots; it can optionally\ndescribe a single snapshot, or just the snapshots associated with a particular\ncluster.","ref":"AWS.MemoryDB.html#describe_snapshots/3","title":"AWS.MemoryDB.describe_snapshots/3","type":"function"},{"doc":"Returns a list of subnet group descriptions.\n\nIf a subnet group name is specified, the list contains only the description of\nthat group.","ref":"AWS.MemoryDB.html#describe_subnet_groups/3","title":"AWS.MemoryDB.describe_subnet_groups/3","type":"function"},{"doc":"Returns a list of users.","ref":"AWS.MemoryDB.html#describe_users/3","title":"AWS.MemoryDB.describe_users/3","type":"function"},{"doc":"Used to failover a shard.\n\nThis API is designed for testing the behavior of your application in case of\nMemoryDB failover. It is not designed to be used as a production-level tool for\ninitiating a failover to overcome a problem you may have with the cluster.\nMoreover, in certain conditions such as large scale operational events, Amazon\nmay block this API.","ref":"AWS.MemoryDB.html#failover_shard/3","title":"AWS.MemoryDB.failover_shard/3","type":"function"},{"doc":"Lists all available node types that you can scale to from your cluster's current\nnode type.\n\nWhen you use the UpdateCluster operation to scale your cluster, the value of the\nNodeType parameter must be one of the node types returned by this operation.","ref":"AWS.MemoryDB.html#list_allowed_node_type_updates/3","title":"AWS.MemoryDB.list_allowed_node_type_updates/3","type":"function"},{"doc":"Lists all tags currently on a named resource.\n\nA tag is a key-value pair where the key and value are case-sensitive. You can\nuse tags to categorize and track your MemoryDB resources. For more information,\nsee [Tagging your MemoryDB resources](https://docs.aws.amazon.com/MemoryDB/latest/devguide/Tagging-Resources.html)","ref":"AWS.MemoryDB.html#list_tags/3","title":"AWS.MemoryDB.list_tags/3","type":"function"},{"doc":"","ref":"AWS.MemoryDB.html#metadata/0","title":"AWS.MemoryDB.metadata/0","type":"function"},{"doc":"Allows you to purchase a reserved node offering.\n\nReserved nodes are not eligible for cancellation and are non-refundable.","ref":"AWS.MemoryDB.html#purchase_reserved_nodes_offering/3","title":"AWS.MemoryDB.purchase_reserved_nodes_offering/3","type":"function"},{"doc":"Modifies the parameters of a parameter group to the engine or system default\nvalue.\n\nYou can reset specific parameters by submitting a list of parameter names. To\nreset the entire parameter group, specify the AllParameters and\nParameterGroupName parameters.","ref":"AWS.MemoryDB.html#reset_parameter_group/3","title":"AWS.MemoryDB.reset_parameter_group/3","type":"function"},{"doc":"A tag is a key-value pair where the key and value are case-sensitive.\n\nYou can use tags to categorize and track all your MemoryDB resources. When you\nadd or remove tags on clusters, those actions will be replicated to all nodes in\nthe cluster. For more information, see [Resource-level permissions](https://docs.aws.amazon.com/MemoryDB/latest/devguide/iam.resourcelevelpermissions.html).\n\nFor example, you can use cost-allocation tags to your MemoryDB resources, Amazon\ngenerates a cost allocation report as a comma-separated value (CSV) file with\nyour usage and costs aggregated by your tags. You can apply tags that represent\nbusiness categories (such as cost centers, application names, or owners) to\norganize your costs across multiple services. For more information, see [Using Cost Allocation\nTags](https://docs.aws.amazon.com/MemoryDB/latest/devguide/tagging.html).","ref":"AWS.MemoryDB.html#tag_resource/3","title":"AWS.MemoryDB.tag_resource/3","type":"function"},{"doc":"Use this operation to remove tags on a resource","ref":"AWS.MemoryDB.html#untag_resource/3","title":"AWS.MemoryDB.untag_resource/3","type":"function"},{"doc":"Changes the list of users that belong to the Access Control List.","ref":"AWS.MemoryDB.html#update_acl/3","title":"AWS.MemoryDB.update_acl/3","type":"function"},{"doc":"Modifies the settings for a cluster.\n\nYou can use this operation to change one or more cluster configuration settings\nby specifying the settings and the new values.","ref":"AWS.MemoryDB.html#update_cluster/3","title":"AWS.MemoryDB.update_cluster/3","type":"function"},{"doc":"Updates the parameters of a parameter group.\n\nYou can modify up to 20 parameters in a single request by submitting a list\nparameter name and value pairs.","ref":"AWS.MemoryDB.html#update_parameter_group/3","title":"AWS.MemoryDB.update_parameter_group/3","type":"function"},{"doc":"Updates a subnet group.\n\nFor more information, see [Updating a subnet group](https://docs.aws.amazon.com/MemoryDB/latest/devguide/ubnetGroups.Modifying.html)","ref":"AWS.MemoryDB.html#update_subnet_group/3","title":"AWS.MemoryDB.update_subnet_group/3","type":"function"},{"doc":"Changes user password(s) and/or access string.","ref":"AWS.MemoryDB.html#update_user/3","title":"AWS.MemoryDB.update_user/3","type":"function"},{"doc":"The Application Migration Service service.","ref":"AWS.Mgn.html","title":"AWS.Mgn","type":"module"},{"doc":"Archive application.","ref":"AWS.Mgn.html#archive_application/3","title":"AWS.Mgn.archive_application/3","type":"function"},{"doc":"Archive wave.","ref":"AWS.Mgn.html#archive_wave/3","title":"AWS.Mgn.archive_wave/3","type":"function"},{"doc":"Associate applications to wave.","ref":"AWS.Mgn.html#associate_applications/3","title":"AWS.Mgn.associate_applications/3","type":"function"},{"doc":"Associate source servers to application.","ref":"AWS.Mgn.html#associate_source_servers/3","title":"AWS.Mgn.associate_source_servers/3","type":"function"},{"doc":"Allows the user to set the SourceServer.LifeCycle.state property for specific\nSource Server IDs to one of the following: READY_FOR_TEST or READY_FOR_CUTOVER.\n\nThis command only works if the Source Server is already launchable\n(dataReplicationInfo.lagDuration is not null.)","ref":"AWS.Mgn.html#change_server_life_cycle_state/3","title":"AWS.Mgn.change_server_life_cycle_state/3","type":"function"},{"doc":"Create application.","ref":"AWS.Mgn.html#create_application/3","title":"AWS.Mgn.create_application/3","type":"function"},{"doc":"Create Connector.","ref":"AWS.Mgn.html#create_connector/3","title":"AWS.Mgn.create_connector/3","type":"function"},{"doc":"Creates a new Launch Configuration Template.","ref":"AWS.Mgn.html#create_launch_configuration_template/3","title":"AWS.Mgn.create_launch_configuration_template/3","type":"function"},{"doc":"Creates a new ReplicationConfigurationTemplate.","ref":"AWS.Mgn.html#create_replication_configuration_template/3","title":"AWS.Mgn.create_replication_configuration_template/3","type":"function"},{"doc":"Create wave.","ref":"AWS.Mgn.html#create_wave/3","title":"AWS.Mgn.create_wave/3","type":"function"},{"doc":"Delete application.","ref":"AWS.Mgn.html#delete_application/3","title":"AWS.Mgn.delete_application/3","type":"function"},{"doc":"Delete Connector.","ref":"AWS.Mgn.html#delete_connector/3","title":"AWS.Mgn.delete_connector/3","type":"function"},{"doc":"Deletes a single Job by ID.","ref":"AWS.Mgn.html#delete_job/3","title":"AWS.Mgn.delete_job/3","type":"function"},{"doc":"Deletes a single Launch Configuration Template by ID.","ref":"AWS.Mgn.html#delete_launch_configuration_template/3","title":"AWS.Mgn.delete_launch_configuration_template/3","type":"function"},{"doc":"Deletes a single Replication Configuration Template by ID","ref":"AWS.Mgn.html#delete_replication_configuration_template/3","title":"AWS.Mgn.delete_replication_configuration_template/3","type":"function"},{"doc":"Deletes a single source server by ID.","ref":"AWS.Mgn.html#delete_source_server/3","title":"AWS.Mgn.delete_source_server/3","type":"function"},{"doc":"Deletes a given vCenter client by ID.","ref":"AWS.Mgn.html#delete_vcenter_client/3","title":"AWS.Mgn.delete_vcenter_client/3","type":"function"},{"doc":"Delete wave.","ref":"AWS.Mgn.html#delete_wave/3","title":"AWS.Mgn.delete_wave/3","type":"function"},{"doc":"Retrieves detailed job log items with paging.","ref":"AWS.Mgn.html#describe_job_log_items/3","title":"AWS.Mgn.describe_job_log_items/3","type":"function"},{"doc":"Returns a list of Jobs.\n\nUse the JobsID and fromDate and toData filters to limit which jobs are returned.\nThe response is sorted by creationDataTime - latest date first. Jobs are\nnormally created by the StartTest, StartCutover, and TerminateTargetInstances\nAPIs. Jobs are also created by DiagnosticLaunch and\nTerminateDiagnosticInstances, which are APIs available only to *Support* and\nonly used in response to relevant support tickets.","ref":"AWS.Mgn.html#describe_jobs/3","title":"AWS.Mgn.describe_jobs/3","type":"function"},{"doc":"Lists all Launch Configuration Templates, filtered by Launch Configuration\nTemplate IDs","ref":"AWS.Mgn.html#describe_launch_configuration_templates/3","title":"AWS.Mgn.describe_launch_configuration_templates/3","type":"function"},{"doc":"Lists all ReplicationConfigurationTemplates, filtered by Source Server IDs.","ref":"AWS.Mgn.html#describe_replication_configuration_templates/3","title":"AWS.Mgn.describe_replication_configuration_templates/3","type":"function"},{"doc":"Retrieves all SourceServers or multiple SourceServers by ID.","ref":"AWS.Mgn.html#describe_source_servers/3","title":"AWS.Mgn.describe_source_servers/3","type":"function"},{"doc":"Returns a list of the installed vCenter clients.","ref":"AWS.Mgn.html#describe_vcenter_clients/4","title":"AWS.Mgn.describe_vcenter_clients/4","type":"function"},{"doc":"Disassociate applications from wave.","ref":"AWS.Mgn.html#disassociate_applications/3","title":"AWS.Mgn.disassociate_applications/3","type":"function"},{"doc":"Disassociate source servers from application.","ref":"AWS.Mgn.html#disassociate_source_servers/3","title":"AWS.Mgn.disassociate_source_servers/3","type":"function"},{"doc":"Disconnects specific Source Servers from Application Migration Service.\n\nData replication is stopped immediately. All AWS resources created by\nApplication Migration Service for enabling the replication of these source\nservers will be terminated / deleted within 90 minutes. Launched Test or Cutover\ninstances will NOT be terminated. If the agent on the source server has not been\nprevented from communicating with the Application Migration Service service,\nthen it will receive a command to uninstall itself (within approximately 10\nminutes). The following properties of the SourceServer will be changed\nimmediately: dataReplicationInfo.dataReplicationState will be set to\nDISCONNECTED; The totalStorageBytes property for each of\ndataReplicationInfo.replicatedDisks will be set to zero;\ndataReplicationInfo.lagDuration and dataReplicationInfo.lagDuration will be\nnullified.","ref":"AWS.Mgn.html#disconnect_from_service/3","title":"AWS.Mgn.disconnect_from_service/3","type":"function"},{"doc":"Finalizes the cutover immediately for specific Source Servers.\n\nAll AWS resources created by Application Migration Service for enabling the\nreplication of these source servers will be terminated / deleted within 90\nminutes. Launched Test or Cutover instances will NOT be terminated. The AWS\nReplication Agent will receive a command to uninstall itself (within 10\nminutes). The following properties of the SourceServer will be changed\nimmediately: dataReplicationInfo.dataReplicationState will be changed to\nDISCONNECTED; The SourceServer.lifeCycle.state will be changed to CUTOVER; The\ntotalStorageBytes property fo each of dataReplicationInfo.replicatedDisks will\nbe set to zero; dataReplicationInfo.lagDuration and\ndataReplicationInfo.lagDuration will be nullified.","ref":"AWS.Mgn.html#finalize_cutover/3","title":"AWS.Mgn.finalize_cutover/3","type":"function"},{"doc":"Lists all LaunchConfigurations available, filtered by Source Server IDs.","ref":"AWS.Mgn.html#get_launch_configuration/3","title":"AWS.Mgn.get_launch_configuration/3","type":"function"},{"doc":"Lists all ReplicationConfigurations, filtered by Source Server ID.","ref":"AWS.Mgn.html#get_replication_configuration/3","title":"AWS.Mgn.get_replication_configuration/3","type":"function"},{"doc":"Initialize Application Migration Service.","ref":"AWS.Mgn.html#initialize_service/3","title":"AWS.Mgn.initialize_service/3","type":"function"},{"doc":"Retrieves all applications or multiple applications by ID.","ref":"AWS.Mgn.html#list_applications/3","title":"AWS.Mgn.list_applications/3","type":"function"},{"doc":"List Connectors.","ref":"AWS.Mgn.html#list_connectors/3","title":"AWS.Mgn.list_connectors/3","type":"function"},{"doc":"List export errors.","ref":"AWS.Mgn.html#list_export_errors/3","title":"AWS.Mgn.list_export_errors/3","type":"function"},{"doc":"List exports.","ref":"AWS.Mgn.html#list_exports/3","title":"AWS.Mgn.list_exports/3","type":"function"},{"doc":"List import errors.","ref":"AWS.Mgn.html#list_import_errors/3","title":"AWS.Mgn.list_import_errors/3","type":"function"},{"doc":"List imports.","ref":"AWS.Mgn.html#list_imports/3","title":"AWS.Mgn.list_imports/3","type":"function"},{"doc":"List Managed Accounts.","ref":"AWS.Mgn.html#list_managed_accounts/3","title":"AWS.Mgn.list_managed_accounts/3","type":"function"},{"doc":"List source server post migration custom actions.","ref":"AWS.Mgn.html#list_source_server_actions/3","title":"AWS.Mgn.list_source_server_actions/3","type":"function"},{"doc":"List all tags for your Application Migration Service resources.","ref":"AWS.Mgn.html#list_tags_for_resource/3","title":"AWS.Mgn.list_tags_for_resource/3","type":"function"},{"doc":"List template post migration custom actions.","ref":"AWS.Mgn.html#list_template_actions/3","title":"AWS.Mgn.list_template_actions/3","type":"function"},{"doc":"Retrieves all waves or multiple waves by ID.","ref":"AWS.Mgn.html#list_waves/3","title":"AWS.Mgn.list_waves/3","type":"function"},{"doc":"Archives specific Source Servers by setting the SourceServer.isArchived property\nto true for specified SourceServers by ID.\n\nThis command only works for SourceServers with a lifecycle. state which equals\nDISCONNECTED or CUTOVER.","ref":"AWS.Mgn.html#mark_as_archived/3","title":"AWS.Mgn.mark_as_archived/3","type":"function"},{"doc":"","ref":"AWS.Mgn.html#metadata/0","title":"AWS.Mgn.metadata/0","type":"function"},{"doc":"Pause Replication.","ref":"AWS.Mgn.html#pause_replication/3","title":"AWS.Mgn.pause_replication/3","type":"function"},{"doc":"Put source server post migration custom action.","ref":"AWS.Mgn.html#put_source_server_action/3","title":"AWS.Mgn.put_source_server_action/3","type":"function"},{"doc":"Put template post migration custom action.","ref":"AWS.Mgn.html#put_template_action/3","title":"AWS.Mgn.put_template_action/3","type":"function"},{"doc":"Remove source server post migration custom action.","ref":"AWS.Mgn.html#remove_source_server_action/3","title":"AWS.Mgn.remove_source_server_action/3","type":"function"},{"doc":"Remove template post migration custom action.","ref":"AWS.Mgn.html#remove_template_action/3","title":"AWS.Mgn.remove_template_action/3","type":"function"},{"doc":"Resume Replication.","ref":"AWS.Mgn.html#resume_replication/3","title":"AWS.Mgn.resume_replication/3","type":"function"},{"doc":"Causes the data replication initiation sequence to begin immediately upon next\nHandshake for specified SourceServer IDs, regardless of when the previous\ninitiation started.\n\nThis command will not work if the SourceServer is not stalled or is in a\nDISCONNECTED or STOPPED state.","ref":"AWS.Mgn.html#retry_data_replication/3","title":"AWS.Mgn.retry_data_replication/3","type":"function"},{"doc":"Launches a Cutover Instance for specific Source Servers.\n\nThis command starts a LAUNCH job whose initiatedBy property is StartCutover and\nchanges the SourceServer.lifeCycle.state property to CUTTING_OVER.","ref":"AWS.Mgn.html#start_cutover/3","title":"AWS.Mgn.start_cutover/3","type":"function"},{"doc":"Start export.","ref":"AWS.Mgn.html#start_export/3","title":"AWS.Mgn.start_export/3","type":"function"},{"doc":"Start import.","ref":"AWS.Mgn.html#start_import/3","title":"AWS.Mgn.start_import/3","type":"function"},{"doc":"Starts replication for SNAPSHOT_SHIPPING agents.","ref":"AWS.Mgn.html#start_replication/3","title":"AWS.Mgn.start_replication/3","type":"function"},{"doc":"Launches a Test Instance for specific Source Servers.\n\nThis command starts a LAUNCH job whose initiatedBy property is StartTest and\nchanges the SourceServer.lifeCycle.state property to TESTING.","ref":"AWS.Mgn.html#start_test/3","title":"AWS.Mgn.start_test/3","type":"function"},{"doc":"Stop Replication.","ref":"AWS.Mgn.html#stop_replication/3","title":"AWS.Mgn.stop_replication/3","type":"function"},{"doc":"Adds or overwrites only the specified tags for the specified Application\nMigration Service resource or resources.\n\nWhen you specify an existing tag key, the value is overwritten with the new\nvalue. Each resource can have a maximum of 50 tags. Each tag consists of a key\nand optional value.","ref":"AWS.Mgn.html#tag_resource/4","title":"AWS.Mgn.tag_resource/4","type":"function"},{"doc":"Starts a job that terminates specific launched EC2 Test and Cutover instances.\n\nThis command will not work for any Source Server with a lifecycle.state of\nTESTING, CUTTING_OVER, or CUTOVER.","ref":"AWS.Mgn.html#terminate_target_instances/3","title":"AWS.Mgn.terminate_target_instances/3","type":"function"},{"doc":"Unarchive application.","ref":"AWS.Mgn.html#unarchive_application/3","title":"AWS.Mgn.unarchive_application/3","type":"function"},{"doc":"Unarchive wave.","ref":"AWS.Mgn.html#unarchive_wave/3","title":"AWS.Mgn.unarchive_wave/3","type":"function"},{"doc":"Deletes the specified set of tags from the specified set of Application\nMigration Service resources.","ref":"AWS.Mgn.html#untag_resource/4","title":"AWS.Mgn.untag_resource/4","type":"function"},{"doc":"Update application.","ref":"AWS.Mgn.html#update_application/3","title":"AWS.Mgn.update_application/3","type":"function"},{"doc":"Update Connector.","ref":"AWS.Mgn.html#update_connector/3","title":"AWS.Mgn.update_connector/3","type":"function"},{"doc":"Updates multiple LaunchConfigurations by Source Server ID.","ref":"AWS.Mgn.html#update_launch_configuration/3","title":"AWS.Mgn.update_launch_configuration/3","type":"function"},{"doc":"Updates an existing Launch Configuration Template by ID.","ref":"AWS.Mgn.html#update_launch_configuration_template/3","title":"AWS.Mgn.update_launch_configuration_template/3","type":"function"},{"doc":"Allows you to update multiple ReplicationConfigurations by Source Server ID.","ref":"AWS.Mgn.html#update_replication_configuration/3","title":"AWS.Mgn.update_replication_configuration/3","type":"function"},{"doc":"Updates multiple ReplicationConfigurationTemplates by ID.","ref":"AWS.Mgn.html#update_replication_configuration_template/3","title":"AWS.Mgn.update_replication_configuration_template/3","type":"function"},{"doc":"Update Source Server.","ref":"AWS.Mgn.html#update_source_server/3","title":"AWS.Mgn.update_source_server/3","type":"function"},{"doc":"Allows you to change between the AGENT_BASED replication type and the\nSNAPSHOT_SHIPPING replication type.","ref":"AWS.Mgn.html#update_source_server_replication_type/3","title":"AWS.Mgn.update_source_server_replication_type/3","type":"function"},{"doc":"Update wave.","ref":"AWS.Mgn.html#update_wave/3","title":"AWS.Mgn.update_wave/3","type":"function"},{"doc":"The AWS Migration Hub API methods help to obtain server and application\nmigration status and integrate your resource-specific migration tool by\nproviding a programmatic interface to Migration Hub.\n\nRemember that you must set your AWS Migration Hub home region before you call\nany of these APIs, or a `HomeRegionNotSetException` error will be returned.\nAlso, you must make the API calls while in your home region.","ref":"AWS.MigrationHub.html","title":"AWS.MigrationHub","type":"module"},{"doc":"Associates a created artifact of an AWS cloud resource, the target receiving the\nmigration, with the migration task performed by a migration tool.\n\nThis API has the following traits:\n\n  * Migration tools can call the `AssociateCreatedArtifact` operation\nto indicate which AWS artifact is associated with a migration task.\n\n  * The created artifact name must be provided in ARN (Amazon Resource\nName) format which will contain information about type and region; for example:\n`arn:aws:ec2:us-east-1:488216288981:image/ami-6d0ba87b`.\n\n  * Examples of the AWS resource behind the created artifact are,\nAMI's, EC2 instance, or DMS endpoint, etc.","ref":"AWS.MigrationHub.html#associate_created_artifact/3","title":"AWS.MigrationHub.associate_created_artifact/3","type":"function"},{"doc":"Associates a discovered resource ID from Application Discovery Service with a\nmigration task.","ref":"AWS.MigrationHub.html#associate_discovered_resource/3","title":"AWS.MigrationHub.associate_discovered_resource/3","type":"function"},{"doc":"Creates a progress update stream which is an AWS resource used for access\ncontrol as well as a namespace for migration task names that is implicitly\nlinked to your AWS account.\n\nIt must uniquely identify the migration tool as it is used for all updates made\nby the tool; however, it does not need to be unique for each AWS account because\nit is scoped to the AWS account.","ref":"AWS.MigrationHub.html#create_progress_update_stream/3","title":"AWS.MigrationHub.create_progress_update_stream/3","type":"function"},{"doc":"Deletes a progress update stream, including all of its tasks, which was\npreviously created as an AWS resource used for access control.\n\nThis API has the following traits:\n\n  * The only parameter needed for `DeleteProgressUpdateStream` is the\nstream name (same as a `CreateProgressUpdateStream` call).\n\n  * The call will return, and a background process will asynchronously\ndelete the stream and all of its resources (tasks, associated resources,\nresource attributes, created artifacts).\n\n  * If the stream takes time to be deleted, it might still show up on\na `ListProgressUpdateStreams` call.\n\n  * `CreateProgressUpdateStream`, `ImportMigrationTask`,\n`NotifyMigrationTaskState`, and all Associate[*] APIs related to the tasks\nbelonging to the stream will throw \"InvalidInputException\" if the stream of the\nsame name is in the process of being deleted.\n\n  * Once the stream and all of its resources are deleted,\n`CreateProgressUpdateStream` for a stream of the same name will succeed, and\nthat stream will be an entirely new logical resource (without any resources\nassociated with the old stream).","ref":"AWS.MigrationHub.html#delete_progress_update_stream/3","title":"AWS.MigrationHub.delete_progress_update_stream/3","type":"function"},{"doc":"Gets the migration status of an application.","ref":"AWS.MigrationHub.html#describe_application_state/3","title":"AWS.MigrationHub.describe_application_state/3","type":"function"},{"doc":"Retrieves a list of all attributes associated with a specific migration task.","ref":"AWS.MigrationHub.html#describe_migration_task/3","title":"AWS.MigrationHub.describe_migration_task/3","type":"function"},{"doc":"Disassociates a created artifact of an AWS resource with a migration task\nperformed by a migration tool that was previously associated.\n\nThis API has the following traits:\n\n  * A migration user can call the `DisassociateCreatedArtifacts`\noperation to disassociate a created AWS Artifact from a migration task.\n\n  * The created artifact name must be provided in ARN (Amazon Resource\nName) format which will contain information about type and region; for example:\n`arn:aws:ec2:us-east-1:488216288981:image/ami-6d0ba87b`.\n\n  * Examples of the AWS resource behind the created artifact are,\nAMI's, EC2 instance, or RDS instance, etc.","ref":"AWS.MigrationHub.html#disassociate_created_artifact/3","title":"AWS.MigrationHub.disassociate_created_artifact/3","type":"function"},{"doc":"Disassociate an Application Discovery Service discovered resource from a\nmigration task.","ref":"AWS.MigrationHub.html#disassociate_discovered_resource/3","title":"AWS.MigrationHub.disassociate_discovered_resource/3","type":"function"},{"doc":"Registers a new migration task which represents a server, database, etc., being\nmigrated to AWS by a migration tool.\n\nThis API is a prerequisite to calling the `NotifyMigrationTaskState` API as the\nmigration tool must first register the migration task with Migration Hub.","ref":"AWS.MigrationHub.html#import_migration_task/3","title":"AWS.MigrationHub.import_migration_task/3","type":"function"},{"doc":"Lists all the migration statuses for your applications.\n\nIf you use the optional `ApplicationIds` parameter, only the migration statuses\nfor those applications will be returned.","ref":"AWS.MigrationHub.html#list_application_states/3","title":"AWS.MigrationHub.list_application_states/3","type":"function"},{"doc":"Lists the created artifacts attached to a given migration task in an update\nstream.\n\nThis API has the following traits:\n\n  * Gets the list of the created artifacts while migration is taking\nplace.\n\n  * Shows the artifacts created by the migration tool that was\nassociated by the `AssociateCreatedArtifact` API.\n\n  * Lists created artifacts in a paginated interface.","ref":"AWS.MigrationHub.html#list_created_artifacts/3","title":"AWS.MigrationHub.list_created_artifacts/3","type":"function"},{"doc":"Lists discovered resources associated with the given `MigrationTask`.","ref":"AWS.MigrationHub.html#list_discovered_resources/3","title":"AWS.MigrationHub.list_discovered_resources/3","type":"function"},{"doc":"Lists all, or filtered by resource name, migration tasks associated with the\nuser account making this call.\n\nThis API has the following traits:\n\n  * Can show a summary list of the most recent migration tasks.\n\n  * Can show a summary list of migration tasks associated with a given\ndiscovered resource.\n\n  * Lists migration tasks in a paginated interface.","ref":"AWS.MigrationHub.html#list_migration_tasks/3","title":"AWS.MigrationHub.list_migration_tasks/3","type":"function"},{"doc":"Lists progress update streams associated with the user account making this call.","ref":"AWS.MigrationHub.html#list_progress_update_streams/3","title":"AWS.MigrationHub.list_progress_update_streams/3","type":"function"},{"doc":"","ref":"AWS.MigrationHub.html#metadata/0","title":"AWS.MigrationHub.metadata/0","type":"function"},{"doc":"Sets the migration state of an application.\n\nFor a given application identified by the value passed to `ApplicationId`, its\nstatus is set or updated by passing one of three values to `Status`:\n`NOT_STARTED | IN_PROGRESS | COMPLETED`.","ref":"AWS.MigrationHub.html#notify_application_state/3","title":"AWS.MigrationHub.notify_application_state/3","type":"function"},{"doc":"Notifies Migration Hub of the current status, progress, or other detail\nregarding a migration task.\n\nThis API has the following traits:\n\n  * Migration tools will call the `NotifyMigrationTaskState` API to\nshare the latest progress and status.\n\n  * `MigrationTaskName` is used for addressing updates to the correct\ntarget.\n\n  * `ProgressUpdateStream` is used for access control and to provide a\nnamespace for each migration tool.","ref":"AWS.MigrationHub.html#notify_migration_task_state/3","title":"AWS.MigrationHub.notify_migration_task_state/3","type":"function"},{"doc":"Provides identifying details of the resource being migrated so that it can be\nassociated in the Application Discovery Service repository.\n\nThis association occurs asynchronously after `PutResourceAttributes` returns.\n\n   Keep in mind that subsequent calls to PutResourceAttributes will\noverride previously stored attributes. For example, if it is first called with a\nMAC address, but later, it is desired to *add* an IP address, it will then be\nrequired to call it with *both* the IP and MAC addresses to prevent overriding\nthe MAC address.\n\n   Note the instructions regarding the special use case of the [\n`ResourceAttributeList`\n](https://docs.aws.amazon.com/migrationhub/latest/ug/API_PutResourceAttributes.html#migrationhub-PutResourceAttributes-request-ResourceAttributeList)\nparameter when specifying any \"VM\" related value.\n\nBecause this is an asynchronous call, it will always return 200, whether an\nassociation occurs or not. To confirm if an association was found based on the\nprovided details, call `ListDiscoveredResources`.","ref":"AWS.MigrationHub.html#put_resource_attributes/3","title":"AWS.MigrationHub.put_resource_attributes/3","type":"function"},{"doc":"The AWS Migration Hub home region APIs are available specifically for working\nwith your Migration Hub home region.\n\nYou can use these APIs to determine a home region, as well as to create and work\nwith controls that describe the home region.\n\n  * You must make API calls for write actions (create, notify,\nassociate, disassociate, import, or put) while in your home region, or a\n`HomeRegionNotSetException` error is returned.\n\n  * API calls for read actions (list, describe, stop, and delete) are\npermitted outside of your home region.\n\n  * If you call a write API outside the home region, an\n`InvalidInputException` is returned.\n\n  * You can call `GetHomeRegion` action to obtain the account's\nMigration Hub home region.\n\nFor specific API usage, see the sections that follow in this AWS Migration Hub\nHome Region API reference.","ref":"AWS.MigrationHubConfig.html","title":"AWS.MigrationHubConfig","type":"module"},{"doc":"This API sets up the home region for the calling account only.","ref":"AWS.MigrationHubConfig.html#create_home_region_control/3","title":"AWS.MigrationHubConfig.create_home_region_control/3","type":"function"},{"doc":"This operation deletes the home region configuration for the calling account.\n\nThe operation does not delete discovery or migration tracking data in the home\nregion.","ref":"AWS.MigrationHubConfig.html#delete_home_region_control/3","title":"AWS.MigrationHubConfig.delete_home_region_control/3","type":"function"},{"doc":"This API permits filtering on the `ControlId` and `HomeRegion` fields.","ref":"AWS.MigrationHubConfig.html#describe_home_region_controls/3","title":"AWS.MigrationHubConfig.describe_home_region_controls/3","type":"function"},{"doc":"Returns the calling account’s home region, if configured.\n\nThis API is used by other AWS services to determine the regional endpoint for\ncalling AWS Application Discovery Service and Migration Hub. You must call\n`GetHomeRegion` at least once before you call any other AWS Application\nDiscovery Service and AWS Migration Hub APIs, to obtain the account's Migration\nHub home region.","ref":"AWS.MigrationHubConfig.html#get_home_region/3","title":"AWS.MigrationHubConfig.get_home_region/3","type":"function"},{"doc":"","ref":"AWS.MigrationHubConfig.html#metadata/0","title":"AWS.MigrationHubConfig.metadata/0","type":"function"},{"doc":"This API reference provides descriptions, syntax, and other details about each\nof the actions and data types for AWS Migration Hub Orchestrator.\n\nhe topic for each action shows the API request parameters and the response.\nAlternatively, you can use one of the AWS SDKs to access an API that is tailored\nto the programming language or platform that you're using.","ref":"AWS.MigrationHubOrchestrator.html","title":"AWS.MigrationHubOrchestrator","type":"module"},{"doc":"Create a workflow to orchestrate your migrations.","ref":"AWS.MigrationHubOrchestrator.html#create_workflow/3","title":"AWS.MigrationHubOrchestrator.create_workflow/3","type":"function"},{"doc":"Create a step in the migration workflow.","ref":"AWS.MigrationHubOrchestrator.html#create_workflow_step/3","title":"AWS.MigrationHubOrchestrator.create_workflow_step/3","type":"function"},{"doc":"Create a step group in a migration workflow.","ref":"AWS.MigrationHubOrchestrator.html#create_workflow_step_group/3","title":"AWS.MigrationHubOrchestrator.create_workflow_step_group/3","type":"function"},{"doc":"Delete a migration workflow.\n\nYou must pause a running workflow in Migration Hub Orchestrator console to\ndelete it.","ref":"AWS.MigrationHubOrchestrator.html#delete_workflow/4","title":"AWS.MigrationHubOrchestrator.delete_workflow/4","type":"function"},{"doc":"Delete a step in a migration workflow.\n\nPause the workflow to delete a running step.","ref":"AWS.MigrationHubOrchestrator.html#delete_workflow_step/4","title":"AWS.MigrationHubOrchestrator.delete_workflow_step/4","type":"function"},{"doc":"Delete a step group in a migration workflow.","ref":"AWS.MigrationHubOrchestrator.html#delete_workflow_step_group/4","title":"AWS.MigrationHubOrchestrator.delete_workflow_step_group/4","type":"function"},{"doc":"Get the template you want to use for creating a migration workflow.","ref":"AWS.MigrationHubOrchestrator.html#get_template/3","title":"AWS.MigrationHubOrchestrator.get_template/3","type":"function"},{"doc":"Get a specific step in a template.","ref":"AWS.MigrationHubOrchestrator.html#get_template_step/5","title":"AWS.MigrationHubOrchestrator.get_template_step/5","type":"function"},{"doc":"Get a step group in a template.","ref":"AWS.MigrationHubOrchestrator.html#get_template_step_group/4","title":"AWS.MigrationHubOrchestrator.get_template_step_group/4","type":"function"},{"doc":"Get migration workflow.","ref":"AWS.MigrationHubOrchestrator.html#get_workflow/3","title":"AWS.MigrationHubOrchestrator.get_workflow/3","type":"function"},{"doc":"Get a step in the migration workflow.","ref":"AWS.MigrationHubOrchestrator.html#get_workflow_step/5","title":"AWS.MigrationHubOrchestrator.get_workflow_step/5","type":"function"},{"doc":"Get the step group of a migration workflow.","ref":"AWS.MigrationHubOrchestrator.html#get_workflow_step_group/4","title":"AWS.MigrationHubOrchestrator.get_workflow_step_group/4","type":"function"},{"doc":"List AWS Migration Hub Orchestrator plugins.","ref":"AWS.MigrationHubOrchestrator.html#list_plugins/4","title":"AWS.MigrationHubOrchestrator.list_plugins/4","type":"function"},{"doc":"List the tags added to a resource.","ref":"AWS.MigrationHubOrchestrator.html#list_tags_for_resource/3","title":"AWS.MigrationHubOrchestrator.list_tags_for_resource/3","type":"function"},{"doc":"List the step groups in a template.","ref":"AWS.MigrationHubOrchestrator.html#list_template_step_groups/5","title":"AWS.MigrationHubOrchestrator.list_template_step_groups/5","type":"function"},{"doc":"List the steps in a template.","ref":"AWS.MigrationHubOrchestrator.html#list_template_steps/6","title":"AWS.MigrationHubOrchestrator.list_template_steps/6","type":"function"},{"doc":"List the templates available in Migration Hub Orchestrator to create a migration\nworkflow.","ref":"AWS.MigrationHubOrchestrator.html#list_templates/5","title":"AWS.MigrationHubOrchestrator.list_templates/5","type":"function"},{"doc":"List the step groups in a migration workflow.","ref":"AWS.MigrationHubOrchestrator.html#list_workflow_step_groups/5","title":"AWS.MigrationHubOrchestrator.list_workflow_step_groups/5","type":"function"},{"doc":"List the steps in a workflow.","ref":"AWS.MigrationHubOrchestrator.html#list_workflow_steps/6","title":"AWS.MigrationHubOrchestrator.list_workflow_steps/6","type":"function"},{"doc":"List the migration workflows.","ref":"AWS.MigrationHubOrchestrator.html#list_workflows/8","title":"AWS.MigrationHubOrchestrator.list_workflows/8","type":"function"},{"doc":"","ref":"AWS.MigrationHubOrchestrator.html#metadata/0","title":"AWS.MigrationHubOrchestrator.metadata/0","type":"function"},{"doc":"Retry a failed step in a migration workflow.","ref":"AWS.MigrationHubOrchestrator.html#retry_workflow_step/4","title":"AWS.MigrationHubOrchestrator.retry_workflow_step/4","type":"function"},{"doc":"Start a migration workflow.","ref":"AWS.MigrationHubOrchestrator.html#start_workflow/4","title":"AWS.MigrationHubOrchestrator.start_workflow/4","type":"function"},{"doc":"Stop an ongoing migration workflow.","ref":"AWS.MigrationHubOrchestrator.html#stop_workflow/4","title":"AWS.MigrationHubOrchestrator.stop_workflow/4","type":"function"},{"doc":"Tag a resource by specifying its Amazon Resource Name (ARN).","ref":"AWS.MigrationHubOrchestrator.html#tag_resource/4","title":"AWS.MigrationHubOrchestrator.tag_resource/4","type":"function"},{"doc":"Deletes the tags for a resource.","ref":"AWS.MigrationHubOrchestrator.html#untag_resource/4","title":"AWS.MigrationHubOrchestrator.untag_resource/4","type":"function"},{"doc":"Update a migration workflow.","ref":"AWS.MigrationHubOrchestrator.html#update_workflow/4","title":"AWS.MigrationHubOrchestrator.update_workflow/4","type":"function"},{"doc":"Update a step in a migration workflow.","ref":"AWS.MigrationHubOrchestrator.html#update_workflow_step/4","title":"AWS.MigrationHubOrchestrator.update_workflow_step/4","type":"function"},{"doc":"Update the step group in a migration workflow.","ref":"AWS.MigrationHubOrchestrator.html#update_workflow_step_group/4","title":"AWS.MigrationHubOrchestrator.update_workflow_step_group/4","type":"function"},{"doc":"Amazon Web Services Migration Hub Refactor Spaces\n\nThis API reference provides descriptions, syntax, and other details about each\nof the actions and data types for Amazon Web Services Migration Hub Refactor\nSpaces (Refactor Spaces).\n\nThe topic for each action shows the API request parameters and the response.\nAlternatively, you can use one of the Amazon Web Services SDKs to access an API\nthat is tailored to the programming language or platform that you're using. For\nmore information, see [Amazon Web Services SDKs](https://aws.amazon.com/tools/#SDKs).\n\nTo share Refactor Spaces environments with other Amazon Web Services accounts or\nwith Organizations and their OUs, use Resource Access Manager's\n`CreateResourceShare` API. See\n[CreateResourceShare](https://docs.aws.amazon.com/ram/latest/APIReference/API_CreateResourceShare.html)\nin the *Amazon Web Services RAM API Reference*.","ref":"AWS.MigrationHubRefactorSpaces.html","title":"AWS.MigrationHubRefactorSpaces","type":"module"},{"doc":"Creates an Amazon Web Services Migration Hub Refactor Spaces application.\n\nThe account that owns the environment also owns the applications created inside\nthe environment, regardless of the account that creates the application.\nRefactor Spaces provisions an Amazon API Gateway, API Gateway VPC link, and\nNetwork Load Balancer for the application proxy inside your account.\n\nIn environments created with a\n[CreateEnvironment:NetworkFabricType](https://docs.aws.amazon.com/migrationhub-refactor-spaces/latest/APIReference/API_CreateEnvironment.html#migrationhubrefactorspaces-CreateEnvironment-request-NetworkFabricType) of `NONE` you need to configure [ VPC to VPC\nconnectivity](https://docs.aws.amazon.com/whitepapers/latest/aws-vpc-connectivity-options/amazon-vpc-to-amazon-vpc-connectivity-options.html)\nbetween your service VPC and the application proxy VPC to route traffic through\nthe application proxy to a service with a private URL endpoint. For more\ninformation, see [ Create an application](https://docs.aws.amazon.com/migrationhub-refactor-spaces/latest/userguide/getting-started-create-application.html)\nin the *Refactor Spaces User Guide*.","ref":"AWS.MigrationHubRefactorSpaces.html#create_application/4","title":"AWS.MigrationHubRefactorSpaces.create_application/4","type":"function"},{"doc":"Creates an Amazon Web Services Migration Hub Refactor Spaces environment.\n\nThe caller owns the environment resource, and all Refactor Spaces applications,\nservices, and routes created within the environment. They are referred to as the\n*environment owner*. The environment owner has cross-account visibility and\ncontrol of Refactor Spaces resources that are added to the environment by other\naccounts that the environment is shared with.\n\nWhen creating an environment with a\n[CreateEnvironment:NetworkFabricType](https://docs.aws.amazon.com/migrationhub-refactor-spaces/latest/APIReference/API_CreateEnvironment.html#migrationhubrefactorspaces-CreateEnvironment-request-NetworkFabricType) of `TRANSIT_GATEWAY`, Refactor Spaces provisions a transit gateway to enable\nservices in VPCs to communicate directly across accounts. If\n[CreateEnvironment:NetworkFabricType](https://docs.aws.amazon.com/migrationhub-refactor-spaces/latest/APIReference/API_CreateEnvironment.html#migrationhubrefactorspaces-CreateEnvironment-request-NetworkFabricType)\nis `NONE`, Refactor Spaces does not create a transit gateway and you must use\nyour network infrastructure to route traffic to services with private URL\nendpoints.","ref":"AWS.MigrationHubRefactorSpaces.html#create_environment/3","title":"AWS.MigrationHubRefactorSpaces.create_environment/3","type":"function"},{"doc":"Creates an Amazon Web Services Migration Hub Refactor Spaces route.\n\nThe account owner of the service resource is always the environment owner,\nregardless of which account creates the route. Routes target a service in the\napplication. If an application does not have any routes, then the first route\nmust be created as a `DEFAULT` `RouteType`.\n\nWhen created, the default route defaults to an active state so state is not a\nrequired input. However, like all other state values the state of the default\nroute can be updated after creation, but only when all other routes are also\ninactive. Conversely, no route can be active without the default route also\nbeing active.\n\nWhen you create a route, Refactor Spaces configures the Amazon API Gateway to\nsend traffic to the target service as follows:\n\n  *","ref":"AWS.MigrationHubRefactorSpaces.html#create_route/5","title":"AWS.MigrationHubRefactorSpaces.create_route/5","type":"function"},{"doc":"If the service has a URL endpoint, and the endpoint resolves to a private IP\naddress, Refactor Spaces routes traffic using the API Gateway VPC link. If a\nservice endpoint resolves to a public IP address, Refactor Spaces routes traffic\nover the public internet. Services can have HTTP or HTTPS URL endpoints. For\nHTTPS URLs, publicly-signed certificates are supported. Private Certificate\nAuthorities (CAs) are permitted only if the CA's domain is also publicly\nresolvable.\n\nRefactor Spaces automatically resolves the public Domain Name System (DNS) names\nthat are set in `CreateService:UrlEndpoint `when you create a service. The DNS\nnames resolve when the DNS time-to-live (TTL) expires, or every 60 seconds for\nTTLs less than 60 seconds. This periodic DNS resolution ensures that the route\nconfiguration remains up-to-date.","ref":"AWS.MigrationHubRefactorSpaces.html#create_route/5-url-endpoints","title":"URL Endpoints - AWS.MigrationHubRefactorSpaces.create_route/5","type":"function"},{"doc":"A one-time health check is performed on the service when either the route is\nupdated from inactive to active, or when it is created with an active state. If\nthe health check fails, the route transitions the route state to `FAILED`, an\nerror code of `SERVICE_ENDPOINT_HEALTH_CHECK_FAILURE` is provided, and no\ntraffic is sent to the service.\n\nFor private URLs, a target group is created on the Network Load Balancer and the\nload balancer target group runs default target health checks. By default, the\nhealth check is run against the service endpoint URL. Optionally, the health\ncheck can be performed against a different protocol, port, and/or path using the\n[CreateService:UrlEndpoint](https://docs.aws.amazon.com/migrationhub-refactor-spaces/latest/APIReference/API_CreateService.html#migrationhubrefactorspaces-CreateService-request-UrlEndpoint) parameter. All other health check settings for the load balancer use the default\nvalues described in the [Health checks for your target\ngroups](https://docs.aws.amazon.com/elasticloadbalancing/latest/application/target-group-health-checks.html)\nin the *Elastic Load Balancing guide*. The health check is considered successful\nif at least one target within the target group transitions to a healthy state.\n\n  *","ref":"AWS.MigrationHubRefactorSpaces.html#create_route/5-one-time-health-check","title":"One-time health check - AWS.MigrationHubRefactorSpaces.create_route/5","type":"function"},{"doc":"If the service has an Lambda function endpoint, then Refactor Spaces configures\nthe Lambda function's resource policy to allow the application's API Gateway to\ninvoke the function.\n\nThe Lambda function state is checked. If the function is not active, the\nfunction configuration is updated so that Lambda resources are provisioned. If\nthe Lambda state is `Failed`, then the route creation fails. For more\ninformation, see the [GetFunctionConfiguration's State response parameter](https://docs.aws.amazon.com/lambda/latest/dg/API_GetFunctionConfiguration.html#SSS-GetFunctionConfiguration-response-State)\nin the *Lambda Developer Guide*.\n\nA check is performed to determine that a Lambda function with the specified ARN\nexists. If it does not exist, the health check fails. For public URLs, a\nconnection is opened to the public endpoint. If the URL is not reachable, the\nhealth check fails.","ref":"AWS.MigrationHubRefactorSpaces.html#create_route/5-lambda-function-endpoints","title":"Lambda function endpoints - AWS.MigrationHubRefactorSpaces.create_route/5","type":"function"},{"doc":"When you create environments without a network bridge\n([CreateEnvironment:NetworkFabricType](https://docs.aws.amazon.com/migrationhub-refactor-spaces/latest/APIReference/API_CreateEnvironment.html#migrationhubrefactorspaces-CreateEnvironment-request-NetworkFabricType) is `NONE)` and you use your own networking infrastructure, you need to configure\n[VPC to VPC\nconnectivity](https://docs.aws.amazon.com/whitepapers/latest/aws-vpc-connectivity-options/amazon-vpc-to-amazon-vpc-connectivity-options.html)\nbetween your network and the application proxy VPC. Route creation from the\napplication proxy to service endpoints will fail if your network is not\nconfigured to connect to the application proxy VPC. For more information, see [\nCreate a\nroute](https://docs.aws.amazon.com/migrationhub-refactor-spaces/latest/userguide/getting-started-create-role.html)\nin the *Refactor Spaces User Guide*.","ref":"AWS.MigrationHubRefactorSpaces.html#create_route/5-environments-without-a-network-bridge","title":"Environments without a network bridge - AWS.MigrationHubRefactorSpaces.create_route/5","type":"function"},{"doc":"Creates an Amazon Web Services Migration Hub Refactor Spaces service.\n\nThe account owner of the service is always the environment owner, regardless of\nwhich account in the environment creates the service. Services have either a URL\nendpoint in a virtual private cloud (VPC), or a Lambda function endpoint.\n\nIf an Amazon Web Services resource is launched in a service VPC, and you want it\nto be accessible to all of an environment’s services with VPCs and routes, apply\nthe `RefactorSpacesSecurityGroup` to the resource. Alternatively, to add more\ncross-account constraints, apply your own security group.","ref":"AWS.MigrationHubRefactorSpaces.html#create_service/5","title":"AWS.MigrationHubRefactorSpaces.create_service/5","type":"function"},{"doc":"Deletes an Amazon Web Services Migration Hub Refactor Spaces application.\n\nBefore you can delete an application, you must first delete any services or\nroutes within the application.","ref":"AWS.MigrationHubRefactorSpaces.html#delete_application/5","title":"AWS.MigrationHubRefactorSpaces.delete_application/5","type":"function"},{"doc":"Deletes an Amazon Web Services Migration Hub Refactor Spaces environment.\n\nBefore you can delete an environment, you must first delete any applications and\nservices within the environment.","ref":"AWS.MigrationHubRefactorSpaces.html#delete_environment/4","title":"AWS.MigrationHubRefactorSpaces.delete_environment/4","type":"function"},{"doc":"Deletes the resource policy set for the environment.","ref":"AWS.MigrationHubRefactorSpaces.html#delete_resource_policy/4","title":"AWS.MigrationHubRefactorSpaces.delete_resource_policy/4","type":"function"},{"doc":"Deletes an Amazon Web Services Migration Hub Refactor Spaces route.","ref":"AWS.MigrationHubRefactorSpaces.html#delete_route/6","title":"AWS.MigrationHubRefactorSpaces.delete_route/6","type":"function"},{"doc":"Deletes an Amazon Web Services Migration Hub Refactor Spaces service.","ref":"AWS.MigrationHubRefactorSpaces.html#delete_service/6","title":"AWS.MigrationHubRefactorSpaces.delete_service/6","type":"function"},{"doc":"Gets an Amazon Web Services Migration Hub Refactor Spaces application.","ref":"AWS.MigrationHubRefactorSpaces.html#get_application/4","title":"AWS.MigrationHubRefactorSpaces.get_application/4","type":"function"},{"doc":"Gets an Amazon Web Services Migration Hub Refactor Spaces environment.","ref":"AWS.MigrationHubRefactorSpaces.html#get_environment/3","title":"AWS.MigrationHubRefactorSpaces.get_environment/3","type":"function"},{"doc":"Gets the resource-based permission policy that is set for the given environment.","ref":"AWS.MigrationHubRefactorSpaces.html#get_resource_policy/3","title":"AWS.MigrationHubRefactorSpaces.get_resource_policy/3","type":"function"},{"doc":"Gets an Amazon Web Services Migration Hub Refactor Spaces route.","ref":"AWS.MigrationHubRefactorSpaces.html#get_route/5","title":"AWS.MigrationHubRefactorSpaces.get_route/5","type":"function"},{"doc":"Gets an Amazon Web Services Migration Hub Refactor Spaces service.","ref":"AWS.MigrationHubRefactorSpaces.html#get_service/5","title":"AWS.MigrationHubRefactorSpaces.get_service/5","type":"function"},{"doc":"Lists all the Amazon Web Services Migration Hub Refactor Spaces applications\nwithin an environment.","ref":"AWS.MigrationHubRefactorSpaces.html#list_applications/5","title":"AWS.MigrationHubRefactorSpaces.list_applications/5","type":"function"},{"doc":"Lists all Amazon Web Services Migration Hub Refactor Spaces service virtual\nprivate clouds (VPCs) that are part of the environment.","ref":"AWS.MigrationHubRefactorSpaces.html#list_environment_vpcs/5","title":"AWS.MigrationHubRefactorSpaces.list_environment_vpcs/5","type":"function"},{"doc":"Lists Amazon Web Services Migration Hub Refactor Spaces environments owned by a\ncaller account or shared with the caller account.","ref":"AWS.MigrationHubRefactorSpaces.html#list_environments/4","title":"AWS.MigrationHubRefactorSpaces.list_environments/4","type":"function"},{"doc":"Lists all the Amazon Web Services Migration Hub Refactor Spaces routes within an\napplication.","ref":"AWS.MigrationHubRefactorSpaces.html#list_routes/6","title":"AWS.MigrationHubRefactorSpaces.list_routes/6","type":"function"},{"doc":"Lists all the Amazon Web Services Migration Hub Refactor Spaces services within\nan application.","ref":"AWS.MigrationHubRefactorSpaces.html#list_services/6","title":"AWS.MigrationHubRefactorSpaces.list_services/6","type":"function"},{"doc":"Lists the tags of a resource.\n\nThe caller account must be the same as the resource’s `OwnerAccountId`. Listing\ntags in other accounts is not supported.","ref":"AWS.MigrationHubRefactorSpaces.html#list_tags_for_resource/3","title":"AWS.MigrationHubRefactorSpaces.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.MigrationHubRefactorSpaces.html#metadata/0","title":"AWS.MigrationHubRefactorSpaces.metadata/0","type":"function"},{"doc":"Attaches a resource-based permission policy to the Amazon Web Services Migration\nHub Refactor Spaces environment.\n\nThe policy must contain the same actions and condition statements as the\n`arn:aws:ram::aws:permission/AWSRAMDefaultPermissionRefactorSpacesEnvironment`\npermission in Resource Access Manager. The policy must not contain new lines or\nblank lines.","ref":"AWS.MigrationHubRefactorSpaces.html#put_resource_policy/3","title":"AWS.MigrationHubRefactorSpaces.put_resource_policy/3","type":"function"},{"doc":"Removes the tags of a given resource.\n\nTags are metadata which can be used to manage a resource. To tag a resource, the\ncaller account must be the same as the resource’s `OwnerAccountId`. Tagging\nresources in other accounts is not supported.\n\nAmazon Web Services Migration Hub Refactor Spaces does not propagate tags to\norchestrated resources, such as an environment’s transit gateway.","ref":"AWS.MigrationHubRefactorSpaces.html#tag_resource/4","title":"AWS.MigrationHubRefactorSpaces.tag_resource/4","type":"function"},{"doc":"Adds to or modifies the tags of the given resource.\n\nTags are metadata which can be used to manage a resource. To untag a resource,\nthe caller account must be the same as the resource’s `OwnerAccountId`.\nUntagging resources across accounts is not supported.","ref":"AWS.MigrationHubRefactorSpaces.html#untag_resource/4","title":"AWS.MigrationHubRefactorSpaces.untag_resource/4","type":"function"},{"doc":"Updates an Amazon Web Services Migration Hub Refactor Spaces route.","ref":"AWS.MigrationHubRefactorSpaces.html#update_route/6","title":"AWS.MigrationHubRefactorSpaces.update_route/6","type":"function"},{"doc":"Migration Hub Strategy Recommendations\n\nThis API reference provides descriptions, syntax, and other details about each\nof the actions and data types for Migration Hub Strategy Recommendations\n(Strategy Recommendations).\n\nThe topic for each action shows the API request parameters and the response.\nAlternatively, you can use one of the AWS SDKs to access an API that is tailored\nto the programming language or platform that you're using. For more information,\nsee [AWS SDKs](http://aws.amazon.com/tools/#SDKs).","ref":"AWS.MigrationHubStrategy.html","title":"AWS.MigrationHubStrategy","type":"module"},{"doc":"Retrieves details about an application component.","ref":"AWS.MigrationHubStrategy.html#get_application_component_details/3","title":"AWS.MigrationHubStrategy.get_application_component_details/3","type":"function"},{"doc":"Retrieves a list of all the recommended strategies and tools for an application\ncomponent running on a server.","ref":"AWS.MigrationHubStrategy.html#get_application_component_strategies/3","title":"AWS.MigrationHubStrategy.get_application_component_strategies/3","type":"function"},{"doc":"Retrieves the status of an on-going assessment.","ref":"AWS.MigrationHubStrategy.html#get_assessment/3","title":"AWS.MigrationHubStrategy.get_assessment/3","type":"function"},{"doc":"Retrieves the details about a specific import task.","ref":"AWS.MigrationHubStrategy.html#get_import_file_task/3","title":"AWS.MigrationHubStrategy.get_import_file_task/3","type":"function"},{"doc":"Retrieve the latest ID of a specific assessment task.","ref":"AWS.MigrationHubStrategy.html#get_latest_assessment_id/2","title":"AWS.MigrationHubStrategy.get_latest_assessment_id/2","type":"function"},{"doc":"Retrieves your migration and modernization preferences.","ref":"AWS.MigrationHubStrategy.html#get_portfolio_preferences/2","title":"AWS.MigrationHubStrategy.get_portfolio_preferences/2","type":"function"},{"doc":"Retrieves overall summary including the number of servers to rehost and the\noverall number of anti-patterns.","ref":"AWS.MigrationHubStrategy.html#get_portfolio_summary/2","title":"AWS.MigrationHubStrategy.get_portfolio_summary/2","type":"function"},{"doc":"Retrieves detailed information about the specified recommendation report.","ref":"AWS.MigrationHubStrategy.html#get_recommendation_report_details/3","title":"AWS.MigrationHubStrategy.get_recommendation_report_details/3","type":"function"},{"doc":"Retrieves detailed information about a specified server.","ref":"AWS.MigrationHubStrategy.html#get_server_details/5","title":"AWS.MigrationHubStrategy.get_server_details/5","type":"function"},{"doc":"Retrieves recommended strategies and tools for the specified server.","ref":"AWS.MigrationHubStrategy.html#get_server_strategies/3","title":"AWS.MigrationHubStrategy.get_server_strategies/3","type":"function"},{"doc":"Retrieves a list of all the servers fetched from customer vCenter using Strategy\nRecommendation Collector.","ref":"AWS.MigrationHubStrategy.html#list_analyzable_servers/3","title":"AWS.MigrationHubStrategy.list_analyzable_servers/3","type":"function"},{"doc":"Retrieves a list of all the application components (processes).","ref":"AWS.MigrationHubStrategy.html#list_application_components/3","title":"AWS.MigrationHubStrategy.list_application_components/3","type":"function"},{"doc":"Retrieves a list of all the installed collectors.","ref":"AWS.MigrationHubStrategy.html#list_collectors/4","title":"AWS.MigrationHubStrategy.list_collectors/4","type":"function"},{"doc":"Retrieves a list of all the imports performed.","ref":"AWS.MigrationHubStrategy.html#list_import_file_task/4","title":"AWS.MigrationHubStrategy.list_import_file_task/4","type":"function"},{"doc":"Returns a list of all the servers.","ref":"AWS.MigrationHubStrategy.html#list_servers/3","title":"AWS.MigrationHubStrategy.list_servers/3","type":"function"},{"doc":"","ref":"AWS.MigrationHubStrategy.html#metadata/0","title":"AWS.MigrationHubStrategy.metadata/0","type":"function"},{"doc":"Saves the specified migration and modernization preferences.","ref":"AWS.MigrationHubStrategy.html#put_portfolio_preferences/3","title":"AWS.MigrationHubStrategy.put_portfolio_preferences/3","type":"function"},{"doc":"Starts the assessment of an on-premises environment.","ref":"AWS.MigrationHubStrategy.html#start_assessment/3","title":"AWS.MigrationHubStrategy.start_assessment/3","type":"function"},{"doc":"Starts a file import.","ref":"AWS.MigrationHubStrategy.html#start_import_file_task/3","title":"AWS.MigrationHubStrategy.start_import_file_task/3","type":"function"},{"doc":"Starts generating a recommendation report.","ref":"AWS.MigrationHubStrategy.html#start_recommendation_report_generation/3","title":"AWS.MigrationHubStrategy.start_recommendation_report_generation/3","type":"function"},{"doc":"Stops the assessment of an on-premises environment.","ref":"AWS.MigrationHubStrategy.html#stop_assessment/3","title":"AWS.MigrationHubStrategy.stop_assessment/3","type":"function"},{"doc":"Updates the configuration of an application component.","ref":"AWS.MigrationHubStrategy.html#update_application_component_config/3","title":"AWS.MigrationHubStrategy.update_application_component_config/3","type":"function"},{"doc":"Updates the configuration of the specified server.","ref":"AWS.MigrationHubStrategy.html#update_server_config/3","title":"AWS.MigrationHubStrategy.update_server_config/3","type":"function"},{"doc":"AWS Mobile Service provides mobile app and website developers with capabilities\nrequired to configure AWS resources and bootstrap their developer desktop\nprojects with the necessary SDKs, constants, tools and samples to make use of\nthose resources.","ref":"AWS.Mobile.html","title":"AWS.Mobile","type":"module"},{"doc":"Creates an AWS Mobile Hub project.","ref":"AWS.Mobile.html#create_project/3","title":"AWS.Mobile.create_project/3","type":"function"},{"doc":"Delets a project in AWS Mobile Hub.","ref":"AWS.Mobile.html#delete_project/4","title":"AWS.Mobile.delete_project/4","type":"function"},{"doc":"Get the bundle details for the requested bundle id.","ref":"AWS.Mobile.html#describe_bundle/3","title":"AWS.Mobile.describe_bundle/3","type":"function"},{"doc":"Gets details about a project in AWS Mobile Hub.","ref":"AWS.Mobile.html#describe_project/4","title":"AWS.Mobile.describe_project/4","type":"function"},{"doc":"Generates customized software development kit (SDK) and or tool packages used to\nintegrate mobile web or mobile app clients with backend AWS resources.","ref":"AWS.Mobile.html#export_bundle/4","title":"AWS.Mobile.export_bundle/4","type":"function"},{"doc":"Exports project configuration to a snapshot which can be downloaded and shared.\n\nNote that mobile app push credentials are encrypted in exported projects, so\nthey can only be shared successfully within the same AWS account.","ref":"AWS.Mobile.html#export_project/4","title":"AWS.Mobile.export_project/4","type":"function"},{"doc":"List all available bundles.","ref":"AWS.Mobile.html#list_bundles/4","title":"AWS.Mobile.list_bundles/4","type":"function"},{"doc":"Lists projects in AWS Mobile Hub.","ref":"AWS.Mobile.html#list_projects/4","title":"AWS.Mobile.list_projects/4","type":"function"},{"doc":"","ref":"AWS.Mobile.html#metadata/0","title":"AWS.Mobile.metadata/0","type":"function"},{"doc":"Update an existing project.","ref":"AWS.Mobile.html#update_project/3","title":"AWS.Mobile.update_project/3","type":"function"},{"doc":"Amazon Mobile Analytics is a service for collecting, visualizing, and\nunderstanding app usage data at scale.","ref":"AWS.MobileAnalytics.html","title":"AWS.MobileAnalytics","type":"module"},{"doc":"","ref":"AWS.MobileAnalytics.html#metadata/0","title":"AWS.MobileAnalytics.metadata/0","type":"function"},{"doc":"The PutEvents operation records one or more events.\n\nYou can have up to 1,500 unique custom events per app, any combination of up to\n40 attributes and metrics per custom event, and any number of attribute or\nmetric values.","ref":"AWS.MobileAnalytics.html#put_events/3","title":"AWS.MobileAnalytics.put_events/3","type":"function"},{"doc":"Amazon MQ is a managed message broker service for Apache ActiveMQ and RabbitMQ\nthat makes it easy to set up and operate message brokers in the cloud.\n\nA message broker allows software applications and components to communicate\nusing various programming languages, operating systems, and formal messaging\nprotocols.","ref":"AWS.Mq.html","title":"AWS.Mq","type":"module"},{"doc":"Creates a broker.\n\nNote: This API is asynchronous.\n\nTo create a broker, you must either use the AmazonMQFullAccess IAM policy or\ninclude the following EC2 permissions in your IAM policy.\n\n  * ec2:CreateNetworkInterface\n\nThis permission is required to allow Amazon MQ to create an elastic network\ninterface (ENI) on behalf of your account.\n\n  * ec2:CreateNetworkInterfacePermission\n\nThis permission is required to attach the ENI to the broker instance.\n\n  * ec2:DeleteNetworkInterface\n\n  * ec2:DeleteNetworkInterfacePermission\n\n  * ec2:DetachNetworkInterface\n\n  * ec2:DescribeInternetGateways\n\n  * ec2:DescribeNetworkInterfaces\n\n  * ec2:DescribeNetworkInterfacePermissions\n\n  * ec2:DescribeRouteTables\n\n  * ec2:DescribeSecurityGroups\n\n  * ec2:DescribeSubnets\n\n  * ec2:DescribeVpcs\n\nFor more information, see [Create an IAM User and Get Your Amazon Web Services Credentials](https://docs.aws.amazon.com//amazon-mq/latest/developer-guide/amazon-mq-setting-up.html#create-iam-user)\nand [Never Modify or Delete the Amazon MQ Elastic Network Interface](https://docs.aws.amazon.com//amazon-mq/latest/developer-guide/connecting-to-amazon-mq.html#never-modify-delete-elastic-network-interface)\nin the *Amazon MQ Developer Guide*.","ref":"AWS.Mq.html#create_broker/3","title":"AWS.Mq.create_broker/3","type":"function"},{"doc":"Creates a new configuration for the specified configuration name.\n\nAmazon MQ uses the default configuration (the engine type and version).","ref":"AWS.Mq.html#create_configuration/3","title":"AWS.Mq.create_configuration/3","type":"function"},{"doc":"Add a tag to a resource.","ref":"AWS.Mq.html#create_tags/4","title":"AWS.Mq.create_tags/4","type":"function"},{"doc":"Creates an ActiveMQ user.\n\nDo not add personally identifiable information (PII) or other confidential or\nsensitive information in broker usernames. Broker usernames are accessible to\nother Amazon Web Services services, including CloudWatch Logs. Broker usernames\nare not intended to be used for private or sensitive data.","ref":"AWS.Mq.html#create_user/5","title":"AWS.Mq.create_user/5","type":"function"},{"doc":"Deletes a broker.\n\nNote: This API is asynchronous.","ref":"AWS.Mq.html#delete_broker/4","title":"AWS.Mq.delete_broker/4","type":"function"},{"doc":"Removes a tag from a resource.","ref":"AWS.Mq.html#delete_tags/4","title":"AWS.Mq.delete_tags/4","type":"function"},{"doc":"Deletes an ActiveMQ user.","ref":"AWS.Mq.html#delete_user/5","title":"AWS.Mq.delete_user/5","type":"function"},{"doc":"Returns information about the specified broker.","ref":"AWS.Mq.html#describe_broker/3","title":"AWS.Mq.describe_broker/3","type":"function"},{"doc":"Describe available engine types and versions.","ref":"AWS.Mq.html#describe_broker_engine_types/5","title":"AWS.Mq.describe_broker_engine_types/5","type":"function"},{"doc":"Describe available broker instance options.","ref":"AWS.Mq.html#describe_broker_instance_options/7","title":"AWS.Mq.describe_broker_instance_options/7","type":"function"},{"doc":"Returns information about the specified configuration.","ref":"AWS.Mq.html#describe_configuration/3","title":"AWS.Mq.describe_configuration/3","type":"function"},{"doc":"Returns the specified configuration revision for the specified configuration.","ref":"AWS.Mq.html#describe_configuration_revision/4","title":"AWS.Mq.describe_configuration_revision/4","type":"function"},{"doc":"Returns information about an ActiveMQ user.","ref":"AWS.Mq.html#describe_user/4","title":"AWS.Mq.describe_user/4","type":"function"},{"doc":"Returns a list of all brokers.","ref":"AWS.Mq.html#list_brokers/4","title":"AWS.Mq.list_brokers/4","type":"function"},{"doc":"Returns a list of all revisions for the specified configuration.","ref":"AWS.Mq.html#list_configuration_revisions/5","title":"AWS.Mq.list_configuration_revisions/5","type":"function"},{"doc":"Returns a list of all configurations.","ref":"AWS.Mq.html#list_configurations/4","title":"AWS.Mq.list_configurations/4","type":"function"},{"doc":"Lists tags for a resource.","ref":"AWS.Mq.html#list_tags/3","title":"AWS.Mq.list_tags/3","type":"function"},{"doc":"Returns a list of all ActiveMQ users.","ref":"AWS.Mq.html#list_users/5","title":"AWS.Mq.list_users/5","type":"function"},{"doc":"","ref":"AWS.Mq.html#metadata/0","title":"AWS.Mq.metadata/0","type":"function"},{"doc":"Promotes a data replication replica broker to the primary broker role.","ref":"AWS.Mq.html#promote/4","title":"AWS.Mq.promote/4","type":"function"},{"doc":"Reboots a broker.\n\nNote: This API is asynchronous.","ref":"AWS.Mq.html#reboot_broker/4","title":"AWS.Mq.reboot_broker/4","type":"function"},{"doc":"Adds a pending configuration change to a broker.","ref":"AWS.Mq.html#update_broker/4","title":"AWS.Mq.update_broker/4","type":"function"},{"doc":"Updates the specified configuration.","ref":"AWS.Mq.html#update_configuration/4","title":"AWS.Mq.update_configuration/4","type":"function"},{"doc":"Updates the information for an ActiveMQ user.","ref":"AWS.Mq.html#update_user/5","title":"AWS.Mq.update_user/5","type":"function"},{"doc":"Amazon Neptune\n\nAmazon Neptune is a fast, reliable, fully-managed graph database service that\nmakes it easy to build and run applications that work with highly connected\ndatasets.\n\nThe core of Amazon Neptune is a purpose-built, high-performance graph database\nengine optimized for storing billions of relationships and querying the graph\nwith milliseconds latency. Amazon Neptune supports popular graph models Property\nGraph and W3C's RDF, and their respective query languages Apache TinkerPop\nGremlin and SPARQL, allowing you to easily build queries that efficiently\nnavigate highly connected datasets. Neptune powers graph use cases such as\nrecommendation engines, fraud detection, knowledge graphs, drug discovery, and\nnetwork security.\n\nThis interface reference for Amazon Neptune contains documentation for a\nprogramming or command line interface you can use to manage Amazon Neptune. Note\nthat Amazon Neptune is asynchronous, which means that some interfaces might\nrequire techniques such as polling or callback functions to determine when a\ncommand has been applied. In this reference, the parameter descriptions indicate\nwhether a command is applied immediately, on the next instance reboot, or during\nthe maintenance window. The reference structure is as follows, and we list\nfollowing some related topics from the user guide.","ref":"AWS.Neptune.html","title":"AWS.Neptune","type":"module"},{"doc":"Associates an Identity and Access Management (IAM) role with an Neptune DB\ncluster.","ref":"AWS.Neptune.html#add_role_to_db_cluster/3","title":"AWS.Neptune.add_role_to_db_cluster/3","type":"function"},{"doc":"Adds a source identifier to an existing event notification subscription.","ref":"AWS.Neptune.html#add_source_identifier_to_subscription/3","title":"AWS.Neptune.add_source_identifier_to_subscription/3","type":"function"},{"doc":"Adds metadata tags to an Amazon Neptune resource.\n\nThese tags can also be used with cost allocation reporting to track cost\nassociated with Amazon Neptune resources, or used in a Condition statement in an\nIAM policy for Amazon Neptune.","ref":"AWS.Neptune.html#add_tags_to_resource/3","title":"AWS.Neptune.add_tags_to_resource/3","type":"function"},{"doc":"Applies a pending maintenance action to a resource (for example, to a DB\ninstance).","ref":"AWS.Neptune.html#apply_pending_maintenance_action/3","title":"AWS.Neptune.apply_pending_maintenance_action/3","type":"function"},{"doc":"Copies the specified DB cluster parameter group.","ref":"AWS.Neptune.html#copy_db_cluster_parameter_group/3","title":"AWS.Neptune.copy_db_cluster_parameter_group/3","type":"function"},{"doc":"Copies a snapshot of a DB cluster.\n\nTo copy a DB cluster snapshot from a shared manual DB cluster snapshot,\n`SourceDBClusterSnapshotIdentifier` must be the Amazon Resource Name (ARN) of\nthe shared DB cluster snapshot.","ref":"AWS.Neptune.html#copy_db_cluster_snapshot/3","title":"AWS.Neptune.copy_db_cluster_snapshot/3","type":"function"},{"doc":"Copies the specified DB parameter group.","ref":"AWS.Neptune.html#copy_db_parameter_group/3","title":"AWS.Neptune.copy_db_parameter_group/3","type":"function"},{"doc":"Creates a new Amazon Neptune DB cluster.\n\nYou can use the `ReplicationSourceIdentifier` parameter to create the DB cluster\nas a Read Replica of another DB cluster or Amazon Neptune DB instance.\n\nNote that when you create a new cluster using `CreateDBCluster` directly,\ndeletion protection is disabled by default (when you create a new production\ncluster in the console, deletion protection is enabled by default). You can only\ndelete a DB cluster if its `DeletionProtection` field is set to `false`.","ref":"AWS.Neptune.html#create_db_cluster/3","title":"AWS.Neptune.create_db_cluster/3","type":"function"},{"doc":"Creates a new custom endpoint and associates it with an Amazon Neptune DB\ncluster.","ref":"AWS.Neptune.html#create_db_cluster_endpoint/3","title":"AWS.Neptune.create_db_cluster_endpoint/3","type":"function"},{"doc":"Creates a new DB cluster parameter group.\n\nParameters in a DB cluster parameter group apply to all of the instances in a DB\ncluster.\n\nA DB cluster parameter group is initially created with the default parameters\nfor the database engine used by instances in the DB cluster. To provide custom\nvalues for any of the parameters, you must modify the group after creating it\nusing `ModifyDBClusterParameterGroup`. Once you've created a DB cluster\nparameter group, you need to associate it with your DB cluster using\n`ModifyDBCluster`. When you associate a new DB cluster parameter group with a\nrunning DB cluster, you need to reboot the DB instances in the DB cluster\nwithout failover for the new DB cluster parameter group and associated settings\nto take effect.\n\nAfter you create a DB cluster parameter group, you should wait at least 5\nminutes before creating your first DB cluster that uses that DB cluster\nparameter group as the default parameter group. This allows Amazon Neptune to\nfully complete the create action before the DB cluster parameter group is used\nas the default for a new DB cluster. This is especially important for parameters\nthat are critical when creating the default database for a DB cluster, such as\nthe character set for the default database defined by the\n`character_set_database` parameter. You can use the *Parameter Groups* option of\nthe [Amazon Neptune console](https://console.aws.amazon.com/rds/) or the\n`DescribeDBClusterParameters` command to verify that your DB cluster parameter\ngroup has been created or modified.","ref":"AWS.Neptune.html#create_db_cluster_parameter_group/3","title":"AWS.Neptune.create_db_cluster_parameter_group/3","type":"function"},{"doc":"Creates a snapshot of a DB cluster.","ref":"AWS.Neptune.html#create_db_cluster_snapshot/3","title":"AWS.Neptune.create_db_cluster_snapshot/3","type":"function"},{"doc":"Creates a new DB instance.","ref":"AWS.Neptune.html#create_db_instance/3","title":"AWS.Neptune.create_db_instance/3","type":"function"},{"doc":"Creates a new DB parameter group.\n\nA DB parameter group is initially created with the default parameters for the\ndatabase engine used by the DB instance. To provide custom values for any of the\nparameters, you must modify the group after creating it using\n*ModifyDBParameterGroup*. Once you've created a DB parameter group, you need to\nassociate it with your DB instance using *ModifyDBInstance*. When you associate\na new DB parameter group with a running DB instance, you need to reboot the DB\ninstance without failover for the new DB parameter group and associated settings\nto take effect.\n\nAfter you create a DB parameter group, you should wait at least 5 minutes before\ncreating your first DB instance that uses that DB parameter group as the default\nparameter group. This allows Amazon Neptune to fully complete the create action\nbefore the parameter group is used as the default for a new DB instance. This is\nespecially important for parameters that are critical when creating the default\ndatabase for a DB instance, such as the character set for the default database\ndefined by the `character_set_database` parameter. You can use the *Parameter\nGroups* option of the Amazon Neptune console or the *DescribeDBParameters*\ncommand to verify that your DB parameter group has been created or modified.","ref":"AWS.Neptune.html#create_db_parameter_group/3","title":"AWS.Neptune.create_db_parameter_group/3","type":"function"},{"doc":"Creates a new DB subnet group.\n\nDB subnet groups must contain at least one subnet in at least two AZs in the\nAmazon Region.","ref":"AWS.Neptune.html#create_db_subnet_group/3","title":"AWS.Neptune.create_db_subnet_group/3","type":"function"},{"doc":"Creates an event notification subscription.\n\nThis action requires a topic ARN (Amazon Resource Name) created by either the\nNeptune console, the SNS console, or the SNS API. To obtain an ARN with SNS, you\nmust create a topic in Amazon SNS and subscribe to the topic. The ARN is\ndisplayed in the SNS console.\n\nYou can specify the type of source (SourceType) you want to be notified of,\nprovide a list of Neptune sources (SourceIds) that triggers the events, and\nprovide a list of event categories (EventCategories) for events you want to be\nnotified of. For example, you can specify SourceType = db-instance, SourceIds =\nmydbinstance1, mydbinstance2 and EventCategories = Availability, Backup.\n\nIf you specify both the SourceType and SourceIds, such as SourceType =\ndb-instance and SourceIdentifier = myDBInstance1, you are notified of all the\ndb-instance events for the specified source. If you specify a SourceType but do\nnot specify a SourceIdentifier, you receive notice of the events for that source\ntype for all your Neptune sources. If you do not specify either the SourceType\nnor the SourceIdentifier, you are notified of events generated from all Neptune\nsources belonging to your customer account.","ref":"AWS.Neptune.html#create_event_subscription/3","title":"AWS.Neptune.create_event_subscription/3","type":"function"},{"doc":"Creates a Neptune global database spread across multiple Amazon Regions.\n\nThe global database contains a single primary cluster with read-write\ncapability, and read-only secondary clusters that receive data from the primary\ncluster through high-speed replication performed by the Neptune storage\nsubsystem.\n\nYou can create a global database that is initially empty, and then add a primary\ncluster and secondary clusters to it, or you can specify an existing Neptune\ncluster during the create operation to become the primary cluster of the global\ndatabase.","ref":"AWS.Neptune.html#create_global_cluster/3","title":"AWS.Neptune.create_global_cluster/3","type":"function"},{"doc":"The DeleteDBCluster action deletes a previously provisioned DB cluster.\n\nWhen you delete a DB cluster, all automated backups for that DB cluster are\ndeleted and can't be recovered. Manual DB cluster snapshots of the specified DB\ncluster are not deleted.\n\nNote that the DB Cluster cannot be deleted if deletion protection is enabled. To\ndelete it, you must first set its `DeletionProtection` field to `False`.","ref":"AWS.Neptune.html#delete_db_cluster/3","title":"AWS.Neptune.delete_db_cluster/3","type":"function"},{"doc":"Deletes a custom endpoint and removes it from an Amazon Neptune DB cluster.","ref":"AWS.Neptune.html#delete_db_cluster_endpoint/3","title":"AWS.Neptune.delete_db_cluster_endpoint/3","type":"function"},{"doc":"Deletes a specified DB cluster parameter group.\n\nThe DB cluster parameter group to be deleted can't be associated with any DB\nclusters.","ref":"AWS.Neptune.html#delete_db_cluster_parameter_group/3","title":"AWS.Neptune.delete_db_cluster_parameter_group/3","type":"function"},{"doc":"Deletes a DB cluster snapshot.\n\nIf the snapshot is being copied, the copy operation is terminated.\n\nThe DB cluster snapshot must be in the `available` state to be deleted.","ref":"AWS.Neptune.html#delete_db_cluster_snapshot/3","title":"AWS.Neptune.delete_db_cluster_snapshot/3","type":"function"},{"doc":"The DeleteDBInstance action deletes a previously provisioned DB instance.\n\nWhen you delete a DB instance, all automated backups for that instance are\ndeleted and can't be recovered. Manual DB snapshots of the DB instance to be\ndeleted by `DeleteDBInstance` are not deleted.\n\nIf you request a final DB snapshot the status of the Amazon Neptune DB instance\nis `deleting` until the DB snapshot is created. The API action\n`DescribeDBInstance` is used to monitor the status of this operation. The action\ncan't be canceled or reverted once submitted.\n\nNote that when a DB instance is in a failure state and has a status of `failed`,\n`incompatible-restore`, or `incompatible-network`, you can only delete it when\nthe `SkipFinalSnapshot` parameter is set to `true`.\n\nYou can't delete a DB instance if it is the only instance in the DB cluster, or\nif it has deletion protection enabled.","ref":"AWS.Neptune.html#delete_db_instance/3","title":"AWS.Neptune.delete_db_instance/3","type":"function"},{"doc":"Deletes a specified DBParameterGroup.\n\nThe DBParameterGroup to be deleted can't be associated with any DB instances.","ref":"AWS.Neptune.html#delete_db_parameter_group/3","title":"AWS.Neptune.delete_db_parameter_group/3","type":"function"},{"doc":"Deletes a DB subnet group.\n\nThe specified database subnet group must not be associated with any DB\ninstances.","ref":"AWS.Neptune.html#delete_db_subnet_group/3","title":"AWS.Neptune.delete_db_subnet_group/3","type":"function"},{"doc":"Deletes an event notification subscription.","ref":"AWS.Neptune.html#delete_event_subscription/3","title":"AWS.Neptune.delete_event_subscription/3","type":"function"},{"doc":"Deletes a global database.\n\nThe primary and all secondary clusters must already be detached or deleted\nfirst.","ref":"AWS.Neptune.html#delete_global_cluster/3","title":"AWS.Neptune.delete_global_cluster/3","type":"function"},{"doc":"Returns information about endpoints for an Amazon Neptune DB cluster.\n\nThis operation can also return information for Amazon RDS clusters and Amazon\nDocDB clusters.","ref":"AWS.Neptune.html#describe_db_cluster_endpoints/3","title":"AWS.Neptune.describe_db_cluster_endpoints/3","type":"function"},{"doc":"Returns a list of `DBClusterParameterGroup` descriptions.\n\nIf a `DBClusterParameterGroupName` parameter is specified, the list will contain\nonly the description of the specified DB cluster parameter group.","ref":"AWS.Neptune.html#describe_db_cluster_parameter_groups/3","title":"AWS.Neptune.describe_db_cluster_parameter_groups/3","type":"function"},{"doc":"Returns the detailed parameter list for a particular DB cluster parameter group.","ref":"AWS.Neptune.html#describe_db_cluster_parameters/3","title":"AWS.Neptune.describe_db_cluster_parameters/3","type":"function"},{"doc":"Returns a list of DB cluster snapshot attribute names and values for a manual DB\ncluster snapshot.\n\nWhen sharing snapshots with other Amazon accounts,\n`DescribeDBClusterSnapshotAttributes` returns the `restore` attribute and a list\nof IDs for the Amazon accounts that are authorized to copy or restore the manual\nDB cluster snapshot. If `all` is included in the list of values for the\n`restore` attribute, then the manual DB cluster snapshot is public and can be\ncopied or restored by all Amazon accounts.\n\nTo add or remove access for an Amazon account to copy or restore a manual DB\ncluster snapshot, or to make the manual DB cluster snapshot public or private,\nuse the `ModifyDBClusterSnapshotAttribute` API action.","ref":"AWS.Neptune.html#describe_db_cluster_snapshot_attributes/3","title":"AWS.Neptune.describe_db_cluster_snapshot_attributes/3","type":"function"},{"doc":"Returns information about DB cluster snapshots.\n\nThis API action supports pagination.","ref":"AWS.Neptune.html#describe_db_cluster_snapshots/3","title":"AWS.Neptune.describe_db_cluster_snapshots/3","type":"function"},{"doc":"Returns information about provisioned DB clusters, and supports pagination.\n\nThis operation can also return information for Amazon RDS clusters and Amazon\nDocDB clusters.","ref":"AWS.Neptune.html#describe_db_clusters/3","title":"AWS.Neptune.describe_db_clusters/3","type":"function"},{"doc":"Returns a list of the available DB engines.","ref":"AWS.Neptune.html#describe_db_engine_versions/3","title":"AWS.Neptune.describe_db_engine_versions/3","type":"function"},{"doc":"Returns information about provisioned instances, and supports pagination.\n\nThis operation can also return information for Amazon RDS instances and Amazon\nDocDB instances.","ref":"AWS.Neptune.html#describe_db_instances/3","title":"AWS.Neptune.describe_db_instances/3","type":"function"},{"doc":"Returns a list of `DBParameterGroup` descriptions.\n\nIf a `DBParameterGroupName` is specified, the list will contain only the\ndescription of the specified DB parameter group.","ref":"AWS.Neptune.html#describe_db_parameter_groups/3","title":"AWS.Neptune.describe_db_parameter_groups/3","type":"function"},{"doc":"Returns the detailed parameter list for a particular DB parameter group.","ref":"AWS.Neptune.html#describe_db_parameters/3","title":"AWS.Neptune.describe_db_parameters/3","type":"function"},{"doc":"Returns a list of DBSubnetGroup descriptions.\n\nIf a DBSubnetGroupName is specified, the list will contain only the descriptions\nof the specified DBSubnetGroup.\n\nFor an overview of CIDR ranges, go to the [Wikipedia Tutorial](http://en.wikipedia.org/wiki/Classless_Inter-Domain_Routing).","ref":"AWS.Neptune.html#describe_db_subnet_groups/3","title":"AWS.Neptune.describe_db_subnet_groups/3","type":"function"},{"doc":"Returns the default engine and system parameter information for the cluster\ndatabase engine.","ref":"AWS.Neptune.html#describe_engine_default_cluster_parameters/3","title":"AWS.Neptune.describe_engine_default_cluster_parameters/3","type":"function"},{"doc":"Returns the default engine and system parameter information for the specified\ndatabase engine.","ref":"AWS.Neptune.html#describe_engine_default_parameters/3","title":"AWS.Neptune.describe_engine_default_parameters/3","type":"function"},{"doc":"Displays a list of categories for all event source types, or, if specified, for\na specified source type.","ref":"AWS.Neptune.html#describe_event_categories/3","title":"AWS.Neptune.describe_event_categories/3","type":"function"},{"doc":"Lists all the subscription descriptions for a customer account.\n\nThe description for a subscription includes SubscriptionName, SNSTopicARN,\nCustomerID, SourceType, SourceID, CreationTime, and Status.\n\nIf you specify a SubscriptionName, lists the description for that subscription.","ref":"AWS.Neptune.html#describe_event_subscriptions/3","title":"AWS.Neptune.describe_event_subscriptions/3","type":"function"},{"doc":"Returns events related to DB instances, DB security groups, DB snapshots, and DB\nparameter groups for the past 14 days.\n\nEvents specific to a particular DB instance, DB security group, database\nsnapshot, or DB parameter group can be obtained by providing the name as a\nparameter. By default, the past hour of events are returned.","ref":"AWS.Neptune.html#describe_events/3","title":"AWS.Neptune.describe_events/3","type":"function"},{"doc":"Returns information about Neptune global database clusters.\n\nThis API supports pagination.","ref":"AWS.Neptune.html#describe_global_clusters/3","title":"AWS.Neptune.describe_global_clusters/3","type":"function"},{"doc":"Returns a list of orderable DB instance options for the specified engine.","ref":"AWS.Neptune.html#describe_orderable_db_instance_options/3","title":"AWS.Neptune.describe_orderable_db_instance_options/3","type":"function"},{"doc":"Returns a list of resources (for example, DB instances) that have at least one\npending maintenance action.","ref":"AWS.Neptune.html#describe_pending_maintenance_actions/3","title":"AWS.Neptune.describe_pending_maintenance_actions/3","type":"function"},{"doc":"You can call `DescribeValidDBInstanceModifications` to learn what modifications\nyou can make to your DB instance.\n\nYou can use this information when you call `ModifyDBInstance`.","ref":"AWS.Neptune.html#describe_valid_db_instance_modifications/3","title":"AWS.Neptune.describe_valid_db_instance_modifications/3","type":"function"},{"doc":"Forces a failover for a DB cluster.\n\nA failover for a DB cluster promotes one of the Read Replicas (read-only\ninstances) in the DB cluster to be the primary instance (the cluster writer).\n\nAmazon Neptune will automatically fail over to a Read Replica, if one exists,\nwhen the primary instance fails. You can force a failover when you want to\nsimulate a failure of a primary instance for testing. Because each instance in a\nDB cluster has its own endpoint address, you will need to clean up and\nre-establish any existing connections that use those endpoint addresses when the\nfailover is complete.","ref":"AWS.Neptune.html#failover_db_cluster/3","title":"AWS.Neptune.failover_db_cluster/3","type":"function"},{"doc":"Initiates the failover process for a Neptune global database.\n\nA failover for a Neptune global database promotes one of secondary read-only DB\nclusters to be the primary DB cluster and demotes the primary DB cluster to\nbeing a secondary (read-only) DB cluster. In other words, the role of the\ncurrent primary DB cluster and the selected target secondary DB cluster are\nswitched. The selected secondary DB cluster assumes full read/write capabilities\nfor the Neptune global database.\n\nThis action applies **only** to Neptune global databases. This action is only\nintended for use on healthy Neptune global databases with healthy Neptune DB\nclusters and no region-wide outages, to test disaster recovery scenarios or to\nreconfigure the global database topology.","ref":"AWS.Neptune.html#failover_global_cluster/3","title":"AWS.Neptune.failover_global_cluster/3","type":"function"},{"doc":"Lists all tags on an Amazon Neptune resource.","ref":"AWS.Neptune.html#list_tags_for_resource/3","title":"AWS.Neptune.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.Neptune.html#metadata/0","title":"AWS.Neptune.metadata/0","type":"function"},{"doc":"Modify a setting for a DB cluster.\n\nYou can change one or more database configuration parameters by specifying these\nparameters and the new values in the request.","ref":"AWS.Neptune.html#modify_db_cluster/3","title":"AWS.Neptune.modify_db_cluster/3","type":"function"},{"doc":"Modifies the properties of an endpoint in an Amazon Neptune DB cluster.","ref":"AWS.Neptune.html#modify_db_cluster_endpoint/3","title":"AWS.Neptune.modify_db_cluster_endpoint/3","type":"function"},{"doc":"Modifies the parameters of a DB cluster parameter group.\n\nTo modify more than one parameter, submit a list of the following:\n`ParameterName`, `ParameterValue`, and `ApplyMethod`. A maximum of 20 parameters\ncan be modified in a single request.\n\nChanges to dynamic parameters are applied immediately. Changes to static\nparameters require a reboot without failover to the DB cluster associated with\nthe parameter group before the change can take effect.\n\nAfter you create a DB cluster parameter group, you should wait at least 5\nminutes before creating your first DB cluster that uses that DB cluster\nparameter group as the default parameter group. This allows Amazon Neptune to\nfully complete the create action before the parameter group is used as the\ndefault for a new DB cluster. This is especially important for parameters that\nare critical when creating the default database for a DB cluster, such as the\ncharacter set for the default database defined by the `character_set_database`\nparameter. You can use the *Parameter Groups* option of the Amazon Neptune\nconsole or the `DescribeDBClusterParameters` command to verify that your DB\ncluster parameter group has been created or modified.","ref":"AWS.Neptune.html#modify_db_cluster_parameter_group/3","title":"AWS.Neptune.modify_db_cluster_parameter_group/3","type":"function"},{"doc":"Adds an attribute and values to, or removes an attribute and values from, a\nmanual DB cluster snapshot.\n\nTo share a manual DB cluster snapshot with other Amazon accounts, specify\n`restore` as the `AttributeName` and use the `ValuesToAdd` parameter to add a\nlist of IDs of the Amazon accounts that are authorized to restore the manual DB\ncluster snapshot. Use the value `all` to make the manual DB cluster snapshot\npublic, which means that it can be copied or restored by all Amazon accounts. Do\nnot add the `all` value for any manual DB cluster snapshots that contain private\ninformation that you don't want available to all Amazon accounts. If a manual DB\ncluster snapshot is encrypted, it can be shared, but only by specifying a list\nof authorized Amazon account IDs for the `ValuesToAdd` parameter. You can't use\n`all` as a value for that parameter in this case.\n\nTo view which Amazon accounts have access to copy or restore a manual DB cluster\nsnapshot, or whether a manual DB cluster snapshot public or private, use the\n`DescribeDBClusterSnapshotAttributes` API action.","ref":"AWS.Neptune.html#modify_db_cluster_snapshot_attribute/3","title":"AWS.Neptune.modify_db_cluster_snapshot_attribute/3","type":"function"},{"doc":"Modifies settings for a DB instance.\n\nYou can change one or more database configuration parameters by specifying these\nparameters and the new values in the request. To learn what modifications you\ncan make to your DB instance, call `DescribeValidDBInstanceModifications` before\nyou call `ModifyDBInstance`.","ref":"AWS.Neptune.html#modify_db_instance/3","title":"AWS.Neptune.modify_db_instance/3","type":"function"},{"doc":"Modifies the parameters of a DB parameter group.\n\nTo modify more than one parameter, submit a list of the following:\n`ParameterName`, `ParameterValue`, and `ApplyMethod`. A maximum of 20 parameters\ncan be modified in a single request.\n\nChanges to dynamic parameters are applied immediately. Changes to static\nparameters require a reboot without failover to the DB instance associated with\nthe parameter group before the change can take effect.\n\nAfter you modify a DB parameter group, you should wait at least 5 minutes before\ncreating your first DB instance that uses that DB parameter group as the default\nparameter group. This allows Amazon Neptune to fully complete the modify action\nbefore the parameter group is used as the default for a new DB instance. This is\nespecially important for parameters that are critical when creating the default\ndatabase for a DB instance, such as the character set for the default database\ndefined by the `character_set_database` parameter. You can use the *Parameter\nGroups* option of the Amazon Neptune console or the *DescribeDBParameters*\ncommand to verify that your DB parameter group has been created or modified.","ref":"AWS.Neptune.html#modify_db_parameter_group/3","title":"AWS.Neptune.modify_db_parameter_group/3","type":"function"},{"doc":"Modifies an existing DB subnet group.\n\nDB subnet groups must contain at least one subnet in at least two AZs in the\nAmazon Region.","ref":"AWS.Neptune.html#modify_db_subnet_group/3","title":"AWS.Neptune.modify_db_subnet_group/3","type":"function"},{"doc":"Modifies an existing event notification subscription.\n\nNote that you can't modify the source identifiers using this call; to change\nsource identifiers for a subscription, use the\n`AddSourceIdentifierToSubscription` and `RemoveSourceIdentifierFromSubscription`\ncalls.\n\nYou can see a list of the event categories for a given SourceType by using the\n**DescribeEventCategories** action.","ref":"AWS.Neptune.html#modify_event_subscription/3","title":"AWS.Neptune.modify_event_subscription/3","type":"function"},{"doc":"Modify a setting for an Amazon Neptune global cluster.\n\nYou can change one or more database configuration parameters by specifying these\nparameters and their new values in the request.","ref":"AWS.Neptune.html#modify_global_cluster/3","title":"AWS.Neptune.modify_global_cluster/3","type":"function"},{"doc":"Not supported.","ref":"AWS.Neptune.html#promote_read_replica_db_cluster/3","title":"AWS.Neptune.promote_read_replica_db_cluster/3","type":"function"},{"doc":"You might need to reboot your DB instance, usually for maintenance reasons.\n\nFor example, if you make certain modifications, or if you change the DB\nparameter group associated with the DB instance, you must reboot the instance\nfor the changes to take effect.\n\nRebooting a DB instance restarts the database engine service. Rebooting a DB\ninstance results in a momentary outage, during which the DB instance status is\nset to rebooting.","ref":"AWS.Neptune.html#reboot_db_instance/3","title":"AWS.Neptune.reboot_db_instance/3","type":"function"},{"doc":"Detaches a Neptune DB cluster from a Neptune global database.\n\nA secondary cluster becomes a normal standalone cluster with read-write\ncapability instead of being read-only, and no longer receives data from a the\nprimary cluster.","ref":"AWS.Neptune.html#remove_from_global_cluster/3","title":"AWS.Neptune.remove_from_global_cluster/3","type":"function"},{"doc":"Disassociates an Identity and Access Management (IAM) role from a DB cluster.","ref":"AWS.Neptune.html#remove_role_from_db_cluster/3","title":"AWS.Neptune.remove_role_from_db_cluster/3","type":"function"},{"doc":"Removes a source identifier from an existing event notification subscription.","ref":"AWS.Neptune.html#remove_source_identifier_from_subscription/3","title":"AWS.Neptune.remove_source_identifier_from_subscription/3","type":"function"},{"doc":"Removes metadata tags from an Amazon Neptune resource.","ref":"AWS.Neptune.html#remove_tags_from_resource/3","title":"AWS.Neptune.remove_tags_from_resource/3","type":"function"},{"doc":"Modifies the parameters of a DB cluster parameter group to the default value.\n\nTo reset specific parameters submit a list of the following: `ParameterName` and\n`ApplyMethod`. To reset the entire DB cluster parameter group, specify the\n`DBClusterParameterGroupName` and `ResetAllParameters` parameters.\n\nWhen resetting the entire group, dynamic parameters are updated immediately and\nstatic parameters are set to `pending-reboot` to take effect on the next DB\ninstance restart or `RebootDBInstance` request. You must call `RebootDBInstance`\nfor every DB instance in your DB cluster that you want the updated static\nparameter to apply to.","ref":"AWS.Neptune.html#reset_db_cluster_parameter_group/3","title":"AWS.Neptune.reset_db_cluster_parameter_group/3","type":"function"},{"doc":"Modifies the parameters of a DB parameter group to the engine/system default\nvalue.\n\nTo reset specific parameters, provide a list of the following: `ParameterName`\nand `ApplyMethod`. To reset the entire DB parameter group, specify the\n`DBParameterGroup` name and `ResetAllParameters` parameters. When resetting the\nentire group, dynamic parameters are updated immediately and static parameters\nare set to `pending-reboot` to take effect on the next DB instance restart or\n`RebootDBInstance` request.","ref":"AWS.Neptune.html#reset_db_parameter_group/3","title":"AWS.Neptune.reset_db_parameter_group/3","type":"function"},{"doc":"Creates a new DB cluster from a DB snapshot or DB cluster snapshot.\n\nIf a DB snapshot is specified, the target DB cluster is created from the source\nDB snapshot with a default configuration and default security group.\n\nIf a DB cluster snapshot is specified, the target DB cluster is created from the\nsource DB cluster restore point with the same configuration as the original\nsource DB cluster, except that the new DB cluster is created with the default\nsecurity group.","ref":"AWS.Neptune.html#restore_db_cluster_from_snapshot/3","title":"AWS.Neptune.restore_db_cluster_from_snapshot/3","type":"function"},{"doc":"Restores a DB cluster to an arbitrary point in time.\n\nUsers can restore to any point in time before `LatestRestorableTime` for up to\n`BackupRetentionPeriod` days. The target DB cluster is created from the source\nDB cluster with the same configuration as the original DB cluster, except that\nthe new DB cluster is created with the default DB security group.\n\nThis action only restores the DB cluster, not the DB instances for that DB\ncluster. You must invoke the `CreateDBInstance` action to create DB instances\nfor the restored DB cluster, specifying the identifier of the restored DB\ncluster in `DBClusterIdentifier`. You can create DB instances only after the\n`RestoreDBClusterToPointInTime` action has completed and the DB cluster is\navailable.","ref":"AWS.Neptune.html#restore_db_cluster_to_point_in_time/3","title":"AWS.Neptune.restore_db_cluster_to_point_in_time/3","type":"function"},{"doc":"Starts an Amazon Neptune DB cluster that was stopped using the Amazon console,\nthe Amazon CLI stop-db-cluster command, or the StopDBCluster API.","ref":"AWS.Neptune.html#start_db_cluster/3","title":"AWS.Neptune.start_db_cluster/3","type":"function"},{"doc":"Stops an Amazon Neptune DB cluster.\n\nWhen you stop a DB cluster, Neptune retains the DB cluster's metadata, including\nits endpoints and DB parameter groups.\n\nNeptune also retains the transaction logs so you can do a point-in-time restore\nif necessary.","ref":"AWS.Neptune.html#stop_db_cluster/3","title":"AWS.Neptune.stop_db_cluster/3","type":"function"},{"doc":"Neptune Data API\n\nThe Amazon Neptune data API provides SDK support for more than 40 of Neptune's\ndata operations, including data loading, query execution, data inquiry, and\nmachine learning.\n\nIt supports the Gremlin and openCypher query languages, and is available in all\nSDK languages. It automatically signs API requests and greatly simplifies\nintegrating Neptune into your applications.","ref":"AWS.Neptunedata.html","title":"AWS.Neptunedata","type":"module"},{"doc":"Cancels a Gremlin query.\n\nSee [Gremlin query cancellation](https://docs.aws.amazon.com/neptune/latest/userguide/gremlin-api-status-cancel.html)\nfor more information.\n\nWhen invoking this operation in a Neptune cluster that has IAM authentication\nenabled, the IAM user or role making the request must have a policy attached\nthat allows the\n[neptune-db:CancelQuery](https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#cancelquery)\nIAM action in that cluster.","ref":"AWS.Neptunedata.html#cancel_gremlin_query/4","title":"AWS.Neptunedata.cancel_gremlin_query/4","type":"function"},{"doc":"Cancels a specified load job.\n\nThis is an HTTP `DELETE` request. See [Neptune Loader Get-Status API](https://docs.aws.amazon.com/neptune/latest/userguide/load-api-reference-status.htm)\nfor more information.\n\nWhen invoking this operation in a Neptune cluster that has IAM authentication\nenabled, the IAM user or role making the request must have a policy attached\nthat allows the\n[neptune-db:CancelLoaderJob](https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#cancelloaderjob)\nIAM action in that cluster..","ref":"AWS.Neptunedata.html#cancel_loader_job/4","title":"AWS.Neptunedata.cancel_loader_job/4","type":"function"},{"doc":"Cancels a Neptune ML data processing job.\n\nSee [The `dataprocessing` command](https://docs.aws.amazon.com/neptune/latest/userguide/machine-learning-api-dataprocessing.html).\n\nWhen invoking this operation in a Neptune cluster that has IAM authentication\nenabled, the IAM user or role making the request must have a policy attached\nthat allows the\n[neptune-db:CancelMLDataProcessingJob](https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#cancelmldataprocessingjob)\nIAM action in that cluster.","ref":"AWS.Neptunedata.html#cancel_ml_data_processing_job/4","title":"AWS.Neptunedata.cancel_ml_data_processing_job/4","type":"function"},{"doc":"Cancels a Neptune ML model training job.\n\nSee [Model training using the `modeltraining` command](https://docs.aws.amazon.com/neptune/latest/userguide/machine-learning-api-modeltraining.html).\n\nWhen invoking this operation in a Neptune cluster that has IAM authentication\nenabled, the IAM user or role making the request must have a policy attached\nthat allows the\n[neptune-db:CancelMLModelTrainingJob](https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#cancelmlmodeltrainingjob)\nIAM action in that cluster.","ref":"AWS.Neptunedata.html#cancel_ml_model_training_job/4","title":"AWS.Neptunedata.cancel_ml_model_training_job/4","type":"function"},{"doc":"Cancels a specified model transform job.\n\nSee [Use a trained model to generate new model artifacts](https://docs.aws.amazon.com/neptune/latest/userguide/machine-learning-model-transform.html).\n\nWhen invoking this operation in a Neptune cluster that has IAM authentication\nenabled, the IAM user or role making the request must have a policy attached\nthat allows the\n[neptune-db:CancelMLModelTransformJob](https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#cancelmlmodeltransformjob)\nIAM action in that cluster.","ref":"AWS.Neptunedata.html#cancel_ml_model_transform_job/4","title":"AWS.Neptunedata.cancel_ml_model_transform_job/4","type":"function"},{"doc":"Cancels a specified openCypher query.\n\nSee [Neptune openCypher status endpoint](https://docs.aws.amazon.com/neptune/latest/userguide/access-graph-opencypher-status.html)\nfor more information.\n\nWhen invoking this operation in a Neptune cluster that has IAM authentication\nenabled, the IAM user or role making the request must have a policy attached\nthat allows the\n[neptune-db:CancelQuery](https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#cancelquery)\nIAM action in that cluster.","ref":"AWS.Neptunedata.html#cancel_open_cypher_query/4","title":"AWS.Neptunedata.cancel_open_cypher_query/4","type":"function"},{"doc":"Creates a new Neptune ML inference endpoint that lets you query one specific\nmodel that the model-training process constructed.\n\nSee [Managing inference endpoints using the endpoints command](https://docs.aws.amazon.com/neptune/latest/userguide/machine-learning-api-endpoints.html).\n\nWhen invoking this operation in a Neptune cluster that has IAM authentication\nenabled, the IAM user or role making the request must have a policy attached\nthat allows the\n[neptune-db:CreateMLEndpoint](https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#createmlendpoint)\nIAM action in that cluster.","ref":"AWS.Neptunedata.html#create_ml_endpoint/3","title":"AWS.Neptunedata.create_ml_endpoint/3","type":"function"},{"doc":"Cancels the creation of a Neptune ML inference endpoint.\n\nSee [Managing inference endpoints using the endpoints command](https://docs.aws.amazon.com/neptune/latest/userguide/machine-learning-api-endpoints.html).\n\nWhen invoking this operation in a Neptune cluster that has IAM authentication\nenabled, the IAM user or role making the request must have a policy attached\nthat allows the\n[neptune-db:DeleteMLEndpoint](https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#deletemlendpoint)\nIAM action in that cluster.","ref":"AWS.Neptunedata.html#delete_ml_endpoint/4","title":"AWS.Neptunedata.delete_ml_endpoint/4","type":"function"},{"doc":"Deletes statistics for Gremlin and openCypher (property graph) data.\n\nWhen invoking this operation in a Neptune cluster that has IAM authentication\nenabled, the IAM user or role making the request must have a policy attached\nthat allows the\n[neptune-db:DeleteStatistics](https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#deletestatistics)\nIAM action in that cluster.","ref":"AWS.Neptunedata.html#delete_propertygraph_statistics/3","title":"AWS.Neptunedata.delete_propertygraph_statistics/3","type":"function"},{"doc":"Deletes SPARQL statistics\n\nWhen invoking this operation in a Neptune cluster that has IAM authentication\nenabled, the IAM user or role making the request must have a policy attached\nthat allows the\n[neptune-db:DeleteStatistics](https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#deletestatistics)\nIAM action in that cluster.","ref":"AWS.Neptunedata.html#delete_sparql_statistics/3","title":"AWS.Neptunedata.delete_sparql_statistics/3","type":"function"},{"doc":"The fast reset REST API lets you reset a Neptune graph quicky and easily,\nremoving all of its data.\n\nNeptune fast reset is a two-step process. First you call `ExecuteFastReset` with\n`action` set to `initiateDatabaseReset`. This returns a UUID token which you\nthen include when calling `ExecuteFastReset` again with `action` set to\n`performDatabaseReset`. See [Empty an Amazon Neptune DB cluster using the fast reset\nAPI](https://docs.aws.amazon.com/neptune/latest/userguide/manage-console-fast-reset.html).\n\nWhen invoking this operation in a Neptune cluster that has IAM authentication\nenabled, the IAM user or role making the request must have a policy attached\nthat allows the\n[neptune-db:ResetDatabase](https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#resetdatabase)\nIAM action in that cluster.","ref":"AWS.Neptunedata.html#execute_fast_reset/3","title":"AWS.Neptunedata.execute_fast_reset/3","type":"function"},{"doc":"Executes a Gremlin Explain query.\n\nAmazon Neptune has added a Gremlin feature named `explain` that provides is a\nself-service tool for understanding the execution approach being taken by the\nNeptune engine for the query. You invoke it by adding an `explain` parameter to\nan HTTP call that submits a Gremlin query.\n\nThe explain feature provides information about the logical structure of query\nexecution plans. You can use this information to identify potential evaluation\nand execution bottlenecks and to tune your query, as explained in [Tuning Gremlin\nqueries](https://docs.aws.amazon.com/neptune/latest/userguide/gremlin-traversal-tuning.html).\nYou can also use query hints to improve query execution plans.\n\nWhen invoking this operation in a Neptune cluster that has IAM authentication\nenabled, the IAM user or role making the request must have a policy attached\nthat allows one of the following IAM actions in that cluster, depending on the\nquery:\n\n  *\n[neptune-db:ReadDataViaQuery](https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#readdataviaquery)     *\n[neptune-db:WriteDataViaQuery](https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#writedataviaquery)\n\n  *\n[neptune-db:DeleteDataViaQuery](https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#deletedataviaquery) \n\nNote that the\n[neptune-db:QueryLanguage:Gremlin](https://docs.aws.amazon.com/neptune/latest/userguide/iam-data-condition-keys.html#iam-neptune-condition-keys)\nIAM condition key can be used in the policy document to restrict the use of\nGremlin queries (see [Condition keys available in Neptune IAM data-access policy statements](https://docs.aws.amazon.com/neptune/latest/userguide/iam-data-condition-keys.html)).","ref":"AWS.Neptunedata.html#execute_gremlin_explain_query/3","title":"AWS.Neptunedata.execute_gremlin_explain_query/3","type":"function"},{"doc":"Executes a Gremlin Profile query, which runs a specified traversal, collects\nvarious metrics about the run, and produces a profile report as output.\n\nSee [Gremlin profile API in Neptune](https://docs.aws.amazon.com/neptune/latest/userguide/gremlin-profile-api.html)\nfor details.\n\nWhen invoking this operation in a Neptune cluster that has IAM authentication\nenabled, the IAM user or role making the request must have a policy attached\nthat allows the\n[neptune-db:ReadDataViaQuery](https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#readdataviaquery) IAM action in that cluster.\n\nNote that the\n[neptune-db:QueryLanguage:Gremlin](https://docs.aws.amazon.com/neptune/latest/userguide/iam-data-condition-keys.html#iam-neptune-condition-keys)\nIAM condition key can be used in the policy document to restrict the use of\nGremlin queries (see [Condition keys available in Neptune IAM data-access policy statements](https://docs.aws.amazon.com/neptune/latest/userguide/iam-data-condition-keys.html)).","ref":"AWS.Neptunedata.html#execute_gremlin_profile_query/3","title":"AWS.Neptunedata.execute_gremlin_profile_query/3","type":"function"},{"doc":"This commands executes a Gremlin query.\n\nAmazon Neptune is compatible with Apache TinkerPop3 and Gremlin, so you can use\nthe Gremlin traversal language to query the graph, as described under [The Graph](https://tinkerpop.apache.org/docs/current/reference/#graph) in the Apache\nTinkerPop3 documentation. More details can also be found in [Accessing a Neptune graph with\nGremlin](https://docs.aws.amazon.com/neptune/latest/userguide/access-graph-gremlin.html).\n\nWhen invoking this operation in a Neptune cluster that has IAM authentication\nenabled, the IAM user or role making the request must have a policy attached\nthat enables one of the following IAM actions in that cluster, depending on the\nquery:\n\n  *\n[neptune-db:ReadDataViaQuery](https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#readdataviaquery)     *\n[neptune-db:WriteDataViaQuery](https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#writedataviaquery)\n\n  *\n[neptune-db:DeleteDataViaQuery](https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#deletedataviaquery) \n\nNote that the\n[neptune-db:QueryLanguage:Gremlin](https://docs.aws.amazon.com/neptune/latest/userguide/iam-data-condition-keys.html#iam-neptune-condition-keys)\nIAM condition key can be used in the policy document to restrict the use of\nGremlin queries (see [Condition keys available in Neptune IAM data-access policy statements](https://docs.aws.amazon.com/neptune/latest/userguide/iam-data-condition-keys.html)).","ref":"AWS.Neptunedata.html#execute_gremlin_query/3","title":"AWS.Neptunedata.execute_gremlin_query/3","type":"function"},{"doc":"Executes an openCypher `explain` request.\n\nSee [The openCypher explain feature](https://docs.aws.amazon.com/neptune/latest/userguide/access-graph-opencypher-explain.html)\nfor more information.\n\nWhen invoking this operation in a Neptune cluster that has IAM authentication\nenabled, the IAM user or role making the request must have a policy attached\nthat allows the\n[neptune-db:ReadDataViaQuery](https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#readdataviaquery) IAM action in that cluster.\n\nNote that the\n[neptune-db:QueryLanguage:OpenCypher](https://docs.aws.amazon.com/neptune/latest/userguide/iam-data-condition-keys.html#iam-neptune-condition-keys)\nIAM condition key can be used in the policy document to restrict the use of\nopenCypher queries (see [Condition keys available in Neptune IAM data-access policy\nstatements](https://docs.aws.amazon.com/neptune/latest/userguide/iam-data-condition-keys.html)).","ref":"AWS.Neptunedata.html#execute_open_cypher_explain_query/3","title":"AWS.Neptunedata.execute_open_cypher_explain_query/3","type":"function"},{"doc":"Retrieves the status of the graph database on the host.\n\nWhen invoking this operation in a Neptune cluster that has IAM authentication\nenabled, the IAM user or role making the request must have a policy attached\nthat allows the\n[neptune-db:GetEngineStatus](https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#getenginestatus)\nIAM action in that cluster.","ref":"AWS.Neptunedata.html#get_engine_status/2","title":"AWS.Neptunedata.get_engine_status/2","type":"function"},{"doc":"Gets the status of a specified Gremlin query.\n\nWhen invoking this operation in a Neptune cluster that has IAM authentication\nenabled, the IAM user or role making the request must have a policy attached\nthat allows the\n[neptune-db:GetQueryStatus](https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#getquerystatus) IAM action in that cluster.\n\nNote that the\n[neptune-db:QueryLanguage:Gremlin](https://docs.aws.amazon.com/neptune/latest/userguide/iam-data-condition-keys.html#iam-neptune-condition-keys)\nIAM condition key can be used in the policy document to restrict the use of\nGremlin queries (see [Condition keys available in Neptune IAM data-access policy statements](https://docs.aws.amazon.com/neptune/latest/userguide/iam-data-condition-keys.html)).","ref":"AWS.Neptunedata.html#get_gremlin_query_status/3","title":"AWS.Neptunedata.get_gremlin_query_status/3","type":"function"},{"doc":"Retrieves information about a specified data processing job.\n\nSee [The `dataprocessing` command](https://docs.aws.amazon.com/neptune/latest/userguide/machine-learning-api-dataprocessing.html).\n\nWhen invoking this operation in a Neptune cluster that has IAM authentication\nenabled, the IAM user or role making the request must have a policy attached\nthat allows the\n[neptune-db:neptune-db:GetMLDataProcessingJobStatus](https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#getmldataprocessingjobstatus)\nIAM action in that cluster.","ref":"AWS.Neptunedata.html#get_ml_data_processing_job/4","title":"AWS.Neptunedata.get_ml_data_processing_job/4","type":"function"},{"doc":"Retrieves details about an inference endpoint.\n\nSee [Managing inference endpoints using the endpoints command](https://docs.aws.amazon.com/neptune/latest/userguide/machine-learning-api-endpoints.html).\n\nWhen invoking this operation in a Neptune cluster that has IAM authentication\nenabled, the IAM user or role making the request must have a policy attached\nthat allows the\n[neptune-db:GetMLEndpointStatus](https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#getmlendpointstatus)\nIAM action in that cluster.","ref":"AWS.Neptunedata.html#get_ml_endpoint/4","title":"AWS.Neptunedata.get_ml_endpoint/4","type":"function"},{"doc":"Retrieves information about a Neptune ML model training job.\n\nSee [Model training using the `modeltraining` command](https://docs.aws.amazon.com/neptune/latest/userguide/machine-learning-api-modeltraining.html).\n\nWhen invoking this operation in a Neptune cluster that has IAM authentication\nenabled, the IAM user or role making the request must have a policy attached\nthat allows the\n[neptune-db:GetMLModelTrainingJobStatus](https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#getmlmodeltrainingjobstatus)\nIAM action in that cluster.","ref":"AWS.Neptunedata.html#get_ml_model_training_job/4","title":"AWS.Neptunedata.get_ml_model_training_job/4","type":"function"},{"doc":"Gets information about a specified model transform job.\n\nSee [Use a trained model to generate new model artifacts](https://docs.aws.amazon.com/neptune/latest/userguide/machine-learning-model-transform.html).\n\nWhen invoking this operation in a Neptune cluster that has IAM authentication\nenabled, the IAM user or role making the request must have a policy attached\nthat allows the\n[neptune-db:GetMLModelTransformJobStatus](https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#getmlmodeltransformjobstatus)\nIAM action in that cluster.","ref":"AWS.Neptunedata.html#get_ml_model_transform_job/4","title":"AWS.Neptunedata.get_ml_model_transform_job/4","type":"function"},{"doc":"Retrieves the status of a specified openCypher query.\n\nWhen invoking this operation in a Neptune cluster that has IAM authentication\nenabled, the IAM user or role making the request must have a policy attached\nthat allows the\n[neptune-db:GetQueryStatus](https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#getquerystatus) IAM action in that cluster.\n\nNote that the\n[neptune-db:QueryLanguage:OpenCypher](https://docs.aws.amazon.com/neptune/latest/userguide/iam-data-condition-keys.html#iam-neptune-condition-keys)\nIAM condition key can be used in the policy document to restrict the use of\nopenCypher queries (see [Condition keys available in Neptune IAM data-access policy\nstatements](https://docs.aws.amazon.com/neptune/latest/userguide/iam-data-condition-keys.html)).","ref":"AWS.Neptunedata.html#get_open_cypher_query_status/3","title":"AWS.Neptunedata.get_open_cypher_query_status/3","type":"function"},{"doc":"Gets property graph statistics (Gremlin and openCypher).\n\nWhen invoking this operation in a Neptune cluster that has IAM authentication\nenabled, the IAM user or role making the request must have a policy attached\nthat allows the\n[neptune-db:GetStatisticsStatus](https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#getstatisticsstatus)\nIAM action in that cluster.","ref":"AWS.Neptunedata.html#get_propertygraph_statistics/2","title":"AWS.Neptunedata.get_propertygraph_statistics/2","type":"function"},{"doc":"Gets a graph summary for a property graph.\n\nWhen invoking this operation in a Neptune cluster that has IAM authentication\nenabled, the IAM user or role making the request must have a policy attached\nthat allows the\n[neptune-db:GetGraphSummary](https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#getgraphsummary)\nIAM action in that cluster.","ref":"AWS.Neptunedata.html#get_propertygraph_summary/3","title":"AWS.Neptunedata.get_propertygraph_summary/3","type":"function"},{"doc":"Gets a graph summary for an RDF graph.\n\nWhen invoking this operation in a Neptune cluster that has IAM authentication\nenabled, the IAM user or role making the request must have a policy attached\nthat allows the\n[neptune-db:GetGraphSummary](https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#getgraphsummary)\nIAM action in that cluster.","ref":"AWS.Neptunedata.html#get_r_d_f_graph_summary/3","title":"AWS.Neptunedata.get_r_d_f_graph_summary/3","type":"function"},{"doc":"Gets RDF statistics (SPARQL).","ref":"AWS.Neptunedata.html#get_sparql_statistics/2","title":"AWS.Neptunedata.get_sparql_statistics/2","type":"function"},{"doc":"Gets a stream for an RDF graph.\n\nWith the Neptune Streams feature, you can generate a complete sequence of\nchange-log entries that record every change made to your graph data as it\nhappens. `GetSparqlStream` lets you collect these change-log entries for an RDF\ngraph.\n\nThe Neptune streams feature needs to be enabled on your Neptune DBcluster. To\nenable streams, set the\n[neptune_streams](https://docs.aws.amazon.com/neptune/latest/userguide/parameters.html#parameters-db-cluster-parameters-neptune_streams) DB cluster parameter to `1`.\n\nSee [Capturing graph changes in real time using Neptune\nstreams](https://docs.aws.amazon.com/neptune/latest/userguide/streams.html).\n\nWhen invoking this operation in a Neptune cluster that has IAM authentication\nenabled, the IAM user or role making the request must have a policy attached\nthat allows the\n[neptune-db:GetStreamRecords](https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#getstreamrecords) IAM action in that cluster.\n\nNote that the\n[neptune-db:QueryLanguage:Sparql](https://docs.aws.amazon.com/neptune/latest/userguide/iam-data-condition-keys.html#iam-neptune-condition-keys)\nIAM condition key can be used in the policy document to restrict the use of\nSPARQL queries (see [Condition keys available in Neptune IAM data-access policy statements](https://docs.aws.amazon.com/neptune/latest/userguide/iam-data-condition-keys.html)).","ref":"AWS.Neptunedata.html#get_sparql_stream/7","title":"AWS.Neptunedata.get_sparql_stream/7","type":"function"},{"doc":"Lists active Gremlin queries.\n\nSee [Gremlin query status API](https://docs.aws.amazon.com/neptune/latest/userguide/gremlin-api-status.html)\nfor details about the output.\n\nWhen invoking this operation in a Neptune cluster that has IAM authentication\nenabled, the IAM user or role making the request must have a policy attached\nthat allows the\n[neptune-db:GetQueryStatus](https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#getquerystatus) IAM action in that cluster.\n\nNote that the\n[neptune-db:QueryLanguage:Gremlin](https://docs.aws.amazon.com/neptune/latest/userguide/iam-data-condition-keys.html#iam-neptune-condition-keys)\nIAM condition key can be used in the policy document to restrict the use of\nGremlin queries (see [Condition keys available in Neptune IAM data-access policy statements](https://docs.aws.amazon.com/neptune/latest/userguide/iam-data-condition-keys.html)).","ref":"AWS.Neptunedata.html#list_gremlin_queries/3","title":"AWS.Neptunedata.list_gremlin_queries/3","type":"function"},{"doc":"Retrieves a list of the `loadIds` for all active loader jobs.\n\nWhen invoking this operation in a Neptune cluster that has IAM authentication\nenabled, the IAM user or role making the request must have a policy attached\nthat allows the\n[neptune-db:ListLoaderJobs](https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#listloaderjobs)\nIAM action in that cluster..","ref":"AWS.Neptunedata.html#list_loader_jobs/4","title":"AWS.Neptunedata.list_loader_jobs/4","type":"function"},{"doc":"Returns a list of Neptune ML data processing jobs.\n\nSee [Listing active data-processing jobs using the Neptune ML dataprocessing command](https://docs.aws.amazon.com/neptune/latest/userguide/machine-learning-api-dataprocessing.html#machine-learning-api-dataprocessing-list-jobs).\n\nWhen invoking this operation in a Neptune cluster that has IAM authentication\nenabled, the IAM user or role making the request must have a policy attached\nthat allows the\n[neptune-db:ListMLDataProcessingJobs](https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#listmldataprocessingjobs)\nIAM action in that cluster.","ref":"AWS.Neptunedata.html#list_ml_data_processing_jobs/4","title":"AWS.Neptunedata.list_ml_data_processing_jobs/4","type":"function"},{"doc":"Lists existing inference endpoints.\n\nSee [Managing inference endpoints using the endpoints command](https://docs.aws.amazon.com/neptune/latest/userguide/machine-learning-api-endpoints.html).\n\nWhen invoking this operation in a Neptune cluster that has IAM authentication\nenabled, the IAM user or role making the request must have a policy attached\nthat allows the\n[neptune-db:ListMLEndpoints](https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#listmlendpoints)\nIAM action in that cluster.","ref":"AWS.Neptunedata.html#list_ml_endpoints/4","title":"AWS.Neptunedata.list_ml_endpoints/4","type":"function"},{"doc":"Lists Neptune ML model-training jobs.\n\nSee [Model training using the `modeltraining` command](https://docs.aws.amazon.com/neptune/latest/userguide/machine-learning-api-modeltraining.html).\n\nWhen invoking this operation in a Neptune cluster that has IAM authentication\nenabled, the IAM user or role making the request must have a policy attached\nthat allows the\n[neptune-db:neptune-db:ListMLModelTrainingJobs](https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#neptune-db:listmlmodeltrainingjobs)\nIAM action in that cluster.","ref":"AWS.Neptunedata.html#list_ml_model_training_jobs/4","title":"AWS.Neptunedata.list_ml_model_training_jobs/4","type":"function"},{"doc":"Returns a list of model transform job IDs.\n\nSee [Use a trained model to generate new model artifacts](https://docs.aws.amazon.com/neptune/latest/userguide/machine-learning-model-transform.html).\n\nWhen invoking this operation in a Neptune cluster that has IAM authentication\nenabled, the IAM user or role making the request must have a policy attached\nthat allows the\n[neptune-db:ListMLModelTransformJobs](https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#listmlmodeltransformjobs)\nIAM action in that cluster.","ref":"AWS.Neptunedata.html#list_ml_model_transform_jobs/4","title":"AWS.Neptunedata.list_ml_model_transform_jobs/4","type":"function"},{"doc":"Lists active openCypher queries.\n\nSee [Neptune openCypher status endpoint](https://docs.aws.amazon.com/neptune/latest/userguide/access-graph-opencypher-status.html)\nfor more information.\n\nWhen invoking this operation in a Neptune cluster that has IAM authentication\nenabled, the IAM user or role making the request must have a policy attached\nthat allows the\n[neptune-db:GetQueryStatus](https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#getquerystatus) IAM action in that cluster.\n\nNote that the\n[neptune-db:QueryLanguage:OpenCypher](https://docs.aws.amazon.com/neptune/latest/userguide/iam-data-condition-keys.html#iam-neptune-condition-keys)\nIAM condition key can be used in the policy document to restrict the use of\nopenCypher queries (see [Condition keys available in Neptune IAM data-access policy\nstatements](https://docs.aws.amazon.com/neptune/latest/userguide/iam-data-condition-keys.html)).","ref":"AWS.Neptunedata.html#list_open_cypher_queries/3","title":"AWS.Neptunedata.list_open_cypher_queries/3","type":"function"},{"doc":"Manages the generation and use of property graph statistics.\n\nWhen invoking this operation in a Neptune cluster that has IAM authentication\nenabled, the IAM user or role making the request must have a policy attached\nthat allows the\n[neptune-db:ManageStatistics](https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#managestatistics)\nIAM action in that cluster.","ref":"AWS.Neptunedata.html#manage_propertygraph_statistics/3","title":"AWS.Neptunedata.manage_propertygraph_statistics/3","type":"function"},{"doc":"Manages the generation and use of RDF graph statistics.\n\nWhen invoking this operation in a Neptune cluster that has IAM authentication\nenabled, the IAM user or role making the request must have a policy attached\nthat allows the\n[neptune-db:ManageStatistics](https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#managestatistics)\nIAM action in that cluster.","ref":"AWS.Neptunedata.html#manage_sparql_statistics/3","title":"AWS.Neptunedata.manage_sparql_statistics/3","type":"function"},{"doc":"","ref":"AWS.Neptunedata.html#metadata/0","title":"AWS.Neptunedata.metadata/0","type":"function"},{"doc":"Starts a Neptune bulk loader job to load data from an Amazon S3 bucket into a\nNeptune DB instance.\n\nSee [Using the Amazon Neptune Bulk Loader to Ingest Data](https://docs.aws.amazon.com/neptune/latest/userguide/bulk-load.html).\n\nWhen invoking this operation in a Neptune cluster that has IAM authentication\nenabled, the IAM user or role making the request must have a policy attached\nthat allows the\n[neptune-db:StartLoaderJob](https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#startloaderjob)\nIAM action in that cluster.","ref":"AWS.Neptunedata.html#start_loader_job/3","title":"AWS.Neptunedata.start_loader_job/3","type":"function"},{"doc":"Creates a new Neptune ML data processing job for processing the graph data\nexported from Neptune for training.\n\nSee [The `dataprocessing` command](https://docs.aws.amazon.com/neptune/latest/userguide/machine-learning-api-dataprocessing.html).\n\nWhen invoking this operation in a Neptune cluster that has IAM authentication\nenabled, the IAM user or role making the request must have a policy attached\nthat allows the\n[neptune-db:StartMLModelDataProcessingJob](https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#startmlmodeldataprocessingjob)\nIAM action in that cluster.","ref":"AWS.Neptunedata.html#start_ml_data_processing_job/3","title":"AWS.Neptunedata.start_ml_data_processing_job/3","type":"function"},{"doc":"Creates a new Neptune ML model training job.\n\nSee [Model training using the `modeltraining` command](https://docs.aws.amazon.com/neptune/latest/userguide/machine-learning-api-modeltraining.html).\n\nWhen invoking this operation in a Neptune cluster that has IAM authentication\nenabled, the IAM user or role making the request must have a policy attached\nthat allows the\n[neptune-db:StartMLModelTrainingJob](https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#startmlmodeltrainingjob)\nIAM action in that cluster.","ref":"AWS.Neptunedata.html#start_ml_model_training_job/3","title":"AWS.Neptunedata.start_ml_model_training_job/3","type":"function"},{"doc":"Creates a new model transform job.\n\nSee [Use a trained model to generate new model artifacts](https://docs.aws.amazon.com/neptune/latest/userguide/machine-learning-model-transform.html).\n\nWhen invoking this operation in a Neptune cluster that has IAM authentication\nenabled, the IAM user or role making the request must have a policy attached\nthat allows the\n[neptune-db:StartMLModelTransformJob](https://docs.aws.amazon.com/neptune/latest/userguide/iam-dp-actions.html#startmlmodeltransformjob)\nIAM action in that cluster.","ref":"AWS.Neptunedata.html#start_ml_model_transform_job/3","title":"AWS.Neptunedata.start_ml_model_transform_job/3","type":"function"},{"doc":"This is the API Reference for Network Firewall.\n\nThis guide is for developers who need detailed information about the Network\nFirewall API actions, data types, and errors.\n\n  * The REST API requires you to handle connection details, such as\ncalculating signatures, handling request retries, and error handling. For\ngeneral information about using the Amazon Web Services REST APIs, see [Amazon Web Services APIs](https://docs.aws.amazon.com/general/latest/gr/aws-apis.html).\n\nTo access Network Firewall using the REST API endpoint:\n`https://network-firewall. .amazonaws.com `\n\n  * Alternatively, you can use one of the Amazon Web Services SDKs to\naccess an API that's tailored to the programming language or platform that\nyou're using. For more information, see [Amazon Web Services SDKs](http://aws.amazon.com/tools/#SDKs).\n\n  * For descriptions of Network Firewall features, including and\nstep-by-step instructions on how to use them through the Network Firewall\nconsole, see the [Network Firewall Developer Guide](https://docs.aws.amazon.com/network-firewall/latest/developerguide/).\n\nNetwork Firewall is a stateful, managed, network firewall and intrusion\ndetection and prevention service for Amazon Virtual Private Cloud (Amazon VPC).\nWith Network Firewall, you can filter traffic at the perimeter of your VPC. This\nincludes filtering traffic going to and coming from an internet gateway, NAT\ngateway, or over VPN or Direct Connect. Network Firewall uses rules that are\ncompatible with Suricata, a free, open source network analysis and threat\ndetection engine. Network Firewall supports Suricata version 6.0.9. For\ninformation about Suricata, see the [Suricata website](https://suricata.io/).  You can use Network Firewall to monitor and protect your VPC traffic in a number\nof ways. The following are just a few examples:\n\n  * Allow domains or IP addresses for known Amazon Web Services\nservice endpoints, such as Amazon S3, and block all other forms of traffic.\n\n  * Use custom lists of known bad domains to limit the types of domain\nnames that your applications can access.\n\n  * Perform deep packet inspection on traffic entering or leaving your\nVPC.\n\n  * Use stateful protocol detection to filter protocols like HTTPS,\nregardless of the port used.\n\nTo enable Network Firewall for your VPCs, you perform steps in both Amazon VPC\nand in Network Firewall. For information about using Amazon VPC, see [Amazon VPC\nUser Guide](https://docs.aws.amazon.com/vpc/latest/userguide/).\n\nTo start using Network Firewall, do the following:\n\n  1. (Optional) If you don't already have a VPC that you want to\nprotect, create it in Amazon VPC.\n\n  2. In Amazon VPC, in each Availability Zone where you want to have a\nfirewall endpoint, create a subnet for the sole use of Network Firewall.\n\n  3. In Network Firewall, create stateless and stateful rule groups,\nto define the components of the network traffic filtering behavior that you want\nyour firewall to have.\n\n  4. In Network Firewall, create a firewall policy that uses your rule\ngroups and specifies additional default traffic filtering behavior.\n\n  5. In Network Firewall, create a firewall and specify your new\nfirewall policy and VPC subnets. Network Firewall creates a firewall endpoint in\neach subnet that you specify, with the behavior that's defined in the firewall\npolicy.\n\n  6. In Amazon VPC, use ingress routing enhancements to route traffic\nthrough the new firewall endpoints.","ref":"AWS.NetworkFirewall.html","title":"AWS.NetworkFirewall","type":"module"},{"doc":"Associates a `FirewallPolicy` to a `Firewall`.\n\nA firewall policy defines how to monitor and manage your VPC network traffic,\nusing a collection of inspection rule groups and other settings. Each firewall\nrequires one firewall policy association, and you can use the same firewall\npolicy for multiple firewalls.","ref":"AWS.NetworkFirewall.html#associate_firewall_policy/3","title":"AWS.NetworkFirewall.associate_firewall_policy/3","type":"function"},{"doc":"Associates the specified subnets in the Amazon VPC to the firewall.\n\nYou can specify one subnet for each of the Availability Zones that the VPC\nspans.\n\nThis request creates an Network Firewall firewall endpoint in each of the\nsubnets. To enable the firewall's protections, you must also modify the VPC's\nroute tables for each subnet's Availability Zone, to redirect the traffic that's\ncoming into and going out of the zone through the firewall endpoint.","ref":"AWS.NetworkFirewall.html#associate_subnets/3","title":"AWS.NetworkFirewall.associate_subnets/3","type":"function"},{"doc":"Creates an Network Firewall `Firewall` and accompanying `FirewallStatus` for a\nVPC.\n\nThe firewall defines the configuration settings for an Network Firewall\nfirewall. The settings that you can define at creation include the firewall\npolicy, the subnets in your VPC to use for the firewall endpoints, and any tags\nthat are attached to the firewall Amazon Web Services resource.\n\nAfter you create a firewall, you can provide additional settings, like the\nlogging configuration.\n\nTo update the settings for a firewall, you use the operations that apply to the\nsettings themselves, for example `UpdateLoggingConfiguration`,\n`AssociateSubnets`, and `UpdateFirewallDeleteProtection`.\n\nTo manage a firewall's tags, use the standard Amazon Web Services resource\ntagging operations, `ListTagsForResource`, `TagResource`, and `UntagResource`.\n\nTo retrieve information about firewalls, use `ListFirewalls` and\n`DescribeFirewall`.","ref":"AWS.NetworkFirewall.html#create_firewall/3","title":"AWS.NetworkFirewall.create_firewall/3","type":"function"},{"doc":"Creates the firewall policy for the firewall according to the specifications.\n\nAn Network Firewall firewall policy defines the behavior of a firewall, in a\ncollection of stateless and stateful rule groups and other settings. You can use\none firewall policy for multiple firewalls.","ref":"AWS.NetworkFirewall.html#create_firewall_policy/3","title":"AWS.NetworkFirewall.create_firewall_policy/3","type":"function"},{"doc":"Creates the specified stateless or stateful rule group, which includes the rules\nfor network traffic inspection, a capacity setting, and tags.\n\nYou provide your rule group specification in your request using either\n`RuleGroup` or `Rules`.","ref":"AWS.NetworkFirewall.html#create_rule_group/3","title":"AWS.NetworkFirewall.create_rule_group/3","type":"function"},{"doc":"Creates an Network Firewall TLS inspection configuration.\n\nA TLS inspection configuration contains Certificate Manager certificate\nassociations between and the scope configurations that Network Firewall uses to\ndecrypt and re-encrypt traffic traveling through your firewall.\n\nAfter you create a TLS inspection configuration, you can associate it with a new\nfirewall policy.\n\nTo update the settings for a TLS inspection configuration, use\n`UpdateTLSInspectionConfiguration`.\n\nTo manage a TLS inspection configuration's tags, use the standard Amazon Web\nServices resource tagging operations, `ListTagsForResource`, `TagResource`, and\n`UntagResource`.\n\nTo retrieve information about TLS inspection configurations, use\n`ListTLSInspectionConfigurations` and `DescribeTLSInspectionConfiguration`.\n\nFor more information about TLS inspection configurations, see [Inspecting SSL/TLS traffic with TLS inspection\nconfigurations](https://docs.aws.amazon.com/network-firewall/latest/developerguide/tls-inspection.html)\nin the *Network Firewall Developer Guide*.","ref":"AWS.NetworkFirewall.html#create_t_l_s_inspection_configuration/3","title":"AWS.NetworkFirewall.create_t_l_s_inspection_configuration/3","type":"function"},{"doc":"Deletes the specified `Firewall` and its `FirewallStatus`.\n\nThis operation requires the firewall's `DeleteProtection` flag to be `FALSE`.\nYou can't revert this operation.\n\nYou can check whether a firewall is in use by reviewing the route tables for the\nAvailability Zones where you have firewall subnet mappings. Retrieve the subnet\nmappings by calling `DescribeFirewall`. You define and update the route tables\nthrough Amazon VPC. As needed, update the route tables for the zones to remove\nthe firewall endpoints. When the route tables no longer use the firewall\nendpoints, you can remove the firewall safely.\n\nTo delete a firewall, remove the delete protection if you need to using\n`UpdateFirewallDeleteProtection`, then delete the firewall by calling\n`DeleteFirewall`.","ref":"AWS.NetworkFirewall.html#delete_firewall/3","title":"AWS.NetworkFirewall.delete_firewall/3","type":"function"},{"doc":"Deletes the specified `FirewallPolicy`.","ref":"AWS.NetworkFirewall.html#delete_firewall_policy/3","title":"AWS.NetworkFirewall.delete_firewall_policy/3","type":"function"},{"doc":"Deletes a resource policy that you created in a `PutResourcePolicy` request.","ref":"AWS.NetworkFirewall.html#delete_resource_policy/3","title":"AWS.NetworkFirewall.delete_resource_policy/3","type":"function"},{"doc":"Deletes the specified `RuleGroup`.","ref":"AWS.NetworkFirewall.html#delete_rule_group/3","title":"AWS.NetworkFirewall.delete_rule_group/3","type":"function"},{"doc":"Deletes the specified `TLSInspectionConfiguration`.","ref":"AWS.NetworkFirewall.html#delete_t_l_s_inspection_configuration/3","title":"AWS.NetworkFirewall.delete_t_l_s_inspection_configuration/3","type":"function"},{"doc":"Returns the data objects for the specified firewall.","ref":"AWS.NetworkFirewall.html#describe_firewall/3","title":"AWS.NetworkFirewall.describe_firewall/3","type":"function"},{"doc":"Returns the data objects for the specified firewall policy.","ref":"AWS.NetworkFirewall.html#describe_firewall_policy/3","title":"AWS.NetworkFirewall.describe_firewall_policy/3","type":"function"},{"doc":"Returns the logging configuration for the specified firewall.","ref":"AWS.NetworkFirewall.html#describe_logging_configuration/3","title":"AWS.NetworkFirewall.describe_logging_configuration/3","type":"function"},{"doc":"Retrieves a resource policy that you created in a `PutResourcePolicy` request.","ref":"AWS.NetworkFirewall.html#describe_resource_policy/3","title":"AWS.NetworkFirewall.describe_resource_policy/3","type":"function"},{"doc":"Returns the data objects for the specified rule group.","ref":"AWS.NetworkFirewall.html#describe_rule_group/3","title":"AWS.NetworkFirewall.describe_rule_group/3","type":"function"},{"doc":"High-level information about a rule group, returned by operations like create\nand describe.\n\nYou can use the information provided in the metadata to retrieve and manage a\nrule group. You can retrieve all objects for a rule group by calling\n`DescribeRuleGroup`.","ref":"AWS.NetworkFirewall.html#describe_rule_group_metadata/3","title":"AWS.NetworkFirewall.describe_rule_group_metadata/3","type":"function"},{"doc":"Returns the data objects for the specified TLS inspection configuration.","ref":"AWS.NetworkFirewall.html#describe_t_l_s_inspection_configuration/3","title":"AWS.NetworkFirewall.describe_t_l_s_inspection_configuration/3","type":"function"},{"doc":"Removes the specified subnet associations from the firewall.\n\nThis removes the firewall endpoints from the subnets and removes any network\nfiltering protections that the endpoints were providing.","ref":"AWS.NetworkFirewall.html#disassociate_subnets/3","title":"AWS.NetworkFirewall.disassociate_subnets/3","type":"function"},{"doc":"Retrieves the metadata for the firewall policies that you have defined.\n\nDepending on your setting for max results and the number of firewall policies, a\nsingle call might not return the full list.","ref":"AWS.NetworkFirewall.html#list_firewall_policies/3","title":"AWS.NetworkFirewall.list_firewall_policies/3","type":"function"},{"doc":"Retrieves the metadata for the firewalls that you have defined.\n\nIf you provide VPC identifiers in your request, this returns only the firewalls\nfor those VPCs.\n\nDepending on your setting for max results and the number of firewalls, a single\ncall might not return the full list.","ref":"AWS.NetworkFirewall.html#list_firewalls/3","title":"AWS.NetworkFirewall.list_firewalls/3","type":"function"},{"doc":"Retrieves the metadata for the rule groups that you have defined.\n\nDepending on your setting for max results and the number of rule groups, a\nsingle call might not return the full list.","ref":"AWS.NetworkFirewall.html#list_rule_groups/3","title":"AWS.NetworkFirewall.list_rule_groups/3","type":"function"},{"doc":"Retrieves the metadata for the TLS inspection configurations that you have\ndefined.\n\nDepending on your setting for max results and the number of TLS inspection\nconfigurations, a single call might not return the full list.","ref":"AWS.NetworkFirewall.html#list_t_l_s_inspection_configurations/3","title":"AWS.NetworkFirewall.list_t_l_s_inspection_configurations/3","type":"function"},{"doc":"Retrieves the tags associated with the specified resource.\n\nTags are key:value pairs that you can use to categorize and manage your\nresources, for purposes like billing. For example, you might set the tag key to\n\"customer\" and the value to the customer name or ID. You can specify one or more\ntags to add to each Amazon Web Services resource, up to 50 tags for a resource.\n\nYou can tag the Amazon Web Services resources that you manage through Network\nFirewall: firewalls, firewall policies, and rule groups.","ref":"AWS.NetworkFirewall.html#list_tags_for_resource/3","title":"AWS.NetworkFirewall.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.NetworkFirewall.html#metadata/0","title":"AWS.NetworkFirewall.metadata/0","type":"function"},{"doc":"Creates or updates an IAM policy for your rule group or firewall policy.\n\nUse this to share rule groups and firewall policies between accounts. This\noperation works in conjunction with the Amazon Web Services Resource Access\nManager (RAM) service to manage resource sharing for Network Firewall.\n\nUse this operation to create or update a resource policy for your rule group or\nfirewall policy. In the policy, you specify the accounts that you want to share\nthe resource with and the operations that you want the accounts to be able to\nperform.\n\nWhen you add an account in the resource policy, you then run the following\nResource Access Manager (RAM) operations to access and accept the shared rule\ngroup or firewall policy.\n\n  *\n[GetResourceShareInvitations](https://docs.aws.amazon.com/ram/latest/APIReference/API_GetResourceShareInvitations.html) - Returns the Amazon Resource Names (ARNs) of the resource share invitations.\n\n  *\n[AcceptResourceShareInvitation](https://docs.aws.amazon.com/ram/latest/APIReference/API_AcceptResourceShareInvitation.html)\n- Accepts the share invitation for a specified resource share.\n\nFor additional information about resource sharing using RAM, see [Resource Access Manager User\nGuide](https://docs.aws.amazon.com/ram/latest/userguide/what-is.html).","ref":"AWS.NetworkFirewall.html#put_resource_policy/3","title":"AWS.NetworkFirewall.put_resource_policy/3","type":"function"},{"doc":"Adds the specified tags to the specified resource.\n\nTags are key:value pairs that you can use to categorize and manage your\nresources, for purposes like billing. For example, you might set the tag key to\n\"customer\" and the value to the customer name or ID. You can specify one or more\ntags to add to each Amazon Web Services resource, up to 50 tags for a resource.\n\nYou can tag the Amazon Web Services resources that you manage through Network\nFirewall: firewalls, firewall policies, and rule groups.","ref":"AWS.NetworkFirewall.html#tag_resource/3","title":"AWS.NetworkFirewall.tag_resource/3","type":"function"},{"doc":"Removes the tags with the specified keys from the specified resource.\n\nTags are key:value pairs that you can use to categorize and manage your\nresources, for purposes like billing. For example, you might set the tag key to\n\"customer\" and the value to the customer name or ID. You can specify one or more\ntags to add to each Amazon Web Services resource, up to 50 tags for a resource.\n\nYou can manage tags for the Amazon Web Services resources that you manage\nthrough Network Firewall: firewalls, firewall policies, and rule groups.","ref":"AWS.NetworkFirewall.html#untag_resource/3","title":"AWS.NetworkFirewall.untag_resource/3","type":"function"},{"doc":"Modifies the flag, `DeleteProtection`, which indicates whether it is possible to\ndelete the firewall.\n\nIf the flag is set to `TRUE`, the firewall is protected against deletion. This\nsetting helps protect against accidentally deleting a firewall that's in use.","ref":"AWS.NetworkFirewall.html#update_firewall_delete_protection/3","title":"AWS.NetworkFirewall.update_firewall_delete_protection/3","type":"function"},{"doc":"Modifies the description for the specified firewall.\n\nUse the description to help you identify the firewall when you're working with\nit.","ref":"AWS.NetworkFirewall.html#update_firewall_description/3","title":"AWS.NetworkFirewall.update_firewall_description/3","type":"function"},{"doc":"A complex type that contains settings for encryption of your firewall resources.","ref":"AWS.NetworkFirewall.html#update_firewall_encryption_configuration/3","title":"AWS.NetworkFirewall.update_firewall_encryption_configuration/3","type":"function"},{"doc":"Updates the properties of the specified firewall policy.","ref":"AWS.NetworkFirewall.html#update_firewall_policy/3","title":"AWS.NetworkFirewall.update_firewall_policy/3","type":"function"},{"doc":"Modifies the flag, `ChangeProtection`, which indicates whether it is possible to\nchange the firewall.\n\nIf the flag is set to `TRUE`, the firewall is protected from changes. This\nsetting helps protect against accidentally changing a firewall that's in use.","ref":"AWS.NetworkFirewall.html#update_firewall_policy_change_protection/3","title":"AWS.NetworkFirewall.update_firewall_policy_change_protection/3","type":"function"},{"doc":"Sets the logging configuration for the specified firewall.\n\nTo change the logging configuration, retrieve the `LoggingConfiguration` by\ncalling `DescribeLoggingConfiguration`, then change it and provide the modified\nobject to this update call. You must change the logging configuration one\n`LogDestinationConfig` at a time inside the retrieved `LoggingConfiguration`\nobject.\n\nYou can perform only one of the following actions in any call to\n`UpdateLoggingConfiguration`:\n\n  * Create a new log destination object by adding a single\n`LogDestinationConfig` array element to `LogDestinationConfigs`.\n\n  * Delete a log destination object by removing a single\n`LogDestinationConfig` array element from `LogDestinationConfigs`.\n\n  * Change the `LogDestination` setting in a single\n`LogDestinationConfig` array element.\n\nYou can't change the `LogDestinationType` or `LogType` in a\n`LogDestinationConfig`. To change these settings, delete the existing\n`LogDestinationConfig` object and create a new one, using two separate calls to\nthis update operation.","ref":"AWS.NetworkFirewall.html#update_logging_configuration/3","title":"AWS.NetworkFirewall.update_logging_configuration/3","type":"function"},{"doc":"Updates the rule settings for the specified rule group.\n\nYou use a rule group by reference in one or more firewall policies. When you\nmodify a rule group, you modify all firewall policies that use the rule group.\n\nTo update a rule group, first call `DescribeRuleGroup` to retrieve the current\n`RuleGroup` object, update the object as needed, and then provide the updated\nobject to this call.","ref":"AWS.NetworkFirewall.html#update_rule_group/3","title":"AWS.NetworkFirewall.update_rule_group/3","type":"function"},{"doc":"","ref":"AWS.NetworkFirewall.html#update_subnet_change_protection/3","title":"AWS.NetworkFirewall.update_subnet_change_protection/3","type":"function"},{"doc":"Updates the TLS inspection configuration settings for the specified TLS\ninspection configuration.\n\nYou use a TLS inspection configuration by referencing it in one or more firewall\npolicies. When you modify a TLS inspection configuration, you modify all\nfirewall policies that use the TLS inspection configuration.\n\nTo update a TLS inspection configuration, first call\n`DescribeTLSInspectionConfiguration` to retrieve the current\n`TLSInspectionConfiguration` object, update the object as needed, and then\nprovide the updated object to this call.","ref":"AWS.NetworkFirewall.html#update_t_l_s_inspection_configuration/3","title":"AWS.NetworkFirewall.update_t_l_s_inspection_configuration/3","type":"function"},{"doc":"Amazon Web Services enables you to centrally manage your Amazon Web Services\nCloud WAN core network and your Transit Gateway network across Amazon Web\nServices accounts, Regions, and on-premises locations.","ref":"AWS.NetworkManager.html","title":"AWS.NetworkManager","type":"module"},{"doc":"Accepts a core network attachment request.\n\nOnce the attachment request is accepted by a core network owner, the attachment\nis created and connected to a core network.","ref":"AWS.NetworkManager.html#accept_attachment/4","title":"AWS.NetworkManager.accept_attachment/4","type":"function"},{"doc":"Associates a core network Connect peer with a device and optionally, with a\nlink.\n\nIf you specify a link, it must be associated with the specified device. You can\nonly associate core network Connect peers that have been created on a core\nnetwork Connect attachment on a core network.","ref":"AWS.NetworkManager.html#associate_connect_peer/4","title":"AWS.NetworkManager.associate_connect_peer/4","type":"function"},{"doc":"Associates a customer gateway with a device and optionally, with a link.\n\nIf you specify a link, it must be associated with the specified device.\n\nYou can only associate customer gateways that are connected to a VPN attachment\non a transit gateway or core network registered in your global network. When you\nregister a transit gateway or core network, customer gateways that are connected\nto the transit gateway are automatically included in the global network. To list\ncustomer gateways that are connected to a transit gateway, use the\n[DescribeVpnConnections](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeVpnConnections.html)\nEC2 API and filter by `transit-gateway-id`.\n\nYou cannot associate a customer gateway with more than one device and link.","ref":"AWS.NetworkManager.html#associate_customer_gateway/4","title":"AWS.NetworkManager.associate_customer_gateway/4","type":"function"},{"doc":"Associates a link to a device.\n\nA device can be associated to multiple links and a link can be associated to\nmultiple devices. The device and link must be in the same global network and the\nsame site.","ref":"AWS.NetworkManager.html#associate_link/4","title":"AWS.NetworkManager.associate_link/4","type":"function"},{"doc":"Associates a transit gateway Connect peer with a device, and optionally, with a\nlink.\n\nIf you specify a link, it must be associated with the specified device.\n\nYou can only associate transit gateway Connect peers that have been created on a\ntransit gateway that's registered in your global network.\n\nYou cannot associate a transit gateway Connect peer with more than one device\nand link.","ref":"AWS.NetworkManager.html#associate_transit_gateway_connect_peer/4","title":"AWS.NetworkManager.associate_transit_gateway_connect_peer/4","type":"function"},{"doc":"Creates a core network Connect attachment from a specified core network\nattachment.\n\nA core network Connect attachment is a GRE-based tunnel attachment that you can\nuse to establish a connection between a core network and an appliance. A core\nnetwork Connect attachment uses an existing VPC attachment as the underlying\ntransport mechanism.","ref":"AWS.NetworkManager.html#create_connect_attachment/3","title":"AWS.NetworkManager.create_connect_attachment/3","type":"function"},{"doc":"Creates a core network Connect peer for a specified core network connect\nattachment between a core network and an appliance.\n\nThe peer address and transit gateway address must be the same IP address family\n(IPv4 or IPv6).","ref":"AWS.NetworkManager.html#create_connect_peer/3","title":"AWS.NetworkManager.create_connect_peer/3","type":"function"},{"doc":"Creates a connection between two devices.\n\nThe devices can be a physical or virtual appliance that connects to a\nthird-party appliance in a VPC, or a physical appliance that connects to another\nphysical appliance in an on-premises network.","ref":"AWS.NetworkManager.html#create_connection/4","title":"AWS.NetworkManager.create_connection/4","type":"function"},{"doc":"Creates a core network as part of your global network, and optionally, with a\ncore network policy.","ref":"AWS.NetworkManager.html#create_core_network/3","title":"AWS.NetworkManager.create_core_network/3","type":"function"},{"doc":"Creates a new device in a global network.\n\nIf you specify both a site ID and a location, the location of the site is used\nfor visualization in the Network Manager console.","ref":"AWS.NetworkManager.html#create_device/4","title":"AWS.NetworkManager.create_device/4","type":"function"},{"doc":"Creates a new, empty global network.","ref":"AWS.NetworkManager.html#create_global_network/3","title":"AWS.NetworkManager.create_global_network/3","type":"function"},{"doc":"Creates a new link for a specified site.","ref":"AWS.NetworkManager.html#create_link/4","title":"AWS.NetworkManager.create_link/4","type":"function"},{"doc":"Creates a new site in a global network.","ref":"AWS.NetworkManager.html#create_site/4","title":"AWS.NetworkManager.create_site/4","type":"function"},{"doc":"Creates an Amazon Web Services site-to-site VPN attachment on an edge location\nof a core network.","ref":"AWS.NetworkManager.html#create_site_to_site_vpn_attachment/3","title":"AWS.NetworkManager.create_site_to_site_vpn_attachment/3","type":"function"},{"doc":"Creates a transit gateway peering connection.","ref":"AWS.NetworkManager.html#create_transit_gateway_peering/3","title":"AWS.NetworkManager.create_transit_gateway_peering/3","type":"function"},{"doc":"Creates a transit gateway route table attachment.","ref":"AWS.NetworkManager.html#create_transit_gateway_route_table_attachment/3","title":"AWS.NetworkManager.create_transit_gateway_route_table_attachment/3","type":"function"},{"doc":"Creates a VPC attachment on an edge location of a core network.","ref":"AWS.NetworkManager.html#create_vpc_attachment/3","title":"AWS.NetworkManager.create_vpc_attachment/3","type":"function"},{"doc":"Deletes an attachment.\n\nSupports all attachment types.","ref":"AWS.NetworkManager.html#delete_attachment/4","title":"AWS.NetworkManager.delete_attachment/4","type":"function"},{"doc":"Deletes a Connect peer.","ref":"AWS.NetworkManager.html#delete_connect_peer/4","title":"AWS.NetworkManager.delete_connect_peer/4","type":"function"},{"doc":"Deletes the specified connection in your global network.","ref":"AWS.NetworkManager.html#delete_connection/5","title":"AWS.NetworkManager.delete_connection/5","type":"function"},{"doc":"Deletes a core network along with all core network policies.\n\nThis can only be done if there are no attachments on a core network.","ref":"AWS.NetworkManager.html#delete_core_network/4","title":"AWS.NetworkManager.delete_core_network/4","type":"function"},{"doc":"Deletes a policy version from a core network.\n\nYou can't delete the current LIVE policy.","ref":"AWS.NetworkManager.html#delete_core_network_policy_version/5","title":"AWS.NetworkManager.delete_core_network_policy_version/5","type":"function"},{"doc":"Deletes an existing device.\n\nYou must first disassociate the device from any links and customer gateways.","ref":"AWS.NetworkManager.html#delete_device/5","title":"AWS.NetworkManager.delete_device/5","type":"function"},{"doc":"Deletes an existing global network.\n\nYou must first delete all global network objects (devices, links, and sites),\nderegister all transit gateways, and delete any core networks.","ref":"AWS.NetworkManager.html#delete_global_network/4","title":"AWS.NetworkManager.delete_global_network/4","type":"function"},{"doc":"Deletes an existing link.\n\nYou must first disassociate the link from any devices and customer gateways.","ref":"AWS.NetworkManager.html#delete_link/5","title":"AWS.NetworkManager.delete_link/5","type":"function"},{"doc":"Deletes an existing peering connection.","ref":"AWS.NetworkManager.html#delete_peering/4","title":"AWS.NetworkManager.delete_peering/4","type":"function"},{"doc":"Deletes a resource policy for the specified resource.\n\nThis revokes the access of the principals specified in the resource policy.","ref":"AWS.NetworkManager.html#delete_resource_policy/4","title":"AWS.NetworkManager.delete_resource_policy/4","type":"function"},{"doc":"Deletes an existing site.\n\nThe site cannot be associated with any device or link.","ref":"AWS.NetworkManager.html#delete_site/5","title":"AWS.NetworkManager.delete_site/5","type":"function"},{"doc":"Deregisters a transit gateway from your global network.\n\nThis action does not delete your transit gateway, or modify any of its\nattachments. This action removes any customer gateway associations.","ref":"AWS.NetworkManager.html#deregister_transit_gateway/5","title":"AWS.NetworkManager.deregister_transit_gateway/5","type":"function"},{"doc":"Describes one or more global networks.\n\nBy default, all global networks are described. To describe the objects in your\nglobal network, you must use the appropriate `Get*` action. For example, to list\nthe transit gateways in your global network, use\n`GetTransitGatewayRegistrations`.","ref":"AWS.NetworkManager.html#describe_global_networks/5","title":"AWS.NetworkManager.describe_global_networks/5","type":"function"},{"doc":"Disassociates a core network Connect peer from a device and a link.","ref":"AWS.NetworkManager.html#disassociate_connect_peer/5","title":"AWS.NetworkManager.disassociate_connect_peer/5","type":"function"},{"doc":"Disassociates a customer gateway from a device and a link.","ref":"AWS.NetworkManager.html#disassociate_customer_gateway/5","title":"AWS.NetworkManager.disassociate_customer_gateway/5","type":"function"},{"doc":"Disassociates an existing device from a link.\n\nYou must first disassociate any customer gateways that are associated with the\nlink.","ref":"AWS.NetworkManager.html#disassociate_link/4","title":"AWS.NetworkManager.disassociate_link/4","type":"function"},{"doc":"Disassociates a transit gateway Connect peer from a device and link.","ref":"AWS.NetworkManager.html#disassociate_transit_gateway_connect_peer/5","title":"AWS.NetworkManager.disassociate_transit_gateway_connect_peer/5","type":"function"},{"doc":"Executes a change set on your core network.\n\nDeploys changes globally based on the policy submitted..","ref":"AWS.NetworkManager.html#execute_core_network_change_set/5","title":"AWS.NetworkManager.execute_core_network_change_set/5","type":"function"},{"doc":"Returns information about a core network Connect attachment.","ref":"AWS.NetworkManager.html#get_connect_attachment/3","title":"AWS.NetworkManager.get_connect_attachment/3","type":"function"},{"doc":"Returns information about a core network Connect peer.","ref":"AWS.NetworkManager.html#get_connect_peer/3","title":"AWS.NetworkManager.get_connect_peer/3","type":"function"},{"doc":"Returns information about a core network Connect peer associations.","ref":"AWS.NetworkManager.html#get_connect_peer_associations/6","title":"AWS.NetworkManager.get_connect_peer_associations/6","type":"function"},{"doc":"Gets information about one or more of your connections in a global network.","ref":"AWS.NetworkManager.html#get_connections/7","title":"AWS.NetworkManager.get_connections/7","type":"function"},{"doc":"Returns information about the LIVE policy for a core network.","ref":"AWS.NetworkManager.html#get_core_network/3","title":"AWS.NetworkManager.get_core_network/3","type":"function"},{"doc":"Returns information about a core network change event.","ref":"AWS.NetworkManager.html#get_core_network_change_events/6","title":"AWS.NetworkManager.get_core_network_change_events/6","type":"function"},{"doc":"Returns a change set between the LIVE core network policy and a submitted\npolicy.","ref":"AWS.NetworkManager.html#get_core_network_change_set/6","title":"AWS.NetworkManager.get_core_network_change_set/6","type":"function"},{"doc":"Returns details about a core network policy.\n\nYou can get details about your current live policy or any previous policy\nversion.","ref":"AWS.NetworkManager.html#get_core_network_policy/5","title":"AWS.NetworkManager.get_core_network_policy/5","type":"function"},{"doc":"Gets the association information for customer gateways that are associated with\ndevices and links in your global network.","ref":"AWS.NetworkManager.html#get_customer_gateway_associations/6","title":"AWS.NetworkManager.get_customer_gateway_associations/6","type":"function"},{"doc":"Gets information about one or more of your devices in a global network.","ref":"AWS.NetworkManager.html#get_devices/7","title":"AWS.NetworkManager.get_devices/7","type":"function"},{"doc":"Gets the link associations for a device or a link.\n\nEither the device ID or the link ID must be specified.","ref":"AWS.NetworkManager.html#get_link_associations/7","title":"AWS.NetworkManager.get_link_associations/7","type":"function"},{"doc":"Gets information about one or more links in a specified global network.\n\nIf you specify the site ID, you cannot specify the type or provider in the same\nrequest. You can specify the type and provider in the same request.","ref":"AWS.NetworkManager.html#get_links/9","title":"AWS.NetworkManager.get_links/9","type":"function"},{"doc":"Gets the count of network resources, by resource type, for the specified global\nnetwork.","ref":"AWS.NetworkManager.html#get_network_resource_counts/6","title":"AWS.NetworkManager.get_network_resource_counts/6","type":"function"},{"doc":"Gets the network resource relationships for the specified global network.","ref":"AWS.NetworkManager.html#get_network_resource_relationships/11","title":"AWS.NetworkManager.get_network_resource_relationships/11","type":"function"},{"doc":"Describes the network resources for the specified global network.\n\nThe results include information from the corresponding Describe call for the\nresource, minus any sensitive information such as pre-shared keys.","ref":"AWS.NetworkManager.html#get_network_resources/11","title":"AWS.NetworkManager.get_network_resources/11","type":"function"},{"doc":"Gets the network routes of the specified global network.","ref":"AWS.NetworkManager.html#get_network_routes/4","title":"AWS.NetworkManager.get_network_routes/4","type":"function"},{"doc":"Gets the network telemetry of the specified global network.","ref":"AWS.NetworkManager.html#get_network_telemetry/11","title":"AWS.NetworkManager.get_network_telemetry/11","type":"function"},{"doc":"Returns information about a resource policy.","ref":"AWS.NetworkManager.html#get_resource_policy/3","title":"AWS.NetworkManager.get_resource_policy/3","type":"function"},{"doc":"Gets information about the specified route analysis.","ref":"AWS.NetworkManager.html#get_route_analysis/4","title":"AWS.NetworkManager.get_route_analysis/4","type":"function"},{"doc":"Returns information about a site-to-site VPN attachment.","ref":"AWS.NetworkManager.html#get_site_to_site_vpn_attachment/3","title":"AWS.NetworkManager.get_site_to_site_vpn_attachment/3","type":"function"},{"doc":"Gets information about one or more of your sites in a global network.","ref":"AWS.NetworkManager.html#get_sites/6","title":"AWS.NetworkManager.get_sites/6","type":"function"},{"doc":"Gets information about one or more of your transit gateway Connect peer\nassociations in a global network.","ref":"AWS.NetworkManager.html#get_transit_gateway_connect_peer_associations/6","title":"AWS.NetworkManager.get_transit_gateway_connect_peer_associations/6","type":"function"},{"doc":"Returns information about a transit gateway peer.","ref":"AWS.NetworkManager.html#get_transit_gateway_peering/3","title":"AWS.NetworkManager.get_transit_gateway_peering/3","type":"function"},{"doc":"Gets information about the transit gateway registrations in a specified global\nnetwork.","ref":"AWS.NetworkManager.html#get_transit_gateway_registrations/6","title":"AWS.NetworkManager.get_transit_gateway_registrations/6","type":"function"},{"doc":"Returns information about a transit gateway route table attachment.","ref":"AWS.NetworkManager.html#get_transit_gateway_route_table_attachment/3","title":"AWS.NetworkManager.get_transit_gateway_route_table_attachment/3","type":"function"},{"doc":"Returns information about a VPC attachment.","ref":"AWS.NetworkManager.html#get_vpc_attachment/3","title":"AWS.NetworkManager.get_vpc_attachment/3","type":"function"},{"doc":"Returns a list of core network attachments.","ref":"AWS.NetworkManager.html#list_attachments/8","title":"AWS.NetworkManager.list_attachments/8","type":"function"},{"doc":"Returns a list of core network Connect peers.","ref":"AWS.NetworkManager.html#list_connect_peers/6","title":"AWS.NetworkManager.list_connect_peers/6","type":"function"},{"doc":"Returns a list of core network policy versions.","ref":"AWS.NetworkManager.html#list_core_network_policy_versions/5","title":"AWS.NetworkManager.list_core_network_policy_versions/5","type":"function"},{"doc":"Returns a list of owned and shared core networks.","ref":"AWS.NetworkManager.html#list_core_networks/4","title":"AWS.NetworkManager.list_core_networks/4","type":"function"},{"doc":"Gets the status of the Service Linked Role (SLR) deployment for the accounts in\na given Amazon Web Services Organization.","ref":"AWS.NetworkManager.html#list_organization_service_access_status/4","title":"AWS.NetworkManager.list_organization_service_access_status/4","type":"function"},{"doc":"Lists the peerings for a core network.","ref":"AWS.NetworkManager.html#list_peerings/8","title":"AWS.NetworkManager.list_peerings/8","type":"function"},{"doc":"Lists the tags for a specified resource.","ref":"AWS.NetworkManager.html#list_tags_for_resource/3","title":"AWS.NetworkManager.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.NetworkManager.html#metadata/0","title":"AWS.NetworkManager.metadata/0","type":"function"},{"doc":"Creates a new, immutable version of a core network policy.\n\nA subsequent change set is created showing the differences between the LIVE\npolicy and the submitted policy.","ref":"AWS.NetworkManager.html#put_core_network_policy/4","title":"AWS.NetworkManager.put_core_network_policy/4","type":"function"},{"doc":"Creates or updates a resource policy.","ref":"AWS.NetworkManager.html#put_resource_policy/4","title":"AWS.NetworkManager.put_resource_policy/4","type":"function"},{"doc":"Registers a transit gateway in your global network.\n\nNot all Regions support transit gateways for global networks. For a list of the\nsupported Regions, see [Region Availability](https://docs.aws.amazon.com/network-manager/latest/tgwnm/what-are-global-networks.html#nm-available-regions)\nin the *Amazon Web Services Transit Gateways for Global Networks User Guide*.\nThe transit gateway can be in any of the supported Amazon Web Services Regions,\nbut it must be owned by the same Amazon Web Services account that owns the\nglobal network. You cannot register a transit gateway in more than one global\nnetwork.","ref":"AWS.NetworkManager.html#register_transit_gateway/4","title":"AWS.NetworkManager.register_transit_gateway/4","type":"function"},{"doc":"Rejects a core network attachment request.","ref":"AWS.NetworkManager.html#reject_attachment/4","title":"AWS.NetworkManager.reject_attachment/4","type":"function"},{"doc":"Restores a previous policy version as a new, immutable version of a core network\npolicy.\n\nA subsequent change set is created showing the differences between the LIVE\npolicy and restored policy.","ref":"AWS.NetworkManager.html#restore_core_network_policy_version/5","title":"AWS.NetworkManager.restore_core_network_policy_version/5","type":"function"},{"doc":"Enables the Network Manager service for an Amazon Web Services Organization.\n\nThis can only be called by a management account within the organization.","ref":"AWS.NetworkManager.html#start_organization_service_access_update/3","title":"AWS.NetworkManager.start_organization_service_access_update/3","type":"function"},{"doc":"Starts analyzing the routing path between the specified source and destination.\n\nFor more information, see [Route Analyzer](https://docs.aws.amazon.com/vpc/latest/tgw/route-analyzer.html).","ref":"AWS.NetworkManager.html#start_route_analysis/4","title":"AWS.NetworkManager.start_route_analysis/4","type":"function"},{"doc":"Tags a specified resource.","ref":"AWS.NetworkManager.html#tag_resource/4","title":"AWS.NetworkManager.tag_resource/4","type":"function"},{"doc":"Removes tags from a specified resource.","ref":"AWS.NetworkManager.html#untag_resource/4","title":"AWS.NetworkManager.untag_resource/4","type":"function"},{"doc":"Updates the information for an existing connection.\n\nTo remove information for any of the parameters, specify an empty string.","ref":"AWS.NetworkManager.html#update_connection/5","title":"AWS.NetworkManager.update_connection/5","type":"function"},{"doc":"Updates the description of a core network.","ref":"AWS.NetworkManager.html#update_core_network/4","title":"AWS.NetworkManager.update_core_network/4","type":"function"},{"doc":"Updates the details for an existing device.\n\nTo remove information for any of the parameters, specify an empty string.","ref":"AWS.NetworkManager.html#update_device/5","title":"AWS.NetworkManager.update_device/5","type":"function"},{"doc":"Updates an existing global network.\n\nTo remove information for any of the parameters, specify an empty string.","ref":"AWS.NetworkManager.html#update_global_network/4","title":"AWS.NetworkManager.update_global_network/4","type":"function"},{"doc":"Updates the details for an existing link.\n\nTo remove information for any of the parameters, specify an empty string.","ref":"AWS.NetworkManager.html#update_link/5","title":"AWS.NetworkManager.update_link/5","type":"function"},{"doc":"Updates the resource metadata for the specified global network.","ref":"AWS.NetworkManager.html#update_network_resource_metadata/5","title":"AWS.NetworkManager.update_network_resource_metadata/5","type":"function"},{"doc":"Updates the information for an existing site.\n\nTo remove information for any of the parameters, specify an empty string.","ref":"AWS.NetworkManager.html#update_site/5","title":"AWS.NetworkManager.update_site/5","type":"function"},{"doc":"Updates a VPC attachment.","ref":"AWS.NetworkManager.html#update_vpc_attachment/4","title":"AWS.NetworkManager.update_vpc_attachment/4","type":"function"},{"doc":"Amazon CloudWatch Network Monitor is an Amazon Web Services active network\nmonitoring service that identifies if a network issues exists within the Amazon\nWeb Services network or your own company network.\n\nWithin Network Monitor you'll choose the source VPCs and subnets from the Amazon\nWeb Services network in which you operate and then you'll choose the destination\nIP addresses from your on-premises network. From these sources and destinations,\nNetwork Monitor creates a monitor containing all the possible source and\ndestination combinations, each of which is called a probe, within a single\nmonitor. These probes then monitor network traffic to help you identify where\nnetwork issues might be affecting your traffic.\n\nFor more information, see [Using Amazon CloudWatch Network Monitor](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/what-is-network-monitor.html)\nin the *Amazon CloudWatch User Guide*.","ref":"AWS.NetworkMonitor.html","title":"AWS.NetworkMonitor","type":"module"},{"doc":"Creates a monitor between a source subnet and destination IP address.\n\nWithin a monitor you'll create one or more probes that monitor network traffic\nbetween your source Amazon Web Services VPC subnets and your destination IP\naddresses. Each probe then aggregates and sends metrics to Amazon CloudWatch.","ref":"AWS.NetworkMonitor.html#create_monitor/3","title":"AWS.NetworkMonitor.create_monitor/3","type":"function"},{"doc":"Create a probe within a monitor.\n\nOnce you create a probe, and it begins monitoring your network traffic, you'll\nincur billing charges for that probe.","ref":"AWS.NetworkMonitor.html#create_probe/4","title":"AWS.NetworkMonitor.create_probe/4","type":"function"},{"doc":"Deletes a specified monitor.","ref":"AWS.NetworkMonitor.html#delete_monitor/4","title":"AWS.NetworkMonitor.delete_monitor/4","type":"function"},{"doc":"Deletes the specified monitor.\n\nOnce a probe is deleted you'll no longer incur any billing fees for that probe.","ref":"AWS.NetworkMonitor.html#delete_probe/5","title":"AWS.NetworkMonitor.delete_probe/5","type":"function"},{"doc":"Returns details about a specific monitor.","ref":"AWS.NetworkMonitor.html#get_monitor/3","title":"AWS.NetworkMonitor.get_monitor/3","type":"function"},{"doc":"Returns the details about a probe.\n\nYou'll need both the `monitorName` and `probeId`.","ref":"AWS.NetworkMonitor.html#get_probe/4","title":"AWS.NetworkMonitor.get_probe/4","type":"function"},{"doc":"Returns a list of all of your monitors.","ref":"AWS.NetworkMonitor.html#list_monitors/5","title":"AWS.NetworkMonitor.list_monitors/5","type":"function"},{"doc":"Lists the tags assigned to this resource.","ref":"AWS.NetworkMonitor.html#list_tags_for_resource/3","title":"AWS.NetworkMonitor.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.NetworkMonitor.html#metadata/0","title":"AWS.NetworkMonitor.metadata/0","type":"function"},{"doc":"Adds key-value pairs to a monitor or probe.","ref":"AWS.NetworkMonitor.html#tag_resource/4","title":"AWS.NetworkMonitor.tag_resource/4","type":"function"},{"doc":"Removes a key-value pair from a monitor or probe.","ref":"AWS.NetworkMonitor.html#untag_resource/4","title":"AWS.NetworkMonitor.untag_resource/4","type":"function"},{"doc":"Updates the `aggregationPeriod` for a monitor.\n\nMonitors support an `aggregationPeriod` of either `30` or `60` seconds.","ref":"AWS.NetworkMonitor.html#update_monitor/4","title":"AWS.NetworkMonitor.update_monitor/4","type":"function"},{"doc":"Updates a monitor probe.\n\nThis action requires both the `monitorName` and `probeId` parameters. Run\n`ListMonitors` to get a list of monitor names. Run `GetMonitor` to get a list of\nprobes and probe IDs.","ref":"AWS.NetworkMonitor.html#update_probe/5","title":"AWS.NetworkMonitor.update_probe/5","type":"function"},{"doc":"Welcome to the Amazon Nimble Studio API reference.\n\nThis API reference provides methods, schema, resources, parameters, and more to\nhelp you get the most out of Nimble Studio.\n\nNimble Studio is a virtual studio that empowers visual effects, animation, and\ninteractive content teams to create content securely within a scalable, private\ncloud service.","ref":"AWS.Nimble.html","title":"AWS.Nimble","type":"module"},{"doc":"Accept EULAs.","ref":"AWS.Nimble.html#accept_eulas/4","title":"AWS.Nimble.accept_eulas/4","type":"function"},{"doc":"Create a launch profile.","ref":"AWS.Nimble.html#create_launch_profile/4","title":"AWS.Nimble.create_launch_profile/4","type":"function"},{"doc":"Creates a streaming image resource in a studio.","ref":"AWS.Nimble.html#create_streaming_image/4","title":"AWS.Nimble.create_streaming_image/4","type":"function"},{"doc":"Creates a streaming session in a studio.\n\nAfter invoking this operation, you must poll GetStreamingSession until the\nstreaming session is in the `READY` state.","ref":"AWS.Nimble.html#create_streaming_session/4","title":"AWS.Nimble.create_streaming_session/4","type":"function"},{"doc":"Creates a streaming session stream for a streaming session.\n\nAfter invoking this API, invoke GetStreamingSessionStream with the returned\nstreamId to poll the resource until it is in the `READY` state.","ref":"AWS.Nimble.html#create_streaming_session_stream/5","title":"AWS.Nimble.create_streaming_session_stream/5","type":"function"},{"doc":"Create a new studio.\n\nWhen creating a studio, two IAM roles must be provided: the admin role and the\nuser role. These roles are assumed by your users when they log in to the Nimble\nStudio portal.\n\nThe user role must have the `AmazonNimbleStudio-StudioUser` managed policy\nattached for the portal to function properly.\n\nThe admin role must have the `AmazonNimbleStudio-StudioAdmin` managed policy\nattached for the portal to function properly.\n\nYou may optionally specify a KMS key in the `StudioEncryptionConfiguration`.\n\nIn Nimble Studio, resource names, descriptions, initialization scripts, and\nother data you provide are always encrypted at rest using an KMS key. By\ndefault, this key is owned by Amazon Web Services and managed on your behalf.\nYou may provide your own KMS key when calling `CreateStudio` to encrypt this\ndata using a key you own and manage.\n\nWhen providing an KMS key during studio creation, Nimble Studio creates KMS\ngrants in your account to provide your studio user and admin roles access to\nthese KMS keys.\n\nIf you delete this grant, the studio will no longer be accessible to your portal\nusers.\n\nIf you delete the studio KMS key, your studio will no longer be accessible.","ref":"AWS.Nimble.html#create_studio/3","title":"AWS.Nimble.create_studio/3","type":"function"},{"doc":"Creates a studio component resource.","ref":"AWS.Nimble.html#create_studio_component/4","title":"AWS.Nimble.create_studio_component/4","type":"function"},{"doc":"Permanently delete a launch profile.","ref":"AWS.Nimble.html#delete_launch_profile/5","title":"AWS.Nimble.delete_launch_profile/5","type":"function"},{"doc":"Delete a user from launch profile membership.","ref":"AWS.Nimble.html#delete_launch_profile_member/6","title":"AWS.Nimble.delete_launch_profile_member/6","type":"function"},{"doc":"Delete streaming image.","ref":"AWS.Nimble.html#delete_streaming_image/5","title":"AWS.Nimble.delete_streaming_image/5","type":"function"},{"doc":"Deletes streaming session resource.\n\nAfter invoking this operation, use GetStreamingSession to poll the resource\nuntil it transitions to a `DELETED` state.\n\nA streaming session will count against your streaming session quota until it is\nmarked `DELETED`.","ref":"AWS.Nimble.html#delete_streaming_session/5","title":"AWS.Nimble.delete_streaming_session/5","type":"function"},{"doc":"Delete a studio resource.","ref":"AWS.Nimble.html#delete_studio/4","title":"AWS.Nimble.delete_studio/4","type":"function"},{"doc":"Deletes a studio component resource.","ref":"AWS.Nimble.html#delete_studio_component/5","title":"AWS.Nimble.delete_studio_component/5","type":"function"},{"doc":"Delete a user from studio membership.","ref":"AWS.Nimble.html#delete_studio_member/5","title":"AWS.Nimble.delete_studio_member/5","type":"function"},{"doc":"Get EULA.","ref":"AWS.Nimble.html#get_eula/3","title":"AWS.Nimble.get_eula/3","type":"function"},{"doc":"Get a launch profile.","ref":"AWS.Nimble.html#get_launch_profile/4","title":"AWS.Nimble.get_launch_profile/4","type":"function"},{"doc":"Launch profile details include the launch profile resource and summary\ninformation of resources that are used by, or available to, the launch profile.\n\nThis includes the name and description of all studio components used by the\nlaunch profiles, and the name and description of streaming images that can be\nused with this launch profile.","ref":"AWS.Nimble.html#get_launch_profile_details/4","title":"AWS.Nimble.get_launch_profile_details/4","type":"function"},{"doc":"Get a launch profile initialization.","ref":"AWS.Nimble.html#get_launch_profile_initialization/7","title":"AWS.Nimble.get_launch_profile_initialization/7","type":"function"},{"doc":"Get a user persona in launch profile membership.","ref":"AWS.Nimble.html#get_launch_profile_member/5","title":"AWS.Nimble.get_launch_profile_member/5","type":"function"},{"doc":"Get streaming image.","ref":"AWS.Nimble.html#get_streaming_image/4","title":"AWS.Nimble.get_streaming_image/4","type":"function"},{"doc":"Gets StreamingSession resource.\n\nInvoke this operation to poll for a streaming session state while creating or\ndeleting a session.","ref":"AWS.Nimble.html#get_streaming_session/4","title":"AWS.Nimble.get_streaming_session/4","type":"function"},{"doc":"Gets `StreamingSessionBackup` resource.\n\nInvoke this operation to poll for a streaming session backup while stopping a\nstreaming session.","ref":"AWS.Nimble.html#get_streaming_session_backup/4","title":"AWS.Nimble.get_streaming_session_backup/4","type":"function"},{"doc":"Gets a StreamingSessionStream for a streaming session.\n\nInvoke this operation to poll the resource after invoking\n`CreateStreamingSessionStream`.\n\nAfter the `StreamingSessionStream` changes to the `READY` state, the url\nproperty will contain a stream to be used with the DCV streaming client.","ref":"AWS.Nimble.html#get_streaming_session_stream/5","title":"AWS.Nimble.get_streaming_session_stream/5","type":"function"},{"doc":"Get a studio resource.","ref":"AWS.Nimble.html#get_studio/3","title":"AWS.Nimble.get_studio/3","type":"function"},{"doc":"Gets a studio component resource.","ref":"AWS.Nimble.html#get_studio_component/4","title":"AWS.Nimble.get_studio_component/4","type":"function"},{"doc":"Get a user's membership in a studio.","ref":"AWS.Nimble.html#get_studio_member/4","title":"AWS.Nimble.get_studio_member/4","type":"function"},{"doc":"List EULA acceptances.","ref":"AWS.Nimble.html#list_eula_acceptances/5","title":"AWS.Nimble.list_eula_acceptances/5","type":"function"},{"doc":"List EULAs.","ref":"AWS.Nimble.html#list_eulas/4","title":"AWS.Nimble.list_eulas/4","type":"function"},{"doc":"Get all users in a given launch profile membership.","ref":"AWS.Nimble.html#list_launch_profile_members/6","title":"AWS.Nimble.list_launch_profile_members/6","type":"function"},{"doc":"List all the launch profiles a studio.","ref":"AWS.Nimble.html#list_launch_profiles/7","title":"AWS.Nimble.list_launch_profiles/7","type":"function"},{"doc":"List the streaming image resources available to this studio.\n\nThis list will contain both images provided by Amazon Web Services, as well as\nstreaming images that you have created in your studio.","ref":"AWS.Nimble.html#list_streaming_images/5","title":"AWS.Nimble.list_streaming_images/5","type":"function"},{"doc":"Lists the backups of a streaming session in a studio.","ref":"AWS.Nimble.html#list_streaming_session_backups/5","title":"AWS.Nimble.list_streaming_session_backups/5","type":"function"},{"doc":"Lists the streaming sessions in a studio.","ref":"AWS.Nimble.html#list_streaming_sessions/7","title":"AWS.Nimble.list_streaming_sessions/7","type":"function"},{"doc":"Lists the `StudioComponents` in a studio.","ref":"AWS.Nimble.html#list_studio_components/7","title":"AWS.Nimble.list_studio_components/7","type":"function"},{"doc":"Get all users in a given studio membership.\n\n`ListStudioMembers` only returns admin members.","ref":"AWS.Nimble.html#list_studio_members/5","title":"AWS.Nimble.list_studio_members/5","type":"function"},{"doc":"List studios in your Amazon Web Services accounts in the requested Amazon Web\nServices Region.","ref":"AWS.Nimble.html#list_studios/3","title":"AWS.Nimble.list_studios/3","type":"function"},{"doc":"Gets the tags for a resource, given its Amazon Resource Names (ARN).\n\nThis operation supports ARNs for all resource types in Nimble Studio that\nsupport tags, including studio, studio component, launch profile, streaming\nimage, and streaming session. All resources that can be tagged will contain an\nARN property, so you do not have to create this ARN yourself.","ref":"AWS.Nimble.html#list_tags_for_resource/3","title":"AWS.Nimble.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.Nimble.html#metadata/0","title":"AWS.Nimble.metadata/0","type":"function"},{"doc":"Add/update users with given persona to launch profile membership.","ref":"AWS.Nimble.html#put_launch_profile_members/5","title":"AWS.Nimble.put_launch_profile_members/5","type":"function"},{"doc":"Add/update users with given persona to studio membership.","ref":"AWS.Nimble.html#put_studio_members/4","title":"AWS.Nimble.put_studio_members/4","type":"function"},{"doc":"Transitions sessions from the `STOPPED` state into the `READY` state.\n\nThe `START_IN_PROGRESS` state is the intermediate state between the `STOPPED`\nand `READY` states.","ref":"AWS.Nimble.html#start_streaming_session/5","title":"AWS.Nimble.start_streaming_session/5","type":"function"},{"doc":"Repairs the IAM Identity Center configuration for a given studio.\n\nIf the studio has a valid IAM Identity Center configuration currently associated\nwith it, this operation will fail with a validation error.\n\nIf the studio does not have a valid IAM Identity Center configuration currently\nassociated with it, then a new IAM Identity Center application is created for\nthe studio and the studio is changed to the `READY` state.\n\nAfter the IAM Identity Center application is repaired, you must use the Amazon\nNimble Studio console to add administrators and users to your studio.","ref":"AWS.Nimble.html#start_studio_s_s_o_configuration_repair/4","title":"AWS.Nimble.start_studio_s_s_o_configuration_repair/4","type":"function"},{"doc":"Transitions sessions from the `READY` state into the `STOPPED` state.\n\nThe `STOP_IN_PROGRESS` state is the intermediate state between the `READY` and\n`STOPPED` states.","ref":"AWS.Nimble.html#stop_streaming_session/5","title":"AWS.Nimble.stop_streaming_session/5","type":"function"},{"doc":"Creates tags for a resource, given its ARN.","ref":"AWS.Nimble.html#tag_resource/4","title":"AWS.Nimble.tag_resource/4","type":"function"},{"doc":"Deletes the tags for a resource.","ref":"AWS.Nimble.html#untag_resource/4","title":"AWS.Nimble.untag_resource/4","type":"function"},{"doc":"Update a launch profile.","ref":"AWS.Nimble.html#update_launch_profile/5","title":"AWS.Nimble.update_launch_profile/5","type":"function"},{"doc":"Update a user persona in launch profile membership.","ref":"AWS.Nimble.html#update_launch_profile_member/6","title":"AWS.Nimble.update_launch_profile_member/6","type":"function"},{"doc":"Update streaming image.","ref":"AWS.Nimble.html#update_streaming_image/5","title":"AWS.Nimble.update_streaming_image/5","type":"function"},{"doc":"Update a Studio resource.\n\nCurrently, this operation only supports updating the displayName of your studio.","ref":"AWS.Nimble.html#update_studio/4","title":"AWS.Nimble.update_studio/4","type":"function"},{"doc":"Updates a studio component resource.","ref":"AWS.Nimble.html#update_studio_component/5","title":"AWS.Nimble.update_studio_component/5","type":"function"},{"doc":"Use Amazon CloudWatch Observability Access Manager to create and manage links\nbetween source accounts and monitoring accounts by using *CloudWatch\ncross-account observability*.\n\nWith CloudWatch cross-account observability, you can monitor and troubleshoot\napplications that span multiple accounts within a Region. Seamlessly search,\nvisualize, and analyze your metrics, logs, traces, and Application Insights\napplications in any of the linked accounts without account boundaries.\n\nSet up one or more Amazon Web Services accounts as *monitoring accounts* and\nlink them with multiple *source accounts*. A monitoring account is a central\nAmazon Web Services account that can view and interact with observability data\ngenerated from source accounts. A source account is an individual Amazon Web\nServices account that generates observability data for the resources that reside\nin it. Source accounts share their observability data with the monitoring\naccount. The shared observability data can include metrics in Amazon CloudWatch,\nlogs in Amazon CloudWatch Logs, traces in X-Ray, and applications in Amazon\nCloudWatch Application Insights.","ref":"AWS.OAM.html","title":"AWS.OAM","type":"module"},{"doc":"Creates a link between a source account and a sink that you have created in a\nmonitoring account.\n\nBefore you create a link, you must create a sink in the monitoring account and\ncreate a sink policy in that account. The sink policy must permit the source\naccount to link to it. You can grant permission to source accounts by granting\npermission to an entire organization or to individual accounts.\n\nFor more information, see\n[CreateSink](https://docs.aws.amazon.com/OAM/latest/APIReference/API_CreateSink.html) and\n[PutSinkPolicy](https://docs.aws.amazon.com/OAM/latest/APIReference/API_PutSinkPolicy.html).\n\nEach monitoring account can be linked to as many as 100,000 source accounts.\n\nEach source account can be linked to as many as five monitoring accounts.","ref":"AWS.OAM.html#create_link/3","title":"AWS.OAM.create_link/3","type":"function"},{"doc":"Use this to create a *sink* in the current account, so that it can be used as a\nmonitoring account in CloudWatch cross-account observability.\n\nA sink is a resource that represents an attachment point in a monitoring\naccount. Source accounts can link to the sink to send observability data.\n\nAfter you create a sink, you must create a sink policy that allows source\naccounts to attach to it. For more information, see\n[PutSinkPolicy](https://docs.aws.amazon.com/OAM/latest/APIReference/API_PutSinkPolicy.html).\n\nEach account can contain one sink. If you delete a sink, you can then create a\nnew one in that account.","ref":"AWS.OAM.html#create_sink/3","title":"AWS.OAM.create_sink/3","type":"function"},{"doc":"Deletes a link between a monitoring account sink and a source account.\n\nYou must run this operation in the source account.","ref":"AWS.OAM.html#delete_link/3","title":"AWS.OAM.delete_link/3","type":"function"},{"doc":"Deletes a sink.\n\nYou must delete all links to a sink before you can delete that sink.","ref":"AWS.OAM.html#delete_sink/3","title":"AWS.OAM.delete_sink/3","type":"function"},{"doc":"Returns complete information about one link.\n\nTo use this operation, provide the link ARN. To retrieve a list of link ARNs,\nuse\n[ListLinks](https://docs.aws.amazon.com/OAM/latest/APIReference/API_ListLinks.html).","ref":"AWS.OAM.html#get_link/3","title":"AWS.OAM.get_link/3","type":"function"},{"doc":"Returns complete information about one monitoring account sink.\n\nTo use this operation, provide the sink ARN. To retrieve a list of sink ARNs,\nuse\n[ListSinks](https://docs.aws.amazon.com/OAM/latest/APIReference/API_ListSinks.html).","ref":"AWS.OAM.html#get_sink/3","title":"AWS.OAM.get_sink/3","type":"function"},{"doc":"Returns the current sink policy attached to this sink.\n\nThe sink policy specifies what accounts can attach to this sink as source\naccounts, and what types of data they can share.","ref":"AWS.OAM.html#get_sink_policy/3","title":"AWS.OAM.get_sink_policy/3","type":"function"},{"doc":"Returns a list of source account links that are linked to this monitoring\naccount sink.\n\nTo use this operation, provide the sink ARN. To retrieve a list of sink ARNs,\nuse\n[ListSinks](https://docs.aws.amazon.com/OAM/latest/APIReference/API_ListSinks.html).  To find a list of links for one source account, use\n[ListLinks](https://docs.aws.amazon.com/OAM/latest/APIReference/API_ListLinks.html).","ref":"AWS.OAM.html#list_attached_links/3","title":"AWS.OAM.list_attached_links/3","type":"function"},{"doc":"Use this operation in a source account to return a list of links to monitoring\naccount sinks that this source account has.\n\nTo find a list of links for one monitoring account sink, use\n[ListAttachedLinks](https://docs.aws.amazon.com/OAM/latest/APIReference/API_ListAttachedLinks.html)\nfrom within the monitoring account.","ref":"AWS.OAM.html#list_links/3","title":"AWS.OAM.list_links/3","type":"function"},{"doc":"Use this operation in a monitoring account to return the list of sinks created\nin that account.","ref":"AWS.OAM.html#list_sinks/3","title":"AWS.OAM.list_sinks/3","type":"function"},{"doc":"Displays the tags associated with a resource.\n\nBoth sinks and links support tagging.","ref":"AWS.OAM.html#list_tags_for_resource/3","title":"AWS.OAM.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.OAM.html#metadata/0","title":"AWS.OAM.metadata/0","type":"function"},{"doc":"Creates or updates the resource policy that grants permissions to source\naccounts to link to the monitoring account sink.\n\nWhen you create a sink policy, you can grant permissions to all accounts in an\norganization or to individual accounts.\n\nYou can also use a sink policy to limit the types of data that is shared. The\nthree types that you can allow or deny are:\n\n  * **Metrics** - Specify with `AWS::CloudWatch::Metric`\n\n  * **Log groups** - Specify with `AWS::Logs::LogGroup`\n\n  * **Traces** - Specify with `AWS::XRay::Trace`\n\n  * **Application Insights - Applications** - Specify with\n`AWS::ApplicationInsights::Application`\n\nSee the examples in this section to see how to specify permitted source accounts\nand data types.","ref":"AWS.OAM.html#put_sink_policy/3","title":"AWS.OAM.put_sink_policy/3","type":"function"},{"doc":"Assigns one or more tags (key-value pairs) to the specified resource.\n\nBoth sinks and links can be tagged.\n\nTags can help you organize and categorize your resources. You can also use them\nto scope user permissions by granting a user permission to access or change only\nresources with certain tag values.\n\nTags don't have any semantic meaning to Amazon Web Services and are interpreted\nstrictly as strings of characters.\n\nYou can use the `TagResource` action with a resource that already has tags. If\nyou specify a new tag key for the alarm, this tag is appended to the list of\ntags associated with the alarm. If you specify a tag key that is already\nassociated with the alarm, the new tag value that you specify replaces the\nprevious value for that tag.\n\nYou can associate as many as 50 tags with a resource.\n\nUnlike tagging permissions in other Amazon Web Services services, to tag or\nuntag links and sinks you must have the `oam:ResourceTag` permission. The\n`iam:ResourceTag` permission does not allow you to tag and untag links and\nsinks.","ref":"AWS.OAM.html#tag_resource/4","title":"AWS.OAM.tag_resource/4","type":"function"},{"doc":"Removes one or more tags from the specified resource.\n\nUnlike tagging permissions in other Amazon Web Services services, to tag or\nuntag links and sinks you must have the `oam:ResourceTag` permission. The\n`iam:TagResource` permission does not allow you to tag and untag links and\nsinks.","ref":"AWS.OAM.html#untag_resource/4","title":"AWS.OAM.untag_resource/4","type":"function"},{"doc":"Use this operation to change what types of data are shared from a source account\nto its linked monitoring account sink.\n\nYou can't change the sink or change the monitoring account with this operation.\n\nTo update the list of tags associated with the sink, use\n[TagResource](https://docs.aws.amazon.com/OAM/latest/APIReference/API_TagResource.html).","ref":"AWS.OAM.html#update_link/3","title":"AWS.OAM.update_link/3","type":"function"},{"doc":"Use the Amazon OpenSearch Ingestion API to create and manage ingestion\npipelines.\n\nOpenSearch Ingestion is a fully managed data collector that delivers real-time\nlog and trace data to OpenSearch Service domains. For more information, see\n[Getting data into your cluster using OpenSearch Ingestion](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/ingestion.html).","ref":"AWS.OSIS.html","title":"AWS.OSIS","type":"module"},{"doc":"Creates an OpenSearch Ingestion pipeline.\n\nFor more information, see [Creating Amazon OpenSearch Ingestion pipelines](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/creating-pipeline.html).","ref":"AWS.OSIS.html#create_pipeline/3","title":"AWS.OSIS.create_pipeline/3","type":"function"},{"doc":"Deletes an OpenSearch Ingestion pipeline.\n\nFor more information, see [Deleting Amazon OpenSearch Ingestion pipelines](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/delete-pipeline.html).","ref":"AWS.OSIS.html#delete_pipeline/4","title":"AWS.OSIS.delete_pipeline/4","type":"function"},{"doc":"Retrieves information about an OpenSearch Ingestion pipeline.","ref":"AWS.OSIS.html#get_pipeline/3","title":"AWS.OSIS.get_pipeline/3","type":"function"},{"doc":"Retrieves information about a specific blueprint for OpenSearch Ingestion.\n\nBlueprints are templates for the configuration needed for a `CreatePipeline`\nrequest. For more information, see [Using blueprints to create a pipeline](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/creating-pipeline.html#pipeline-blueprint).","ref":"AWS.OSIS.html#get_pipeline_blueprint/3","title":"AWS.OSIS.get_pipeline_blueprint/3","type":"function"},{"doc":"Returns progress information for the current change happening on an OpenSearch\nIngestion pipeline.\n\nCurrently, this operation only returns information when a pipeline is being\ncreated.\n\nFor more information, see [Tracking the status of pipeline creation](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/creating-pipeline.html#get-pipeline-progress).","ref":"AWS.OSIS.html#get_pipeline_change_progress/3","title":"AWS.OSIS.get_pipeline_change_progress/3","type":"function"},{"doc":"Retrieves a list of all available blueprints for Data Prepper.\n\nFor more information, see [Using blueprints to create a pipeline](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/creating-pipeline.html#pipeline-blueprint).","ref":"AWS.OSIS.html#list_pipeline_blueprints/3","title":"AWS.OSIS.list_pipeline_blueprints/3","type":"function"},{"doc":"Lists all OpenSearch Ingestion pipelines in the current Amazon Web Services\naccount and Region.\n\nFor more information, see [Viewing Amazon OpenSearch Ingestion pipelines](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/list-pipeline.html).","ref":"AWS.OSIS.html#list_pipelines/4","title":"AWS.OSIS.list_pipelines/4","type":"function"},{"doc":"Lists all resource tags associated with an OpenSearch Ingestion pipeline.\n\nFor more information, see [Tagging Amazon OpenSearch Ingestion pipelines](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/tag-pipeline.html).","ref":"AWS.OSIS.html#list_tags_for_resource/3","title":"AWS.OSIS.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.OSIS.html#metadata/0","title":"AWS.OSIS.metadata/0","type":"function"},{"doc":"Starts an OpenSearch Ingestion pipeline.\n\nFor more information, see [Starting an OpenSearch Ingestion pipeline](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/pipeline--stop-start.html#pipeline--start).","ref":"AWS.OSIS.html#start_pipeline/4","title":"AWS.OSIS.start_pipeline/4","type":"function"},{"doc":"Stops an OpenSearch Ingestion pipeline.\n\nFor more information, see [Stopping an OpenSearch Ingestion pipeline](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/pipeline--stop-start.html#pipeline--stop).","ref":"AWS.OSIS.html#stop_pipeline/4","title":"AWS.OSIS.stop_pipeline/4","type":"function"},{"doc":"Tags an OpenSearch Ingestion pipeline.\n\nFor more information, see [Tagging Amazon OpenSearch Ingestion pipelines](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/tag-pipeline.html).","ref":"AWS.OSIS.html#tag_resource/3","title":"AWS.OSIS.tag_resource/3","type":"function"},{"doc":"Removes one or more tags from an OpenSearch Ingestion pipeline.\n\nFor more information, see [Tagging Amazon OpenSearch Ingestion pipelines](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/tag-pipeline.html).","ref":"AWS.OSIS.html#untag_resource/3","title":"AWS.OSIS.untag_resource/3","type":"function"},{"doc":"Updates an OpenSearch Ingestion pipeline.\n\nFor more information, see [Updating Amazon OpenSearch Ingestion pipelines](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/update-pipeline.html).","ref":"AWS.OSIS.html#update_pipeline/4","title":"AWS.OSIS.update_pipeline/4","type":"function"},{"doc":"Checks whether an OpenSearch Ingestion pipeline configuration is valid prior to\ncreation.\n\nFor more information, see [Creating Amazon OpenSearch Ingestion pipelines](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/creating-pipeline.html).","ref":"AWS.OSIS.html#validate_pipeline/3","title":"AWS.OSIS.validate_pipeline/3","type":"function"},{"doc":"This is the *AWS HealthOmics API Reference*.\n\nFor an introduction to the service, see [What is AWS HealthOmics?](https://docs.aws.amazon.com/omics/latest/dev/) in the *AWS\nHealthOmics User Guide*.","ref":"AWS.Omics.html","title":"AWS.Omics","type":"module"},{"doc":"Stops a multipart upload.","ref":"AWS.Omics.html#abort_multipart_read_set_upload/5","title":"AWS.Omics.abort_multipart_read_set_upload/5","type":"function"},{"doc":"Accepts a share for an analytics store.","ref":"AWS.Omics.html#accept_share/4","title":"AWS.Omics.accept_share/4","type":"function"},{"doc":"Deletes one or more read sets.","ref":"AWS.Omics.html#batch_delete_read_set/4","title":"AWS.Omics.batch_delete_read_set/4","type":"function"},{"doc":"Cancels an annotation import job.","ref":"AWS.Omics.html#cancel_annotation_import_job/4","title":"AWS.Omics.cancel_annotation_import_job/4","type":"function"},{"doc":"Cancels a run.","ref":"AWS.Omics.html#cancel_run/4","title":"AWS.Omics.cancel_run/4","type":"function"},{"doc":"Cancels a variant import job.","ref":"AWS.Omics.html#cancel_variant_import_job/4","title":"AWS.Omics.cancel_variant_import_job/4","type":"function"},{"doc":"Concludes a multipart upload once you have uploaded all the components.","ref":"AWS.Omics.html#complete_multipart_read_set_upload/5","title":"AWS.Omics.complete_multipart_read_set_upload/5","type":"function"},{"doc":"Creates an annotation store.","ref":"AWS.Omics.html#create_annotation_store/3","title":"AWS.Omics.create_annotation_store/3","type":"function"},{"doc":"Creates a new version of an annotation store.","ref":"AWS.Omics.html#create_annotation_store_version/4","title":"AWS.Omics.create_annotation_store_version/4","type":"function"},{"doc":"Begins a multipart read set upload.","ref":"AWS.Omics.html#create_multipart_read_set_upload/4","title":"AWS.Omics.create_multipart_read_set_upload/4","type":"function"},{"doc":"Creates a reference store.","ref":"AWS.Omics.html#create_reference_store/3","title":"AWS.Omics.create_reference_store/3","type":"function"},{"doc":"Creates a run group.","ref":"AWS.Omics.html#create_run_group/3","title":"AWS.Omics.create_run_group/3","type":"function"},{"doc":"Creates a sequence store.","ref":"AWS.Omics.html#create_sequence_store/3","title":"AWS.Omics.create_sequence_store/3","type":"function"},{"doc":"Creates a share offer that can be accepted outside the account by a subscriber.\n\nThe share is created by the owner and accepted by the principal subscriber.","ref":"AWS.Omics.html#create_share/3","title":"AWS.Omics.create_share/3","type":"function"},{"doc":"Creates a variant store.","ref":"AWS.Omics.html#create_variant_store/3","title":"AWS.Omics.create_variant_store/3","type":"function"},{"doc":"Creates a workflow.","ref":"AWS.Omics.html#create_workflow/3","title":"AWS.Omics.create_workflow/3","type":"function"},{"doc":"Deletes an annotation store.","ref":"AWS.Omics.html#delete_annotation_store/4","title":"AWS.Omics.delete_annotation_store/4","type":"function"},{"doc":"Deletes one or multiple versions of an annotation store.","ref":"AWS.Omics.html#delete_annotation_store_versions/4","title":"AWS.Omics.delete_annotation_store_versions/4","type":"function"},{"doc":"Deletes a genome reference.","ref":"AWS.Omics.html#delete_reference/5","title":"AWS.Omics.delete_reference/5","type":"function"},{"doc":"Deletes a genome reference store.","ref":"AWS.Omics.html#delete_reference_store/4","title":"AWS.Omics.delete_reference_store/4","type":"function"},{"doc":"Deletes a workflow run.","ref":"AWS.Omics.html#delete_run/4","title":"AWS.Omics.delete_run/4","type":"function"},{"doc":"Deletes a workflow run group.","ref":"AWS.Omics.html#delete_run_group/4","title":"AWS.Omics.delete_run_group/4","type":"function"},{"doc":"Deletes a sequence store.","ref":"AWS.Omics.html#delete_sequence_store/4","title":"AWS.Omics.delete_sequence_store/4","type":"function"},{"doc":"Deletes a share of an analytics store.","ref":"AWS.Omics.html#delete_share/4","title":"AWS.Omics.delete_share/4","type":"function"},{"doc":"Deletes a variant store.","ref":"AWS.Omics.html#delete_variant_store/4","title":"AWS.Omics.delete_variant_store/4","type":"function"},{"doc":"Deletes a workflow.","ref":"AWS.Omics.html#delete_workflow/4","title":"AWS.Omics.delete_workflow/4","type":"function"},{"doc":"Gets information about an annotation import job.","ref":"AWS.Omics.html#get_annotation_import_job/3","title":"AWS.Omics.get_annotation_import_job/3","type":"function"},{"doc":"Gets information about an annotation store.","ref":"AWS.Omics.html#get_annotation_store/3","title":"AWS.Omics.get_annotation_store/3","type":"function"},{"doc":"Retrieves the metadata for an annotation store version.","ref":"AWS.Omics.html#get_annotation_store_version/4","title":"AWS.Omics.get_annotation_store_version/4","type":"function"},{"doc":"Gets a file from a read set.","ref":"AWS.Omics.html#get_read_set/6","title":"AWS.Omics.get_read_set/6","type":"function"},{"doc":"Gets information about a read set activation job.","ref":"AWS.Omics.html#get_read_set_activation_job/4","title":"AWS.Omics.get_read_set_activation_job/4","type":"function"},{"doc":"Gets information about a read set export job.","ref":"AWS.Omics.html#get_read_set_export_job/4","title":"AWS.Omics.get_read_set_export_job/4","type":"function"},{"doc":"Gets information about a read set import job.","ref":"AWS.Omics.html#get_read_set_import_job/4","title":"AWS.Omics.get_read_set_import_job/4","type":"function"},{"doc":"Gets details about a read set.","ref":"AWS.Omics.html#get_read_set_metadata/4","title":"AWS.Omics.get_read_set_metadata/4","type":"function"},{"doc":"Gets a reference file.","ref":"AWS.Omics.html#get_reference/7","title":"AWS.Omics.get_reference/7","type":"function"},{"doc":"Gets information about a reference import job.","ref":"AWS.Omics.html#get_reference_import_job/4","title":"AWS.Omics.get_reference_import_job/4","type":"function"},{"doc":"Gets information about a genome reference's metadata.","ref":"AWS.Omics.html#get_reference_metadata/4","title":"AWS.Omics.get_reference_metadata/4","type":"function"},{"doc":"Gets information about a reference store.","ref":"AWS.Omics.html#get_reference_store/3","title":"AWS.Omics.get_reference_store/3","type":"function"},{"doc":"Gets information about a workflow run.","ref":"AWS.Omics.html#get_run/4","title":"AWS.Omics.get_run/4","type":"function"},{"doc":"Gets information about a workflow run group.","ref":"AWS.Omics.html#get_run_group/3","title":"AWS.Omics.get_run_group/3","type":"function"},{"doc":"Gets information about a workflow run task.","ref":"AWS.Omics.html#get_run_task/4","title":"AWS.Omics.get_run_task/4","type":"function"},{"doc":"Gets information about a sequence store.","ref":"AWS.Omics.html#get_sequence_store/3","title":"AWS.Omics.get_sequence_store/3","type":"function"},{"doc":"Retrieves the metadata for a share.","ref":"AWS.Omics.html#get_share/3","title":"AWS.Omics.get_share/3","type":"function"},{"doc":"Gets information about a variant import job.","ref":"AWS.Omics.html#get_variant_import_job/3","title":"AWS.Omics.get_variant_import_job/3","type":"function"},{"doc":"Gets information about a variant store.","ref":"AWS.Omics.html#get_variant_store/3","title":"AWS.Omics.get_variant_store/3","type":"function"},{"doc":"Gets information about a workflow.","ref":"AWS.Omics.html#get_workflow/5","title":"AWS.Omics.get_workflow/5","type":"function"},{"doc":"Retrieves a list of annotation import jobs.","ref":"AWS.Omics.html#list_annotation_import_jobs/3","title":"AWS.Omics.list_annotation_import_jobs/3","type":"function"},{"doc":"Lists the versions of an annotation store.","ref":"AWS.Omics.html#list_annotation_store_versions/4","title":"AWS.Omics.list_annotation_store_versions/4","type":"function"},{"doc":"Retrieves a list of annotation stores.","ref":"AWS.Omics.html#list_annotation_stores/3","title":"AWS.Omics.list_annotation_stores/3","type":"function"},{"doc":"Lists multipart read set uploads and for in progress uploads.\n\nOnce the upload is completed, a read set is created and the upload will no\nlonger be returned in the respone.","ref":"AWS.Omics.html#list_multipart_read_set_uploads/4","title":"AWS.Omics.list_multipart_read_set_uploads/4","type":"function"},{"doc":"Retrieves a list of read set activation jobs.","ref":"AWS.Omics.html#list_read_set_activation_jobs/4","title":"AWS.Omics.list_read_set_activation_jobs/4","type":"function"},{"doc":"Retrieves a list of read set export jobs.","ref":"AWS.Omics.html#list_read_set_export_jobs/4","title":"AWS.Omics.list_read_set_export_jobs/4","type":"function"},{"doc":"Retrieves a list of read set import jobs.","ref":"AWS.Omics.html#list_read_set_import_jobs/4","title":"AWS.Omics.list_read_set_import_jobs/4","type":"function"},{"doc":"This operation will list all parts in a requested multipart upload for a\nsequence store.","ref":"AWS.Omics.html#list_read_set_upload_parts/5","title":"AWS.Omics.list_read_set_upload_parts/5","type":"function"},{"doc":"Retrieves a list of read sets.","ref":"AWS.Omics.html#list_read_sets/4","title":"AWS.Omics.list_read_sets/4","type":"function"},{"doc":"Retrieves a list of reference import jobs.","ref":"AWS.Omics.html#list_reference_import_jobs/4","title":"AWS.Omics.list_reference_import_jobs/4","type":"function"},{"doc":"Retrieves a list of reference stores.","ref":"AWS.Omics.html#list_reference_stores/3","title":"AWS.Omics.list_reference_stores/3","type":"function"},{"doc":"Retrieves a list of references.","ref":"AWS.Omics.html#list_references/4","title":"AWS.Omics.list_references/4","type":"function"},{"doc":"Retrieves a list of run groups.","ref":"AWS.Omics.html#list_run_groups/5","title":"AWS.Omics.list_run_groups/5","type":"function"},{"doc":"Retrieves a list of tasks for a run.","ref":"AWS.Omics.html#list_run_tasks/6","title":"AWS.Omics.list_run_tasks/6","type":"function"},{"doc":"Retrieves a list of runs.","ref":"AWS.Omics.html#list_runs/7","title":"AWS.Omics.list_runs/7","type":"function"},{"doc":"Retrieves a list of sequence stores.","ref":"AWS.Omics.html#list_sequence_stores/3","title":"AWS.Omics.list_sequence_stores/3","type":"function"},{"doc":"Lists all shares associated with an account.","ref":"AWS.Omics.html#list_shares/3","title":"AWS.Omics.list_shares/3","type":"function"},{"doc":"Retrieves a list of tags for a resource.","ref":"AWS.Omics.html#list_tags_for_resource/3","title":"AWS.Omics.list_tags_for_resource/3","type":"function"},{"doc":"Retrieves a list of variant import jobs.","ref":"AWS.Omics.html#list_variant_import_jobs/3","title":"AWS.Omics.list_variant_import_jobs/3","type":"function"},{"doc":"Retrieves a list of variant stores.","ref":"AWS.Omics.html#list_variant_stores/3","title":"AWS.Omics.list_variant_stores/3","type":"function"},{"doc":"Retrieves a list of workflows.","ref":"AWS.Omics.html#list_workflows/6","title":"AWS.Omics.list_workflows/6","type":"function"},{"doc":"","ref":"AWS.Omics.html#metadata/0","title":"AWS.Omics.metadata/0","type":"function"},{"doc":"Starts an annotation import job.","ref":"AWS.Omics.html#start_annotation_import_job/3","title":"AWS.Omics.start_annotation_import_job/3","type":"function"},{"doc":"Activates an archived read set.\n\nTo reduce storage charges, Amazon Omics archives unused read sets after 30 days.","ref":"AWS.Omics.html#start_read_set_activation_job/4","title":"AWS.Omics.start_read_set_activation_job/4","type":"function"},{"doc":"Exports a read set to Amazon S3.","ref":"AWS.Omics.html#start_read_set_export_job/4","title":"AWS.Omics.start_read_set_export_job/4","type":"function"},{"doc":"Starts a read set import job.","ref":"AWS.Omics.html#start_read_set_import_job/4","title":"AWS.Omics.start_read_set_import_job/4","type":"function"},{"doc":"Starts a reference import job.","ref":"AWS.Omics.html#start_reference_import_job/4","title":"AWS.Omics.start_reference_import_job/4","type":"function"},{"doc":"Starts a workflow run.\n\nTo duplicate a run, specify the run's ID and a role ARN. The remaining\nparameters are copied from the previous run.\n\nThe total number of runs in your account is subject to a quota per Region. To\navoid needing to delete runs manually, you can set the retention mode to\n`REMOVE`. Runs with this setting are deleted automatically when the run quoata\nis exceeded.","ref":"AWS.Omics.html#start_run/3","title":"AWS.Omics.start_run/3","type":"function"},{"doc":"Starts a variant import job.","ref":"AWS.Omics.html#start_variant_import_job/3","title":"AWS.Omics.start_variant_import_job/3","type":"function"},{"doc":"Tags a resource.","ref":"AWS.Omics.html#tag_resource/4","title":"AWS.Omics.tag_resource/4","type":"function"},{"doc":"Removes tags from a resource.","ref":"AWS.Omics.html#untag_resource/4","title":"AWS.Omics.untag_resource/4","type":"function"},{"doc":"Updates an annotation store.","ref":"AWS.Omics.html#update_annotation_store/4","title":"AWS.Omics.update_annotation_store/4","type":"function"},{"doc":"Updates the description of an annotation store version.","ref":"AWS.Omics.html#update_annotation_store_version/5","title":"AWS.Omics.update_annotation_store_version/5","type":"function"},{"doc":"Updates a run group.","ref":"AWS.Omics.html#update_run_group/4","title":"AWS.Omics.update_run_group/4","type":"function"},{"doc":"Updates a variant store.","ref":"AWS.Omics.html#update_variant_store/4","title":"AWS.Omics.update_variant_store/4","type":"function"},{"doc":"Updates a workflow.","ref":"AWS.Omics.html#update_workflow/4","title":"AWS.Omics.update_workflow/4","type":"function"},{"doc":"This operation uploads a specific part of a read set.\n\nIf you upload a new part using a previously used part number, the previously\nuploaded part will be overwritten.","ref":"AWS.Omics.html#upload_read_set_part/5","title":"AWS.Omics.upload_read_set_part/5","type":"function"},{"doc":"Use the Amazon OpenSearch Service configuration API to create, configure, and\nmanage OpenSearch Service domains.\n\nFor sample code that uses the configuration API, see the [ *Amazon OpenSearch Service Developer Guide*\n](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/opensearch-configuration-samples.html).\nThe guide also contains [sample code](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/request-signing.html)\nfor sending signed HTTP requests to the OpenSearch APIs. The endpoint for\nconfiguration service requests is Region specific: es.*region*.amazonaws.com.\nFor example, es.us-east-1.amazonaws.com. For a current list of supported Regions\nand endpoints, see [Amazon Web Services service endpoints](https://docs.aws.amazon.com/general/latest/gr/rande.html#service-regions).","ref":"AWS.OpenSearch.html","title":"AWS.OpenSearch","type":"module"},{"doc":"Allows the destination Amazon OpenSearch Service domain owner to accept an\ninbound cross-cluster search connection request.\n\nFor more information, see [Cross-cluster search for Amazon OpenSearch Service](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/cross-cluster-search.html).","ref":"AWS.OpenSearch.html#accept_inbound_connection/4","title":"AWS.OpenSearch.accept_inbound_connection/4","type":"function"},{"doc":"Creates a new direct-query data source to the specified domain.\n\nFor more information, see [Creating Amazon OpenSearch Service data source integrations with Amazon\nS3](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/direct-query-s3-creating.html).","ref":"AWS.OpenSearch.html#add_data_source/4","title":"AWS.OpenSearch.add_data_source/4","type":"function"},{"doc":"Attaches tags to an existing Amazon OpenSearch Service domain.\n\nTags are a set of case-sensitive key-value pairs. A domain can have up to 10\ntags. For more information, see [Tagging Amazon OpenSearch Service domains](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/managedomains-awsresourcetagging.html).","ref":"AWS.OpenSearch.html#add_tags/3","title":"AWS.OpenSearch.add_tags/3","type":"function"},{"doc":"Associates a package with an Amazon OpenSearch Service domain.\n\nFor more information, see [Custom packages for Amazon OpenSearch Service](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/custom-packages.html).","ref":"AWS.OpenSearch.html#associate_package/5","title":"AWS.OpenSearch.associate_package/5","type":"function"},{"doc":"Provides access to an Amazon OpenSearch Service domain through the use of an\ninterface VPC endpoint.","ref":"AWS.OpenSearch.html#authorize_vpc_endpoint_access/4","title":"AWS.OpenSearch.authorize_vpc_endpoint_access/4","type":"function"},{"doc":"Cancels a pending configuration change on an Amazon OpenSearch Service domain.","ref":"AWS.OpenSearch.html#cancel_domain_config_change/4","title":"AWS.OpenSearch.cancel_domain_config_change/4","type":"function"},{"doc":"Cancels a scheduled service software update for an Amazon OpenSearch Service\ndomain.\n\nYou can only perform this operation before the `AutomatedUpdateDate` and when\nthe domain's `UpdateStatus` is `PENDING_UPDATE`. For more information, see\n[Service software updates in Amazon OpenSearch Service](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/service-software.html).","ref":"AWS.OpenSearch.html#cancel_service_software_update/3","title":"AWS.OpenSearch.cancel_service_software_update/3","type":"function"},{"doc":"Creates an Amazon OpenSearch Service domain.\n\nFor more information, see [Creating and managing Amazon OpenSearch Service domains](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/createupdatedomains.html).","ref":"AWS.OpenSearch.html#create_domain/3","title":"AWS.OpenSearch.create_domain/3","type":"function"},{"doc":"Creates a new cross-cluster search connection from a source Amazon OpenSearch\nService domain to a destination domain.\n\nFor more information, see [Cross-cluster search for Amazon OpenSearch Service](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/cross-cluster-search.html).","ref":"AWS.OpenSearch.html#create_outbound_connection/3","title":"AWS.OpenSearch.create_outbound_connection/3","type":"function"},{"doc":"Creates a package for use with Amazon OpenSearch Service domains.\n\nFor more information, see [Custom packages for Amazon OpenSearch Service](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/custom-packages.html).","ref":"AWS.OpenSearch.html#create_package/3","title":"AWS.OpenSearch.create_package/3","type":"function"},{"doc":"Creates an Amazon OpenSearch Service-managed VPC endpoint.","ref":"AWS.OpenSearch.html#create_vpc_endpoint/3","title":"AWS.OpenSearch.create_vpc_endpoint/3","type":"function"},{"doc":"Deletes a direct-query data source.\n\nFor more information, see [Deleting an Amazon OpenSearch Service data source with Amazon\nS3](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/direct-query-s3-delete.html).","ref":"AWS.OpenSearch.html#delete_data_source/5","title":"AWS.OpenSearch.delete_data_source/5","type":"function"},{"doc":"Deletes an Amazon OpenSearch Service domain and all of its data.\n\nYou can't recover a domain after you delete it.","ref":"AWS.OpenSearch.html#delete_domain/4","title":"AWS.OpenSearch.delete_domain/4","type":"function"},{"doc":"Allows the destination Amazon OpenSearch Service domain owner to delete an\nexisting inbound cross-cluster search connection.\n\nFor more information, see [Cross-cluster search for Amazon OpenSearch Service](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/cross-cluster-search.html).","ref":"AWS.OpenSearch.html#delete_inbound_connection/4","title":"AWS.OpenSearch.delete_inbound_connection/4","type":"function"},{"doc":"Allows the source Amazon OpenSearch Service domain owner to delete an existing\noutbound cross-cluster search connection.\n\nFor more information, see [Cross-cluster search for Amazon OpenSearch Service](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/cross-cluster-search.html).","ref":"AWS.OpenSearch.html#delete_outbound_connection/4","title":"AWS.OpenSearch.delete_outbound_connection/4","type":"function"},{"doc":"Deletes an Amazon OpenSearch Service package.\n\nFor more information, see [Custom packages for Amazon OpenSearch Service](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/custom-packages.html).","ref":"AWS.OpenSearch.html#delete_package/4","title":"AWS.OpenSearch.delete_package/4","type":"function"},{"doc":"Deletes an Amazon OpenSearch Service-managed interface VPC endpoint.","ref":"AWS.OpenSearch.html#delete_vpc_endpoint/4","title":"AWS.OpenSearch.delete_vpc_endpoint/4","type":"function"},{"doc":"Describes the domain configuration for the specified Amazon OpenSearch Service\ndomain, including the domain ID, domain service endpoint, and domain ARN.","ref":"AWS.OpenSearch.html#describe_domain/3","title":"AWS.OpenSearch.describe_domain/3","type":"function"},{"doc":"Returns the list of optimizations that Auto-Tune has made to an Amazon\nOpenSearch Service domain.\n\nFor more information, see [Auto-Tune for Amazon OpenSearch Service](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/auto-tune.html).","ref":"AWS.OpenSearch.html#describe_domain_auto_tunes/3","title":"AWS.OpenSearch.describe_domain_auto_tunes/3","type":"function"},{"doc":"Returns information about the current blue/green deployment happening on an\nAmazon OpenSearch Service domain.\n\nFor more information, see [Making configuration changes in Amazon OpenSearch Service](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/managedomains-configuration-changes.html).","ref":"AWS.OpenSearch.html#describe_domain_change_progress/4","title":"AWS.OpenSearch.describe_domain_change_progress/4","type":"function"},{"doc":"Returns the configuration of an Amazon OpenSearch Service domain.","ref":"AWS.OpenSearch.html#describe_domain_config/3","title":"AWS.OpenSearch.describe_domain_config/3","type":"function"},{"doc":"Returns information about domain and node health, the standby Availability Zone,\nnumber of nodes per Availability Zone, and shard count per node.","ref":"AWS.OpenSearch.html#describe_domain_health/3","title":"AWS.OpenSearch.describe_domain_health/3","type":"function"},{"doc":"Returns information about domain and nodes, including data nodes, master nodes,\nultrawarm nodes, Availability Zone(s), standby nodes, node configurations, and\nnode states.","ref":"AWS.OpenSearch.html#describe_domain_nodes/3","title":"AWS.OpenSearch.describe_domain_nodes/3","type":"function"},{"doc":"Returns domain configuration information about the specified Amazon OpenSearch\nService domains.","ref":"AWS.OpenSearch.html#describe_domains/3","title":"AWS.OpenSearch.describe_domains/3","type":"function"},{"doc":"Describes the progress of a pre-update dry run analysis on an Amazon OpenSearch\nService domain.\n\nFor more information, see [Determining whether a change will cause a blue/green deployment](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/managedomains-configuration-changes#dryrun).","ref":"AWS.OpenSearch.html#describe_dry_run_progress/5","title":"AWS.OpenSearch.describe_dry_run_progress/5","type":"function"},{"doc":"Lists all the inbound cross-cluster search connections for a destination\n(remote) Amazon OpenSearch Service domain.\n\nFor more information, see [Cross-cluster search for Amazon OpenSearch Service](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/cross-cluster-search.html).","ref":"AWS.OpenSearch.html#describe_inbound_connections/3","title":"AWS.OpenSearch.describe_inbound_connections/3","type":"function"},{"doc":"Describes the instance count, storage, and master node limits for a given\nOpenSearch or Elasticsearch version and instance type.","ref":"AWS.OpenSearch.html#describe_instance_type_limits/5","title":"AWS.OpenSearch.describe_instance_type_limits/5","type":"function"},{"doc":"Lists all the outbound cross-cluster connections for a local (source) Amazon\nOpenSearch Service domain.\n\nFor more information, see [Cross-cluster search for Amazon OpenSearch Service](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/cross-cluster-search.html).","ref":"AWS.OpenSearch.html#describe_outbound_connections/3","title":"AWS.OpenSearch.describe_outbound_connections/3","type":"function"},{"doc":"Describes all packages available to OpenSearch Service.\n\nFor more information, see [Custom packages for Amazon OpenSearch Service](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/custom-packages.html).","ref":"AWS.OpenSearch.html#describe_packages/3","title":"AWS.OpenSearch.describe_packages/3","type":"function"},{"doc":"Describes the available Amazon OpenSearch Service Reserved Instance offerings\nfor a given Region.\n\nFor more information, see [Reserved Instances in Amazon OpenSearch Service](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/ri.html).","ref":"AWS.OpenSearch.html#describe_reserved_instance_offerings/5","title":"AWS.OpenSearch.describe_reserved_instance_offerings/5","type":"function"},{"doc":"Describes the Amazon OpenSearch Service instances that you have reserved in a\ngiven Region.\n\nFor more information, see [Reserved Instances in Amazon OpenSearch Service](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/ri.html).","ref":"AWS.OpenSearch.html#describe_reserved_instances/5","title":"AWS.OpenSearch.describe_reserved_instances/5","type":"function"},{"doc":"Describes one or more Amazon OpenSearch Service-managed VPC endpoints.","ref":"AWS.OpenSearch.html#describe_vpc_endpoints/3","title":"AWS.OpenSearch.describe_vpc_endpoints/3","type":"function"},{"doc":"Removes a package from the specified Amazon OpenSearch Service domain.\n\nThe package can't be in use with any OpenSearch index for the dissociation to\nsucceed. The package is still available in OpenSearch Service for association\nlater. For more information, see [Custom packages for Amazon OpenSearch Service](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/custom-packages.html).","ref":"AWS.OpenSearch.html#dissociate_package/5","title":"AWS.OpenSearch.dissociate_package/5","type":"function"},{"doc":"Returns a map of OpenSearch or Elasticsearch versions and the versions you can\nupgrade them to.","ref":"AWS.OpenSearch.html#get_compatible_versions/3","title":"AWS.OpenSearch.get_compatible_versions/3","type":"function"},{"doc":"Retrieves information about a direct query data source.","ref":"AWS.OpenSearch.html#get_data_source/4","title":"AWS.OpenSearch.get_data_source/4","type":"function"},{"doc":"The status of the maintenance action.","ref":"AWS.OpenSearch.html#get_domain_maintenance_status/4","title":"AWS.OpenSearch.get_domain_maintenance_status/4","type":"function"},{"doc":"Returns a list of Amazon OpenSearch Service package versions, along with their\ncreation time, commit message, and plugin properties (if the package is a zip\nplugin package).\n\nFor more information, see [Custom packages for Amazon OpenSearch Service](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/custom-packages.html).","ref":"AWS.OpenSearch.html#get_package_version_history/5","title":"AWS.OpenSearch.get_package_version_history/5","type":"function"},{"doc":"Retrieves the complete history of the last 10 upgrades performed on an Amazon\nOpenSearch Service domain.","ref":"AWS.OpenSearch.html#get_upgrade_history/5","title":"AWS.OpenSearch.get_upgrade_history/5","type":"function"},{"doc":"Returns the most recent status of the last upgrade or upgrade eligibility check\nperformed on an Amazon OpenSearch Service domain.","ref":"AWS.OpenSearch.html#get_upgrade_status/3","title":"AWS.OpenSearch.get_upgrade_status/3","type":"function"},{"doc":"Lists direct-query data sources for a specific domain.\n\nFor more information, see For more information, see [Working with Amazon OpenSearch Service direct queries with Amazon\nS3](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/direct-query-s3.html).","ref":"AWS.OpenSearch.html#list_data_sources/3","title":"AWS.OpenSearch.list_data_sources/3","type":"function"},{"doc":"A list of maintenance actions for the domain.","ref":"AWS.OpenSearch.html#list_domain_maintenances/7","title":"AWS.OpenSearch.list_domain_maintenances/7","type":"function"},{"doc":"Returns the names of all Amazon OpenSearch Service domains owned by the current\nuser in the active Region.","ref":"AWS.OpenSearch.html#list_domain_names/3","title":"AWS.OpenSearch.list_domain_names/3","type":"function"},{"doc":"Lists all Amazon OpenSearch Service domains associated with a given package.\n\nFor more information, see [Custom packages for Amazon OpenSearch Service](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/custom-packages.html).","ref":"AWS.OpenSearch.html#list_domains_for_package/5","title":"AWS.OpenSearch.list_domains_for_package/5","type":"function"},{"doc":"Lists all instance types and available features for a given OpenSearch or\nElasticsearch version.","ref":"AWS.OpenSearch.html#list_instance_type_details/8","title":"AWS.OpenSearch.list_instance_type_details/8","type":"function"},{"doc":"Lists all packages associated with an Amazon OpenSearch Service domain.\n\nFor more information, see [Custom packages for Amazon OpenSearch Service](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/custom-packages.html).","ref":"AWS.OpenSearch.html#list_packages_for_domain/5","title":"AWS.OpenSearch.list_packages_for_domain/5","type":"function"},{"doc":"Retrieves a list of configuration changes that are scheduled for a domain.\n\nThese changes can be [service software updates](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/service-software.html)\nor [blue/green Auto-Tune enhancements](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/auto-tune.html#auto-tune-types).","ref":"AWS.OpenSearch.html#list_scheduled_actions/5","title":"AWS.OpenSearch.list_scheduled_actions/5","type":"function"},{"doc":"Returns all resource tags for an Amazon OpenSearch Service domain.\n\nFor more information, see [Tagging Amazon OpenSearch Service domains](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/managedomains-awsresourcetagging.html).","ref":"AWS.OpenSearch.html#list_tags/3","title":"AWS.OpenSearch.list_tags/3","type":"function"},{"doc":"Lists all versions of OpenSearch and Elasticsearch that Amazon OpenSearch\nService supports.","ref":"AWS.OpenSearch.html#list_versions/4","title":"AWS.OpenSearch.list_versions/4","type":"function"},{"doc":"Retrieves information about each Amazon Web Services principal that is allowed\nto access a given Amazon OpenSearch Service domain through the use of an\ninterface VPC endpoint.","ref":"AWS.OpenSearch.html#list_vpc_endpoint_access/4","title":"AWS.OpenSearch.list_vpc_endpoint_access/4","type":"function"},{"doc":"Retrieves all Amazon OpenSearch Service-managed VPC endpoints in the current\nAmazon Web Services account and Region.","ref":"AWS.OpenSearch.html#list_vpc_endpoints/3","title":"AWS.OpenSearch.list_vpc_endpoints/3","type":"function"},{"doc":"Retrieves all Amazon OpenSearch Service-managed VPC endpoints associated with a\nparticular domain.","ref":"AWS.OpenSearch.html#list_vpc_endpoints_for_domain/4","title":"AWS.OpenSearch.list_vpc_endpoints_for_domain/4","type":"function"},{"doc":"","ref":"AWS.OpenSearch.html#metadata/0","title":"AWS.OpenSearch.metadata/0","type":"function"},{"doc":"Allows you to purchase Amazon OpenSearch Service Reserved Instances.","ref":"AWS.OpenSearch.html#purchase_reserved_instance_offering/3","title":"AWS.OpenSearch.purchase_reserved_instance_offering/3","type":"function"},{"doc":"Allows the remote Amazon OpenSearch Service domain owner to reject an inbound\ncross-cluster connection request.","ref":"AWS.OpenSearch.html#reject_inbound_connection/4","title":"AWS.OpenSearch.reject_inbound_connection/4","type":"function"},{"doc":"Removes the specified set of tags from an Amazon OpenSearch Service domain.\n\nFor more information, see [ Tagging Amazon OpenSearch Service domains](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/managedomains.html#managedomains-awsresorcetagging).","ref":"AWS.OpenSearch.html#remove_tags/3","title":"AWS.OpenSearch.remove_tags/3","type":"function"},{"doc":"Revokes access to an Amazon OpenSearch Service domain that was provided through\nan interface VPC endpoint.","ref":"AWS.OpenSearch.html#revoke_vpc_endpoint_access/4","title":"AWS.OpenSearch.revoke_vpc_endpoint_access/4","type":"function"},{"doc":"Starts the node maintenance process on the data node.\n\nThese processes can include a node reboot, an Opensearch or Elasticsearch\nprocess restart, or a Dashboard or Kibana restart.","ref":"AWS.OpenSearch.html#start_domain_maintenance/4","title":"AWS.OpenSearch.start_domain_maintenance/4","type":"function"},{"doc":"Schedules a service software update for an Amazon OpenSearch Service domain.\n\nFor more information, see [Service software updates in Amazon OpenSearch Service](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/service-software.html).","ref":"AWS.OpenSearch.html#start_service_software_update/3","title":"AWS.OpenSearch.start_service_software_update/3","type":"function"},{"doc":"Updates a direct-query data source.\n\nFor more information, see [Working with Amazon OpenSearch Service data source integrations with Amazon\nS3](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/direct-query-s3-creating.html).","ref":"AWS.OpenSearch.html#update_data_source/5","title":"AWS.OpenSearch.update_data_source/5","type":"function"},{"doc":"Modifies the cluster configuration of the specified Amazon OpenSearch Service\ndomain.","ref":"AWS.OpenSearch.html#update_domain_config/4","title":"AWS.OpenSearch.update_domain_config/4","type":"function"},{"doc":"Updates a package for use with Amazon OpenSearch Service domains.\n\nFor more information, see [Custom packages for Amazon OpenSearch Service](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/custom-packages.html).","ref":"AWS.OpenSearch.html#update_package/3","title":"AWS.OpenSearch.update_package/3","type":"function"},{"doc":"Reschedules a planned domain configuration change for a later time.\n\nThis change can be a scheduled [service software update](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/service-software.html)\nor a [blue/green Auto-Tune enhancement](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/auto-tune.html#auto-tune-types).","ref":"AWS.OpenSearch.html#update_scheduled_action/4","title":"AWS.OpenSearch.update_scheduled_action/4","type":"function"},{"doc":"Modifies an Amazon OpenSearch Service-managed interface VPC endpoint.","ref":"AWS.OpenSearch.html#update_vpc_endpoint/3","title":"AWS.OpenSearch.update_vpc_endpoint/3","type":"function"},{"doc":"Allows you to either upgrade your Amazon OpenSearch Service domain or perform an\nupgrade eligibility check to a compatible version of OpenSearch or\nElasticsearch.","ref":"AWS.OpenSearch.html#upgrade_domain/3","title":"AWS.OpenSearch.upgrade_domain/3","type":"function"},{"doc":"Use the Amazon OpenSearch Serverless API to create, configure, and manage\nOpenSearch Serverless collections and security policies.\n\nOpenSearch Serverless is an on-demand, pre-provisioned serverless configuration\nfor Amazon OpenSearch Service. OpenSearch Serverless removes the operational\ncomplexities of provisioning, configuring, and tuning your OpenSearch clusters.\nIt enables you to easily search and analyze petabytes of data without having to\nworry about the underlying infrastructure and data management.\n\nTo learn more about OpenSearch Serverless, see [What is Amazon OpenSearch Serverless?](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-overview.html)","ref":"AWS.OpenSearchServerless.html","title":"AWS.OpenSearchServerless","type":"module"},{"doc":"Returns attributes for one or more collections, including the collection\nendpoint and the OpenSearch Dashboards endpoint.\n\nFor more information, see [Creating and managing Amazon OpenSearch Serverless collections](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-manage.html).","ref":"AWS.OpenSearchServerless.html#batch_get_collection/3","title":"AWS.OpenSearchServerless.batch_get_collection/3","type":"function"},{"doc":"Returns a list of successful and failed retrievals for the OpenSearch Serverless\nindexes.\n\nFor more information, see [Viewing data lifecycle policies](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-lifecycle.html#serverless-lifecycle-list).","ref":"AWS.OpenSearchServerless.html#batch_get_effective_lifecycle_policy/3","title":"AWS.OpenSearchServerless.batch_get_effective_lifecycle_policy/3","type":"function"},{"doc":"Returns one or more configured OpenSearch Serverless lifecycle policies.\n\nFor more information, see [Viewing data lifecycle policies](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-lifecycle.html#serverless-lifecycle-list).","ref":"AWS.OpenSearchServerless.html#batch_get_lifecycle_policy/3","title":"AWS.OpenSearchServerless.batch_get_lifecycle_policy/3","type":"function"},{"doc":"Returns attributes for one or more VPC endpoints associated with the current\naccount.\n\nFor more information, see [Access Amazon OpenSearch Serverless using an interface\nendpoint](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-vpc.html).","ref":"AWS.OpenSearchServerless.html#batch_get_vpc_endpoint/3","title":"AWS.OpenSearchServerless.batch_get_vpc_endpoint/3","type":"function"},{"doc":"Creates a data access policy for OpenSearch Serverless.\n\nAccess policies limit access to collections and the resources within them, and\nallow a user to access that data irrespective of the access mechanism or network\nsource. For more information, see [Data access control for Amazon OpenSearch Serverless](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-data-access.html).","ref":"AWS.OpenSearchServerless.html#create_access_policy/3","title":"AWS.OpenSearchServerless.create_access_policy/3","type":"function"},{"doc":"Creates a new OpenSearch Serverless collection.\n\nFor more information, see [Creating and managing Amazon OpenSearch Serverless collections](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-manage.html).","ref":"AWS.OpenSearchServerless.html#create_collection/3","title":"AWS.OpenSearchServerless.create_collection/3","type":"function"},{"doc":"Creates a lifecyle policy to be applied to OpenSearch Serverless indexes.\n\nLifecycle policies define the number of days or hours to retain the data on an\nOpenSearch Serverless index. For more information, see [Creating data lifecycle policies](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-lifecycle.html#serverless-lifecycle-create).","ref":"AWS.OpenSearchServerless.html#create_lifecycle_policy/3","title":"AWS.OpenSearchServerless.create_lifecycle_policy/3","type":"function"},{"doc":"Specifies a security configuration for OpenSearch Serverless.\n\nFor more information, see [SAML authentication for Amazon OpenSearch Serverless](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-saml.html).","ref":"AWS.OpenSearchServerless.html#create_security_config/3","title":"AWS.OpenSearchServerless.create_security_config/3","type":"function"},{"doc":"Creates a security policy to be used by one or more OpenSearch Serverless\ncollections.\n\nSecurity policies provide access to a collection and its OpenSearch Dashboards\nendpoint from public networks or specific VPC endpoints. They also allow you to\nsecure a collection with a KMS encryption key. For more information, see\n[Network access for Amazon OpenSearch Serverless](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-network.html)\nand [Encryption at rest for Amazon OpenSearch Serverless](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-encryption.html).","ref":"AWS.OpenSearchServerless.html#create_security_policy/3","title":"AWS.OpenSearchServerless.create_security_policy/3","type":"function"},{"doc":"Creates an OpenSearch Serverless-managed interface VPC endpoint.\n\nFor more information, see [Access Amazon OpenSearch Serverless using an interface\nendpoint](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-vpc.html).","ref":"AWS.OpenSearchServerless.html#create_vpc_endpoint/3","title":"AWS.OpenSearchServerless.create_vpc_endpoint/3","type":"function"},{"doc":"Deletes an OpenSearch Serverless access policy.\n\nFor more information, see [Data access control for Amazon OpenSearch Serverless](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-data-access.html).","ref":"AWS.OpenSearchServerless.html#delete_access_policy/3","title":"AWS.OpenSearchServerless.delete_access_policy/3","type":"function"},{"doc":"Deletes an OpenSearch Serverless collection.\n\nFor more information, see [Creating and managing Amazon OpenSearch Serverless collections](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-manage.html).","ref":"AWS.OpenSearchServerless.html#delete_collection/3","title":"AWS.OpenSearchServerless.delete_collection/3","type":"function"},{"doc":"Deletes an OpenSearch Serverless lifecycle policy.\n\nFor more information, see [Deleting data lifecycle policies](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-lifecycle.html#serverless-lifecycle-delete).","ref":"AWS.OpenSearchServerless.html#delete_lifecycle_policy/3","title":"AWS.OpenSearchServerless.delete_lifecycle_policy/3","type":"function"},{"doc":"Deletes a security configuration for OpenSearch Serverless.\n\nFor more information, see [SAML authentication for Amazon OpenSearch Serverless](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-saml.html).","ref":"AWS.OpenSearchServerless.html#delete_security_config/3","title":"AWS.OpenSearchServerless.delete_security_config/3","type":"function"},{"doc":"Deletes an OpenSearch Serverless security policy.","ref":"AWS.OpenSearchServerless.html#delete_security_policy/3","title":"AWS.OpenSearchServerless.delete_security_policy/3","type":"function"},{"doc":"Deletes an OpenSearch Serverless-managed interface endpoint.\n\nFor more information, see [Access Amazon OpenSearch Serverless using an interface\nendpoint](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-vpc.html).","ref":"AWS.OpenSearchServerless.html#delete_vpc_endpoint/3","title":"AWS.OpenSearchServerless.delete_vpc_endpoint/3","type":"function"},{"doc":"Returns an OpenSearch Serverless access policy.\n\nFor more information, see [Data access control for Amazon OpenSearch Serverless](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-data-access.html).","ref":"AWS.OpenSearchServerless.html#get_access_policy/3","title":"AWS.OpenSearchServerless.get_access_policy/3","type":"function"},{"doc":"Returns account-level settings related to OpenSearch Serverless.","ref":"AWS.OpenSearchServerless.html#get_account_settings/3","title":"AWS.OpenSearchServerless.get_account_settings/3","type":"function"},{"doc":"Returns statistical information about your OpenSearch Serverless access\npolicies, security configurations, and security policies.","ref":"AWS.OpenSearchServerless.html#get_policies_stats/3","title":"AWS.OpenSearchServerless.get_policies_stats/3","type":"function"},{"doc":"Returns information about an OpenSearch Serverless security configuration.\n\nFor more information, see [SAML authentication for Amazon OpenSearch Serverless](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-saml.html).","ref":"AWS.OpenSearchServerless.html#get_security_config/3","title":"AWS.OpenSearchServerless.get_security_config/3","type":"function"},{"doc":"Returns information about a configured OpenSearch Serverless security policy.\n\nFor more information, see [Network access for Amazon OpenSearch Serverless](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-network.html)\nand [Encryption at rest for Amazon OpenSearch Serverless](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-encryption.html).","ref":"AWS.OpenSearchServerless.html#get_security_policy/3","title":"AWS.OpenSearchServerless.get_security_policy/3","type":"function"},{"doc":"Returns information about a list of OpenSearch Serverless access policies.","ref":"AWS.OpenSearchServerless.html#list_access_policies/3","title":"AWS.OpenSearchServerless.list_access_policies/3","type":"function"},{"doc":"Lists all OpenSearch Serverless collections.\n\nFor more information, see [Creating and managing Amazon OpenSearch Serverless collections](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-manage.html).\n\nMake sure to include an empty request body {} if you don't include any\ncollection filters in the request.","ref":"AWS.OpenSearchServerless.html#list_collections/3","title":"AWS.OpenSearchServerless.list_collections/3","type":"function"},{"doc":"Returns a list of OpenSearch Serverless lifecycle policies.\n\nFor more information, see [Viewing data lifecycle policies](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-lifecycle.html#serverless-lifecycle-list).","ref":"AWS.OpenSearchServerless.html#list_lifecycle_policies/3","title":"AWS.OpenSearchServerless.list_lifecycle_policies/3","type":"function"},{"doc":"Returns information about configured OpenSearch Serverless security\nconfigurations.\n\nFor more information, see [SAML authentication for Amazon OpenSearch Serverless](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-saml.html).","ref":"AWS.OpenSearchServerless.html#list_security_configs/3","title":"AWS.OpenSearchServerless.list_security_configs/3","type":"function"},{"doc":"Returns information about configured OpenSearch Serverless security policies.","ref":"AWS.OpenSearchServerless.html#list_security_policies/3","title":"AWS.OpenSearchServerless.list_security_policies/3","type":"function"},{"doc":"Returns the tags for an OpenSearch Serverless resource.\n\nFor more information, see [Tagging Amazon OpenSearch Serverless collections](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/tag-collection.html).","ref":"AWS.OpenSearchServerless.html#list_tags_for_resource/3","title":"AWS.OpenSearchServerless.list_tags_for_resource/3","type":"function"},{"doc":"Returns the OpenSearch Serverless-managed interface VPC endpoints associated\nwith the current account.\n\nFor more information, see [Access Amazon OpenSearch Serverless using an interface\nendpoint](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-vpc.html).","ref":"AWS.OpenSearchServerless.html#list_vpc_endpoints/3","title":"AWS.OpenSearchServerless.list_vpc_endpoints/3","type":"function"},{"doc":"","ref":"AWS.OpenSearchServerless.html#metadata/0","title":"AWS.OpenSearchServerless.metadata/0","type":"function"},{"doc":"Associates tags with an OpenSearch Serverless resource.\n\nFor more information, see [Tagging Amazon OpenSearch Serverless collections](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/tag-collection.html).","ref":"AWS.OpenSearchServerless.html#tag_resource/3","title":"AWS.OpenSearchServerless.tag_resource/3","type":"function"},{"doc":"Removes a tag or set of tags from an OpenSearch Serverless resource.\n\nFor more information, see [Tagging Amazon OpenSearch Serverless collections](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/tag-collection.html).","ref":"AWS.OpenSearchServerless.html#untag_resource/3","title":"AWS.OpenSearchServerless.untag_resource/3","type":"function"},{"doc":"Updates an OpenSearch Serverless access policy.\n\nFor more information, see [Data access control for Amazon OpenSearch Serverless](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-data-access.html).","ref":"AWS.OpenSearchServerless.html#update_access_policy/3","title":"AWS.OpenSearchServerless.update_access_policy/3","type":"function"},{"doc":"Update the OpenSearch Serverless settings for the current Amazon Web Services\naccount.\n\nFor more information, see [Managing capacity limits for Amazon OpenSearch Serverless](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-scaling.html).","ref":"AWS.OpenSearchServerless.html#update_account_settings/3","title":"AWS.OpenSearchServerless.update_account_settings/3","type":"function"},{"doc":"Updates an OpenSearch Serverless collection.","ref":"AWS.OpenSearchServerless.html#update_collection/3","title":"AWS.OpenSearchServerless.update_collection/3","type":"function"},{"doc":"Updates an OpenSearch Serverless access policy.\n\nFor more information, see [Updating data lifecycle policies](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-lifecycle.html#serverless-lifecycle-update).","ref":"AWS.OpenSearchServerless.html#update_lifecycle_policy/3","title":"AWS.OpenSearchServerless.update_lifecycle_policy/3","type":"function"},{"doc":"Updates a security configuration for OpenSearch Serverless.\n\nFor more information, see [SAML authentication for Amazon OpenSearch Serverless](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-saml.html).","ref":"AWS.OpenSearchServerless.html#update_security_config/3","title":"AWS.OpenSearchServerless.update_security_config/3","type":"function"},{"doc":"Updates an OpenSearch Serverless security policy.\n\nFor more information, see [Network access for Amazon OpenSearch Serverless](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-network.html)\nand [Encryption at rest for Amazon OpenSearch Serverless](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-encryption.html).","ref":"AWS.OpenSearchServerless.html#update_security_policy/3","title":"AWS.OpenSearchServerless.update_security_policy/3","type":"function"},{"doc":"Updates an OpenSearch Serverless-managed interface endpoint.\n\nFor more information, see [Access Amazon OpenSearch Serverless using an interface\nendpoint](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-vpc.html).","ref":"AWS.OpenSearchServerless.html#update_vpc_endpoint/3","title":"AWS.OpenSearchServerless.update_vpc_endpoint/3","type":"function"},{"doc":"AWS OpsWorks\n\nWelcome to the *AWS OpsWorks Stacks API Reference*.\n\nThis guide provides descriptions, syntax, and usage examples for AWS OpsWorks\nStacks actions and data types, including common parameters and error codes.\n\nAWS OpsWorks Stacks is an application management service that provides an\nintegrated experience for overseeing the complete application lifecycle. For\ninformation about this product, go to the [AWS OpsWorks](http://aws.amazon.com/opsworks/) details page.","ref":"AWS.OpsWorks.html","title":"AWS.OpsWorks","type":"module"},{"doc":"The most common way to use the AWS OpsWorks Stacks API is by using the AWS\nCommand Line Interface (CLI) or by using one of the AWS SDKs to implement\napplications in your preferred language. For more information, see:\n\n  * [AWS CLI](https://docs.aws.amazon.com/cli/latest/userguide/cli-chap-welcome.html)\n\n  * [AWS SDK for Java](https://docs.aws.amazon.com/AWSJavaSDK/latest/javadoc/com/amazonaws/services/opsworks/AWSOpsWorksClient.html)\n\n  * [AWS SDK for .NET](https://docs.aws.amazon.com/sdkfornet/latest/apidocs/html/N_Amazon_OpsWorks.htm)\n\n  * [AWS SDK for PHP 2](https://docs.aws.amazon.com/aws-sdk-php-2/latest/class-Aws.OpsWorks.OpsWorksClient.html)\n\n  * [AWS SDK for Ruby](http://docs.aws.amazon.com/sdkforruby/api/)     * [AWS SDK for\nNode.js](http://aws.amazon.com/documentation/sdkforjavascript/)\n\n  * [AWS SDK for Python(Boto)](http://docs.pythonboto.org/en/latest/ref/opsworks.html)","ref":"AWS.OpsWorks.html#module-sdks-and-cli","title":"SDKs and CLI - AWS.OpsWorks","type":"module"},{"doc":"AWS OpsWorks Stacks supports the following endpoints, all HTTPS. You must\nconnect to one of the following endpoints. Stacks can only be accessed or\nmanaged within the endpoint in which they are created.\n\n  * opsworks.us-east-1.amazonaws.com\n\n  * opsworks.us-east-2.amazonaws.com\n\n  * opsworks.us-west-1.amazonaws.com\n\n  * opsworks.us-west-2.amazonaws.com\n\n  * opsworks.ca-central-1.amazonaws.com (API only; not available in\nthe AWS console)\n\n  * opsworks.eu-west-1.amazonaws.com\n\n  * opsworks.eu-west-2.amazonaws.com\n\n  * opsworks.eu-west-3.amazonaws.com\n\n  * opsworks.eu-central-1.amazonaws.com\n\n  * opsworks.ap-northeast-1.amazonaws.com\n\n  * opsworks.ap-northeast-2.amazonaws.com\n\n  * opsworks.ap-south-1.amazonaws.com\n\n  * opsworks.ap-southeast-1.amazonaws.com\n\n  * opsworks.ap-southeast-2.amazonaws.com\n\n  * opsworks.sa-east-1.amazonaws.com","ref":"AWS.OpsWorks.html#module-endpoints","title":"Endpoints - AWS.OpsWorks","type":"module"},{"doc":"When you call `CreateStack`, `CloneStack`, or `UpdateStack` we recommend you use\nthe `ConfigurationManager` parameter to specify the Chef version. The\nrecommended and default value for Linux stacks is currently 12. Windows stacks\nuse Chef 12.2. For more information, see [Chef Versions](https://docs.aws.amazon.com/opsworks/latest/userguide/workingcookbook-chef11.html).\n\nYou can specify Chef 12, 11.10, or 11.4 for your Linux stack. We recommend\nmigrating your existing Linux stacks to Chef 12 as soon as possible.","ref":"AWS.OpsWorks.html#module-chef-versions","title":"Chef Versions - AWS.OpsWorks","type":"module"},{"doc":"Assign a registered instance to a layer.\n\n  * You can assign registered on-premises instances to any layer type.\n\n  * You can assign registered Amazon EC2 instances only to custom\nlayers.\n\n  * You cannot use this action with instances that were created with\nAWS OpsWorks Stacks.\n\n**Required Permissions**: To use this action, an AWS Identity and Access\nManagement (IAM) user must have a Manage permissions level for the stack or an\nattached policy that explicitly grants permissions. For more information on user\npermissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#assign_instance/3","title":"AWS.OpsWorks.assign_instance/3","type":"function"},{"doc":"Assigns one of the stack's registered Amazon EBS volumes to a specified\ninstance.\n\nThe volume must first be registered with the stack by calling `RegisterVolume`.\nAfter you register the volume, you must call `UpdateVolume` to specify a mount\npoint before calling `AssignVolume`. For more information, see [Resource Management](https://docs.aws.amazon.com/opsworks/latest/userguide/resources.html).\n\n**Required Permissions**: To use this action, an IAM user must have a Manage\npermissions level for the stack, or an attached policy that explicitly grants\npermissions. For more information on user permissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#assign_volume/3","title":"AWS.OpsWorks.assign_volume/3","type":"function"},{"doc":"Associates one of the stack's registered Elastic IP addresses with a specified\ninstance.\n\nThe address must first be registered with the stack by calling\n`RegisterElasticIp`. For more information, see [Resource Management](https://docs.aws.amazon.com/opsworks/latest/userguide/resources.html).\n\n**Required Permissions**: To use this action, an IAM user must have a Manage\npermissions level for the stack, or an attached policy that explicitly grants\npermissions. For more information on user permissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#associate_elastic_ip/3","title":"AWS.OpsWorks.associate_elastic_ip/3","type":"function"},{"doc":"Attaches an Elastic Load Balancing load balancer to a specified layer.\n\nAWS OpsWorks Stacks does not support Application Load Balancer. You can only use\nClassic Load Balancer with AWS OpsWorks Stacks. For more information, see\n[Elastic Load Balancing](https://docs.aws.amazon.com/opsworks/latest/userguide/layers-elb.html).\n\nYou must create the Elastic Load Balancing instance separately, by using the\nElastic Load Balancing console, API, or CLI. For more information, see [ Elastic Load Balancing Developer\nGuide](https://docs.aws.amazon.com/ElasticLoadBalancing/latest/DeveloperGuide/Welcome.html).\n\n**Required Permissions**: To use this action, an IAM user must have a Manage\npermissions level for the stack, or an attached policy that explicitly grants\npermissions. For more information on user permissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#attach_elastic_load_balancer/3","title":"AWS.OpsWorks.attach_elastic_load_balancer/3","type":"function"},{"doc":"Creates a clone of a specified stack.\n\nFor more information, see [Clone a Stack](https://docs.aws.amazon.com/opsworks/latest/userguide/workingstacks-cloning.html).\nBy default, all parameters are set to the values used by the parent stack.\n\n**Required Permissions**: To use this action, an IAM user must have an attached\npolicy that explicitly grants permissions. For more information about user\npermissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#clone_stack/3","title":"AWS.OpsWorks.clone_stack/3","type":"function"},{"doc":"Creates an app for a specified stack.\n\nFor more information, see [Creating Apps](https://docs.aws.amazon.com/opsworks/latest/userguide/workingapps-creating.html).\n\n**Required Permissions**: To use this action, an IAM user must have a Manage\npermissions level for the stack, or an attached policy that explicitly grants\npermissions. For more information on user permissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#create_app/3","title":"AWS.OpsWorks.create_app/3","type":"function"},{"doc":"Runs deployment or stack commands.\n\nFor more information, see [Deploying Apps](https://docs.aws.amazon.com/opsworks/latest/userguide/workingapps-deploying.html)\nand [Run Stack Commands](https://docs.aws.amazon.com/opsworks/latest/userguide/workingstacks-commands.html).\n\n**Required Permissions**: To use this action, an IAM user must have a Deploy or\nManage permissions level for the stack, or an attached policy that explicitly\ngrants permissions. For more information on user permissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#create_deployment/3","title":"AWS.OpsWorks.create_deployment/3","type":"function"},{"doc":"Creates an instance in a specified stack.\n\nFor more information, see [Adding an Instance to a Layer](https://docs.aws.amazon.com/opsworks/latest/userguide/workinginstances-add.html).\n\n**Required Permissions**: To use this action, an IAM user must have a Manage\npermissions level for the stack, or an attached policy that explicitly grants\npermissions. For more information on user permissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#create_instance/3","title":"AWS.OpsWorks.create_instance/3","type":"function"},{"doc":"Creates a layer.\n\nFor more information, see [How to Create a Layer](https://docs.aws.amazon.com/opsworks/latest/userguide/workinglayers-basics-create.html).\n\nYou should use **CreateLayer** for noncustom layer types such as PHP App Server\nonly if the stack does not have an existing layer of that type. A stack can have\nat most one instance of each noncustom layer; if you attempt to create a second\ninstance, **CreateLayer** fails. A stack can have an arbitrary number of custom\nlayers, so you can call **CreateLayer** as many times as you like for that layer\ntype.\n\n**Required Permissions**: To use this action, an IAM user must have a Manage\npermissions level for the stack, or an attached policy that explicitly grants\npermissions. For more information on user permissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#create_layer/3","title":"AWS.OpsWorks.create_layer/3","type":"function"},{"doc":"Creates a new stack.\n\nFor more information, see [Create a New Stack](https://docs.aws.amazon.com/opsworks/latest/userguide/workingstacks-edit.html).\n\n**Required Permissions**: To use this action, an IAM user must have an attached\npolicy that explicitly grants permissions. For more information about user\npermissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#create_stack/3","title":"AWS.OpsWorks.create_stack/3","type":"function"},{"doc":"Creates a new user profile.\n\n**Required Permissions**: To use this action, an IAM user must have an attached\npolicy that explicitly grants permissions. For more information about user\npermissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#create_user_profile/3","title":"AWS.OpsWorks.create_user_profile/3","type":"function"},{"doc":"Deletes a specified app.\n\n**Required Permissions**: To use this action, an IAM user must have a Manage\npermissions level for the stack, or an attached policy that explicitly grants\npermissions. For more information on user permissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#delete_app/3","title":"AWS.OpsWorks.delete_app/3","type":"function"},{"doc":"Deletes a specified instance, which terminates the associated Amazon EC2\ninstance.\n\nYou must stop an instance before you can delete it.\n\nFor more information, see [Deleting Instances](https://docs.aws.amazon.com/opsworks/latest/userguide/workinginstances-delete.html).\n\n**Required Permissions**: To use this action, an IAM user must have a Manage\npermissions level for the stack, or an attached policy that explicitly grants\npermissions. For more information on user permissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#delete_instance/3","title":"AWS.OpsWorks.delete_instance/3","type":"function"},{"doc":"Deletes a specified layer.\n\nYou must first stop and then delete all associated instances or unassign\nregistered instances. For more information, see [How to Delete a Layer](https://docs.aws.amazon.com/opsworks/latest/userguide/workinglayers-basics-delete.html).\n\n**Required Permissions**: To use this action, an IAM user must have a Manage\npermissions level for the stack, or an attached policy that explicitly grants\npermissions. For more information on user permissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#delete_layer/3","title":"AWS.OpsWorks.delete_layer/3","type":"function"},{"doc":"Deletes a specified stack.\n\nYou must first delete all instances, layers, and apps or deregister registered\ninstances. For more information, see [Shut Down a Stack](https://docs.aws.amazon.com/opsworks/latest/userguide/workingstacks-shutting.html).\n\n**Required Permissions**: To use this action, an IAM user must have a Manage\npermissions level for the stack, or an attached policy that explicitly grants\npermissions. For more information on user permissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#delete_stack/3","title":"AWS.OpsWorks.delete_stack/3","type":"function"},{"doc":"Deletes a user profile.\n\n**Required Permissions**: To use this action, an IAM user must have an attached\npolicy that explicitly grants permissions. For more information about user\npermissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#delete_user_profile/3","title":"AWS.OpsWorks.delete_user_profile/3","type":"function"},{"doc":"Deregisters a specified Amazon ECS cluster from a stack.\n\nFor more information, see [ Resource Management](https://docs.aws.amazon.com/opsworks/latest/userguide/workinglayers-ecscluster.html#workinglayers-ecscluster-delete).\n\n**Required Permissions**: To use this action, an IAM user must have a Manage\npermissions level for the stack or an attached policy that explicitly grants\npermissions. For more information on user permissions, see\n[https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#deregister_ecs_cluster/3","title":"AWS.OpsWorks.deregister_ecs_cluster/3","type":"function"},{"doc":"Deregisters a specified Elastic IP address.\n\nThe address can then be registered by another stack. For more information, see\n[Resource Management](https://docs.aws.amazon.com/opsworks/latest/userguide/resources.html).\n\n**Required Permissions**: To use this action, an IAM user must have a Manage\npermissions level for the stack, or an attached policy that explicitly grants\npermissions. For more information on user permissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#deregister_elastic_ip/3","title":"AWS.OpsWorks.deregister_elastic_ip/3","type":"function"},{"doc":"Deregister a registered Amazon EC2 or on-premises instance.\n\nThis action removes the instance from the stack and returns it to your control.\nThis action cannot be used with instances that were created with AWS OpsWorks\nStacks.\n\n**Required Permissions**: To use this action, an IAM user must have a Manage\npermissions level for the stack or an attached policy that explicitly grants\npermissions. For more information on user permissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#deregister_instance/3","title":"AWS.OpsWorks.deregister_instance/3","type":"function"},{"doc":"Deregisters an Amazon RDS instance.\n\n**Required Permissions**: To use this action, an IAM user must have a Manage\npermissions level for the stack, or an attached policy that explicitly grants\npermissions. For more information on user permissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#deregister_rds_db_instance/3","title":"AWS.OpsWorks.deregister_rds_db_instance/3","type":"function"},{"doc":"Deregisters an Amazon EBS volume.\n\nThe volume can then be registered by another stack. For more information, see\n[Resource Management](https://docs.aws.amazon.com/opsworks/latest/userguide/resources.html).\n\n**Required Permissions**: To use this action, an IAM user must have a Manage\npermissions level for the stack, or an attached policy that explicitly grants\npermissions. For more information on user permissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#deregister_volume/3","title":"AWS.OpsWorks.deregister_volume/3","type":"function"},{"doc":"Describes the available AWS OpsWorks Stacks agent versions.\n\nYou must specify a stack ID or a configuration manager. `DescribeAgentVersions`\nreturns a list of available agent versions for the specified stack or\nconfiguration manager.","ref":"AWS.OpsWorks.html#describe_agent_versions/3","title":"AWS.OpsWorks.describe_agent_versions/3","type":"function"},{"doc":"Requests a description of a specified set of apps.\n\nThis call accepts only one resource-identifying parameter.\n\n**Required Permissions**: To use this action, an IAM user must have a Show,\nDeploy, or Manage permissions level for the stack, or an attached policy that\nexplicitly grants permissions. For more information about user permissions, see\n[Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#describe_apps/3","title":"AWS.OpsWorks.describe_apps/3","type":"function"},{"doc":"Describes the results of specified commands.\n\nThis call accepts only one resource-identifying parameter.\n\n**Required Permissions**: To use this action, an IAM user must have a Show,\nDeploy, or Manage permissions level for the stack, or an attached policy that\nexplicitly grants permissions. For more information about user permissions, see\n[Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#describe_commands/3","title":"AWS.OpsWorks.describe_commands/3","type":"function"},{"doc":"Requests a description of a specified set of deployments.\n\nThis call accepts only one resource-identifying parameter.\n\n**Required Permissions**: To use this action, an IAM user must have a Show,\nDeploy, or Manage permissions level for the stack, or an attached policy that\nexplicitly grants permissions. For more information about user permissions, see\n[Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#describe_deployments/3","title":"AWS.OpsWorks.describe_deployments/3","type":"function"},{"doc":"Describes Amazon ECS clusters that are registered with a stack.\n\nIf you specify only a stack ID, you can use the `MaxResults` and `NextToken`\nparameters to paginate the response. However, AWS OpsWorks Stacks currently\nsupports only one cluster per layer, so the result set has a maximum of one\nelement.\n\n**Required Permissions**: To use this action, an IAM user must have a Show,\nDeploy, or Manage permissions level for the stack or an attached policy that\nexplicitly grants permission. For more information about user permissions, see\n[Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).\n\nThis call accepts only one resource-identifying parameter.","ref":"AWS.OpsWorks.html#describe_ecs_clusters/3","title":"AWS.OpsWorks.describe_ecs_clusters/3","type":"function"},{"doc":"Describes [Elastic IP addresses](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/elastic-ip-addresses-eip.html).\n\nThis call accepts only one resource-identifying parameter.\n\n**Required Permissions**: To use this action, an IAM user must have a Show,\nDeploy, or Manage permissions level for the stack, or an attached policy that\nexplicitly grants permissions. For more information about user permissions, see\n[Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#describe_elastic_ips/3","title":"AWS.OpsWorks.describe_elastic_ips/3","type":"function"},{"doc":"Describes a stack's Elastic Load Balancing instances.\n\nThis call accepts only one resource-identifying parameter.\n\n**Required Permissions**: To use this action, an IAM user must have a Show,\nDeploy, or Manage permissions level for the stack, or an attached policy that\nexplicitly grants permissions. For more information about user permissions, see\n[Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#describe_elastic_load_balancers/3","title":"AWS.OpsWorks.describe_elastic_load_balancers/3","type":"function"},{"doc":"Requests a description of a set of instances.\n\nThis call accepts only one resource-identifying parameter.\n\n**Required Permissions**: To use this action, an IAM user must have a Show,\nDeploy, or Manage permissions level for the stack, or an attached policy that\nexplicitly grants permissions. For more information about user permissions, see\n[Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#describe_instances/3","title":"AWS.OpsWorks.describe_instances/3","type":"function"},{"doc":"Requests a description of one or more layers in a specified stack.\n\nThis call accepts only one resource-identifying parameter.\n\n**Required Permissions**: To use this action, an IAM user must have a Show,\nDeploy, or Manage permissions level for the stack, or an attached policy that\nexplicitly grants permissions. For more information about user permissions, see\n[Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#describe_layers/3","title":"AWS.OpsWorks.describe_layers/3","type":"function"},{"doc":"Describes load-based auto scaling configurations for specified layers.\n\nYou must specify at least one of the parameters.\n\n**Required Permissions**: To use this action, an IAM user must have a Show,\nDeploy, or Manage permissions level for the stack, or an attached policy that\nexplicitly grants permissions. For more information about user permissions, see\n[Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#describe_load_based_auto_scaling/3","title":"AWS.OpsWorks.describe_load_based_auto_scaling/3","type":"function"},{"doc":"Describes a user's SSH information.\n\n**Required Permissions**: To use this action, an IAM user must have\nself-management enabled or an attached policy that explicitly grants\npermissions. For more information about user permissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#describe_my_user_profile/3","title":"AWS.OpsWorks.describe_my_user_profile/3","type":"function"},{"doc":"Describes the operating systems that are supported by AWS OpsWorks Stacks.","ref":"AWS.OpsWorks.html#describe_operating_systems/3","title":"AWS.OpsWorks.describe_operating_systems/3","type":"function"},{"doc":"Describes the permissions for a specified stack.\n\n**Required Permissions**: To use this action, an IAM user must have a Manage\npermissions level for the stack, or an attached policy that explicitly grants\npermissions. For more information on user permissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#describe_permissions/3","title":"AWS.OpsWorks.describe_permissions/3","type":"function"},{"doc":"Describe an instance's RAID arrays.\n\nThis call accepts only one resource-identifying parameter.\n\n**Required Permissions**: To use this action, an IAM user must have a Show,\nDeploy, or Manage permissions level for the stack, or an attached policy that\nexplicitly grants permissions. For more information about user permissions, see\n[Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#describe_raid_arrays/3","title":"AWS.OpsWorks.describe_raid_arrays/3","type":"function"},{"doc":"Describes Amazon RDS instances.\n\n**Required Permissions**: To use this action, an IAM user must have a Show,\nDeploy, or Manage permissions level for the stack, or an attached policy that\nexplicitly grants permissions. For more information about user permissions, see\n[Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).\n\nThis call accepts only one resource-identifying parameter.","ref":"AWS.OpsWorks.html#describe_rds_db_instances/3","title":"AWS.OpsWorks.describe_rds_db_instances/3","type":"function"},{"doc":"Describes AWS OpsWorks Stacks service errors.\n\n**Required Permissions**: To use this action, an IAM user must have a Show,\nDeploy, or Manage permissions level for the stack, or an attached policy that\nexplicitly grants permissions. For more information about user permissions, see\n[Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).\n\nThis call accepts only one resource-identifying parameter.","ref":"AWS.OpsWorks.html#describe_service_errors/3","title":"AWS.OpsWorks.describe_service_errors/3","type":"function"},{"doc":"Requests a description of a stack's provisioning parameters.\n\n**Required Permissions**: To use this action, an IAM user must have a Show,\nDeploy, or Manage permissions level for the stack or an attached policy that\nexplicitly grants permissions. For more information about user permissions, see\n[Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#describe_stack_provisioning_parameters/3","title":"AWS.OpsWorks.describe_stack_provisioning_parameters/3","type":"function"},{"doc":"Describes the number of layers and apps in a specified stack, and the number of\ninstances in each state, such as `running_setup` or `online`.\n\n**Required Permissions**: To use this action, an IAM user must have a Show,\nDeploy, or Manage permissions level for the stack, or an attached policy that\nexplicitly grants permissions. For more information about user permissions, see\n[Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#describe_stack_summary/3","title":"AWS.OpsWorks.describe_stack_summary/3","type":"function"},{"doc":"Requests a description of one or more stacks.\n\n**Required Permissions**: To use this action, an IAM user must have a Show,\nDeploy, or Manage permissions level for the stack, or an attached policy that\nexplicitly grants permissions. For more information about user permissions, see\n[Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#describe_stacks/3","title":"AWS.OpsWorks.describe_stacks/3","type":"function"},{"doc":"Describes time-based auto scaling configurations for specified instances.\n\nYou must specify at least one of the parameters.\n\n**Required Permissions**: To use this action, an IAM user must have a Show,\nDeploy, or Manage permissions level for the stack, or an attached policy that\nexplicitly grants permissions. For more information about user permissions, see\n[Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#describe_time_based_auto_scaling/3","title":"AWS.OpsWorks.describe_time_based_auto_scaling/3","type":"function"},{"doc":"Describe specified users.\n\n**Required Permissions**: To use this action, an IAM user must have an attached\npolicy that explicitly grants permissions. For more information about user\npermissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#describe_user_profiles/3","title":"AWS.OpsWorks.describe_user_profiles/3","type":"function"},{"doc":"Describes an instance's Amazon EBS volumes.\n\nThis call accepts only one resource-identifying parameter.\n\n**Required Permissions**: To use this action, an IAM user must have a Show,\nDeploy, or Manage permissions level for the stack, or an attached policy that\nexplicitly grants permissions. For more information about user permissions, see\n[Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#describe_volumes/3","title":"AWS.OpsWorks.describe_volumes/3","type":"function"},{"doc":"Detaches a specified Elastic Load Balancing instance from its layer.\n\n**Required Permissions**: To use this action, an IAM user must have a Manage\npermissions level for the stack, or an attached policy that explicitly grants\npermissions. For more information on user permissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#detach_elastic_load_balancer/3","title":"AWS.OpsWorks.detach_elastic_load_balancer/3","type":"function"},{"doc":"Disassociates an Elastic IP address from its instance.\n\nThe address remains registered with the stack. For more information, see\n[Resource Management](https://docs.aws.amazon.com/opsworks/latest/userguide/resources.html).\n\n**Required Permissions**: To use this action, an IAM user must have a Manage\npermissions level for the stack, or an attached policy that explicitly grants\npermissions. For more information on user permissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#disassociate_elastic_ip/3","title":"AWS.OpsWorks.disassociate_elastic_ip/3","type":"function"},{"doc":"Gets a generated host name for the specified layer, based on the current host\nname theme.\n\n**Required Permissions**: To use this action, an IAM user must have a Manage\npermissions level for the stack, or an attached policy that explicitly grants\npermissions. For more information on user permissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#get_hostname_suggestion/3","title":"AWS.OpsWorks.get_hostname_suggestion/3","type":"function"},{"doc":"This action can be used only with Windows stacks.\n\nGrants RDP access to a Windows instance for a specified time period.","ref":"AWS.OpsWorks.html#grant_access/3","title":"AWS.OpsWorks.grant_access/3","type":"function"},{"doc":"Returns a list of tags that are applied to the specified stack or layer.","ref":"AWS.OpsWorks.html#list_tags/3","title":"AWS.OpsWorks.list_tags/3","type":"function"},{"doc":"","ref":"AWS.OpsWorks.html#metadata/0","title":"AWS.OpsWorks.metadata/0","type":"function"},{"doc":"Reboots a specified instance.\n\nFor more information, see [Starting, Stopping, and Rebooting Instances](https://docs.aws.amazon.com/opsworks/latest/userguide/workinginstances-starting.html).\n\n**Required Permissions**: To use this action, an IAM user must have a Manage\npermissions level for the stack, or an attached policy that explicitly grants\npermissions. For more information on user permissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#reboot_instance/3","title":"AWS.OpsWorks.reboot_instance/3","type":"function"},{"doc":"Registers a specified Amazon ECS cluster with a stack.\n\nYou can register only one cluster with a stack. A cluster can be registered with\nonly one stack. For more information, see [ Resource Management](https://docs.aws.amazon.com/opsworks/latest/userguide/workinglayers-ecscluster.html).\n\n**Required Permissions**: To use this action, an IAM user must have a Manage\npermissions level for the stack or an attached policy that explicitly grants\npermissions. For more information on user permissions, see [ Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#register_ecs_cluster/3","title":"AWS.OpsWorks.register_ecs_cluster/3","type":"function"},{"doc":"Registers an Elastic IP address with a specified stack.\n\nAn address can be registered with only one stack at a time. If the address is\nalready registered, you must first deregister it by calling\n`DeregisterElasticIp`. For more information, see [Resource Management](https://docs.aws.amazon.com/opsworks/latest/userguide/resources.html).\n\n**Required Permissions**: To use this action, an IAM user must have a Manage\npermissions level for the stack, or an attached policy that explicitly grants\npermissions. For more information on user permissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#register_elastic_ip/3","title":"AWS.OpsWorks.register_elastic_ip/3","type":"function"},{"doc":"Registers instances that were created outside of AWS OpsWorks Stacks with a\nspecified stack.\n\nWe do not recommend using this action to register instances. The complete\nregistration operation includes two tasks: installing the AWS OpsWorks Stacks\nagent on the instance, and registering the instance with the stack.\n`RegisterInstance` handles only the second step. You should instead use the AWS\nCLI `register` command, which performs the entire registration operation. For\nmore information, see [ Registering an Instance with an AWS OpsWorks Stacks Stack](https://docs.aws.amazon.com/opsworks/latest/userguide/registered-instances-register.html).\n\nRegistered instances have the same requirements as instances that are created by\nusing the `CreateInstance` API. For example, registered instances must be\nrunning a supported Linux-based operating system, and they must have a supported\ninstance type. For more information about requirements for instances that you\nwant to register, see [ Preparing the Instance](https://docs.aws.amazon.com/opsworks/latest/userguide/registered-instances-register-registering-preparer.html).\n\n**Required Permissions**: To use this action, an IAM user must have a Manage\npermissions level for the stack or an attached policy that explicitly grants\npermissions. For more information on user permissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#register_instance/3","title":"AWS.OpsWorks.register_instance/3","type":"function"},{"doc":"Registers an Amazon RDS instance with a stack.\n\n**Required Permissions**: To use this action, an IAM user must have a Manage\npermissions level for the stack, or an attached policy that explicitly grants\npermissions. For more information on user permissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#register_rds_db_instance/3","title":"AWS.OpsWorks.register_rds_db_instance/3","type":"function"},{"doc":"Registers an Amazon EBS volume with a specified stack.\n\nA volume can be registered with only one stack at a time. If the volume is\nalready registered, you must first deregister it by calling `DeregisterVolume`.\nFor more information, see [Resource Management](https://docs.aws.amazon.com/opsworks/latest/userguide/resources.html).\n\n**Required Permissions**: To use this action, an IAM user must have a Manage\npermissions level for the stack, or an attached policy that explicitly grants\npermissions. For more information on user permissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#register_volume/3","title":"AWS.OpsWorks.register_volume/3","type":"function"},{"doc":"Specify the load-based auto scaling configuration for a specified layer.\n\nFor more information, see [Managing Load with Time-based and Load-based Instances](https://docs.aws.amazon.com/opsworks/latest/userguide/workinginstances-autoscaling.html).\n\nTo use load-based auto scaling, you must create a set of load-based auto scaling\ninstances. Load-based auto scaling operates only on the instances from that set,\nso you must ensure that you have created enough instances to handle the maximum\nanticipated load.\n\n**Required Permissions**: To use this action, an IAM user must have a Manage\npermissions level for the stack, or an attached policy that explicitly grants\npermissions. For more information on user permissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#set_load_based_auto_scaling/3","title":"AWS.OpsWorks.set_load_based_auto_scaling/3","type":"function"},{"doc":"Specifies a user's permissions.\n\nFor more information, see [Security and Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/workingsecurity.html).\n\n**Required Permissions**: To use this action, an IAM user must have a Manage\npermissions level for the stack, or an attached policy that explicitly grants\npermissions. For more information on user permissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#set_permission/3","title":"AWS.OpsWorks.set_permission/3","type":"function"},{"doc":"Specify the time-based auto scaling configuration for a specified instance.\n\nFor more information, see [Managing Load with Time-based and Load-based Instances](https://docs.aws.amazon.com/opsworks/latest/userguide/workinginstances-autoscaling.html).\n\n**Required Permissions**: To use this action, an IAM user must have a Manage\npermissions level for the stack, or an attached policy that explicitly grants\npermissions. For more information on user permissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#set_time_based_auto_scaling/3","title":"AWS.OpsWorks.set_time_based_auto_scaling/3","type":"function"},{"doc":"Starts a specified instance.\n\nFor more information, see [Starting, Stopping, and Rebooting Instances](https://docs.aws.amazon.com/opsworks/latest/userguide/workinginstances-starting.html).\n\n**Required Permissions**: To use this action, an IAM user must have a Manage\npermissions level for the stack, or an attached policy that explicitly grants\npermissions. For more information on user permissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#start_instance/3","title":"AWS.OpsWorks.start_instance/3","type":"function"},{"doc":"Starts a stack's instances.\n\n**Required Permissions**: To use this action, an IAM user must have a Manage\npermissions level for the stack, or an attached policy that explicitly grants\npermissions. For more information on user permissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#start_stack/3","title":"AWS.OpsWorks.start_stack/3","type":"function"},{"doc":"Stops a specified instance.\n\nWhen you stop a standard instance, the data disappears and must be reinstalled\nwhen you restart the instance. You can stop an Amazon EBS-backed instance\nwithout losing data. For more information, see [Starting, Stopping, and Rebooting\nInstances](https://docs.aws.amazon.com/opsworks/latest/userguide/workinginstances-starting.html).\n\n**Required Permissions**: To use this action, an IAM user must have a Manage\npermissions level for the stack, or an attached policy that explicitly grants\npermissions. For more information on user permissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#stop_instance/3","title":"AWS.OpsWorks.stop_instance/3","type":"function"},{"doc":"Stops a specified stack.\n\n**Required Permissions**: To use this action, an IAM user must have a Manage\npermissions level for the stack, or an attached policy that explicitly grants\npermissions. For more information on user permissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#stop_stack/3","title":"AWS.OpsWorks.stop_stack/3","type":"function"},{"doc":"Apply cost-allocation tags to a specified stack or layer in AWS OpsWorks Stacks.\n\nFor more information about how tagging works, see\n[Tags](https://docs.aws.amazon.com/opsworks/latest/userguide/tagging.html) in\nthe AWS OpsWorks User Guide.","ref":"AWS.OpsWorks.html#tag_resource/3","title":"AWS.OpsWorks.tag_resource/3","type":"function"},{"doc":"Unassigns a registered instance from all layers that are using the instance.\n\nThe instance remains in the stack as an unassigned instance, and can be assigned\nto another layer as needed. You cannot use this action with instances that were\ncreated with AWS OpsWorks Stacks.\n\n**Required Permissions**: To use this action, an IAM user must have a Manage\npermissions level for the stack or an attached policy that explicitly grants\npermissions. For more information about user permissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#unassign_instance/3","title":"AWS.OpsWorks.unassign_instance/3","type":"function"},{"doc":"Unassigns an assigned Amazon EBS volume.\n\nThe volume remains registered with the stack. For more information, see\n[Resource Management](https://docs.aws.amazon.com/opsworks/latest/userguide/resources.html).\n\n**Required Permissions**: To use this action, an IAM user must have a Manage\npermissions level for the stack, or an attached policy that explicitly grants\npermissions. For more information on user permissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#unassign_volume/3","title":"AWS.OpsWorks.unassign_volume/3","type":"function"},{"doc":"Removes tags from a specified stack or layer.","ref":"AWS.OpsWorks.html#untag_resource/3","title":"AWS.OpsWorks.untag_resource/3","type":"function"},{"doc":"Updates a specified app.\n\n**Required Permissions**: To use this action, an IAM user must have a Deploy or\nManage permissions level for the stack, or an attached policy that explicitly\ngrants permissions. For more information on user permissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#update_app/3","title":"AWS.OpsWorks.update_app/3","type":"function"},{"doc":"Updates a registered Elastic IP address's name.\n\nFor more information, see [Resource Management](https://docs.aws.amazon.com/opsworks/latest/userguide/resources.html).\n\n**Required Permissions**: To use this action, an IAM user must have a Manage\npermissions level for the stack, or an attached policy that explicitly grants\npermissions. For more information on user permissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#update_elastic_ip/3","title":"AWS.OpsWorks.update_elastic_ip/3","type":"function"},{"doc":"Updates a specified instance.\n\n**Required Permissions**: To use this action, an IAM user must have a Manage\npermissions level for the stack, or an attached policy that explicitly grants\npermissions. For more information on user permissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#update_instance/3","title":"AWS.OpsWorks.update_instance/3","type":"function"},{"doc":"Updates a specified layer.\n\n**Required Permissions**: To use this action, an IAM user must have a Manage\npermissions level for the stack, or an attached policy that explicitly grants\npermissions. For more information on user permissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#update_layer/3","title":"AWS.OpsWorks.update_layer/3","type":"function"},{"doc":"Updates a user's SSH public key.\n\n**Required Permissions**: To use this action, an IAM user must have\nself-management enabled or an attached policy that explicitly grants\npermissions. For more information about user permissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#update_my_user_profile/3","title":"AWS.OpsWorks.update_my_user_profile/3","type":"function"},{"doc":"Updates an Amazon RDS instance.\n\n**Required Permissions**: To use this action, an IAM user must have a Manage\npermissions level for the stack, or an attached policy that explicitly grants\npermissions. For more information on user permissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#update_rds_db_instance/3","title":"AWS.OpsWorks.update_rds_db_instance/3","type":"function"},{"doc":"Updates a specified stack.\n\n**Required Permissions**: To use this action, an IAM user must have a Manage\npermissions level for the stack, or an attached policy that explicitly grants\npermissions. For more information on user permissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#update_stack/3","title":"AWS.OpsWorks.update_stack/3","type":"function"},{"doc":"Updates a specified user profile.\n\n**Required Permissions**: To use this action, an IAM user must have an attached\npolicy that explicitly grants permissions. For more information about user\npermissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#update_user_profile/3","title":"AWS.OpsWorks.update_user_profile/3","type":"function"},{"doc":"Updates an Amazon EBS volume's name or mount point.\n\nFor more information, see [Resource Management](https://docs.aws.amazon.com/opsworks/latest/userguide/resources.html).\n\n**Required Permissions**: To use this action, an IAM user must have a Manage\npermissions level for the stack, or an attached policy that explicitly grants\npermissions. For more information on user permissions, see [Managing User Permissions](https://docs.aws.amazon.com/opsworks/latest/userguide/opsworks-security-users.html).","ref":"AWS.OpsWorks.html#update_volume/3","title":"AWS.OpsWorks.update_volume/3","type":"function"},{"doc":"AWS OpsWorks CM\n\nAWS OpsWorks for configuration management (CM) is a service that runs and\nmanages configuration management servers.\n\nYou can use AWS OpsWorks CM to create and manage AWS OpsWorks for Chef Automate\nand AWS OpsWorks for Puppet Enterprise servers, and add or remove nodes for the\nservers to manage.","ref":"AWS.OpsWorksCM.html","title":"AWS.OpsWorksCM","type":"module"},{"doc":"* **Server**: A configuration management server that can be\nhighly-available. The configuration management server runs on an Amazon Elastic\nCompute Cloud (EC2) instance, and may use various other AWS services, such as\nAmazon Relational Database Service (RDS) and Elastic Load Balancing. A server is\na generic abstraction over the configuration manager that you want to use, much\nlike Amazon RDS. In AWS OpsWorks CM, you do not start or stop servers. After you\ncreate servers, they continue to run until they are deleted.\n\n  * **Engine**: The engine is the specific configuration manager that\nyou want to use. Valid values in this release include `ChefAutomate` and\n`Puppet`.\n\n  * **Backup**: This is an application-level backup of the data that\nthe configuration manager stores. AWS OpsWorks CM creates an S3 bucket for\nbackups when you launch the first server. A backup maintains a snapshot of a\nserver's configuration-related attributes at the time the backup starts.\n\n  * **Events**: Events are always related to a server. Events are\nwritten during server creation, when health checks run, when backups are\ncreated, when system maintenance is performed, etc. When you delete a server,\nthe server's events are also deleted.\n\n  * **Account attributes**: Every account has attributes that are\nassigned in the AWS OpsWorks CM database. These attributes store information\nabout configuration limits (servers, backups, etc.) and your customer account.","ref":"AWS.OpsWorksCM.html#module-glossary-of-terms","title":"Glossary of terms - AWS.OpsWorksCM","type":"module"},{"doc":"AWS OpsWorks CM supports the following endpoints, all HTTPS. You must connect to\none of the following endpoints. Your servers can only be accessed or managed\nwithin the endpoint in which they are created.\n\n  * opsworks-cm.us-east-1.amazonaws.com\n\n  * opsworks-cm.us-east-2.amazonaws.com\n\n  * opsworks-cm.us-west-1.amazonaws.com\n\n  * opsworks-cm.us-west-2.amazonaws.com\n\n  * opsworks-cm.ap-northeast-1.amazonaws.com\n\n  * opsworks-cm.ap-southeast-1.amazonaws.com\n\n  * opsworks-cm.ap-southeast-2.amazonaws.com\n\n  * opsworks-cm.eu-central-1.amazonaws.com\n\n  * opsworks-cm.eu-west-1.amazonaws.com\n\nFor more information, see [AWS OpsWorks endpoints and quotas](https://docs.aws.amazon.com/general/latest/gr/opsworks-service.html) in\nthe AWS General Reference.","ref":"AWS.OpsWorksCM.html#module-endpoints","title":"Endpoints - AWS.OpsWorksCM","type":"module"},{"doc":"All API operations allow for five requests per second with a burst of 10\nrequests per second.","ref":"AWS.OpsWorksCM.html#module-throttling-limits","title":"Throttling limits - AWS.OpsWorksCM","type":"module"},{"doc":"Associates a new node with the server.\n\nFor more information about how to disassociate a node, see `DisassociateNode`.\n\nOn a Chef server: This command is an alternative to `knife bootstrap`.\n\nExample (Chef): `aws opsworks-cm associate-node --server-name *MyServer*\n--node-name *MyManagedNode* --engine-attributes\n\"Name=*CHEF_ORGANIZATION*,Value=default\"\n\"Name=*CHEF_NODE_PUBLIC_KEY*,Value=*public-key-pem*\"`\n\nOn a Puppet server, this command is an alternative to the `puppet cert sign`\ncommand that signs a Puppet node CSR.\n\nExample (Puppet): `aws opsworks-cm associate-node --server-name *MyServer*\n--node-name *MyManagedNode* --engine-attributes\n\"Name=*PUPPET_NODE_CSR*,Value=*csr-pem*\"`\n\nA node can can only be associated with servers that are in a `HEALTHY` state.\nOtherwise, an `InvalidStateException` is thrown. A `ResourceNotFoundException`\nis thrown when the server does not exist. A `ValidationException` is raised when\nparameters of the request are not valid. The AssociateNode API call can be\nintegrated into Auto Scaling configurations, AWS Cloudformation templates, or\nthe user data of a server's instance.","ref":"AWS.OpsWorksCM.html#associate_node/3","title":"AWS.OpsWorksCM.associate_node/3","type":"function"},{"doc":"Creates an application-level backup of a server.\n\nWhile the server is in the `BACKING_UP` state, the server cannot be changed, and\nno additional backup can be created.\n\nBackups can be created for servers in `RUNNING`, `HEALTHY`, and `UNHEALTHY`\nstates. By default, you can create a maximum of 50 manual backups.\n\nThis operation is asynchronous.\n\nA `LimitExceededException` is thrown when the maximum number of manual backups\nis reached. An `InvalidStateException` is thrown when the server is not in any\nof the following states: RUNNING, HEALTHY, or UNHEALTHY. A\n`ResourceNotFoundException` is thrown when the server is not found. A\n`ValidationException` is thrown when parameters of the request are not valid.","ref":"AWS.OpsWorksCM.html#create_backup/3","title":"AWS.OpsWorksCM.create_backup/3","type":"function"},{"doc":"Creates and immedately starts a new server.\n\nThe server is ready to use when it is in the `HEALTHY` state. By default, you\ncan create a maximum of 10 servers.\n\nThis operation is asynchronous.\n\nA `LimitExceededException` is thrown when you have created the maximum number of\nservers (10). A `ResourceAlreadyExistsException` is thrown when a server with\nthe same name already exists in the account. A `ResourceNotFoundException` is\nthrown when you specify a backup ID that is not valid or is for a backup that\ndoes not exist. A `ValidationException` is thrown when parameters of the request\nare not valid.\n\nIf you do not specify a security group by adding the `SecurityGroupIds`\nparameter, AWS OpsWorks creates a new security group.\n\n*Chef Automate:* The default security group opens the Chef server to the world\non TCP port 443. If a KeyName is present, AWS OpsWorks enables SSH access. SSH\nis also open to the world on TCP port 22.\n\n*Puppet Enterprise:* The default security group opens TCP ports 22, 443, 4433,\n8140, 8142, 8143, and 8170. If a KeyName is present, AWS OpsWorks enables SSH\naccess. SSH is also open to the world on TCP port 22.\n\nBy default, your server is accessible from any IP address. We recommend that you\nupdate your security group rules to allow access from known IP addresses and\naddress ranges only. To edit security group rules, open Security Groups in the\nnavigation pane of the EC2 management console.\n\nTo specify your own domain for a server, and provide your own self-signed or\nCA-signed certificate and private key, specify values for `CustomDomain`,\n`CustomCertificate`, and `CustomPrivateKey`.","ref":"AWS.OpsWorksCM.html#create_server/3","title":"AWS.OpsWorksCM.create_server/3","type":"function"},{"doc":"Deletes a backup.\n\nYou can delete both manual and automated backups. This operation is\nasynchronous.\n\nAn `InvalidStateException` is thrown when a backup deletion is already in\nprogress. A `ResourceNotFoundException` is thrown when the backup does not\nexist. A `ValidationException` is thrown when parameters of the request are not\nvalid.","ref":"AWS.OpsWorksCM.html#delete_backup/3","title":"AWS.OpsWorksCM.delete_backup/3","type":"function"},{"doc":"Deletes the server and the underlying AWS CloudFormation stacks (including the\nserver's EC2 instance).\n\nWhen you run this command, the server state is updated to `DELETING`. After the\nserver is deleted, it is no longer returned by `DescribeServer` requests. If the\nAWS CloudFormation stack cannot be deleted, the server cannot be deleted.\n\nThis operation is asynchronous.\n\nAn `InvalidStateException` is thrown when a server deletion is already in\nprogress. A `ResourceNotFoundException` is thrown when the server does not\nexist. A `ValidationException` is raised when parameters of the request are not\nvalid.","ref":"AWS.OpsWorksCM.html#delete_server/3","title":"AWS.OpsWorksCM.delete_server/3","type":"function"},{"doc":"Describes your OpsWorks-CM account attributes.\n\nThis operation is synchronous.","ref":"AWS.OpsWorksCM.html#describe_account_attributes/3","title":"AWS.OpsWorksCM.describe_account_attributes/3","type":"function"},{"doc":"Describes backups.\n\nThe results are ordered by time, with newest backups first. If you do not\nspecify a BackupId or ServerName, the command returns all backups.\n\nThis operation is synchronous.\n\nA `ResourceNotFoundException` is thrown when the backup does not exist. A\n`ValidationException` is raised when parameters of the request are not valid.","ref":"AWS.OpsWorksCM.html#describe_backups/3","title":"AWS.OpsWorksCM.describe_backups/3","type":"function"},{"doc":"Describes events for a specified server.\n\nResults are ordered by time, with newest events first.\n\nThis operation is synchronous.\n\nA `ResourceNotFoundException` is thrown when the server does not exist. A\n`ValidationException` is raised when parameters of the request are not valid.","ref":"AWS.OpsWorksCM.html#describe_events/3","title":"AWS.OpsWorksCM.describe_events/3","type":"function"},{"doc":"Returns the current status of an existing association or disassociation request.\n\nA `ResourceNotFoundException` is thrown when no recent association or\ndisassociation request with the specified token is found, or when the server\ndoes not exist. A `ValidationException` is raised when parameters of the request\nare not valid.","ref":"AWS.OpsWorksCM.html#describe_node_association_status/3","title":"AWS.OpsWorksCM.describe_node_association_status/3","type":"function"},{"doc":"Lists all configuration management servers that are identified with your\naccount.\n\nOnly the stored results from Amazon DynamoDB are returned. AWS OpsWorks CM does\nnot query other services.\n\nThis operation is synchronous.\n\nA `ResourceNotFoundException` is thrown when the server does not exist. A\n`ValidationException` is raised when parameters of the request are not valid.","ref":"AWS.OpsWorksCM.html#describe_servers/3","title":"AWS.OpsWorksCM.describe_servers/3","type":"function"},{"doc":"Disassociates a node from an AWS OpsWorks CM server, and removes the node from\nthe server's managed nodes.\n\nAfter a node is disassociated, the node key pair is no longer valid for\naccessing the configuration manager's API. For more information about how to\nassociate a node, see `AssociateNode`.\n\nA node can can only be disassociated from a server that is in a `HEALTHY` state.\nOtherwise, an `InvalidStateException` is thrown. A `ResourceNotFoundException`\nis thrown when the server does not exist. A `ValidationException` is raised when\nparameters of the request are not valid.","ref":"AWS.OpsWorksCM.html#disassociate_node/3","title":"AWS.OpsWorksCM.disassociate_node/3","type":"function"},{"doc":"Exports a specified server engine attribute as a base64-encoded string.\n\nFor example, you can export user data that you can use in EC2 to associate nodes\nwith a server.\n\nThis operation is synchronous.\n\nA `ValidationException` is raised when parameters of the request are not valid.\nA `ResourceNotFoundException` is thrown when the server does not exist. An\n`InvalidStateException` is thrown when the server is in any of the following\nstates: CREATING, TERMINATED, FAILED or DELETING.","ref":"AWS.OpsWorksCM.html#export_server_engine_attribute/3","title":"AWS.OpsWorksCM.export_server_engine_attribute/3","type":"function"},{"doc":"Returns a list of tags that are applied to the specified AWS OpsWorks for Chef\nAutomate or AWS OpsWorks for Puppet Enterprise servers or backups.","ref":"AWS.OpsWorksCM.html#list_tags_for_resource/3","title":"AWS.OpsWorksCM.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.OpsWorksCM.html#metadata/0","title":"AWS.OpsWorksCM.metadata/0","type":"function"},{"doc":"Restores a backup to a server that is in a `CONNECTION_LOST`, `HEALTHY`,\n`RUNNING`, `UNHEALTHY`, or `TERMINATED` state.\n\nWhen you run RestoreServer, the server's EC2 instance is deleted, and a new EC2\ninstance is configured. RestoreServer maintains the existing server endpoint, so\nconfiguration management of the server's client devices (nodes) should continue\nto work.\n\nRestoring from a backup is performed by creating a new EC2 instance. If\nrestoration is successful, and the server is in a `HEALTHY` state, AWS OpsWorks\nCM switches traffic over to the new instance. After restoration is finished, the\nold EC2 instance is maintained in a `Running` or `Stopped` state, but is\neventually terminated.\n\nThis operation is asynchronous.\n\nAn `InvalidStateException` is thrown when the server is not in a valid state. A\n`ResourceNotFoundException` is thrown when the server does not exist. A\n`ValidationException` is raised when parameters of the request are not valid.","ref":"AWS.OpsWorksCM.html#restore_server/3","title":"AWS.OpsWorksCM.restore_server/3","type":"function"},{"doc":"Manually starts server maintenance.\n\nThis command can be useful if an earlier maintenance attempt failed, and the\nunderlying cause of maintenance failure has been resolved. The server is in an\n`UNDER_MAINTENANCE` state while maintenance is in progress.\n\nMaintenance can only be started on servers in `HEALTHY` and `UNHEALTHY` states.\nOtherwise, an `InvalidStateException` is thrown. A `ResourceNotFoundException`\nis thrown when the server does not exist. A `ValidationException` is raised when\nparameters of the request are not valid.","ref":"AWS.OpsWorksCM.html#start_maintenance/3","title":"AWS.OpsWorksCM.start_maintenance/3","type":"function"},{"doc":"Applies tags to an AWS OpsWorks for Chef Automate or AWS OpsWorks for Puppet\nEnterprise server, or to server backups.","ref":"AWS.OpsWorksCM.html#tag_resource/3","title":"AWS.OpsWorksCM.tag_resource/3","type":"function"},{"doc":"Removes specified tags from an AWS OpsWorks-CM server or backup.","ref":"AWS.OpsWorksCM.html#untag_resource/3","title":"AWS.OpsWorksCM.untag_resource/3","type":"function"},{"doc":"Updates settings for a server.\n\nThis operation is synchronous.","ref":"AWS.OpsWorksCM.html#update_server/3","title":"AWS.OpsWorksCM.update_server/3","type":"function"},{"doc":"Updates engine-specific attributes on a specified server.\n\nThe server enters the `MODIFYING` state when this operation is in progress. Only\none update can occur at a time. You can use this command to reset a Chef\nserver's public key (`CHEF_PIVOTAL_KEY`) or a Puppet server's admin password\n(`PUPPET_ADMIN_PASSWORD`).\n\nThis operation is asynchronous.\n\nThis operation can only be called for servers in `HEALTHY` or `UNHEALTHY`\nstates. Otherwise, an `InvalidStateException` is raised. A\n`ResourceNotFoundException` is thrown when the server does not exist. A\n`ValidationException` is raised when parameters of the request are not valid.","ref":"AWS.OpsWorksCM.html#update_server_engine_attributes/3","title":"AWS.OpsWorksCM.update_server_engine_attributes/3","type":"function"},{"doc":"Organizations is a web service that enables you to consolidate your multiple\nAmazon Web Services accounts into an *organization* and centrally manage your\naccounts and their resources.\n\nThis guide provides descriptions of the Organizations operations. For more\ninformation about using this service, see the [Organizations User Guide](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_introduction.html).","ref":"AWS.Organizations.html","title":"AWS.Organizations","type":"module"},{"doc":"We welcome your feedback. Send your comments to\n[feedback-awsorganizations@amazon.com](mailto:feedback-awsorganizations@amazon.com) or post your feedback and questions in the [Organizations support\nforum](http://forums.aws.amazon.com/forum.jspa?forumID=219). For more\ninformation about the Amazon Web Services support forums, see [Forums Help](http://forums.aws.amazon.com/help.jspa).","ref":"AWS.Organizations.html#module-support-and-feedback-for-organizations","title":"Support and feedback for Organizations - AWS.Organizations","type":"module"},{"doc":"For the current release of Organizations, specify the `us-east-1` region for all\nAmazon Web Services API and CLI calls made from the commercial Amazon Web\nServices Regions outside of China. If calling from one of the Amazon Web\nServices Regions in China, then specify `cn-northwest-1`. You can do this in the\nCLI by using these parameters and commands:\n\n  * Use the following parameter with each command to specify both the\nendpoint and its region:\n\n`--endpoint-url https://organizations.us-east-1.amazonaws.com` *(from commercial\nAmazon Web Services Regions outside of China)*\n\nor\n\n`--endpoint-url https://organizations.cn-northwest-1.amazonaws.com.cn` *(from\nAmazon Web Services Regions in China)*\n\n  * Use the default endpoint, but configure your default region with\nthis command:\n\n`aws configure set default.region us-east-1` *(from commercial Amazon Web\nServices Regions outside of China)*\n\nor\n\n`aws configure set default.region cn-northwest-1` *(from Amazon Web Services\nRegions in China)*\n\n  * Use the following parameter with each command to specify the\nendpoint:\n\n`--region us-east-1` *(from commercial Amazon Web Services Regions outside of\nChina)*\n\nor\n\n`--region cn-northwest-1` *(from Amazon Web Services Regions in China)*","ref":"AWS.Organizations.html#module-endpoint-to-call-when-using-the-cli-or-the-amazon-web-services-sdk","title":"Endpoint to call When using the CLI or the Amazon Web Services SDK - AWS.Organizations","type":"module"},{"doc":"Organizations supports CloudTrail, a service that records Amazon Web Services\nAPI calls for your Amazon Web Services account and delivers log files to an\nAmazon S3 bucket. By using information collected by CloudTrail, you can\ndetermine which requests the Organizations service received, who made the\nrequest and when, and so on. For more about Organizations and its support for\nCloudTrail, see [Logging Organizations API calls with CloudTrail](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_incident-response.html#orgs_cloudtrail-integration)\nin the *Organizations User Guide*. To learn more about CloudTrail, including how\nto turn it on and find your log files, see the [CloudTrail User Guide](https://docs.aws.amazon.com/awscloudtrail/latest/userguide/what_is_cloud_trail_top_level.html).","ref":"AWS.Organizations.html#module-recording-api-requests","title":"Recording API Requests - AWS.Organizations","type":"module"},{"doc":"Sends a response to the originator of a handshake agreeing to the action\nproposed by the handshake request.\n\nYou can only call this operation by the following principals when they also have\nthe relevant IAM permissions:\n\n  * **Invitation to join** or","ref":"AWS.Organizations.html#accept_handshake/3","title":"AWS.Organizations.accept_handshake/3","type":"function"},{"doc":"handshakes: only a principal from the member account.\n\nThe user who calls the API for an invitation to join must have the\n`organizations:AcceptHandshake` permission. If you enabled all features in the\norganization, the user must also have the `iam:CreateServiceLinkedRole`\npermission so that Organizations can create the required service-linked role\nnamed `AWSServiceRoleForOrganizations`. For more information, see [Organizations and service-linked\nroles](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_integration_services.html#orgs_integrate_services-using_slrs)\nin the *Organizations User Guide*.\n\n  * **Enable all features final confirmation** handshake: only a\nprincipal from the management account.\n\nFor more information about invitations, see [Inviting an Amazon Web Services account to join your\norganization](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_accounts_invites.html)\nin the *Organizations User Guide*. For more information about requests to enable\nall features in the organization, see [Enabling all features in your organization](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_org_support-all-features.html)\nin the *Organizations User Guide*.\n\nAfter you accept a handshake, it continues to appear in the results of relevant\nAPIs for only 30 days. After that, it's deleted.","ref":"AWS.Organizations.html#accept_handshake/3-approve-all-features-request","title":"Approve all features request - AWS.Organizations.accept_handshake/3","type":"function"},{"doc":"Attaches a policy to a root, an organizational unit (OU), or an individual\naccount.\n\nHow the policy affects accounts depends on the type of policy. Refer to the\n*Organizations User Guide* for information about each policy type:\n\n  *\n[AISERVICES_OPT_OUT_POLICY](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_policies_ai-opt-out.html)     *\n[BACKUP_POLICY](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_policies_backup.html)\n\n  *\n[SERVICE_CONTROL_POLICY](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_policies_scp.html)     *\n[TAG_POLICY](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_policies_tag-policies.html)\n\nThis operation can be called only from the organization's management account or\nby a member account that is a delegated administrator for an Amazon Web Services\nservice.","ref":"AWS.Organizations.html#attach_policy/3","title":"AWS.Organizations.attach_policy/3","type":"function"},{"doc":"Cancels a handshake.\n\nCanceling a handshake sets the handshake state to `CANCELED`.\n\nThis operation can be called only from the account that originated the\nhandshake. The recipient of the handshake can't cancel it, but can use\n`DeclineHandshake` instead. After a handshake is canceled, the recipient can no\nlonger respond to that handshake.\n\nAfter you cancel a handshake, it continues to appear in the results of relevant\nAPIs for only 30 days. After that, it's deleted.","ref":"AWS.Organizations.html#cancel_handshake/3","title":"AWS.Organizations.cancel_handshake/3","type":"function"},{"doc":"Closes an Amazon Web Services member account within an organization.\n\nYou can close an account when [all features are enabled\n](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_org_support-all-features.html).\nYou can't close the management account with this API. This is an asynchronous\nrequest that Amazon Web Services performs in the background. Because\n`CloseAccount` operates asynchronously, it can return a successful completion\nmessage even though account closure might still be in progress. You need to wait\na few minutes before the account is fully closed. To check the status of the\nrequest, do one of the following:\n\n  * Use the `AccountId` that you sent in the `CloseAccount` request to\nprovide as a parameter to the `DescribeAccount` operation.\n\nWhile the close account request is in progress, Account status will indicate\nPENDING_CLOSURE. When the close account request completes, the status will\nchange to SUSPENDED.\n\n  * Check the CloudTrail log for the `CloseAccountResult` event that\ngets published after the account closes successfully. For information on using\nCloudTrail with Organizations, see [Logging and monitoring in Organizations](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_security_incident-response.html#orgs_cloudtrail-integration)\nin the *Organizations User Guide*.\n\n   You can close only 10% of member accounts, between 10 and 1000,\nwithin a rolling 30 day period. This quota is not bound by a calendar month, but\nstarts when you close an account. After you reach this limit, you can close\nadditional accounts. For more information, see [Closing a member account in your organization](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_accounts_close.html)\nand [Quotas for Organizations](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_reference_limits.html)in\nthe *Organizations User Guide*.\n\n   To reinstate a closed account, contact Amazon Web Services Support\nwithin the 90-day grace period while the account is in SUSPENDED status.\n\n   If the Amazon Web Services account you attempt to close is linked\nto an Amazon Web Services GovCloud (US) account, the `CloseAccount` request will\nclose both accounts. To learn important pre-closure details, see [ Closing an Amazon Web Services GovCloud (US)\naccount](https://docs.aws.amazon.com/govcloud-us/latest/UserGuide/Closing-govcloud-account.html)\nin the * Amazon Web Services GovCloud User Guide*.","ref":"AWS.Organizations.html#close_account/3","title":"AWS.Organizations.close_account/3","type":"function"},{"doc":"Creates an Amazon Web Services account that is automatically a member of the\norganization whose credentials made the request.\n\nThis is an asynchronous request that Amazon Web Services performs in the\nbackground. Because `CreateAccount` operates asynchronously, it can return a\nsuccessful completion message even though account initialization might still be\nin progress. You might need to wait a few minutes before you can successfully\naccess the account. To check the status of the request, do one of the following:\n\n  * Use the `Id` value of the `CreateAccountStatus` response element\nfrom this operation to provide as a parameter to the\n`DescribeCreateAccountStatus` operation.\n\n  * Check the CloudTrail log for the `CreateAccountResult` event. For\ninformation on using CloudTrail with Organizations, see [Logging and monitoring in\nOrganizations](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_security_incident-response.html#orgs_cloudtrail-integration)\nin the *Organizations User Guide*.\n\nThe user who calls the API to create an account must have the\n`organizations:CreateAccount` permission. If you enabled all features in the\norganization, Organizations creates the required service-linked role named\n`AWSServiceRoleForOrganizations`. For more information, see [Organizations and service-linked\nroles](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_integrate_services.html#orgs_integrate_services-using_slrs)\nin the *Organizations User Guide*.\n\nIf the request includes tags, then the requester must have the\n`organizations:TagResource` permission.\n\nOrganizations preconfigures the new member account with a role (named\n`OrganizationAccountAccessRole` by default) that grants users in the management\naccount administrator permissions in the new member account. Principals in the\nmanagement account can assume the role. Organizations clones the company name\nand address information for the new account from the organization's management\naccount.\n\nThis operation can be called only from the organization's management account.\n\nFor more information about creating accounts, see [Creating a member account in your\norganization](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_accounts_create.html)\nin the *Organizations User Guide*.\n\n   When you create an account in an organization using the\nOrganizations console, API, or CLI commands, the information required for the\naccount to operate as a standalone account, such as a payment method and signing\nthe end user license agreement (EULA) is *not* automatically collected. If you\nmust remove an account from your organization later, you can do so only after\nyou provide the missing information. For more information, see [Considerations before removing an account from an\norganization](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_account-before-remove.html)\nin the *Organizations User Guide*.\n\n   If you get an exception that indicates that you exceeded your\naccount limits for the organization, contact [Amazon Web Services Support](https://console.aws.amazon.com/support/home#/).\n\n   If you get an exception that indicates that the operation failed\nbecause your organization is still initializing, wait one hour and then try\nagain. If the error persists, contact [Amazon Web Services Support](https://console.aws.amazon.com/support/home#/).\n\n   Using `CreateAccount` to create multiple temporary accounts isn't\nrecommended. You can only close an account from the Billing and Cost Management\nconsole, and you must be signed in as the root user. For information on the\nrequirements and process for closing an account, see [Closing a member account in your\norganization](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_accounts_close.html)\nin the *Organizations User Guide*.\n\nWhen you create a member account with this operation, you can choose whether to\ncreate the account with the","ref":"AWS.Organizations.html#create_account/3","title":"AWS.Organizations.create_account/3","type":"function"},{"doc":"switch enabled. If you enable it, IAM users and roles that have appropriate\npermissions can view billing information for the account. If you disable it,\nonly the account root user can access billing information. For information about\nhow to disable this switch for an account, see [Granting access to your billing information and\ntools](https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/control-access-billing.html#grantaccess).","ref":"AWS.Organizations.html#create_account/3-iam-user-and-role-access-to-billing-information","title":"IAM User and Role Access to Billing Information - AWS.Organizations.create_account/3","type":"function"},{"doc":"This action is available if all of the following are true:\n\n  * You're authorized to create accounts in the Amazon Web Services\nGovCloud (US) Region.\n\nFor more information on the Amazon Web Services GovCloud (US) Region, see the [\n*Amazon Web Services GovCloud User\nGuide*.](https://docs.aws.amazon.com/govcloud-us/latest/UserGuide/welcome.html)\n\n  * You already have an account in the Amazon Web Services GovCloud\n(US) Region that is paired with a management account of an organization in the\ncommercial Region.\n\n  * You call this action from the management account of your\norganization in the commercial Region.\n\n  * You have the `organizations:CreateGovCloudAccount` permission.\n\nOrganizations automatically creates the required service-linked role named\n`AWSServiceRoleForOrganizations`. For more information, see [Organizations and service-linked\nroles](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_integrate_services.html#orgs_integrate_services-using_slrs)\nin the *Organizations User Guide*.\n\nAmazon Web Services automatically enables CloudTrail for Amazon Web Services\nGovCloud (US) accounts, but you should also do the following:\n\n  * Verify that CloudTrail is enabled to store logs.\n\n  * Create an Amazon S3 bucket for CloudTrail log storage.\n\nFor more information, see [Verifying CloudTrail Is Enabled](https://docs.aws.amazon.com/govcloud-us/latest/UserGuide/verifying-cloudtrail.html)\nin the *Amazon Web Services GovCloud User Guide*.\n\nIf the request includes tags, then the requester must have the\n`organizations:TagResource` permission. The tags are attached to the commercial\naccount associated with the GovCloud account, rather than the GovCloud account\nitself. To add tags to the GovCloud account, call the `TagResource` operation in\nthe GovCloud Region after the new GovCloud account exists.\n\nYou call this action from the management account of your organization in the\ncommercial Region to create a standalone Amazon Web Services account in the\nAmazon Web Services GovCloud (US) Region. After the account is created, the\nmanagement account of an organization in the Amazon Web Services GovCloud (US)\nRegion can invite it to that organization. For more information on inviting\nstandalone accounts in the Amazon Web Services GovCloud (US) to join an\norganization, see\n[Organizations](https://docs.aws.amazon.com/govcloud-us/latest/UserGuide/govcloud-organizations.html) in the *Amazon Web Services GovCloud User Guide*.\n\nCalling `CreateGovCloudAccount` is an asynchronous request that Amazon Web\nServices performs in the background. Because `CreateGovCloudAccount` operates\nasynchronously, it can return a successful completion message even though\naccount initialization might still be in progress. You might need to wait a few\nminutes before you can successfully access the account. To check the status of\nthe request, do one of the following:\n\n  * Use the `OperationId` response element from this operation to\nprovide as a parameter to the `DescribeCreateAccountStatus` operation.\n\n  * Check the CloudTrail log for the `CreateAccountResult` event. For\ninformation on using CloudTrail with Organizations, see [Logging and monitoring\nin\nOrganizations](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_security_incident-response.html)\nin the *Organizations User Guide*.\n\nWhen you call the `CreateGovCloudAccount` action, you create two accounts: a\nstandalone account in the Amazon Web Services GovCloud (US) Region and an\nassociated account in the commercial Region for billing and support purposes.\nThe account in the commercial Region is automatically a member of the\norganization whose credentials made the request. Both accounts are associated\nwith the same email address.\n\nA role is created in the new account in the commercial Region that allows the\nmanagement account in the organization in the commercial Region to assume it. An\nAmazon Web Services GovCloud (US) account is then created and associated with\nthe commercial account that you just created. A role is also created in the new\nAmazon Web Services GovCloud (US) account that can be assumed by the Amazon Web\nServices GovCloud (US) account that is associated with the management account of\nthe commercial organization. For more information and to view a diagram that\nexplains how account access works, see\n[Organizations](https://docs.aws.amazon.com/govcloud-us/latest/UserGuide/govcloud-organizations.html) in the *Amazon Web Services GovCloud User Guide*.\n\nFor more information about creating accounts, see [Creating a member account in\nyour\norganization](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_accounts_create.html)\nin the *Organizations User Guide*.\n\n   When you create an account in an organization using the\nOrganizations console, API, or CLI commands, the information required for the\naccount to operate as a standalone account is *not* automatically collected.\nThis includes a payment method and signing the end user license agreement\n(EULA). If you must remove an account from your organization later, you can do\nso only after you provide the missing information. For more information, see\n[Considerations before removing an account from an organization](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_account-before-remove.html)\nin the *Organizations User Guide*.\n\n   If you get an exception that indicates that you exceeded your\naccount limits for the organization, contact [Amazon Web Services Support](https://console.aws.amazon.com/support/home#/).\n\n   If you get an exception that indicates that the operation failed\nbecause your organization is still initializing, wait one hour and then try\nagain. If the error persists, contact [Amazon Web Services Support](https://console.aws.amazon.com/support/home#/).\n\n   Using `CreateGovCloudAccount` to create multiple temporary accounts\nisn't recommended. You can only close an account from the Amazon Web Services\nBilling and Cost Management console, and you must be signed in as the root user.\nFor information on the requirements and process for closing an account, see\n[Closing a member account in your organization](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_accounts_close.html)\nin the *Organizations User Guide*.\n\nWhen you create a member account with this operation, you can choose whether to\ncreate the account with the","ref":"AWS.Organizations.html#create_gov_cloud_account/3","title":"AWS.Organizations.create_gov_cloud_account/3","type":"function"},{"doc":"switch enabled. If you enable it, IAM users and roles that have appropriate\npermissions can view billing information for the account. If you disable it,\nonly the account root user can access billing information. For information about\nhow to disable this switch for an account, see [Granting access to your billing information and\ntools](https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/grantaccess.html).","ref":"AWS.Organizations.html#create_gov_cloud_account/3-iam-user-and-role-access-to-billing-information","title":"IAM User and Role Access to Billing Information - AWS.Organizations.create_gov_cloud_account/3","type":"function"},{"doc":"Creates an Amazon Web Services organization.\n\nThe account whose user is calling the `CreateOrganization` operation\nautomatically becomes the [management account](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_getting-started_concepts.html#account)\nof the new organization.\n\nThis operation must be called using credentials from the account that is to\nbecome the new organization's management account. The principal must also have\nthe relevant IAM permissions.\n\nBy default (or if you set the `FeatureSet` parameter to `ALL`), the new\norganization is created with all features enabled and service control policies\nautomatically enabled in the root. If you instead choose to create the\norganization supporting only the consolidated billing features by setting the\n`FeatureSet` parameter to `CONSOLIDATED_BILLING`, no policy types are enabled by\ndefault and you can't use organization policies.","ref":"AWS.Organizations.html#create_organization/3","title":"AWS.Organizations.create_organization/3","type":"function"},{"doc":"Creates an organizational unit (OU) within a root or parent OU.\n\nAn OU is a container for accounts that enables you to organize your accounts to\napply policies according to your business requirements. The number of levels\ndeep that you can nest OUs is dependent upon the policy types enabled for that\nroot. For service control policies, the limit is five.\n\nFor more information about OUs, see [Managing organizational units (OUs)](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_ous.html)\nin the *Organizations User Guide*.\n\nIf the request includes tags, then the requester must have the\n`organizations:TagResource` permission.\n\nThis operation can be called only from the organization's management account.","ref":"AWS.Organizations.html#create_organizational_unit/3","title":"AWS.Organizations.create_organizational_unit/3","type":"function"},{"doc":"Creates a policy of a specified type that you can attach to a root, an\norganizational unit (OU), or an individual Amazon Web Services account.\n\nFor more information about policies and their use, see [Managing Organizations policies](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_policies.html).\n\nIf the request includes tags, then the requester must have the\n`organizations:TagResource` permission.\n\nThis operation can be called only from the organization's management account or\nby a member account that is a delegated administrator for an Amazon Web Services\nservice.","ref":"AWS.Organizations.html#create_policy/3","title":"AWS.Organizations.create_policy/3","type":"function"},{"doc":"Declines a handshake request.\n\nThis sets the handshake state to `DECLINED` and effectively deactivates the\nrequest.\n\nThis operation can be called only from the account that received the handshake.\nThe originator of the handshake can use `CancelHandshake` instead. The\noriginator can't reactivate a declined request, but can reinitiate the process\nwith a new handshake request.\n\nAfter you decline a handshake, it continues to appear in the results of relevant\nAPIs for only 30 days. After that, it's deleted.","ref":"AWS.Organizations.html#decline_handshake/3","title":"AWS.Organizations.decline_handshake/3","type":"function"},{"doc":"Deletes the organization.\n\nYou can delete an organization only by using credentials from the management\naccount. The organization must be empty of member accounts.","ref":"AWS.Organizations.html#delete_organization/3","title":"AWS.Organizations.delete_organization/3","type":"function"},{"doc":"Deletes an organizational unit (OU) from a root or another OU.\n\nYou must first remove all accounts and child OUs from the OU that you want to\ndelete.\n\nThis operation can be called only from the organization's management account.","ref":"AWS.Organizations.html#delete_organizational_unit/3","title":"AWS.Organizations.delete_organizational_unit/3","type":"function"},{"doc":"Deletes the specified policy from your organization.\n\nBefore you perform this operation, you must first detach the policy from all\norganizational units (OUs), roots, and accounts.\n\nThis operation can be called only from the organization's management account or\nby a member account that is a delegated administrator for an Amazon Web Services\nservice.","ref":"AWS.Organizations.html#delete_policy/3","title":"AWS.Organizations.delete_policy/3","type":"function"},{"doc":"Deletes the resource policy from your organization.\n\nYou can only call this operation from the organization's management account.","ref":"AWS.Organizations.html#delete_resource_policy/3","title":"AWS.Organizations.delete_resource_policy/3","type":"function"},{"doc":"Removes the specified member Amazon Web Services account as a delegated\nadministrator for the specified Amazon Web Services service.\n\nDeregistering a delegated administrator can have unintended impacts on the\nfunctionality of the enabled Amazon Web Services service. See the documentation\nfor the enabled service before you deregister a delegated administrator so that\nyou understand any potential impacts.\n\nYou can run this action only for Amazon Web Services services that support this\nfeature. For a current list of services that support it, see the column\n*Supports Delegated Administrator* in the table at [Amazon Web Services Services that you can use with\nOrganizations](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_integrate_services_list.html)\nin the *Organizations User Guide.*\n\nThis operation can be called only from the organization's management account.","ref":"AWS.Organizations.html#deregister_delegated_administrator/3","title":"AWS.Organizations.deregister_delegated_administrator/3","type":"function"},{"doc":"Retrieves Organizations-related information about the specified account.\n\nThis operation can be called only from the organization's management account or\nby a member account that is a delegated administrator for an Amazon Web Services\nservice.","ref":"AWS.Organizations.html#describe_account/3","title":"AWS.Organizations.describe_account/3","type":"function"},{"doc":"Retrieves the current status of an asynchronous request to create an account.\n\nThis operation can be called only from the organization's management account or\nby a member account that is a delegated administrator for an Amazon Web Services\nservice.","ref":"AWS.Organizations.html#describe_create_account_status/3","title":"AWS.Organizations.describe_create_account_status/3","type":"function"},{"doc":"Returns the contents of the effective policy for specified policy type and\naccount.\n\nThe effective policy is the aggregation of any policies of the specified type\nthat the account inherits, plus any policy of that type that is directly\nattached to the account.\n\nThis operation applies only to policy types *other* than service control\npolicies (SCPs).\n\nFor more information about policy inheritance, see [Understanding management policy\ninheritance](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_policies_inheritance_mgmt.html)\nin the *Organizations User Guide*.\n\nThis operation can be called from any account in the organization.","ref":"AWS.Organizations.html#describe_effective_policy/3","title":"AWS.Organizations.describe_effective_policy/3","type":"function"},{"doc":"Retrieves information about a previously requested handshake.\n\nThe handshake ID comes from the response to the original\n`InviteAccountToOrganization` operation that generated the handshake.\n\nYou can access handshakes that are `ACCEPTED`, `DECLINED`, or `CANCELED` for\nonly 30 days after they change to that state. They're then deleted and no longer\naccessible.\n\nThis operation can be called from any account in the organization.","ref":"AWS.Organizations.html#describe_handshake/3","title":"AWS.Organizations.describe_handshake/3","type":"function"},{"doc":"Retrieves information about the organization that the user's account belongs to.\n\nThis operation can be called from any account in the organization.\n\nEven if a policy type is shown as available in the organization, you can disable\nit separately at the root level with `DisablePolicyType`. Use `ListRoots` to see\nthe status of policy types for a specified root.","ref":"AWS.Organizations.html#describe_organization/3","title":"AWS.Organizations.describe_organization/3","type":"function"},{"doc":"Retrieves information about an organizational unit (OU).\n\nThis operation can be called only from the organization's management account or\nby a member account that is a delegated administrator for an Amazon Web Services\nservice.","ref":"AWS.Organizations.html#describe_organizational_unit/3","title":"AWS.Organizations.describe_organizational_unit/3","type":"function"},{"doc":"Retrieves information about a policy.\n\nThis operation can be called only from the organization's management account or\nby a member account that is a delegated administrator for an Amazon Web Services\nservice.","ref":"AWS.Organizations.html#describe_policy/3","title":"AWS.Organizations.describe_policy/3","type":"function"},{"doc":"Retrieves information about a resource policy.\n\nThis operation can be called only from the organization's management account or\nby a member account that is a delegated administrator for an Amazon Web Services\nservice.","ref":"AWS.Organizations.html#describe_resource_policy/3","title":"AWS.Organizations.describe_resource_policy/3","type":"function"},{"doc":"Detaches a policy from a target root, organizational unit (OU), or account.\n\nIf the policy being detached is a service control policy (SCP), the changes to\npermissions for Identity and Access Management (IAM) users and roles in affected\naccounts are immediate.\n\nEvery root, OU, and account must have at least one SCP attached. If you want to\nreplace the default `FullAWSAccess` policy with an SCP that limits the\npermissions that can be delegated, you must attach the replacement SCP before\nyou can remove the default SCP. This is the authorization strategy of an \"[allow list](https://docs.aws.amazon.com/organizations/latest/userguide/SCP_strategies.html#orgs_policies_allowlist)\".\nIf you instead attach a second SCP and leave the `FullAWSAccess` SCP still\nattached, and specify `\"Effect\": \"Deny\"` in the second SCP to override the\n`\"Effect\": \"Allow\"` in the `FullAWSAccess` policy (or any other attached SCP),\nyou're using the authorization strategy of a \"[deny list](https://docs.aws.amazon.com/organizations/latest/userguide/SCP_strategies.html#orgs_policies_denylist)\".\n\nThis operation can be called only from the organization's management account or\nby a member account that is a delegated administrator for an Amazon Web Services\nservice.","ref":"AWS.Organizations.html#detach_policy/3","title":"AWS.Organizations.detach_policy/3","type":"function"},{"doc":"Disables the integration of an Amazon Web Services service (the service that is\nspecified by `ServicePrincipal`) with Organizations.\n\nWhen you disable integration, the specified service no longer can create a\n[service-linked role](https://docs.aws.amazon.com/IAM/latest/UserGuide/using-service-linked-roles.html)\nin *new* accounts in your organization. This means the service can't perform\noperations on your behalf on any new accounts in your organization. The service\ncan still perform operations in older accounts until the service completes its\nclean-up from Organizations.\n\nWe ** *strongly recommend* ** that you don't use this command to disable\nintegration between Organizations and the specified Amazon Web Services service.\nInstead, use the console or commands that are provided by the specified service.\nThis lets the trusted service perform any required initialization when enabling\ntrusted access, such as creating any required resources and any required clean\nup of resources when disabling trusted access.\n\nFor information about how to disable trusted service access to your organization\nusing the trusted service, see the **Learn more** link under the **Supports\nTrusted Access** column at [Amazon Web Services services that you can use with Organizations](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_integrate_services_list.html).\non this page.\n\nIf you disable access by using this command, it causes the following actions to\noccur:\n\n   The service can no longer create a service-linked role in the\naccounts in your organization. This means that the service can't perform\noperations on your behalf on any new accounts in your organization. The service\ncan still perform operations in older accounts until the service completes its\nclean-up from Organizations.\n\n   The service can no longer perform tasks in the member accounts in\nthe organization, unless those operations are explicitly permitted by the IAM\npolicies that are attached to your roles. This includes any data aggregation\nfrom the member accounts to the management account, or to a delegated\nadministrator account, where relevant.\n\n   Some services detect this and clean up any remaining data or\nresources related to the integration, while other services stop accessing the\norganization but leave any historical data and configuration in place to support\na possible re-enabling of the integration.\n\nUsing the other service's console or commands to disable the integration ensures\nthat the other service is aware that it can clean up any resources that are\nrequired only for the integration. How the service cleans up its resources in\nthe organization's accounts depends on that service. For more information, see\nthe documentation for the other Amazon Web Services service.\n\nAfter you perform the `DisableAWSServiceAccess` operation, the specified service\ncan no longer perform operations in your organization's accounts\n\nFor more information about integrating other services with Organizations,\nincluding the list of services that work with Organizations, see [Using Organizations with other Amazon Web Services\nservices](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_integrate_services.html)\nin the *Organizations User Guide*.\n\nThis operation can be called only from the organization's management account.","ref":"AWS.Organizations.html#disable_aws_service_access/3","title":"AWS.Organizations.disable_aws_service_access/3","type":"function"},{"doc":"Disables an organizational policy type in a root.\n\nA policy of a certain type can be attached to entities in a root only if that\ntype is enabled in the root. After you perform this operation, you no longer can\nattach policies of the specified type to that root or to any organizational unit\n(OU) or account in that root. You can undo this by using the `EnablePolicyType`\noperation.\n\nThis is an asynchronous request that Amazon Web Services performs in the\nbackground. If you disable a policy type for a root, it still appears enabled\nfor the organization if [all features](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_org_support-all-features.html)\nare enabled for the organization. Amazon Web Services recommends that you first\nuse `ListRoots` to see the status of policy types for a specified root, and then\nuse this operation.\n\nThis operation can be called only from the organization's management account or\nby a member account that is a delegated administrator for an Amazon Web Services\nservice.\n\nTo view the status of available policy types in the organization, use\n`DescribeOrganization`.","ref":"AWS.Organizations.html#disable_policy_type/3","title":"AWS.Organizations.disable_policy_type/3","type":"function"},{"doc":"Enables all features in an organization.\n\nThis enables the use of organization policies that can restrict the services and\nactions that can be called in each account. Until you enable all features, you\nhave access only to consolidated billing, and you can't use any of the advanced\naccount administration features that Organizations supports. For more\ninformation, see [Enabling all features in your organization](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_org_support-all-features.html)\nin the *Organizations User Guide*.\n\nThis operation is required only for organizations that were created explicitly\nwith only the consolidated billing features enabled. Calling this operation\nsends a handshake to every invited account in the organization. The feature set\nchange can be finalized and the additional features enabled only after all\nadministrators in the invited accounts approve the change by accepting the\nhandshake.\n\nAfter you enable all features, you can separately enable or disable individual\npolicy types in a root using `EnablePolicyType` and `DisablePolicyType`. To see\nthe status of policy types in a root, use `ListRoots`.\n\nAfter all invited member accounts accept the handshake, you finalize the feature\nset change by accepting the handshake that contains `\"Action\":\n\"ENABLE_ALL_FEATURES\"`. This completes the change.\n\nAfter you enable all features in your organization, the management account in\nthe organization can apply policies on all member accounts. These policies can\nrestrict what users and even administrators in those accounts can do. The\nmanagement account can apply policies that prevent accounts from leaving the\norganization. Ensure that your account administrators are aware of this.\n\nThis operation can be called only from the organization's management account.","ref":"AWS.Organizations.html#enable_all_features/3","title":"AWS.Organizations.enable_all_features/3","type":"function"},{"doc":"Enables the integration of an Amazon Web Services service (the service that is\nspecified by `ServicePrincipal`) with Organizations.\n\nWhen you enable integration, you allow the specified service to create a\n[service-linked role](https://docs.aws.amazon.com/IAM/latest/UserGuide/using-service-linked-roles.html)\nin all the accounts in your organization. This allows the service to perform\noperations on your behalf in your organization and its accounts.\n\nWe recommend that you enable integration between Organizations and the specified\nAmazon Web Services service by using the console or commands that are provided\nby the specified service. Doing so ensures that the service is aware that it can\ncreate the resources that are required for the integration. How the service\ncreates those resources in the organization's accounts depends on that service.\nFor more information, see the documentation for the other Amazon Web Services\nservice.\n\nFor more information about enabling services to integrate with Organizations,\nsee [Using Organizations with other Amazon Web Services services](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_integrate_services.html)\nin the *Organizations User Guide*.\n\nYou can only call this operation from the organization's management account and\nonly if the organization has [enabled all features](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_org_support-all-features.html).","ref":"AWS.Organizations.html#enable_aws_service_access/3","title":"AWS.Organizations.enable_aws_service_access/3","type":"function"},{"doc":"Enables a policy type in a root.\n\nAfter you enable a policy type in a root, you can attach policies of that type\nto the root, any organizational unit (OU), or account in that root. You can undo\nthis by using the `DisablePolicyType` operation.\n\nThis is an asynchronous request that Amazon Web Services performs in the\nbackground. Amazon Web Services recommends that you first use `ListRoots` to see\nthe status of policy types for a specified root, and then use this operation.\n\nThis operation can be called only from the organization's management account or\nby a member account that is a delegated administrator for an Amazon Web Services\nservice.\n\nYou can enable a policy type in a root only if that policy type is available in\nthe organization. To view the status of available policy types in the\norganization, use `DescribeOrganization`.","ref":"AWS.Organizations.html#enable_policy_type/3","title":"AWS.Organizations.enable_policy_type/3","type":"function"},{"doc":"Sends an invitation to another account to join your organization as a member\naccount.\n\nOrganizations sends email on your behalf to the email address that is associated\nwith the other account's owner. The invitation is implemented as a `Handshake`\nwhose details are in the response.\n\n   You can invite Amazon Web Services accounts only from the same\nseller as the management account. For example, if your organization's management\naccount was created by Amazon Internet Services Pvt. Ltd (AISPL), an Amazon Web\nServices seller in India, you can invite only other AISPL accounts to your\norganization. You can't combine accounts from AISPL and Amazon Web Services or\nfrom any other Amazon Web Services seller. For more information, see\n[Consolidated billing in India](https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/useconsolidatedbilling-India.html).\n\n   If you receive an exception that indicates that you exceeded your\naccount limits for the organization or that the operation failed because your\norganization is still initializing, wait one hour and then try again. If the\nerror persists after an hour, contact [Amazon Web Services Support](https://console.aws.amazon.com/support/home#/).\n\nIf the request includes tags, then the requester must have the\n`organizations:TagResource` permission.\n\nThis operation can be called only from the organization's management account.","ref":"AWS.Organizations.html#invite_account_to_organization/3","title":"AWS.Organizations.invite_account_to_organization/3","type":"function"},{"doc":"Removes a member account from its parent organization.\n\nThis version of the operation is performed by the account that wants to leave.\nTo remove a member account as a user in the management account, use\n`RemoveAccountFromOrganization` instead.\n\nThis operation can be called only from a member account in the organization.\n\n   The management account in an organization with all features enabled\ncan set service control policies (SCPs) that can restrict what administrators of\nmember accounts can do. This includes preventing them from successfully calling\n`LeaveOrganization` and leaving the organization.\n\n   You can leave an organization as a member account only if the\naccount is configured with the information required to operate as a standalone\naccount. When you create an account in an organization using the Organizations\nconsole, API, or CLI commands, the information required of standalone accounts\nis *not* automatically collected. For each account that you want to make\nstandalone, you must perform the following steps. If any of the steps are\nalready completed for this account, that step doesn't appear.\n\n     Choose a support plan\n\n     Provide and verify the required contact information\n\n     Provide a current payment method\n\nAmazon Web Services uses the payment method to charge for any billable (not free\ntier) Amazon Web Services activity that occurs while the account isn't attached\nto an organization. For more information, see [Considerations before removing an account from an\norganization](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_account-before-remove.html)\nin the *Organizations User Guide*.\n\n   The account that you want to leave must not be a delegated\nadministrator account for any Amazon Web Services service enabled for your\norganization. If the account is a delegated administrator, you must first change\nthe delegated administrator account to another account that is remaining in the\norganization.\n\n   You can leave an organization only after you enable IAM user access\nto billing in your account. For more information, see [About IAM access to the Billing and Cost Management\nconsole](https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/grantaccess.html#ControllingAccessWebsite-Activate)\nin the *Amazon Web Services Billing and Cost Management User Guide*.\n\n   After the account leaves the organization, all tags that were\nattached to the account object in the organization are deleted. Amazon Web\nServices accounts outside of an organization do not support tags.\n\n   A newly created account has a waiting period before it can be\nremoved from its organization. If you get an error that indicates that a wait\nperiod is required, then try again in a few days.\n\n   If you are using an organization principal to call\n`LeaveOrganization` across multiple accounts, you can only do this up to 5\naccounts per second in a single organization.","ref":"AWS.Organizations.html#leave_organization/3","title":"AWS.Organizations.leave_organization/3","type":"function"},{"doc":"Lists all the accounts in the organization.\n\nTo request only the accounts in a specified root or organizational unit (OU),\nuse the `ListAccountsForParent` operation instead.\n\nAlways check the `NextToken` response parameter for a `null` value when calling\na `List*` operation. These operations can occasionally return an empty set of\nresults even when there are more results available. The `NextToken` response\nparameter value is `null` *only* when there are no more results to display.\n\nThis operation can be called only from the organization's management account or\nby a member account that is a delegated administrator for an Amazon Web Services\nservice.","ref":"AWS.Organizations.html#list_accounts/3","title":"AWS.Organizations.list_accounts/3","type":"function"},{"doc":"Lists the accounts in an organization that are contained by the specified target\nroot or organizational unit (OU).\n\nIf you specify the root, you get a list of all the accounts that aren't in any\nOU. If you specify an OU, you get a list of all the accounts in only that OU and\nnot in any child OUs. To get a list of all accounts in the organization, use the\n`ListAccounts` operation.\n\nAlways check the `NextToken` response parameter for a `null` value when calling\na `List*` operation. These operations can occasionally return an empty set of\nresults even when there are more results available. The `NextToken` response\nparameter value is `null` *only* when there are no more results to display.\n\nThis operation can be called only from the organization's management account or\nby a member account that is a delegated administrator for an Amazon Web Services\nservice.","ref":"AWS.Organizations.html#list_accounts_for_parent/3","title":"AWS.Organizations.list_accounts_for_parent/3","type":"function"},{"doc":"Returns a list of the Amazon Web Services services that you enabled to integrate\nwith your organization.\n\nAfter a service on this list creates the resources that it requires for the\nintegration, it can perform operations on your organization and its accounts.\n\nFor more information about integrating other services with Organizations,\nincluding the list of services that currently work with Organizations, see\n[Using Organizations with other Amazon Web Services services](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_integrate_services.html)\nin the *Organizations User Guide*.\n\nThis operation can be called only from the organization's management account or\nby a member account that is a delegated administrator for an Amazon Web Services\nservice.","ref":"AWS.Organizations.html#list_aws_service_access_for_organization/3","title":"AWS.Organizations.list_aws_service_access_for_organization/3","type":"function"},{"doc":"Lists all of the organizational units (OUs) or accounts that are contained in\nthe specified parent OU or root.\n\nThis operation, along with `ListParents` enables you to traverse the tree\nstructure that makes up this root.\n\nAlways check the `NextToken` response parameter for a `null` value when calling\na `List*` operation. These operations can occasionally return an empty set of\nresults even when there are more results available. The `NextToken` response\nparameter value is `null` *only* when there are no more results to display.\n\nThis operation can be called only from the organization's management account or\nby a member account that is a delegated administrator for an Amazon Web Services\nservice.","ref":"AWS.Organizations.html#list_children/3","title":"AWS.Organizations.list_children/3","type":"function"},{"doc":"Lists the account creation requests that match the specified status that is\ncurrently being tracked for the organization.\n\nAlways check the `NextToken` response parameter for a `null` value when calling\na `List*` operation. These operations can occasionally return an empty set of\nresults even when there are more results available. The `NextToken` response\nparameter value is `null` *only* when there are no more results to display.\n\nThis operation can be called only from the organization's management account or\nby a member account that is a delegated administrator for an Amazon Web Services\nservice.","ref":"AWS.Organizations.html#list_create_account_status/3","title":"AWS.Organizations.list_create_account_status/3","type":"function"},{"doc":"Lists the Amazon Web Services accounts that are designated as delegated\nadministrators in this organization.\n\nThis operation can be called only from the organization's management account or\nby a member account that is a delegated administrator for an Amazon Web Services\nservice.","ref":"AWS.Organizations.html#list_delegated_administrators/3","title":"AWS.Organizations.list_delegated_administrators/3","type":"function"},{"doc":"List the Amazon Web Services services for which the specified account is a\ndelegated administrator.\n\nThis operation can be called only from the organization's management account or\nby a member account that is a delegated administrator for an Amazon Web Services\nservice.","ref":"AWS.Organizations.html#list_delegated_services_for_account/3","title":"AWS.Organizations.list_delegated_services_for_account/3","type":"function"},{"doc":"Lists the current handshakes that are associated with the account of the\nrequesting user.\n\nHandshakes that are `ACCEPTED`, `DECLINED`, `CANCELED`, or `EXPIRED` appear in\nthe results of this API for only 30 days after changing to that state. After\nthat, they're deleted and no longer accessible.\n\nAlways check the `NextToken` response parameter for a `null` value when calling\na `List*` operation. These operations can occasionally return an empty set of\nresults even when there are more results available. The `NextToken` response\nparameter value is `null` *only* when there are no more results to display.\n\nThis operation can be called from any account in the organization.","ref":"AWS.Organizations.html#list_handshakes_for_account/3","title":"AWS.Organizations.list_handshakes_for_account/3","type":"function"},{"doc":"Lists the handshakes that are associated with the organization that the\nrequesting user is part of.\n\nThe `ListHandshakesForOrganization` operation returns a list of handshake\nstructures. Each structure contains details and status about a handshake.\n\nHandshakes that are `ACCEPTED`, `DECLINED`, `CANCELED`, or `EXPIRED` appear in\nthe results of this API for only 30 days after changing to that state. After\nthat, they're deleted and no longer accessible.\n\nAlways check the `NextToken` response parameter for a `null` value when calling\na `List*` operation. These operations can occasionally return an empty set of\nresults even when there are more results available. The `NextToken` response\nparameter value is `null` *only* when there are no more results to display.\n\nThis operation can be called only from the organization's management account or\nby a member account that is a delegated administrator for an Amazon Web Services\nservice.","ref":"AWS.Organizations.html#list_handshakes_for_organization/3","title":"AWS.Organizations.list_handshakes_for_organization/3","type":"function"},{"doc":"Lists the organizational units (OUs) in a parent organizational unit or root.\n\nAlways check the `NextToken` response parameter for a `null` value when calling\na `List*` operation. These operations can occasionally return an empty set of\nresults even when there are more results available. The `NextToken` response\nparameter value is `null` *only* when there are no more results to display.\n\nThis operation can be called only from the organization's management account or\nby a member account that is a delegated administrator for an Amazon Web Services\nservice.","ref":"AWS.Organizations.html#list_organizational_units_for_parent/3","title":"AWS.Organizations.list_organizational_units_for_parent/3","type":"function"},{"doc":"Lists the root or organizational units (OUs) that serve as the immediate parent\nof the specified child OU or account.\n\nThis operation, along with `ListChildren` enables you to traverse the tree\nstructure that makes up this root.\n\nAlways check the `NextToken` response parameter for a `null` value when calling\na `List*` operation. These operations can occasionally return an empty set of\nresults even when there are more results available. The `NextToken` response\nparameter value is `null` *only* when there are no more results to display.\n\nThis operation can be called only from the organization's management account or\nby a member account that is a delegated administrator for an Amazon Web Services\nservice.\n\nIn the current release, a child can have only a single parent.","ref":"AWS.Organizations.html#list_parents/3","title":"AWS.Organizations.list_parents/3","type":"function"},{"doc":"Retrieves the list of all policies in an organization of a specified type.\n\nAlways check the `NextToken` response parameter for a `null` value when calling\na `List*` operation. These operations can occasionally return an empty set of\nresults even when there are more results available. The `NextToken` response\nparameter value is `null` *only* when there are no more results to display.\n\nThis operation can be called only from the organization's management account or\nby a member account that is a delegated administrator for an Amazon Web Services\nservice.","ref":"AWS.Organizations.html#list_policies/3","title":"AWS.Organizations.list_policies/3","type":"function"},{"doc":"Lists the policies that are directly attached to the specified target root,\norganizational unit (OU), or account.\n\nYou must specify the policy type that you want included in the returned list.\n\nAlways check the `NextToken` response parameter for a `null` value when calling\na `List*` operation. These operations can occasionally return an empty set of\nresults even when there are more results available. The `NextToken` response\nparameter value is `null` *only* when there are no more results to display.\n\nThis operation can be called only from the organization's management account or\nby a member account that is a delegated administrator for an Amazon Web Services\nservice.","ref":"AWS.Organizations.html#list_policies_for_target/3","title":"AWS.Organizations.list_policies_for_target/3","type":"function"},{"doc":"Lists the roots that are defined in the current organization.\n\nAlways check the `NextToken` response parameter for a `null` value when calling\na `List*` operation. These operations can occasionally return an empty set of\nresults even when there are more results available. The `NextToken` response\nparameter value is `null` *only* when there are no more results to display.\n\nThis operation can be called only from the organization's management account or\nby a member account that is a delegated administrator for an Amazon Web Services\nservice.\n\nPolicy types can be enabled and disabled in roots. This is distinct from whether\nthey're available in the organization. When you enable all features, you make\npolicy types available for use in that organization. Individual policy types can\nthen be enabled and disabled in a root. To see the availability of a policy type\nin an organization, use `DescribeOrganization`.","ref":"AWS.Organizations.html#list_roots/3","title":"AWS.Organizations.list_roots/3","type":"function"},{"doc":"Lists tags that are attached to the specified resource.\n\nYou can attach tags to the following resources in Organizations.\n\n  * Amazon Web Services account\n\n  * Organization root\n\n  * Organizational unit (OU)\n\n  * Policy (any type)\n\nThis operation can be called only from the organization's management account or\nby a member account that is a delegated administrator for an Amazon Web Services\nservice.","ref":"AWS.Organizations.html#list_tags_for_resource/3","title":"AWS.Organizations.list_tags_for_resource/3","type":"function"},{"doc":"Lists all the roots, organizational units (OUs), and accounts that the specified\npolicy is attached to.\n\nAlways check the `NextToken` response parameter for a `null` value when calling\na `List*` operation. These operations can occasionally return an empty set of\nresults even when there are more results available. The `NextToken` response\nparameter value is `null` *only* when there are no more results to display.\n\nThis operation can be called only from the organization's management account or\nby a member account that is a delegated administrator for an Amazon Web Services\nservice.","ref":"AWS.Organizations.html#list_targets_for_policy/3","title":"AWS.Organizations.list_targets_for_policy/3","type":"function"},{"doc":"","ref":"AWS.Organizations.html#metadata/0","title":"AWS.Organizations.metadata/0","type":"function"},{"doc":"Moves an account from its current source parent root or organizational unit (OU)\nto the specified destination parent root or OU.\n\nThis operation can be called only from the organization's management account.","ref":"AWS.Organizations.html#move_account/3","title":"AWS.Organizations.move_account/3","type":"function"},{"doc":"Creates or updates a resource policy.\n\nYou can only call this operation from the organization's management account.","ref":"AWS.Organizations.html#put_resource_policy/3","title":"AWS.Organizations.put_resource_policy/3","type":"function"},{"doc":"Enables the specified member account to administer the Organizations features of\nthe specified Amazon Web Services service.\n\nIt grants read-only access to Organizations service data. The account still\nrequires IAM permissions to access and administer the Amazon Web Services\nservice.\n\nYou can run this action only for Amazon Web Services services that support this\nfeature. For a current list of services that support it, see the column\n*Supports Delegated Administrator* in the table at [Amazon Web Services Services that you can use with\nOrganizations](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_integrate_services_list.html)\nin the *Organizations User Guide.*\n\nThis operation can be called only from the organization's management account.","ref":"AWS.Organizations.html#register_delegated_administrator/3","title":"AWS.Organizations.register_delegated_administrator/3","type":"function"},{"doc":"Removes the specified account from the organization.\n\nThe removed account becomes a standalone account that isn't a member of any\norganization. It's no longer subject to any policies and is responsible for its\nown bill payments. The organization's management account is no longer charged\nfor any expenses accrued by the member account after it's removed from the\norganization.\n\nThis operation can be called only from the organization's management account.\nMember accounts can remove themselves with `LeaveOrganization` instead.\n\n   You can remove an account from your organization only if the\naccount is configured with the information required to operate as a standalone\naccount. When you create an account in an organization using the Organizations\nconsole, API, or CLI commands, the information required of standalone accounts\nis *not* automatically collected. For more information, see [Considerations before removing an account from an\norganization](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_account-before-remove.html)\nin the *Organizations User Guide*.\n\n   The account that you want to leave must not be a delegated\nadministrator account for any Amazon Web Services service enabled for your\norganization. If the account is a delegated administrator, you must first change\nthe delegated administrator account to another account that is remaining in the\norganization.\n\n   After the account leaves the organization, all tags that were\nattached to the account object in the organization are deleted. Amazon Web\nServices accounts outside of an organization do not support tags.","ref":"AWS.Organizations.html#remove_account_from_organization/3","title":"AWS.Organizations.remove_account_from_organization/3","type":"function"},{"doc":"Adds one or more tags to the specified resource.\n\nCurrently, you can attach tags to the following resources in Organizations.\n\n  * Amazon Web Services account\n\n  * Organization root\n\n  * Organizational unit (OU)\n\n  * Policy (any type)\n\nThis operation can be called only from the organization's management account or\nby a member account that is a delegated administrator for an Amazon Web Services\nservice.","ref":"AWS.Organizations.html#tag_resource/3","title":"AWS.Organizations.tag_resource/3","type":"function"},{"doc":"Removes any tags with the specified keys from the specified resource.\n\nYou can attach tags to the following resources in Organizations.\n\n  * Amazon Web Services account\n\n  * Organization root\n\n  * Organizational unit (OU)\n\n  * Policy (any type)\n\nThis operation can be called only from the organization's management account or\nby a member account that is a delegated administrator for an Amazon Web Services\nservice.","ref":"AWS.Organizations.html#untag_resource/3","title":"AWS.Organizations.untag_resource/3","type":"function"},{"doc":"Renames the specified organizational unit (OU).\n\nThe ID and ARN don't change. The child OUs and accounts remain in place, and any\nattached policies of the OU remain attached.\n\nThis operation can be called only from the organization's management account.","ref":"AWS.Organizations.html#update_organizational_unit/3","title":"AWS.Organizations.update_organizational_unit/3","type":"function"},{"doc":"Updates an existing policy with a new name, description, or content.\n\nIf you don't supply any parameter, that value remains unchanged. You can't\nchange a policy's type.\n\nThis operation can be called only from the organization's management account or\nby a member account that is a delegated administrator for an Amazon Web Services\nservice.","ref":"AWS.Organizations.html#update_policy/3","title":"AWS.Organizations.update_policy/3","type":"function"},{"doc":"Amazon Web Services Outposts is a fully managed service that extends Amazon Web\nServices infrastructure, APIs, and tools to customer premises.\n\nBy providing local access to Amazon Web Services managed infrastructure, Amazon\nWeb Services Outposts enables customers to build and run applications on\npremises using the same programming interfaces as in Amazon Web Services\nRegions, while using local compute and storage resources for lower latency and\nlocal data processing needs.","ref":"AWS.Outposts.html","title":"AWS.Outposts","type":"module"},{"doc":"Cancels the specified order for an Outpost.","ref":"AWS.Outposts.html#cancel_order/4","title":"AWS.Outposts.cancel_order/4","type":"function"},{"doc":"Creates an order for an Outpost.","ref":"AWS.Outposts.html#create_order/3","title":"AWS.Outposts.create_order/3","type":"function"},{"doc":"Creates an Outpost.\n\nYou can specify either an Availability one or an AZ ID.","ref":"AWS.Outposts.html#create_outpost/3","title":"AWS.Outposts.create_outpost/3","type":"function"},{"doc":"Creates a site for an Outpost.","ref":"AWS.Outposts.html#create_site/3","title":"AWS.Outposts.create_site/3","type":"function"},{"doc":"Deletes the specified Outpost.","ref":"AWS.Outposts.html#delete_outpost/4","title":"AWS.Outposts.delete_outpost/4","type":"function"},{"doc":"Deletes the specified site.","ref":"AWS.Outposts.html#delete_site/4","title":"AWS.Outposts.delete_site/4","type":"function"},{"doc":"Gets information about the specified catalog item.","ref":"AWS.Outposts.html#get_catalog_item/3","title":"AWS.Outposts.get_catalog_item/3","type":"function"},{"doc":"Amazon Web Services uses this action to install Outpost servers.\n\nGets information about the specified connection.\n\nUse CloudTrail to monitor this action or Amazon Web Services managed policy for\nAmazon Web Services Outposts to secure it. For more information, see [ Amazon Web Services managed policies for Amazon Web Services\nOutposts](https://docs.aws.amazon.com/outposts/latest/userguide/security-iam-awsmanpol.html)\nand [ Logging Amazon Web Services Outposts API calls with Amazon Web Services CloudTrail](https://docs.aws.amazon.com/outposts/latest/userguide/logging-using-cloudtrail.html)\nin the *Amazon Web Services Outposts User Guide*.","ref":"AWS.Outposts.html#get_connection/3","title":"AWS.Outposts.get_connection/3","type":"function"},{"doc":"Gets information about the specified order.","ref":"AWS.Outposts.html#get_order/3","title":"AWS.Outposts.get_order/3","type":"function"},{"doc":"Gets information about the specified Outpost.","ref":"AWS.Outposts.html#get_outpost/3","title":"AWS.Outposts.get_outpost/3","type":"function"},{"doc":"Gets the instance types for the specified Outpost.","ref":"AWS.Outposts.html#get_outpost_instance_types/5","title":"AWS.Outposts.get_outpost_instance_types/5","type":"function"},{"doc":"Gets information about the specified Outpost site.","ref":"AWS.Outposts.html#get_site/3","title":"AWS.Outposts.get_site/3","type":"function"},{"doc":"Gets the site address of the specified site.","ref":"AWS.Outposts.html#get_site_address/4","title":"AWS.Outposts.get_site_address/4","type":"function"},{"doc":"Lists the hardware assets for the specified Outpost.\n\nUse filters to return specific results. If you specify multiple filters, the\nresults include only the resources that match all of the specified filters. For\na filter where you can specify multiple values, the results include items that\nmatch any of the values that you specify for the filter.","ref":"AWS.Outposts.html#list_assets/7","title":"AWS.Outposts.list_assets/7","type":"function"},{"doc":"Lists the items in the catalog.\n\nUse filters to return specific results. If you specify multiple filters, the\nresults include only the resources that match all of the specified filters. For\na filter where you can specify multiple values, the results include items that\nmatch any of the values that you specify for the filter.","ref":"AWS.Outposts.html#list_catalog_items/7","title":"AWS.Outposts.list_catalog_items/7","type":"function"},{"doc":"Lists the Outpost orders for your Amazon Web Services account.","ref":"AWS.Outposts.html#list_orders/5","title":"AWS.Outposts.list_orders/5","type":"function"},{"doc":"Lists the Outposts for your Amazon Web Services account.\n\nUse filters to return specific results. If you specify multiple filters, the\nresults include only the resources that match all of the specified filters. For\na filter where you can specify multiple values, the results include items that\nmatch any of the values that you specify for the filter.","ref":"AWS.Outposts.html#list_outposts/7","title":"AWS.Outposts.list_outposts/7","type":"function"},{"doc":"Lists the Outpost sites for your Amazon Web Services account.\n\nUse filters to return specific results.\n\nUse filters to return specific results. If you specify multiple filters, the\nresults include only the resources that match all of the specified filters. For\na filter where you can specify multiple values, the results include items that\nmatch any of the values that you specify for the filter.","ref":"AWS.Outposts.html#list_sites/7","title":"AWS.Outposts.list_sites/7","type":"function"},{"doc":"Lists the tags for the specified resource.","ref":"AWS.Outposts.html#list_tags_for_resource/3","title":"AWS.Outposts.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.Outposts.html#metadata/0","title":"AWS.Outposts.metadata/0","type":"function"},{"doc":"Amazon Web Services uses this action to install Outpost servers.\n\nStarts the connection required for Outpost server installation.\n\nUse CloudTrail to monitor this action or Amazon Web Services managed policy for\nAmazon Web Services Outposts to secure it. For more information, see [ Amazon Web Services managed policies for Amazon Web Services\nOutposts](https://docs.aws.amazon.com/outposts/latest/userguide/security-iam-awsmanpol.html)\nand [ Logging Amazon Web Services Outposts API calls with Amazon Web Services CloudTrail](https://docs.aws.amazon.com/outposts/latest/userguide/logging-using-cloudtrail.html)\nin the *Amazon Web Services Outposts User Guide*.","ref":"AWS.Outposts.html#start_connection/3","title":"AWS.Outposts.start_connection/3","type":"function"},{"doc":"Adds tags to the specified resource.","ref":"AWS.Outposts.html#tag_resource/4","title":"AWS.Outposts.tag_resource/4","type":"function"},{"doc":"Removes tags from the specified resource.","ref":"AWS.Outposts.html#untag_resource/4","title":"AWS.Outposts.untag_resource/4","type":"function"},{"doc":"Updates an Outpost.","ref":"AWS.Outposts.html#update_outpost/4","title":"AWS.Outposts.update_outpost/4","type":"function"},{"doc":"Updates the specified site.","ref":"AWS.Outposts.html#update_site/4","title":"AWS.Outposts.update_site/4","type":"function"},{"doc":"Updates the address of the specified site.\n\nYou can't update a site address if there is an order in progress. You must wait\nfor the order to complete or cancel the order.\n\nYou can update the operating address before you place an order at the site, or\nafter all Outposts that belong to the site have been deactivated.","ref":"AWS.Outposts.html#update_site_address/4","title":"AWS.Outposts.update_site_address/4","type":"function"},{"doc":"Update the physical and logistical details for a rack at a site.\n\nFor more information about hardware requirements for racks, see [Network readiness\nchecklist](https://docs.aws.amazon.com/outposts/latest/userguide/outposts-requirements.html#checklist)\nin the Amazon Web Services Outposts User Guide.\n\nTo update a rack at a site with an order of `IN_PROGRESS`, you must wait for the\norder to complete or cancel the order.","ref":"AWS.Outposts.html#update_site_rack_physical_properties/4","title":"AWS.Outposts.update_site_rack_physical_properties/4","type":"function"},{"doc":"Amazon RDS Performance Insights\n\nAmazon RDS Performance Insights enables you to monitor and explore different\ndimensions of database load based on data captured from a running DB instance.\n\nThe guide provides detailed information about Performance Insights data types,\nparameters and errors.\n\nWhen Performance Insights is enabled, the Amazon RDS Performance Insights API\nprovides visibility into the performance of your DB instance. Amazon CloudWatch\nprovides the authoritative source for Amazon Web Services service-vended\nmonitoring metrics. Performance Insights offers a domain-specific view of DB\nload.\n\nDB load is measured as average active sessions. Performance Insights provides\nthe data to API consumers as a two-dimensional time-series dataset. The time\ndimension provides DB load data for each time point in the queried time range.\nEach time point decomposes overall load in relation to the requested dimensions,\nmeasured at that time point. Examples include SQL, Wait event, User, and Host.\n\n  * To learn more about Performance Insights and Amazon Aurora DB\ninstances, go to the * [ Amazon Aurora User Guide](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/USER_PerfInsights.html)\n*.\n\n  * To learn more about Performance Insights and Amazon RDS DB\ninstances, go to the * [ Amazon RDS User Guide](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_PerfInsights.html)\n*.\n\n  * To learn more about Performance Insights and Amazon DocumentDB\nclusters, go to the * [ Amazon DocumentDB Developer Guide](https://docs.aws.amazon.com/documentdb/latest/developerguide/performance-insights.html)\n*.","ref":"AWS.PI.html","title":"AWS.PI","type":"module"},{"doc":"Creates a new performance analysis report for a specific time period for the DB\ninstance.","ref":"AWS.PI.html#create_performance_analysis_report/3","title":"AWS.PI.create_performance_analysis_report/3","type":"function"},{"doc":"Deletes a performance analysis report.","ref":"AWS.PI.html#delete_performance_analysis_report/3","title":"AWS.PI.delete_performance_analysis_report/3","type":"function"},{"doc":"For a specific time period, retrieve the top `N` dimension keys for a metric.\n\nEach response element returns a maximum of 500 bytes. For larger elements, such\nas SQL statements, only the first 500 bytes are returned.","ref":"AWS.PI.html#describe_dimension_keys/3","title":"AWS.PI.describe_dimension_keys/3","type":"function"},{"doc":"Get the attributes of the specified dimension group for a DB instance or data\nsource.\n\nFor example, if you specify a SQL ID, `GetDimensionKeyDetails` retrieves the\nfull text of the dimension `db.sql.statement` associated with this ID. This\noperation is useful because `GetResourceMetrics` and `DescribeDimensionKeys`\ndon't support retrieval of large SQL statement text.","ref":"AWS.PI.html#get_dimension_key_details/3","title":"AWS.PI.get_dimension_key_details/3","type":"function"},{"doc":"Retrieves the report including the report ID, status, time details, and the\ninsights with recommendations.\n\nThe report status can be `RUNNING`, `SUCCEEDED`, or `FAILED`. The insights\ninclude the `description` and `recommendation` fields.","ref":"AWS.PI.html#get_performance_analysis_report/3","title":"AWS.PI.get_performance_analysis_report/3","type":"function"},{"doc":"Retrieve the metadata for different features.\n\nFor example, the metadata might indicate that a feature is turned on or off on a\nspecific DB instance.","ref":"AWS.PI.html#get_resource_metadata/3","title":"AWS.PI.get_resource_metadata/3","type":"function"},{"doc":"Retrieve Performance Insights metrics for a set of data sources over a time\nperiod.\n\nYou can provide specific dimension groups and dimensions, and provide\naggregation and filtering criteria for each group.\n\nEach response element returns a maximum of 500 bytes. For larger elements, such\nas SQL statements, only the first 500 bytes are returned.","ref":"AWS.PI.html#get_resource_metrics/3","title":"AWS.PI.get_resource_metrics/3","type":"function"},{"doc":"Retrieve the dimensions that can be queried for each specified metric type on a\nspecified DB instance.","ref":"AWS.PI.html#list_available_resource_dimensions/3","title":"AWS.PI.list_available_resource_dimensions/3","type":"function"},{"doc":"Retrieve metrics of the specified types that can be queried for a specified DB\ninstance.","ref":"AWS.PI.html#list_available_resource_metrics/3","title":"AWS.PI.list_available_resource_metrics/3","type":"function"},{"doc":"Lists all the analysis reports created for the DB instance.\n\nThe reports are sorted based on the start time of each report.","ref":"AWS.PI.html#list_performance_analysis_reports/3","title":"AWS.PI.list_performance_analysis_reports/3","type":"function"},{"doc":"Retrieves all the metadata tags associated with Amazon RDS Performance Insights\nresource.","ref":"AWS.PI.html#list_tags_for_resource/3","title":"AWS.PI.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.PI.html#metadata/0","title":"AWS.PI.metadata/0","type":"function"},{"doc":"Adds metadata tags to the Amazon RDS Performance Insights resource.","ref":"AWS.PI.html#tag_resource/3","title":"AWS.PI.tag_resource/3","type":"function"},{"doc":"Deletes the metadata tags from the Amazon RDS Performance Insights resource.","ref":"AWS.PI.html#untag_resource/3","title":"AWS.PI.untag_resource/3","type":"function"},{"doc":"AWS Panorama","ref":"AWS.Panorama.html","title":"AWS.Panorama","type":"module"},{"doc":"This is the *AWS Panorama API Reference*.\n\nFor an introduction to the service, see [What is AWS Panorama?](https://docs.aws.amazon.com/panorama/latest/dev/panorama-welcome.html)\nin the *AWS Panorama Developer Guide*.","ref":"AWS.Panorama.html#module-overview","title":"Overview - AWS.Panorama","type":"module"},{"doc":"Creates an application instance and deploys it to a device.","ref":"AWS.Panorama.html#create_application_instance/3","title":"AWS.Panorama.create_application_instance/3","type":"function"},{"doc":"Creates a job to run on a device.\n\nA job can update a device's software or reboot it.","ref":"AWS.Panorama.html#create_job_for_devices/3","title":"AWS.Panorama.create_job_for_devices/3","type":"function"},{"doc":"Creates a camera stream node.","ref":"AWS.Panorama.html#create_node_from_template_job/3","title":"AWS.Panorama.create_node_from_template_job/3","type":"function"},{"doc":"Creates a package and storage location in an Amazon S3 access point.","ref":"AWS.Panorama.html#create_package/3","title":"AWS.Panorama.create_package/3","type":"function"},{"doc":"Imports a node package.","ref":"AWS.Panorama.html#create_package_import_job/3","title":"AWS.Panorama.create_package_import_job/3","type":"function"},{"doc":"Deletes a device.","ref":"AWS.Panorama.html#delete_device/4","title":"AWS.Panorama.delete_device/4","type":"function"},{"doc":"Deletes a package.\n\nTo delete a package, you need permission to call `s3:DeleteObject` in addition\nto permissions for the AWS Panorama API.","ref":"AWS.Panorama.html#delete_package/4","title":"AWS.Panorama.delete_package/4","type":"function"},{"doc":"Deregisters a package version.","ref":"AWS.Panorama.html#deregister_package_version/6","title":"AWS.Panorama.deregister_package_version/6","type":"function"},{"doc":"Returns information about an application instance on a device.","ref":"AWS.Panorama.html#describe_application_instance/3","title":"AWS.Panorama.describe_application_instance/3","type":"function"},{"doc":"Returns information about an application instance's configuration manifest.","ref":"AWS.Panorama.html#describe_application_instance_details/3","title":"AWS.Panorama.describe_application_instance_details/3","type":"function"},{"doc":"Returns information about a device.","ref":"AWS.Panorama.html#describe_device/3","title":"AWS.Panorama.describe_device/3","type":"function"},{"doc":"Returns information about a device job.","ref":"AWS.Panorama.html#describe_device_job/3","title":"AWS.Panorama.describe_device_job/3","type":"function"},{"doc":"Returns information about a node.","ref":"AWS.Panorama.html#describe_node/4","title":"AWS.Panorama.describe_node/4","type":"function"},{"doc":"Returns information about a job to create a camera stream node.","ref":"AWS.Panorama.html#describe_node_from_template_job/3","title":"AWS.Panorama.describe_node_from_template_job/3","type":"function"},{"doc":"Returns information about a package.","ref":"AWS.Panorama.html#describe_package/3","title":"AWS.Panorama.describe_package/3","type":"function"},{"doc":"Returns information about a package import job.","ref":"AWS.Panorama.html#describe_package_import_job/3","title":"AWS.Panorama.describe_package_import_job/3","type":"function"},{"doc":"Returns information about a package version.","ref":"AWS.Panorama.html#describe_package_version/6","title":"AWS.Panorama.describe_package_version/6","type":"function"},{"doc":"Returns a list of application instance dependencies.","ref":"AWS.Panorama.html#list_application_instance_dependencies/5","title":"AWS.Panorama.list_application_instance_dependencies/5","type":"function"},{"doc":"Returns a list of application node instances.","ref":"AWS.Panorama.html#list_application_instance_node_instances/5","title":"AWS.Panorama.list_application_instance_node_instances/5","type":"function"},{"doc":"Returns a list of application instances.","ref":"AWS.Panorama.html#list_application_instances/6","title":"AWS.Panorama.list_application_instances/6","type":"function"},{"doc":"Returns a list of devices.","ref":"AWS.Panorama.html#list_devices/8","title":"AWS.Panorama.list_devices/8","type":"function"},{"doc":"Returns a list of jobs.","ref":"AWS.Panorama.html#list_devices_jobs/5","title":"AWS.Panorama.list_devices_jobs/5","type":"function"},{"doc":"Returns a list of camera stream node jobs.","ref":"AWS.Panorama.html#list_node_from_template_jobs/4","title":"AWS.Panorama.list_node_from_template_jobs/4","type":"function"},{"doc":"Returns a list of nodes.","ref":"AWS.Panorama.html#list_nodes/9","title":"AWS.Panorama.list_nodes/9","type":"function"},{"doc":"Returns a list of package import jobs.","ref":"AWS.Panorama.html#list_package_import_jobs/4","title":"AWS.Panorama.list_package_import_jobs/4","type":"function"},{"doc":"Returns a list of packages.","ref":"AWS.Panorama.html#list_packages/4","title":"AWS.Panorama.list_packages/4","type":"function"},{"doc":"Returns a list of tags for a resource.","ref":"AWS.Panorama.html#list_tags_for_resource/3","title":"AWS.Panorama.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.Panorama.html#metadata/0","title":"AWS.Panorama.metadata/0","type":"function"},{"doc":"Creates a device and returns a configuration archive.\n\nThe configuration archive is a ZIP file that contains a provisioning certificate\nthat is valid for 5 minutes. Name the configuration archive\n`certificates-omni_*device-name*.zip` and transfer it to the device within 5\nminutes. Use the included USB storage device and connect it to the USB 3.0 port\nnext to the HDMI output.","ref":"AWS.Panorama.html#provision_device/3","title":"AWS.Panorama.provision_device/3","type":"function"},{"doc":"Registers a package version.","ref":"AWS.Panorama.html#register_package_version/6","title":"AWS.Panorama.register_package_version/6","type":"function"},{"doc":"Removes an application instance.","ref":"AWS.Panorama.html#remove_application_instance/4","title":"AWS.Panorama.remove_application_instance/4","type":"function"},{"doc":"Signal camera nodes to stop or resume.","ref":"AWS.Panorama.html#signal_application_instance_node_instances/4","title":"AWS.Panorama.signal_application_instance_node_instances/4","type":"function"},{"doc":"Tags a resource.","ref":"AWS.Panorama.html#tag_resource/4","title":"AWS.Panorama.tag_resource/4","type":"function"},{"doc":"Removes tags from a resource.","ref":"AWS.Panorama.html#untag_resource/4","title":"AWS.Panorama.untag_resource/4","type":"function"},{"doc":"Updates a device's metadata.","ref":"AWS.Panorama.html#update_device_metadata/4","title":"AWS.Panorama.update_device_metadata/4","type":"function"},{"doc":"Amazon Web Services Payment Cryptography Control Plane APIs manage encryption\nkeys for use during payment-related cryptographic operations.\n\nYou can create, import, export, share, manage, and delete keys. You can also\nmanage Identity and Access Management (IAM) policies for keys. For more\ninformation, see [Identity and access management](https://docs.aws.amazon.com/payment-cryptography/latest/userguide/security-iam.html)\nin the *Amazon Web Services Payment Cryptography User Guide.*\n\nTo use encryption keys for payment-related transaction processing and associated\ncryptographic operations, you use the [Amazon Web Services Payment Cryptography Data\nPlane](https://docs.aws.amazon.com/payment-cryptography/latest/DataAPIReference/Welcome.html).\nYou can perform actions like encrypt, decrypt, generate, and verify\npayment-related data.\n\nAll Amazon Web Services Payment Cryptography API calls must be signed and\ntransmitted using Transport Layer Security (TLS). We recommend you always use\nthe latest supported TLS version for logging API requests.\n\nAmazon Web Services Payment Cryptography supports CloudTrail for control plane\noperations, a service that logs Amazon Web Services API calls and related events\nfor your Amazon Web Services account and delivers them to an Amazon S3 bucket\nyou specify. By using the information collected by CloudTrail, you can determine\nwhat requests were made to Amazon Web Services Payment Cryptography, who made\nthe request, when it was made, and so on. If you don't conﬁgure a trail, you can\nstill view the most recent events in the CloudTrail console. For more\ninformation, see the [CloudTrail User Guide](https://docs.aws.amazon.com/awscloudtrail/latest/userguide/).","ref":"AWS.PaymentCryptography.html","title":"AWS.PaymentCryptography","type":"module"},{"doc":"Creates an *alias*, or a friendly name, for an Amazon Web Services Payment\nCryptography key.\n\nYou can use an alias to identify a key in the console and when you call\ncryptographic operations such as\n[EncryptData](https://docs.aws.amazon.com/payment-cryptography/latest/DataAPIReference/API_EncryptData.html) or\n[DecryptData](https://docs.aws.amazon.com/payment-cryptography/latest/DataAPIReference/API_DecryptData.html).\n\nYou can associate the alias with any key in the same Amazon Web Services Region.\nEach alias is associated with only one key at a time, but a key can have\nmultiple aliases. You can't create an alias without a key. The alias must be\nunique in the account and Amazon Web Services Region, but you can create another\nalias with the same name in a different Amazon Web Services Region.\n\nTo change the key that's associated with the alias, call `UpdateAlias`. To\ndelete the alias, call `DeleteAlias`. These operations don't affect the\nunderlying key. To get the alias that you created, call `ListAliases`.\n\n**Cross-account use**: This operation can't be used across different Amazon Web\nServices accounts.","ref":"AWS.PaymentCryptography.html#create_alias/3","title":"AWS.PaymentCryptography.create_alias/3","type":"function"},{"doc":"* `DeleteAlias`\n\n  * `GetAlias`\n\n  * `ListAliases`\n\n  * `UpdateAlias`","ref":"AWS.PaymentCryptography.html#create_alias/3-related-operations","title":"Related operations: - AWS.PaymentCryptography.create_alias/3","type":"function"},{"doc":"Creates an Amazon Web Services Payment Cryptography key, a logical\nrepresentation of a cryptographic key, that is unique in your account and Amazon\nWeb Services Region.\n\nYou use keys for cryptographic functions such as encryption and decryption.\n\nIn addition to the key material used in cryptographic operations, an Amazon Web\nServices Payment Cryptography key includes metadata such as the key ARN, key\nusage, key origin, creation date, description, and key state.\n\nWhen you create a key, you specify both immutable and mutable data about the\nkey. The immutable data contains key attributes that define the scope and\ncryptographic operations that you can perform using the key, for example key\nclass (example: `SYMMETRIC_KEY`), key algorithm (example: `TDES_2KEY`), key\nusage (example: `TR31_P0_PIN_ENCRYPTION_KEY`) and key modes of use (example:\n`Encrypt`). For information about valid combinations of key attributes, see\n[Understanding key attributes](https://docs.aws.amazon.com/payment-cryptography/latest/userguide/keys-validattributes.html)\nin the *Amazon Web Services Payment Cryptography User Guide*. The mutable data\ncontained within a key includes usage timestamp and key deletion timestamp and\ncan be modified after creation.\n\nAmazon Web Services Payment Cryptography binds key attributes to keys using key\nblocks when you store or export them. Amazon Web Services Payment Cryptography\nstores the key contents wrapped and never stores or transmits them in the clear.\n\n**Cross-account use**: This operation can't be used across different Amazon Web\nServices accounts.","ref":"AWS.PaymentCryptography.html#create_key/3","title":"AWS.PaymentCryptography.create_key/3","type":"function"},{"doc":"* `DeleteKey`\n\n  * `GetKey`\n\n  * `ListKeys`","ref":"AWS.PaymentCryptography.html#create_key/3-related-operations","title":"Related operations: - AWS.PaymentCryptography.create_key/3","type":"function"},{"doc":"Deletes the alias, but doesn't affect the underlying key.\n\nEach key can have multiple aliases. To get the aliases of all keys, use the\n`ListAliases` operation. To change the alias of a key, first use `DeleteAlias`\nto delete the current alias and then use `CreateAlias` to create a new alias. To\nassociate an existing alias with a different key, call `UpdateAlias`.\n\n**Cross-account use:** This operation can't be used across different Amazon Web\nServices accounts.","ref":"AWS.PaymentCryptography.html#delete_alias/3","title":"AWS.PaymentCryptography.delete_alias/3","type":"function"},{"doc":"* `CreateAlias`\n\n  * `GetAlias`\n\n  * `ListAliases`\n\n  * `UpdateAlias`","ref":"AWS.PaymentCryptography.html#delete_alias/3-related-operations","title":"Related operations: - AWS.PaymentCryptography.delete_alias/3","type":"function"},{"doc":"Deletes the key material and metadata associated with Amazon Web Services\nPayment Cryptography key.\n\nKey deletion is irreversible. After a key is deleted, you can't perform\ncryptographic operations using the key. For example, you can't decrypt data that\nwas encrypted by a deleted Amazon Web Services Payment Cryptography key, and the\ndata may become unrecoverable. Because key deletion is destructive, Amazon Web\nServices Payment Cryptography has a safety mechanism to prevent accidental\ndeletion of a key. When you call this operation, Amazon Web Services Payment\nCryptography disables the specified key but doesn't delete it until after a\nwaiting period set using `DeleteKeyInDays`. The default waiting period is 7\ndays. During the waiting period, the `KeyState` is `DELETE_PENDING`. After the\nkey is deleted, the `KeyState` is `DELETE_COMPLETE`.\n\nYou should delete a key only when you are sure that you don't need to use it\nanymore and no other parties are utilizing this key. If you aren't sure,\nconsider deactivating it instead by calling `StopKeyUsage`.\n\n**Cross-account use:** This operation can't be used across different Amazon Web\nServices accounts.","ref":"AWS.PaymentCryptography.html#delete_key/3","title":"AWS.PaymentCryptography.delete_key/3","type":"function"},{"doc":"* `RestoreKey`\n\n  * `StartKeyUsage`\n\n  * `StopKeyUsage`","ref":"AWS.PaymentCryptography.html#delete_key/3-related-operations","title":"Related operations: - AWS.PaymentCryptography.delete_key/3","type":"function"},{"doc":"Exports a key from Amazon Web Services Payment Cryptography.\n\nAmazon Web Services Payment Cryptography simplifies key exchange by replacing\nthe existing paper-based approach with a modern electronic approach. With\n`ExportKey` you can export symmetric keys using either symmetric and asymmetric\nkey exchange mechanisms. Using this operation, you can share your Amazon Web\nServices Payment Cryptography generated keys with other service partners to\nperform cryptographic operations outside of Amazon Web Services Payment\nCryptography\n\nFor symmetric key exchange, Amazon Web Services Payment Cryptography uses the\nANSI X9 TR-31 norm in accordance with PCI PIN guidelines. And for asymmetric key\nexchange, Amazon Web Services Payment Cryptography supports ANSI X9 TR-34 norm\nand RSA wrap and unwrap key exchange mechanism. Asymmetric key exchange methods\nare typically used to establish bi-directional trust between the two parties\nexhanging keys and are used for initial key exchange such as Key Encryption Key\n(KEK). After which you can export working keys using symmetric method to perform\nvarious cryptographic operations within Amazon Web Services Payment\nCryptography.\n\nThe TR-34 norm is intended for exchanging 3DES keys only and keys are imported\nin a WrappedKeyBlock format. Key attributes (such as KeyUsage, KeyAlgorithm,\nKeyModesOfUse, Exportability) are contained within the key block. With RSA wrap\nand unwrap, you can exchange both 3DES and AES-128 keys. The keys are imported\nin a WrappedKeyCryptogram format and you will need to specify the key attributes\nduring import.\n\nYou can also use `ExportKey` functionality to generate and export an IPEK\n(Initial Pin Encryption Key) from Amazon Web Services Payment Cryptography using\neither TR-31 or TR-34 export key exchange. IPEK is generated from BDK (Base\nDerivation Key) and `ExportDukptInitialKey` attribute KSN (`KeySerialNumber`).\nThe generated IPEK does not persist within Amazon Web Services Payment\nCryptography and has to be re-generated each time during export.","ref":"AWS.PaymentCryptography.html#export_key/3","title":"AWS.PaymentCryptography.export_key/3","type":"function"},{"doc":"Using this operation, you can export initial key using TR-34 asymmetric key\nexchange. You can only export KEK generated within Amazon Web Services Payment\nCryptography. In TR-34 terminology, the sending party of the key is called Key\nDistribution Host (KDH) and the receiving party of the key is called Key\nReceiving Device (KRD). During key export process, KDH is Amazon Web Services\nPayment Cryptography which initiates key export and KRD is the user receiving\nthe key.\n\nTo initiate TR-34 key export, the KRD must obtain an export token by calling\n`GetParametersForExport`. This operation also generates a key pair for the\npurpose of key export, signs the key and returns back the signing public key\ncertificate (also known as KDH signing certificate) and root certificate chain.\nThe KDH uses the private key to sign the the export payload and the signing\npublic key certificate is provided to KRD to verify the signature. The KRD can\nimport the root certificate into its Hardware Security Module (HSM), as\nrequired. The export token and the associated KDH signing certificate expires\nafter 7 days.\n\nNext the KRD generates a key pair for the the purpose of encrypting the KDH key\nand provides the public key cerificate (also known as KRD wrapping certificate)\nback to KDH. The KRD will also import the root cerificate chain into Amazon Web\nServices Payment Cryptography by calling `ImportKey` for\n`RootCertificatePublicKey`. The KDH, Amazon Web Services Payment Cryptography,\nwill use the KRD wrapping cerificate to encrypt (wrap) the key under export and\nsigns it with signing private key to generate a TR-34 WrappedKeyBlock. For more\ninformation on TR-34 key export, see section [Exporting symmetric keys](https://docs.aws.amazon.com/payment-cryptography/latest/userguide/keys-export.html)\nin the *Amazon Web Services Payment Cryptography User Guide*.\n\nSet the following parameters:\n\n  * `ExportAttributes`: Specify export attributes in case of IPEK\nexport. This parameter is optional for KEK export.\n\n  * `ExportKeyIdentifier`: The `KeyARN` of the KEK or BDK (in case of\nIPEK) under export.\n\n  * `KeyMaterial`: Use `Tr34KeyBlock` parameters.\n\n  * `CertificateAuthorityPublicKeyIdentifier`: The `KeyARN` of the\ncertificate chain that signed the KRD wrapping key certificate.\n\n  * `ExportToken`: Obtained from KDH by calling\n`GetParametersForImport`.\n\n  * `WrappingKeyCertificate`: The public key certificate in PEM format\n(base64 encoded) of the KRD wrapping key Amazon Web Services Payment\nCryptography uses for encryption of the TR-34 export payload. This certificate\nmust be signed by the root certificate (CertificateAuthorityPublicKeyIdentifier)\nimported into Amazon Web Services Payment Cryptography.\n\nWhen this operation is successful, Amazon Web Services Payment Cryptography\nreturns the KEK or IPEK as a TR-34 WrappedKeyBlock.","ref":"AWS.PaymentCryptography.html#export_key/3-to-export-initial-keys-kek-or-ipek-using-tr-34","title":"To export initial keys (KEK) or IPEK using TR-34 - AWS.PaymentCryptography.export_key/3","type":"function"},{"doc":"Using this operation, you can export initial key using asymmetric RSA wrap and\nunwrap key exchange method. To initiate export, generate an asymmetric key pair\non the receiving HSM and obtain the public key certificate in PEM format (base64\nencoded) for the purpose of wrapping and the root certifiate chain. Import the\nroot certificate into Amazon Web Services Payment Cryptography by calling\n`ImportKey` for `RootCertificatePublicKey`.\n\nNext call `ExportKey` and set the following parameters:\n\n  * `CertificateAuthorityPublicKeyIdentifier`: The `KeyARN` of the\ncertificate chain that signed wrapping key certificate.\n\n  * `KeyMaterial`: Set to `KeyCryptogram`.\n\n  * `WrappingKeyCertificate`: The public key certificate in PEM format\n(base64 encoded) obtained by the receiving HSM and signed by the root\ncertificate (CertificateAuthorityPublicKeyIdentifier) imported into Amazon Web\nServices Payment Cryptography. The receiving HSM uses its private key component\nto unwrap the WrappedKeyCryptogram.\n\nWhen this operation is successful, Amazon Web Services Payment Cryptography\nreturns the WrappedKeyCryptogram.","ref":"AWS.PaymentCryptography.html#export_key/3-to-export-initial-keys-kek-or-ipek-using-rsa-wrap-and-unwrap","title":"To export initial keys (KEK) or IPEK using RSA Wrap and Unwrap - AWS.PaymentCryptography.export_key/3","type":"function"},{"doc":"Using this operation, you can export working keys or IPEK using TR-31 symmetric\nkey exchange. In TR-31, you must use an initial key such as KEK to encrypt or\nwrap the key under export. To establish a KEK, you can use `CreateKey` or\n`ImportKey`.\n\nSet the following parameters:\n\n  * `ExportAttributes`: Specify export attributes in case of IPEK\nexport. This parameter is optional for KEK export.\n\n  * `ExportKeyIdentifier`: The `KeyARN` of the KEK or BDK (in case of\nIPEK) under export.\n\n  * `KeyMaterial`: Use `Tr31KeyBlock` parameters.\n\nWhen this operation is successful, Amazon Web Services Payment Cryptography\nreturns the working key or IPEK as a TR-31 WrappedKeyBlock.\n\n**Cross-account use:** This operation can't be used across different Amazon Web\nServices accounts.","ref":"AWS.PaymentCryptography.html#export_key/3-to-export-working-keys-or-ipek-using-tr-31","title":"To export working keys or IPEK using TR-31 - AWS.PaymentCryptography.export_key/3","type":"function"},{"doc":"* `GetParametersForExport`\n\n  * `ImportKey`","ref":"AWS.PaymentCryptography.html#export_key/3-related-operations","title":"Related operations: - AWS.PaymentCryptography.export_key/3","type":"function"},{"doc":"Gets the Amazon Web Services Payment Cryptography key associated with the alias.\n\n**Cross-account use:** This operation can't be used across different Amazon Web\nServices accounts.","ref":"AWS.PaymentCryptography.html#get_alias/3","title":"AWS.PaymentCryptography.get_alias/3","type":"function"},{"doc":"* `CreateAlias`\n\n  * `DeleteAlias`\n\n  * `ListAliases`\n\n  * `UpdateAlias`","ref":"AWS.PaymentCryptography.html#get_alias/3-related-operations","title":"Related operations: - AWS.PaymentCryptography.get_alias/3","type":"function"},{"doc":"Gets the key material for an Amazon Web Services Payment Cryptography key,\nincluding the immutable and mutable data specified when the key was created.\n\n**Cross-account use:** This operation can't be used across different Amazon Web\nServices accounts.","ref":"AWS.PaymentCryptography.html#get_key/3","title":"AWS.PaymentCryptography.get_key/3","type":"function"},{"doc":"* `CreateKey`\n\n  * `DeleteKey`\n\n  * `ListKeys`","ref":"AWS.PaymentCryptography.html#get_key/3-related-operations","title":"Related operations: - AWS.PaymentCryptography.get_key/3","type":"function"},{"doc":"Gets the export token and the signing key certificate to initiate a TR-34 key\nexport from Amazon Web Services Payment Cryptography.\n\nThe signing key certificate signs the wrapped key under export within the TR-34\nkey payload. The export token and signing key certificate must be in place and\noperational before calling `ExportKey`. The export token expires in 7 days. You\ncan use the same export token to export multiple keys from your service account.\n\n**Cross-account use:** This operation can't be used across different Amazon Web\nServices accounts.","ref":"AWS.PaymentCryptography.html#get_parameters_for_export/3","title":"AWS.PaymentCryptography.get_parameters_for_export/3","type":"function"},{"doc":"* `ExportKey`\n\n  * `GetParametersForImport`","ref":"AWS.PaymentCryptography.html#get_parameters_for_export/3-related-operations","title":"Related operations: - AWS.PaymentCryptography.get_parameters_for_export/3","type":"function"},{"doc":"Gets the import token and the wrapping key certificate in PEM format (base64\nencoded) to initiate a TR-34 WrappedKeyBlock or a RSA WrappedKeyCryptogram\nimport into Amazon Web Services Payment Cryptography.\n\nThe wrapping key certificate wraps the key under import. The import token and\nwrapping key certificate must be in place and operational before calling\n`ImportKey`. The import token expires in 7 days. You can use the same import\ntoken to import multiple keys into your service account.\n\n**Cross-account use:** This operation can't be used across different Amazon Web\nServices accounts.","ref":"AWS.PaymentCryptography.html#get_parameters_for_import/3","title":"AWS.PaymentCryptography.get_parameters_for_import/3","type":"function"},{"doc":"* `GetParametersForExport`\n\n  * `ImportKey`","ref":"AWS.PaymentCryptography.html#get_parameters_for_import/3-related-operations","title":"Related operations: - AWS.PaymentCryptography.get_parameters_for_import/3","type":"function"},{"doc":"Gets the public key certificate of the asymmetric key pair that exists within\nAmazon Web Services Payment Cryptography.\n\nUnlike the private key of an asymmetric key, which never leaves Amazon Web\nServices Payment Cryptography unencrypted, callers with\n`GetPublicKeyCertificate` permission can download the public key certificate of\nthe asymmetric key. You can share the public key certificate to allow others to\nencrypt messages and verify signatures outside of Amazon Web Services Payment\nCryptography\n\n**Cross-account use:** This operation can't be used across different Amazon Web\nServices accounts.","ref":"AWS.PaymentCryptography.html#get_public_key_certificate/3","title":"AWS.PaymentCryptography.get_public_key_certificate/3","type":"function"},{"doc":"Imports symmetric keys and public key certificates in PEM format (base64\nencoded) into Amazon Web Services Payment Cryptography.\n\nAmazon Web Services Payment Cryptography simplifies key exchange by replacing\nthe existing paper-based approach with a modern electronic approach. With\n`ImportKey` you can import symmetric keys using either symmetric and asymmetric\nkey exchange mechanisms.\n\nFor symmetric key exchange, Amazon Web Services Payment Cryptography uses the\nANSI X9 TR-31 norm in accordance with PCI PIN guidelines. And for asymmetric key\nexchange, Amazon Web Services Payment Cryptography supports ANSI X9 TR-34 norm\nand RSA wrap and unwrap key exchange mechanisms. Asymmetric key exchange methods\nare typically used to establish bi-directional trust between the two parties\nexhanging keys and are used for initial key exchange such as Key Encryption Key\n(KEK) or Zone Master Key (ZMK). After which you can import working keys using\nsymmetric method to perform various cryptographic operations within Amazon Web\nServices Payment Cryptography.\n\nThe TR-34 norm is intended for exchanging 3DES keys only and keys are imported\nin a WrappedKeyBlock format. Key attributes (such as KeyUsage, KeyAlgorithm,\nKeyModesOfUse, Exportability) are contained within the key block. With RSA wrap\nand unwrap, you can exchange both 3DES and AES-128 keys. The keys are imported\nin a WrappedKeyCryptogram format and you will need to specify the key attributes\nduring import.\n\nYou can also import a *root public key certificate*, used to sign other public\nkey certificates, or a *trusted public key certificate* under an already\nestablished root public key certificate.","ref":"AWS.PaymentCryptography.html#import_key/3","title":"AWS.PaymentCryptography.import_key/3","type":"function"},{"doc":"You can also import a *root public key certificate*, used to sign other public\nkey certificates, or a *trusted public key certificate* under an already\nestablished root public key certificate.","ref":"AWS.PaymentCryptography.html#import_key/3-to-import-a-public-root-key-certificate","title":"To import a public root key certificate - AWS.PaymentCryptography.import_key/3","type":"function"},{"doc":"Using this operation, you can import the public component (in PEM cerificate\nformat) of your private root key. You can use the imported public root key\ncertificate for digital signatures, for example signing wrapping key or signing\nkey in TR-34, within your Amazon Web Services Payment Cryptography account.\n\nSet the following parameters:\n\n  * `KeyMaterial`: `RootCertificatePublicKey`\n\n  * `KeyClass`: `PUBLIC_KEY`\n\n  * `KeyModesOfUse`: `Verify`\n\n  * `KeyUsage`: `TR31_S0_ASYMMETRIC_KEY_FOR_DIGITAL_SIGNATURE`\n\n  * `PublicKeyCertificate`: The public key certificate in PEM format\n(base64 encoded) of the private root key under import.","ref":"AWS.PaymentCryptography.html#import_key/3-to-import-a-public-root-key-certificate","title":"To import a public root key certificate - AWS.PaymentCryptography.import_key/3","type":"function"},{"doc":"The root public key certificate must be in place and operational before you\nimport a trusted public key certificate. Set the following parameters:\n\n  * `KeyMaterial`: `TrustedCertificatePublicKey`\n\n  * `CertificateAuthorityPublicKeyIdentifier`: `KeyArn` of the\n`RootCertificatePublicKey`.\n\n  * `KeyModesOfUse` and `KeyUsage`: Corresponding to the cryptographic\noperations such as wrap, sign, or encrypt that you will allow the trusted public\nkey certificate to perform.\n\n  * `PublicKeyCertificate`: The trusted public key certificate in PEM\nformat (base64 encoded) under import.","ref":"AWS.PaymentCryptography.html#import_key/3-to-import-a-trusted-public-key-certificate","title":"To import a trusted public key certificate - AWS.PaymentCryptography.import_key/3","type":"function"},{"doc":"Using this operation, you can import initial key using TR-34 asymmetric key\nexchange. In TR-34 terminology, the sending party of the key is called Key\nDistribution Host (KDH) and the receiving party of the key is called Key\nReceiving Device (KRD). During the key import process, KDH is the user who\ninitiates the key import and KRD is Amazon Web Services Payment Cryptography who\nreceives the key.\n\nTo initiate TR-34 key import, the KDH must obtain an import token by calling\n`GetParametersForImport`. This operation generates an encryption keypair for the\npurpose of key import, signs the key and returns back the wrapping key\ncertificate (also known as KRD wrapping certificate) and the root certificate\nchain. The KDH must trust and install the KRD wrapping certificate on its HSM\nand use it to encrypt (wrap) the KDH key during TR-34 WrappedKeyBlock\ngeneration. The import token and associated KRD wrapping certificate expires\nafter 7 days.\n\nNext the KDH generates a key pair for the purpose of signing the encrypted KDH\nkey and provides the public certificate of the signing key to Amazon Web\nServices Payment Cryptography. The KDH will also need to import the root\ncertificate chain of the KDH signing certificate by calling `ImportKey` for\n`RootCertificatePublicKey`. For more information on TR-34 key import, see\nsection [Importing symmetric keys](https://docs.aws.amazon.com/payment-cryptography/latest/userguide/keys-import.html)\nin the *Amazon Web Services Payment Cryptography User Guide*.\n\nSet the following parameters:\n\n  * `KeyMaterial`: Use `Tr34KeyBlock` parameters.\n\n  * `CertificateAuthorityPublicKeyIdentifier`: The `KeyARN` of the\ncertificate chain that signed the KDH signing key certificate.\n\n  * `ImportToken`: Obtained from KRD by calling\n`GetParametersForImport`.\n\n  * `WrappedKeyBlock`: The TR-34 wrapped key material from KDH. It\ncontains the KDH key under import, wrapped with KRD wrapping certificate and\nsigned by KDH signing private key. This TR-34 key block is typically generated\nby the KDH Hardware Security Module (HSM) outside of Amazon Web Services Payment\nCryptography.\n\n  * `SigningKeyCertificate`: The public key certificate in PEM format\n(base64 encoded) of the KDH signing key generated under the root certificate\n(CertificateAuthorityPublicKeyIdentifier) imported in Amazon Web Services\nPayment Cryptography.","ref":"AWS.PaymentCryptography.html#import_key/3-to-import-initial-keys-kek-or-zmk-or-similar-using-tr-34","title":"To import initial keys (KEK or ZMK or similar) using TR-34 - AWS.PaymentCryptography.import_key/3","type":"function"},{"doc":"Using this operation, you can import initial key using asymmetric RSA wrap and\nunwrap key exchange method. To initiate import, call `GetParametersForImport`\nwith `KeyMaterial` set to `KEY_CRYPTOGRAM` to generate an import token. This\noperation also generates an encryption keypair for the purpose of key import,\nsigns the key and returns back the wrapping key certificate in PEM format\n(base64 encoded) and its root certificate chain. The import token and associated\nKRD wrapping certificate expires after 7 days.\n\nYou must trust and install the wrapping certificate and its certificate chain on\nthe sending HSM and use it to wrap the key under export for WrappedKeyCryptogram\ngeneration. Next call `ImportKey` with `KeyMaterial` set to `KEY_CRYPTOGRAM` and\nprovide the `ImportToken` and `KeyAttributes` for the key under import.","ref":"AWS.PaymentCryptography.html#import_key/3-to-import-initial-keys-kek-or-zmk-or-similar-using-rsa-wrap-and-unwrap","title":"To import initial keys (KEK or ZMK or similar) using RSA Wrap and Unwrap - AWS.PaymentCryptography.import_key/3","type":"function"},{"doc":"Amazon Web Services Payment Cryptography uses TR-31 symmetric key exchange norm\nto import working keys. A KEK must be established within Amazon Web Services\nPayment Cryptography by using TR-34 key import or by using `CreateKey`. To\ninitiate a TR-31 key import, set the following parameters:\n\n  * `KeyMaterial`: Use `Tr31KeyBlock` parameters.\n\n  * `WrappedKeyBlock`: The TR-31 wrapped key material. It contains the\nkey under import, encrypted using KEK. The TR-31 key block is typically\ngenerated by a HSM outside of Amazon Web Services Payment Cryptography.\n\n  * `WrappingKeyIdentifier`: The `KeyArn` of the KEK that Amazon Web\nServices Payment Cryptography uses to decrypt or unwrap the key under import.\n\n**Cross-account use:** This operation can't be used across different Amazon Web\nServices accounts.","ref":"AWS.PaymentCryptography.html#import_key/3-to-import-working-keys-using-tr-31","title":"To import working keys using TR-31 - AWS.PaymentCryptography.import_key/3","type":"function"},{"doc":"* `ExportKey`\n\n  * `GetParametersForImport`","ref":"AWS.PaymentCryptography.html#import_key/3-related-operations","title":"Related operations: - AWS.PaymentCryptography.import_key/3","type":"function"},{"doc":"Lists the aliases for all keys in the caller's Amazon Web Services account and\nAmazon Web Services Region.\n\nYou can filter the list of aliases. For more information, see [Using aliases](https://docs.aws.amazon.com/payment-cryptography/latest/userguide/keys-managealias.html)\nin the *Amazon Web Services Payment Cryptography User Guide*.\n\nThis is a paginated operation, which means that each response might contain only\na subset of all the aliases. When the response contains only a subset of\naliases, it includes a `NextToken` value. Use this value in a subsequent\n`ListAliases` request to get more aliases. When you receive a response with no\nNextToken (or an empty or null value), that means there are no more aliases to\nget.\n\n**Cross-account use:** This operation can't be used across different Amazon Web\nServices accounts.","ref":"AWS.PaymentCryptography.html#list_aliases/3","title":"AWS.PaymentCryptography.list_aliases/3","type":"function"},{"doc":"* `CreateAlias`\n\n  * `DeleteAlias`\n\n  * `GetAlias`\n\n  * `UpdateAlias`","ref":"AWS.PaymentCryptography.html#list_aliases/3-related-operations","title":"Related operations: - AWS.PaymentCryptography.list_aliases/3","type":"function"},{"doc":"Lists the keys in the caller's Amazon Web Services account and Amazon Web\nServices Region.\n\nYou can filter the list of keys.\n\nThis is a paginated operation, which means that each response might contain only\na subset of all the keys. When the response contains only a subset of keys, it\nincludes a `NextToken` value. Use this value in a subsequent `ListKeys` request\nto get more keys. When you receive a response with no NextToken (or an empty or\nnull value), that means there are no more keys to get.\n\n**Cross-account use:** This operation can't be used across different Amazon Web\nServices accounts.","ref":"AWS.PaymentCryptography.html#list_keys/3","title":"AWS.PaymentCryptography.list_keys/3","type":"function"},{"doc":"* `CreateKey`\n\n  * `DeleteKey`\n\n  * `GetKey`","ref":"AWS.PaymentCryptography.html#list_keys/3-related-operations","title":"Related operations: - AWS.PaymentCryptography.list_keys/3","type":"function"},{"doc":"Lists the tags for an Amazon Web Services resource.\n\nThis is a paginated operation, which means that each response might contain only\na subset of all the tags. When the response contains only a subset of tags, it\nincludes a `NextToken` value. Use this value in a subsequent\n`ListTagsForResource` request to get more tags. When you receive a response with\nno NextToken (or an empty or null value), that means there are no more tags to\nget.\n\n**Cross-account use:** This operation can't be used across different Amazon Web\nServices accounts.","ref":"AWS.PaymentCryptography.html#list_tags_for_resource/3","title":"AWS.PaymentCryptography.list_tags_for_resource/3","type":"function"},{"doc":"* `TagResource`\n\n  * `UntagResource`","ref":"AWS.PaymentCryptography.html#list_tags_for_resource/3-related-operations","title":"Related operations: - AWS.PaymentCryptography.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.PaymentCryptography.html#metadata/0","title":"AWS.PaymentCryptography.metadata/0","type":"function"},{"doc":"Cancels a scheduled key deletion during the waiting period.\n\nUse this operation to restore a `Key` that is scheduled for deletion.\n\nDuring the waiting period, the `KeyState` is `DELETE_PENDING` and\n`deletePendingTimestamp` contains the date and time after which the `Key` will\nbe deleted. After `Key` is restored, the `KeyState` is `CREATE_COMPLETE`, and\nthe value for `deletePendingTimestamp` is removed.\n\n**Cross-account use:** This operation can't be used across different Amazon Web\nServices accounts.","ref":"AWS.PaymentCryptography.html#restore_key/3","title":"AWS.PaymentCryptography.restore_key/3","type":"function"},{"doc":"* `DeleteKey`\n\n  * `StartKeyUsage`\n\n  * `StopKeyUsage`","ref":"AWS.PaymentCryptography.html#restore_key/3-related-operations","title":"Related operations: - AWS.PaymentCryptography.restore_key/3","type":"function"},{"doc":"Enables an Amazon Web Services Payment Cryptography key, which makes it active\nfor cryptographic operations within Amazon Web Services Payment Cryptography\n\n**Cross-account use:** This operation can't be used across different Amazon Web\nServices accounts.","ref":"AWS.PaymentCryptography.html#start_key_usage/3","title":"AWS.PaymentCryptography.start_key_usage/3","type":"function"},{"doc":"* `StopKeyUsage`","ref":"AWS.PaymentCryptography.html#start_key_usage/3-related-operations","title":"Related operations: - AWS.PaymentCryptography.start_key_usage/3","type":"function"},{"doc":"Disables an Amazon Web Services Payment Cryptography key, which makes it\ninactive within Amazon Web Services Payment Cryptography.\n\nYou can use this operation instead of `DeleteKey` to deactivate a key. You can\nenable the key in the future by calling `StartKeyUsage`.\n\n**Cross-account use:** This operation can't be used across different Amazon Web\nServices accounts.","ref":"AWS.PaymentCryptography.html#stop_key_usage/3","title":"AWS.PaymentCryptography.stop_key_usage/3","type":"function"},{"doc":"* `DeleteKey`\n\n  * `StartKeyUsage`","ref":"AWS.PaymentCryptography.html#stop_key_usage/3-related-operations","title":"Related operations: - AWS.PaymentCryptography.stop_key_usage/3","type":"function"},{"doc":"Adds or edits tags on an Amazon Web Services Payment Cryptography key.\n\nTagging or untagging an Amazon Web Services Payment Cryptography key can allow\nor deny permission to the key.\n\nEach tag consists of a tag key and a tag value, both of which are case-sensitive\nstrings. The tag value can be an empty (null) string. To add a tag, specify a\nnew tag key and a tag value. To edit a tag, specify an existing tag key and a\nnew tag value. You can also add tags to an Amazon Web Services Payment\nCryptography key when you create it with `CreateKey`.\n\n**Cross-account use:** This operation can't be used across different Amazon Web\nServices accounts.","ref":"AWS.PaymentCryptography.html#tag_resource/3","title":"AWS.PaymentCryptography.tag_resource/3","type":"function"},{"doc":"* `ListTagsForResource`\n\n  * `UntagResource`","ref":"AWS.PaymentCryptography.html#tag_resource/3-related-operations","title":"Related operations: - AWS.PaymentCryptography.tag_resource/3","type":"function"},{"doc":"Deletes a tag from an Amazon Web Services Payment Cryptography key.\n\nTagging or untagging an Amazon Web Services Payment Cryptography key can allow\nor deny permission to the key.\n\n**Cross-account use:** This operation can't be used across different Amazon Web\nServices accounts.","ref":"AWS.PaymentCryptography.html#untag_resource/3","title":"AWS.PaymentCryptography.untag_resource/3","type":"function"},{"doc":"* `ListTagsForResource`\n\n  * `TagResource`","ref":"AWS.PaymentCryptography.html#untag_resource/3-related-operations","title":"Related operations: - AWS.PaymentCryptography.untag_resource/3","type":"function"},{"doc":"Associates an existing Amazon Web Services Payment Cryptography alias with a\ndifferent key.\n\nEach alias is associated with only one Amazon Web Services Payment Cryptography\nkey at a time, although a key can have multiple aliases. The alias and the\nAmazon Web Services Payment Cryptography key must be in the same Amazon Web\nServices account and Amazon Web Services Region\n\n**Cross-account use:** This operation can't be used across different Amazon Web\nServices accounts.","ref":"AWS.PaymentCryptography.html#update_alias/3","title":"AWS.PaymentCryptography.update_alias/3","type":"function"},{"doc":"* `CreateAlias`\n\n  * `DeleteAlias`\n\n  * `GetAlias`\n\n  * `ListAliases`","ref":"AWS.PaymentCryptography.html#update_alias/3-related-operations","title":"Related operations: - AWS.PaymentCryptography.update_alias/3","type":"function"},{"doc":"You use the Amazon Web Services Payment Cryptography Data Plane to manage how\nencryption keys are used for payment-related transaction processing and\nassociated cryptographic operations.\n\nYou can encrypt, decrypt, generate, verify, and translate payment-related\ncryptographic operations in Amazon Web Services Payment Cryptography. For more\ninformation, see [Data operations](https://docs.aws.amazon.com/payment-cryptography/latest/userguide/data-operations.html)\nin the *Amazon Web Services Payment Cryptography User Guide*.\n\nTo manage your encryption keys, you use the [Amazon Web Services Payment Cryptography Control\nPlane](https://docs.aws.amazon.com/payment-cryptography/latest/APIReference/Welcome.html).\nYou can create, import, export, share, manage, and delete keys. You can also\nmanage Identity and Access Management (IAM) policies for keys.","ref":"AWS.PaymentCryptographyData.html","title":"AWS.PaymentCryptographyData","type":"module"},{"doc":"Decrypts ciphertext data to plaintext using symmetric, asymmetric, or DUKPT data\nencryption key.\n\nFor more information, see [Decrypt data](https://docs.aws.amazon.com/payment-cryptography/latest/userguide/decrypt-data.html)\nin the *Amazon Web Services Payment Cryptography User Guide*.\n\nYou can use an encryption key generated within Amazon Web Services Payment\nCryptography, or you can import your own encryption key by calling\n[ImportKey](https://docs.aws.amazon.com/payment-cryptography/latest/APIReference/API_ImportKey.html). For this operation, the key must have `KeyModesOfUse` set to `Decrypt`. In\nasymmetric decryption, Amazon Web Services Payment Cryptography decrypts the\nciphertext using the private component of the asymmetric encryption key pair.\nFor data encryption outside of Amazon Web Services Payment Cryptography, you can\nexport the public component of the asymmetric key pair by calling\n[GetPublicCertificate](https://docs.aws.amazon.com/payment-cryptography/latest/APIReference/API_GetPublicKeyCertificate.html).\n\nFor symmetric and DUKPT decryption, Amazon Web Services Payment Cryptography\nsupports `TDES` and `AES` algorithms. For asymmetric decryption, Amazon Web\nServices Payment Cryptography supports `RSA`. When you use DUKPT, for `TDES`\nalgorithm, the ciphertext data length must be a multiple of 16 bytes. For `AES`\nalgorithm, the ciphertext data length must be a multiple of 32 bytes.\n\nFor information about valid keys for this operation, see [Understanding key attributes](https://docs.aws.amazon.com/payment-cryptography/latest/userguide/keys-validattributes.html)\nand [Key types for specific data operations](https://docs.aws.amazon.com/payment-cryptography/latest/userguide/crypto-ops-validkeys-ops.html)\nin the *Amazon Web Services Payment Cryptography User Guide*.\n\n**Cross-account use**: This operation can't be used across different Amazon Web\nServices accounts.","ref":"AWS.PaymentCryptographyData.html#decrypt_data/4","title":"AWS.PaymentCryptographyData.decrypt_data/4","type":"function"},{"doc":"* `EncryptData`\n\n  *\n[GetPublicCertificate](https://docs.aws.amazon.com/payment-cryptography/latest/APIReference/API_GetPublicKeyCertificate.html)     *\n[ImportKey](https://docs.aws.amazon.com/payment-cryptography/latest/APIReference/API_ImportKey.html)","ref":"AWS.PaymentCryptographyData.html#decrypt_data/4-related-operations","title":"Related operations: - AWS.PaymentCryptographyData.decrypt_data/4","type":"function"},{"doc":"Encrypts plaintext data to ciphertext using symmetric, asymmetric, or DUKPT data\nencryption key.\n\nFor more information, see [Encrypt data](https://docs.aws.amazon.com/payment-cryptography/latest/userguide/encrypt-data.html)\nin the *Amazon Web Services Payment Cryptography User Guide*.\n\nYou can generate an encryption key within Amazon Web Services Payment\nCryptography by calling\n[CreateKey](https://docs.aws.amazon.com/payment-cryptography/latest/APIReference/API_CreateKey.html). You can import your own encryption key by calling\n[ImportKey](https://docs.aws.amazon.com/payment-cryptography/latest/APIReference/API_ImportKey.html).\nFor this operation, the key must have `KeyModesOfUse` set to `Encrypt`. In\nasymmetric encryption, plaintext is encrypted using public component. You can\nimport the public component of an asymmetric key pair created outside Amazon Web\nServices Payment Cryptography by calling\n[ImportKey](https://docs.aws.amazon.com/payment-cryptography/latest/APIReference/API_ImportKey.html)).  for symmetric and DUKPT encryption, Amazon Web Services Payment Cryptography\nsupports `TDES` and `AES` algorithms. For asymmetric encryption, Amazon Web\nServices Payment Cryptography supports `RSA`. To encrypt using DUKPT, you must\nalready have a DUKPT key in your account with `KeyModesOfUse` set to\n`DeriveKey`, or you can generate a new DUKPT key by calling\n[CreateKey](https://docs.aws.amazon.com/payment-cryptography/latest/APIReference/API_CreateKey.html).\n\nFor information about valid keys for this operation, see [Understanding key attributes](https://docs.aws.amazon.com/payment-cryptography/latest/userguide/keys-validattributes.html)\nand [Key types for specific data operations](https://docs.aws.amazon.com/payment-cryptography/latest/userguide/crypto-ops-validkeys-ops.html)\nin the *Amazon Web Services Payment Cryptography User Guide*.\n\n**Cross-account use**: This operation can't be used across different Amazon Web\nServices accounts.","ref":"AWS.PaymentCryptographyData.html#encrypt_data/4","title":"AWS.PaymentCryptographyData.encrypt_data/4","type":"function"},{"doc":"* `DecryptData`\n\n  *\n[GetPublicCertificate](https://docs.aws.amazon.com/payment-cryptography/latest/APIReference/API_GetPublicKeyCertificate.html)     *\n[ImportKey](https://docs.aws.amazon.com/payment-cryptography/latest/APIReference/API_ImportKey.html)\n\n  * `ReEncryptData`","ref":"AWS.PaymentCryptographyData.html#encrypt_data/4-related-operations","title":"Related operations: - AWS.PaymentCryptographyData.encrypt_data/4","type":"function"},{"doc":"Generates card-related validation data using algorithms such as Card\nVerification Values (CVV/CVV2), Dynamic Card Verification Values (dCVV/dCVV2),\nor Card Security Codes (CSC).\n\nFor more information, see [Generate card data](https://docs.aws.amazon.com/payment-cryptography/latest/userguide/generate-card-data.html)\nin the *Amazon Web Services Payment Cryptography User Guide*.\n\nThis operation generates a CVV or CSC value that is printed on a payment credit\nor debit card during card production. The CVV or CSC, PAN (Primary Account\nNumber) and expiration date of the card are required to check its validity\nduring transaction processing. To begin this operation, a CVK (Card Verification\nKey) encryption key is required. You can use\n[CreateKey](https://docs.aws.amazon.com/payment-cryptography/latest/APIReference/API_CreateKey.html) or\n[ImportKey](https://docs.aws.amazon.com/payment-cryptography/latest/APIReference/API_ImportKey.html)\nto establish a CVK within Amazon Web Services Payment Cryptography. The\n`KeyModesOfUse` should be set to `Generate` and `Verify` for a CVK encryption\nkey.\n\nFor information about valid keys for this operation, see [Understanding key attributes](https://docs.aws.amazon.com/payment-cryptography/latest/userguide/keys-validattributes.html)\nand [Key types for specific data operations](https://docs.aws.amazon.com/payment-cryptography/latest/userguide/crypto-ops-validkeys-ops.html)\nin the *Amazon Web Services Payment Cryptography User Guide*.\n\n**Cross-account use**: This operation can't be used across different Amazon Web\nServices accounts.","ref":"AWS.PaymentCryptographyData.html#generate_card_validation_data/3","title":"AWS.PaymentCryptographyData.generate_card_validation_data/3","type":"function"},{"doc":"*\n[ImportKey](https://docs.aws.amazon.com/payment-cryptography/latest/APIReference/API_ImportKey.html)\n\n  * `VerifyCardValidationData`","ref":"AWS.PaymentCryptographyData.html#generate_card_validation_data/3-related-operations","title":"Related operations: - AWS.PaymentCryptographyData.generate_card_validation_data/3","type":"function"},{"doc":"Generates a Message Authentication Code (MAC) cryptogram within Amazon Web\nServices Payment Cryptography.\n\nYou can use this operation when keys won't be shared but mutual data is present\non both ends for validation. In this case, known data values are used to\ngenerate a MAC on both ends for comparision without sending or receiving data in\nciphertext or plaintext. You can use this operation to generate a DUPKT, HMAC or\nEMV MAC by setting generation attributes and algorithm to the associated values.\nThe MAC generation encryption key must have valid values for `KeyUsage` such as\n`TR31_M7_HMAC_KEY` for HMAC generation, and they key must have `KeyModesOfUse`\nset to `Generate` and `Verify`.\n\nFor information about valid keys for this operation, see [Understanding key attributes](https://docs.aws.amazon.com/payment-cryptography/latest/userguide/keys-validattributes.html)\nand [Key types for specific data operations](https://docs.aws.amazon.com/payment-cryptography/latest/userguide/crypto-ops-validkeys-ops.html)\nin the *Amazon Web Services Payment Cryptography User Guide*.\n\n**Cross-account use**: This operation can't be used across different Amazon Web\nServices accounts.","ref":"AWS.PaymentCryptographyData.html#generate_mac/3","title":"AWS.PaymentCryptographyData.generate_mac/3","type":"function"},{"doc":"* `VerifyMac`","ref":"AWS.PaymentCryptographyData.html#generate_mac/3-related-operations","title":"Related operations: - AWS.PaymentCryptographyData.generate_mac/3","type":"function"},{"doc":"Generates pin-related data such as PIN, PIN Verification Value (PVV), PIN Block,\nand PIN Offset during new card issuance or reissuance.\n\nFor more information, see [Generate PIN data](https://docs.aws.amazon.com/payment-cryptography/latest/userguide/generate-pin-data.html)\nin the *Amazon Web Services Payment Cryptography User Guide*.\n\nPIN data is never transmitted in clear to or from Amazon Web Services Payment\nCryptography. This operation generates PIN, PVV, or PIN Offset and then encrypts\nit using Pin Encryption Key (PEK) to create an `EncryptedPinBlock` for\ntransmission from Amazon Web Services Payment Cryptography. This operation uses\na separate Pin Verification Key (PVK) for VISA PVV generation.\n\nFor information about valid keys for this operation, see [Understanding key attributes](https://docs.aws.amazon.com/payment-cryptography/latest/userguide/keys-validattributes.html)\nand [Key types for specific data operations](https://docs.aws.amazon.com/payment-cryptography/latest/userguide/crypto-ops-validkeys-ops.html)\nin the *Amazon Web Services Payment Cryptography User Guide*.\n\n**Cross-account use**: This operation can't be used across different Amazon Web\nServices accounts.","ref":"AWS.PaymentCryptographyData.html#generate_pin_data/3","title":"AWS.PaymentCryptographyData.generate_pin_data/3","type":"function"},{"doc":"* `GenerateCardValidationData`\n\n  * `TranslatePinData`\n\n  * `VerifyPinData`","ref":"AWS.PaymentCryptographyData.html#generate_pin_data/3-related-operations","title":"Related operations: - AWS.PaymentCryptographyData.generate_pin_data/3","type":"function"},{"doc":"","ref":"AWS.PaymentCryptographyData.html#metadata/0","title":"AWS.PaymentCryptographyData.metadata/0","type":"function"},{"doc":"Re-encrypt ciphertext using DUKPT, Symmetric and Asymmetric Data Encryption\nKeys.\n\nYou can either generate an encryption key within Amazon Web Services Payment\nCryptography by calling\n[CreateKey](https://docs.aws.amazon.com/payment-cryptography/latest/APIReference/API_CreateKey.html) or import your own encryption key by calling\n[ImportKey](https://docs.aws.amazon.com/payment-cryptography/latest/APIReference/API_ImportKey.html).\nThe `KeyArn` for use with this operation must be in a compatible key state with\n`KeyModesOfUse` set to `Encrypt`. In asymmetric encryption, ciphertext is\nencrypted using public component (imported by calling\n[ImportKey](https://docs.aws.amazon.com/payment-cryptography/latest/APIReference/API_ImportKey.html)) of the asymmetric key pair created outside of Amazon Web Services Payment\nCryptography.\n\nFor symmetric and DUKPT encryption, Amazon Web Services Payment Cryptography\nsupports `TDES` and `AES` algorithms. For asymmetric encryption, Amazon Web\nServices Payment Cryptography supports `RSA`. To encrypt using DUKPT, a DUKPT\nkey must already exist within your account with `KeyModesOfUse` set to\n`DeriveKey` or a new DUKPT can be generated by calling\n[CreateKey](https://docs.aws.amazon.com/payment-cryptography/latest/APIReference/API_CreateKey.html).\n\nFor information about valid keys for this operation, see [Understanding key attributes](https://docs.aws.amazon.com/payment-cryptography/latest/userguide/keys-validattributes.html)\nand [Key types for specific data operations](https://docs.aws.amazon.com/payment-cryptography/latest/userguide/crypto-ops-validkeys-ops.html)\nin the *Amazon Web Services Payment Cryptography User Guide*.\n\n**Cross-account use**: This operation can't be used across different Amazon Web\nServices accounts.","ref":"AWS.PaymentCryptographyData.html#re_encrypt_data/4","title":"AWS.PaymentCryptographyData.re_encrypt_data/4","type":"function"},{"doc":"* `DecryptData`\n\n  * `EncryptData`\n\n  *\n[GetPublicCertificate](https://docs.aws.amazon.com/payment-cryptography/latest/APIReference/API_GetPublicKeyCertificate.html)     *\n[ImportKey](https://docs.aws.amazon.com/payment-cryptography/latest/APIReference/API_ImportKey.html)","ref":"AWS.PaymentCryptographyData.html#re_encrypt_data/4-related-operations","title":"Related operations: - AWS.PaymentCryptographyData.re_encrypt_data/4","type":"function"},{"doc":"Translates encrypted PIN block from and to ISO 9564 formats 0,1,3,4.\n\nFor more information, see [Translate PIN data](https://docs.aws.amazon.com/payment-cryptography/latest/userguide/translate-pin-data.html)\nin the *Amazon Web Services Payment Cryptography User Guide*.\n\nPIN block translation involves changing the encrytion of PIN block from one\nencryption key to another encryption key and changing PIN block format from one\nto another without PIN block data leaving Amazon Web Services Payment\nCryptography. The encryption key transformation can be from PEK (Pin Encryption\nKey) to BDK (Base Derivation Key) for DUKPT or from BDK for DUKPT to PEK. Amazon\nWeb Services Payment Cryptography supports `TDES` and `AES` key derivation type\nfor DUKPT tranlations. You can use this operation for P2PE (Point to Point\nEncryption) use cases where the encryption keys should change but the processing\nsystem either does not need to, or is not permitted to, decrypt the data.\n\nThe allowed combinations of PIN block format translations are guided by PCI. It\nis important to note that not all encrypted PIN block formats (example, format\n1) require PAN (Primary Account Number) as input. And as such, PIN block format\nthat requires PAN (example, formats 0,3,4) cannot be translated to a format\n(format 1) that does not require a PAN for generation.\n\nFor information about valid keys for this operation, see [Understanding key attributes](https://docs.aws.amazon.com/payment-cryptography/latest/userguide/keys-validattributes.html)\nand [Key types for specific data operations](https://docs.aws.amazon.com/payment-cryptography/latest/userguide/crypto-ops-validkeys-ops.html)\nin the *Amazon Web Services Payment Cryptography User Guide*.\n\nAt this time, Amazon Web Services Payment Cryptography does not support\ntranslations to PIN format 4.\n\n**Cross-account use**: This operation can't be used across different Amazon Web\nServices accounts.","ref":"AWS.PaymentCryptographyData.html#translate_pin_data/3","title":"AWS.PaymentCryptographyData.translate_pin_data/3","type":"function"},{"doc":"* `GeneratePinData`\n\n  * `VerifyPinData`","ref":"AWS.PaymentCryptographyData.html#translate_pin_data/3-related-operations","title":"Related operations: - AWS.PaymentCryptographyData.translate_pin_data/3","type":"function"},{"doc":"Verifies Authorization Request Cryptogram (ARQC) for a EMV chip payment card\nauthorization.\n\nFor more information, see [Verify auth request cryptogram](https://docs.aws.amazon.com/payment-cryptography/latest/userguide/data-operations.verifyauthrequestcryptogram.html)\nin the *Amazon Web Services Payment Cryptography User Guide*.\n\nARQC generation is done outside of Amazon Web Services Payment Cryptography and\nis typically generated on a point of sale terminal for an EMV chip card to\nobtain payment authorization during transaction time. For ARQC verification, you\nmust first import the ARQC generated outside of Amazon Web Services Payment\nCryptography by calling\n[ImportKey](https://docs.aws.amazon.com/payment-cryptography/latest/APIReference/API_ImportKey.html). This operation uses the imported ARQC and an major encryption key (DUKPT)\ncreated by calling\n[CreateKey](https://docs.aws.amazon.com/payment-cryptography/latest/APIReference/API_CreateKey.html)\nto either provide a boolean ARQC verification result or provide an APRC\n(Authorization Response Cryptogram) response using Method 1 or Method 2. The\n`ARPC_METHOD_1` uses `AuthResponseCode` to generate ARPC and `ARPC_METHOD_2`\nuses `CardStatusUpdate` to generate ARPC.\n\nFor information about valid keys for this operation, see [Understanding key attributes](https://docs.aws.amazon.com/payment-cryptography/latest/userguide/keys-validattributes.html)\nand [Key types for specific data operations](https://docs.aws.amazon.com/payment-cryptography/latest/userguide/crypto-ops-validkeys-ops.html)\nin the *Amazon Web Services Payment Cryptography User Guide*.\n\n**Cross-account use**: This operation can't be used across different Amazon Web\nServices accounts.","ref":"AWS.PaymentCryptographyData.html#verify_auth_request_cryptogram/3","title":"AWS.PaymentCryptographyData.verify_auth_request_cryptogram/3","type":"function"},{"doc":"* `VerifyCardValidationData`\n\n  * `VerifyPinData`","ref":"AWS.PaymentCryptographyData.html#verify_auth_request_cryptogram/3-related-operations","title":"Related operations: - AWS.PaymentCryptographyData.verify_auth_request_cryptogram/3","type":"function"},{"doc":"Verifies card-related validation data using algorithms such as Card Verification\nValues (CVV/CVV2), Dynamic Card Verification Values (dCVV/dCVV2) and Card\nSecurity Codes (CSC).\n\nFor more information, see [Verify card data](https://docs.aws.amazon.com/payment-cryptography/latest/userguide/verify-card-data.html)\nin the *Amazon Web Services Payment Cryptography User Guide*.\n\nThis operation validates the CVV or CSC codes that is printed on a payment\ncredit or debit card during card payment transaction. The input values are\ntypically provided as part of an inbound transaction to an issuer or supporting\nplatform partner. Amazon Web Services Payment Cryptography uses CVV or CSC, PAN\n(Primary Account Number) and expiration date of the card to check its validity\nduring transaction processing. In this operation, the CVK (Card Verification\nKey) encryption key for use with card data verification is same as the one in\nused for `GenerateCardValidationData`.\n\nFor information about valid keys for this operation, see [Understanding key attributes](https://docs.aws.amazon.com/payment-cryptography/latest/userguide/keys-validattributes.html)\nand [Key types for specific data operations](https://docs.aws.amazon.com/payment-cryptography/latest/userguide/crypto-ops-validkeys-ops.html)\nin the *Amazon Web Services Payment Cryptography User Guide*.\n\n**Cross-account use**: This operation can't be used across different Amazon Web\nServices accounts.","ref":"AWS.PaymentCryptographyData.html#verify_card_validation_data/3","title":"AWS.PaymentCryptographyData.verify_card_validation_data/3","type":"function"},{"doc":"* `GenerateCardValidationData`\n\n  * `VerifyAuthRequestCryptogram`\n\n  * `VerifyPinData`","ref":"AWS.PaymentCryptographyData.html#verify_card_validation_data/3-related-operations","title":"Related operations: - AWS.PaymentCryptographyData.verify_card_validation_data/3","type":"function"},{"doc":"Verifies a Message Authentication Code (MAC).\n\nYou can use this operation when keys won't be shared but mutual data is present\non both ends for validation. In this case, known data values are used to\ngenerate a MAC on both ends for verification without sending or receiving data\nin ciphertext or plaintext. You can use this operation to verify a DUPKT, HMAC\nor EMV MAC by setting generation attributes and algorithm to the associated\nvalues. Use the same encryption key for MAC verification as you use for\n`GenerateMac`.\n\nFor information about valid keys for this operation, see [Understanding key attributes](https://docs.aws.amazon.com/payment-cryptography/latest/userguide/keys-validattributes.html)\nand [Key types for specific data operations](https://docs.aws.amazon.com/payment-cryptography/latest/userguide/crypto-ops-validkeys-ops.html)\nin the *Amazon Web Services Payment Cryptography User Guide*.\n\n**Cross-account use**: This operation can't be used across different Amazon Web\nServices accounts.","ref":"AWS.PaymentCryptographyData.html#verify_mac/3","title":"AWS.PaymentCryptographyData.verify_mac/3","type":"function"},{"doc":"* `GenerateMac`","ref":"AWS.PaymentCryptographyData.html#verify_mac/3-related-operations","title":"Related operations: - AWS.PaymentCryptographyData.verify_mac/3","type":"function"},{"doc":"Verifies pin-related data such as PIN and PIN Offset using algorithms including\nVISA PVV and IBM3624.\n\nFor more information, see [Verify PIN data](https://docs.aws.amazon.com/payment-cryptography/latest/userguide/verify-pin-data.html)\nin the *Amazon Web Services Payment Cryptography User Guide*.\n\nThis operation verifies PIN data for user payment card. A card holder PIN data\nis never transmitted in clear to or from Amazon Web Services Payment\nCryptography. This operation uses PIN Verification Key (PVK) for PIN or PIN\nOffset generation and then encrypts it using PIN Encryption Key (PEK) to create\nan `EncryptedPinBlock` for transmission from Amazon Web Services Payment\nCryptography.\n\nFor information about valid keys for this operation, see [Understanding key attributes](https://docs.aws.amazon.com/payment-cryptography/latest/userguide/keys-validattributes.html)\nand [Key types for specific data operations](https://docs.aws.amazon.com/payment-cryptography/latest/userguide/crypto-ops-validkeys-ops.html)\nin the *Amazon Web Services Payment Cryptography User Guide*.\n\n**Cross-account use**: This operation can't be used across different Amazon Web\nServices accounts.","ref":"AWS.PaymentCryptographyData.html#verify_pin_data/3","title":"AWS.PaymentCryptographyData.verify_pin_data/3","type":"function"},{"doc":"* `GeneratePinData`\n\n  * `TranslatePinData`","ref":"AWS.PaymentCryptographyData.html#verify_pin_data/3-related-operations","title":"Related operations: - AWS.PaymentCryptographyData.verify_pin_data/3","type":"function"},{"doc":"Amazon Web Services Private CA Connector for Active Directory creates a\nconnector between Amazon Web Services Private CA and Active Directory (AD) that\nenables you to provision security certificates for AD signed by a private CA\nthat you own.\n\nFor more information, see [Amazon Web Services Private CA Connector for Active Directory](https://docs.aws.amazon.com/privateca/latest/userguide/ad-connector.html).","ref":"AWS.PcaConnectorAd.html","title":"AWS.PcaConnectorAd","type":"module"},{"doc":"Creates a connector between Amazon Web Services Private CA and an Active\nDirectory.\n\nYou must specify the private CA, directory ID, and security groups.","ref":"AWS.PcaConnectorAd.html#create_connector/3","title":"AWS.PcaConnectorAd.create_connector/3","type":"function"},{"doc":"Creates a directory registration that authorizes communication between Amazon\nWeb Services Private CA and an Active Directory","ref":"AWS.PcaConnectorAd.html#create_directory_registration/3","title":"AWS.PcaConnectorAd.create_directory_registration/3","type":"function"},{"doc":"Creates a service principal name (SPN) for the service account in Active\nDirectory.\n\nKerberos authentication uses SPNs to associate a service instance with a service\nsign-in account.","ref":"AWS.PcaConnectorAd.html#create_service_principal_name/5","title":"AWS.PcaConnectorAd.create_service_principal_name/5","type":"function"},{"doc":"Creates an Active Directory compatible certificate template.\n\nThe connectors issues certificates using these templates based on the\nrequester’s Active Directory group membership.","ref":"AWS.PcaConnectorAd.html#create_template/3","title":"AWS.PcaConnectorAd.create_template/3","type":"function"},{"doc":"Create a group access control entry.\n\nAllow or deny Active Directory groups from enrolling and/or autoenrolling with\nthe template based on the group security identifiers (SIDs).","ref":"AWS.PcaConnectorAd.html#create_template_group_access_control_entry/4","title":"AWS.PcaConnectorAd.create_template_group_access_control_entry/4","type":"function"},{"doc":"Deletes a connector for Active Directory.\n\nYou must provide the Amazon Resource Name (ARN) of the connector that you want\nto delete. You can find the ARN by calling the\n[https://docs.aws.amazon.com/pca-connector-ad/latest/APIReference/API_ListConnectors](https://docs.aws.amazon.com/pca-connector-ad/latest/APIReference/API_ListConnectors) action. Deleting a connector does not deregister your directory with Amazon Web\nServices Private CA. You can deregister your directory by calling the\n[https://docs.aws.amazon.com/pca-connector-ad/latest/APIReference/API_DeleteDirectoryRegistration](https://docs.aws.amazon.com/pca-connector-ad/latest/APIReference/API_DeleteDirectoryRegistration)\naction.","ref":"AWS.PcaConnectorAd.html#delete_connector/4","title":"AWS.PcaConnectorAd.delete_connector/4","type":"function"},{"doc":"Deletes a directory registration.\n\nDeleting a directory registration deauthorizes Amazon Web Services Private CA\nwith the directory.","ref":"AWS.PcaConnectorAd.html#delete_directory_registration/4","title":"AWS.PcaConnectorAd.delete_directory_registration/4","type":"function"},{"doc":"Deletes the service principal name (SPN) used by a connector to authenticate\nwith your Active Directory.","ref":"AWS.PcaConnectorAd.html#delete_service_principal_name/5","title":"AWS.PcaConnectorAd.delete_service_principal_name/5","type":"function"},{"doc":"Deletes a template.\n\nCertificates issued using the template are still valid until they are revoked or\nexpired.","ref":"AWS.PcaConnectorAd.html#delete_template/4","title":"AWS.PcaConnectorAd.delete_template/4","type":"function"},{"doc":"Deletes a group access control entry.","ref":"AWS.PcaConnectorAd.html#delete_template_group_access_control_entry/5","title":"AWS.PcaConnectorAd.delete_template_group_access_control_entry/5","type":"function"},{"doc":"Lists information about your connector.\n\nYou specify the connector on input by its ARN (Amazon Resource Name).","ref":"AWS.PcaConnectorAd.html#get_connector/3","title":"AWS.PcaConnectorAd.get_connector/3","type":"function"},{"doc":"A structure that contains information about your directory registration.","ref":"AWS.PcaConnectorAd.html#get_directory_registration/3","title":"AWS.PcaConnectorAd.get_directory_registration/3","type":"function"},{"doc":"Lists the service principal name that the connector uses to authenticate with\nActive Directory.","ref":"AWS.PcaConnectorAd.html#get_service_principal_name/4","title":"AWS.PcaConnectorAd.get_service_principal_name/4","type":"function"},{"doc":"Retrieves a certificate template that the connector uses to issue certificates\nfrom a private CA.","ref":"AWS.PcaConnectorAd.html#get_template/3","title":"AWS.PcaConnectorAd.get_template/3","type":"function"},{"doc":"Retrieves the group access control entries for a template.","ref":"AWS.PcaConnectorAd.html#get_template_group_access_control_entry/4","title":"AWS.PcaConnectorAd.get_template_group_access_control_entry/4","type":"function"},{"doc":"Lists the connectors that you created by using the\n[https://docs.aws.amazon.com/pca-connector-ad/latest/APIReference/API_CreateConnector](https://docs.aws.amazon.com/pca-connector-ad/latest/APIReference/API_CreateConnector)\naction.","ref":"AWS.PcaConnectorAd.html#list_connectors/4","title":"AWS.PcaConnectorAd.list_connectors/4","type":"function"},{"doc":"Lists the directory registrations that you created by using the\n[https://docs.aws.amazon.com/pca-connector-ad/latest/APIReference/API_CreateDirectoryRegistration](https://docs.aws.amazon.com/pca-connector-ad/latest/APIReference/API_CreateDirectoryRegistration)\naction.","ref":"AWS.PcaConnectorAd.html#list_directory_registrations/4","title":"AWS.PcaConnectorAd.list_directory_registrations/4","type":"function"},{"doc":"Lists the service principal names that the connector uses to authenticate with\nActive Directory.","ref":"AWS.PcaConnectorAd.html#list_service_principal_names/5","title":"AWS.PcaConnectorAd.list_service_principal_names/5","type":"function"},{"doc":"Lists the tags, if any, that are associated with your resource.","ref":"AWS.PcaConnectorAd.html#list_tags_for_resource/3","title":"AWS.PcaConnectorAd.list_tags_for_resource/3","type":"function"},{"doc":"Lists group access control entries you created.","ref":"AWS.PcaConnectorAd.html#list_template_group_access_control_entries/5","title":"AWS.PcaConnectorAd.list_template_group_access_control_entries/5","type":"function"},{"doc":"Lists the templates, if any, that are associated with a connector.","ref":"AWS.PcaConnectorAd.html#list_templates/5","title":"AWS.PcaConnectorAd.list_templates/5","type":"function"},{"doc":"","ref":"AWS.PcaConnectorAd.html#metadata/0","title":"AWS.PcaConnectorAd.metadata/0","type":"function"},{"doc":"Adds one or more tags to your resource.","ref":"AWS.PcaConnectorAd.html#tag_resource/4","title":"AWS.PcaConnectorAd.tag_resource/4","type":"function"},{"doc":"Removes one or more tags from your resource.","ref":"AWS.PcaConnectorAd.html#untag_resource/4","title":"AWS.PcaConnectorAd.untag_resource/4","type":"function"},{"doc":"Update template configuration to define the information included in\ncertificates.","ref":"AWS.PcaConnectorAd.html#update_template/4","title":"AWS.PcaConnectorAd.update_template/4","type":"function"},{"doc":"Update a group access control entry you created using\n[CreateTemplateGroupAccessControlEntry](https://docs.aws.amazon.com/pca-connector-ad/latest/APIReference/API_CreateTemplateGroupAccessControlEntry.html).","ref":"AWS.PcaConnectorAd.html#update_template_group_access_control_entry/5","title":"AWS.PcaConnectorAd.update_template_group_access_control_entry/5","type":"function"},{"doc":"Amazon Personalize is a machine learning service that makes it easy to add\nindividualized recommendations to customers.","ref":"AWS.Personalize.html","title":"AWS.Personalize","type":"module"},{"doc":"Generates batch recommendations based on a list of items or users stored in\nAmazon S3 and exports the recommendations to an Amazon S3 bucket.\n\nTo generate batch recommendations, specify the ARN of a solution version and an\nAmazon S3 URI for the input and output data. For user personalization, popular\nitems, and personalized ranking solutions, the batch inference job generates a\nlist of recommended items for each user ID in the input file. For related items\nsolutions, the job generates a list of recommended items for each item ID in the\ninput file.\n\nFor more information, see [Creating a batch inference job\n](https://docs.aws.amazon.com/personalize/latest/dg/getting-batch-recommendations.html).\n\nIf you use the Similar-Items recipe, Amazon Personalize can add descriptive\nthemes to batch recommendations. To generate themes, set the job's mode to\n`THEME_GENERATION` and specify the name of the field that contains item names in\nthe input data.\n\nFor more information about generating themes, see [Batch recommendations with themes from Content Generator\n](https://docs.aws.amazon.com/personalize/latest/dg/themed-batch-recommendations.html).\n\nYou can't get batch recommendations with the Trending-Now or Next-Best-Action\nrecipes.","ref":"AWS.Personalize.html#create_batch_inference_job/3","title":"AWS.Personalize.create_batch_inference_job/3","type":"function"},{"doc":"Creates a batch segment job.\n\nThe operation can handle up to 50 million records and the input file must be in\nJSON format. For more information, see [Getting batch recommendations and user segments](https://docs.aws.amazon.com/personalize/latest/dg/recommendations-batch.html).","ref":"AWS.Personalize.html#create_batch_segment_job/3","title":"AWS.Personalize.create_batch_segment_job/3","type":"function"},{"doc":"Creates a campaign that deploys a solution version.\n\nWhen a client calls the\n[GetRecommendations](https://docs.aws.amazon.com/personalize/latest/dg/API_RS_GetRecommendations.html) and\n[GetPersonalizedRanking](https://docs.aws.amazon.com/personalize/latest/dg/API_RS_GetPersonalizedRanking.html)\nAPIs, a campaign is specified in the request.","ref":"AWS.Personalize.html#create_campaign/3","title":"AWS.Personalize.create_campaign/3","type":"function"},{"doc":"A high `minProvisionedTPS` will increase your cost. We recommend starting with 1\nfor `minProvisionedTPS` (the default). Track your usage using Amazon CloudWatch\nmetrics, and increase the `minProvisionedTPS` as necessary.\n\nWhen you create an Amazon Personalize campaign, you can specify the minimum\nprovisioned transactions per second (`minProvisionedTPS`) for the campaign. This\nis the baseline transaction throughput for the campaign provisioned by Amazon\nPersonalize. It sets the minimum billing charge for the campaign while it is\nactive. A transaction is a single `GetRecommendations` or\n`GetPersonalizedRanking` request. The default `minProvisionedTPS` is 1.\n\nIf your TPS increases beyond the `minProvisionedTPS`, Amazon Personalize\nauto-scales the provisioned capacity up and down, but never below\n`minProvisionedTPS`. There's a short time delay while the capacity is increased\nthat might cause loss of transactions. When your traffic reduces, capacity\nreturns to the `minProvisionedTPS`.\n\nYou are charged for the the minimum provisioned TPS or, if your requests exceed\nthe `minProvisionedTPS`, the actual TPS. The actual TPS is the total number of\nrecommendation requests you make. We recommend starting with a low\n`minProvisionedTPS`, track your usage using Amazon CloudWatch metrics, and then\nincrease the `minProvisionedTPS` as necessary.\n\nFor more information about campaign costs, see [Amazon Personalize pricing](https://aws.amazon.com/personalize/pricing/).","ref":"AWS.Personalize.html#create_campaign/3-minimum-provisioned-tps-and-auto-scaling","title":"Minimum Provisioned TPS and Auto-Scaling - AWS.Personalize.create_campaign/3","type":"function"},{"doc":"A campaign can be in one of the following states:\n\n  * CREATE PENDING > CREATE IN_PROGRESS > ACTIVE -or- CREATE FAILED\n\n  * DELETE PENDING > DELETE IN_PROGRESS\n\nTo get the campaign status, call\n[DescribeCampaign](https://docs.aws.amazon.com/personalize/latest/dg/API_DescribeCampaign.html).  Wait until the `status` of the campaign is `ACTIVE` before asking the campaign\nfor recommendations.","ref":"AWS.Personalize.html#create_campaign/3-status","title":"Status - AWS.Personalize.create_campaign/3","type":"function"},{"doc":"*\n[ListCampaigns](https://docs.aws.amazon.com/personalize/latest/dg/API_ListCampaigns.html)\n\n  *\n[DescribeCampaign](https://docs.aws.amazon.com/personalize/latest/dg/API_DescribeCampaign.html)     *\n[UpdateCampaign](https://docs.aws.amazon.com/personalize/latest/dg/API_UpdateCampaign.html)\n\n  *\n[DeleteCampaign](https://docs.aws.amazon.com/personalize/latest/dg/API_DeleteCampaign.html)","ref":"AWS.Personalize.html#create_campaign/3-related-apis","title":"Related APIs - AWS.Personalize.create_campaign/3","type":"function"},{"doc":"Creates an empty dataset and adds it to the specified dataset group.\n\nUse\n[CreateDatasetImportJob](https://docs.aws.amazon.com/personalize/latest/dg/API_CreateDatasetImportJob.html) to import your training data to a dataset.\n\nThere are 5 types of datasets:\n\n  * Item interactions\n\n  * Items\n\n  * Users\n\n  * Action interactions\n\n  * Actions\n\nEach dataset type has an associated schema with required field types. Only the\n`Item interactions` dataset is required in order to train a model (also referred\nto as creating a solution).\n\nA dataset can be in one of the following states:\n\n  * CREATE PENDING > CREATE IN_PROGRESS > ACTIVE -or- CREATE FAILED\n\n  * DELETE PENDING > DELETE IN_PROGRESS\n\nTo get the status of the dataset, call\n[DescribeDataset](https://docs.aws.amazon.com/personalize/latest/dg/API_DescribeDataset.html).","ref":"AWS.Personalize.html#create_dataset/3","title":"AWS.Personalize.create_dataset/3","type":"function"},{"doc":"*\n[CreateDatasetGroup](https://docs.aws.amazon.com/personalize/latest/dg/API_CreateDatasetGroup.html)     *\n[ListDatasets](https://docs.aws.amazon.com/personalize/latest/dg/API_ListDatasets.html)\n\n  *\n[DescribeDataset](https://docs.aws.amazon.com/personalize/latest/dg/API_DescribeDataset.html)     *\n[DeleteDataset](https://docs.aws.amazon.com/personalize/latest/dg/API_DeleteDataset.html)","ref":"AWS.Personalize.html#create_dataset/3-related-apis","title":"Related APIs - AWS.Personalize.create_dataset/3","type":"function"},{"doc":"Creates a job that exports data from your dataset to an Amazon S3 bucket.\n\nTo allow Amazon Personalize to export the training data, you must specify an\nservice-linked IAM role that gives Amazon Personalize `PutObject` permissions\nfor your Amazon S3 bucket. For information, see [Exporting a dataset](https://docs.aws.amazon.com/personalize/latest/dg/export-data.html) in\nthe Amazon Personalize developer guide.","ref":"AWS.Personalize.html#create_dataset_export_job/3","title":"AWS.Personalize.create_dataset_export_job/3","type":"function"},{"doc":"A dataset export job can be in one of the following states:\n\n  * CREATE PENDING > CREATE IN_PROGRESS > ACTIVE -or- CREATE FAILED\n\nTo get the status of the export job, call\n[DescribeDatasetExportJob](https://docs.aws.amazon.com/personalize/latest/dg/API_DescribeDatasetExportJob.html),\nand specify the Amazon Resource Name (ARN) of the dataset export job. The\ndataset export is complete when the status shows as ACTIVE. If the status shows\nas CREATE FAILED, the response includes a `failureReason` key, which describes\nwhy the job failed.","ref":"AWS.Personalize.html#create_dataset_export_job/3-status","title":"Status - AWS.Personalize.create_dataset_export_job/3","type":"function"},{"doc":"Creates an empty dataset group.\n\nA dataset group is a container for Amazon Personalize resources. A dataset group\ncan contain at most three datasets, one for each type of dataset:\n\n  * Item interactions\n\n  * Items\n\n  * Users\n\n  * Actions\n\n  * Action interactions\n\nA dataset group can be a Domain dataset group, where you specify a domain and\nuse pre-configured resources like recommenders, or a Custom dataset group, where\nyou use custom resources, such as a solution with a solution version, that you\ndeploy with a campaign. If you start with a Domain dataset group, you can still\nadd custom resources such as solutions and solution versions trained with\nrecipes for custom use cases and deployed with campaigns.\n\nA dataset group can be in one of the following states:\n\n  * CREATE PENDING > CREATE IN_PROGRESS > ACTIVE -or- CREATE FAILED\n\n  * DELETE PENDING\n\nTo get the status of the dataset group, call\n[DescribeDatasetGroup](https://docs.aws.amazon.com/personalize/latest/dg/API_DescribeDatasetGroup.html). If the status shows as CREATE FAILED, the response includes a `failureReason`\nkey, which describes why the creation failed.\n\nYou must wait until the `status` of the dataset group is `ACTIVE` before adding\na dataset to the group.\n\nYou can specify an Key Management Service (KMS) key to encrypt the datasets in\nthe group. If you specify a KMS key, you must also include an Identity and\nAccess Management (IAM) role that has permission to access the key.","ref":"AWS.Personalize.html#create_dataset_group/3","title":"AWS.Personalize.create_dataset_group/3","type":"function"},{"doc":"*\n[CreateDataset](https://docs.aws.amazon.com/personalize/latest/dg/API_CreateDataset.html)\n\n  *\n[CreateEventTracker](https://docs.aws.amazon.com/personalize/latest/dg/API_CreateEventTracker.html)     *\n[CreateSolution](https://docs.aws.amazon.com/personalize/latest/dg/API_CreateSolution.html)","ref":"AWS.Personalize.html#create_dataset_group/3-apis-that-require-a-dataset-group-arn-in-the-request","title":"APIs that require a dataset group ARN in the request - AWS.Personalize.create_dataset_group/3","type":"function"},{"doc":"*\n[ListDatasetGroups](https://docs.aws.amazon.com/personalize/latest/dg/API_ListDatasetGroups.html)     *\n[DescribeDatasetGroup](https://docs.aws.amazon.com/personalize/latest/dg/API_DescribeDatasetGroup.html)\n\n  *\n[DeleteDatasetGroup](https://docs.aws.amazon.com/personalize/latest/dg/API_DeleteDatasetGroup.html)","ref":"AWS.Personalize.html#create_dataset_group/3-related-apis","title":"Related APIs - AWS.Personalize.create_dataset_group/3","type":"function"},{"doc":"Creates a job that imports training data from your data source (an Amazon S3\nbucket) to an Amazon Personalize dataset.\n\nTo allow Amazon Personalize to import the training data, you must specify an IAM\nservice role that has permission to read from the data source, as Amazon\nPersonalize makes a copy of your data and processes it internally. For\ninformation on granting access to your Amazon S3 bucket, see [Giving Amazon Personalize Access to Amazon S3\nResources](https://docs.aws.amazon.com/personalize/latest/dg/granting-personalize-s3-access.html).\n\nIf you already created a recommender or deployed a custom solution version with\na campaign, how new bulk records influence recommendations depends on the domain\nuse case or recipe that you use. For more information, see [How new data influences real-time\nrecommendations](https://docs.aws.amazon.com/personalize/latest/dg/how-new-data-influences-recommendations.html).\n\nBy default, a dataset import job replaces any existing data in the dataset that\nyou imported in bulk. To add new records without replacing existing data,\nspecify INCREMENTAL for the import mode in the CreateDatasetImportJob operation.","ref":"AWS.Personalize.html#create_dataset_import_job/3","title":"AWS.Personalize.create_dataset_import_job/3","type":"function"},{"doc":"A dataset import job can be in one of the following states:\n\n  * CREATE PENDING > CREATE IN_PROGRESS > ACTIVE -or- CREATE FAILED\n\nTo get the status of the import job, call\n[DescribeDatasetImportJob](https://docs.aws.amazon.com/personalize/latest/dg/API_DescribeDatasetImportJob.html), providing the Amazon Resource Name (ARN) of the dataset import job. The dataset\nimport is complete when the status shows as ACTIVE. If the status shows as\nCREATE FAILED, the response includes a `failureReason` key, which describes why\nthe job failed.\n\nImporting takes time. You must wait until the status shows as ACTIVE before\ntraining a model using the dataset.","ref":"AWS.Personalize.html#create_dataset_import_job/3-status","title":"Status - AWS.Personalize.create_dataset_import_job/3","type":"function"},{"doc":"*\n[ListDatasetImportJobs](https://docs.aws.amazon.com/personalize/latest/dg/API_ListDatasetImportJobs.html)\n\n  *\n[DescribeDatasetImportJob](https://docs.aws.amazon.com/personalize/latest/dg/API_DescribeDatasetImportJob.html)","ref":"AWS.Personalize.html#create_dataset_import_job/3-related-apis","title":"Related APIs - AWS.Personalize.create_dataset_import_job/3","type":"function"},{"doc":"Creates an event tracker that you use when adding event data to a specified\ndataset group using the\n[PutEvents](https://docs.aws.amazon.com/personalize/latest/dg/API_UBS_PutEvents.html) API.\n\nOnly one event tracker can be associated with a dataset group. You will get an\nerror if you call `CreateEventTracker` using the same dataset group as an\nexisting event tracker.\n\nWhen you create an event tracker, the response includes a tracking ID, which you\npass as a parameter when you use the\n[PutEvents](https://docs.aws.amazon.com/personalize/latest/dg/API_UBS_PutEvents.html)\noperation. Amazon Personalize then appends the event data to the Item\ninteractions dataset of the dataset group you specify in your event tracker.\n\nThe event tracker can be in one of the following states:\n\n  * CREATE PENDING > CREATE IN_PROGRESS > ACTIVE -or- CREATE FAILED\n\n  * DELETE PENDING > DELETE IN_PROGRESS\n\nTo get the status of the event tracker, call\n[DescribeEventTracker](https://docs.aws.amazon.com/personalize/latest/dg/API_DescribeEventTracker.html).  The event tracker must be in the ACTIVE state before using the tracking ID.","ref":"AWS.Personalize.html#create_event_tracker/3","title":"AWS.Personalize.create_event_tracker/3","type":"function"},{"doc":"*\n[ListEventTrackers](https://docs.aws.amazon.com/personalize/latest/dg/API_ListEventTrackers.html)\n\n  *\n[DescribeEventTracker](https://docs.aws.amazon.com/personalize/latest/dg/API_DescribeEventTracker.html)     *\n[DeleteEventTracker](https://docs.aws.amazon.com/personalize/latest/dg/API_DeleteEventTracker.html)","ref":"AWS.Personalize.html#create_event_tracker/3-related-apis","title":"Related APIs - AWS.Personalize.create_event_tracker/3","type":"function"},{"doc":"Creates a recommendation filter.\n\nFor more information, see [Filtering recommendations and user segments](https://docs.aws.amazon.com/personalize/latest/dg/filter.html).","ref":"AWS.Personalize.html#create_filter/3","title":"AWS.Personalize.create_filter/3","type":"function"},{"doc":"Creates a metric attribution.\n\nA metric attribution creates reports on the data that you import into Amazon\nPersonalize. Depending on how you imported the data, you can view reports in\nAmazon CloudWatch or Amazon S3. For more information, see [Measuring impact of recommendations](https://docs.aws.amazon.com/personalize/latest/dg/measuring-recommendation-impact.html).","ref":"AWS.Personalize.html#create_metric_attribution/3","title":"AWS.Personalize.create_metric_attribution/3","type":"function"},{"doc":"Creates a recommender with the recipe (a Domain dataset group use case) you\nspecify.\n\nYou create recommenders for a Domain dataset group and specify the recommender's\nAmazon Resource Name (ARN) when you make a\n[GetRecommendations](https://docs.aws.amazon.com/personalize/latest/dg/API_RS_GetRecommendations.html) request.","ref":"AWS.Personalize.html#create_recommender/3","title":"AWS.Personalize.create_recommender/3","type":"function"},{"doc":"A high `minRecommendationRequestsPerSecond` will increase your bill. We\nrecommend starting with 1 for `minRecommendationRequestsPerSecond` (the\ndefault). Track your usage using Amazon CloudWatch metrics, and increase the\n`minRecommendationRequestsPerSecond` as necessary.\n\nWhen you create a recommender, you can configure the recommender's minimum\nrecommendation requests per second. The minimum recommendation requests per\nsecond (`minRecommendationRequestsPerSecond`) specifies the baseline\nrecommendation request throughput provisioned by Amazon Personalize. The default\nminRecommendationRequestsPerSecond is `1`. A recommendation request is a single\n`GetRecommendations` operation. Request throughput is measured in requests per\nsecond and Amazon Personalize uses your requests per second to derive your\nrequests per hour and the price of your recommender usage.\n\nIf your requests per second increases beyond\n`minRecommendationRequestsPerSecond`, Amazon Personalize auto-scales the\nprovisioned capacity up and down, but never below\n`minRecommendationRequestsPerSecond`. There's a short time delay while the\ncapacity is increased that might cause loss of requests.\n\nYour bill is the greater of either the minimum requests per hour (based on\nminRecommendationRequestsPerSecond) or the actual number of requests. The actual\nrequest throughput used is calculated as the average requests/second within a\none-hour window. We recommend starting with the default\n`minRecommendationRequestsPerSecond`, track your usage using Amazon CloudWatch\nmetrics, and then increase the `minRecommendationRequestsPerSecond` as\nnecessary.","ref":"AWS.Personalize.html#create_recommender/3-minimum-recommendation-requests-per-second","title":"Minimum recommendation requests per second - AWS.Personalize.create_recommender/3","type":"function"},{"doc":"A recommender can be in one of the following states:\n\n  * CREATE PENDING > CREATE IN_PROGRESS > ACTIVE -or- CREATE FAILED\n\n  * STOP PENDING > STOP IN_PROGRESS > INACTIVE > START PENDING > START\nIN_PROGRESS > ACTIVE\n\n  * DELETE PENDING > DELETE IN_PROGRESS\n\nTo get the recommender status, call\n[DescribeRecommender](https://docs.aws.amazon.com/personalize/latest/dg/API_DescribeRecommender.html).\n\nWait until the `status` of the recommender is `ACTIVE` before asking the\nrecommender for recommendations.","ref":"AWS.Personalize.html#create_recommender/3-status","title":"Status - AWS.Personalize.create_recommender/3","type":"function"},{"doc":"*\n[ListRecommenders](https://docs.aws.amazon.com/personalize/latest/dg/API_ListRecommenders.html)     *\n[DescribeRecommender](https://docs.aws.amazon.com/personalize/latest/dg/API_DescribeRecommender.html)\n\n  *\n[UpdateRecommender](https://docs.aws.amazon.com/personalize/latest/dg/API_UpdateRecommender.html)     *\n[DeleteRecommender](https://docs.aws.amazon.com/personalize/latest/dg/API_DeleteRecommender.html)","ref":"AWS.Personalize.html#create_recommender/3-related-apis","title":"Related APIs - AWS.Personalize.create_recommender/3","type":"function"},{"doc":"Creates an Amazon Personalize schema from the specified schema string.\n\nThe schema you create must be in Avro JSON format.\n\nAmazon Personalize recognizes three schema variants. Each schema is associated\nwith a dataset type and has a set of required field and keywords. If you are\ncreating a schema for a dataset in a Domain dataset group, you provide the\ndomain of the Domain dataset group. You specify a schema when you call\n[CreateDataset](https://docs.aws.amazon.com/personalize/latest/dg/API_CreateDataset.html).","ref":"AWS.Personalize.html#create_schema/3","title":"AWS.Personalize.create_schema/3","type":"function"},{"doc":"*\n[ListSchemas](https://docs.aws.amazon.com/personalize/latest/dg/API_ListSchemas.html)\n\n  *\n[DescribeSchema](https://docs.aws.amazon.com/personalize/latest/dg/API_DescribeSchema.html)     *\n[DeleteSchema](https://docs.aws.amazon.com/personalize/latest/dg/API_DeleteSchema.html)","ref":"AWS.Personalize.html#create_schema/3-related-apis","title":"Related APIs - AWS.Personalize.create_schema/3","type":"function"},{"doc":"Creates the configuration for training a model.\n\nA trained model is known as a solution version. After the configuration is\ncreated, you train the model (create a solution version) by calling the\n[CreateSolutionVersion](https://docs.aws.amazon.com/personalize/latest/dg/API_CreateSolutionVersion.html) operation. Every time you call `CreateSolutionVersion`, a new version of the\nsolution is created.\n\nAfter creating a solution version, you check its accuracy by calling\n[GetSolutionMetrics](https://docs.aws.amazon.com/personalize/latest/dg/API_GetSolutionMetrics.html).\nWhen you are satisfied with the version, you deploy it using\n[CreateCampaign](https://docs.aws.amazon.com/personalize/latest/dg/API_CreateCampaign.html). The campaign provides recommendations to a client through the\n[GetRecommendations](https://docs.aws.amazon.com/personalize/latest/dg/API_RS_GetRecommendations.html)\nAPI.\n\nTo train a model, Amazon Personalize requires training data and a recipe. The\ntraining data comes from the dataset group that you provide in the request. A\nrecipe specifies the training algorithm and a feature transformation. You can\nspecify one of the predefined recipes provided by Amazon Personalize.\n\nAmazon Personalize doesn't support configuring the `hpoObjective` for solution\nhyperparameter optimization at this time.","ref":"AWS.Personalize.html#create_solution/3","title":"AWS.Personalize.create_solution/3","type":"function"},{"doc":"A solution can be in one of the following states:\n\n  * CREATE PENDING > CREATE IN_PROGRESS > ACTIVE -or- CREATE FAILED\n\n  * DELETE PENDING > DELETE IN_PROGRESS\n\nTo get the status of the solution, call\n[DescribeSolution](https://docs.aws.amazon.com/personalize/latest/dg/API_DescribeSolution.html). Wait until the status shows as ACTIVE before calling `CreateSolutionVersion`.","ref":"AWS.Personalize.html#create_solution/3-status","title":"Status - AWS.Personalize.create_solution/3","type":"function"},{"doc":"*\n[ListSolutions](https://docs.aws.amazon.com/personalize/latest/dg/API_ListSolutions.html)\n\n  *\n[CreateSolutionVersion](https://docs.aws.amazon.com/personalize/latest/dg/API_CreateSolutionVersion.html)     *\n[DescribeSolution](https://docs.aws.amazon.com/personalize/latest/dg/API_DescribeSolution.html)\n\n  *\n[DeleteSolution](https://docs.aws.amazon.com/personalize/latest/dg/API_DeleteSolution.html) \n\n  *\n[ListSolutionVersions](https://docs.aws.amazon.com/personalize/latest/dg/API_ListSolutionVersions.html)\n\n  *\n[DescribeSolutionVersion](https://docs.aws.amazon.com/personalize/latest/dg/API_DescribeSolutionVersion.html)","ref":"AWS.Personalize.html#create_solution/3-related-apis","title":"Related APIs - AWS.Personalize.create_solution/3","type":"function"},{"doc":"Trains or retrains an active solution in a Custom dataset group.\n\nA solution is created using the\n[CreateSolution](https://docs.aws.amazon.com/personalize/latest/dg/API_CreateSolution.html) operation and must be in the ACTIVE state before calling\n`CreateSolutionVersion`. A new version of the solution is created every time you\ncall this operation.","ref":"AWS.Personalize.html#create_solution_version/3","title":"AWS.Personalize.create_solution_version/3","type":"function"},{"doc":"A solution version can be in one of the following states:\n\n  * CREATE PENDING\n\n  * CREATE IN_PROGRESS\n\n  * ACTIVE\n\n  * CREATE FAILED\n\n  * CREATE STOPPING\n\n  * CREATE STOPPED\n\nTo get the status of the version, call\n[DescribeSolutionVersion](https://docs.aws.amazon.com/personalize/latest/dg/API_DescribeSolutionVersion.html).\nWait until the status shows as ACTIVE before calling `CreateCampaign`.\n\nIf the status shows as CREATE FAILED, the response includes a `failureReason`\nkey, which describes why the job failed.","ref":"AWS.Personalize.html#create_solution_version/3-status","title":"Status - AWS.Personalize.create_solution_version/3","type":"function"},{"doc":"*\n[ListSolutionVersions](https://docs.aws.amazon.com/personalize/latest/dg/API_ListSolutionVersions.html)     *\n[DescribeSolutionVersion](https://docs.aws.amazon.com/personalize/latest/dg/API_DescribeSolutionVersion.html)\n\n  *\n[ListSolutions](https://docs.aws.amazon.com/personalize/latest/dg/API_ListSolutions.html)     *\n[CreateSolution](https://docs.aws.amazon.com/personalize/latest/dg/API_CreateSolution.html)\n\n  *\n[DescribeSolution](https://docs.aws.amazon.com/personalize/latest/dg/API_DescribeSolution.html)     *\n[DeleteSolution](https://docs.aws.amazon.com/personalize/latest/dg/API_DeleteSolution.html)","ref":"AWS.Personalize.html#create_solution_version/3-related-apis","title":"Related APIs - AWS.Personalize.create_solution_version/3","type":"function"},{"doc":"Removes a campaign by deleting the solution deployment.\n\nThe solution that the campaign is based on is not deleted and can be redeployed\nwhen needed. A deleted campaign can no longer be specified in a\n[GetRecommendations](https://docs.aws.amazon.com/personalize/latest/dg/API_RS_GetRecommendations.html) request. For information on creating campaigns, see\n[CreateCampaign](https://docs.aws.amazon.com/personalize/latest/dg/API_CreateCampaign.html).","ref":"AWS.Personalize.html#delete_campaign/3","title":"AWS.Personalize.delete_campaign/3","type":"function"},{"doc":"Deletes a dataset.\n\nYou can't delete a dataset if an associated `DatasetImportJob` or\n`SolutionVersion` is in the CREATE PENDING or IN PROGRESS state. For more\ninformation on datasets, see\n[CreateDataset](https://docs.aws.amazon.com/personalize/latest/dg/API_CreateDataset.html).","ref":"AWS.Personalize.html#delete_dataset/3","title":"AWS.Personalize.delete_dataset/3","type":"function"},{"doc":"Deletes a dataset group.\n\nBefore you delete a dataset group, you must delete the following:\n\n  * All associated event trackers.\n\n  * All associated solutions.\n\n  * All datasets in the dataset group.","ref":"AWS.Personalize.html#delete_dataset_group/3","title":"AWS.Personalize.delete_dataset_group/3","type":"function"},{"doc":"Deletes the event tracker.\n\nDoes not delete the dataset from the dataset group. For more information on\nevent trackers, see\n[CreateEventTracker](https://docs.aws.amazon.com/personalize/latest/dg/API_CreateEventTracker.html).","ref":"AWS.Personalize.html#delete_event_tracker/3","title":"AWS.Personalize.delete_event_tracker/3","type":"function"},{"doc":"Deletes a filter.","ref":"AWS.Personalize.html#delete_filter/3","title":"AWS.Personalize.delete_filter/3","type":"function"},{"doc":"Deletes a metric attribution.","ref":"AWS.Personalize.html#delete_metric_attribution/3","title":"AWS.Personalize.delete_metric_attribution/3","type":"function"},{"doc":"Deactivates and removes a recommender.\n\nA deleted recommender can no longer be specified in a\n[GetRecommendations](https://docs.aws.amazon.com/personalize/latest/dg/API_RS_GetRecommendations.html)\nrequest.","ref":"AWS.Personalize.html#delete_recommender/3","title":"AWS.Personalize.delete_recommender/3","type":"function"},{"doc":"Deletes a schema.\n\nBefore deleting a schema, you must delete all datasets referencing the schema.\nFor more information on schemas, see\n[CreateSchema](https://docs.aws.amazon.com/personalize/latest/dg/API_CreateSchema.html).","ref":"AWS.Personalize.html#delete_schema/3","title":"AWS.Personalize.delete_schema/3","type":"function"},{"doc":"Deletes all versions of a solution and the `Solution` object itself.\n\nBefore deleting a solution, you must delete all campaigns based on the solution.\nTo determine what campaigns are using the solution, call\n[ListCampaigns](https://docs.aws.amazon.com/personalize/latest/dg/API_ListCampaigns.html) and supply the Amazon Resource Name (ARN) of the solution. You can't delete a\nsolution if an associated `SolutionVersion` is in the CREATE PENDING or IN\nPROGRESS state. For more information on solutions, see\n[CreateSolution](https://docs.aws.amazon.com/personalize/latest/dg/API_CreateSolution.html).","ref":"AWS.Personalize.html#delete_solution/3","title":"AWS.Personalize.delete_solution/3","type":"function"},{"doc":"Describes the given algorithm.","ref":"AWS.Personalize.html#describe_algorithm/3","title":"AWS.Personalize.describe_algorithm/3","type":"function"},{"doc":"Gets the properties of a batch inference job including name, Amazon Resource\nName (ARN), status, input and output configurations, and the ARN of the solution\nversion used to generate the recommendations.","ref":"AWS.Personalize.html#describe_batch_inference_job/3","title":"AWS.Personalize.describe_batch_inference_job/3","type":"function"},{"doc":"Gets the properties of a batch segment job including name, Amazon Resource Name\n(ARN), status, input and output configurations, and the ARN of the solution\nversion used to generate segments.","ref":"AWS.Personalize.html#describe_batch_segment_job/3","title":"AWS.Personalize.describe_batch_segment_job/3","type":"function"},{"doc":"Describes the given campaign, including its status.\n\nA campaign can be in one of the following states:\n\n  * CREATE PENDING > CREATE IN_PROGRESS > ACTIVE -or- CREATE FAILED\n\n  * DELETE PENDING > DELETE IN_PROGRESS\n\nWhen the `status` is `CREATE FAILED`, the response includes the `failureReason`\nkey, which describes why.\n\nFor more information on campaigns, see\n[CreateCampaign](https://docs.aws.amazon.com/personalize/latest/dg/API_CreateCampaign.html).","ref":"AWS.Personalize.html#describe_campaign/3","title":"AWS.Personalize.describe_campaign/3","type":"function"},{"doc":"Describes the given dataset.\n\nFor more information on datasets, see\n[CreateDataset](https://docs.aws.amazon.com/personalize/latest/dg/API_CreateDataset.html).","ref":"AWS.Personalize.html#describe_dataset/3","title":"AWS.Personalize.describe_dataset/3","type":"function"},{"doc":"Describes the dataset export job created by\n[CreateDatasetExportJob](https://docs.aws.amazon.com/personalize/latest/dg/API_CreateDatasetExportJob.html),\nincluding the export job status.","ref":"AWS.Personalize.html#describe_dataset_export_job/3","title":"AWS.Personalize.describe_dataset_export_job/3","type":"function"},{"doc":"Describes the given dataset group.\n\nFor more information on dataset groups, see\n[CreateDatasetGroup](https://docs.aws.amazon.com/personalize/latest/dg/API_CreateDatasetGroup.html).","ref":"AWS.Personalize.html#describe_dataset_group/3","title":"AWS.Personalize.describe_dataset_group/3","type":"function"},{"doc":"Describes the dataset import job created by\n[CreateDatasetImportJob](https://docs.aws.amazon.com/personalize/latest/dg/API_CreateDatasetImportJob.html),\nincluding the import job status.","ref":"AWS.Personalize.html#describe_dataset_import_job/3","title":"AWS.Personalize.describe_dataset_import_job/3","type":"function"},{"doc":"Describes an event tracker.\n\nThe response includes the `trackingId` and `status` of the event tracker. For\nmore information on event trackers, see\n[CreateEventTracker](https://docs.aws.amazon.com/personalize/latest/dg/API_CreateEventTracker.html).","ref":"AWS.Personalize.html#describe_event_tracker/3","title":"AWS.Personalize.describe_event_tracker/3","type":"function"},{"doc":"Describes the given feature transformation.","ref":"AWS.Personalize.html#describe_feature_transformation/3","title":"AWS.Personalize.describe_feature_transformation/3","type":"function"},{"doc":"Describes a filter's properties.","ref":"AWS.Personalize.html#describe_filter/3","title":"AWS.Personalize.describe_filter/3","type":"function"},{"doc":"Describes a metric attribution.","ref":"AWS.Personalize.html#describe_metric_attribution/3","title":"AWS.Personalize.describe_metric_attribution/3","type":"function"},{"doc":"Describes a recipe.\n\nA recipe contains three items:\n\n  * An algorithm that trains a model.\n\n  * Hyperparameters that govern the training.\n\n  * Feature transformation information for modifying the input data\nbefore training.\n\nAmazon Personalize provides a set of predefined recipes. You specify a recipe\nwhen you create a solution with the\n[CreateSolution](https://docs.aws.amazon.com/personalize/latest/dg/API_CreateSolution.html) API. `CreateSolution` trains a model by using the algorithm in the specified\nrecipe and a training dataset. The solution, when deployed as a campaign, can\nprovide recommendations using the\n[GetRecommendations](https://docs.aws.amazon.com/personalize/latest/dg/API_RS_GetRecommendations.html)\nAPI.","ref":"AWS.Personalize.html#describe_recipe/3","title":"AWS.Personalize.describe_recipe/3","type":"function"},{"doc":"Describes the given recommender, including its status.\n\nA recommender can be in one of the following states:\n\n  * CREATE PENDING > CREATE IN_PROGRESS > ACTIVE -or- CREATE FAILED\n\n  * STOP PENDING > STOP IN_PROGRESS > INACTIVE > START PENDING > START\nIN_PROGRESS > ACTIVE\n\n  * DELETE PENDING > DELETE IN_PROGRESS\n\nWhen the `status` is `CREATE FAILED`, the response includes the `failureReason`\nkey, which describes why.\n\nThe `modelMetrics` key is null when the recommender is being created or deleted.\n\nFor more information on recommenders, see\n[CreateRecommender](https://docs.aws.amazon.com/personalize/latest/dg/API_CreateRecommender.html).","ref":"AWS.Personalize.html#describe_recommender/3","title":"AWS.Personalize.describe_recommender/3","type":"function"},{"doc":"Describes a schema.\n\nFor more information on schemas, see\n[CreateSchema](https://docs.aws.amazon.com/personalize/latest/dg/API_CreateSchema.html).","ref":"AWS.Personalize.html#describe_schema/3","title":"AWS.Personalize.describe_schema/3","type":"function"},{"doc":"Describes a solution.\n\nFor more information on solutions, see\n[CreateSolution](https://docs.aws.amazon.com/personalize/latest/dg/API_CreateSolution.html).","ref":"AWS.Personalize.html#describe_solution/3","title":"AWS.Personalize.describe_solution/3","type":"function"},{"doc":"Describes a specific version of a solution.\n\nFor more information on solutions, see\n[CreateSolution](https://docs.aws.amazon.com/personalize/latest/dg/API_CreateSolution.html)","ref":"AWS.Personalize.html#describe_solution_version/3","title":"AWS.Personalize.describe_solution_version/3","type":"function"},{"doc":"Gets the metrics for the specified solution version.","ref":"AWS.Personalize.html#get_solution_metrics/3","title":"AWS.Personalize.get_solution_metrics/3","type":"function"},{"doc":"Gets a list of the batch inference jobs that have been performed off of a\nsolution version.","ref":"AWS.Personalize.html#list_batch_inference_jobs/3","title":"AWS.Personalize.list_batch_inference_jobs/3","type":"function"},{"doc":"Gets a list of the batch segment jobs that have been performed off of a solution\nversion that you specify.","ref":"AWS.Personalize.html#list_batch_segment_jobs/3","title":"AWS.Personalize.list_batch_segment_jobs/3","type":"function"},{"doc":"Returns a list of campaigns that use the given solution.\n\nWhen a solution is not specified, all the campaigns associated with the account\nare listed. The response provides the properties for each campaign, including\nthe Amazon Resource Name (ARN). For more information on campaigns, see\n[CreateCampaign](https://docs.aws.amazon.com/personalize/latest/dg/API_CreateCampaign.html).","ref":"AWS.Personalize.html#list_campaigns/3","title":"AWS.Personalize.list_campaigns/3","type":"function"},{"doc":"Returns a list of dataset export jobs that use the given dataset.\n\nWhen a dataset is not specified, all the dataset export jobs associated with the\naccount are listed. The response provides the properties for each dataset export\njob, including the Amazon Resource Name (ARN). For more information on dataset\nexport jobs, see\n[CreateDatasetExportJob](https://docs.aws.amazon.com/personalize/latest/dg/API_CreateDatasetExportJob.html). For more information on datasets, see\n[CreateDataset](https://docs.aws.amazon.com/personalize/latest/dg/API_CreateDataset.html).","ref":"AWS.Personalize.html#list_dataset_export_jobs/3","title":"AWS.Personalize.list_dataset_export_jobs/3","type":"function"},{"doc":"Returns a list of dataset groups.\n\nThe response provides the properties for each dataset group, including the\nAmazon Resource Name (ARN). For more information on dataset groups, see\n[CreateDatasetGroup](https://docs.aws.amazon.com/personalize/latest/dg/API_CreateDatasetGroup.html).","ref":"AWS.Personalize.html#list_dataset_groups/3","title":"AWS.Personalize.list_dataset_groups/3","type":"function"},{"doc":"Returns a list of dataset import jobs that use the given dataset.\n\nWhen a dataset is not specified, all the dataset import jobs associated with the\naccount are listed. The response provides the properties for each dataset import\njob, including the Amazon Resource Name (ARN). For more information on dataset\nimport jobs, see\n[CreateDatasetImportJob](https://docs.aws.amazon.com/personalize/latest/dg/API_CreateDatasetImportJob.html). For more information on datasets, see\n[CreateDataset](https://docs.aws.amazon.com/personalize/latest/dg/API_CreateDataset.html).","ref":"AWS.Personalize.html#list_dataset_import_jobs/3","title":"AWS.Personalize.list_dataset_import_jobs/3","type":"function"},{"doc":"Returns the list of datasets contained in the given dataset group.\n\nThe response provides the properties for each dataset, including the Amazon\nResource Name (ARN). For more information on datasets, see\n[CreateDataset](https://docs.aws.amazon.com/personalize/latest/dg/API_CreateDataset.html).","ref":"AWS.Personalize.html#list_datasets/3","title":"AWS.Personalize.list_datasets/3","type":"function"},{"doc":"Returns the list of event trackers associated with the account.\n\nThe response provides the properties for each event tracker, including the\nAmazon Resource Name (ARN) and tracking ID. For more information on event\ntrackers, see\n[CreateEventTracker](https://docs.aws.amazon.com/personalize/latest/dg/API_CreateEventTracker.html).","ref":"AWS.Personalize.html#list_event_trackers/3","title":"AWS.Personalize.list_event_trackers/3","type":"function"},{"doc":"Lists all filters that belong to a given dataset group.","ref":"AWS.Personalize.html#list_filters/3","title":"AWS.Personalize.list_filters/3","type":"function"},{"doc":"Lists the metrics for the metric attribution.","ref":"AWS.Personalize.html#list_metric_attribution_metrics/3","title":"AWS.Personalize.list_metric_attribution_metrics/3","type":"function"},{"doc":"Lists metric attributions.","ref":"AWS.Personalize.html#list_metric_attributions/3","title":"AWS.Personalize.list_metric_attributions/3","type":"function"},{"doc":"Returns a list of available recipes.\n\nThe response provides the properties for each recipe, including the recipe's\nAmazon Resource Name (ARN).","ref":"AWS.Personalize.html#list_recipes/3","title":"AWS.Personalize.list_recipes/3","type":"function"},{"doc":"Returns a list of recommenders in a given Domain dataset group.\n\nWhen a Domain dataset group is not specified, all the recommenders associated\nwith the account are listed. The response provides the properties for each\nrecommender, including the Amazon Resource Name (ARN). For more information on\nrecommenders, see\n[CreateRecommender](https://docs.aws.amazon.com/personalize/latest/dg/API_CreateRecommender.html).","ref":"AWS.Personalize.html#list_recommenders/3","title":"AWS.Personalize.list_recommenders/3","type":"function"},{"doc":"Returns the list of schemas associated with the account.\n\nThe response provides the properties for each schema, including the Amazon\nResource Name (ARN). For more information on schemas, see\n[CreateSchema](https://docs.aws.amazon.com/personalize/latest/dg/API_CreateSchema.html).","ref":"AWS.Personalize.html#list_schemas/3","title":"AWS.Personalize.list_schemas/3","type":"function"},{"doc":"Returns a list of solution versions for the given solution.\n\nWhen a solution is not specified, all the solution versions associated with the\naccount are listed. The response provides the properties for each solution\nversion, including the Amazon Resource Name (ARN).","ref":"AWS.Personalize.html#list_solution_versions/3","title":"AWS.Personalize.list_solution_versions/3","type":"function"},{"doc":"Returns a list of solutions that use the given dataset group.\n\nWhen a dataset group is not specified, all the solutions associated with the\naccount are listed. The response provides the properties for each solution,\nincluding the Amazon Resource Name (ARN). For more information on solutions, see\n[CreateSolution](https://docs.aws.amazon.com/personalize/latest/dg/API_CreateSolution.html).","ref":"AWS.Personalize.html#list_solutions/3","title":"AWS.Personalize.list_solutions/3","type":"function"},{"doc":"Get a list of\n[tags](https://docs.aws.amazon.com/personalize/latest/dg/tagging-resources.html)\nattached to a resource.","ref":"AWS.Personalize.html#list_tags_for_resource/3","title":"AWS.Personalize.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.Personalize.html#metadata/0","title":"AWS.Personalize.metadata/0","type":"function"},{"doc":"Starts a recommender that is INACTIVE.\n\nStarting a recommender does not create any new models, but resumes billing and\nautomatic retraining for the recommender.","ref":"AWS.Personalize.html#start_recommender/3","title":"AWS.Personalize.start_recommender/3","type":"function"},{"doc":"Stops a recommender that is ACTIVE.\n\nStopping a recommender halts billing and automatic retraining for the\nrecommender.","ref":"AWS.Personalize.html#stop_recommender/3","title":"AWS.Personalize.stop_recommender/3","type":"function"},{"doc":"Stops creating a solution version that is in a state of CREATE_PENDING or CREATE\nIN_PROGRESS.\n\nDepending on the current state of the solution version, the solution version\nstate changes as follows:\n\n  * CREATE_PENDING > CREATE_STOPPED\n\nor\n\n  * CREATE_IN_PROGRESS > CREATE_STOPPING > CREATE_STOPPED\n\nYou are billed for all of the training completed up until you stop the solution\nversion creation. You cannot resume creating a solution version once it has been\nstopped.","ref":"AWS.Personalize.html#stop_solution_version_creation/3","title":"AWS.Personalize.stop_solution_version_creation/3","type":"function"},{"doc":"Add a list of tags to a resource.","ref":"AWS.Personalize.html#tag_resource/3","title":"AWS.Personalize.tag_resource/3","type":"function"},{"doc":"Remove\n[tags](https://docs.aws.amazon.com/personalize/latest/dg/tagging-resources.html)\nthat are attached to a resource.","ref":"AWS.Personalize.html#untag_resource/3","title":"AWS.Personalize.untag_resource/3","type":"function"},{"doc":"Updates a campaign to deploy a retrained solution version with an existing\ncampaign, change your campaign's `minProvisionedTPS`, or modify your campaign's\nconfiguration, such as the exploration configuration.\n\nTo update a campaign, the campaign status must be ACTIVE or CREATE FAILED. Check\nthe campaign status using the\n[DescribeCampaign](https://docs.aws.amazon.com/personalize/latest/dg/API_DescribeCampaign.html) operation.\n\nYou can still get recommendations from a campaign while an update is in\nprogress. The campaign will use the previous solution version and campaign\nconfiguration to generate recommendations until the latest campaign update\nstatus is `Active`.\n\nFor more information about updating a campaign, including code samples, see\n[Updating a\ncampaign](https://docs.aws.amazon.com/personalize/latest/dg/update-campaigns.html).\nFor more information about campaigns, see [Creating a campaign](https://docs.aws.amazon.com/personalize/latest/dg/campaigns.html).","ref":"AWS.Personalize.html#update_campaign/3","title":"AWS.Personalize.update_campaign/3","type":"function"},{"doc":"Update a dataset to replace its schema with a new or existing one.\n\nFor more information, see [Replacing a dataset's schema](https://docs.aws.amazon.com/personalize/latest/dg/updating-dataset-schema.html).","ref":"AWS.Personalize.html#update_dataset/3","title":"AWS.Personalize.update_dataset/3","type":"function"},{"doc":"Updates a metric attribution.","ref":"AWS.Personalize.html#update_metric_attribution/3","title":"AWS.Personalize.update_metric_attribution/3","type":"function"},{"doc":"Updates the recommender to modify the recommender configuration.\n\nIf you update the recommender to modify the columns used in training, Amazon\nPersonalize automatically starts a full retraining of the models backing your\nrecommender. While the update completes, you can still get recommendations from\nthe recommender. The recommender uses the previous configuration until the\nupdate completes. To track the status of this update, use the\n`latestRecommenderUpdate` returned in the\n[DescribeRecommender](https://docs.aws.amazon.com/personalize/latest/dg/API_DescribeRecommender.html)\noperation.","ref":"AWS.Personalize.html#update_recommender/3","title":"AWS.Personalize.update_recommender/3","type":"function"},{"doc":"Amazon Personalize can consume real-time user event data, such as *stream* or\n*click* data, and use it for model training either alone or combined with\nhistorical data.\n\nFor more information see [Recording item interaction events](https://docs.aws.amazon.com/personalize/latest/dg/recording-item-interaction-events.html).","ref":"AWS.PersonalizeEvents.html","title":"AWS.PersonalizeEvents","type":"module"},{"doc":"","ref":"AWS.PersonalizeEvents.html#metadata/0","title":"AWS.PersonalizeEvents.metadata/0","type":"function"},{"doc":"Records action interaction event data.\n\nAn *action interaction* event is an interaction between a user and an *action*.\nFor example, a user taking an action, such a enrolling in a membership program\nor downloading your app.\n\nFor more information about recording action interactions, see [Recording action interaction\nevents](https://docs.aws.amazon.com/personalize/latest/dg/recording-action-interaction-events.html).\nFor more information about actions in an Actions dataset, see [Actions dataset](https://docs.aws.amazon.com/personalize/latest/dg/actions-datasets.html).","ref":"AWS.PersonalizeEvents.html#put_action_interactions/3","title":"AWS.PersonalizeEvents.put_action_interactions/3","type":"function"},{"doc":"Adds one or more actions to an Actions dataset.\n\nFor more information see [Importing actions individually](https://docs.aws.amazon.com/personalize/latest/dg/importing-actions.html).","ref":"AWS.PersonalizeEvents.html#put_actions/3","title":"AWS.PersonalizeEvents.put_actions/3","type":"function"},{"doc":"Records item interaction event data.\n\nFor more information see [Recording item interaction events](https://docs.aws.amazon.com/personalize/latest/dg/recording-item-interaction-events.html).","ref":"AWS.PersonalizeEvents.html#put_events/3","title":"AWS.PersonalizeEvents.put_events/3","type":"function"},{"doc":"Adds one or more items to an Items dataset.\n\nFor more information see [Importing items individually](https://docs.aws.amazon.com/personalize/latest/dg/importing-items.html).","ref":"AWS.PersonalizeEvents.html#put_items/3","title":"AWS.PersonalizeEvents.put_items/3","type":"function"},{"doc":"Adds one or more users to a Users dataset.\n\nFor more information see [Importing users individually](https://docs.aws.amazon.com/personalize/latest/dg/importing-users.html).","ref":"AWS.PersonalizeEvents.html#put_users/3","title":"AWS.PersonalizeEvents.put_users/3","type":"function"},{"doc":"","ref":"AWS.PersonalizeRuntime.html","title":"AWS.PersonalizeRuntime","type":"module"},{"doc":"Returns a list of recommended actions in sorted in descending order by\nprediction score.\n\nUse the `GetActionRecommendations` API if you have a custom campaign that\ndeploys a solution version trained with a PERSONALIZED_ACTIONS recipe.\n\nFor more information about PERSONALIZED_ACTIONS recipes, see\n[PERSONALIZED_ACTIONS recipes](https://docs.aws.amazon.com/personalize/latest/dg/nexts-best-action-recipes.html).\nFor more information about getting action recommendations, see [Getting action recommendations](https://docs.aws.amazon.com/personalize/latest/dg/get-action-recommendations.html).","ref":"AWS.PersonalizeRuntime.html#get_action_recommendations/3","title":"AWS.PersonalizeRuntime.get_action_recommendations/3","type":"function"},{"doc":"Re-ranks a list of recommended items for the given user.\n\nThe first item in the list is deemed the most likely item to be of interest to\nthe user.\n\nThe solution backing the campaign must have been created using a recipe of type\nPERSONALIZED_RANKING.","ref":"AWS.PersonalizeRuntime.html#get_personalized_ranking/3","title":"AWS.PersonalizeRuntime.get_personalized_ranking/3","type":"function"},{"doc":"Returns a list of recommended items.\n\nFor campaigns, the campaign's Amazon Resource Name (ARN) is required and the\nrequired user and item input depends on the recipe type used to create the\nsolution backing the campaign as follows:\n\n  * USER_PERSONALIZATION - `userId` required, `itemId` not used\n\n  * RELATED_ITEMS - `itemId` required, `userId` not used\n\nCampaigns that are backed by a solution created using a recipe of type\nPERSONALIZED_RANKING use the API.\n\nFor recommenders, the recommender's ARN is required and the required item and\nuser input depends on the use case (domain-based recipe) backing the\nrecommender. For information on use case requirements see [Choosing recommender use\ncases](https://docs.aws.amazon.com/personalize/latest/dg/domain-use-cases.html).","ref":"AWS.PersonalizeRuntime.html#get_recommendations/3","title":"AWS.PersonalizeRuntime.get_recommendations/3","type":"function"},{"doc":"","ref":"AWS.PersonalizeRuntime.html#metadata/0","title":"AWS.PersonalizeRuntime.metadata/0","type":"function"},{"doc":"Doc Engage API - Amazon Pinpoint API","ref":"AWS.Pinpoint.html","title":"AWS.Pinpoint","type":"module"},{"doc":"Creates an application.","ref":"AWS.Pinpoint.html#create_app/3","title":"AWS.Pinpoint.create_app/3","type":"function"},{"doc":"Creates a new campaign for an application or updates the settings of an existing\ncampaign for an application.","ref":"AWS.Pinpoint.html#create_campaign/4","title":"AWS.Pinpoint.create_campaign/4","type":"function"},{"doc":"Creates a message template for messages that are sent through the email channel.","ref":"AWS.Pinpoint.html#create_email_template/4","title":"AWS.Pinpoint.create_email_template/4","type":"function"},{"doc":"Creates an export job for an application.","ref":"AWS.Pinpoint.html#create_export_job/4","title":"AWS.Pinpoint.create_export_job/4","type":"function"},{"doc":"Creates an import job for an application.","ref":"AWS.Pinpoint.html#create_import_job/4","title":"AWS.Pinpoint.create_import_job/4","type":"function"},{"doc":"Creates a new message template for messages using the in-app message channel.","ref":"AWS.Pinpoint.html#create_in_app_template/4","title":"AWS.Pinpoint.create_in_app_template/4","type":"function"},{"doc":"Creates a journey for an application.","ref":"AWS.Pinpoint.html#create_journey/4","title":"AWS.Pinpoint.create_journey/4","type":"function"},{"doc":"Creates a message template for messages that are sent through a push\nnotification channel.","ref":"AWS.Pinpoint.html#create_push_template/4","title":"AWS.Pinpoint.create_push_template/4","type":"function"},{"doc":"Creates an Amazon Pinpoint configuration for a recommender model.","ref":"AWS.Pinpoint.html#create_recommender_configuration/3","title":"AWS.Pinpoint.create_recommender_configuration/3","type":"function"},{"doc":"Creates a new segment for an application or updates the configuration,\ndimension, and other settings for an existing segment that's associated with an\napplication.","ref":"AWS.Pinpoint.html#create_segment/4","title":"AWS.Pinpoint.create_segment/4","type":"function"},{"doc":"Creates a message template for messages that are sent through the SMS channel.","ref":"AWS.Pinpoint.html#create_sms_template/4","title":"AWS.Pinpoint.create_sms_template/4","type":"function"},{"doc":"Creates a message template for messages that are sent through the voice channel.","ref":"AWS.Pinpoint.html#create_voice_template/4","title":"AWS.Pinpoint.create_voice_template/4","type":"function"},{"doc":"Disables the ADM channel for an application and deletes any existing settings\nfor the channel.","ref":"AWS.Pinpoint.html#delete_adm_channel/4","title":"AWS.Pinpoint.delete_adm_channel/4","type":"function"},{"doc":"Disables the APNs channel for an application and deletes any existing settings\nfor the channel.","ref":"AWS.Pinpoint.html#delete_apns_channel/4","title":"AWS.Pinpoint.delete_apns_channel/4","type":"function"},{"doc":"Disables the APNs sandbox channel for an application and deletes any existing\nsettings for the channel.","ref":"AWS.Pinpoint.html#delete_apns_sandbox_channel/4","title":"AWS.Pinpoint.delete_apns_sandbox_channel/4","type":"function"},{"doc":"Disables the APNs VoIP channel for an application and deletes any existing\nsettings for the channel.","ref":"AWS.Pinpoint.html#delete_apns_voip_channel/4","title":"AWS.Pinpoint.delete_apns_voip_channel/4","type":"function"},{"doc":"Disables the APNs VoIP sandbox channel for an application and deletes any\nexisting settings for the channel.","ref":"AWS.Pinpoint.html#delete_apns_voip_sandbox_channel/4","title":"AWS.Pinpoint.delete_apns_voip_sandbox_channel/4","type":"function"},{"doc":"Deletes an application.","ref":"AWS.Pinpoint.html#delete_app/4","title":"AWS.Pinpoint.delete_app/4","type":"function"},{"doc":"Disables the Baidu channel for an application and deletes any existing settings\nfor the channel.","ref":"AWS.Pinpoint.html#delete_baidu_channel/4","title":"AWS.Pinpoint.delete_baidu_channel/4","type":"function"},{"doc":"Deletes a campaign from an application.","ref":"AWS.Pinpoint.html#delete_campaign/5","title":"AWS.Pinpoint.delete_campaign/5","type":"function"},{"doc":"Disables the email channel for an application and deletes any existing settings\nfor the channel.","ref":"AWS.Pinpoint.html#delete_email_channel/4","title":"AWS.Pinpoint.delete_email_channel/4","type":"function"},{"doc":"Deletes a message template for messages that were sent through the email\nchannel.","ref":"AWS.Pinpoint.html#delete_email_template/4","title":"AWS.Pinpoint.delete_email_template/4","type":"function"},{"doc":"Deletes an endpoint from an application.","ref":"AWS.Pinpoint.html#delete_endpoint/5","title":"AWS.Pinpoint.delete_endpoint/5","type":"function"},{"doc":"Deletes the event stream for an application.","ref":"AWS.Pinpoint.html#delete_event_stream/4","title":"AWS.Pinpoint.delete_event_stream/4","type":"function"},{"doc":"Disables the GCM channel for an application and deletes any existing settings\nfor the channel.","ref":"AWS.Pinpoint.html#delete_gcm_channel/4","title":"AWS.Pinpoint.delete_gcm_channel/4","type":"function"},{"doc":"Deletes a message template for messages sent using the in-app message channel.","ref":"AWS.Pinpoint.html#delete_in_app_template/4","title":"AWS.Pinpoint.delete_in_app_template/4","type":"function"},{"doc":"Deletes a journey from an application.","ref":"AWS.Pinpoint.html#delete_journey/5","title":"AWS.Pinpoint.delete_journey/5","type":"function"},{"doc":"Deletes a message template for messages that were sent through a push\nnotification channel.","ref":"AWS.Pinpoint.html#delete_push_template/4","title":"AWS.Pinpoint.delete_push_template/4","type":"function"},{"doc":"Deletes an Amazon Pinpoint configuration for a recommender model.","ref":"AWS.Pinpoint.html#delete_recommender_configuration/4","title":"AWS.Pinpoint.delete_recommender_configuration/4","type":"function"},{"doc":"Deletes a segment from an application.","ref":"AWS.Pinpoint.html#delete_segment/5","title":"AWS.Pinpoint.delete_segment/5","type":"function"},{"doc":"Disables the SMS channel for an application and deletes any existing settings\nfor the channel.","ref":"AWS.Pinpoint.html#delete_sms_channel/4","title":"AWS.Pinpoint.delete_sms_channel/4","type":"function"},{"doc":"Deletes a message template for messages that were sent through the SMS channel.","ref":"AWS.Pinpoint.html#delete_sms_template/4","title":"AWS.Pinpoint.delete_sms_template/4","type":"function"},{"doc":"Deletes all the endpoints that are associated with a specific user ID.","ref":"AWS.Pinpoint.html#delete_user_endpoints/5","title":"AWS.Pinpoint.delete_user_endpoints/5","type":"function"},{"doc":"Disables the voice channel for an application and deletes any existing settings\nfor the channel.","ref":"AWS.Pinpoint.html#delete_voice_channel/4","title":"AWS.Pinpoint.delete_voice_channel/4","type":"function"},{"doc":"Deletes a message template for messages that were sent through the voice\nchannel.","ref":"AWS.Pinpoint.html#delete_voice_template/4","title":"AWS.Pinpoint.delete_voice_template/4","type":"function"},{"doc":"Retrieves information about the status and settings of the ADM channel for an\napplication.","ref":"AWS.Pinpoint.html#get_adm_channel/3","title":"AWS.Pinpoint.get_adm_channel/3","type":"function"},{"doc":"Retrieves information about the status and settings of the APNs channel for an\napplication.","ref":"AWS.Pinpoint.html#get_apns_channel/3","title":"AWS.Pinpoint.get_apns_channel/3","type":"function"},{"doc":"Retrieves information about the status and settings of the APNs sandbox channel\nfor an application.","ref":"AWS.Pinpoint.html#get_apns_sandbox_channel/3","title":"AWS.Pinpoint.get_apns_sandbox_channel/3","type":"function"},{"doc":"Retrieves information about the status and settings of the APNs VoIP channel for\nan application.","ref":"AWS.Pinpoint.html#get_apns_voip_channel/3","title":"AWS.Pinpoint.get_apns_voip_channel/3","type":"function"},{"doc":"Retrieves information about the status and settings of the APNs VoIP sandbox\nchannel for an application.","ref":"AWS.Pinpoint.html#get_apns_voip_sandbox_channel/3","title":"AWS.Pinpoint.get_apns_voip_sandbox_channel/3","type":"function"},{"doc":"Retrieves information about an application.","ref":"AWS.Pinpoint.html#get_app/3","title":"AWS.Pinpoint.get_app/3","type":"function"},{"doc":"Retrieves (queries) pre-aggregated data for a standard metric that applies to an\napplication.","ref":"AWS.Pinpoint.html#get_application_date_range_kpi/8","title":"AWS.Pinpoint.get_application_date_range_kpi/8","type":"function"},{"doc":"Retrieves information about the settings for an application.","ref":"AWS.Pinpoint.html#get_application_settings/3","title":"AWS.Pinpoint.get_application_settings/3","type":"function"},{"doc":"Retrieves information about all the applications that are associated with your\nAmazon Pinpoint account.","ref":"AWS.Pinpoint.html#get_apps/4","title":"AWS.Pinpoint.get_apps/4","type":"function"},{"doc":"Retrieves information about the status and settings of the Baidu channel for an\napplication.","ref":"AWS.Pinpoint.html#get_baidu_channel/3","title":"AWS.Pinpoint.get_baidu_channel/3","type":"function"},{"doc":"Retrieves information about the status, configuration, and other settings for a\ncampaign.","ref":"AWS.Pinpoint.html#get_campaign/4","title":"AWS.Pinpoint.get_campaign/4","type":"function"},{"doc":"Retrieves information about all the activities for a campaign.","ref":"AWS.Pinpoint.html#get_campaign_activities/6","title":"AWS.Pinpoint.get_campaign_activities/6","type":"function"},{"doc":"Retrieves (queries) pre-aggregated data for a standard metric that applies to a\ncampaign.","ref":"AWS.Pinpoint.html#get_campaign_date_range_kpi/9","title":"AWS.Pinpoint.get_campaign_date_range_kpi/9","type":"function"},{"doc":"Retrieves information about the status, configuration, and other settings for a\nspecific version of a campaign.","ref":"AWS.Pinpoint.html#get_campaign_version/5","title":"AWS.Pinpoint.get_campaign_version/5","type":"function"},{"doc":"Retrieves information about the status, configuration, and other settings for\nall versions of a campaign.","ref":"AWS.Pinpoint.html#get_campaign_versions/6","title":"AWS.Pinpoint.get_campaign_versions/6","type":"function"},{"doc":"Retrieves information about the status, configuration, and other settings for\nall the campaigns that are associated with an application.","ref":"AWS.Pinpoint.html#get_campaigns/5","title":"AWS.Pinpoint.get_campaigns/5","type":"function"},{"doc":"Retrieves information about the history and status of each channel for an\napplication.","ref":"AWS.Pinpoint.html#get_channels/3","title":"AWS.Pinpoint.get_channels/3","type":"function"},{"doc":"Retrieves information about the status and settings of the email channel for an\napplication.","ref":"AWS.Pinpoint.html#get_email_channel/3","title":"AWS.Pinpoint.get_email_channel/3","type":"function"},{"doc":"Retrieves the content and settings of a message template for messages that are\nsent through the email channel.","ref":"AWS.Pinpoint.html#get_email_template/4","title":"AWS.Pinpoint.get_email_template/4","type":"function"},{"doc":"Retrieves information about the settings and attributes of a specific endpoint\nfor an application.","ref":"AWS.Pinpoint.html#get_endpoint/4","title":"AWS.Pinpoint.get_endpoint/4","type":"function"},{"doc":"Retrieves information about the event stream settings for an application.","ref":"AWS.Pinpoint.html#get_event_stream/3","title":"AWS.Pinpoint.get_event_stream/3","type":"function"},{"doc":"Retrieves information about the status and settings of a specific export job for\nan application.","ref":"AWS.Pinpoint.html#get_export_job/4","title":"AWS.Pinpoint.get_export_job/4","type":"function"},{"doc":"Retrieves information about the status and settings of all the export jobs for\nan application.","ref":"AWS.Pinpoint.html#get_export_jobs/5","title":"AWS.Pinpoint.get_export_jobs/5","type":"function"},{"doc":"Retrieves information about the status and settings of the GCM channel for an\napplication.","ref":"AWS.Pinpoint.html#get_gcm_channel/3","title":"AWS.Pinpoint.get_gcm_channel/3","type":"function"},{"doc":"Retrieves information about the status and settings of a specific import job for\nan application.","ref":"AWS.Pinpoint.html#get_import_job/4","title":"AWS.Pinpoint.get_import_job/4","type":"function"},{"doc":"Retrieves information about the status and settings of all the import jobs for\nan application.","ref":"AWS.Pinpoint.html#get_import_jobs/5","title":"AWS.Pinpoint.get_import_jobs/5","type":"function"},{"doc":"Retrieves the in-app messages targeted for the provided endpoint ID.","ref":"AWS.Pinpoint.html#get_in_app_messages/4","title":"AWS.Pinpoint.get_in_app_messages/4","type":"function"},{"doc":"Retrieves the content and settings of a message template for messages sent\nthrough the in-app channel.","ref":"AWS.Pinpoint.html#get_in_app_template/4","title":"AWS.Pinpoint.get_in_app_template/4","type":"function"},{"doc":"Retrieves information about the status, configuration, and other settings for a\njourney.","ref":"AWS.Pinpoint.html#get_journey/4","title":"AWS.Pinpoint.get_journey/4","type":"function"},{"doc":"Retrieves (queries) pre-aggregated data for a standard engagement metric that\napplies to a journey.","ref":"AWS.Pinpoint.html#get_journey_date_range_kpi/9","title":"AWS.Pinpoint.get_journey_date_range_kpi/9","type":"function"},{"doc":"Retrieves (queries) pre-aggregated data for a standard execution metric that\napplies to a journey activity.","ref":"AWS.Pinpoint.html#get_journey_execution_activity_metrics/7","title":"AWS.Pinpoint.get_journey_execution_activity_metrics/7","type":"function"},{"doc":"Retrieves (queries) pre-aggregated data for a standard execution metric that\napplies to a journey.","ref":"AWS.Pinpoint.html#get_journey_execution_metrics/6","title":"AWS.Pinpoint.get_journey_execution_metrics/6","type":"function"},{"doc":"Retrieves (queries) pre-aggregated data for a standard run execution metric that\napplies to a journey activity.","ref":"AWS.Pinpoint.html#get_journey_run_execution_activity_metrics/8","title":"AWS.Pinpoint.get_journey_run_execution_activity_metrics/8","type":"function"},{"doc":"Retrieves (queries) pre-aggregated data for a standard run execution metric that\napplies to a journey.","ref":"AWS.Pinpoint.html#get_journey_run_execution_metrics/7","title":"AWS.Pinpoint.get_journey_run_execution_metrics/7","type":"function"},{"doc":"Provides information about the runs of a journey.","ref":"AWS.Pinpoint.html#get_journey_runs/6","title":"AWS.Pinpoint.get_journey_runs/6","type":"function"},{"doc":"Retrieves the content and settings of a message template for messages that are\nsent through a push notification channel.","ref":"AWS.Pinpoint.html#get_push_template/4","title":"AWS.Pinpoint.get_push_template/4","type":"function"},{"doc":"Retrieves information about an Amazon Pinpoint configuration for a recommender\nmodel.","ref":"AWS.Pinpoint.html#get_recommender_configuration/3","title":"AWS.Pinpoint.get_recommender_configuration/3","type":"function"},{"doc":"Retrieves information about all the recommender model configurations that are\nassociated with your Amazon Pinpoint account.","ref":"AWS.Pinpoint.html#get_recommender_configurations/4","title":"AWS.Pinpoint.get_recommender_configurations/4","type":"function"},{"doc":"Retrieves information about the configuration, dimension, and other settings for\na specific segment that's associated with an application.","ref":"AWS.Pinpoint.html#get_segment/4","title":"AWS.Pinpoint.get_segment/4","type":"function"},{"doc":"Retrieves information about the status and settings of the export jobs for a\nsegment.","ref":"AWS.Pinpoint.html#get_segment_export_jobs/6","title":"AWS.Pinpoint.get_segment_export_jobs/6","type":"function"},{"doc":"Retrieves information about the status and settings of the import jobs for a\nsegment.","ref":"AWS.Pinpoint.html#get_segment_import_jobs/6","title":"AWS.Pinpoint.get_segment_import_jobs/6","type":"function"},{"doc":"Retrieves information about the configuration, dimension, and other settings for\na specific version of a segment that's associated with an application.","ref":"AWS.Pinpoint.html#get_segment_version/5","title":"AWS.Pinpoint.get_segment_version/5","type":"function"},{"doc":"Retrieves information about the configuration, dimension, and other settings for\nall the versions of a specific segment that's associated with an application.","ref":"AWS.Pinpoint.html#get_segment_versions/6","title":"AWS.Pinpoint.get_segment_versions/6","type":"function"},{"doc":"Retrieves information about the configuration, dimension, and other settings for\nall the segments that are associated with an application.","ref":"AWS.Pinpoint.html#get_segments/5","title":"AWS.Pinpoint.get_segments/5","type":"function"},{"doc":"Retrieves information about the status and settings of the SMS channel for an\napplication.","ref":"AWS.Pinpoint.html#get_sms_channel/3","title":"AWS.Pinpoint.get_sms_channel/3","type":"function"},{"doc":"Retrieves the content and settings of a message template for messages that are\nsent through the SMS channel.","ref":"AWS.Pinpoint.html#get_sms_template/4","title":"AWS.Pinpoint.get_sms_template/4","type":"function"},{"doc":"Retrieves information about all the endpoints that are associated with a\nspecific user ID.","ref":"AWS.Pinpoint.html#get_user_endpoints/4","title":"AWS.Pinpoint.get_user_endpoints/4","type":"function"},{"doc":"Retrieves information about the status and settings of the voice channel for an\napplication.","ref":"AWS.Pinpoint.html#get_voice_channel/3","title":"AWS.Pinpoint.get_voice_channel/3","type":"function"},{"doc":"Retrieves the content and settings of a message template for messages that are\nsent through the voice channel.","ref":"AWS.Pinpoint.html#get_voice_template/4","title":"AWS.Pinpoint.get_voice_template/4","type":"function"},{"doc":"Retrieves information about the status, configuration, and other settings for\nall the journeys that are associated with an application.","ref":"AWS.Pinpoint.html#list_journeys/5","title":"AWS.Pinpoint.list_journeys/5","type":"function"},{"doc":"Retrieves all the tags (keys and values) that are associated with an\napplication, campaign, message template, or segment.","ref":"AWS.Pinpoint.html#list_tags_for_resource/3","title":"AWS.Pinpoint.list_tags_for_resource/3","type":"function"},{"doc":"Retrieves information about all the versions of a specific message template.","ref":"AWS.Pinpoint.html#list_template_versions/6","title":"AWS.Pinpoint.list_template_versions/6","type":"function"},{"doc":"Retrieves information about all the message templates that are associated with\nyour Amazon Pinpoint account.","ref":"AWS.Pinpoint.html#list_templates/6","title":"AWS.Pinpoint.list_templates/6","type":"function"},{"doc":"","ref":"AWS.Pinpoint.html#metadata/0","title":"AWS.Pinpoint.metadata/0","type":"function"},{"doc":"Retrieves information about a phone number.","ref":"AWS.Pinpoint.html#phone_number_validate/3","title":"AWS.Pinpoint.phone_number_validate/3","type":"function"},{"doc":"Creates a new event stream for an application or updates the settings of an\nexisting event stream for an application.","ref":"AWS.Pinpoint.html#put_event_stream/4","title":"AWS.Pinpoint.put_event_stream/4","type":"function"},{"doc":"Creates a new event to record for endpoints, or creates or updates endpoint data\nthat existing events are associated with.","ref":"AWS.Pinpoint.html#put_events/4","title":"AWS.Pinpoint.put_events/4","type":"function"},{"doc":"Removes one or more custom attributes, of the same attribute type, from the\napplication.\n\nExisting endpoints still have the attributes but Amazon Pinpoint will stop\ncapturing new or changed values for these attributes.","ref":"AWS.Pinpoint.html#remove_attributes/5","title":"AWS.Pinpoint.remove_attributes/5","type":"function"},{"doc":"Creates and sends a direct message.","ref":"AWS.Pinpoint.html#send_messages/4","title":"AWS.Pinpoint.send_messages/4","type":"function"},{"doc":"Send an OTP message","ref":"AWS.Pinpoint.html#send_o_t_p_message/4","title":"AWS.Pinpoint.send_o_t_p_message/4","type":"function"},{"doc":"Creates and sends a message to a list of users.","ref":"AWS.Pinpoint.html#send_users_messages/4","title":"AWS.Pinpoint.send_users_messages/4","type":"function"},{"doc":"Adds one or more tags (keys and values) to an application, campaign, message\ntemplate, or segment.","ref":"AWS.Pinpoint.html#tag_resource/4","title":"AWS.Pinpoint.tag_resource/4","type":"function"},{"doc":"Removes one or more tags (keys and values) from an application, campaign,\nmessage template, or segment.","ref":"AWS.Pinpoint.html#untag_resource/4","title":"AWS.Pinpoint.untag_resource/4","type":"function"},{"doc":"Enables the ADM channel for an application or updates the status and settings of\nthe ADM channel for an application.","ref":"AWS.Pinpoint.html#update_adm_channel/4","title":"AWS.Pinpoint.update_adm_channel/4","type":"function"},{"doc":"Enables the APNs channel for an application or updates the status and settings\nof the APNs channel for an application.","ref":"AWS.Pinpoint.html#update_apns_channel/4","title":"AWS.Pinpoint.update_apns_channel/4","type":"function"},{"doc":"Enables the APNs sandbox channel for an application or updates the status and\nsettings of the APNs sandbox channel for an application.","ref":"AWS.Pinpoint.html#update_apns_sandbox_channel/4","title":"AWS.Pinpoint.update_apns_sandbox_channel/4","type":"function"},{"doc":"Enables the APNs VoIP channel for an application or updates the status and\nsettings of the APNs VoIP channel for an application.","ref":"AWS.Pinpoint.html#update_apns_voip_channel/4","title":"AWS.Pinpoint.update_apns_voip_channel/4","type":"function"},{"doc":"Enables the APNs VoIP sandbox channel for an application or updates the status\nand settings of the APNs VoIP sandbox channel for an application.","ref":"AWS.Pinpoint.html#update_apns_voip_sandbox_channel/4","title":"AWS.Pinpoint.update_apns_voip_sandbox_channel/4","type":"function"},{"doc":"Updates the settings for an application.","ref":"AWS.Pinpoint.html#update_application_settings/4","title":"AWS.Pinpoint.update_application_settings/4","type":"function"},{"doc":"Enables the Baidu channel for an application or updates the status and settings\nof the Baidu channel for an application.","ref":"AWS.Pinpoint.html#update_baidu_channel/4","title":"AWS.Pinpoint.update_baidu_channel/4","type":"function"},{"doc":"Updates the configuration and other settings for a campaign.","ref":"AWS.Pinpoint.html#update_campaign/5","title":"AWS.Pinpoint.update_campaign/5","type":"function"},{"doc":"Enables the email channel for an application or updates the status and settings\nof the email channel for an application.","ref":"AWS.Pinpoint.html#update_email_channel/4","title":"AWS.Pinpoint.update_email_channel/4","type":"function"},{"doc":"Updates an existing message template for messages that are sent through the\nemail channel.","ref":"AWS.Pinpoint.html#update_email_template/4","title":"AWS.Pinpoint.update_email_template/4","type":"function"},{"doc":"Creates a new endpoint for an application or updates the settings and attributes\nof an existing endpoint for an application.\n\nYou can also use this operation to define custom attributes for an endpoint. If\nan update includes one or more values for a custom attribute, Amazon Pinpoint\nreplaces (overwrites) any existing values with the new values.","ref":"AWS.Pinpoint.html#update_endpoint/5","title":"AWS.Pinpoint.update_endpoint/5","type":"function"},{"doc":"Creates a new batch of endpoints for an application or updates the settings and\nattributes of a batch of existing endpoints for an application.\n\nYou can also use this operation to define custom attributes for a batch of\nendpoints. If an update includes one or more values for a custom attribute,\nAmazon Pinpoint replaces (overwrites) any existing values with the new values.","ref":"AWS.Pinpoint.html#update_endpoints_batch/4","title":"AWS.Pinpoint.update_endpoints_batch/4","type":"function"},{"doc":"Enables the GCM channel for an application or updates the status and settings of\nthe GCM channel for an application.","ref":"AWS.Pinpoint.html#update_gcm_channel/4","title":"AWS.Pinpoint.update_gcm_channel/4","type":"function"},{"doc":"Updates an existing message template for messages sent through the in-app\nmessage channel.","ref":"AWS.Pinpoint.html#update_in_app_template/4","title":"AWS.Pinpoint.update_in_app_template/4","type":"function"},{"doc":"Updates the configuration and other settings for a journey.","ref":"AWS.Pinpoint.html#update_journey/5","title":"AWS.Pinpoint.update_journey/5","type":"function"},{"doc":"Pause, resume or cancels (stops) a journey.","ref":"AWS.Pinpoint.html#update_journey_state/5","title":"AWS.Pinpoint.update_journey_state/5","type":"function"},{"doc":"Updates an existing message template for messages that are sent through a push\nnotification channel.","ref":"AWS.Pinpoint.html#update_push_template/4","title":"AWS.Pinpoint.update_push_template/4","type":"function"},{"doc":"Updates an Amazon Pinpoint configuration for a recommender model.","ref":"AWS.Pinpoint.html#update_recommender_configuration/4","title":"AWS.Pinpoint.update_recommender_configuration/4","type":"function"},{"doc":"Creates a new segment for an application or updates the configuration,\ndimension, and other settings for an existing segment that's associated with an\napplication.","ref":"AWS.Pinpoint.html#update_segment/5","title":"AWS.Pinpoint.update_segment/5","type":"function"},{"doc":"Enables the SMS channel for an application or updates the status and settings of\nthe SMS channel for an application.","ref":"AWS.Pinpoint.html#update_sms_channel/4","title":"AWS.Pinpoint.update_sms_channel/4","type":"function"},{"doc":"Updates an existing message template for messages that are sent through the SMS\nchannel.","ref":"AWS.Pinpoint.html#update_sms_template/4","title":"AWS.Pinpoint.update_sms_template/4","type":"function"},{"doc":"Changes the status of a specific version of a message template to *active*.","ref":"AWS.Pinpoint.html#update_template_active_version/5","title":"AWS.Pinpoint.update_template_active_version/5","type":"function"},{"doc":"Enables the voice channel for an application or updates the status and settings\nof the voice channel for an application.","ref":"AWS.Pinpoint.html#update_voice_channel/4","title":"AWS.Pinpoint.update_voice_channel/4","type":"function"},{"doc":"Updates an existing message template for messages that are sent through the\nvoice channel.","ref":"AWS.Pinpoint.html#update_voice_template/4","title":"AWS.Pinpoint.update_voice_template/4","type":"function"},{"doc":"Verify an OTP","ref":"AWS.Pinpoint.html#verify_o_t_p_message/4","title":"AWS.Pinpoint.verify_o_t_p_message/4","type":"function"},{"doc":"Amazon Pinpoint Email Service\n\nWelcome to the *Amazon Pinpoint Email API Reference*.\n\nThis guide provides information about the Amazon Pinpoint Email API (version\n1.0), including supported operations, data types, parameters, and schemas.\n\n[Amazon Pinpoint](https://aws.amazon.com/pinpoint) is an AWS service that you can use to engage with your customers across multiple messaging channels. You\ncan use Amazon Pinpoint to send email, SMS text messages, voice messages, and\npush notifications. The Amazon Pinpoint Email API provides programmatic access\nto options that are unique to the email channel and supplement the options\nprovided by the Amazon Pinpoint API.\n\nIf you're new to Amazon Pinpoint, you might find it helpful to also review the\n[Amazon Pinpoint Developer\nGuide](https://docs.aws.amazon.com/pinpoint/latest/developerguide/welcome.html).\nThe *Amazon Pinpoint Developer Guide* provides tutorials, code samples, and\nprocedures that demonstrate how to use Amazon Pinpoint features programmatically\nand how to integrate Amazon Pinpoint functionality into mobile apps and other\ntypes of applications. The guide also provides information about key topics such\nas Amazon Pinpoint integration with other AWS services and the limits that apply\nto using the service.\n\nThe Amazon Pinpoint Email API is available in several AWS Regions and it\nprovides an endpoint for each of these Regions. For a list of all the Regions\nand endpoints where the API is currently available, see [AWS Service Endpoints](https://docs.aws.amazon.com/general/latest/gr/rande.html#pinpoint_region)\nin the *Amazon Web Services General Reference*. To learn more about AWS Regions,\nsee [Managing AWS Regions](https://docs.aws.amazon.com/general/latest/gr/rande-manage.html) in the\n*Amazon Web Services General Reference*.\n\nIn each Region, AWS maintains multiple Availability Zones. These Availability\nZones are physically isolated from each other, but are united by private,\nlow-latency, high-throughput, and highly redundant network connections. These\nAvailability Zones enable us to provide very high levels of availability and\nredundancy, while also minimizing latency. To learn more about the number of\nAvailability Zones that are available in each Region, see [AWS Global Infrastructure](http://aws.amazon.com/about-aws/global-infrastructure/).","ref":"AWS.PinpointEmail.html","title":"AWS.PinpointEmail","type":"module"},{"doc":"Create a configuration set.\n\n*Configuration sets* are groups of rules that you can apply to the emails you\nsend using Amazon Pinpoint. You apply a configuration set to an email by\nincluding a reference to the configuration set in the headers of the email. When\nyou apply a configuration set to an email, all of the rules in that\nconfiguration set are applied to the email.","ref":"AWS.PinpointEmail.html#create_configuration_set/3","title":"AWS.PinpointEmail.create_configuration_set/3","type":"function"},{"doc":"Create an event destination.\n\nIn Amazon Pinpoint, *events* include message sends, deliveries, opens, clicks,\nbounces, and complaints. *Event destinations* are places that you can send\ninformation about these events to. For example, you can send event data to\nAmazon SNS to receive notifications when you receive bounces or complaints, or\nyou can use Amazon Kinesis Data Firehose to stream data to Amazon S3 for\nlong-term storage.\n\nA single configuration set can include more than one event destination.","ref":"AWS.PinpointEmail.html#create_configuration_set_event_destination/4","title":"AWS.PinpointEmail.create_configuration_set_event_destination/4","type":"function"},{"doc":"Create a new pool of dedicated IP addresses.\n\nA pool can include one or more dedicated IP addresses that are associated with\nyour Amazon Pinpoint account. You can associate a pool with a configuration set.\nWhen you send an email that uses that configuration set, Amazon Pinpoint sends\nit using only the IP addresses in the associated pool.","ref":"AWS.PinpointEmail.html#create_dedicated_ip_pool/3","title":"AWS.PinpointEmail.create_dedicated_ip_pool/3","type":"function"},{"doc":"Create a new predictive inbox placement test.\n\nPredictive inbox placement tests can help you predict how your messages will be\nhandled by various email providers around the world. When you perform a\npredictive inbox placement test, you provide a sample message that contains the\ncontent that you plan to send to your customers. Amazon Pinpoint then sends that\nmessage to special email addresses spread across several major email providers.\nAfter about 24 hours, the test is complete, and you can use the\n`GetDeliverabilityTestReport` operation to view the results of the test.","ref":"AWS.PinpointEmail.html#create_deliverability_test_report/3","title":"AWS.PinpointEmail.create_deliverability_test_report/3","type":"function"},{"doc":"Verifies an email identity for use with Amazon Pinpoint.\n\nIn Amazon Pinpoint, an identity is an email address or domain that you use when\nyou send email. Before you can use an identity to send email with Amazon\nPinpoint, you first have to verify it. By verifying an address, you demonstrate\nthat you're the owner of the address, and that you've given Amazon Pinpoint\npermission to send email from the address.\n\nWhen you verify an email address, Amazon Pinpoint sends an email to the address.\nYour email address is verified as soon as you follow the link in the\nverification email.\n\nWhen you verify a domain, this operation provides a set of DKIM tokens, which\nyou can convert into CNAME tokens. You add these CNAME tokens to the DNS\nconfiguration for your domain. Your domain is verified when Amazon Pinpoint\ndetects these records in the DNS configuration for your domain. It usually takes\naround 72 hours to complete the domain verification process.","ref":"AWS.PinpointEmail.html#create_email_identity/3","title":"AWS.PinpointEmail.create_email_identity/3","type":"function"},{"doc":"Delete an existing configuration set.\n\nIn Amazon Pinpoint, *configuration sets* are groups of rules that you can apply\nto the emails you send. You apply a configuration set to an email by including a\nreference to the configuration set in the headers of the email. When you apply a\nconfiguration set to an email, all of the rules in that configuration set are\napplied to the email.","ref":"AWS.PinpointEmail.html#delete_configuration_set/4","title":"AWS.PinpointEmail.delete_configuration_set/4","type":"function"},{"doc":"Delete an event destination.\n\nIn Amazon Pinpoint, *events* include message sends, deliveries, opens, clicks,\nbounces, and complaints. *Event destinations* are places that you can send\ninformation about these events to. For example, you can send event data to\nAmazon SNS to receive notifications when you receive bounces or complaints, or\nyou can use Amazon Kinesis Data Firehose to stream data to Amazon S3 for\nlong-term storage.","ref":"AWS.PinpointEmail.html#delete_configuration_set_event_destination/5","title":"AWS.PinpointEmail.delete_configuration_set_event_destination/5","type":"function"},{"doc":"Delete a dedicated IP pool.","ref":"AWS.PinpointEmail.html#delete_dedicated_ip_pool/4","title":"AWS.PinpointEmail.delete_dedicated_ip_pool/4","type":"function"},{"doc":"Deletes an email identity that you previously verified for use with Amazon\nPinpoint.\n\nAn identity can be either an email address or a domain name.","ref":"AWS.PinpointEmail.html#delete_email_identity/4","title":"AWS.PinpointEmail.delete_email_identity/4","type":"function"},{"doc":"Obtain information about the email-sending status and capabilities of your\nAmazon Pinpoint account in the current AWS Region.","ref":"AWS.PinpointEmail.html#get_account/2","title":"AWS.PinpointEmail.get_account/2","type":"function"},{"doc":"Retrieve a list of the blacklists that your dedicated IP addresses appear on.","ref":"AWS.PinpointEmail.html#get_blacklist_reports/3","title":"AWS.PinpointEmail.get_blacklist_reports/3","type":"function"},{"doc":"Get information about an existing configuration set, including the dedicated IP\npool that it's associated with, whether or not it's enabled for sending email,\nand more.\n\nIn Amazon Pinpoint, *configuration sets* are groups of rules that you can apply\nto the emails you send. You apply a configuration set to an email by including a\nreference to the configuration set in the headers of the email. When you apply a\nconfiguration set to an email, all of the rules in that configuration set are\napplied to the email.","ref":"AWS.PinpointEmail.html#get_configuration_set/3","title":"AWS.PinpointEmail.get_configuration_set/3","type":"function"},{"doc":"Retrieve a list of event destinations that are associated with a configuration\nset.\n\nIn Amazon Pinpoint, *events* include message sends, deliveries, opens, clicks,\nbounces, and complaints. *Event destinations* are places that you can send\ninformation about these events to. For example, you can send event data to\nAmazon SNS to receive notifications when you receive bounces or complaints, or\nyou can use Amazon Kinesis Data Firehose to stream data to Amazon S3 for\nlong-term storage.","ref":"AWS.PinpointEmail.html#get_configuration_set_event_destinations/3","title":"AWS.PinpointEmail.get_configuration_set_event_destinations/3","type":"function"},{"doc":"Get information about a dedicated IP address, including the name of the\ndedicated IP pool that it's associated with, as well information about the\nautomatic warm-up process for the address.","ref":"AWS.PinpointEmail.html#get_dedicated_ip/3","title":"AWS.PinpointEmail.get_dedicated_ip/3","type":"function"},{"doc":"List the dedicated IP addresses that are associated with your Amazon Pinpoint\naccount.","ref":"AWS.PinpointEmail.html#get_dedicated_ips/5","title":"AWS.PinpointEmail.get_dedicated_ips/5","type":"function"},{"doc":"Retrieve information about the status of the Deliverability dashboard for your\nAmazon Pinpoint account.\n\nWhen the Deliverability dashboard is enabled, you gain access to reputation,\ndeliverability, and other metrics for the domains that you use to send email\nusing Amazon Pinpoint. You also gain the ability to perform predictive inbox\nplacement tests.\n\nWhen you use the Deliverability dashboard, you pay a monthly subscription\ncharge, in addition to any other fees that you accrue by using Amazon Pinpoint.\nFor more information about the features and cost of a Deliverability dashboard\nsubscription, see [Amazon Pinpoint Pricing](http://aws.amazon.com/pinpoint/pricing/).","ref":"AWS.PinpointEmail.html#get_deliverability_dashboard_options/2","title":"AWS.PinpointEmail.get_deliverability_dashboard_options/2","type":"function"},{"doc":"Retrieve the results of a predictive inbox placement test.","ref":"AWS.PinpointEmail.html#get_deliverability_test_report/3","title":"AWS.PinpointEmail.get_deliverability_test_report/3","type":"function"},{"doc":"Retrieve all the deliverability data for a specific campaign.\n\nThis data is available for a campaign only if the campaign sent email by using a\ndomain that the Deliverability dashboard is enabled for\n(`PutDeliverabilityDashboardOption` operation).","ref":"AWS.PinpointEmail.html#get_domain_deliverability_campaign/3","title":"AWS.PinpointEmail.get_domain_deliverability_campaign/3","type":"function"},{"doc":"Retrieve inbox placement and engagement rates for the domains that you use to\nsend email.","ref":"AWS.PinpointEmail.html#get_domain_statistics_report/5","title":"AWS.PinpointEmail.get_domain_statistics_report/5","type":"function"},{"doc":"Provides information about a specific identity associated with your Amazon\nPinpoint account, including the identity's verification status, its DKIM\nauthentication status, and its custom Mail-From settings.","ref":"AWS.PinpointEmail.html#get_email_identity/3","title":"AWS.PinpointEmail.get_email_identity/3","type":"function"},{"doc":"List all of the configuration sets associated with your Amazon Pinpoint account\nin the current region.\n\nIn Amazon Pinpoint, *configuration sets* are groups of rules that you can apply\nto the emails you send. You apply a configuration set to an email by including a\nreference to the configuration set in the headers of the email. When you apply a\nconfiguration set to an email, all of the rules in that configuration set are\napplied to the email.","ref":"AWS.PinpointEmail.html#list_configuration_sets/4","title":"AWS.PinpointEmail.list_configuration_sets/4","type":"function"},{"doc":"List all of the dedicated IP pools that exist in your Amazon Pinpoint account in\nthe current AWS Region.","ref":"AWS.PinpointEmail.html#list_dedicated_ip_pools/4","title":"AWS.PinpointEmail.list_dedicated_ip_pools/4","type":"function"},{"doc":"Show a list of the predictive inbox placement tests that you've performed,\nregardless of their statuses.\n\nFor predictive inbox placement tests that are complete, you can use the\n`GetDeliverabilityTestReport` operation to view the results.","ref":"AWS.PinpointEmail.html#list_deliverability_test_reports/4","title":"AWS.PinpointEmail.list_deliverability_test_reports/4","type":"function"},{"doc":"Retrieve deliverability data for all the campaigns that used a specific domain\nto send email during a specified time range.\n\nThis data is available for a domain only if you enabled the Deliverability\ndashboard (`PutDeliverabilityDashboardOption` operation) for the domain.","ref":"AWS.PinpointEmail.html#list_domain_deliverability_campaigns/7","title":"AWS.PinpointEmail.list_domain_deliverability_campaigns/7","type":"function"},{"doc":"Returns a list of all of the email identities that are associated with your\nAmazon Pinpoint account.\n\nAn identity can be either an email address or a domain. This operation returns\nidentities that are verified as well as those that aren't.","ref":"AWS.PinpointEmail.html#list_email_identities/4","title":"AWS.PinpointEmail.list_email_identities/4","type":"function"},{"doc":"Retrieve a list of the tags (keys and values) that are associated with a\nspecified resource.\n\nA *tag* is a label that you optionally define and associate with a resource in\nAmazon Pinpoint. Each tag consists of a required *tag key* and an optional\nassociated *tag value*. A tag key is a general label that acts as a category for\nmore specific tag values. A tag value acts as a descriptor within a tag key.","ref":"AWS.PinpointEmail.html#list_tags_for_resource/3","title":"AWS.PinpointEmail.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.PinpointEmail.html#metadata/0","title":"AWS.PinpointEmail.metadata/0","type":"function"},{"doc":"Enable or disable the automatic warm-up feature for dedicated IP addresses.","ref":"AWS.PinpointEmail.html#put_account_dedicated_ip_warmup_attributes/3","title":"AWS.PinpointEmail.put_account_dedicated_ip_warmup_attributes/3","type":"function"},{"doc":"Enable or disable the ability of your account to send email.","ref":"AWS.PinpointEmail.html#put_account_sending_attributes/3","title":"AWS.PinpointEmail.put_account_sending_attributes/3","type":"function"},{"doc":"Associate a configuration set with a dedicated IP pool.\n\nYou can use dedicated IP pools to create groups of dedicated IP addresses for\nsending specific types of email.","ref":"AWS.PinpointEmail.html#put_configuration_set_delivery_options/4","title":"AWS.PinpointEmail.put_configuration_set_delivery_options/4","type":"function"},{"doc":"Enable or disable collection of reputation metrics for emails that you send\nusing a particular configuration set in a specific AWS Region.","ref":"AWS.PinpointEmail.html#put_configuration_set_reputation_options/4","title":"AWS.PinpointEmail.put_configuration_set_reputation_options/4","type":"function"},{"doc":"Enable or disable email sending for messages that use a particular configuration\nset in a specific AWS Region.","ref":"AWS.PinpointEmail.html#put_configuration_set_sending_options/4","title":"AWS.PinpointEmail.put_configuration_set_sending_options/4","type":"function"},{"doc":"Specify a custom domain to use for open and click tracking elements in email\nthat you send using Amazon Pinpoint.","ref":"AWS.PinpointEmail.html#put_configuration_set_tracking_options/4","title":"AWS.PinpointEmail.put_configuration_set_tracking_options/4","type":"function"},{"doc":"Move a dedicated IP address to an existing dedicated IP pool.\n\nThe dedicated IP address that you specify must already exist, and must be\nassociated with your Amazon Pinpoint account.\n\nThe dedicated IP pool you specify must already exist. You can create a new pool\nby using the `CreateDedicatedIpPool` operation.","ref":"AWS.PinpointEmail.html#put_dedicated_ip_in_pool/4","title":"AWS.PinpointEmail.put_dedicated_ip_in_pool/4","type":"function"},{"doc":"","ref":"AWS.PinpointEmail.html#put_dedicated_ip_warmup_attributes/4","title":"AWS.PinpointEmail.put_dedicated_ip_warmup_attributes/4","type":"function"},{"doc":"Enable or disable the Deliverability dashboard for your Amazon Pinpoint account.\n\nWhen you enable the Deliverability dashboard, you gain access to reputation,\ndeliverability, and other metrics for the domains that you use to send email\nusing Amazon Pinpoint. You also gain the ability to perform predictive inbox\nplacement tests.\n\nWhen you use the Deliverability dashboard, you pay a monthly subscription\ncharge, in addition to any other fees that you accrue by using Amazon Pinpoint.\nFor more information about the features and cost of a Deliverability dashboard\nsubscription, see [Amazon Pinpoint Pricing](http://aws.amazon.com/pinpoint/pricing/).","ref":"AWS.PinpointEmail.html#put_deliverability_dashboard_option/3","title":"AWS.PinpointEmail.put_deliverability_dashboard_option/3","type":"function"},{"doc":"Used to enable or disable DKIM authentication for an email identity.","ref":"AWS.PinpointEmail.html#put_email_identity_dkim_attributes/4","title":"AWS.PinpointEmail.put_email_identity_dkim_attributes/4","type":"function"},{"doc":"Used to enable or disable feedback forwarding for an identity.\n\nThis setting determines what happens when an identity is used to send an email\nthat results in a bounce or complaint event.\n\nWhen you enable feedback forwarding, Amazon Pinpoint sends you email\nnotifications when bounce or complaint events occur. Amazon Pinpoint sends this\nnotification to the address that you specified in the Return-Path header of the\noriginal email.\n\nWhen you disable feedback forwarding, Amazon Pinpoint sends notifications\nthrough other mechanisms, such as by notifying an Amazon SNS topic. You're\nrequired to have a method of tracking bounces and complaints. If you haven't set\nup another mechanism for receiving bounce or complaint notifications, Amazon\nPinpoint sends an email notification when these events occur (even if this\nsetting is disabled).","ref":"AWS.PinpointEmail.html#put_email_identity_feedback_attributes/4","title":"AWS.PinpointEmail.put_email_identity_feedback_attributes/4","type":"function"},{"doc":"Used to enable or disable the custom Mail-From domain configuration for an email\nidentity.","ref":"AWS.PinpointEmail.html#put_email_identity_mail_from_attributes/4","title":"AWS.PinpointEmail.put_email_identity_mail_from_attributes/4","type":"function"},{"doc":"Sends an email message.\n\nYou can use the Amazon Pinpoint Email API to send two types of messages:\n\n  * **Simple** – A standard email message. When you create this type\nof message, you specify the sender, the recipient, and the message body, and\nAmazon Pinpoint assembles the message for you.\n\n  * **Raw** – A raw, MIME-formatted email message. When you send this\ntype of email, you have to specify all of the message headers, as well as the\nmessage body. You can use this message type to send messages that contain\nattachments. The message that you specify has to be a valid MIME message.","ref":"AWS.PinpointEmail.html#send_email/3","title":"AWS.PinpointEmail.send_email/3","type":"function"},{"doc":"Add one or more tags (keys and values) to a specified resource.\n\nA *tag* is a label that you optionally define and associate with a resource in\nAmazon Pinpoint. Tags can help you categorize and manage resources in different\nways, such as by purpose, owner, environment, or other criteria. A resource can\nhave as many as 50 tags.\n\nEach tag consists of a required *tag key* and an associated *tag value*, both of\nwhich you define. A tag key is a general label that acts as a category for more\nspecific tag values. A tag value acts as a descriptor within a tag key.","ref":"AWS.PinpointEmail.html#tag_resource/3","title":"AWS.PinpointEmail.tag_resource/3","type":"function"},{"doc":"Remove one or more tags (keys and values) from a specified resource.","ref":"AWS.PinpointEmail.html#untag_resource/3","title":"AWS.PinpointEmail.untag_resource/3","type":"function"},{"doc":"Update the configuration of an event destination for a configuration set.\n\nIn Amazon Pinpoint, *events* include message sends, deliveries, opens, clicks,\nbounces, and complaints. *Event destinations* are places that you can send\ninformation about these events to. For example, you can send event data to\nAmazon SNS to receive notifications when you receive bounces or complaints, or\nyou can use Amazon Kinesis Data Firehose to stream data to Amazon S3 for\nlong-term storage.","ref":"AWS.PinpointEmail.html#update_configuration_set_event_destination/5","title":"AWS.PinpointEmail.update_configuration_set_event_destination/5","type":"function"},{"doc":"Pinpoint SMS and Voice Messaging public facing APIs","ref":"AWS.PinpointSMSVoice.html","title":"AWS.PinpointSMSVoice","type":"module"},{"doc":"Create a new configuration set.\n\nAfter you create the configuration set, you can add one or more event\ndestinations to it.","ref":"AWS.PinpointSMSVoice.html#create_configuration_set/3","title":"AWS.PinpointSMSVoice.create_configuration_set/3","type":"function"},{"doc":"Create a new event destination in a configuration set.","ref":"AWS.PinpointSMSVoice.html#create_configuration_set_event_destination/4","title":"AWS.PinpointSMSVoice.create_configuration_set_event_destination/4","type":"function"},{"doc":"Deletes an existing configuration set.","ref":"AWS.PinpointSMSVoice.html#delete_configuration_set/4","title":"AWS.PinpointSMSVoice.delete_configuration_set/4","type":"function"},{"doc":"Deletes an event destination in a configuration set.","ref":"AWS.PinpointSMSVoice.html#delete_configuration_set_event_destination/5","title":"AWS.PinpointSMSVoice.delete_configuration_set_event_destination/5","type":"function"},{"doc":"Obtain information about an event destination, including the types of events it\nreports, the Amazon Resource Name (ARN) of the destination, and the name of the\nevent destination.","ref":"AWS.PinpointSMSVoice.html#get_configuration_set_event_destinations/3","title":"AWS.PinpointSMSVoice.get_configuration_set_event_destinations/3","type":"function"},{"doc":"List all of the configuration sets associated with your Amazon Pinpoint account\nin the current region.","ref":"AWS.PinpointSMSVoice.html#list_configuration_sets/4","title":"AWS.PinpointSMSVoice.list_configuration_sets/4","type":"function"},{"doc":"","ref":"AWS.PinpointSMSVoice.html#metadata/0","title":"AWS.PinpointSMSVoice.metadata/0","type":"function"},{"doc":"Create a new voice message and send it to a recipient's phone number.","ref":"AWS.PinpointSMSVoice.html#send_voice_message/3","title":"AWS.PinpointSMSVoice.send_voice_message/3","type":"function"},{"doc":"Update an event destination in a configuration set.\n\nAn event destination is a location that you publish information about your voice\ncalls to. For example, you can log an event to an Amazon CloudWatch destination\nwhen a call fails.","ref":"AWS.PinpointSMSVoice.html#update_configuration_set_event_destination/5","title":"AWS.PinpointSMSVoice.update_configuration_set_event_destination/5","type":"function"},{"doc":"Welcome to the *Amazon Pinpoint SMS and Voice, version 2 API Reference*.\n\nThis guide provides information about Amazon Pinpoint SMS and Voice, version 2\nAPI resources, including supported HTTP methods, parameters, and schemas.\n\nAmazon Pinpoint is an Amazon Web Services service that you can use to engage\nwith your recipients across multiple messaging channels. The Amazon Pinpoint SMS\nand Voice, version 2 API provides programmatic access to options that are unique\nto the SMS and voice channels and supplements the resources provided by the\nAmazon Pinpoint API.\n\nIf you're new to Amazon Pinpoint, it's also helpful to review the [ Amazon Pinpoint Developer\nGuide](https://docs.aws.amazon.com/pinpoint/latest/developerguide/welcome.html).\nThe *Amazon Pinpoint Developer Guide* provides tutorials, code samples, and\nprocedures that demonstrate how to use Amazon Pinpoint features programmatically\nand how to integrate Amazon Pinpoint functionality into mobile apps and other\ntypes of applications. The guide also provides key information, such as Amazon\nPinpoint integration with other Amazon Web Services services, and the quotas\nthat apply to use of the service.","ref":"AWS.PinpointSMSVoiceV2.html","title":"AWS.PinpointSMSVoiceV2","type":"module"},{"doc":"The *Amazon Pinpoint SMS and Voice, version 2 API Reference* is available in\nseveral Amazon Web Services Regions and it provides an endpoint for each of\nthese Regions. For a list of all the Regions and endpoints where the API is\ncurrently available, see [Amazon Web Services Service Endpoints](https://docs.aws.amazon.com/general/latest/gr/rande.html#pinpoint_region)\nand [Amazon Pinpoint endpoints and quotas](https://docs.aws.amazon.com/general/latest/gr/pinpoint.html) in the\nAmazon Web Services General Reference. To learn more about Amazon Web Services\nRegions, see [Managing Amazon Web Services Regions](https://docs.aws.amazon.com/general/latest/gr/rande-manage.html) in the\nAmazon Web Services General Reference.\n\nIn each Region, Amazon Web Services maintains multiple Availability Zones. These\nAvailability Zones are physically isolated from each other, but are united by\nprivate, low-latency, high-throughput, and highly redundant network connections.\nThese Availability Zones enable us to provide very high levels of availability\nand redundancy, while also minimizing latency. To learn more about the number of\nAvailability Zones that are available in each Region, see [Amazon Web Services Global Infrastructure.](https://aws.amazon.com/about-aws/global-infrastructure/)","ref":"AWS.PinpointSMSVoiceV2.html#module-regional-availability","title":"Regional availability - AWS.PinpointSMSVoiceV2","type":"module"},{"doc":"Associates the specified origination identity with a pool.\n\nIf the origination identity is a phone number and is already associated with\nanother pool, an error is returned. A sender ID can be associated with multiple\npools.\n\nIf the origination identity configuration doesn't match the pool's\nconfiguration, an error is returned.","ref":"AWS.PinpointSMSVoiceV2.html#associate_origination_identity/3","title":"AWS.PinpointSMSVoiceV2.associate_origination_identity/3","type":"function"},{"doc":"Creates a new configuration set.\n\nAfter you create the configuration set, you can add one or more event\ndestinations to it.\n\nA configuration set is a set of rules that you apply to the SMS and voice\nmessages that you send.\n\nWhen you send a message, you can optionally specify a single configuration set.","ref":"AWS.PinpointSMSVoiceV2.html#create_configuration_set/3","title":"AWS.PinpointSMSVoiceV2.create_configuration_set/3","type":"function"},{"doc":"Creates a new event destination in a configuration set.\n\nAn event destination is a location where you send message events. The event\noptions are Amazon CloudWatch, Amazon Kinesis Data Firehose, or Amazon SNS. For\nexample, when a message is delivered successfully, you can send information\nabout that event to an event destination, or send notifications to endpoints\nthat are subscribed to an Amazon SNS topic.\n\nEach configuration set can contain between 0 and 5 event destinations. Each\nevent destination can contain a reference to a single destination, such as a\nCloudWatch or Kinesis Data Firehose destination.","ref":"AWS.PinpointSMSVoiceV2.html#create_event_destination/3","title":"AWS.PinpointSMSVoiceV2.create_event_destination/3","type":"function"},{"doc":"Creates a new opt-out list.\n\nIf the opt-out list name already exists, an error is returned.\n\nAn opt-out list is a list of phone numbers that are opted out, meaning you can't\nsend SMS or voice messages to them. If end user replies with the keyword \"STOP,\"\nan entry for the phone number is added to the opt-out list. In addition to STOP,\nyour recipients can use any supported opt-out keyword, such as CANCEL or OPTOUT.\nFor a list of supported opt-out keywords, see [ SMS opt out\n](https://docs.aws.amazon.com/pinpoint/latest/userguide/channels-sms-manage.html#channels-sms-manage-optout)\nin the *Amazon Pinpoint User Guide*.","ref":"AWS.PinpointSMSVoiceV2.html#create_opt_out_list/3","title":"AWS.PinpointSMSVoiceV2.create_opt_out_list/3","type":"function"},{"doc":"Creates a new pool and associates the specified origination identity to the\npool.\n\nA pool can include one or more phone numbers and SenderIds that are associated\nwith your Amazon Web Services account.\n\nThe new pool inherits its configuration from the specified origination identity.\nThis includes keywords, message type, opt-out list, two-way configuration, and\nself-managed opt-out configuration. Deletion protection isn't inherited from the\norigination identity and defaults to false.\n\nIf the origination identity is a phone number and is already associated with\nanother pool, an error is returned. A sender ID can be associated with multiple\npools.","ref":"AWS.PinpointSMSVoiceV2.html#create_pool/3","title":"AWS.PinpointSMSVoiceV2.create_pool/3","type":"function"},{"doc":"Creates a new registration based on the **RegistrationType** field.","ref":"AWS.PinpointSMSVoiceV2.html#create_registration/3","title":"AWS.PinpointSMSVoiceV2.create_registration/3","type":"function"},{"doc":"Associate the registration with an origination identity such as a phone number\nor sender ID.","ref":"AWS.PinpointSMSVoiceV2.html#create_registration_association/3","title":"AWS.PinpointSMSVoiceV2.create_registration_association/3","type":"function"},{"doc":"Create a new registration attachment to use for uploading a file or a URL to a\nfile.\n\nThe maximum file size is 1MiB and valid file extensions are PDF, JPEG and PNG.\nFor example, many sender ID registrations require a signed “letter of\nauthorization” (LOA) to be submitted.","ref":"AWS.PinpointSMSVoiceV2.html#create_registration_attachment/3","title":"AWS.PinpointSMSVoiceV2.create_registration_attachment/3","type":"function"},{"doc":"Create a new version of the registration and increase the **VersionNumber**.\n\nThe previous version of the registration becomes read-only.","ref":"AWS.PinpointSMSVoiceV2.html#create_registration_version/3","title":"AWS.PinpointSMSVoiceV2.create_registration_version/3","type":"function"},{"doc":"You can only send messages to verified destination numbers when your account is\nin the sandbox.\n\nYou can add up to 10 verified destination numbers.","ref":"AWS.PinpointSMSVoiceV2.html#create_verified_destination_number/3","title":"AWS.PinpointSMSVoiceV2.create_verified_destination_number/3","type":"function"},{"doc":"Deletes an existing configuration set.\n\nA configuration set is a set of rules that you apply to voice and SMS messages\nthat you send. In a configuration set, you can specify a destination for\nspecific types of events related to voice and SMS messages.","ref":"AWS.PinpointSMSVoiceV2.html#delete_configuration_set/3","title":"AWS.PinpointSMSVoiceV2.delete_configuration_set/3","type":"function"},{"doc":"Deletes an existing default message type on a configuration set.\n\nA message type is a type of messages that you plan to send. If you send\naccount-related messages or time-sensitive messages such as one-time passcodes,\nchoose **Transactional**. If you plan to send messages that contain marketing\nmaterial or other promotional content, choose **Promotional**. This setting\napplies to your entire Amazon Web Services account.","ref":"AWS.PinpointSMSVoiceV2.html#delete_default_message_type/3","title":"AWS.PinpointSMSVoiceV2.delete_default_message_type/3","type":"function"},{"doc":"Deletes an existing default sender ID on a configuration set.\n\nA default sender ID is the identity that appears on recipients' devices when\nthey receive SMS messages. Support for sender ID capabilities varies by country\nor region.","ref":"AWS.PinpointSMSVoiceV2.html#delete_default_sender_id/3","title":"AWS.PinpointSMSVoiceV2.delete_default_sender_id/3","type":"function"},{"doc":"Deletes an existing event destination.\n\nAn event destination is a location where you send response information about the\nmessages that you send. For example, when a message is delivered successfully,\nyou can send information about that event to an Amazon CloudWatch destination,\nor send notifications to endpoints that are subscribed to an Amazon SNS topic.","ref":"AWS.PinpointSMSVoiceV2.html#delete_event_destination/3","title":"AWS.PinpointSMSVoiceV2.delete_event_destination/3","type":"function"},{"doc":"Deletes an existing keyword from an origination phone number or pool.\n\nA keyword is a word that you can search for on a particular phone number or\npool. It is also a specific word or phrase that an end user can send to your\nnumber to elicit a response, such as an informational message or a special\noffer. When your number receives a message that begins with a keyword, Amazon\nPinpoint responds with a customizable message.\n\nKeywords \"HELP\" and \"STOP\" can't be deleted or modified.","ref":"AWS.PinpointSMSVoiceV2.html#delete_keyword/3","title":"AWS.PinpointSMSVoiceV2.delete_keyword/3","type":"function"},{"doc":"Deletes an existing opt-out list.\n\nAll opted out phone numbers in the opt-out list are deleted.\n\nIf the specified opt-out list name doesn't exist or is in-use by an origination\nphone number or pool, an error is returned.","ref":"AWS.PinpointSMSVoiceV2.html#delete_opt_out_list/3","title":"AWS.PinpointSMSVoiceV2.delete_opt_out_list/3","type":"function"},{"doc":"Deletes an existing opted out destination phone number from the specified\nopt-out list.\n\nEach destination phone number can only be deleted once every 30 days.\n\nIf the specified destination phone number doesn't exist or if the opt-out list\ndoesn't exist, an error is returned.","ref":"AWS.PinpointSMSVoiceV2.html#delete_opted_out_number/3","title":"AWS.PinpointSMSVoiceV2.delete_opted_out_number/3","type":"function"},{"doc":"Deletes an existing pool.\n\nDeleting a pool disassociates all origination identities from that pool.\n\nIf the pool status isn't active or if deletion protection is enabled, an error\nis returned.\n\nA pool is a collection of phone numbers and SenderIds. A pool can include one or\nmore phone numbers and SenderIds that are associated with your Amazon Web\nServices account.","ref":"AWS.PinpointSMSVoiceV2.html#delete_pool/3","title":"AWS.PinpointSMSVoiceV2.delete_pool/3","type":"function"},{"doc":"Permanently delete an existing registration from your account.","ref":"AWS.PinpointSMSVoiceV2.html#delete_registration/3","title":"AWS.PinpointSMSVoiceV2.delete_registration/3","type":"function"},{"doc":"Permanently delete the specified registration attachment.","ref":"AWS.PinpointSMSVoiceV2.html#delete_registration_attachment/3","title":"AWS.PinpointSMSVoiceV2.delete_registration_attachment/3","type":"function"},{"doc":"Delete the value in a registration form field.","ref":"AWS.PinpointSMSVoiceV2.html#delete_registration_field_value/3","title":"AWS.PinpointSMSVoiceV2.delete_registration_field_value/3","type":"function"},{"doc":"Deletes an account-level monthly spending limit override for sending text\nmessages.\n\nDeleting a spend limit override will set the `EnforcedLimit` to equal the\n`MaxLimit`, which is controlled by Amazon Web Services. For more information on\nspend limits (quotas) see [Amazon Pinpoint quotas\n](https://docs.aws.amazon.com/pinpoint/latest/developerguide/quotas.html) in the\n*Amazon Pinpoint Developer Guide*.","ref":"AWS.PinpointSMSVoiceV2.html#delete_text_message_spend_limit_override/3","title":"AWS.PinpointSMSVoiceV2.delete_text_message_spend_limit_override/3","type":"function"},{"doc":"Delete a verified destination phone number.","ref":"AWS.PinpointSMSVoiceV2.html#delete_verified_destination_number/3","title":"AWS.PinpointSMSVoiceV2.delete_verified_destination_number/3","type":"function"},{"doc":"Deletes an account level monthly spend limit override for sending voice\nmessages.\n\nDeleting a spend limit override sets the `EnforcedLimit` equal to the\n`MaxLimit`, which is controlled by Amazon Web Services. For more information on\nspending limits (quotas) see [Amazon Pinpoint quotas](https://docs.aws.amazon.com/pinpoint/latest/developerguide/quotas.html)\nin the *Amazon Pinpoint Developer Guide*.","ref":"AWS.PinpointSMSVoiceV2.html#delete_voice_message_spend_limit_override/3","title":"AWS.PinpointSMSVoiceV2.delete_voice_message_spend_limit_override/3","type":"function"},{"doc":"Describes attributes of your Amazon Web Services account.\n\nThe supported account attributes include account tier, which indicates whether\nyour account is in the sandbox or production environment. When you're ready to\nmove your account out of the sandbox, create an Amazon Web Services Support case\nfor a service limit increase request.\n\nNew Amazon Pinpoint accounts are placed into an SMS or voice sandbox. The\nsandbox protects both Amazon Web Services end recipients and SMS or voice\nrecipients from fraud and abuse.","ref":"AWS.PinpointSMSVoiceV2.html#describe_account_attributes/3","title":"AWS.PinpointSMSVoiceV2.describe_account_attributes/3","type":"function"},{"doc":"Describes the current Amazon Pinpoint SMS Voice V2 resource quotas for your\naccount.\n\nThe description for a quota includes the quota name, current usage toward that\nquota, and the quota's maximum value.\n\nWhen you establish an Amazon Web Services account, the account has initial\nquotas on the maximum number of configuration sets, opt-out lists, phone\nnumbers, and pools that you can create in a given Region. For more information\nsee [ Amazon Pinpoint quotas\n](https://docs.aws.amazon.com/pinpoint/latest/developerguide/quotas.html) in the\n*Amazon Pinpoint Developer Guide*.","ref":"AWS.PinpointSMSVoiceV2.html#describe_account_limits/3","title":"AWS.PinpointSMSVoiceV2.describe_account_limits/3","type":"function"},{"doc":"Describes the specified configuration sets or all in your account.\n\nIf you specify configuration set names, the output includes information for only\nthe specified configuration sets. If you specify filters, the output includes\ninformation for only those configuration sets that meet the filter criteria. If\nyou don't specify configuration set names or filters, the output includes\ninformation for all configuration sets.\n\nIf you specify a configuration set name that isn't valid, an error is returned.","ref":"AWS.PinpointSMSVoiceV2.html#describe_configuration_sets/3","title":"AWS.PinpointSMSVoiceV2.describe_configuration_sets/3","type":"function"},{"doc":"Describes the specified keywords or all keywords on your origination phone\nnumber or pool.\n\nA keyword is a word that you can search for on a particular phone number or\npool. It is also a specific word or phrase that an end user can send to your\nnumber to elicit a response, such as an informational message or a special\noffer. When your number receives a message that begins with a keyword, Amazon\nPinpoint responds with a customizable message.\n\nIf you specify a keyword that isn't valid, an error is returned.","ref":"AWS.PinpointSMSVoiceV2.html#describe_keywords/3","title":"AWS.PinpointSMSVoiceV2.describe_keywords/3","type":"function"},{"doc":"Describes the specified opt-out list or all opt-out lists in your account.\n\nIf you specify opt-out list names, the output includes information for only the\nspecified opt-out lists. Opt-out lists include only those that meet the filter\ncriteria. If you don't specify opt-out list names or filters, the output\nincludes information for all opt-out lists.\n\nIf you specify an opt-out list name that isn't valid, an error is returned.","ref":"AWS.PinpointSMSVoiceV2.html#describe_opt_out_lists/3","title":"AWS.PinpointSMSVoiceV2.describe_opt_out_lists/3","type":"function"},{"doc":"Describes the specified opted out destination numbers or all opted out\ndestination numbers in an opt-out list.\n\nIf you specify opted out numbers, the output includes information for only the\nspecified opted out numbers. If you specify filters, the output includes\ninformation for only those opted out numbers that meet the filter criteria. If\nyou don't specify opted out numbers or filters, the output includes information\nfor all opted out destination numbers in your opt-out list.\n\nIf you specify an opted out number that isn't valid, an error is returned.","ref":"AWS.PinpointSMSVoiceV2.html#describe_opted_out_numbers/3","title":"AWS.PinpointSMSVoiceV2.describe_opted_out_numbers/3","type":"function"},{"doc":"Describes the specified origination phone number, or all the phone numbers in\nyour account.\n\nIf you specify phone number IDs, the output includes information for only the\nspecified phone numbers. If you specify filters, the output includes information\nfor only those phone numbers that meet the filter criteria. If you don't specify\nphone number IDs or filters, the output includes information for all phone\nnumbers.\n\nIf you specify a phone number ID that isn't valid, an error is returned.","ref":"AWS.PinpointSMSVoiceV2.html#describe_phone_numbers/3","title":"AWS.PinpointSMSVoiceV2.describe_phone_numbers/3","type":"function"},{"doc":"Retrieves the specified pools or all pools associated with your Amazon Web\nServices account.\n\nIf you specify pool IDs, the output includes information for only the specified\npools. If you specify filters, the output includes information for only those\npools that meet the filter criteria. If you don't specify pool IDs or filters,\nthe output includes information for all pools.\n\nIf you specify a pool ID that isn't valid, an error is returned.\n\nA pool is a collection of phone numbers and SenderIds. A pool can include one or\nmore phone numbers and SenderIds that are associated with your Amazon Web\nServices account.","ref":"AWS.PinpointSMSVoiceV2.html#describe_pools/3","title":"AWS.PinpointSMSVoiceV2.describe_pools/3","type":"function"},{"doc":"Retrieves the specified registration attachments or all registration attachments\nassociated with your Amazon Web Services account.","ref":"AWS.PinpointSMSVoiceV2.html#describe_registration_attachments/3","title":"AWS.PinpointSMSVoiceV2.describe_registration_attachments/3","type":"function"},{"doc":"Retrieves the specified registration type field definitions.\n\nYou can use DescribeRegistrationFieldDefinitions to view the requirements for\ncreating, filling out, and submitting each registration type.","ref":"AWS.PinpointSMSVoiceV2.html#describe_registration_field_definitions/3","title":"AWS.PinpointSMSVoiceV2.describe_registration_field_definitions/3","type":"function"},{"doc":"Retrieves the specified registration field values.","ref":"AWS.PinpointSMSVoiceV2.html#describe_registration_field_values/3","title":"AWS.PinpointSMSVoiceV2.describe_registration_field_values/3","type":"function"},{"doc":"Retrieves the specified registration section definitions.\n\nYou can use DescribeRegistrationSectionDefinitions to view the requirements for\ncreating, filling out, and submitting each registration type.","ref":"AWS.PinpointSMSVoiceV2.html#describe_registration_section_definitions/3","title":"AWS.PinpointSMSVoiceV2.describe_registration_section_definitions/3","type":"function"},{"doc":"Retrieves the specified registration type definitions.\n\nYou can use DescribeRegistrationTypeDefinitions to view the requirements for\ncreating, filling out, and submitting each registration type.","ref":"AWS.PinpointSMSVoiceV2.html#describe_registration_type_definitions/3","title":"AWS.PinpointSMSVoiceV2.describe_registration_type_definitions/3","type":"function"},{"doc":"Retrieves the specified registration version.","ref":"AWS.PinpointSMSVoiceV2.html#describe_registration_versions/3","title":"AWS.PinpointSMSVoiceV2.describe_registration_versions/3","type":"function"},{"doc":"Retrieves the specified registrations.","ref":"AWS.PinpointSMSVoiceV2.html#describe_registrations/3","title":"AWS.PinpointSMSVoiceV2.describe_registrations/3","type":"function"},{"doc":"Describes the specified SenderIds or all SenderIds associated with your Amazon\nWeb Services account.\n\nIf you specify SenderIds, the output includes information for only the specified\nSenderIds. If you specify filters, the output includes information for only\nthose SenderIds that meet the filter criteria. If you don't specify SenderIds or\nfilters, the output includes information for all SenderIds.\n\nf you specify a sender ID that isn't valid, an error is returned.","ref":"AWS.PinpointSMSVoiceV2.html#describe_sender_ids/3","title":"AWS.PinpointSMSVoiceV2.describe_sender_ids/3","type":"function"},{"doc":"Describes the current Amazon Pinpoint monthly spend limits for sending voice and\ntext messages.\n\nWhen you establish an Amazon Web Services account, the account has initial\nmonthly spend limit in a given Region. For more information on increasing your\nmonthly spend limit, see [ Requesting increases to your monthly SMS spending quota for Amazon Pinpoint\n](https://docs.aws.amazon.com/pinpoint/latest/userguide/channels-sms-awssupport-spend-threshold.html)\nin the *Amazon Pinpoint User Guide*.","ref":"AWS.PinpointSMSVoiceV2.html#describe_spend_limits/3","title":"AWS.PinpointSMSVoiceV2.describe_spend_limits/3","type":"function"},{"doc":"Retrieves the specified verified destiona numbers.","ref":"AWS.PinpointSMSVoiceV2.html#describe_verified_destination_numbers/3","title":"AWS.PinpointSMSVoiceV2.describe_verified_destination_numbers/3","type":"function"},{"doc":"Removes the specified origination identity from an existing pool.\n\nIf the origination identity isn't associated with the specified pool, an error\nis returned.","ref":"AWS.PinpointSMSVoiceV2.html#disassociate_origination_identity/3","title":"AWS.PinpointSMSVoiceV2.disassociate_origination_identity/3","type":"function"},{"doc":"Discard the current version of the registration.","ref":"AWS.PinpointSMSVoiceV2.html#discard_registration_version/3","title":"AWS.PinpointSMSVoiceV2.discard_registration_version/3","type":"function"},{"doc":"Lists all associated origination identities in your pool.\n\nIf you specify filters, the output includes information for only those\norigination identities that meet the filter criteria.","ref":"AWS.PinpointSMSVoiceV2.html#list_pool_origination_identities/3","title":"AWS.PinpointSMSVoiceV2.list_pool_origination_identities/3","type":"function"},{"doc":"Retreive all of the origination identies that are associated with a\nregistration.","ref":"AWS.PinpointSMSVoiceV2.html#list_registration_associations/3","title":"AWS.PinpointSMSVoiceV2.list_registration_associations/3","type":"function"},{"doc":"List all tags associated with a resource.","ref":"AWS.PinpointSMSVoiceV2.html#list_tags_for_resource/3","title":"AWS.PinpointSMSVoiceV2.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.PinpointSMSVoiceV2.html#metadata/0","title":"AWS.PinpointSMSVoiceV2.metadata/0","type":"function"},{"doc":"Creates or updates a keyword configuration on an origination phone number or\npool.\n\nA keyword is a word that you can search for on a particular phone number or\npool. It is also a specific word or phrase that an end user can send to your\nnumber to elicit a response, such as an informational message or a special\noffer. When your number receives a message that begins with a keyword, Amazon\nPinpoint responds with a customizable message.\n\nIf you specify a keyword that isn't valid, an error is returned.","ref":"AWS.PinpointSMSVoiceV2.html#put_keyword/3","title":"AWS.PinpointSMSVoiceV2.put_keyword/3","type":"function"},{"doc":"Creates an opted out destination phone number in the opt-out list.\n\nIf the destination phone number isn't valid or if the specified opt-out list\ndoesn't exist, an error is returned.","ref":"AWS.PinpointSMSVoiceV2.html#put_opted_out_number/3","title":"AWS.PinpointSMSVoiceV2.put_opted_out_number/3","type":"function"},{"doc":"Creates or updates a field value for a registration.","ref":"AWS.PinpointSMSVoiceV2.html#put_registration_field_value/3","title":"AWS.PinpointSMSVoiceV2.put_registration_field_value/3","type":"function"},{"doc":"Releases an existing origination phone number in your account.\n\nOnce released, a phone number is no longer available for sending messages.\n\nIf the origination phone number has deletion protection enabled or is associated\nwith a pool, an error is returned.","ref":"AWS.PinpointSMSVoiceV2.html#release_phone_number/3","title":"AWS.PinpointSMSVoiceV2.release_phone_number/3","type":"function"},{"doc":"Releases an existing sender ID in your account.","ref":"AWS.PinpointSMSVoiceV2.html#release_sender_id/3","title":"AWS.PinpointSMSVoiceV2.release_sender_id/3","type":"function"},{"doc":"Request an origination phone number for use in your account.\n\nFor more information on phone number request see [ Requesting a number\n](https://docs.aws.amazon.com/pinpoint/latest/userguide/settings-sms-request-number.html)\nin the *Amazon Pinpoint User Guide*.","ref":"AWS.PinpointSMSVoiceV2.html#request_phone_number/3","title":"AWS.PinpointSMSVoiceV2.request_phone_number/3","type":"function"},{"doc":"Request a new sender ID that doesn't require registration.","ref":"AWS.PinpointSMSVoiceV2.html#request_sender_id/3","title":"AWS.PinpointSMSVoiceV2.request_sender_id/3","type":"function"},{"doc":"Before you can send test messages to a verified destination phone number you\nneed to opt-in the verified destination phone number.\n\nCreates a new text message with a verification code and send it to a verified\ndestination phone number. Once you have the verification code use\n`VerifyDestinationNumber` to opt-in the verified destination phone number to\nreceive messages.","ref":"AWS.PinpointSMSVoiceV2.html#send_destination_number_verification_code/3","title":"AWS.PinpointSMSVoiceV2.send_destination_number_verification_code/3","type":"function"},{"doc":"Creates a new text message and sends it to a recipient's phone number.\n\nSMS throughput limits are measured in Message Parts per Second (MPS). Your MPS\nlimit depends on the destination country of your messages, as well as the type\nof phone number (origination number) that you use to send the message. For more\ninformation, see [Message Parts per Second (MPS) limits](https://docs.aws.amazon.com/pinpoint/latest/userguide/channels-sms-limitations-mps.html)\nin the *Amazon Pinpoint User Guide*.","ref":"AWS.PinpointSMSVoiceV2.html#send_text_message/3","title":"AWS.PinpointSMSVoiceV2.send_text_message/3","type":"function"},{"doc":"Allows you to send a request that sends a voice message through Amazon Pinpoint.\n\nThis operation uses [Amazon Polly](http://aws.amazon.com/polly/) to convert a\ntext script into a voice message.","ref":"AWS.PinpointSMSVoiceV2.html#send_voice_message/3","title":"AWS.PinpointSMSVoiceV2.send_voice_message/3","type":"function"},{"doc":"Sets the default message type on a configuration set.\n\nChoose the category of SMS messages that you plan to send from this account. If\nyou send account-related messages or time-sensitive messages such as one-time\npasscodes, choose **Transactional**. If you plan to send messages that contain\nmarketing material or other promotional content, choose **Promotional**. This\nsetting applies to your entire Amazon Web Services account.","ref":"AWS.PinpointSMSVoiceV2.html#set_default_message_type/3","title":"AWS.PinpointSMSVoiceV2.set_default_message_type/3","type":"function"},{"doc":"Sets default sender ID on a configuration set.\n\nWhen sending a text message to a destination country that supports sender IDs,\nthe default sender ID on the configuration set specified will be used if no\ndedicated origination phone numbers or registered sender IDs are available in\nyour account.","ref":"AWS.PinpointSMSVoiceV2.html#set_default_sender_id/3","title":"AWS.PinpointSMSVoiceV2.set_default_sender_id/3","type":"function"},{"doc":"Sets an account level monthly spend limit override for sending text messages.\n\nThe requested spend limit must be less than or equal to the `MaxLimit`, which is\nset by Amazon Web Services.","ref":"AWS.PinpointSMSVoiceV2.html#set_text_message_spend_limit_override/3","title":"AWS.PinpointSMSVoiceV2.set_text_message_spend_limit_override/3","type":"function"},{"doc":"Sets an account level monthly spend limit override for sending voice messages.\n\nThe requested spend limit must be less than or equal to the `MaxLimit`, which is\nset by Amazon Web Services.","ref":"AWS.PinpointSMSVoiceV2.html#set_voice_message_spend_limit_override/3","title":"AWS.PinpointSMSVoiceV2.set_voice_message_spend_limit_override/3","type":"function"},{"doc":"Submit the specified registration for review and approval.","ref":"AWS.PinpointSMSVoiceV2.html#submit_registration_version/3","title":"AWS.PinpointSMSVoiceV2.submit_registration_version/3","type":"function"},{"doc":"Adds or overwrites only the specified tags for the specified Amazon Pinpoint SMS\nVoice, version 2 resource.\n\nWhen you specify an existing tag key, the value is overwritten with the new\nvalue. Each resource can have a maximum of 50 tags. Each tag consists of a key\nand an optional value. Tag keys must be unique per resource. For more\ninformation about tags, see [ Tagging Amazon Pinpoint resources](https://docs.aws.amazon.com/pinpoint/latest/developerguide/tagging-resources.html)\nin the *Amazon Pinpoint Developer Guide*.","ref":"AWS.PinpointSMSVoiceV2.html#tag_resource/3","title":"AWS.PinpointSMSVoiceV2.tag_resource/3","type":"function"},{"doc":"Removes the association of the specified tags from an Amazon Pinpoint SMS Voice\nV2 resource.\n\nFor more information on tags see [ Tagging Amazon Pinpoint resources](https://docs.aws.amazon.com/pinpoint/latest/developerguide/tagging-resources.html)\nin the *Amazon Pinpoint Developer Guide*.","ref":"AWS.PinpointSMSVoiceV2.html#untag_resource/3","title":"AWS.PinpointSMSVoiceV2.untag_resource/3","type":"function"},{"doc":"Updates an existing event destination in a configuration set.\n\nYou can update the IAM role ARN for CloudWatch Logs and Kinesis Data Firehose.\nYou can also enable or disable the event destination.\n\nYou may want to update an event destination to change its matching event types\nor updating the destination resource ARN. You can't change an event\ndestination's type between CloudWatch Logs, Kinesis Data Firehose, and Amazon\nSNS.","ref":"AWS.PinpointSMSVoiceV2.html#update_event_destination/3","title":"AWS.PinpointSMSVoiceV2.update_event_destination/3","type":"function"},{"doc":"Updates the configuration of an existing origination phone number.\n\nYou can update the opt-out list, enable or disable two-way messaging, change the\nTwoWayChannelArn, enable or disable self-managed opt-outs, and enable or disable\ndeletion protection.\n\nIf the origination phone number is associated with a pool, an error is returned.","ref":"AWS.PinpointSMSVoiceV2.html#update_phone_number/3","title":"AWS.PinpointSMSVoiceV2.update_phone_number/3","type":"function"},{"doc":"Updates the configuration of an existing pool.\n\nYou can update the opt-out list, enable or disable two-way messaging, change the\n`TwoWayChannelArn`, enable or disable self-managed opt-outs, enable or disable\ndeletion protection, and enable or disable shared routes.","ref":"AWS.PinpointSMSVoiceV2.html#update_pool/3","title":"AWS.PinpointSMSVoiceV2.update_pool/3","type":"function"},{"doc":"Updates the configuration of an existing sender ID.","ref":"AWS.PinpointSMSVoiceV2.html#update_sender_id/3","title":"AWS.PinpointSMSVoiceV2.update_sender_id/3","type":"function"},{"doc":"Use the verification code that was received by the verified destination phone\nnumber to opt-in the verified destination phone number to receive more messages.","ref":"AWS.PinpointSMSVoiceV2.html#verify_destination_number/3","title":"AWS.PinpointSMSVoiceV2.verify_destination_number/3","type":"function"},{"doc":"Amazon EventBridge Pipes connects event sources to targets.\n\nPipes reduces the need for specialized knowledge and integration code when\ndeveloping event driven architectures. This helps ensures consistency across\nyour company’s applications. With Pipes, the target can be any available\nEventBridge target. To set up a pipe, you select the event source, add optional\nevent filtering, define optional enrichment, and select the target for the event\ndata.","ref":"AWS.Pipes.html","title":"AWS.Pipes","type":"module"},{"doc":"Create a pipe.\n\nAmazon EventBridge Pipes connect event sources to targets and reduces the need\nfor specialized knowledge and integration code.","ref":"AWS.Pipes.html#create_pipe/4","title":"AWS.Pipes.create_pipe/4","type":"function"},{"doc":"Delete an existing pipe.\n\nFor more information about pipes, see [Amazon EventBridge Pipes](https://docs.aws.amazon.com/eventbridge/latest/userguide/eb-pipes.html)\nin the Amazon EventBridge User Guide.","ref":"AWS.Pipes.html#delete_pipe/4","title":"AWS.Pipes.delete_pipe/4","type":"function"},{"doc":"Get the information about an existing pipe.\n\nFor more information about pipes, see [Amazon EventBridge Pipes](https://docs.aws.amazon.com/eventbridge/latest/userguide/eb-pipes.html)\nin the Amazon EventBridge User Guide.","ref":"AWS.Pipes.html#describe_pipe/3","title":"AWS.Pipes.describe_pipe/3","type":"function"},{"doc":"Get the pipes associated with this account.\n\nFor more information about pipes, see [Amazon EventBridge Pipes](https://docs.aws.amazon.com/eventbridge/latest/userguide/eb-pipes.html)\nin the Amazon EventBridge User Guide.","ref":"AWS.Pipes.html#list_pipes/9","title":"AWS.Pipes.list_pipes/9","type":"function"},{"doc":"Displays the tags associated with a pipe.","ref":"AWS.Pipes.html#list_tags_for_resource/3","title":"AWS.Pipes.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.Pipes.html#metadata/0","title":"AWS.Pipes.metadata/0","type":"function"},{"doc":"Start an existing pipe.","ref":"AWS.Pipes.html#start_pipe/4","title":"AWS.Pipes.start_pipe/4","type":"function"},{"doc":"Stop an existing pipe.","ref":"AWS.Pipes.html#stop_pipe/4","title":"AWS.Pipes.stop_pipe/4","type":"function"},{"doc":"Assigns one or more tags (key-value pairs) to the specified pipe.\n\nTags can help you organize and categorize your resources. You can also use them\nto scope user permissions by granting a user permission to access or change only\nresources with certain tag values.\n\nTags don't have any semantic meaning to Amazon Web Services and are interpreted\nstrictly as strings of characters.\n\nYou can use the `TagResource` action with a pipe that already has tags. If you\nspecify a new tag key, this tag is appended to the list of tags associated with\nthe pipe. If you specify a tag key that is already associated with the pipe, the\nnew tag value that you specify replaces the previous value for that tag.\n\nYou can associate as many as 50 tags with a pipe.","ref":"AWS.Pipes.html#tag_resource/4","title":"AWS.Pipes.tag_resource/4","type":"function"},{"doc":"Removes one or more tags from the specified pipes.","ref":"AWS.Pipes.html#untag_resource/4","title":"AWS.Pipes.untag_resource/4","type":"function"},{"doc":"Update an existing pipe.\n\nWhen you call `UpdatePipe`, EventBridge only the updates fields you have\nspecified in the request; the rest remain unchanged. The exception to this is if\nyou modify any Amazon Web Services-service specific fields in the\n`SourceParameters`, `EnrichmentParameters`, or `TargetParameters` objects. For\nexample, `DynamoDBStreamParameters` or `EventBridgeEventBusParameters`.\nEventBridge updates the fields in these objects atomically as one and overrides\nexisting values. This is by design, and means that if you don't specify an\noptional field in one of these `Parameters` objects, EventBridge sets that field\nto its system-default value during the update.\n\nFor more information about pipes, see [ Amazon EventBridge Pipes](https://docs.aws.amazon.com/eventbridge/latest/userguide/eb-pipes.html)\nin the Amazon EventBridge User Guide.","ref":"AWS.Pipes.html#update_pipe/4","title":"AWS.Pipes.update_pipe/4","type":"function"},{"doc":"Amazon Polly is a web service that makes it easy to synthesize speech from text.\n\nThe Amazon Polly service provides API operations for synthesizing high-quality\nspeech from plain text and Speech Synthesis Markup Language (SSML), along with\nmanaging pronunciations lexicons that enable you to get the best results for\nyour application domain.","ref":"AWS.Polly.html","title":"AWS.Polly","type":"module"},{"doc":"Deletes the specified pronunciation lexicon stored in an Amazon Web Services\nRegion.\n\nA lexicon which has been deleted is not available for speech synthesis, nor is\nit possible to retrieve it using either the `GetLexicon` or `ListLexicon` APIs.\n\nFor more information, see [Managing Lexicons](https://docs.aws.amazon.com/polly/latest/dg/managing-lexicons.html).","ref":"AWS.Polly.html#delete_lexicon/4","title":"AWS.Polly.delete_lexicon/4","type":"function"},{"doc":"Returns the list of voices that are available for use when requesting speech\nsynthesis.\n\nEach voice speaks a specified language, is either male or female, and is\nidentified by an ID, which is the ASCII version of the voice name.\n\nWhen synthesizing speech ( `SynthesizeSpeech` ), you provide the voice ID for\nthe voice you want from the list of voices returned by `DescribeVoices`.\n\nFor example, you want your news reader application to read news in a specific\nlanguage, but giving a user the option to choose the voice. Using the\n`DescribeVoices` operation you can provide the user with a list of available\nvoices to select from.\n\nYou can optionally specify a language code to filter the available voices. For\nexample, if you specify `en-US`, the operation returns a list of all available\nUS English voices.\n\nThis operation requires permissions to perform the `polly:DescribeVoices`\naction.","ref":"AWS.Polly.html#describe_voices/6","title":"AWS.Polly.describe_voices/6","type":"function"},{"doc":"Returns the content of the specified pronunciation lexicon stored in an Amazon\nWeb Services Region.\n\nFor more information, see [Managing Lexicons](https://docs.aws.amazon.com/polly/latest/dg/managing-lexicons.html).","ref":"AWS.Polly.html#get_lexicon/3","title":"AWS.Polly.get_lexicon/3","type":"function"},{"doc":"Retrieves a specific SpeechSynthesisTask object based on its TaskID.\n\nThis object contains information about the given speech synthesis task,\nincluding the status of the task, and a link to the S3 bucket containing the\noutput of the task.","ref":"AWS.Polly.html#get_speech_synthesis_task/3","title":"AWS.Polly.get_speech_synthesis_task/3","type":"function"},{"doc":"Returns a list of pronunciation lexicons stored in an Amazon Web Services\nRegion.\n\nFor more information, see [Managing Lexicons](https://docs.aws.amazon.com/polly/latest/dg/managing-lexicons.html).","ref":"AWS.Polly.html#list_lexicons/3","title":"AWS.Polly.list_lexicons/3","type":"function"},{"doc":"Returns a list of SpeechSynthesisTask objects ordered by their creation date.\n\nThis operation can filter the tasks by their status, for example, allowing users\nto list only tasks that are completed.","ref":"AWS.Polly.html#list_speech_synthesis_tasks/5","title":"AWS.Polly.list_speech_synthesis_tasks/5","type":"function"},{"doc":"","ref":"AWS.Polly.html#metadata/0","title":"AWS.Polly.metadata/0","type":"function"},{"doc":"Stores a pronunciation lexicon in an Amazon Web Services Region.\n\nIf a lexicon with the same name already exists in the region, it is overwritten\nby the new lexicon. Lexicon operations have eventual consistency, therefore, it\nmight take some time before the lexicon is available to the SynthesizeSpeech\noperation.\n\nFor more information, see [Managing Lexicons](https://docs.aws.amazon.com/polly/latest/dg/managing-lexicons.html).","ref":"AWS.Polly.html#put_lexicon/4","title":"AWS.Polly.put_lexicon/4","type":"function"},{"doc":"Allows the creation of an asynchronous synthesis task, by starting a new\n`SpeechSynthesisTask`.\n\nThis operation requires all the standard information needed for speech\nsynthesis, plus the name of an Amazon S3 bucket for the service to store the\noutput of the synthesis task and two optional parameters (`OutputS3KeyPrefix`\nand `SnsTopicArn`). Once the synthesis task is created, this operation will\nreturn a `SpeechSynthesisTask` object, which will include an identifier of this\ntask as well as the current status. The `SpeechSynthesisTask` object is\navailable for 72 hours after starting the asynchronous synthesis task.","ref":"AWS.Polly.html#start_speech_synthesis_task/3","title":"AWS.Polly.start_speech_synthesis_task/3","type":"function"},{"doc":"Synthesizes UTF-8 input, plain text or SSML, to a stream of bytes.\n\nSSML input must be valid, well-formed SSML. Some alphabets might not be\navailable with all the voices (for example, Cyrillic might not be read at all by\nEnglish voices) unless phoneme mapping is used. For more information, see [How it\nWorks](https://docs.aws.amazon.com/polly/latest/dg/how-text-to-speech-works.html).","ref":"AWS.Polly.html#synthesize_speech/3","title":"AWS.Polly.synthesize_speech/3","type":"function"},{"doc":"The Amazon Web Services Price List API is a centralized and convenient way to\nprogrammatically query Amazon Web Services for services, products, and pricing\ninformation.\n\nThe Amazon Web Services Price List uses standardized product attributes such as\n`Location`, `Storage Class`, and `Operating System`, and provides prices at the\nSKU level. You can use the Amazon Web Services Price List to do the following:\n\n  * Build cost control and scenario planning tools\n\n  * Reconcile billing data\n\n  * Forecast future spend for budgeting purposes\n\n  * Provide cost benefit analysis that compare your internal workloads\nwith Amazon Web Services\n\nUse `GetServices` without a service code to retrieve the service codes for all\nAmazon Web Services, then `GetServices` with a service code to retrieve the\nattribute names for that service. After you have the service code and attribute\nnames, you can use `GetAttributeValues` to see what values are available for an\nattribute. With the service code and an attribute name and value, you can use\n`GetProducts` to find specific products that you're interested in, such as an\n`AmazonEC2` instance, with a `Provisioned IOPS` `volumeType`.\n\nFor more information, see [Using the Amazon Web Services Price List API](https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/price-changes.html)\nin the *Billing User Guide*.","ref":"AWS.Pricing.html","title":"AWS.Pricing","type":"module"},{"doc":"Returns the metadata for one service or a list of the metadata for all services.\n\nUse this without a service code to get the service codes for all services. Use\nit with a service code, such as `AmazonEC2`, to get information specific to that\nservice, such as the attribute names available for that service. For example,\nsome of the attribute names available for EC2 are `volumeType`, `maxIopsVolume`,\n`operation`, `locationType`, and `instanceCapacity10xlarge`.","ref":"AWS.Pricing.html#describe_services/3","title":"AWS.Pricing.describe_services/3","type":"function"},{"doc":"Returns a list of attribute values.\n\nAttributes are similar to the details in a Price List API offer file. For a list\nof available attributes, see [Offer File Definitions](https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/reading-an-offer.html#pps-defs)\nin the [Billing and Cost Management User Guide](https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-what-is.html).","ref":"AWS.Pricing.html#get_attribute_values/3","title":"AWS.Pricing.get_attribute_values/3","type":"function"},{"doc":"* **This feature is in preview release and is subject to change.\n\nYour use of Amazon Web Services Price List API is subject to the Beta Service\nParticipation terms of the [Amazon Web Services Service Terms](https://aws.amazon.com/service-terms/) (Section 1.10).** *\n\nThis returns the URL that you can retrieve your Price List file from. This URL\nis based on the `PriceListArn` and `FileFormat` that you retrieve from the\n[ListPriceLists](https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_pricing_ListPriceLists.html)\nresponse.","ref":"AWS.Pricing.html#get_price_list_file_url/3","title":"AWS.Pricing.get_price_list_file_url/3","type":"function"},{"doc":"Returns a list of all products that match the filter criteria.","ref":"AWS.Pricing.html#get_products/3","title":"AWS.Pricing.get_products/3","type":"function"},{"doc":"* **This feature is in preview release and is subject to change.\n\nYour use of Amazon Web Services Price List API is subject to the Beta Service\nParticipation terms of the [Amazon Web Services Service Terms](https://aws.amazon.com/service-terms/) (Section 1.10).** *\n\nThis returns a list of Price List references that the requester if authorized to\nview, given a `ServiceCode`, `CurrencyCode`, and an `EffectiveDate`. Use without\na `RegionCode` filter to list Price List references from all available Amazon\nWeb Services Regions. Use with a `RegionCode` filter to get the Price List\nreference that's specific to a specific Amazon Web Services Region. You can use\nthe `PriceListArn` from the response to get your preferred Price List files\nthrough the\n[GetPriceListFileUrl](https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_pricing_GetPriceListFileUrl.html)\nAPI.","ref":"AWS.Pricing.html#list_price_lists/3","title":"AWS.Pricing.list_price_lists/3","type":"function"},{"doc":"","ref":"AWS.Pricing.html#metadata/0","title":"AWS.Pricing.metadata/0","type":"function"},{"doc":"Amazon Web Services Private 5G is a managed service that makes it easy to\ndeploy, operate, and scale your own private mobile network at your on-premises\nlocation.\n\nPrivate 5G provides the pre-configured hardware and software for mobile\nnetworks, helps automate setup, and scales capacity on demand to support\nadditional devices as needed.","ref":"AWS.PrivateNetworks.html","title":"AWS.PrivateNetworks","type":"module"},{"doc":"Acknowledges that the specified network order was received.","ref":"AWS.PrivateNetworks.html#acknowledge_order_receipt/3","title":"AWS.PrivateNetworks.acknowledge_order_receipt/3","type":"function"},{"doc":"Activates the specified device identifier.","ref":"AWS.PrivateNetworks.html#activate_device_identifier/3","title":"AWS.PrivateNetworks.activate_device_identifier/3","type":"function"},{"doc":"Activates the specified network site.","ref":"AWS.PrivateNetworks.html#activate_network_site/3","title":"AWS.PrivateNetworks.activate_network_site/3","type":"function"},{"doc":"Configures the specified network resource.\n\nUse this action to specify the geographic position of the hardware. You must\nprovide Certified Professional Installer (CPI) credentials in the request so\nthat we can obtain spectrum grants. For more information, see [Radio units](https://docs.aws.amazon.com/private-networks/latest/userguide/radio-units.html)\nin the *Amazon Web Services Private 5G User Guide*.","ref":"AWS.PrivateNetworks.html#configure_access_point/3","title":"AWS.PrivateNetworks.configure_access_point/3","type":"function"},{"doc":"Creates a network.","ref":"AWS.PrivateNetworks.html#create_network/3","title":"AWS.PrivateNetworks.create_network/3","type":"function"},{"doc":"Creates a network site.","ref":"AWS.PrivateNetworks.html#create_network_site/3","title":"AWS.PrivateNetworks.create_network_site/3","type":"function"},{"doc":"Deactivates the specified device identifier.","ref":"AWS.PrivateNetworks.html#deactivate_device_identifier/3","title":"AWS.PrivateNetworks.deactivate_device_identifier/3","type":"function"},{"doc":"Deletes the specified network.\n\nYou must delete network sites before you delete the network. For more\ninformation, see\n[DeleteNetworkSite](https://docs.aws.amazon.com/private-networks/latest/APIReference/API_DeleteNetworkSite.html)\nin the *API Reference for Amazon Web Services Private 5G*.","ref":"AWS.PrivateNetworks.html#delete_network/4","title":"AWS.PrivateNetworks.delete_network/4","type":"function"},{"doc":"Deletes the specified network site.\n\nReturn the hardware after you delete the network site. You are responsible for\nminimum charges. For more information, see [Hardware returns](https://docs.aws.amazon.com/private-networks/latest/userguide/hardware-maintenance.html)\nin the *Amazon Web Services Private 5G User Guide*.","ref":"AWS.PrivateNetworks.html#delete_network_site/4","title":"AWS.PrivateNetworks.delete_network_site/4","type":"function"},{"doc":"Gets the specified device identifier.","ref":"AWS.PrivateNetworks.html#get_device_identifier/3","title":"AWS.PrivateNetworks.get_device_identifier/3","type":"function"},{"doc":"Gets the specified network.","ref":"AWS.PrivateNetworks.html#get_network/3","title":"AWS.PrivateNetworks.get_network/3","type":"function"},{"doc":"Gets the specified network resource.","ref":"AWS.PrivateNetworks.html#get_network_resource/3","title":"AWS.PrivateNetworks.get_network_resource/3","type":"function"},{"doc":"Gets the specified network site.","ref":"AWS.PrivateNetworks.html#get_network_site/3","title":"AWS.PrivateNetworks.get_network_site/3","type":"function"},{"doc":"Gets the specified order.","ref":"AWS.PrivateNetworks.html#get_order/3","title":"AWS.PrivateNetworks.get_order/3","type":"function"},{"doc":"Lists device identifiers.\n\nAdd filters to your request to return a more specific list of results. Use\nfilters to match the Amazon Resource Name (ARN) of an order, the status of\ndevice identifiers, or the ARN of the traffic group.\n\nIf you specify multiple filters, filters are joined with an OR, and the request\nreturns results that match all of the specified filters.","ref":"AWS.PrivateNetworks.html#list_device_identifiers/3","title":"AWS.PrivateNetworks.list_device_identifiers/3","type":"function"},{"doc":"Lists network resources.\n\nAdd filters to your request to return a more specific list of results. Use\nfilters to match the Amazon Resource Name (ARN) of an order or the status of\nnetwork resources.\n\nIf you specify multiple filters, filters are joined with an OR, and the request\nreturns results that match all of the specified filters.","ref":"AWS.PrivateNetworks.html#list_network_resources/3","title":"AWS.PrivateNetworks.list_network_resources/3","type":"function"},{"doc":"Lists network sites.\n\nAdd filters to your request to return a more specific list of results. Use\nfilters to match the status of the network site.","ref":"AWS.PrivateNetworks.html#list_network_sites/3","title":"AWS.PrivateNetworks.list_network_sites/3","type":"function"},{"doc":"Lists networks.\n\nAdd filters to your request to return a more specific list of results. Use\nfilters to match the status of the network.","ref":"AWS.PrivateNetworks.html#list_networks/3","title":"AWS.PrivateNetworks.list_networks/3","type":"function"},{"doc":"Lists orders.\n\nAdd filters to your request to return a more specific list of results. Use\nfilters to match the Amazon Resource Name (ARN) of the network site or the\nstatus of the order.\n\nIf you specify multiple filters, filters are joined with an OR, and the request\nreturns results that match all of the specified filters.","ref":"AWS.PrivateNetworks.html#list_orders/3","title":"AWS.PrivateNetworks.list_orders/3","type":"function"},{"doc":"Lists the tags for the specified resource.","ref":"AWS.PrivateNetworks.html#list_tags_for_resource/3","title":"AWS.PrivateNetworks.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.PrivateNetworks.html#metadata/0","title":"AWS.PrivateNetworks.metadata/0","type":"function"},{"doc":"Checks the health of the service.","ref":"AWS.PrivateNetworks.html#ping/2","title":"AWS.PrivateNetworks.ping/2","type":"function"},{"doc":"Use this action to do the following tasks:\n\n  * Update the duration and renewal status of the commitment period\nfor a radio unit.\n\nThe update goes into effect immediately.\n\n  * Request a replacement for a network resource.\n\n  * Request that you return a network resource.\n\nAfter you submit a request to replace or return a network resource, the status\nof the network resource changes to `CREATING_SHIPPING_LABEL`. The shipping label\nis available when the status of the network resource is `PENDING_RETURN`. After\nthe network resource is successfully returned, its status changes to `DELETED`.\nFor more information, see [Return a radio unit](https://docs.aws.amazon.com/private-networks/latest/userguide/radio-units.html#return-radio-unit).","ref":"AWS.PrivateNetworks.html#start_network_resource_update/3","title":"AWS.PrivateNetworks.start_network_resource_update/3","type":"function"},{"doc":"Adds tags to the specified resource.","ref":"AWS.PrivateNetworks.html#tag_resource/4","title":"AWS.PrivateNetworks.tag_resource/4","type":"function"},{"doc":"Removes tags from the specified resource.","ref":"AWS.PrivateNetworks.html#untag_resource/4","title":"AWS.PrivateNetworks.untag_resource/4","type":"function"},{"doc":"Updates the specified network site.","ref":"AWS.PrivateNetworks.html#update_network_site/3","title":"AWS.PrivateNetworks.update_network_site/3","type":"function"},{"doc":"Updates the specified network site plan.","ref":"AWS.PrivateNetworks.html#update_network_site_plan/3","title":"AWS.PrivateNetworks.update_network_site_plan/3","type":"function"},{"doc":"This is the Proton Service API Reference.\n\nIt provides descriptions, syntax and usage examples for each of the\n[actions](https://docs.aws.amazon.com/proton/latest/APIReference/API_Operations.html) and [data\ntypes](https://docs.aws.amazon.com/proton/latest/APIReference/API_Types.html)\nfor the Proton service.\n\nThe documentation for each action shows the Query API request parameters and the\nXML response.\n\nAlternatively, you can use the Amazon Web Services CLI to access an API. For\nmore information, see the [Amazon Web Services Command Line Interface User Guide](https://docs.aws.amazon.com/cli/latest/userguide/cli-chap-welcome.html).\n\nThe Proton service is a two-pronged automation framework. Administrators create\nservice templates to provide standardized infrastructure and deployment tooling\nfor serverless and container based applications. Developers, in turn, select\nfrom the available service templates to automate their application or service\ndeployments.\n\nBecause administrators define the infrastructure and tooling that Proton deploys\nand manages, they need permissions to use all of the listed API operations.\n\nWhen developers select a specific infrastructure and tooling set, Proton deploys\ntheir applications. To monitor their applications that are running on Proton,\ndevelopers need permissions to the service *create*, *list*, *update* and\n*delete* API operations and the service instance *list* and *update* API\noperations.\n\nTo learn more about Proton, see the [Proton User Guide](https://docs.aws.amazon.com/proton/latest/userguide/Welcome.html).","ref":"AWS.Proton.html","title":"AWS.Proton","type":"module"},{"doc":"When you make a mutating API request, the request typically returns a result\nbefore the asynchronous workflows of the operation are complete. Operations\nmight also time out or encounter other server issues before they're complete,\neven if the request already returned a result. This might make it difficult to\ndetermine whether the request succeeded. Moreover, you might need to retry the\nrequest multiple times to ensure that the operation completes successfully.\nHowever, if the original request and the subsequent retries are successful, the\noperation occurs multiple times. This means that you might create more resources\nthan you intended.\n\n*Idempotency* ensures that an API request action completes no more than one\ntime. With an idempotent request, if the original request action completes\nsuccessfully, any subsequent retries complete successfully without performing\nany further actions. However, the result might contain updated information, such\nas the current creation status.\n\nThe following lists of APIs are grouped according to methods that ensure\nidempotency.","ref":"AWS.Proton.html#module-ensuring-idempotency","title":"Ensuring Idempotency - AWS.Proton","type":"module"},{"doc":"The API actions in this list support idempotency with the use of a *client\ntoken*. The corresponding Amazon Web Services CLI commands also support\nidempotency using a client token. A client token is a unique, case-sensitive\nstring of up to 64 ASCII characters. To make an idempotent API request using one\nof these actions, specify a client token in the request. We recommend that you\n*don't* reuse the same client token for other API requests. If you don’t provide\na client token for these APIs, a default client token is automatically provided\nby SDKs.\n\nGiven a request action that has succeeded:\n\nIf you retry the request using the same client token and the same parameters,\nthe retry succeeds without performing any further actions other than returning\nthe original resource detail data in the response.\n\nIf you retry the request using the same client token, but one or more of the\nparameters are different, the retry throws a `ValidationException` with an\n`IdempotentParameterMismatch` error.\n\nClient tokens expire eight hours after a request is made. If you retry the\nrequest with the expired token, a new resource is created.\n\nIf the original resource is deleted and you retry the request, a new resource is\ncreated.\n\nIdempotent create APIs with a client token:\n\n  * CreateEnvironmentTemplateVersion\n\n  * CreateServiceTemplateVersion\n\n  * CreateEnvironmentAccountConnection","ref":"AWS.Proton.html#module-idempotent-create-apis-with-a-client-token","title":"Idempotent create APIs with a client token - AWS.Proton","type":"module"},{"doc":"Given a request action that has succeeded:\n\nIf you retry the request with an API from this group, and the original resource\n*hasn't* been modified, the retry succeeds without performing any further\nactions other than returning the original resource detail data in the response.\n\nIf the original resource has been modified, the retry throws a\n`ConflictException`.\n\nIf you retry with different input parameters, the retry throws a\n`ValidationException` with an `IdempotentParameterMismatch` error.\n\nIdempotent create APIs:\n\n  * CreateEnvironmentTemplate\n\n  * CreateServiceTemplate\n\n  * CreateEnvironment\n\n  * CreateService","ref":"AWS.Proton.html#module-idempotent-create-apis","title":"Idempotent create APIs - AWS.Proton","type":"module"},{"doc":"Given a request action that has succeeded:\n\nWhen you retry the request with an API from this group and the resource was\ndeleted, its metadata is returned in the response.\n\nIf you retry and the resource doesn't exist, the response is empty.\n\nIn both cases, the retry succeeds.\n\nIdempotent delete APIs:\n\n  * DeleteEnvironmentTemplate\n\n  * DeleteEnvironmentTemplateVersion\n\n  * DeleteServiceTemplate\n\n  * DeleteServiceTemplateVersion\n\n  * DeleteEnvironmentAccountConnection","ref":"AWS.Proton.html#module-idempotent-delete-apis","title":"Idempotent delete APIs - AWS.Proton","type":"module"},{"doc":"Given a request action that has succeeded:\n\nIf you retry the request with an API from this group, if the original request\ndelete operation status is `DELETE_IN_PROGRESS`, the retry returns the resource\ndetail data in the response without performing any further actions.\n\nIf the original request delete operation is complete, a retry returns an empty\nresponse.\n\nAsynchronous idempotent delete APIs:\n\n  * DeleteEnvironment\n\n  * DeleteService","ref":"AWS.Proton.html#module-asynchronous-idempotent-delete-apis","title":"Asynchronous idempotent delete APIs - AWS.Proton","type":"module"},{"doc":"In a management account, an environment account connection request is accepted.\n\nWhen the environment account connection request is accepted, Proton can use the\nassociated IAM role to provision environment infrastructure resources in the\nassociated environment account.\n\nFor more information, see [Environment account connections](https://docs.aws.amazon.com/proton/latest/userguide/ag-env-account-connections.html)\nin the *Proton User guide*.","ref":"AWS.Proton.html#accept_environment_account_connection/3","title":"AWS.Proton.accept_environment_account_connection/3","type":"function"},{"doc":"Attempts to cancel a component deployment (for a component that is in the\n`IN_PROGRESS` deployment status).\n\nFor more information about components, see [Proton components](https://docs.aws.amazon.com/proton/latest/userguide/ag-components.html)\nin the *Proton User Guide*.","ref":"AWS.Proton.html#cancel_component_deployment/3","title":"AWS.Proton.cancel_component_deployment/3","type":"function"},{"doc":"Attempts to cancel an environment deployment on an `UpdateEnvironment` action,\nif the deployment is `IN_PROGRESS`.\n\nFor more information, see [Update an environment](https://docs.aws.amazon.com/proton/latest/userguide/ag-env-update.html)\nin the *Proton User guide*.\n\nThe following list includes potential cancellation scenarios.\n\n  * If the cancellation attempt succeeds, the resulting deployment\nstate is `CANCELLED`.\n\n  * If the cancellation attempt fails, the resulting deployment state\nis `FAILED`.\n\n  * If the current `UpdateEnvironment` action succeeds before the\ncancellation attempt starts, the resulting deployment state is `SUCCEEDED` and\nthe cancellation attempt has no effect.","ref":"AWS.Proton.html#cancel_environment_deployment/3","title":"AWS.Proton.cancel_environment_deployment/3","type":"function"},{"doc":"Attempts to cancel a service instance deployment on an `UpdateServiceInstance`\naction, if the deployment is `IN_PROGRESS`.\n\nFor more information, see [Update a service instance](https://docs.aws.amazon.com/proton/latest/userguide/ag-svc-instance-update.html)\nin the *Proton User guide*.\n\nThe following list includes potential cancellation scenarios.\n\n  * If the cancellation attempt succeeds, the resulting deployment\nstate is `CANCELLED`.\n\n  * If the cancellation attempt fails, the resulting deployment state\nis `FAILED`.\n\n  * If the current `UpdateServiceInstance` action succeeds before the\ncancellation attempt starts, the resulting deployment state is `SUCCEEDED` and\nthe cancellation attempt has no effect.","ref":"AWS.Proton.html#cancel_service_instance_deployment/3","title":"AWS.Proton.cancel_service_instance_deployment/3","type":"function"},{"doc":"Attempts to cancel a service pipeline deployment on an `UpdateServicePipeline`\naction, if the deployment is `IN_PROGRESS`.\n\nFor more information, see [Update a service pipeline](https://docs.aws.amazon.com/proton/latest/userguide/ag-svc-pipeline-update.html)\nin the *Proton User guide*.\n\nThe following list includes potential cancellation scenarios.\n\n  * If the cancellation attempt succeeds, the resulting deployment\nstate is `CANCELLED`.\n\n  * If the cancellation attempt fails, the resulting deployment state\nis `FAILED`.\n\n  * If the current `UpdateServicePipeline` action succeeds before the\ncancellation attempt starts, the resulting deployment state is `SUCCEEDED` and\nthe cancellation attempt has no effect.","ref":"AWS.Proton.html#cancel_service_pipeline_deployment/3","title":"AWS.Proton.cancel_service_pipeline_deployment/3","type":"function"},{"doc":"Create an Proton component.\n\nA component is an infrastructure extension for a service instance.\n\nFor more information about components, see [Proton components](https://docs.aws.amazon.com/proton/latest/userguide/ag-components.html)\nin the *Proton User Guide*.","ref":"AWS.Proton.html#create_component/3","title":"AWS.Proton.create_component/3","type":"function"},{"doc":"Deploy a new environment.\n\nAn Proton environment is created from an environment template that defines\ninfrastructure and resources that can be shared across services.","ref":"AWS.Proton.html#create_environment/3","title":"AWS.Proton.create_environment/3","type":"function"},{"doc":"* Amazon Web Services-managed provisioning: Proton makes direct\ncalls to provision your resources.\n\n  * Self-managed provisioning: Proton makes pull requests on your\nrepository to provide compiled infrastructure as code (IaC) files that your IaC\nengine uses to provision resources.\n\nFor more information, see\n[Environments](https://docs.aws.amazon.com/proton/latest/userguide/ag-environments.html) and [Provisioning\nmethods](https://docs.aws.amazon.com/proton/latest/userguide/ag-works-prov-methods.html)\nin the *Proton User Guide*.","ref":"AWS.Proton.html#create_environment/3-you-can-provision-environments-using-the-following-methods","title":"You can provision environments using the following methods: - AWS.Proton.create_environment/3","type":"function"},{"doc":"Create an environment account connection in an environment account so that\nenvironment infrastructure resources can be provisioned in the environment\naccount from a management account.\n\nAn environment account connection is a secure bi-directional connection between\na *management account* and an *environment account* that maintains authorization\nand permissions. For more information, see [Environment account connections](https://docs.aws.amazon.com/proton/latest/userguide/ag-env-account-connections.html)\nin the *Proton User guide*.","ref":"AWS.Proton.html#create_environment_account_connection/3","title":"AWS.Proton.create_environment_account_connection/3","type":"function"},{"doc":"Create an environment template for Proton.\n\nFor more information, see [Environment Templates](https://docs.aws.amazon.com/proton/latest/userguide/ag-templates.html)\nin the *Proton User Guide*.\n\nYou can create an environment template in one of the two following ways:\n\n  * Register and publish a *standard* environment template that\ninstructs Proton to deploy and manage environment infrastructure.\n\n  * Register and publish a *customer managed* environment template\nthat connects Proton to your existing provisioned infrastructure that you\nmanage. Proton *doesn't* manage your existing provisioned infrastructure. To\ncreate an environment template for customer provisioned and managed\ninfrastructure, include the `provisioning` parameter and set the value to\n`CUSTOMER_MANAGED`. For more information, see [Register and publish an environment\ntemplate](https://docs.aws.amazon.com/proton/latest/userguide/template-create.html)\nin the *Proton User Guide*.","ref":"AWS.Proton.html#create_environment_template/3","title":"AWS.Proton.create_environment_template/3","type":"function"},{"doc":"Create a new major or minor version of an environment template.\n\nA major version of an environment template is a version that *isn't* backwards\ncompatible. A minor version of an environment template is a version that's\nbackwards compatible within its major version.","ref":"AWS.Proton.html#create_environment_template_version/3","title":"AWS.Proton.create_environment_template_version/3","type":"function"},{"doc":"Create and register a link to a repository.\n\nProton uses the link to repeatedly access the repository, to either push to it\n(self-managed provisioning) or pull from it (template sync). You can share a\nlinked repository across multiple resources (like environments using\nself-managed provisioning, or synced templates). When you create a repository\nlink, Proton creates a [service-linked role](https://docs.aws.amazon.com/proton/latest/userguide/using-service-linked-roles.html)\nfor you.\n\nFor more information, see [Self-managed provisioning](https://docs.aws.amazon.com/proton/latest/userguide/ag-works-prov-methods.html#ag-works-prov-methods-self),\n[Template bundles](https://docs.aws.amazon.com/proton/latest/userguide/ag-template-authoring.html#ag-template-bundles),\nand [Template sync configurations](https://docs.aws.amazon.com/proton/latest/userguide/ag-template-sync-configs.html)\nin the *Proton User Guide*.","ref":"AWS.Proton.html#create_repository/3","title":"AWS.Proton.create_repository/3","type":"function"},{"doc":"Create an Proton service.\n\nAn Proton service is an instantiation of a service template and often includes\nseveral service instances and pipeline. For more information, see\n[Services](https://docs.aws.amazon.com/proton/latest/userguide/ag-services.html)\nin the *Proton User Guide*.","ref":"AWS.Proton.html#create_service/3","title":"AWS.Proton.create_service/3","type":"function"},{"doc":"Create a service instance.","ref":"AWS.Proton.html#create_service_instance/3","title":"AWS.Proton.create_service_instance/3","type":"function"},{"doc":"Create the Proton Ops configuration file.","ref":"AWS.Proton.html#create_service_sync_config/3","title":"AWS.Proton.create_service_sync_config/3","type":"function"},{"doc":"Create a service template.\n\nThe administrator creates a service template to define standardized\ninfrastructure and an optional CI/CD service pipeline. Developers, in turn,\nselect the service template from Proton. If the selected service template\nincludes a service pipeline definition, they provide a link to their source code\nrepository. Proton then deploys and manages the infrastructure defined by the\nselected service template. For more information, see [Proton templates](https://docs.aws.amazon.com/proton/latest/userguide/ag-templates.html)\nin the *Proton User Guide*.","ref":"AWS.Proton.html#create_service_template/3","title":"AWS.Proton.create_service_template/3","type":"function"},{"doc":"Create a new major or minor version of a service template.\n\nA major version of a service template is a version that *isn't* backward\ncompatible. A minor version of a service template is a version that's backward\ncompatible within its major version.","ref":"AWS.Proton.html#create_service_template_version/3","title":"AWS.Proton.create_service_template_version/3","type":"function"},{"doc":"Set up a template to create new template versions automatically by tracking a\nlinked repository.\n\nA linked repository is a repository that has been registered with Proton. For\nmore information, see `CreateRepository`.\n\nWhen a commit is pushed to your linked repository, Proton checks for changes to\nyour repository template bundles. If it detects a template bundle change, a new\nmajor or minor version of its template is created, if the version doesn’t\nalready exist. For more information, see [Template sync configurations](https://docs.aws.amazon.com/proton/latest/userguide/ag-template-sync-configs.html)\nin the *Proton User Guide*.","ref":"AWS.Proton.html#create_template_sync_config/3","title":"AWS.Proton.create_template_sync_config/3","type":"function"},{"doc":"Delete an Proton component resource.\n\nFor more information about components, see [Proton components](https://docs.aws.amazon.com/proton/latest/userguide/ag-components.html)\nin the *Proton User Guide*.","ref":"AWS.Proton.html#delete_component/3","title":"AWS.Proton.delete_component/3","type":"function"},{"doc":"Delete the deployment.","ref":"AWS.Proton.html#delete_deployment/3","title":"AWS.Proton.delete_deployment/3","type":"function"},{"doc":"Delete an environment.","ref":"AWS.Proton.html#delete_environment/3","title":"AWS.Proton.delete_environment/3","type":"function"},{"doc":"In an environment account, delete an environment account connection.\n\nAfter you delete an environment account connection that’s in use by an Proton\nenvironment, Proton *can’t* manage the environment infrastructure resources\nuntil a new environment account connection is accepted for the environment\naccount and associated environment. You're responsible for cleaning up\nprovisioned resources that remain without an environment connection.\n\nFor more information, see [Environment account connections](https://docs.aws.amazon.com/proton/latest/userguide/ag-env-account-connections.html)\nin the *Proton User guide*.","ref":"AWS.Proton.html#delete_environment_account_connection/3","title":"AWS.Proton.delete_environment_account_connection/3","type":"function"},{"doc":"If no other major or minor versions of an environment template exist, delete the\nenvironment template.","ref":"AWS.Proton.html#delete_environment_template/3","title":"AWS.Proton.delete_environment_template/3","type":"function"},{"doc":"If no other minor versions of an environment template exist, delete a major\nversion of the environment template if it's not the `Recommended` version.\n\nDelete the `Recommended` version of the environment template if no other major\nversions or minor versions of the environment template exist. A major version of\nan environment template is a version that's not backward compatible.\n\nDelete a minor version of an environment template if it *isn't* the\n`Recommended` version. Delete a `Recommended` minor version of the environment\ntemplate if no other minor versions of the environment template exist. A minor\nversion of an environment template is a version that's backward compatible.","ref":"AWS.Proton.html#delete_environment_template_version/3","title":"AWS.Proton.delete_environment_template_version/3","type":"function"},{"doc":"De-register and unlink your repository.","ref":"AWS.Proton.html#delete_repository/3","title":"AWS.Proton.delete_repository/3","type":"function"},{"doc":"Delete a service, with its instances and pipeline.\n\nYou can't delete a service if it has any service instances that have components\nattached to them.\n\nFor more information about components, see [Proton components](https://docs.aws.amazon.com/proton/latest/userguide/ag-components.html)\nin the *Proton User Guide*.","ref":"AWS.Proton.html#delete_service/3","title":"AWS.Proton.delete_service/3","type":"function"},{"doc":"Delete the Proton Ops file.","ref":"AWS.Proton.html#delete_service_sync_config/3","title":"AWS.Proton.delete_service_sync_config/3","type":"function"},{"doc":"If no other major or minor versions of the service template exist, delete the\nservice template.","ref":"AWS.Proton.html#delete_service_template/3","title":"AWS.Proton.delete_service_template/3","type":"function"},{"doc":"If no other minor versions of a service template exist, delete a major version\nof the service template if it's not the `Recommended` version.\n\nDelete the `Recommended` version of the service template if no other major\nversions or minor versions of the service template exist. A major version of a\nservice template is a version that *isn't* backwards compatible.\n\nDelete a minor version of a service template if it's not the `Recommended`\nversion. Delete a `Recommended` minor version of the service template if no\nother minor versions of the service template exist. A minor version of a service\ntemplate is a version that's backwards compatible.","ref":"AWS.Proton.html#delete_service_template_version/3","title":"AWS.Proton.delete_service_template_version/3","type":"function"},{"doc":"Delete a template sync configuration.","ref":"AWS.Proton.html#delete_template_sync_config/3","title":"AWS.Proton.delete_template_sync_config/3","type":"function"},{"doc":"Get detail data for Proton account-wide settings.","ref":"AWS.Proton.html#get_account_settings/3","title":"AWS.Proton.get_account_settings/3","type":"function"},{"doc":"Get detailed data for a component.\n\nFor more information about components, see [Proton components](https://docs.aws.amazon.com/proton/latest/userguide/ag-components.html)\nin the *Proton User Guide*.","ref":"AWS.Proton.html#get_component/3","title":"AWS.Proton.get_component/3","type":"function"},{"doc":"Get detailed data for a deployment.","ref":"AWS.Proton.html#get_deployment/3","title":"AWS.Proton.get_deployment/3","type":"function"},{"doc":"Get detailed data for an environment.","ref":"AWS.Proton.html#get_environment/3","title":"AWS.Proton.get_environment/3","type":"function"},{"doc":"In an environment account, get the detailed data for an environment account\nconnection.\n\nFor more information, see [Environment account connections](https://docs.aws.amazon.com/proton/latest/userguide/ag-env-account-connections.html)\nin the *Proton User guide*.","ref":"AWS.Proton.html#get_environment_account_connection/3","title":"AWS.Proton.get_environment_account_connection/3","type":"function"},{"doc":"Get detailed data for an environment template.","ref":"AWS.Proton.html#get_environment_template/3","title":"AWS.Proton.get_environment_template/3","type":"function"},{"doc":"Get detailed data for a major or minor version of an environment template.","ref":"AWS.Proton.html#get_environment_template_version/3","title":"AWS.Proton.get_environment_template_version/3","type":"function"},{"doc":"Get detail data for a linked repository.","ref":"AWS.Proton.html#get_repository/3","title":"AWS.Proton.get_repository/3","type":"function"},{"doc":"Get the sync status of a repository used for Proton template sync.\n\nFor more information about template sync, see .\n\nA repository sync status isn't tied to the Proton Repository resource (or any\nother Proton resource). Therefore, tags on an Proton Repository resource have no\neffect on this action. Specifically, you can't use these tags to control access\nto this action using Attribute-based access control (ABAC).\n\nFor more information about ABAC, see\n[ABAC](https://docs.aws.amazon.com/proton/latest/userguide/security_iam_service-with-iam.html#security_iam_service-with-iam-tags)\nin the *Proton User Guide*.","ref":"AWS.Proton.html#get_repository_sync_status/3","title":"AWS.Proton.get_repository_sync_status/3","type":"function"},{"doc":"Get counts of Proton resources.\n\nFor infrastructure-provisioning resources (environments, services, service\ninstances, pipelines), the action returns staleness counts. A resource is stale\nwhen it's behind the recommended version of the Proton template that it uses and\nit needs an update to become current.\n\nThe action returns staleness counts (counts of resources that are up-to-date,\nbehind a template major version, or behind a template minor version), the total\nnumber of resources, and the number of resources that are in a failed state,\ngrouped by resource type. Components, environments, and service templates return\nless information - see the `components`, `environments`, and `serviceTemplates`\nfield descriptions.\n\nFor context, the action also returns the total number of each type of Proton\ntemplate in the Amazon Web Services account.\n\nFor more information, see [Proton dashboard](https://docs.aws.amazon.com/proton/latest/userguide/monitoring-dashboard.html)\nin the *Proton User Guide*.","ref":"AWS.Proton.html#get_resources_summary/3","title":"AWS.Proton.get_resources_summary/3","type":"function"},{"doc":"Get detailed data for a service.","ref":"AWS.Proton.html#get_service/3","title":"AWS.Proton.get_service/3","type":"function"},{"doc":"Get detailed data for a service instance.\n\nA service instance is an instantiation of service template and it runs in a\nspecific environment.","ref":"AWS.Proton.html#get_service_instance/3","title":"AWS.Proton.get_service_instance/3","type":"function"},{"doc":"Get the status of the synced service instance.","ref":"AWS.Proton.html#get_service_instance_sync_status/3","title":"AWS.Proton.get_service_instance_sync_status/3","type":"function"},{"doc":"Get detailed data for the service sync blocker summary.","ref":"AWS.Proton.html#get_service_sync_blocker_summary/3","title":"AWS.Proton.get_service_sync_blocker_summary/3","type":"function"},{"doc":"Get detailed information for the service sync configuration.","ref":"AWS.Proton.html#get_service_sync_config/3","title":"AWS.Proton.get_service_sync_config/3","type":"function"},{"doc":"Get detailed data for a service template.","ref":"AWS.Proton.html#get_service_template/3","title":"AWS.Proton.get_service_template/3","type":"function"},{"doc":"Get detailed data for a major or minor version of a service template.","ref":"AWS.Proton.html#get_service_template_version/3","title":"AWS.Proton.get_service_template_version/3","type":"function"},{"doc":"Get detail data for a template sync configuration.","ref":"AWS.Proton.html#get_template_sync_config/3","title":"AWS.Proton.get_template_sync_config/3","type":"function"},{"doc":"Get the status of a template sync.","ref":"AWS.Proton.html#get_template_sync_status/3","title":"AWS.Proton.get_template_sync_status/3","type":"function"},{"doc":"Get a list of component Infrastructure as Code (IaC) outputs.\n\nFor more information about components, see [Proton components](https://docs.aws.amazon.com/proton/latest/userguide/ag-components.html)\nin the *Proton User Guide*.","ref":"AWS.Proton.html#list_component_outputs/3","title":"AWS.Proton.list_component_outputs/3","type":"function"},{"doc":"List provisioned resources for a component with details.\n\nFor more information about components, see [Proton components](https://docs.aws.amazon.com/proton/latest/userguide/ag-components.html)\nin the *Proton User Guide*.","ref":"AWS.Proton.html#list_component_provisioned_resources/3","title":"AWS.Proton.list_component_provisioned_resources/3","type":"function"},{"doc":"List components with summary data.\n\nYou can filter the result list by environment, service, or a single service\ninstance.\n\nFor more information about components, see [Proton components](https://docs.aws.amazon.com/proton/latest/userguide/ag-components.html)\nin the *Proton User Guide*.","ref":"AWS.Proton.html#list_components/3","title":"AWS.Proton.list_components/3","type":"function"},{"doc":"List deployments.\n\nYou can filter the result list by environment, service, or a single service\ninstance.","ref":"AWS.Proton.html#list_deployments/3","title":"AWS.Proton.list_deployments/3","type":"function"},{"doc":"View a list of environment account connections.\n\nFor more information, see [Environment account connections](https://docs.aws.amazon.com/proton/latest/userguide/ag-env-account-connections.html)\nin the *Proton User guide*.","ref":"AWS.Proton.html#list_environment_account_connections/3","title":"AWS.Proton.list_environment_account_connections/3","type":"function"},{"doc":"List the infrastructure as code outputs for your environment.","ref":"AWS.Proton.html#list_environment_outputs/3","title":"AWS.Proton.list_environment_outputs/3","type":"function"},{"doc":"List the provisioned resources for your environment.","ref":"AWS.Proton.html#list_environment_provisioned_resources/3","title":"AWS.Proton.list_environment_provisioned_resources/3","type":"function"},{"doc":"List major or minor versions of an environment template with detail data.","ref":"AWS.Proton.html#list_environment_template_versions/3","title":"AWS.Proton.list_environment_template_versions/3","type":"function"},{"doc":"List environment templates.","ref":"AWS.Proton.html#list_environment_templates/3","title":"AWS.Proton.list_environment_templates/3","type":"function"},{"doc":"List environments with detail data summaries.","ref":"AWS.Proton.html#list_environments/3","title":"AWS.Proton.list_environments/3","type":"function"},{"doc":"List linked repositories with detail data.","ref":"AWS.Proton.html#list_repositories/3","title":"AWS.Proton.list_repositories/3","type":"function"},{"doc":"List repository sync definitions with detail data.","ref":"AWS.Proton.html#list_repository_sync_definitions/3","title":"AWS.Proton.list_repository_sync_definitions/3","type":"function"},{"doc":"Get a list service of instance Infrastructure as Code (IaC) outputs.","ref":"AWS.Proton.html#list_service_instance_outputs/3","title":"AWS.Proton.list_service_instance_outputs/3","type":"function"},{"doc":"List provisioned resources for a service instance with details.","ref":"AWS.Proton.html#list_service_instance_provisioned_resources/3","title":"AWS.Proton.list_service_instance_provisioned_resources/3","type":"function"},{"doc":"List service instances with summary data.\n\nThis action lists service instances of all services in the Amazon Web Services\naccount.","ref":"AWS.Proton.html#list_service_instances/3","title":"AWS.Proton.list_service_instances/3","type":"function"},{"doc":"Get a list of service pipeline Infrastructure as Code (IaC) outputs.","ref":"AWS.Proton.html#list_service_pipeline_outputs/3","title":"AWS.Proton.list_service_pipeline_outputs/3","type":"function"},{"doc":"List provisioned resources for a service and pipeline with details.","ref":"AWS.Proton.html#list_service_pipeline_provisioned_resources/3","title":"AWS.Proton.list_service_pipeline_provisioned_resources/3","type":"function"},{"doc":"List major or minor versions of a service template with detail data.","ref":"AWS.Proton.html#list_service_template_versions/3","title":"AWS.Proton.list_service_template_versions/3","type":"function"},{"doc":"List service templates with detail data.","ref":"AWS.Proton.html#list_service_templates/3","title":"AWS.Proton.list_service_templates/3","type":"function"},{"doc":"List services with summaries of detail data.","ref":"AWS.Proton.html#list_services/3","title":"AWS.Proton.list_services/3","type":"function"},{"doc":"List tags for a resource.\n\nFor more information, see [Proton resources and tagging](https://docs.aws.amazon.com/proton/latest/userguide/resources.html) in\nthe *Proton User Guide*.","ref":"AWS.Proton.html#list_tags_for_resource/3","title":"AWS.Proton.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.Proton.html#metadata/0","title":"AWS.Proton.metadata/0","type":"function"},{"doc":"Notify Proton of status changes to a provisioned resource when you use\nself-managed provisioning.\n\nFor more information, see [Self-managed provisioning](https://docs.aws.amazon.com/proton/latest/userguide/ag-works-prov-methods.html#ag-works-prov-methods-self)\nin the *Proton User Guide*.","ref":"AWS.Proton.html#notify_resource_deployment_status_change/3","title":"AWS.Proton.notify_resource_deployment_status_change/3","type":"function"},{"doc":"In a management account, reject an environment account connection from another\nenvironment account.\n\nAfter you reject an environment account connection request, you *can't* accept\nor use the rejected environment account connection.\n\nYou *can’t* reject an environment account connection that's connected to an\nenvironment.\n\nFor more information, see [Environment account connections](https://docs.aws.amazon.com/proton/latest/userguide/ag-env-account-connections.html)\nin the *Proton User guide*.","ref":"AWS.Proton.html#reject_environment_account_connection/3","title":"AWS.Proton.reject_environment_account_connection/3","type":"function"},{"doc":"Tag a resource.\n\nA tag is a key-value pair of metadata that you associate with an Proton\nresource.\n\nFor more information, see [Proton resources and tagging](https://docs.aws.amazon.com/proton/latest/userguide/resources.html) in\nthe *Proton User Guide*.","ref":"AWS.Proton.html#tag_resource/3","title":"AWS.Proton.tag_resource/3","type":"function"},{"doc":"Remove a customer tag from a resource.\n\nA tag is a key-value pair of metadata associated with an Proton resource.\n\nFor more information, see [Proton resources and tagging](https://docs.aws.amazon.com/proton/latest/userguide/resources.html) in\nthe *Proton User Guide*.","ref":"AWS.Proton.html#untag_resource/3","title":"AWS.Proton.untag_resource/3","type":"function"},{"doc":"Update Proton settings that are used for multiple services in the Amazon Web\nServices account.","ref":"AWS.Proton.html#update_account_settings/3","title":"AWS.Proton.update_account_settings/3","type":"function"},{"doc":"Update a component.\n\nThere are a few modes for updating a component. The `deploymentType` field\ndefines the mode.\n\nYou can't update a component while its deployment status, or the deployment\nstatus of a service instance attached to it, is `IN_PROGRESS`.\n\nFor more information about components, see [Proton components](https://docs.aws.amazon.com/proton/latest/userguide/ag-components.html)\nin the *Proton User Guide*.","ref":"AWS.Proton.html#update_component/3","title":"AWS.Proton.update_component/3","type":"function"},{"doc":"Update an environment.\n\nIf the environment is associated with an environment account connection, *don't*\nupdate or include the `protonServiceRoleArn` and `provisioningRepository`\nparameter to update or connect to an environment account connection.\n\nYou can only update to a new environment account connection if that connection\nwas created in the same environment account that the current environment account\nconnection was created in. The account connection must also be associated with\nthe current environment.\n\nIf the environment *isn't* associated with an environment account connection,\n*don't* update or include the `environmentAccountConnectionId` parameter. You\n*can't* update or connect the environment to an environment account connection\nif it *isn't* already associated with an environment connection.\n\nYou can update either the `environmentAccountConnectionId` or\n`protonServiceRoleArn` parameter and value. You can’t update both.\n\nIf the environment was configured for Amazon Web Services-managed provisioning,\nomit the `provisioningRepository` parameter.\n\nIf the environment was configured for self-managed provisioning, specify the\n`provisioningRepository` parameter and omit the `protonServiceRoleArn` and\n`environmentAccountConnectionId` parameters.\n\nFor more information, see\n[Environments](https://docs.aws.amazon.com/proton/latest/userguide/ag-environments.html) and [Provisioning\nmethods](https://docs.aws.amazon.com/proton/latest/userguide/ag-works-prov-methods.html)\nin the *Proton User Guide*.\n\nThere are four modes for updating an environment. The `deploymentType` field\ndefines the mode.","ref":"AWS.Proton.html#update_environment/3","title":"AWS.Proton.update_environment/3","type":"function"},{"doc":"###\n\n`NONE`\n\nIn this mode, a deployment *doesn't* occur. Only the requested metadata\nparameters are updated.\n\n###\n\n`CURRENT_VERSION`\n\nIn this mode, the environment is deployed and updated with the new spec that you\nprovide. Only requested parameters are updated. *Don’t* include minor or major\nversion parameters when you use this `deployment-type`.\n\n###\n\n`MINOR_VERSION`\n\nIn this mode, the environment is deployed and updated with the published,\nrecommended (latest) minor version of the current major version in use, by\ndefault. You can also specify a different minor version of the current major\nversion in use.\n\n###\n\n`MAJOR_VERSION`\n\nIn this mode, the environment is deployed and updated with the published,\nrecommended (latest) major and minor version of the current template, by\ndefault. You can also specify a different major version that's higher than the\nmajor version in use and a minor version.","ref":"AWS.Proton.html#update_environment/3-definitions","title":"Definitions - AWS.Proton.update_environment/3","type":"function"},{"doc":"In an environment account, update an environment account connection to use a new\nIAM role.\n\nFor more information, see [Environment account connections](https://docs.aws.amazon.com/proton/latest/userguide/ag-env-account-connections.html)\nin the *Proton User guide*.","ref":"AWS.Proton.html#update_environment_account_connection/3","title":"AWS.Proton.update_environment_account_connection/3","type":"function"},{"doc":"Update an environment template.","ref":"AWS.Proton.html#update_environment_template/3","title":"AWS.Proton.update_environment_template/3","type":"function"},{"doc":"Update a major or minor version of an environment template.","ref":"AWS.Proton.html#update_environment_template_version/3","title":"AWS.Proton.update_environment_template_version/3","type":"function"},{"doc":"Edit a service description or use a spec to add and delete service instances.\n\nExisting service instances and the service pipeline *can't* be edited using this\nAPI. They can only be deleted.\n\nUse the `description` parameter to modify the description.\n\nEdit the `spec` parameter to add or delete instances.\n\nYou can't delete a service instance (remove it from the spec) if it has an\nattached component.\n\nFor more information about components, see [Proton components](https://docs.aws.amazon.com/proton/latest/userguide/ag-components.html)\nin the *Proton User Guide*.","ref":"AWS.Proton.html#update_service/3","title":"AWS.Proton.update_service/3","type":"function"},{"doc":"Update a service instance.\n\nThere are a few modes for updating a service instance. The `deploymentType`\nfield defines the mode.\n\nYou can't update a service instance while its deployment status, or the\ndeployment status of a component attached to it, is `IN_PROGRESS`.\n\nFor more information about components, see [Proton components](https://docs.aws.amazon.com/proton/latest/userguide/ag-components.html)\nin the *Proton User Guide*.","ref":"AWS.Proton.html#update_service_instance/3","title":"AWS.Proton.update_service_instance/3","type":"function"},{"doc":"Update the service pipeline.\n\nThere are four modes for updating a service pipeline. The `deploymentType` field\ndefines the mode.","ref":"AWS.Proton.html#update_service_pipeline/3","title":"AWS.Proton.update_service_pipeline/3","type":"function"},{"doc":"###\n\n`NONE`\n\nIn this mode, a deployment *doesn't* occur. Only the requested metadata\nparameters are updated.\n\n###\n\n`CURRENT_VERSION`\n\nIn this mode, the service pipeline is deployed and updated with the new spec\nthat you provide. Only requested parameters are updated. *Don’t* include major\nor minor version parameters when you use this `deployment-type`.\n\n###\n\n`MINOR_VERSION`\n\nIn this mode, the service pipeline is deployed and updated with the published,\nrecommended (latest) minor version of the current major version in use, by\ndefault. You can specify a different minor version of the current major version\nin use.\n\n###\n\n`MAJOR_VERSION`\n\nIn this mode, the service pipeline is deployed and updated with the published,\nrecommended (latest) major and minor version of the current template by default.\nYou can specify a different major version that's higher than the major version\nin use and a minor version.","ref":"AWS.Proton.html#update_service_pipeline/3-definitions","title":"Definitions - AWS.Proton.update_service_pipeline/3","type":"function"},{"doc":"Update the service sync blocker by resolving it.","ref":"AWS.Proton.html#update_service_sync_blocker/3","title":"AWS.Proton.update_service_sync_blocker/3","type":"function"},{"doc":"Update the Proton Ops config file.","ref":"AWS.Proton.html#update_service_sync_config/3","title":"AWS.Proton.update_service_sync_config/3","type":"function"},{"doc":"Update a service template.","ref":"AWS.Proton.html#update_service_template/3","title":"AWS.Proton.update_service_template/3","type":"function"},{"doc":"Update a major or minor version of a service template.","ref":"AWS.Proton.html#update_service_template_version/3","title":"AWS.Proton.update_service_template_version/3","type":"function"},{"doc":"Update template sync configuration parameters, except for the `templateName` and\n`templateType`.\n\nRepository details (branch, name, and provider) should be of a linked\nrepository. A linked repository is a repository that has been registered with\nProton. For more information, see `CreateRepository`.","ref":"AWS.Proton.html#update_template_sync_config/3","title":"AWS.Proton.update_template_sync_config/3","type":"function"},{"doc":"Amazon Q is in preview release and is subject to change.\n\nThis is the *Amazon Q (for business use)* API Reference. Amazon Q is a fully\nmanaged, generative-AI powered enterprise chat assistant that you can deploy\nwithin your organization. Amazon Q enhances employee productivity by supporting\nkey tasks such as question-answering, knowledge discovery, writing email\nmessages, summarizing text, drafting document outlines, and brainstorming ideas.\nUsers ask questions of Amazon Q and get answers that are presented in a\nconversational manner. For an introduction to the service, see the [ *Amazon Q (for business use) Developer Guide*\n](https://docs.aws.amazon.com/amazonq/latest/business-use-dg/what-is.html).\n\nFor an overview of the Amazon Q APIs, see [Overview of Amazon Q API operations](https://docs.aws.amazon.com/amazonq/latest/business-use-dg/api-ref.html#api-overview).\n\nFor information about the IAM access control permissions you need to use this\nAPI, see [IAM roles for Amazon Q](https://docs.aws.amazon.com/amazonq/latest/business-use-dg/iam-roles.html) in\nthe *Amazon Q (for business use) Developer Guide*.\n\nYou can use the following AWS SDKs to access Amazon Q APIs:\n\n  * [AWS SDK for C++](https://docs.aws.amazon.com/sdk-for-cpp)     * [AWS SDK for Go](https://docs.aws.amazon.com/sdk-for-go)\n\n  * [AWS SDK for Java](https://docs.aws.amazon.com/sdk-for-java)     * [AWS SDK for\nJavaScript](https://docs.aws.amazon.com/sdk-for-javascript)\n\n  * [AWS SDK for .NET](https://docs.aws.amazon.com/sdk-for-net)     * [AWS SDK for Python\n(Boto3)](https://docs.aws.amazon.com/pythonsdk)\n\n  * [AWS SDK for Ruby](https://docs.aws.amazon.com/sdk-for-ruby) \n\nThe following resources provide additional information about using the Amazon Q\nAPI:\n\n  * * [Setting up for Amazon\nQ](https://docs.aws.amazon.com/amazonq/latest/business-use-dg/setting-up.html) *\n\n  * * [Amazon Q CLI Reference](https://awscli.amazonaws.com/v2/documentation/api/latest/reference/qbusiness/index.html)\n*\n\n  * * [Amazon Web Services General Reference](https://docs.aws.amazon.com/general/latest/gr/amazonq.html) *","ref":"AWS.QBusiness.html","title":"AWS.QBusiness","type":"module"},{"doc":"Asynchronously deletes one or more documents added using the `BatchPutDocument`\nAPI from an Amazon Q index.\n\nYou can see the progress of the deletion, and any error messages related to the\nprocess, by using CloudWatch.","ref":"AWS.QBusiness.html#batch_delete_document/5","title":"AWS.QBusiness.batch_delete_document/5","type":"function"},{"doc":"Adds one or more documents to an Amazon Q index.\n\nYou use this API to:\n\n  * ingest your structured and unstructured documents and documents\nstored in an Amazon S3 bucket into an Amazon Q index.\n\n  * add custom attributes to documents in an Amazon Q index.\n\n  * attach an access control list to the documents added to an Amazon\nQ index.\n\nYou can see the progress of the deletion, and any error messages related to the\nprocess, by using CloudWatch.","ref":"AWS.QBusiness.html#batch_put_document/5","title":"AWS.QBusiness.batch_put_document/5","type":"function"},{"doc":"Starts or continues a non-streaming Amazon Q conversation.","ref":"AWS.QBusiness.html#chat_sync/4","title":"AWS.QBusiness.chat_sync/4","type":"function"},{"doc":"Creates an Amazon Q application.","ref":"AWS.QBusiness.html#create_application/3","title":"AWS.QBusiness.create_application/3","type":"function"},{"doc":"Creates an Amazon Q index.\n\nTo determine if index creation has completed, check the `Status` field returned\nfrom a call to `DescribeIndex`. The `Status` field is set to `ACTIVE` when the\nindex is ready to use.\n\nOnce the index is active, you can index your documents using the [\n`BatchPutDocument`\n](https://docs.aws.amazon.com/amazonq/latest/api-reference/API_BatchPutDocument.html)\nAPI or the [ `CreateDataSource`\n](https://docs.aws.amazon.com/amazonq/latest/api-reference/API_CreateDataSource.html)\nAPI.","ref":"AWS.QBusiness.html#create_index/4","title":"AWS.QBusiness.create_index/4","type":"function"},{"doc":"Creates an Amazon Q plugin.","ref":"AWS.QBusiness.html#create_plugin/4","title":"AWS.QBusiness.create_plugin/4","type":"function"},{"doc":"Adds a retriever to your Amazon Q application.","ref":"AWS.QBusiness.html#create_retriever/4","title":"AWS.QBusiness.create_retriever/4","type":"function"},{"doc":"Creates a universally unique identifier (UUID) mapped to a list of local user\nids within an application.","ref":"AWS.QBusiness.html#create_user/4","title":"AWS.QBusiness.create_user/4","type":"function"},{"doc":"Creates an Amazon Q web experience.","ref":"AWS.QBusiness.html#create_web_experience/4","title":"AWS.QBusiness.create_web_experience/4","type":"function"},{"doc":"Deletes an Amazon Q application.","ref":"AWS.QBusiness.html#delete_application/4","title":"AWS.QBusiness.delete_application/4","type":"function"},{"doc":"Deletes chat controls configured for an existing Amazon Q application.","ref":"AWS.QBusiness.html#delete_chat_controls_configuration/4","title":"AWS.QBusiness.delete_chat_controls_configuration/4","type":"function"},{"doc":"Deletes an Amazon Q web experience conversation.","ref":"AWS.QBusiness.html#delete_conversation/5","title":"AWS.QBusiness.delete_conversation/5","type":"function"},{"doc":"Deletes an Amazon Q data source connector.\n\nWhile the data source is being deleted, the `Status` field returned by a call to\nthe `DescribeDataSource` API is set to `DELETING`.","ref":"AWS.QBusiness.html#delete_data_source/6","title":"AWS.QBusiness.delete_data_source/6","type":"function"},{"doc":"Deletes a group so that all users and sub groups that belong to the group can no\nlonger access documents only available to that group.\n\nFor example, after deleting the group \"Summer Interns\", all interns who belonged\nto that group no longer see intern-only documents in their chat results.\n\nIf you want to delete, update, or replace users or sub groups of a group, you\nneed to use the `PutGroup` operation. For example, if a user in the group\n\"Engineering\" leaves the engineering team and another user takes their place,\nyou provide an updated list of users or sub groups that belong to the\n\"Engineering\" group when calling `PutGroup`.","ref":"AWS.QBusiness.html#delete_group/6","title":"AWS.QBusiness.delete_group/6","type":"function"},{"doc":"Deletes an Amazon Q index.","ref":"AWS.QBusiness.html#delete_index/5","title":"AWS.QBusiness.delete_index/5","type":"function"},{"doc":"Deletes an Amazon Q plugin.","ref":"AWS.QBusiness.html#delete_plugin/5","title":"AWS.QBusiness.delete_plugin/5","type":"function"},{"doc":"Deletes the retriever used by an Amazon Q application.","ref":"AWS.QBusiness.html#delete_retriever/5","title":"AWS.QBusiness.delete_retriever/5","type":"function"},{"doc":"Deletes a user by email id.","ref":"AWS.QBusiness.html#delete_user/5","title":"AWS.QBusiness.delete_user/5","type":"function"},{"doc":"Deletes an Amazon Q web experience.","ref":"AWS.QBusiness.html#delete_web_experience/5","title":"AWS.QBusiness.delete_web_experience/5","type":"function"},{"doc":"Gets information about an existing Amazon Q application.","ref":"AWS.QBusiness.html#get_application/3","title":"AWS.QBusiness.get_application/3","type":"function"},{"doc":"Gets information about an chat controls configured for an existing Amazon Q\napplication.","ref":"AWS.QBusiness.html#get_chat_controls_configuration/5","title":"AWS.QBusiness.get_chat_controls_configuration/5","type":"function"},{"doc":"Gets information about an existing Amazon Q data source connector.","ref":"AWS.QBusiness.html#get_data_source/5","title":"AWS.QBusiness.get_data_source/5","type":"function"},{"doc":"Describes a group by group name.","ref":"AWS.QBusiness.html#get_group/6","title":"AWS.QBusiness.get_group/6","type":"function"},{"doc":"Gets information about an existing Amazon Q index.","ref":"AWS.QBusiness.html#get_index/4","title":"AWS.QBusiness.get_index/4","type":"function"},{"doc":"Gets information about an existing Amazon Q plugin.","ref":"AWS.QBusiness.html#get_plugin/4","title":"AWS.QBusiness.get_plugin/4","type":"function"},{"doc":"Gets information about an existing retriever used by an Amazon Q application.","ref":"AWS.QBusiness.html#get_retriever/4","title":"AWS.QBusiness.get_retriever/4","type":"function"},{"doc":"Describes the universally unique identifier (UUID) associated with a local user\nin a data source.","ref":"AWS.QBusiness.html#get_user/4","title":"AWS.QBusiness.get_user/4","type":"function"},{"doc":"Gets information about an existing Amazon Q web experience.","ref":"AWS.QBusiness.html#get_web_experience/4","title":"AWS.QBusiness.get_web_experience/4","type":"function"},{"doc":"Lists Amazon Q applications.","ref":"AWS.QBusiness.html#list_applications/4","title":"AWS.QBusiness.list_applications/4","type":"function"},{"doc":"Lists one or more Amazon Q conversations.","ref":"AWS.QBusiness.html#list_conversations/6","title":"AWS.QBusiness.list_conversations/6","type":"function"},{"doc":"Get information about an Amazon Q data source connector synchronization.","ref":"AWS.QBusiness.html#list_data_source_sync_jobs/10","title":"AWS.QBusiness.list_data_source_sync_jobs/10","type":"function"},{"doc":"Lists the Amazon Q data source connectors that you have created.","ref":"AWS.QBusiness.html#list_data_sources/6","title":"AWS.QBusiness.list_data_sources/6","type":"function"},{"doc":"A list of documents attached to an index.","ref":"AWS.QBusiness.html#list_documents/7","title":"AWS.QBusiness.list_documents/7","type":"function"},{"doc":"Provides a list of groups that are mapped to users.","ref":"AWS.QBusiness.html#list_groups/8","title":"AWS.QBusiness.list_groups/8","type":"function"},{"doc":"Lists the Amazon Q indices you have created.","ref":"AWS.QBusiness.html#list_indices/5","title":"AWS.QBusiness.list_indices/5","type":"function"},{"doc":"Gets a list of messages associated with an Amazon Q web experience.","ref":"AWS.QBusiness.html#list_messages/7","title":"AWS.QBusiness.list_messages/7","type":"function"},{"doc":"Lists configured Amazon Q plugins.","ref":"AWS.QBusiness.html#list_plugins/5","title":"AWS.QBusiness.list_plugins/5","type":"function"},{"doc":"Lists the retriever used by an Amazon Q application.","ref":"AWS.QBusiness.html#list_retrievers/5","title":"AWS.QBusiness.list_retrievers/5","type":"function"},{"doc":"Gets a list of tags associated with a specified resource.\n\nAmazon Q applications and data sources can have tags associated with them.","ref":"AWS.QBusiness.html#list_tags_for_resource/3","title":"AWS.QBusiness.list_tags_for_resource/3","type":"function"},{"doc":"Lists one or more Amazon Q Web Experiences.","ref":"AWS.QBusiness.html#list_web_experiences/5","title":"AWS.QBusiness.list_web_experiences/5","type":"function"},{"doc":"","ref":"AWS.QBusiness.html#metadata/0","title":"AWS.QBusiness.metadata/0","type":"function"},{"doc":"Enables your end user to to provide feedback on their Amazon Q generated chat\nresponses.","ref":"AWS.QBusiness.html#put_feedback/6","title":"AWS.QBusiness.put_feedback/6","type":"function"},{"doc":"Create, or updates, a mapping of users—who have access to a document—to groups.\n\nYou can also map sub groups to groups. For example, the group \"Company\nIntellectual Property Teams\" includes sub groups \"Research\" and \"Engineering\".\nThese sub groups include their own list of users or people who work in these\nteams. Only users who work in research and engineering, and therefore belong in\nthe intellectual property group, can see top-secret company documents in their\nAmazon Q chat results.","ref":"AWS.QBusiness.html#put_group/5","title":"AWS.QBusiness.put_group/5","type":"function"},{"doc":"Starts a data source connector synchronization job.\n\nIf a synchronization job is already in progress, Amazon Q returns a\n`ConflictException`.","ref":"AWS.QBusiness.html#start_data_source_sync_job/6","title":"AWS.QBusiness.start_data_source_sync_job/6","type":"function"},{"doc":"Stops an Amazon Q data source connector synchronization job already in progress.","ref":"AWS.QBusiness.html#stop_data_source_sync_job/6","title":"AWS.QBusiness.stop_data_source_sync_job/6","type":"function"},{"doc":"Adds the specified tag to the specified Amazon Q application or data source\nresource.\n\nIf the tag already exists, the existing value is replaced with the new value.","ref":"AWS.QBusiness.html#tag_resource/4","title":"AWS.QBusiness.tag_resource/4","type":"function"},{"doc":"Removes a tag from an Amazon Q application or a data source.","ref":"AWS.QBusiness.html#untag_resource/4","title":"AWS.QBusiness.untag_resource/4","type":"function"},{"doc":"Updates an existing Amazon Q application.","ref":"AWS.QBusiness.html#update_application/4","title":"AWS.QBusiness.update_application/4","type":"function"},{"doc":"Updates an set of chat controls configured for an existing Amazon Q application.","ref":"AWS.QBusiness.html#update_chat_controls_configuration/4","title":"AWS.QBusiness.update_chat_controls_configuration/4","type":"function"},{"doc":"Updates an existing Amazon Q data source connector.","ref":"AWS.QBusiness.html#update_data_source/6","title":"AWS.QBusiness.update_data_source/6","type":"function"},{"doc":"Updates an Amazon Q index.","ref":"AWS.QBusiness.html#update_index/5","title":"AWS.QBusiness.update_index/5","type":"function"},{"doc":"Updates an Amazon Q plugin.","ref":"AWS.QBusiness.html#update_plugin/5","title":"AWS.QBusiness.update_plugin/5","type":"function"},{"doc":"Updates the retriever used for your Amazon Q application.","ref":"AWS.QBusiness.html#update_retriever/5","title":"AWS.QBusiness.update_retriever/5","type":"function"},{"doc":"Updates a information associated with a user id.","ref":"AWS.QBusiness.html#update_user/5","title":"AWS.QBusiness.update_user/5","type":"function"},{"doc":"Updates an Amazon Q web experience.","ref":"AWS.QBusiness.html#update_web_experience/5","title":"AWS.QBusiness.update_web_experience/5","type":"function"},{"doc":"**Powered by Amazon Bedrock**: Amazon Web Services implements [automated abuse detection](https://docs.aws.amazon.com/bedrock/latest/userguide/abuse-detection.html).\n\nBecause Amazon Q in Connect is built on Amazon Bedrock, users can take full\nadvantage of the controls implemented in Amazon Bedrock to enforce safety,\nsecurity, and the responsible use of artificial intelligence (AI).\n\nAmazon Q in Connect is a generative AI customer service assistant. It is an\nLLM-enhanced evolution of Amazon Connect Wisdom that delivers real-time\nrecommendations to help contact center agents resolve customer issues quickly\nand accurately.\n\nAmazon Q automatically detects customer intent during calls and chats using\nconversational analytics and natural language understanding (NLU). It then\nprovides agents with immediate, real-time generative responses and suggested\nactions, and links to relevant documents and articles. Agents can also query\nAmazon Q directly using natural language or keywords to answer customer\nrequests.\n\nUse the Amazon Q in Connect APIs to create an assistant and a knowledge base,\nfor example, or manage content by uploading custom files.\n\nFor more information, see [Use Amazon Q in Connect for generative AI powered agent assistance in\nreal-time](https://docs.aws.amazon.com/connect/latest/adminguide/amazon-q-connect.html)\nin the *Amazon Connect Administrator Guide*.","ref":"AWS.QConnect.html","title":"AWS.QConnect","type":"module"},{"doc":"Creates an Amazon Q in Connect assistant.","ref":"AWS.QConnect.html#create_assistant/3","title":"AWS.QConnect.create_assistant/3","type":"function"},{"doc":"Creates an association between an Amazon Q in Connect assistant and another\nresource.\n\nCurrently, the only supported association is with a knowledge base. An assistant\ncan have only a single association.","ref":"AWS.QConnect.html#create_assistant_association/4","title":"AWS.QConnect.create_assistant_association/4","type":"function"},{"doc":"Creates Amazon Q content.\n\nBefore to calling this API, use\n[StartContentUpload](https://docs.aws.amazon.com/amazon-q-connect/latest/APIReference/API_StartContentUpload.html)\nto upload an asset.","ref":"AWS.QConnect.html#create_content/4","title":"AWS.QConnect.create_content/4","type":"function"},{"doc":"Creates a knowledge base.\n\nWhen using this API, you cannot reuse [Amazon AppIntegrations](https://docs.aws.amazon.com/appintegrations/latest/APIReference/Welcome.html)\nDataIntegrations with external knowledge bases such as Salesforce and\nServiceNow. If you do, you'll get an `InvalidRequestException` error.\n\nFor example, you're programmatically managing your external knowledge base, and\nyou want to add or remove one of the fields that is being ingested from\nSalesforce. Do the following:\n\n   Call\n[DeleteKnowledgeBase](https://docs.aws.amazon.com/amazon-q-connect/latest/APIReference/API_DeleteKnowledgeBase.html).     Call\n[DeleteDataIntegration](https://docs.aws.amazon.com/appintegrations/latest/APIReference/API_DeleteDataIntegration.html).\n\n   Call\n[CreateDataIntegration](https://docs.aws.amazon.com/appintegrations/latest/APIReference/API_CreateDataIntegration.html)\nto recreate the DataIntegration or a create different one.\n\n   Call CreateKnowledgeBase.","ref":"AWS.QConnect.html#create_knowledge_base/3","title":"AWS.QConnect.create_knowledge_base/3","type":"function"},{"doc":"Creates an Amazon Q quick response.","ref":"AWS.QConnect.html#create_quick_response/4","title":"AWS.QConnect.create_quick_response/4","type":"function"},{"doc":"Creates a session.\n\nA session is a contextual container used for generating recommendations. Amazon\nConnect creates a new Amazon Q session for each contact on which Amazon Q is\nenabled.","ref":"AWS.QConnect.html#create_session/4","title":"AWS.QConnect.create_session/4","type":"function"},{"doc":"Deletes an assistant.","ref":"AWS.QConnect.html#delete_assistant/4","title":"AWS.QConnect.delete_assistant/4","type":"function"},{"doc":"Deletes an assistant association.","ref":"AWS.QConnect.html#delete_assistant_association/5","title":"AWS.QConnect.delete_assistant_association/5","type":"function"},{"doc":"Deletes the content.","ref":"AWS.QConnect.html#delete_content/5","title":"AWS.QConnect.delete_content/5","type":"function"},{"doc":"Deletes the quick response import job.","ref":"AWS.QConnect.html#delete_import_job/5","title":"AWS.QConnect.delete_import_job/5","type":"function"},{"doc":"Deletes the knowledge base.\n\nWhen you use this API to delete an external knowledge base such as Salesforce or\nServiceNow, you must also delete the [Amazon AppIntegrations](https://docs.aws.amazon.com/appintegrations/latest/APIReference/Welcome.html)\nDataIntegration. This is because you can't reuse the DataIntegration after it's\nbeen associated with an external knowledge base. However, you can delete and\nrecreate it. See\n[DeleteDataIntegration](https://docs.aws.amazon.com/appintegrations/latest/APIReference/API_DeleteDataIntegration.html) and\n[CreateDataIntegration](https://docs.aws.amazon.com/appintegrations/latest/APIReference/API_CreateDataIntegration.html)\nin the *Amazon AppIntegrations API Reference*.","ref":"AWS.QConnect.html#delete_knowledge_base/4","title":"AWS.QConnect.delete_knowledge_base/4","type":"function"},{"doc":"Deletes a quick response.","ref":"AWS.QConnect.html#delete_quick_response/5","title":"AWS.QConnect.delete_quick_response/5","type":"function"},{"doc":"Retrieves information about an assistant.","ref":"AWS.QConnect.html#get_assistant/3","title":"AWS.QConnect.get_assistant/3","type":"function"},{"doc":"Retrieves information about an assistant association.","ref":"AWS.QConnect.html#get_assistant_association/4","title":"AWS.QConnect.get_assistant_association/4","type":"function"},{"doc":"Retrieves content, including a pre-signed URL to download the content.","ref":"AWS.QConnect.html#get_content/4","title":"AWS.QConnect.get_content/4","type":"function"},{"doc":"Retrieves summary information about the content.","ref":"AWS.QConnect.html#get_content_summary/4","title":"AWS.QConnect.get_content_summary/4","type":"function"},{"doc":"Retrieves the started import job.","ref":"AWS.QConnect.html#get_import_job/4","title":"AWS.QConnect.get_import_job/4","type":"function"},{"doc":"Retrieves information about the knowledge base.","ref":"AWS.QConnect.html#get_knowledge_base/3","title":"AWS.QConnect.get_knowledge_base/3","type":"function"},{"doc":"Retrieves the quick response.","ref":"AWS.QConnect.html#get_quick_response/4","title":"AWS.QConnect.get_quick_response/4","type":"function"},{"doc":"Retrieves recommendations for the specified session.\n\nTo avoid retrieving the same recommendations in subsequent calls, use\n[NotifyRecommendationsReceived](https://docs.aws.amazon.com/amazon-q-connect/latest/APIReference/API_NotifyRecommendationsReceived.html). This API supports long-polling behavior with the `waitTimeSeconds` parameter.\nShort poll is the default behavior and only returns recommendations already\navailable. To perform a manual query against an assistant, use\n[QueryAssistant](https://docs.aws.amazon.com/amazon-q-connect/latest/APIReference/API_QueryAssistant.html).","ref":"AWS.QConnect.html#get_recommendations/6","title":"AWS.QConnect.get_recommendations/6","type":"function"},{"doc":"Retrieves information for a specified session.","ref":"AWS.QConnect.html#get_session/4","title":"AWS.QConnect.get_session/4","type":"function"},{"doc":"Lists information about assistant associations.","ref":"AWS.QConnect.html#list_assistant_associations/5","title":"AWS.QConnect.list_assistant_associations/5","type":"function"},{"doc":"Lists information about assistants.","ref":"AWS.QConnect.html#list_assistants/4","title":"AWS.QConnect.list_assistants/4","type":"function"},{"doc":"Lists the content.","ref":"AWS.QConnect.html#list_contents/5","title":"AWS.QConnect.list_contents/5","type":"function"},{"doc":"Lists information about import jobs.","ref":"AWS.QConnect.html#list_import_jobs/5","title":"AWS.QConnect.list_import_jobs/5","type":"function"},{"doc":"Lists the knowledge bases.","ref":"AWS.QConnect.html#list_knowledge_bases/4","title":"AWS.QConnect.list_knowledge_bases/4","type":"function"},{"doc":"Lists information about quick response.","ref":"AWS.QConnect.html#list_quick_responses/5","title":"AWS.QConnect.list_quick_responses/5","type":"function"},{"doc":"Lists the tags for the specified resource.","ref":"AWS.QConnect.html#list_tags_for_resource/3","title":"AWS.QConnect.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.QConnect.html#metadata/0","title":"AWS.QConnect.metadata/0","type":"function"},{"doc":"Removes the specified recommendations from the specified assistant's queue of\nnewly available recommendations.\n\nYou can use this API in conjunction with\n[GetRecommendations](https://docs.aws.amazon.com/amazon-q-connect/latest/APIReference/API_GetRecommendations.html)\nand a `waitTimeSeconds` input for long-polling behavior and avoiding duplicate\nrecommendations.","ref":"AWS.QConnect.html#notify_recommendations_received/5","title":"AWS.QConnect.notify_recommendations_received/5","type":"function"},{"doc":"Provides feedback against the specified assistant for the specified target.\n\nThis API only supports generative targets.","ref":"AWS.QConnect.html#put_feedback/4","title":"AWS.QConnect.put_feedback/4","type":"function"},{"doc":"Performs a manual search against the specified assistant.\n\nTo retrieve recommendations for an assistant, use\n[GetRecommendations](https://docs.aws.amazon.com/amazon-q-connect/latest/APIReference/API_GetRecommendations.html).","ref":"AWS.QConnect.html#query_assistant/4","title":"AWS.QConnect.query_assistant/4","type":"function"},{"doc":"Removes a URI template from a knowledge base.","ref":"AWS.QConnect.html#remove_knowledge_base_template_uri/4","title":"AWS.QConnect.remove_knowledge_base_template_uri/4","type":"function"},{"doc":"Searches for content in a specified knowledge base.\n\nCan be used to get a specific content resource by its name.","ref":"AWS.QConnect.html#search_content/4","title":"AWS.QConnect.search_content/4","type":"function"},{"doc":"Searches existing Amazon Q quick responses in an Amazon Q knowledge base.","ref":"AWS.QConnect.html#search_quick_responses/4","title":"AWS.QConnect.search_quick_responses/4","type":"function"},{"doc":"Searches for sessions.","ref":"AWS.QConnect.html#search_sessions/4","title":"AWS.QConnect.search_sessions/4","type":"function"},{"doc":"Get a URL to upload content to a knowledge base.\n\nTo upload content, first make a PUT request to the returned URL with your file,\nmaking sure to include the required headers. Then use\n[CreateContent](https://docs.aws.amazon.com/amazon-q-connect/latest/APIReference/API_CreateContent.html) to finalize the content creation process or\n[UpdateContent](https://docs.aws.amazon.com/amazon-q-connect/latest/APIReference/API_UpdateContent.html)\nto modify an existing resource. You can only upload content to a knowledge base\nof type CUSTOM.","ref":"AWS.QConnect.html#start_content_upload/4","title":"AWS.QConnect.start_content_upload/4","type":"function"},{"doc":"Start an asynchronous job to import Amazon Q resources from an uploaded source\nfile.\n\nBefore calling this API, use\n[StartContentUpload](https://docs.aws.amazon.com/wisdom/latest/APIReference/API_StartContentUpload.html) to upload an asset that contains the resource data.\n\n  * For importing Amazon Q quick responses, you need to upload a csv\nfile including the quick responses. For information about how to format the csv\nfile for importing quick responses, see [Import quick\nresponses](https://docs.aws.amazon.com/console/connect/quick-responses/add-data).","ref":"AWS.QConnect.html#start_import_job/4","title":"AWS.QConnect.start_import_job/4","type":"function"},{"doc":"Adds the specified tags to the specified resource.","ref":"AWS.QConnect.html#tag_resource/4","title":"AWS.QConnect.tag_resource/4","type":"function"},{"doc":"Removes the specified tags from the specified resource.","ref":"AWS.QConnect.html#untag_resource/4","title":"AWS.QConnect.untag_resource/4","type":"function"},{"doc":"Updates information about the content.","ref":"AWS.QConnect.html#update_content/5","title":"AWS.QConnect.update_content/5","type":"function"},{"doc":"Updates the template URI of a knowledge base.\n\nThis is only supported for knowledge bases of type EXTERNAL. Include a single\nvariable in `${variable}` format; this interpolated by Amazon Q using ingested\ncontent. For example, if you ingest a Salesforce article, it has an `Id` value,\nand you can set the template URI to\n`https://myInstanceName.lightning.force.com/lightning/r/Knowledge__kav/*${Id}*/view`.","ref":"AWS.QConnect.html#update_knowledge_base_template_uri/4","title":"AWS.QConnect.update_knowledge_base_template_uri/4","type":"function"},{"doc":"Updates an existing Amazon Q quick response.","ref":"AWS.QConnect.html#update_quick_response/5","title":"AWS.QConnect.update_quick_response/5","type":"function"},{"doc":"The resource management API for Amazon QLDB","ref":"AWS.QLDB.html","title":"AWS.QLDB","type":"module"},{"doc":"Ends a given Amazon QLDB journal stream.\n\nBefore a stream can be canceled, its current status must be `ACTIVE`.\n\nYou can't restart a stream after you cancel it. Canceled QLDB stream resources\nare subject to a 7-day retention period, so they are automatically deleted after\nthis limit expires.","ref":"AWS.QLDB.html#cancel_journal_kinesis_stream/5","title":"AWS.QLDB.cancel_journal_kinesis_stream/5","type":"function"},{"doc":"Creates a new ledger in your Amazon Web Services account in the current Region.","ref":"AWS.QLDB.html#create_ledger/3","title":"AWS.QLDB.create_ledger/3","type":"function"},{"doc":"Deletes a ledger and all of its contents.\n\nThis action is irreversible.\n\nIf deletion protection is enabled, you must first disable it before you can\ndelete the ledger. You can disable it by calling the `UpdateLedger` operation to\nset this parameter to `false`.","ref":"AWS.QLDB.html#delete_ledger/4","title":"AWS.QLDB.delete_ledger/4","type":"function"},{"doc":"Returns detailed information about a given Amazon QLDB journal stream.\n\nThe output includes the Amazon Resource Name (ARN), stream name, current status,\ncreation time, and the parameters of the original stream creation request.\n\nThis action does not return any expired journal streams. For more information,\nsee [Expiration for terminal streams](https://docs.aws.amazon.com/qldb/latest/developerguide/streams.create.html#streams.create.states.expiration)\nin the *Amazon QLDB Developer Guide*.","ref":"AWS.QLDB.html#describe_journal_kinesis_stream/4","title":"AWS.QLDB.describe_journal_kinesis_stream/4","type":"function"},{"doc":"Returns information about a journal export job, including the ledger name,\nexport ID, creation time, current status, and the parameters of the original\nexport creation request.\n\nThis action does not return any expired export jobs. For more information, see\n[Export job expiration](https://docs.aws.amazon.com/qldb/latest/developerguide/export-journal.request.html#export-journal.request.expiration)\nin the *Amazon QLDB Developer Guide*.\n\nIf the export job with the given `ExportId` doesn't exist, then throws\n`ResourceNotFoundException`.\n\nIf the ledger with the given `Name` doesn't exist, then throws\n`ResourceNotFoundException`.","ref":"AWS.QLDB.html#describe_journal_s3_export/4","title":"AWS.QLDB.describe_journal_s3_export/4","type":"function"},{"doc":"Returns information about a ledger, including its state, permissions mode,\nencryption at rest settings, and when it was created.","ref":"AWS.QLDB.html#describe_ledger/3","title":"AWS.QLDB.describe_ledger/3","type":"function"},{"doc":"Exports journal contents within a date and time range from a ledger into a\nspecified Amazon Simple Storage Service (Amazon S3) bucket.\n\nA journal export job can write the data objects in either the text or binary\nrepresentation of Amazon Ion format, or in *JSON Lines* text format.\n\nIf the ledger with the given `Name` doesn't exist, then throws\n`ResourceNotFoundException`.\n\nIf the ledger with the given `Name` is in `CREATING` status, then throws\n`ResourcePreconditionNotMetException`.\n\nYou can initiate up to two concurrent journal export requests for each ledger.\nBeyond this limit, journal export requests throw `LimitExceededException`.","ref":"AWS.QLDB.html#export_journal_to_s3/4","title":"AWS.QLDB.export_journal_to_s3/4","type":"function"},{"doc":"Returns a block object at a specified address in a journal.\n\nAlso returns a proof of the specified block for verification if\n`DigestTipAddress` is provided.\n\nFor information about the data contents in a block, see [Journal contents](https://docs.aws.amazon.com/qldb/latest/developerguide/journal-contents.html)\nin the *Amazon QLDB Developer Guide*.\n\nIf the specified ledger doesn't exist or is in `DELETING` status, then throws\n`ResourceNotFoundException`.\n\nIf the specified ledger is in `CREATING` status, then throws\n`ResourcePreconditionNotMetException`.\n\nIf no block exists with the specified address, then throws\n`InvalidParameterException`.","ref":"AWS.QLDB.html#get_block/4","title":"AWS.QLDB.get_block/4","type":"function"},{"doc":"Returns the digest of a ledger at the latest committed block in the journal.\n\nThe response includes a 256-bit hash value and a block address.","ref":"AWS.QLDB.html#get_digest/4","title":"AWS.QLDB.get_digest/4","type":"function"},{"doc":"Returns a revision data object for a specified document ID and block address.\n\nAlso returns a proof of the specified revision for verification if\n`DigestTipAddress` is provided.","ref":"AWS.QLDB.html#get_revision/4","title":"AWS.QLDB.get_revision/4","type":"function"},{"doc":"Returns all Amazon QLDB journal streams for a given ledger.\n\nThis action does not return any expired journal streams. For more information,\nsee [Expiration for terminal streams](https://docs.aws.amazon.com/qldb/latest/developerguide/streams.create.html#streams.create.states.expiration)\nin the *Amazon QLDB Developer Guide*.\n\nThis action returns a maximum of `MaxResults` items. It is paginated so that you\ncan retrieve all the items by calling `ListJournalKinesisStreamsForLedger`\nmultiple times.","ref":"AWS.QLDB.html#list_journal_kinesis_streams_for_ledger/5","title":"AWS.QLDB.list_journal_kinesis_streams_for_ledger/5","type":"function"},{"doc":"Returns all journal export jobs for all ledgers that are associated with the\ncurrent Amazon Web Services account and Region.\n\nThis action returns a maximum of `MaxResults` items, and is paginated so that\nyou can retrieve all the items by calling `ListJournalS3Exports` multiple times.\n\nThis action does not return any expired export jobs. For more information, see\n[Export job expiration](https://docs.aws.amazon.com/qldb/latest/developerguide/export-journal.request.html#export-journal.request.expiration)\nin the *Amazon QLDB Developer Guide*.","ref":"AWS.QLDB.html#list_journal_s3_exports/4","title":"AWS.QLDB.list_journal_s3_exports/4","type":"function"},{"doc":"Returns all journal export jobs for a specified ledger.\n\nThis action returns a maximum of `MaxResults` items, and is paginated so that\nyou can retrieve all the items by calling `ListJournalS3ExportsForLedger`\nmultiple times.\n\nThis action does not return any expired export jobs. For more information, see\n[Export job expiration](https://docs.aws.amazon.com/qldb/latest/developerguide/export-journal.request.html#export-journal.request.expiration)\nin the *Amazon QLDB Developer Guide*.","ref":"AWS.QLDB.html#list_journal_s3_exports_for_ledger/5","title":"AWS.QLDB.list_journal_s3_exports_for_ledger/5","type":"function"},{"doc":"Returns all ledgers that are associated with the current Amazon Web Services\naccount and Region.\n\nThis action returns a maximum of `MaxResults` items and is paginated so that you\ncan retrieve all the items by calling `ListLedgers` multiple times.","ref":"AWS.QLDB.html#list_ledgers/4","title":"AWS.QLDB.list_ledgers/4","type":"function"},{"doc":"Returns all tags for a specified Amazon QLDB resource.","ref":"AWS.QLDB.html#list_tags_for_resource/3","title":"AWS.QLDB.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.QLDB.html#metadata/0","title":"AWS.QLDB.metadata/0","type":"function"},{"doc":"Creates a journal stream for a given Amazon QLDB ledger.\n\nThe stream captures every document revision that is committed to the ledger's\njournal and delivers the data to a specified Amazon Kinesis Data Streams\nresource.","ref":"AWS.QLDB.html#stream_journal_to_kinesis/4","title":"AWS.QLDB.stream_journal_to_kinesis/4","type":"function"},{"doc":"Adds one or more tags to a specified Amazon QLDB resource.\n\nA resource can have up to 50 tags. If you try to create more than 50 tags for a\nresource, your request fails and returns an error.","ref":"AWS.QLDB.html#tag_resource/4","title":"AWS.QLDB.tag_resource/4","type":"function"},{"doc":"Removes one or more tags from a specified Amazon QLDB resource.\n\nYou can specify up to 50 tag keys to remove.","ref":"AWS.QLDB.html#untag_resource/4","title":"AWS.QLDB.untag_resource/4","type":"function"},{"doc":"Updates properties on a ledger.","ref":"AWS.QLDB.html#update_ledger/4","title":"AWS.QLDB.update_ledger/4","type":"function"},{"doc":"Updates the permissions mode of a ledger.\n\nBefore you switch to the `STANDARD` permissions mode, you must first create all\nrequired IAM policies and table tags to avoid disruption to your users. To learn\nmore, see [Migrating to the standard permissions mode](https://docs.aws.amazon.com/qldb/latest/developerguide/ledger-management.basics.html#ledger-mgmt.basics.update-permissions.migrating)\nin the *Amazon QLDB Developer Guide*.","ref":"AWS.QLDB.html#update_ledger_permissions_mode/4","title":"AWS.QLDB.update_ledger_permissions_mode/4","type":"function"},{"doc":"The transactional data APIs for Amazon QLDB\n\nInstead of interacting directly with this API, we recommend using the QLDB\ndriver or the QLDB shell to execute data transactions on a ledger.\n\n   If you are working with an AWS SDK, use the QLDB driver. The driver\nprovides a high-level abstraction layer above this *QLDB Session* data plane and\nmanages `SendCommand` API calls for you. For information and a list of supported\nprogramming languages, see [Getting started with the driver](https://docs.aws.amazon.com/qldb/latest/developerguide/getting-started-driver.html)\nin the *Amazon QLDB Developer Guide*.\n\n   If you are working with the AWS Command Line Interface (AWS CLI),\nuse the QLDB shell. The shell is a command line interface that uses the QLDB\ndriver to interact with a ledger. For information, see [Accessing Amazon QLDB using the QLDB\nshell](https://docs.aws.amazon.com/qldb/latest/developerguide/data-shell.html).","ref":"AWS.QLDBSession.html","title":"AWS.QLDBSession","type":"module"},{"doc":"","ref":"AWS.QLDBSession.html#metadata/0","title":"AWS.QLDBSession.metadata/0","type":"function"},{"doc":"Sends a command to an Amazon QLDB ledger.\n\nInstead of interacting directly with this API, we recommend using the QLDB\ndriver or the QLDB shell to execute data transactions on a ledger.\n\n   If you are working with an AWS SDK, use the QLDB driver. The driver\nprovides a high-level abstraction layer above this *QLDB Session* data plane and\nmanages `SendCommand` API calls for you. For information and a list of supported\nprogramming languages, see [Getting started with the driver](https://docs.aws.amazon.com/qldb/latest/developerguide/getting-started-driver.html)\nin the *Amazon QLDB Developer Guide*.\n\n   If you are working with the AWS Command Line Interface (AWS CLI),\nuse the QLDB shell. The shell is a command line interface that uses the QLDB\ndriver to interact with a ledger. For information, see [Accessing Amazon QLDB using the QLDB\nshell](https://docs.aws.amazon.com/qldb/latest/developerguide/data-shell.html).","ref":"AWS.QLDBSession.html#send_command/3","title":"AWS.QLDBSession.send_command/3","type":"function"},{"doc":"Amazon QuickSight API Reference\n\nAmazon QuickSight is a fully managed, serverless business intelligence service\nfor the Amazon Web Services Cloud that makes it easy to extend data and insights\nto every user in your organization.\n\nThis API reference contains documentation for a programming interface that you\ncan use to manage Amazon QuickSight.","ref":"AWS.QuickSight.html","title":"AWS.QuickSight","type":"module"},{"doc":"Cancels an ongoing ingestion of data into SPICE.","ref":"AWS.QuickSight.html#cancel_ingestion/6","title":"AWS.QuickSight.cancel_ingestion/6","type":"function"},{"doc":"Creates Amazon QuickSight customizations for the current Amazon Web Services\nRegion.\n\nCurrently, you can add a custom default theme by using the\n`CreateAccountCustomization` or `UpdateAccountCustomization` API operation. To\nfurther customize Amazon QuickSight by removing Amazon QuickSight sample assets\nand videos for all new users, see [Customizing Amazon QuickSight](https://docs.aws.amazon.com/quicksight/latest/user/customizing-quicksight.html)\nin the *Amazon QuickSight User Guide.*\n\nYou can create customizations for your Amazon Web Services account or, if you\nspecify a namespace, for a QuickSight namespace instead. Customizations that\napply to a namespace always override customizations that apply to an Amazon Web\nServices account. To find out which customizations apply, use the\n`DescribeAccountCustomization` API operation.\n\nBefore you use the `CreateAccountCustomization` API operation to add a theme as\nthe namespace default, make sure that you first share the theme with the\nnamespace. If you don't share it with the namespace, the theme isn't visible to\nyour users even if you make it the default theme. To check if the theme is\nshared, view the current permissions by using the `\n[DescribeThemePermissions](https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DescribeThemePermissions.html) ` API operation. To share the theme, grant permissions by using the `\n[UpdateThemePermissions](https://docs.aws.amazon.com/quicksight/latest/APIReference/API_UpdateThemePermissions.html)\n` API operation.","ref":"AWS.QuickSight.html#create_account_customization/4","title":"AWS.QuickSight.create_account_customization/4","type":"function"},{"doc":"Creates an Amazon QuickSight account, or subscribes to Amazon QuickSight Q.\n\nThe Amazon Web Services Region for the account is derived from what is\nconfigured in the CLI or SDK.\n\nBefore you use this operation, make sure that you can connect to an existing\nAmazon Web Services account. If you don't have an Amazon Web Services account,\nsee [Sign up for Amazon Web Services](https://docs.aws.amazon.com/quicksight/latest/user/setting-up-aws-sign-up.html)\nin the *Amazon QuickSight User Guide*. The person who signs up for Amazon\nQuickSight needs to have the correct Identity and Access Management (IAM)\npermissions. For more information, see [IAM Policy Examples for Amazon QuickSight](https://docs.aws.amazon.com/quicksight/latest/user/iam-policy-examples.html)\nin the *Amazon QuickSight User Guide*.\n\nIf your IAM policy includes both the `Subscribe` and `CreateAccountSubscription`\nactions, make sure that both actions are set to `Allow`. If either action is set\nto `Deny`, the `Deny` action prevails and your API call fails.\n\nYou can't pass an existing IAM role to access other Amazon Web Services services\nusing this API operation. To pass your existing IAM role to Amazon QuickSight,\nsee [Passing IAM roles to Amazon QuickSight](https://docs.aws.amazon.com/quicksight/latest/user/security_iam_service-with-iam.html#security-create-iam-role)\nin the *Amazon QuickSight User Guide*.\n\nYou can't set default resource access on the new account from the Amazon\nQuickSight API. Instead, add default resource access from the Amazon QuickSight\nconsole. For more information about setting default resource access to Amazon\nWeb Services services, see [Setting default resource access to Amazon Web Services\nservices](https://docs.aws.amazon.com/quicksight/latest/user/scoping-policies-defaults.html)\nin the *Amazon QuickSight User Guide*.","ref":"AWS.QuickSight.html#create_account_subscription/4","title":"AWS.QuickSight.create_account_subscription/4","type":"function"},{"doc":"Creates an analysis in Amazon QuickSight.\n\nAnalyses can be created either from a template or from an `AnalysisDefinition`.","ref":"AWS.QuickSight.html#create_analysis/5","title":"AWS.QuickSight.create_analysis/5","type":"function"},{"doc":"Creates a dashboard from either a template or directly with a\n`DashboardDefinition`.\n\nTo first create a template, see the `\n[CreateTemplate](https://docs.aws.amazon.com/quicksight/latest/APIReference/API_CreateTemplate.html)\n` API operation.\n\nA dashboard is an entity in Amazon QuickSight that identifies Amazon QuickSight\nreports, created from analyses. You can share Amazon QuickSight dashboards. With\nthe right permissions, you can create scheduled email reports from them. If you\nhave the correct permissions, you can create a dashboard from a template that\nexists in a different Amazon Web Services account.","ref":"AWS.QuickSight.html#create_dashboard/5","title":"AWS.QuickSight.create_dashboard/5","type":"function"},{"doc":"Creates a dataset.\n\nThis operation doesn't support datasets that include uploaded files as a source.","ref":"AWS.QuickSight.html#create_data_set/4","title":"AWS.QuickSight.create_data_set/4","type":"function"},{"doc":"Creates a data source.","ref":"AWS.QuickSight.html#create_data_source/4","title":"AWS.QuickSight.create_data_source/4","type":"function"},{"doc":"Creates an empty shared folder.","ref":"AWS.QuickSight.html#create_folder/5","title":"AWS.QuickSight.create_folder/5","type":"function"},{"doc":"Adds an asset, such as a dashboard, analysis, or dataset into a folder.","ref":"AWS.QuickSight.html#create_folder_membership/7","title":"AWS.QuickSight.create_folder_membership/7","type":"function"},{"doc":"Use the `CreateGroup` operation to create a group in Amazon QuickSight.\n\nYou can create up to 10,000 groups in a namespace. If you want to create more\nthan 10,000 groups in a namespace, contact Amazon Web Services Support.\n\nThe permissions resource is\n`arn:aws:quicksight: :* *:group/default/* *\n`.\n\nThe response is a group object.","ref":"AWS.QuickSight.html#create_group/5","title":"AWS.QuickSight.create_group/5","type":"function"},{"doc":"Adds an Amazon QuickSight user to an Amazon QuickSight group.","ref":"AWS.QuickSight.html#create_group_membership/7","title":"AWS.QuickSight.create_group_membership/7","type":"function"},{"doc":"Creates an assignment with one specified IAM policy, identified by its Amazon\nResource Name (ARN).\n\nThis policy assignment is attached to the specified groups or users of Amazon\nQuickSight. Assignment names are unique per Amazon Web Services account. To\navoid overwriting rules in other namespaces, use assignment names that are\nunique.","ref":"AWS.QuickSight.html#create_iam_policy_assignment/5","title":"AWS.QuickSight.create_iam_policy_assignment/5","type":"function"},{"doc":"Creates and starts a new SPICE ingestion for a dataset.\n\nYou can manually refresh datasets in an Enterprise edition account 32 times in a\n24-hour period. You can manually refresh datasets in a Standard edition account\n8 times in a 24-hour period. Each 24-hour period is measured starting 24 hours\nbefore the current date and time.\n\nAny ingestions operating on tagged datasets inherit the same tags automatically\nfor use in access control. For an example, see [How do I create an IAM policy to control access to Amazon EC2 resources using\ntags?](http://aws.amazon.com/premiumsupport/knowledge-center/iam-ec2-resource-tags/)\nin the Amazon Web Services Knowledge Center. Tags are visible on the tagged\ndataset, but not on the ingestion resource.","ref":"AWS.QuickSight.html#create_ingestion/6","title":"AWS.QuickSight.create_ingestion/6","type":"function"},{"doc":"(Enterprise edition only) Creates a new namespace for you to use with Amazon\nQuickSight.\n\nA namespace allows you to isolate the Amazon QuickSight users and groups that\nare registered for that namespace. Users that access the namespace can share\nassets only with other users or groups in the same namespace. They can't see\nusers and groups in other namespaces. You can create a namespace after your\nAmazon Web Services account is subscribed to Amazon QuickSight. The namespace\nmust be unique within the Amazon Web Services account. By default, there is a\nlimit of 100 namespaces per Amazon Web Services account. To increase your limit,\ncreate a ticket with Amazon Web Services Support.","ref":"AWS.QuickSight.html#create_namespace/4","title":"AWS.QuickSight.create_namespace/4","type":"function"},{"doc":"Creates a refresh schedule for a dataset.\n\nYou can create up to 5 different schedules for a single dataset.","ref":"AWS.QuickSight.html#create_refresh_schedule/5","title":"AWS.QuickSight.create_refresh_schedule/5","type":"function"},{"doc":"Use `CreateRoleMembership` to add an existing Amazon QuickSight group to an\nexisting role.","ref":"AWS.QuickSight.html#create_role_membership/7","title":"AWS.QuickSight.create_role_membership/7","type":"function"},{"doc":"Creates a template either from a `TemplateDefinition` or from an existing Amazon\nQuickSight analysis or template.\n\nYou can use the resulting template to create additional dashboards, templates,\nor analyses.\n\nA *template* is an entity in Amazon QuickSight that encapsulates the metadata\nrequired to create an analysis and that you can use to create s dashboard. A\ntemplate adds a layer of abstraction by using placeholders to replace the\ndataset associated with the analysis. You can use templates to create dashboards\nby replacing dataset placeholders with datasets that follow the same schema that\nwas used to create the source analysis and template.","ref":"AWS.QuickSight.html#create_template/5","title":"AWS.QuickSight.create_template/5","type":"function"},{"doc":"Creates a template alias for a template.","ref":"AWS.QuickSight.html#create_template_alias/6","title":"AWS.QuickSight.create_template_alias/6","type":"function"},{"doc":"Creates a theme.\n\nA *theme* is set of configuration options for color and layout. Themes apply to\nanalyses and dashboards. For more information, see [Using Themes in Amazon QuickSight](https://docs.aws.amazon.com/quicksight/latest/user/themes-in-quicksight.html)\nin the *Amazon QuickSight User Guide*.","ref":"AWS.QuickSight.html#create_theme/5","title":"AWS.QuickSight.create_theme/5","type":"function"},{"doc":"Creates a theme alias for a theme.","ref":"AWS.QuickSight.html#create_theme_alias/6","title":"AWS.QuickSight.create_theme_alias/6","type":"function"},{"doc":"Creates a new Q topic.","ref":"AWS.QuickSight.html#create_topic/4","title":"AWS.QuickSight.create_topic/4","type":"function"},{"doc":"Creates a topic refresh schedule.","ref":"AWS.QuickSight.html#create_topic_refresh_schedule/5","title":"AWS.QuickSight.create_topic_refresh_schedule/5","type":"function"},{"doc":"Creates a new VPC connection.","ref":"AWS.QuickSight.html#create_vpc_connection/4","title":"AWS.QuickSight.create_vpc_connection/4","type":"function"},{"doc":"Deletes all Amazon QuickSight customizations in this Amazon Web Services Region\nfor the specified Amazon Web Services account and Amazon QuickSight namespace.","ref":"AWS.QuickSight.html#delete_account_customization/4","title":"AWS.QuickSight.delete_account_customization/4","type":"function"},{"doc":"Use the `DeleteAccountSubscription` operation to delete an Amazon QuickSight\naccount.\n\nThis operation will result in an error message if you have configured your\naccount termination protection settings to `True`. To change this setting and\ndelete your account, call the `UpdateAccountSettings` API and set the value of\nthe `TerminationProtectionEnabled` parameter to `False`, then make another call\nto the `DeleteAccountSubscription` API.","ref":"AWS.QuickSight.html#delete_account_subscription/4","title":"AWS.QuickSight.delete_account_subscription/4","type":"function"},{"doc":"Deletes an analysis from Amazon QuickSight.\n\nYou can optionally include a recovery window during which you can restore the\nanalysis. If you don't specify a recovery window value, the operation defaults\nto 30 days. Amazon QuickSight attaches a `DeletionTime` stamp to the response\nthat specifies the end of the recovery window. At the end of the recovery\nwindow, Amazon QuickSight deletes the analysis permanently.\n\nAt any time before recovery window ends, you can use the `RestoreAnalysis` API\noperation to remove the `DeletionTime` stamp and cancel the deletion of the\nanalysis. The analysis remains visible in the API until it's deleted, so you can\ndescribe it but you can't make a template from it.\n\nAn analysis that's scheduled for deletion isn't accessible in the Amazon\nQuickSight console. To access it in the console, restore it. Deleting an\nanalysis doesn't delete the dashboards that you publish from it.","ref":"AWS.QuickSight.html#delete_analysis/5","title":"AWS.QuickSight.delete_analysis/5","type":"function"},{"doc":"Deletes a dashboard.","ref":"AWS.QuickSight.html#delete_dashboard/5","title":"AWS.QuickSight.delete_dashboard/5","type":"function"},{"doc":"Deletes a dataset.","ref":"AWS.QuickSight.html#delete_data_set/5","title":"AWS.QuickSight.delete_data_set/5","type":"function"},{"doc":"Deletes the dataset refresh properties of the dataset.","ref":"AWS.QuickSight.html#delete_data_set_refresh_properties/5","title":"AWS.QuickSight.delete_data_set_refresh_properties/5","type":"function"},{"doc":"Deletes the data source permanently.\n\nThis operation breaks all the datasets that reference the deleted data source.","ref":"AWS.QuickSight.html#delete_data_source/5","title":"AWS.QuickSight.delete_data_source/5","type":"function"},{"doc":"Deletes an empty folder.","ref":"AWS.QuickSight.html#delete_folder/5","title":"AWS.QuickSight.delete_folder/5","type":"function"},{"doc":"Removes an asset, such as a dashboard, analysis, or dataset, from a folder.","ref":"AWS.QuickSight.html#delete_folder_membership/7","title":"AWS.QuickSight.delete_folder_membership/7","type":"function"},{"doc":"Removes a user group from Amazon QuickSight.","ref":"AWS.QuickSight.html#delete_group/6","title":"AWS.QuickSight.delete_group/6","type":"function"},{"doc":"Removes a user from a group so that the user is no longer a member of the group.","ref":"AWS.QuickSight.html#delete_group_membership/7","title":"AWS.QuickSight.delete_group_membership/7","type":"function"},{"doc":"Deletes an existing IAM policy assignment.","ref":"AWS.QuickSight.html#delete_iam_policy_assignment/6","title":"AWS.QuickSight.delete_iam_policy_assignment/6","type":"function"},{"doc":"Deletes all access scopes and authorized targets that are associated with a\nservice from the Amazon QuickSight IAM Identity Center application.\n\nThis operation is only supported for Amazon QuickSight accounts that use IAM\nIdentity Center.","ref":"AWS.QuickSight.html#delete_identity_propagation_config/5","title":"AWS.QuickSight.delete_identity_propagation_config/5","type":"function"},{"doc":"Deletes a namespace and the users and groups that are associated with the\nnamespace.\n\nThis is an asynchronous process. Assets including dashboards, analyses, datasets\nand data sources are not deleted. To delete these assets, you use the API\noperations for the relevant asset.","ref":"AWS.QuickSight.html#delete_namespace/5","title":"AWS.QuickSight.delete_namespace/5","type":"function"},{"doc":"Deletes a refresh schedule from a dataset.","ref":"AWS.QuickSight.html#delete_refresh_schedule/6","title":"AWS.QuickSight.delete_refresh_schedule/6","type":"function"},{"doc":"Removes custom permissions from the role.","ref":"AWS.QuickSight.html#delete_role_custom_permission/6","title":"AWS.QuickSight.delete_role_custom_permission/6","type":"function"},{"doc":"Removes a group from a role.","ref":"AWS.QuickSight.html#delete_role_membership/7","title":"AWS.QuickSight.delete_role_membership/7","type":"function"},{"doc":"Deletes a template.","ref":"AWS.QuickSight.html#delete_template/5","title":"AWS.QuickSight.delete_template/5","type":"function"},{"doc":"Deletes the item that the specified template alias points to.\n\nIf you provide a specific alias, you delete the version of the template that the\nalias points to.","ref":"AWS.QuickSight.html#delete_template_alias/6","title":"AWS.QuickSight.delete_template_alias/6","type":"function"},{"doc":"Deletes a theme.","ref":"AWS.QuickSight.html#delete_theme/5","title":"AWS.QuickSight.delete_theme/5","type":"function"},{"doc":"Deletes the version of the theme that the specified theme alias points to.\n\nIf you provide a specific alias, you delete the version of the theme that the\nalias points to.","ref":"AWS.QuickSight.html#delete_theme_alias/6","title":"AWS.QuickSight.delete_theme_alias/6","type":"function"},{"doc":"Deletes a topic.","ref":"AWS.QuickSight.html#delete_topic/5","title":"AWS.QuickSight.delete_topic/5","type":"function"},{"doc":"Deletes a topic refresh schedule.","ref":"AWS.QuickSight.html#delete_topic_refresh_schedule/6","title":"AWS.QuickSight.delete_topic_refresh_schedule/6","type":"function"},{"doc":"Deletes the Amazon QuickSight user that is associated with the identity of the\nIAM user or role that's making the call.\n\nThe IAM user isn't deleted as a result of this call.","ref":"AWS.QuickSight.html#delete_user/6","title":"AWS.QuickSight.delete_user/6","type":"function"},{"doc":"Deletes a user identified by its principal ID.","ref":"AWS.QuickSight.html#delete_user_by_principal_id/6","title":"AWS.QuickSight.delete_user_by_principal_id/6","type":"function"},{"doc":"Deletes a VPC connection.","ref":"AWS.QuickSight.html#delete_vpc_connection/5","title":"AWS.QuickSight.delete_vpc_connection/5","type":"function"},{"doc":"Describes the customizations associated with the provided Amazon Web Services\naccount and Amazon Amazon QuickSight namespace in an Amazon Web Services Region.\n\nThe Amazon QuickSight console evaluates which customizations to apply by running\nthis API operation with the `Resolved` flag included.\n\nTo determine what customizations display when you run this command, it can help\nto visualize the relationship of the entities involved.\n\n  * `Amazon Web Services account` - The Amazon Web Services account\nexists at the top of the hierarchy. It has the potential to use all of the\nAmazon Web Services Regions and Amazon Web Services Services. When you subscribe\nto Amazon QuickSight, you choose one Amazon Web Services Region to use as your\nhome Region. That's where your free SPICE capacity is located. You can use\nAmazon QuickSight in any supported Amazon Web Services Region.\n\n  * `Amazon Web Services Region` - In each Amazon Web Services Region\nwhere you sign in to Amazon QuickSight at least once, Amazon QuickSight acts as\na separate instance of the same service. If you have a user directory, it\nresides in us-east-1, which is the US East (N. Virginia). Generally speaking,\nthese users have access to Amazon QuickSight in any Amazon Web Services Region,\nunless they are constrained to a namespace.\n\nTo run the command in a different Amazon Web Services Region, you change your\nRegion settings. If you're using the CLI, you can use one of the following\noptions:\n\n    * Use [command line options](https://docs.aws.amazon.com/cli/latest/userguide/cli-configure-options.html).\n\n    * Use [named profiles](https://docs.aws.amazon.com/cli/latest/userguide/cli-configure-profiles.html).\n\n    * Run `aws configure` to change your default Amazon Web\nServices Region. Use Enter to key the same settings for your keys. For more\ninformation, see [Configuring the CLI](https://docs.aws.amazon.com/cli/latest/userguide/cli-chap-configure.html).\n\n  * `Namespace` - A QuickSight namespace is a partition that contains\nusers and assets (data sources, datasets, dashboards, and so on). To access\nassets that are in a specific namespace, users and groups must also be part of\nthe same namespace. People who share a namespace are completely isolated from\nusers and assets in other namespaces, even if they are in the same Amazon Web\nServices account and Amazon Web Services Region.\n\n  * `Applied customizations` - Within an Amazon Web Services Region, a\nset of Amazon QuickSight customizations can apply to an Amazon Web Services\naccount or to a namespace. Settings that you apply to a namespace override\nsettings that you apply to an Amazon Web Services account. All settings are\nisolated to a single Amazon Web Services Region. To apply them in other Amazon\nWeb Services Regions, run the `CreateAccountCustomization` command in each\nAmazon Web Services Region where you want to apply the same customizations.","ref":"AWS.QuickSight.html#describe_account_customization/5","title":"AWS.QuickSight.describe_account_customization/5","type":"function"},{"doc":"Describes the settings that were used when your Amazon QuickSight subscription\nwas first created in this Amazon Web Services account.","ref":"AWS.QuickSight.html#describe_account_settings/3","title":"AWS.QuickSight.describe_account_settings/3","type":"function"},{"doc":"Use the DescribeAccountSubscription operation to receive a description of an\nAmazon QuickSight account's subscription.\n\nA successful API call returns an `AccountInfo` object that includes an account's\nname, subscription status, authentication type, edition, and notification email\naddress.","ref":"AWS.QuickSight.html#describe_account_subscription/3","title":"AWS.QuickSight.describe_account_subscription/3","type":"function"},{"doc":"Provides a summary of the metadata for an analysis.","ref":"AWS.QuickSight.html#describe_analysis/4","title":"AWS.QuickSight.describe_analysis/4","type":"function"},{"doc":"Provides a detailed description of the definition of an analysis.\n\nIf you do not need to know details about the content of an Analysis, for\ninstance if you are trying to check the status of a recently created or updated\nAnalysis, use the [ `DescribeAnalysis`\n](https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DescribeAnalysis.html)\ninstead.","ref":"AWS.QuickSight.html#describe_analysis_definition/4","title":"AWS.QuickSight.describe_analysis_definition/4","type":"function"},{"doc":"Provides the read and write permissions for an analysis.","ref":"AWS.QuickSight.html#describe_analysis_permissions/4","title":"AWS.QuickSight.describe_analysis_permissions/4","type":"function"},{"doc":"Describes an existing export job.\n\nPoll job descriptions after a job starts to know the status of the job. When a\njob succeeds, a URL is provided to download the exported assets' data from.\nDownload URLs are valid for five minutes after they are generated. You can call\nthe `DescribeAssetBundleExportJob` API for a new download URL as needed.\n\nJob descriptions are available for 14 days after the job starts.","ref":"AWS.QuickSight.html#describe_asset_bundle_export_job/4","title":"AWS.QuickSight.describe_asset_bundle_export_job/4","type":"function"},{"doc":"Describes an existing import job.\n\nPoll job descriptions after starting a job to know when it has succeeded or\nfailed. Job descriptions are available for 14 days after job starts.","ref":"AWS.QuickSight.html#describe_asset_bundle_import_job/4","title":"AWS.QuickSight.describe_asset_bundle_import_job/4","type":"function"},{"doc":"Provides a summary for a dashboard.","ref":"AWS.QuickSight.html#describe_dashboard/6","title":"AWS.QuickSight.describe_dashboard/6","type":"function"},{"doc":"Provides a detailed description of the definition of a dashboard.\n\nIf you do not need to know details about the content of a dashboard, for\ninstance if you are trying to check the status of a recently created or updated\ndashboard, use the [ `DescribeDashboard`\n](https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DescribeDashboard.html)\ninstead.","ref":"AWS.QuickSight.html#describe_dashboard_definition/6","title":"AWS.QuickSight.describe_dashboard_definition/6","type":"function"},{"doc":"Describes read and write permissions for a dashboard.","ref":"AWS.QuickSight.html#describe_dashboard_permissions/4","title":"AWS.QuickSight.describe_dashboard_permissions/4","type":"function"},{"doc":"Describes an existing snapshot job.\n\nPoll job descriptions after a job starts to know the status of the job. For\ninformation on available status codes, see `JobStatus`.","ref":"AWS.QuickSight.html#describe_dashboard_snapshot_job/5","title":"AWS.QuickSight.describe_dashboard_snapshot_job/5","type":"function"},{"doc":"Describes the result of an existing snapshot job that has finished running.\n\nA finished snapshot job will return a `COMPLETED` or `FAILED` status when you\npoll the job with a `DescribeDashboardSnapshotJob` API call.\n\nIf the job has not finished running, this operation returns a message that says\n`Dashboard Snapshot Job with id   has not reached a terminal\nstate.`.","ref":"AWS.QuickSight.html#describe_dashboard_snapshot_job_result/5","title":"AWS.QuickSight.describe_dashboard_snapshot_job_result/5","type":"function"},{"doc":"Describes a dataset.\n\nThis operation doesn't support datasets that include uploaded files as a source.","ref":"AWS.QuickSight.html#describe_data_set/4","title":"AWS.QuickSight.describe_data_set/4","type":"function"},{"doc":"Describes the permissions on a dataset.\n\nThe permissions resource is\n`arn:aws:quicksight:region:aws-account-id:dataset/data-set-id`.","ref":"AWS.QuickSight.html#describe_data_set_permissions/4","title":"AWS.QuickSight.describe_data_set_permissions/4","type":"function"},{"doc":"Describes the refresh properties of a dataset.","ref":"AWS.QuickSight.html#describe_data_set_refresh_properties/4","title":"AWS.QuickSight.describe_data_set_refresh_properties/4","type":"function"},{"doc":"Describes a data source.","ref":"AWS.QuickSight.html#describe_data_source/4","title":"AWS.QuickSight.describe_data_source/4","type":"function"},{"doc":"Describes the resource permissions for a data source.","ref":"AWS.QuickSight.html#describe_data_source_permissions/4","title":"AWS.QuickSight.describe_data_source_permissions/4","type":"function"},{"doc":"Describes a folder.","ref":"AWS.QuickSight.html#describe_folder/4","title":"AWS.QuickSight.describe_folder/4","type":"function"},{"doc":"Describes permissions for a folder.","ref":"AWS.QuickSight.html#describe_folder_permissions/7","title":"AWS.QuickSight.describe_folder_permissions/7","type":"function"},{"doc":"Describes the folder resolved permissions.\n\nPermissions consists of both folder direct permissions and the inherited\npermissions from the ancestor folders.","ref":"AWS.QuickSight.html#describe_folder_resolved_permissions/7","title":"AWS.QuickSight.describe_folder_resolved_permissions/7","type":"function"},{"doc":"Returns an Amazon QuickSight group's description and Amazon Resource Name (ARN).","ref":"AWS.QuickSight.html#describe_group/5","title":"AWS.QuickSight.describe_group/5","type":"function"},{"doc":"Use the `DescribeGroupMembership` operation to determine if a user is a member\nof the specified group.\n\nIf the user exists and is a member of the specified group, an associated\n`GroupMember` object is returned.","ref":"AWS.QuickSight.html#describe_group_membership/6","title":"AWS.QuickSight.describe_group_membership/6","type":"function"},{"doc":"Describes an existing IAM policy assignment, as specified by the assignment\nname.","ref":"AWS.QuickSight.html#describe_iam_policy_assignment/5","title":"AWS.QuickSight.describe_iam_policy_assignment/5","type":"function"},{"doc":"Describes a SPICE ingestion.","ref":"AWS.QuickSight.html#describe_ingestion/5","title":"AWS.QuickSight.describe_ingestion/5","type":"function"},{"doc":"Provides a summary and status of IP rules.","ref":"AWS.QuickSight.html#describe_ip_restriction/3","title":"AWS.QuickSight.describe_ip_restriction/3","type":"function"},{"doc":"Describes the current namespace.","ref":"AWS.QuickSight.html#describe_namespace/4","title":"AWS.QuickSight.describe_namespace/4","type":"function"},{"doc":"Provides a summary of a refresh schedule.","ref":"AWS.QuickSight.html#describe_refresh_schedule/5","title":"AWS.QuickSight.describe_refresh_schedule/5","type":"function"},{"doc":"Describes all custom permissions that are mapped to a role.","ref":"AWS.QuickSight.html#describe_role_custom_permission/5","title":"AWS.QuickSight.describe_role_custom_permission/5","type":"function"},{"doc":"Describes a template's metadata.","ref":"AWS.QuickSight.html#describe_template/6","title":"AWS.QuickSight.describe_template/6","type":"function"},{"doc":"Describes the template alias for a template.","ref":"AWS.QuickSight.html#describe_template_alias/5","title":"AWS.QuickSight.describe_template_alias/5","type":"function"},{"doc":"Provides a detailed description of the definition of a template.\n\nIf you do not need to know details about the content of a template, for instance\nif you are trying to check the status of a recently created or updated template,\nuse the [ `DescribeTemplate`\n](https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DescribeTemplate.html)\ninstead.","ref":"AWS.QuickSight.html#describe_template_definition/6","title":"AWS.QuickSight.describe_template_definition/6","type":"function"},{"doc":"Describes read and write permissions on a template.","ref":"AWS.QuickSight.html#describe_template_permissions/4","title":"AWS.QuickSight.describe_template_permissions/4","type":"function"},{"doc":"Describes a theme.","ref":"AWS.QuickSight.html#describe_theme/6","title":"AWS.QuickSight.describe_theme/6","type":"function"},{"doc":"Describes the alias for a theme.","ref":"AWS.QuickSight.html#describe_theme_alias/5","title":"AWS.QuickSight.describe_theme_alias/5","type":"function"},{"doc":"Describes the read and write permissions for a theme.","ref":"AWS.QuickSight.html#describe_theme_permissions/4","title":"AWS.QuickSight.describe_theme_permissions/4","type":"function"},{"doc":"Describes a topic.","ref":"AWS.QuickSight.html#describe_topic/4","title":"AWS.QuickSight.describe_topic/4","type":"function"},{"doc":"Describes the permissions of a topic.","ref":"AWS.QuickSight.html#describe_topic_permissions/4","title":"AWS.QuickSight.describe_topic_permissions/4","type":"function"},{"doc":"Describes the status of a topic refresh.","ref":"AWS.QuickSight.html#describe_topic_refresh/5","title":"AWS.QuickSight.describe_topic_refresh/5","type":"function"},{"doc":"Deletes a topic refresh schedule.","ref":"AWS.QuickSight.html#describe_topic_refresh_schedule/5","title":"AWS.QuickSight.describe_topic_refresh_schedule/5","type":"function"},{"doc":"Returns information about a user, given the user name.","ref":"AWS.QuickSight.html#describe_user/5","title":"AWS.QuickSight.describe_user/5","type":"function"},{"doc":"Describes a VPC connection.","ref":"AWS.QuickSight.html#describe_vpc_connection/4","title":"AWS.QuickSight.describe_vpc_connection/4","type":"function"},{"doc":"Generates an embed URL that you can use to embed an Amazon QuickSight dashboard\nor visual in your website, without having to register any reader users.\n\nBefore you use this action, make sure that you have configured the dashboards\nand permissions.\n\nThe following rules apply to the generated URL:\n\n  * It contains a temporary bearer token. It is valid for 5 minutes\nafter it is generated. Once redeemed within this period, it cannot be re-used\nagain.\n\n  * The URL validity period should not be confused with the actual\nsession lifetime that can be customized using the `\n[SessionLifetimeInMinutes](https://docs.aws.amazon.com/quicksight/latest/APIReference/API_GenerateEmbedUrlForAnonymousUser.html#QS-GenerateEmbedUrlForAnonymousUser-request-SessionLifetimeInMinutes) ` parameter. The resulting user session is valid for 15 minutes (minimum) to 10\nhours (maximum). The default session duration is 10 hours.\n\n  * You are charged only when the URL is used or there is interaction\nwith Amazon QuickSight.\n\nFor more information, see [Embedded\nAnalytics](https://docs.aws.amazon.com/quicksight/latest/user/embedded-analytics.html)\nin the *Amazon QuickSight User Guide*.\n\nFor more information about the high-level steps for embedding and for an\ninteractive demo of the ways you can customize embedding, visit the [Amazon QuickSight Developer\nPortal](https://docs.aws.amazon.com/quicksight/latest/user/quicksight-dev-portal.html).","ref":"AWS.QuickSight.html#generate_embed_url_for_anonymous_user/4","title":"AWS.QuickSight.generate_embed_url_for_anonymous_user/4","type":"function"},{"doc":"Generates an embed URL that you can use to embed an Amazon QuickSight experience\nin your website.\n\nThis action can be used for any type of user registered in an Amazon QuickSight\naccount. Before you use this action, make sure that you have configured the\nrelevant Amazon QuickSight resource and permissions.\n\nThe following rules apply to the generated URL:\n\n  * It contains a temporary bearer token. It is valid for 5 minutes\nafter it is generated. Once redeemed within this period, it cannot be re-used\nagain.\n\n  * The URL validity period should not be confused with the actual\nsession lifetime that can be customized using the `\n[SessionLifetimeInMinutes](https://docs.aws.amazon.com/quicksight/latest/APIReference/API_GenerateEmbedUrlForRegisteredUser.html#QS-GenerateEmbedUrlForRegisteredUser-request-SessionLifetimeInMinutes) ` parameter.\n\nThe resulting user session is valid for 15 minutes (minimum) to 10 hours\n(maximum). The default session duration is 10 hours.\n\n  * You are charged only when the URL is used or there is interaction\nwith Amazon QuickSight.\n\nFor more information, see [Embedded\nAnalytics](https://docs.aws.amazon.com/quicksight/latest/user/embedded-analytics.html)\nin the *Amazon QuickSight User Guide*.\n\nFor more information about the high-level steps for embedding and for an\ninteractive demo of the ways you can customize embedding, visit the [Amazon QuickSight Developer\nPortal](https://docs.aws.amazon.com/quicksight/latest/user/quicksight-dev-portal.html).","ref":"AWS.QuickSight.html#generate_embed_url_for_registered_user/4","title":"AWS.QuickSight.generate_embed_url_for_registered_user/4","type":"function"},{"doc":"Generates a temporary session URL and authorization code(bearer token) that you\ncan use to embed an Amazon QuickSight read-only dashboard in your website or\napplication.\n\nBefore you use this command, make sure that you have configured the dashboards\nand permissions.\n\nCurrently, you can use `GetDashboardEmbedURL` only from the server, not from the\nuser's browser. The following rules apply to the generated URL:\n\n  * They must be used together.\n\n  * They can be used one time only.\n\n  * They are valid for 5 minutes after you run this command.\n\n  * You are charged only when the URL is used or there is interaction\nwith Amazon QuickSight.\n\n  * The resulting user session is valid for 15 minutes (default) up to\n10 hours (maximum). You can use the optional `SessionLifetimeInMinutes`\nparameter to customize session duration.\n\nFor more information, see [Embedding Analytics Using GetDashboardEmbedUrl](https://docs.aws.amazon.com/quicksight/latest/user/embedded-analytics-deprecated.html)\nin the *Amazon QuickSight User Guide*.\n\nFor more information about the high-level steps for embedding and for an\ninteractive demo of the ways you can customize embedding, visit the [Amazon QuickSight Developer\nPortal](https://docs.aws.amazon.com/quicksight/latest/user/quicksight-dev-portal.html).","ref":"AWS.QuickSight.html#get_dashboard_embed_url/12","title":"AWS.QuickSight.get_dashboard_embed_url/12","type":"function"},{"doc":"Generates a session URL and authorization code that you can use to embed the\nAmazon Amazon QuickSight console in your web server code.\n\nUse `GetSessionEmbedUrl` where you want to provide an authoring portal that\nallows users to create data sources, datasets, analyses, and dashboards. The\nusers who access an embedded Amazon QuickSight console need belong to the author\nor admin security cohort. If you want to restrict permissions to some of these\nfeatures, add a custom permissions profile to the user with the `\n[UpdateUser](https://docs.aws.amazon.com/quicksight/latest/APIReference/API_UpdateUser.html) ` API operation. Use `\n[RegisterUser](https://docs.aws.amazon.com/quicksight/latest/APIReference/API_RegisterUser.html)\n` API operation to add a new user with a custom permission profile attached. For\nmore information, see the following sections in the *Amazon QuickSight User\nGuide*:\n\n  * [Embedding Analytics](https://docs.aws.amazon.com/quicksight/latest/user/embedded-analytics.html)\n\n  * [Customizing Access to the Amazon QuickSight Console](https://docs.aws.amazon.com/quicksight/latest/user/customizing-permissions-to-the-quicksight-console.html)","ref":"AWS.QuickSight.html#get_session_embed_url/6","title":"AWS.QuickSight.get_session_embed_url/6","type":"function"},{"doc":"Lists Amazon QuickSight analyses that exist in the specified Amazon Web Services\naccount.","ref":"AWS.QuickSight.html#list_analyses/5","title":"AWS.QuickSight.list_analyses/5","type":"function"},{"doc":"Lists all asset bundle export jobs that have been taken place in the last 14\ndays.\n\nJobs created more than 14 days ago are deleted forever and are not returned. If\nyou are using the same job ID for multiple jobs, `ListAssetBundleExportJobs`\nonly returns the most recent job that uses the repeated job ID.","ref":"AWS.QuickSight.html#list_asset_bundle_export_jobs/5","title":"AWS.QuickSight.list_asset_bundle_export_jobs/5","type":"function"},{"doc":"Lists all asset bundle import jobs that have taken place in the last 14 days.\n\nJobs created more than 14 days ago are deleted forever and are not returned. If\nyou are using the same job ID for multiple jobs, `ListAssetBundleImportJobs`\nonly returns the most recent job that uses the repeated job ID.","ref":"AWS.QuickSight.html#list_asset_bundle_import_jobs/5","title":"AWS.QuickSight.list_asset_bundle_import_jobs/5","type":"function"},{"doc":"Lists all the versions of the dashboards in the Amazon QuickSight subscription.","ref":"AWS.QuickSight.html#list_dashboard_versions/6","title":"AWS.QuickSight.list_dashboard_versions/6","type":"function"},{"doc":"Lists dashboards in an Amazon Web Services account.","ref":"AWS.QuickSight.html#list_dashboards/5","title":"AWS.QuickSight.list_dashboards/5","type":"function"},{"doc":"Lists all of the datasets belonging to the current Amazon Web Services account\nin an Amazon Web Services Region.\n\nThe permissions resource is\n`arn:aws:quicksight:region:aws-account-id:dataset/*`.","ref":"AWS.QuickSight.html#list_data_sets/5","title":"AWS.QuickSight.list_data_sets/5","type":"function"},{"doc":"Lists data sources in current Amazon Web Services Region that belong to this\nAmazon Web Services account.","ref":"AWS.QuickSight.html#list_data_sources/5","title":"AWS.QuickSight.list_data_sources/5","type":"function"},{"doc":"List all assets (`DASHBOARD`, `ANALYSIS`, and `DATASET`) in a folder.","ref":"AWS.QuickSight.html#list_folder_members/6","title":"AWS.QuickSight.list_folder_members/6","type":"function"},{"doc":"Lists all folders in an account.","ref":"AWS.QuickSight.html#list_folders/5","title":"AWS.QuickSight.list_folders/5","type":"function"},{"doc":"Lists member users in a group.","ref":"AWS.QuickSight.html#list_group_memberships/7","title":"AWS.QuickSight.list_group_memberships/7","type":"function"},{"doc":"Lists all user groups in Amazon QuickSight.","ref":"AWS.QuickSight.html#list_groups/6","title":"AWS.QuickSight.list_groups/6","type":"function"},{"doc":"Lists the IAM policy assignments in the current Amazon QuickSight account.","ref":"AWS.QuickSight.html#list_iam_policy_assignments/7","title":"AWS.QuickSight.list_iam_policy_assignments/7","type":"function"},{"doc":"Lists all of the IAM policy assignments, including the Amazon Resource Names\n(ARNs), for the IAM policies assigned to the specified user and group, or groups\nthat the user belongs to.","ref":"AWS.QuickSight.html#list_iam_policy_assignments_for_user/7","title":"AWS.QuickSight.list_iam_policy_assignments_for_user/7","type":"function"},{"doc":"Lists all services and authorized targets that the Amazon QuickSight IAM\nIdentity Center application can access.\n\nThis operation is only supported for Amazon QuickSight accounts that use IAM\nIdentity Center.","ref":"AWS.QuickSight.html#list_identity_propagation_configs/5","title":"AWS.QuickSight.list_identity_propagation_configs/5","type":"function"},{"doc":"Lists the history of SPICE ingestions for a dataset.","ref":"AWS.QuickSight.html#list_ingestions/6","title":"AWS.QuickSight.list_ingestions/6","type":"function"},{"doc":"Lists the namespaces for the specified Amazon Web Services account.\n\nThis operation doesn't list deleted namespaces.","ref":"AWS.QuickSight.html#list_namespaces/5","title":"AWS.QuickSight.list_namespaces/5","type":"function"},{"doc":"Lists the refresh schedules of a dataset.\n\nEach dataset can have up to 5 schedules.","ref":"AWS.QuickSight.html#list_refresh_schedules/4","title":"AWS.QuickSight.list_refresh_schedules/4","type":"function"},{"doc":"Lists all groups that are associated with a role.","ref":"AWS.QuickSight.html#list_role_memberships/7","title":"AWS.QuickSight.list_role_memberships/7","type":"function"},{"doc":"Lists the tags assigned to a resource.","ref":"AWS.QuickSight.html#list_tags_for_resource/3","title":"AWS.QuickSight.list_tags_for_resource/3","type":"function"},{"doc":"Lists all the aliases of a template.","ref":"AWS.QuickSight.html#list_template_aliases/6","title":"AWS.QuickSight.list_template_aliases/6","type":"function"},{"doc":"Lists all the versions of the templates in the current Amazon QuickSight\naccount.","ref":"AWS.QuickSight.html#list_template_versions/6","title":"AWS.QuickSight.list_template_versions/6","type":"function"},{"doc":"Lists all the templates in the current Amazon QuickSight account.","ref":"AWS.QuickSight.html#list_templates/5","title":"AWS.QuickSight.list_templates/5","type":"function"},{"doc":"Lists all the aliases of a theme.","ref":"AWS.QuickSight.html#list_theme_aliases/6","title":"AWS.QuickSight.list_theme_aliases/6","type":"function"},{"doc":"Lists all the versions of the themes in the current Amazon Web Services account.","ref":"AWS.QuickSight.html#list_theme_versions/6","title":"AWS.QuickSight.list_theme_versions/6","type":"function"},{"doc":"Lists all the themes in the current Amazon Web Services account.","ref":"AWS.QuickSight.html#list_themes/6","title":"AWS.QuickSight.list_themes/6","type":"function"},{"doc":"Lists all of the refresh schedules for a topic.","ref":"AWS.QuickSight.html#list_topic_refresh_schedules/4","title":"AWS.QuickSight.list_topic_refresh_schedules/4","type":"function"},{"doc":"Lists all of the topics within an account.","ref":"AWS.QuickSight.html#list_topics/5","title":"AWS.QuickSight.list_topics/5","type":"function"},{"doc":"Lists the Amazon QuickSight groups that an Amazon QuickSight user is a member\nof.","ref":"AWS.QuickSight.html#list_user_groups/7","title":"AWS.QuickSight.list_user_groups/7","type":"function"},{"doc":"Returns a list of all of the Amazon QuickSight users belonging to this account.","ref":"AWS.QuickSight.html#list_users/6","title":"AWS.QuickSight.list_users/6","type":"function"},{"doc":"Lists all of the VPC connections in the current set Amazon Web Services Region\nof an Amazon Web Services account.","ref":"AWS.QuickSight.html#list_vpc_connections/5","title":"AWS.QuickSight.list_vpc_connections/5","type":"function"},{"doc":"","ref":"AWS.QuickSight.html#metadata/0","title":"AWS.QuickSight.metadata/0","type":"function"},{"doc":"Creates or updates the dataset refresh properties for the dataset.","ref":"AWS.QuickSight.html#put_data_set_refresh_properties/5","title":"AWS.QuickSight.put_data_set_refresh_properties/5","type":"function"},{"doc":"Creates an Amazon QuickSight user whose identity is associated with the Identity\nand Access Management (IAM) identity or role specified in the request.\n\nWhen you register a new user from the Amazon QuickSight API, Amazon QuickSight\ngenerates a registration URL. The user accesses this registration URL to create\ntheir account. Amazon QuickSight doesn't send a registration email to users who\nare registered from the Amazon QuickSight API. If you want new users to receive\na registration email, then add those users in the Amazon QuickSight console. For\nmore information on registering a new user in the Amazon QuickSight console, see\n[ Inviting users to access Amazon QuickSight](https://docs.aws.amazon.com/quicksight/latest/user/managing-users.html#inviting-users).","ref":"AWS.QuickSight.html#register_user/5","title":"AWS.QuickSight.register_user/5","type":"function"},{"doc":"Restores an analysis.","ref":"AWS.QuickSight.html#restore_analysis/5","title":"AWS.QuickSight.restore_analysis/5","type":"function"},{"doc":"Searches for analyses that belong to the user specified in the filter.\n\nThis operation is eventually consistent. The results are best effort and may not\nreflect very recent updates and changes.","ref":"AWS.QuickSight.html#search_analyses/4","title":"AWS.QuickSight.search_analyses/4","type":"function"},{"doc":"Searches for dashboards that belong to a user.\n\nThis operation is eventually consistent. The results are best effort and may not\nreflect very recent updates and changes.","ref":"AWS.QuickSight.html#search_dashboards/4","title":"AWS.QuickSight.search_dashboards/4","type":"function"},{"doc":"Use the `SearchDataSets` operation to search for datasets that belong to an\naccount.","ref":"AWS.QuickSight.html#search_data_sets/4","title":"AWS.QuickSight.search_data_sets/4","type":"function"},{"doc":"Use the `SearchDataSources` operation to search for data sources that belong to\nan account.","ref":"AWS.QuickSight.html#search_data_sources/4","title":"AWS.QuickSight.search_data_sources/4","type":"function"},{"doc":"Searches the subfolders in a folder.","ref":"AWS.QuickSight.html#search_folders/4","title":"AWS.QuickSight.search_folders/4","type":"function"},{"doc":"Use the `SearchGroups` operation to search groups in a specified Amazon\nQuickSight namespace using the supplied filters.","ref":"AWS.QuickSight.html#search_groups/5","title":"AWS.QuickSight.search_groups/5","type":"function"},{"doc":"Starts an Asset Bundle export job.\n\nAn Asset Bundle export job exports specified Amazon QuickSight assets. You can\nalso choose to export any asset dependencies in the same job. Export jobs run\nasynchronously and can be polled with a `DescribeAssetBundleExportJob` API call.\nWhen a job is successfully completed, a download URL that contains the exported\nassets is returned. The URL is valid for 5 minutes and can be refreshed with a\n`DescribeAssetBundleExportJob` API call. Each Amazon QuickSight account can run\nup to 5 export jobs concurrently.\n\nThe API caller must have the necessary permissions in their IAM role to access\neach resource before the resources can be exported.","ref":"AWS.QuickSight.html#start_asset_bundle_export_job/4","title":"AWS.QuickSight.start_asset_bundle_export_job/4","type":"function"},{"doc":"Starts an Asset Bundle import job.\n\nAn Asset Bundle import job imports specified Amazon QuickSight assets into an\nAmazon QuickSight account. You can also choose to import a naming prefix and\nspecified configuration overrides. The assets that are contained in the bundle\nfile that you provide are used to create or update a new or existing asset in\nyour Amazon QuickSight account. Each Amazon QuickSight account can run up to 5\nimport jobs concurrently.\n\nThe API caller must have the necessary `\"create\"`, `\"describe\"`, and `\"update\"`\npermissions in their IAM role to access each resource type that is contained in\nthe bundle file before the resources can be imported.","ref":"AWS.QuickSight.html#start_asset_bundle_import_job/4","title":"AWS.QuickSight.start_asset_bundle_import_job/4","type":"function"},{"doc":"Starts an asynchronous job that generates a dashboard snapshot.\n\nYou can request one of the following format configurations per API call.\n\n  * 1 paginated PDF\n\n  * 1 Excel workbook\n\n  * 5 CSVs\n\nPoll job descriptions with a `DescribeDashboardSnapshotJob` API call. Once the\njob succeeds, use the `DescribeDashboardSnapshotJobResult` API to obtain the\ndownload URIs that the job generates.","ref":"AWS.QuickSight.html#start_dashboard_snapshot_job/5","title":"AWS.QuickSight.start_dashboard_snapshot_job/5","type":"function"},{"doc":"Assigns one or more tags (key-value pairs) to the specified Amazon QuickSight\nresource.\n\nTags can help you organize and categorize your resources. You can also use them\nto scope user permissions, by granting a user permission to access or change\nonly resources with certain tag values. You can use the `TagResource` operation\nwith a resource that already has tags. If you specify a new tag key for the\nresource, this tag is appended to the list of tags associated with the resource.\nIf you specify a tag key that is already associated with the resource, the new\ntag value that you specify replaces the previous value for that tag.\n\nYou can associate as many as 50 tags with a resource. Amazon QuickSight supports\ntagging on data set, data source, dashboard, template, topic, and user.\n\nTagging for Amazon QuickSight works in a similar way to tagging for other Amazon\nWeb Services services, except for the following:\n\n  * Tags are used to track costs for users in Amazon QuickSight. You\ncan't tag other resources that Amazon QuickSight costs are based on, such as\nstorage capacoty (SPICE), session usage, alert consumption, or reporting units.\n\n  * Amazon QuickSight doesn't currently support the tag editor for\nResource Groups.","ref":"AWS.QuickSight.html#tag_resource/4","title":"AWS.QuickSight.tag_resource/4","type":"function"},{"doc":"Removes a tag or tags from a resource.","ref":"AWS.QuickSight.html#untag_resource/4","title":"AWS.QuickSight.untag_resource/4","type":"function"},{"doc":"Updates Amazon QuickSight customizations for the current Amazon Web Services\nRegion.\n\nCurrently, the only customization that you can use is a theme.\n\nYou can use customizations for your Amazon Web Services account or, if you\nspecify a namespace, for a Amazon QuickSight namespace instead. Customizations\nthat apply to a namespace override customizations that apply to an Amazon Web\nServices account. To find out which customizations apply, use the\n`DescribeAccountCustomization` API operation.","ref":"AWS.QuickSight.html#update_account_customization/4","title":"AWS.QuickSight.update_account_customization/4","type":"function"},{"doc":"Updates the Amazon QuickSight settings in your Amazon Web Services account.","ref":"AWS.QuickSight.html#update_account_settings/4","title":"AWS.QuickSight.update_account_settings/4","type":"function"},{"doc":"Updates an analysis in Amazon QuickSight","ref":"AWS.QuickSight.html#update_analysis/5","title":"AWS.QuickSight.update_analysis/5","type":"function"},{"doc":"Updates the read and write permissions for an analysis.","ref":"AWS.QuickSight.html#update_analysis_permissions/5","title":"AWS.QuickSight.update_analysis_permissions/5","type":"function"},{"doc":"Updates a dashboard in an Amazon Web Services account.\n\nUpdating a Dashboard creates a new dashboard version but does not immediately\npublish the new version. You can update the published version of a dashboard by\nusing the `\n[UpdateDashboardPublishedVersion](https://docs.aws.amazon.com/quicksight/latest/APIReference/API_UpdateDashboardPublishedVersion.html)\n` API operation.","ref":"AWS.QuickSight.html#update_dashboard/5","title":"AWS.QuickSight.update_dashboard/5","type":"function"},{"doc":"Updates the linked analyses on a dashboard.","ref":"AWS.QuickSight.html#update_dashboard_links/5","title":"AWS.QuickSight.update_dashboard_links/5","type":"function"},{"doc":"Updates read and write permissions on a dashboard.","ref":"AWS.QuickSight.html#update_dashboard_permissions/5","title":"AWS.QuickSight.update_dashboard_permissions/5","type":"function"},{"doc":"Updates the published version of a dashboard.","ref":"AWS.QuickSight.html#update_dashboard_published_version/6","title":"AWS.QuickSight.update_dashboard_published_version/6","type":"function"},{"doc":"Updates a dataset.\n\nThis operation doesn't support datasets that include uploaded files as a source.\nPartial updates are not supported by this operation.","ref":"AWS.QuickSight.html#update_data_set/5","title":"AWS.QuickSight.update_data_set/5","type":"function"},{"doc":"Updates the permissions on a dataset.\n\nThe permissions resource is\n`arn:aws:quicksight:region:aws-account-id:dataset/data-set-id`.","ref":"AWS.QuickSight.html#update_data_set_permissions/5","title":"AWS.QuickSight.update_data_set_permissions/5","type":"function"},{"doc":"Updates a data source.","ref":"AWS.QuickSight.html#update_data_source/5","title":"AWS.QuickSight.update_data_source/5","type":"function"},{"doc":"Updates the permissions to a data source.","ref":"AWS.QuickSight.html#update_data_source_permissions/5","title":"AWS.QuickSight.update_data_source_permissions/5","type":"function"},{"doc":"Updates the name of a folder.","ref":"AWS.QuickSight.html#update_folder/5","title":"AWS.QuickSight.update_folder/5","type":"function"},{"doc":"Updates permissions of a folder.","ref":"AWS.QuickSight.html#update_folder_permissions/5","title":"AWS.QuickSight.update_folder_permissions/5","type":"function"},{"doc":"Changes a group description.","ref":"AWS.QuickSight.html#update_group/6","title":"AWS.QuickSight.update_group/6","type":"function"},{"doc":"Updates an existing IAM policy assignment.\n\nThis operation updates only the optional parameter or parameters that are\nspecified in the request. This overwrites all of the users included in\n`Identities`.","ref":"AWS.QuickSight.html#update_iam_policy_assignment/6","title":"AWS.QuickSight.update_iam_policy_assignment/6","type":"function"},{"doc":"Adds or updates services and authorized targets to configure what the Amazon\nQuickSight IAM Identity Center application can access.\n\nThis operation is only supported for Amazon QuickSight accounts using IAM\nIdentity Center","ref":"AWS.QuickSight.html#update_identity_propagation_config/5","title":"AWS.QuickSight.update_identity_propagation_config/5","type":"function"},{"doc":"Updates the content and status of IP rules.\n\nTo use this operation, you must provide the entire map of rules. You can use the\n`DescribeIpRestriction` operation to get the current rule map.","ref":"AWS.QuickSight.html#update_ip_restriction/4","title":"AWS.QuickSight.update_ip_restriction/4","type":"function"},{"doc":"Use the `UpdatePublicSharingSettings` operation to turn on or turn off the\npublic sharing settings of an Amazon QuickSight dashboard.\n\nTo use this operation, turn on session capacity pricing for your Amazon\nQuickSight account.\n\nBefore you can turn on public sharing on your account, make sure to give public\nsharing permissions to an administrative user in the Identity and Access\nManagement (IAM) console. For more information on using IAM with Amazon\nQuickSight, see [Using Amazon QuickSight with IAM](https://docs.aws.amazon.com/quicksight/latest/user/security_iam_service-with-iam.html)\nin the *Amazon QuickSight User Guide*.","ref":"AWS.QuickSight.html#update_public_sharing_settings/4","title":"AWS.QuickSight.update_public_sharing_settings/4","type":"function"},{"doc":"Updates a refresh schedule for a dataset.","ref":"AWS.QuickSight.html#update_refresh_schedule/5","title":"AWS.QuickSight.update_refresh_schedule/5","type":"function"},{"doc":"Updates the custom permissions that are associated with a role.","ref":"AWS.QuickSight.html#update_role_custom_permission/6","title":"AWS.QuickSight.update_role_custom_permission/6","type":"function"},{"doc":"Updates a template from an existing Amazon QuickSight analysis or another\ntemplate.","ref":"AWS.QuickSight.html#update_template/5","title":"AWS.QuickSight.update_template/5","type":"function"},{"doc":"Updates the template alias of a template.","ref":"AWS.QuickSight.html#update_template_alias/6","title":"AWS.QuickSight.update_template_alias/6","type":"function"},{"doc":"Updates the resource permissions for a template.","ref":"AWS.QuickSight.html#update_template_permissions/5","title":"AWS.QuickSight.update_template_permissions/5","type":"function"},{"doc":"Updates a theme.","ref":"AWS.QuickSight.html#update_theme/5","title":"AWS.QuickSight.update_theme/5","type":"function"},{"doc":"Updates an alias of a theme.","ref":"AWS.QuickSight.html#update_theme_alias/6","title":"AWS.QuickSight.update_theme_alias/6","type":"function"},{"doc":"Updates the resource permissions for a theme.\n\nPermissions apply to the action to grant or revoke permissions on, for example\n`\"quicksight:DescribeTheme\"`.\n\nTheme permissions apply in groupings. Valid groupings include the following for\nthe three levels of permissions, which are user, owner, or no permissions:\n\n  * User\n\n    * `\"quicksight:DescribeTheme\"`\n\n    * `\"quicksight:DescribeThemeAlias\"`\n\n    * `\"quicksight:ListThemeAliases\"`\n\n    * `\"quicksight:ListThemeVersions\"`\n\n  * Owner\n\n    * `\"quicksight:DescribeTheme\"`\n\n    * `\"quicksight:DescribeThemeAlias\"`\n\n    * `\"quicksight:ListThemeAliases\"`\n\n    * `\"quicksight:ListThemeVersions\"`\n\n    * `\"quicksight:DeleteTheme\"`\n\n    * `\"quicksight:UpdateTheme\"`\n\n    * `\"quicksight:CreateThemeAlias\"`\n\n    * `\"quicksight:DeleteThemeAlias\"`\n\n    * `\"quicksight:UpdateThemeAlias\"`\n\n    * `\"quicksight:UpdateThemePermissions\"`\n\n    * `\"quicksight:DescribeThemePermissions\"`\n\n  * To specify no permissions, omit the permissions list.","ref":"AWS.QuickSight.html#update_theme_permissions/5","title":"AWS.QuickSight.update_theme_permissions/5","type":"function"},{"doc":"Updates a topic.","ref":"AWS.QuickSight.html#update_topic/5","title":"AWS.QuickSight.update_topic/5","type":"function"},{"doc":"Updates the permissions of a topic.","ref":"AWS.QuickSight.html#update_topic_permissions/5","title":"AWS.QuickSight.update_topic_permissions/5","type":"function"},{"doc":"Updates a topic refresh schedule.","ref":"AWS.QuickSight.html#update_topic_refresh_schedule/6","title":"AWS.QuickSight.update_topic_refresh_schedule/6","type":"function"},{"doc":"Updates an Amazon QuickSight user.","ref":"AWS.QuickSight.html#update_user/6","title":"AWS.QuickSight.update_user/6","type":"function"},{"doc":"Updates a VPC connection.","ref":"AWS.QuickSight.html#update_vpc_connection/5","title":"AWS.QuickSight.update_vpc_connection/5","type":"function"},{"doc":"This is the *Resource Access Manager API Reference*.\n\nThis documentation provides descriptions and syntax for each of the actions and\ndata types in RAM. RAM is a service that helps you securely share your Amazon\nWeb Services resources to other Amazon Web Services accounts. If you use\nOrganizations to manage your accounts, then you can share your resources with\nyour entire organization or to organizational units (OUs). For supported\nresource types, you can also share resources with individual Identity and Access\nManagement (IAM) roles and users.\n\nTo learn more about RAM, see the following resources:\n\n  * [Resource Access Manager product page](http://aws.amazon.com/ram)     * [Resource Access Manager User\nGuide](https://docs.aws.amazon.com/ram/latest/userguide/)","ref":"AWS.RAM.html","title":"AWS.RAM","type":"module"},{"doc":"Accepts an invitation to a resource share from another Amazon Web Services\naccount.\n\nAfter you accept the invitation, the resources included in the resource share\nare available to interact with in the relevant Amazon Web Services Management\nConsoles and tools.","ref":"AWS.RAM.html#accept_resource_share_invitation/3","title":"AWS.RAM.accept_resource_share_invitation/3","type":"function"},{"doc":"Adds the specified list of principals and list of resources to a resource share.\n\nPrincipals that already have access to this resource share immediately receive\naccess to the added resources. Newly added principals immediately receive access\nto the resources shared in this resource share.","ref":"AWS.RAM.html#associate_resource_share/3","title":"AWS.RAM.associate_resource_share/3","type":"function"},{"doc":"Adds or replaces the RAM permission for a resource type included in a resource\nshare.\n\nYou can have exactly one permission associated with each resource type in the\nresource share. You can add a new RAM permission only if there are currently no\nresources of that resource type currently in the resource share.","ref":"AWS.RAM.html#associate_resource_share_permission/3","title":"AWS.RAM.associate_resource_share_permission/3","type":"function"},{"doc":"Creates a customer managed permission for a specified resource type that you can\nattach to resource shares.\n\nIt is created in the Amazon Web Services Region in which you call the operation.","ref":"AWS.RAM.html#create_permission/3","title":"AWS.RAM.create_permission/3","type":"function"},{"doc":"Creates a new version of the specified customer managed permission.\n\nThe new version is automatically set as the default version of the customer\nmanaged permission. New resource shares automatically use the default\npermission. Existing resource shares continue to use their original permission\nversions, but you can use `ReplacePermissionAssociations` to update them.\n\nIf the specified customer managed permission already has the maximum of 5\nversions, then you must delete one of the existing versions before you can\ncreate a new one.","ref":"AWS.RAM.html#create_permission_version/3","title":"AWS.RAM.create_permission_version/3","type":"function"},{"doc":"Creates a resource share.\n\nYou can provide a list of the [Amazon Resource Names (ARNs)](https://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html)\nfor the resources that you want to share, a list of principals you want to share\nthe resources with, and the permissions to grant those principals.\n\nSharing a resource makes it available for use by principals outside of the\nAmazon Web Services account that created the resource. Sharing doesn't change\nany permissions or quotas that apply to the resource in the account that created\nit.","ref":"AWS.RAM.html#create_resource_share/3","title":"AWS.RAM.create_resource_share/3","type":"function"},{"doc":"Deletes the specified customer managed permission in the Amazon Web Services\nRegion in which you call this operation.\n\nYou can delete a customer managed permission only if it isn't attached to any\nresource share. The operation deletes all versions associated with the customer\nmanaged permission.","ref":"AWS.RAM.html#delete_permission/3","title":"AWS.RAM.delete_permission/3","type":"function"},{"doc":"Deletes one version of a customer managed permission.\n\nThe version you specify must not be attached to any resource share and must not\nbe the default version for the permission.\n\nIf a customer managed permission has the maximum of 5 versions, then you must\ndelete at least one version before you can create another.","ref":"AWS.RAM.html#delete_permission_version/3","title":"AWS.RAM.delete_permission_version/3","type":"function"},{"doc":"Deletes the specified resource share.\n\nThis doesn't delete any of the resources that were associated with the resource\nshare; it only stops the sharing of those resources through this resource share.","ref":"AWS.RAM.html#delete_resource_share/3","title":"AWS.RAM.delete_resource_share/3","type":"function"},{"doc":"Removes the specified principals or resources from participating in the\nspecified resource share.","ref":"AWS.RAM.html#disassociate_resource_share/3","title":"AWS.RAM.disassociate_resource_share/3","type":"function"},{"doc":"Removes a managed permission from a resource share.\n\nPermission changes take effect immediately. You can remove a managed permission\nfrom a resource share only if there are currently no resources of the relevant\nresource type currently attached to the resource share.","ref":"AWS.RAM.html#disassociate_resource_share_permission/3","title":"AWS.RAM.disassociate_resource_share_permission/3","type":"function"},{"doc":"Enables resource sharing within your organization in Organizations.\n\nThis operation creates a service-linked role called\n`AWSServiceRoleForResourceAccessManager` that has the IAM managed policy named\nAWSResourceAccessManagerServiceRolePolicy attached. This role permits RAM to\nretrieve information about the organization and its structure. This lets you\nshare resources with all of the accounts in the calling account's organization\nby specifying the organization ID, or all of the accounts in an organizational\nunit (OU) by specifying the OU ID. Until you enable sharing within the\norganization, you can specify only individual Amazon Web Services accounts, or\nfor supported resource types, IAM roles and users.\n\nYou must call this operation from an IAM role or user in the organization's\nmanagement account.","ref":"AWS.RAM.html#enable_sharing_with_aws_organization/3","title":"AWS.RAM.enable_sharing_with_aws_organization/3","type":"function"},{"doc":"Retrieves the contents of a managed permission in JSON format.","ref":"AWS.RAM.html#get_permission/3","title":"AWS.RAM.get_permission/3","type":"function"},{"doc":"Retrieves the resource policies for the specified resources that you own and\nhave shared.","ref":"AWS.RAM.html#get_resource_policies/3","title":"AWS.RAM.get_resource_policies/3","type":"function"},{"doc":"Retrieves the lists of resources and principals that associated for resource\nshares that you own.","ref":"AWS.RAM.html#get_resource_share_associations/3","title":"AWS.RAM.get_resource_share_associations/3","type":"function"},{"doc":"Retrieves details about invitations that you have received for resource shares.","ref":"AWS.RAM.html#get_resource_share_invitations/3","title":"AWS.RAM.get_resource_share_invitations/3","type":"function"},{"doc":"Retrieves details about the resource shares that you own or that are shared with\nyou.","ref":"AWS.RAM.html#get_resource_shares/3","title":"AWS.RAM.get_resource_shares/3","type":"function"},{"doc":"Lists the resources in a resource share that is shared with you but for which\nthe invitation is still `PENDING`.\n\nThat means that you haven't accepted or rejected the invitation and the\ninvitation hasn't expired.","ref":"AWS.RAM.html#list_pending_invitation_resources/3","title":"AWS.RAM.list_pending_invitation_resources/3","type":"function"},{"doc":"Lists information about the managed permission and its associations to any\nresource shares that use this managed permission.\n\nThis lets you see which resource shares use which versions of the specified\nmanaged permission.","ref":"AWS.RAM.html#list_permission_associations/3","title":"AWS.RAM.list_permission_associations/3","type":"function"},{"doc":"Lists the available versions of the specified RAM permission.","ref":"AWS.RAM.html#list_permission_versions/3","title":"AWS.RAM.list_permission_versions/3","type":"function"},{"doc":"Retrieves a list of available RAM permissions that you can use for the supported\nresource types.","ref":"AWS.RAM.html#list_permissions/3","title":"AWS.RAM.list_permissions/3","type":"function"},{"doc":"Lists the principals that you are sharing resources with or that are sharing\nresources with you.","ref":"AWS.RAM.html#list_principals/3","title":"AWS.RAM.list_principals/3","type":"function"},{"doc":"Retrieves the current status of the asynchronous tasks performed by RAM when you\nperform the `ReplacePermissionAssociationsWork` operation.","ref":"AWS.RAM.html#list_replace_permission_associations_work/3","title":"AWS.RAM.list_replace_permission_associations_work/3","type":"function"},{"doc":"Lists the RAM permissions that are associated with a resource share.","ref":"AWS.RAM.html#list_resource_share_permissions/3","title":"AWS.RAM.list_resource_share_permissions/3","type":"function"},{"doc":"Lists the resource types that can be shared by RAM.","ref":"AWS.RAM.html#list_resource_types/3","title":"AWS.RAM.list_resource_types/3","type":"function"},{"doc":"Lists the resources that you added to a resource share or the resources that are\nshared with you.","ref":"AWS.RAM.html#list_resources/3","title":"AWS.RAM.list_resources/3","type":"function"},{"doc":"","ref":"AWS.RAM.html#metadata/0","title":"AWS.RAM.metadata/0","type":"function"},{"doc":"When you attach a resource-based policy to a resource, RAM automatically creates\na resource share of `featureSet`=`CREATED_FROM_POLICY` with a managed permission\nthat has the same IAM permissions as the original resource-based policy.\n\nHowever, this type of managed permission is visible to only the resource share\nowner, and the associated resource share can't be modified by using RAM.\n\nThis operation creates a separate, fully manageable customer managed permission\nthat has the same IAM permissions as the original resource-based policy. You can\nassociate this customer managed permission to any resource shares.\n\nBefore you use `PromoteResourceShareCreatedFromPolicy`, you should first run\nthis operation to ensure that you have an appropriate customer managed\npermission that can be associated with the promoted resource share.\n\n   The original `CREATED_FROM_POLICY` policy isn't deleted, and\nresource shares using that original policy aren't automatically updated.\n\n   You can't modify a `CREATED_FROM_POLICY` resource share so you\ncan't associate the new customer managed permission by using\n`ReplacePermsissionAssociations`. However, if you use\n`PromoteResourceShareCreatedFromPolicy`, that operation automatically associates\nthe fully manageable customer managed permission to the newly promoted\n`STANDARD` resource share.\n\n   After you promote a resource share, if the original\n`CREATED_FROM_POLICY` managed permission has no other associations to A resource\nshare, then RAM automatically deletes it.","ref":"AWS.RAM.html#promote_permission_created_from_policy/3","title":"AWS.RAM.promote_permission_created_from_policy/3","type":"function"},{"doc":"When you attach a resource-based policy to a resource, RAM automatically creates\na resource share of `featureSet`=`CREATED_FROM_POLICY` with a managed permission\nthat has the same IAM permissions as the original resource-based policy.\n\nHowever, this type of managed permission is visible to only the resource share\nowner, and the associated resource share can't be modified by using RAM.\n\nThis operation promotes the resource share to a `STANDARD` resource share that\nis fully manageable in RAM. When you promote a resource share, you can then\nmanage the resource share in RAM and it becomes visible to all of the principals\nyou shared it with.\n\nBefore you perform this operation, you should first run\n`PromotePermissionCreatedFromPolicy`to ensure that you have an appropriate\ncustomer managed permission that can be associated with this resource share\nafter its is promoted. If this operation can't find a managed permission that\nexactly matches the existing `CREATED_FROM_POLICY` permission, then this\noperation fails.","ref":"AWS.RAM.html#promote_resource_share_created_from_policy/3","title":"AWS.RAM.promote_resource_share_created_from_policy/3","type":"function"},{"doc":"Rejects an invitation to a resource share from another Amazon Web Services\naccount.","ref":"AWS.RAM.html#reject_resource_share_invitation/3","title":"AWS.RAM.reject_resource_share_invitation/3","type":"function"},{"doc":"Updates all resource shares that use a managed permission to a different managed\npermission.\n\nThis operation always applies the default version of the target managed\npermission. You can optionally specify that the update applies to only resource\nshares that currently use a specified version. This enables you to update to the\nlatest version, without changing the which managed permission is used.\n\nYou can use this operation to update all of your resource shares to use the\ncurrent default version of the permission by specifying the same value for the\n`fromPermissionArn` and `toPermissionArn` parameters.\n\nYou can use the optional `fromPermissionVersion` parameter to update only those\nresources that use a specified version of the managed permission to the new\nmanaged permission.\n\nTo successfully perform this operation, you must have permission to update the\nresource-based policy on all affected resource types.","ref":"AWS.RAM.html#replace_permission_associations/3","title":"AWS.RAM.replace_permission_associations/3","type":"function"},{"doc":"Designates the specified version number as the default version for the specified\ncustomer managed permission.\n\nNew resource shares automatically use this new default permission. Existing\nresource shares continue to use their original permission version, but you can\nuse `ReplacePermissionAssociations` to update them.","ref":"AWS.RAM.html#set_default_permission_version/3","title":"AWS.RAM.set_default_permission_version/3","type":"function"},{"doc":"Adds the specified tag keys and values to a resource share or managed\npermission.\n\nIf you choose a resource share, the tags are attached to only the resource\nshare, not to the resources that are in the resource share.\n\nThe tags on a managed permission are the same for all versions of the managed\npermission.","ref":"AWS.RAM.html#tag_resource/3","title":"AWS.RAM.tag_resource/3","type":"function"},{"doc":"Removes the specified tag key and value pairs from the specified resource share\nor managed permission.","ref":"AWS.RAM.html#untag_resource/3","title":"AWS.RAM.untag_resource/3","type":"function"},{"doc":"Modifies some of the properties of the specified resource share.","ref":"AWS.RAM.html#update_resource_share/3","title":"AWS.RAM.update_resource_share/3","type":"function"},{"doc":"Amazon Relational Database Service\n\nAmazon Relational Database Service (Amazon RDS) is a web service that makes it\neasier to set up, operate, and scale a relational database in the cloud.\n\nIt provides cost-efficient, resizeable capacity for an industry-standard\nrelational database and manages common database administration tasks, freeing up\ndevelopers to focus on what makes their applications and businesses unique.\n\nAmazon RDS gives you access to the capabilities of a MySQL, MariaDB, PostgreSQL,\nMicrosoft SQL Server, Oracle, Db2, or Amazon Aurora database server. These\ncapabilities mean that the code, applications, and tools you already use today\nwith your existing databases work with Amazon RDS without modification. Amazon\nRDS automatically backs up your database and maintains the database software\nthat powers your DB instance. Amazon RDS is flexible: you can scale your DB\ninstance's compute resources and storage capacity to meet your application's\ndemand. As with all Amazon Web Services, there are no up-front investments, and\nyou pay only for the resources you use.\n\nThis interface reference for Amazon RDS contains documentation for a programming\nor command line interface you can use to manage Amazon RDS. Amazon RDS is\nasynchronous, which means that some interfaces might require techniques such as\npolling or callback functions to determine when a command has been applied. In\nthis reference, the parameter descriptions indicate whether a command is applied\nimmediately, on the next instance reboot, or during the maintenance window. The\nreference structure is as follows, and we list following some related topics\nfrom the user guide.","ref":"AWS.RDS.html","title":"AWS.RDS","type":"module"},{"doc":"* For the alphabetical list of API actions, see [API Actions](https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_Operations.html).\n\n  * For the alphabetical list of data types, see [Data Types](https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_Types.html).\n\n  * For a list of common query parameters, see [Common Parameters](https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/CommonParameters.html).\n\n  * For descriptions of the error codes, see [Common Errors](https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/CommonErrors.html).","ref":"AWS.RDS.html#module-amazon-rds-api-reference","title":"Amazon RDS API Reference - AWS.RDS","type":"module"},{"doc":"* For a summary of the Amazon RDS interfaces, see [Available RDS Interfaces](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/Welcome.html#Welcome.Interfaces).\n\n  * For more information about how to use the Query API, see [Using the Query\nAPI](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/Using_the_Query_API.html).","ref":"AWS.RDS.html#module-amazon-rds-user-guide","title":"Amazon RDS User Guide - AWS.RDS","type":"module"},{"doc":"Associates an Identity and Access Management (IAM) role with a DB cluster.","ref":"AWS.RDS.html#add_role_to_db_cluster/3","title":"AWS.RDS.add_role_to_db_cluster/3","type":"function"},{"doc":"Associates an Amazon Web Services Identity and Access Management (IAM) role with\na DB instance.\n\nTo add a role to a DB instance, the status of the DB instance must be\n`available`.\n\nThis command doesn't apply to RDS Custom.","ref":"AWS.RDS.html#add_role_to_db_instance/3","title":"AWS.RDS.add_role_to_db_instance/3","type":"function"},{"doc":"Adds a source identifier to an existing RDS event notification subscription.","ref":"AWS.RDS.html#add_source_identifier_to_subscription/3","title":"AWS.RDS.add_source_identifier_to_subscription/3","type":"function"},{"doc":"Adds metadata tags to an Amazon RDS resource.\n\nThese tags can also be used with cost allocation reporting to track cost\nassociated with Amazon RDS resources, or used in a Condition statement in an IAM\npolicy for Amazon RDS.\n\nFor an overview on tagging Amazon RDS resources, see [Tagging Amazon RDS Resources](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/Overview.Tagging.html).","ref":"AWS.RDS.html#add_tags_to_resource/3","title":"AWS.RDS.add_tags_to_resource/3","type":"function"},{"doc":"Applies a pending maintenance action to a resource (for example, to a DB\ninstance).","ref":"AWS.RDS.html#apply_pending_maintenance_action/3","title":"AWS.RDS.apply_pending_maintenance_action/3","type":"function"},{"doc":"Enables ingress to a DBSecurityGroup using one of two forms of authorization.\n\nFirst, EC2 or VPC security groups can be added to the DBSecurityGroup if the\napplication using the database is running on EC2 or VPC instances. Second, IP\nranges are available if the application accessing your database is running on\nthe internet. Required parameters for this API are one of CIDR range,\nEC2SecurityGroupId for VPC, or (EC2SecurityGroupOwnerId and either\nEC2SecurityGroupName or EC2SecurityGroupId for non-VPC).\n\nYou can't authorize ingress from an EC2 security group in one Amazon Web\nServices Region to an Amazon RDS DB instance in another. You can't authorize\ningress from a VPC security group in one VPC to an Amazon RDS DB instance in\nanother.\n\nFor an overview of CIDR ranges, go to the [Wikipedia Tutorial](http://en.wikipedia.org/wiki/Classless_Inter-Domain_Routing).\n\nEC2-Classic was retired on August 15, 2022. If you haven't migrated from\nEC2-Classic to a VPC, we recommend that you migrate as soon as possible. For\nmore information, see [Migrate from EC2-Classic to a VPC](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/vpc-migrate.html) in\nthe *Amazon EC2 User Guide*, the blog [EC2-Classic Networking is Retiring – Here’s How to\nPrepare](http://aws.amazon.com/blogs/aws/ec2-classic-is-retiring-heres-how-to-prepare/),\nand [Moving a DB instance not in a VPC into a VPC](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_VPC.Non-VPC2VPC.html)\nin the *Amazon RDS User Guide*.","ref":"AWS.RDS.html#authorize_db_security_group_ingress/3","title":"AWS.RDS.authorize_db_security_group_ingress/3","type":"function"},{"doc":"Backtracks a DB cluster to a specific time, without creating a new DB cluster.\n\nFor more information on backtracking, see [ Backtracking an Aurora DB Cluster](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/AuroraMySQL.Managing.Backtrack.html)\nin the *Amazon Aurora User Guide*.\n\nThis action applies only to Aurora MySQL DB clusters.","ref":"AWS.RDS.html#backtrack_db_cluster/3","title":"AWS.RDS.backtrack_db_cluster/3","type":"function"},{"doc":"Cancels an export task in progress that is exporting a snapshot or cluster to\nAmazon S3.\n\nAny data that has already been written to the S3 bucket isn't removed.","ref":"AWS.RDS.html#cancel_export_task/3","title":"AWS.RDS.cancel_export_task/3","type":"function"},{"doc":"Copies the specified DB cluster parameter group.\n\nYou can't copy a default DB cluster parameter group. Instead, create a new\ncustom DB cluster parameter group, which copies the default parameters and\nvalues for the specified DB cluster parameter group family.","ref":"AWS.RDS.html#copy_db_cluster_parameter_group/3","title":"AWS.RDS.copy_db_cluster_parameter_group/3","type":"function"},{"doc":"Copies a snapshot of a DB cluster.\n\nTo copy a DB cluster snapshot from a shared manual DB cluster snapshot,\n`SourceDBClusterSnapshotIdentifier` must be the Amazon Resource Name (ARN) of\nthe shared DB cluster snapshot.\n\nYou can copy an encrypted DB cluster snapshot from another Amazon Web Services\nRegion. In that case, the Amazon Web Services Region where you call the\n`CopyDBClusterSnapshot` operation is the destination Amazon Web Services Region\nfor the encrypted DB cluster snapshot to be copied to. To copy an encrypted DB\ncluster snapshot from another Amazon Web Services Region, you must provide the\nfollowing values:\n\n  * `KmsKeyId` - The Amazon Web Services Key Management System (Amazon\nWeb Services KMS) key identifier for the key to use to encrypt the copy of the\nDB cluster snapshot in the destination Amazon Web Services Region.\n\n  * `TargetDBClusterSnapshotIdentifier` - The identifier for the new\ncopy of the DB cluster snapshot in the destination Amazon Web Services Region.\n\n  * `SourceDBClusterSnapshotIdentifier` - The DB cluster snapshot\nidentifier for the encrypted DB cluster snapshot to be copied. This identifier\nmust be in the ARN format for the source Amazon Web Services Region and is the\nsame value as the `SourceDBClusterSnapshotIdentifier` in the presigned URL.\n\nTo cancel the copy operation once it is in progress, delete the target DB\ncluster snapshot identified by `TargetDBClusterSnapshotIdentifier` while that DB\ncluster snapshot is in \"copying\" status.\n\nFor more information on copying encrypted Amazon Aurora DB cluster snapshots\nfrom one Amazon Web Services Region to another, see [ Copying a Snapshot](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/USER_CopySnapshot.html)\nin the *Amazon Aurora User Guide*.\n\nFor more information on Amazon Aurora DB clusters, see [ What is Amazon Aurora?](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/CHAP_AuroraOverview.html)\nin the *Amazon Aurora User Guide*.\n\nFor more information on Multi-AZ DB clusters, see [ Multi-AZ DB cluster deployments](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/multi-az-db-clusters-concepts.html)\nin the *Amazon RDS User Guide*.","ref":"AWS.RDS.html#copy_db_cluster_snapshot/3","title":"AWS.RDS.copy_db_cluster_snapshot/3","type":"function"},{"doc":"Copies the specified DB parameter group.\n\nYou can't copy a default DB parameter group. Instead, create a new custom DB\nparameter group, which copies the default parameters and values for the\nspecified DB parameter group family.","ref":"AWS.RDS.html#copy_db_parameter_group/3","title":"AWS.RDS.copy_db_parameter_group/3","type":"function"},{"doc":"Copies the specified DB snapshot.\n\nThe source DB snapshot must be in the `available` state.\n\nYou can copy a snapshot from one Amazon Web Services Region to another. In that\ncase, the Amazon Web Services Region where you call the `CopyDBSnapshot`\noperation is the destination Amazon Web Services Region for the DB snapshot\ncopy.\n\nThis command doesn't apply to RDS Custom.\n\nFor more information about copying snapshots, see [Copying a DB Snapshot](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_CopySnapshot.html#USER_CopyDBSnapshot)\nin the *Amazon RDS User Guide*.","ref":"AWS.RDS.html#copy_db_snapshot/3","title":"AWS.RDS.copy_db_snapshot/3","type":"function"},{"doc":"Copies the specified option group.","ref":"AWS.RDS.html#copy_option_group/3","title":"AWS.RDS.copy_option_group/3","type":"function"},{"doc":"Creates a blue/green deployment.\n\nA blue/green deployment creates a staging environment that copies the production\nenvironment. In a blue/green deployment, the blue environment is the current\nproduction environment. The green environment is the staging environment. The\nstaging environment stays in sync with the current production environment using\nlogical replication.\n\nYou can make changes to the databases in the green environment without affecting\nproduction workloads. For example, you can upgrade the major or minor DB engine\nversion, change database parameters, or make schema changes in the staging\nenvironment. You can thoroughly test changes in the green environment. When\nready, you can switch over the environments to promote the green environment to\nbe the new production environment. The switchover typically takes under a\nminute.\n\nFor more information, see [Using Amazon RDS Blue/Green Deployments for database updates](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/blue-green-deployments.html)\nin the *Amazon RDS User Guide* and [ Using Amazon RDS Blue/Green Deployments for database\nupdates](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/blue-green-deployments.html)\nin the *Amazon Aurora User Guide*.","ref":"AWS.RDS.html#create_blue_green_deployment/3","title":"AWS.RDS.create_blue_green_deployment/3","type":"function"},{"doc":"Creates a custom DB engine version (CEV).","ref":"AWS.RDS.html#create_custom_db_engine_version/3","title":"AWS.RDS.create_custom_db_engine_version/3","type":"function"},{"doc":"Creates a new Amazon Aurora DB cluster or Multi-AZ DB cluster.\n\nIf you create an Aurora DB cluster, the request creates an empty cluster. You\nmust explicitly create the writer instance for your DB cluster using the\n[CreateDBInstance](https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CreateDBInstance.html) operation. If you create a Multi-AZ DB cluster, the request creates a writer and\ntwo reader DB instances for you, each in a different Availability Zone.\n\nYou can use the `ReplicationSourceIdentifier` parameter to create an Amazon\nAurora DB cluster as a read replica of another DB cluster or Amazon RDS for\nMySQL or PostgreSQL DB instance. For more information about Amazon Aurora, see\n[What is Amazon\nAurora?](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/CHAP_AuroraOverview.html)\nin the *Amazon Aurora User Guide*.\n\nYou can also use the `ReplicationSourceIdentifier` parameter to create a\nMulti-AZ DB cluster read replica with an RDS for MySQL or PostgreSQL DB instance\nas the source. For more information about Multi-AZ DB clusters, see [Multi-AZ DB cluster\ndeployments](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/multi-az-db-clusters-concepts.html)\nin the *Amazon RDS User Guide*.","ref":"AWS.RDS.html#create_db_cluster/3","title":"AWS.RDS.create_db_cluster/3","type":"function"},{"doc":"Creates a new custom endpoint and associates it with an Amazon Aurora DB\ncluster.\n\nThis action applies only to Aurora DB clusters.","ref":"AWS.RDS.html#create_db_cluster_endpoint/3","title":"AWS.RDS.create_db_cluster_endpoint/3","type":"function"},{"doc":"Creates a new DB cluster parameter group.\n\nParameters in a DB cluster parameter group apply to all of the instances in a DB\ncluster.\n\nA DB cluster parameter group is initially created with the default parameters\nfor the database engine used by instances in the DB cluster. To provide custom\nvalues for any of the parameters, you must modify the group after creating it\nusing `ModifyDBClusterParameterGroup`. Once you've created a DB cluster\nparameter group, you need to associate it with your DB cluster using\n`ModifyDBCluster`.\n\nWhen you associate a new DB cluster parameter group with a running Aurora DB\ncluster, reboot the DB instances in the DB cluster without failover for the new\nDB cluster parameter group and associated settings to take effect.\n\nWhen you associate a new DB cluster parameter group with a running Multi-AZ DB\ncluster, reboot the DB cluster without failover for the new DB cluster parameter\ngroup and associated settings to take effect.\n\nAfter you create a DB cluster parameter group, you should wait at least 5\nminutes before creating your first DB cluster that uses that DB cluster\nparameter group as the default parameter group. This allows Amazon RDS to fully\ncomplete the create action before the DB cluster parameter group is used as the\ndefault for a new DB cluster. This is especially important for parameters that\nare critical when creating the default database for a DB cluster, such as the\ncharacter set for the default database defined by the `character_set_database`\nparameter. You can use the *Parameter Groups* option of the [Amazon RDS console](https://console.aws.amazon.com/rds/) or the\n`DescribeDBClusterParameters` operation to verify that your DB cluster parameter\ngroup has been created or modified.\n\nFor more information on Amazon Aurora, see [ What is Amazon Aurora?](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/CHAP_AuroraOverview.html)\nin the *Amazon Aurora User Guide*.\n\nFor more information on Multi-AZ DB clusters, see [ Multi-AZ DB cluster deployments](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/multi-az-db-clusters-concepts.html)\nin the *Amazon RDS User Guide*.","ref":"AWS.RDS.html#create_db_cluster_parameter_group/3","title":"AWS.RDS.create_db_cluster_parameter_group/3","type":"function"},{"doc":"Creates a snapshot of a DB cluster.\n\nFor more information on Amazon Aurora, see [ What is Amazon Aurora?](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/CHAP_AuroraOverview.html)\nin the *Amazon Aurora User Guide*.\n\nFor more information on Multi-AZ DB clusters, see [ Multi-AZ DB cluster deployments](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/multi-az-db-clusters-concepts.html)\nin the *Amazon RDS User Guide*.","ref":"AWS.RDS.html#create_db_cluster_snapshot/3","title":"AWS.RDS.create_db_cluster_snapshot/3","type":"function"},{"doc":"Creates a new DB instance.\n\nThe new DB instance can be an RDS DB instance, or it can be a DB instance in an\nAurora DB cluster. For an Aurora DB cluster, you can call this operation\nmultiple times to add more than one DB instance to the cluster.\n\nFor more information about creating an RDS DB instance, see [ Creating an Amazon RDS DB\ninstance](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_CreateDBInstance.html)\nin the *Amazon RDS User Guide*.\n\nFor more information about creating a DB instance in an Aurora DB cluster, see [\nCreating an Amazon Aurora DB\ncluster](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/Aurora.CreateInstance.html)\nin the *Amazon Aurora User Guide*.","ref":"AWS.RDS.html#create_db_instance/3","title":"AWS.RDS.create_db_instance/3","type":"function"},{"doc":"Creates a new DB instance that acts as a read replica for an existing source DB\ninstance or Multi-AZ DB cluster.\n\nYou can create a read replica for a DB instance running Db2, MariaDB, MySQL,\nOracle, PostgreSQL, or SQL Server. You can create a read replica for a Multi-AZ\nDB cluster running MySQL or PostgreSQL. For more information, see [Working with read\nreplicas](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_ReadRepl.html)\nand [Migrating from a Multi-AZ DB cluster to a DB instance using a read replica](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/multi-az-db-clusters-concepts.html#multi-az-db-clusters-migrating-to-instance-with-read-replica)\nin the *Amazon RDS User Guide*.\n\nAmazon Aurora doesn't support this operation. To create a DB instance for an\nAurora DB cluster, use the `CreateDBInstance` operation.\n\nAll read replica DB instances are created with backups disabled. All other\nattributes (including DB security groups and DB parameter groups) are inherited\nfrom the source DB instance or cluster, except as specified.\n\nYour source DB instance or cluster must have backup retention enabled.","ref":"AWS.RDS.html#create_db_instance_read_replica/3","title":"AWS.RDS.create_db_instance_read_replica/3","type":"function"},{"doc":"Creates a new DB parameter group.\n\nA DB parameter group is initially created with the default parameters for the\ndatabase engine used by the DB instance. To provide custom values for any of the\nparameters, you must modify the group after creating it using\n`ModifyDBParameterGroup`. Once you've created a DB parameter group, you need to\nassociate it with your DB instance using `ModifyDBInstance`. When you associate\na new DB parameter group with a running DB instance, you need to reboot the DB\ninstance without failover for the new DB parameter group and associated settings\nto take effect.\n\nThis command doesn't apply to RDS Custom.\n\nAfter you create a DB parameter group, you should wait at least 5 minutes before\ncreating your first DB instance that uses that DB parameter group as the default\nparameter group. This allows Amazon RDS to fully complete the create action\nbefore the parameter group is used as the default for a new DB instance. This is\nespecially important for parameters that are critical when creating the default\ndatabase for a DB instance, such as the character set for the default database\ndefined by the `character_set_database` parameter. You can use the *Parameter\nGroups* option of the [Amazon RDS console](https://console.aws.amazon.com/rds/)\nor the *DescribeDBParameters* command to verify that your DB parameter group has\nbeen created or modified.","ref":"AWS.RDS.html#create_db_parameter_group/3","title":"AWS.RDS.create_db_parameter_group/3","type":"function"},{"doc":"Creates a new DB proxy.","ref":"AWS.RDS.html#create_db_proxy/3","title":"AWS.RDS.create_db_proxy/3","type":"function"},{"doc":"Creates a `DBProxyEndpoint`.\n\nOnly applies to proxies that are associated with Aurora DB clusters. You can use\nDB proxy endpoints to specify read/write or read-only access to the DB cluster.\nYou can also use DB proxy endpoints to access a DB proxy through a different VPC\nthan the proxy's default VPC.","ref":"AWS.RDS.html#create_db_proxy_endpoint/3","title":"AWS.RDS.create_db_proxy_endpoint/3","type":"function"},{"doc":"Creates a new DB security group.\n\nDB security groups control access to a DB instance.\n\nA DB security group controls access to EC2-Classic DB instances that are not in\na VPC.\n\nEC2-Classic was retired on August 15, 2022. If you haven't migrated from\nEC2-Classic to a VPC, we recommend that you migrate as soon as possible. For\nmore information, see [Migrate from EC2-Classic to a VPC](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/vpc-migrate.html) in\nthe *Amazon EC2 User Guide*, the blog [EC2-Classic Networking is Retiring – Here’s How to\nPrepare](http://aws.amazon.com/blogs/aws/ec2-classic-is-retiring-heres-how-to-prepare/),\nand [Moving a DB instance not in a VPC into a VPC](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_VPC.Non-VPC2VPC.html)\nin the *Amazon RDS User Guide*.","ref":"AWS.RDS.html#create_db_security_group/3","title":"AWS.RDS.create_db_security_group/3","type":"function"},{"doc":"Creates a new DB shard group for Aurora Limitless Database.\n\nYou must enable Aurora Limitless Database to create a DB shard group.\n\nValid for: Aurora DB clusters only","ref":"AWS.RDS.html#create_db_shard_group/3","title":"AWS.RDS.create_db_shard_group/3","type":"function"},{"doc":"Creates a snapshot of a DB instance.\n\nThe source DB instance must be in the `available` or `storage-optimization`\nstate.","ref":"AWS.RDS.html#create_db_snapshot/3","title":"AWS.RDS.create_db_snapshot/3","type":"function"},{"doc":"Creates a new DB subnet group.\n\nDB subnet groups must contain at least one subnet in at least two AZs in the\nAmazon Web Services Region.","ref":"AWS.RDS.html#create_db_subnet_group/3","title":"AWS.RDS.create_db_subnet_group/3","type":"function"},{"doc":"Creates an RDS event notification subscription.\n\nThis operation requires a topic Amazon Resource Name (ARN) created by either the\nRDS console, the SNS console, or the SNS API. To obtain an ARN with SNS, you\nmust create a topic in Amazon SNS and subscribe to the topic. The ARN is\ndisplayed in the SNS console.\n\nYou can specify the type of source (`SourceType`) that you want to be notified\nof and provide a list of RDS sources (`SourceIds`) that triggers the events. You\ncan also provide a list of event categories (`EventCategories`) for events that\nyou want to be notified of. For example, you can specify `SourceType` =\n`db-instance`, `SourceIds` = `mydbinstance1`, `mydbinstance2` and\n`EventCategories` = `Availability`, `Backup`.\n\nIf you specify both the `SourceType` and `SourceIds`, such as `SourceType` =\n`db-instance` and `SourceIds` = `myDBInstance1`, you are notified of all the\n`db-instance` events for the specified source. If you specify a `SourceType` but\ndo not specify `SourceIds`, you receive notice of the events for that source\ntype for all your RDS sources. If you don't specify either the SourceType or the\n`SourceIds`, you are notified of events generated from all RDS sources belonging\nto your customer account.\n\nFor more information about subscribing to an event for RDS DB engines, see [\nSubscribing to Amazon RDS event\nnotification](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_Events.Subscribing.html)\nin the *Amazon RDS User Guide*.\n\nFor more information about subscribing to an event for Aurora DB engines, see [\nSubscribing to Amazon RDS event\nnotification](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/USER_Events.Subscribing.html)\nin the *Amazon Aurora User Guide*.","ref":"AWS.RDS.html#create_event_subscription/3","title":"AWS.RDS.create_event_subscription/3","type":"function"},{"doc":"Creates an Aurora global database spread across multiple Amazon Web Services\nRegions.\n\nThe global database contains a single primary cluster with read-write\ncapability, and a read-only secondary cluster that receives data from the\nprimary cluster through high-speed replication performed by the Aurora storage\nsubsystem.\n\nYou can create a global database that is initially empty, and then create the\nprimary and secondary DB clusters in the global database. Or you can specify an\nexisting Aurora cluster during the create operation, and this cluster becomes\nthe primary cluster of the global database.\n\nThis operation applies only to Aurora DB clusters.","ref":"AWS.RDS.html#create_global_cluster/3","title":"AWS.RDS.create_global_cluster/3","type":"function"},{"doc":"Creates a zero-ETL integration with Amazon Redshift.","ref":"AWS.RDS.html#create_integration/3","title":"AWS.RDS.create_integration/3","type":"function"},{"doc":"Creates a new option group.\n\nYou can create up to 20 option groups.\n\nThis command doesn't apply to RDS Custom.","ref":"AWS.RDS.html#create_option_group/3","title":"AWS.RDS.create_option_group/3","type":"function"},{"doc":"Creates a tenant database in a DB instance that uses the multi-tenant\nconfiguration.\n\nOnly RDS for Oracle container database (CDB) instances are supported.","ref":"AWS.RDS.html#create_tenant_database/3","title":"AWS.RDS.create_tenant_database/3","type":"function"},{"doc":"Deletes a blue/green deployment.\n\nFor more information, see [Using Amazon RDS Blue/Green Deployments for database updates](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/blue-green-deployments.html)\nin the *Amazon RDS User Guide* and [Using Amazon RDS Blue/Green Deployments for database\nupdates](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/blue-green-deployments.html)\nin the *Amazon Aurora User Guide*.","ref":"AWS.RDS.html#delete_blue_green_deployment/3","title":"AWS.RDS.delete_blue_green_deployment/3","type":"function"},{"doc":"Deletes a custom engine version.\n\nTo run this command, make sure you meet the following prerequisites:\n\n  * The CEV must not be the default for RDS Custom. If it is, change\nthe default before running this command.\n\n  * The CEV must not be associated with an RDS Custom DB instance, RDS\nCustom instance snapshot, or automated backup of your RDS Custom instance.\n\nTypically, deletion takes a few minutes.\n\nThe MediaImport service that imports files from Amazon S3 to create CEVs isn't\nintegrated with Amazon Web Services CloudTrail. If you turn on data logging for\nAmazon RDS in CloudTrail, calls to the `DeleteCustomDbEngineVersion` event\naren't logged. However, you might see calls from the API gateway that accesses\nyour Amazon S3 bucket. These calls originate from the MediaImport service for\nthe `DeleteCustomDbEngineVersion` event.\n\nFor more information, see [Deleting a CEV](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/custom-cev.html#custom-cev.delete)\nin the *Amazon RDS User Guide*.","ref":"AWS.RDS.html#delete_custom_db_engine_version/3","title":"AWS.RDS.delete_custom_db_engine_version/3","type":"function"},{"doc":"The DeleteDBCluster action deletes a previously provisioned DB cluster.\n\nWhen you delete a DB cluster, all automated backups for that DB cluster are\ndeleted and can't be recovered. Manual DB cluster snapshots of the specified DB\ncluster are not deleted.\n\nIf you're deleting a Multi-AZ DB cluster with read replicas, all cluster members\nare terminated and read replicas are promoted to standalone instances.\n\nFor more information on Amazon Aurora, see [ What is Amazon Aurora?](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/CHAP_AuroraOverview.html)\nin the *Amazon Aurora User Guide*.\n\nFor more information on Multi-AZ DB clusters, see [ Multi-AZ DB cluster deployments](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/multi-az-db-clusters-concepts.html)\nin the *Amazon RDS User Guide*.","ref":"AWS.RDS.html#delete_db_cluster/3","title":"AWS.RDS.delete_db_cluster/3","type":"function"},{"doc":"Deletes automated backups using the `DbClusterResourceId` value of the source DB\ncluster or the Amazon Resource Name (ARN) of the automated backups.","ref":"AWS.RDS.html#delete_db_cluster_automated_backup/3","title":"AWS.RDS.delete_db_cluster_automated_backup/3","type":"function"},{"doc":"Deletes a custom endpoint and removes it from an Amazon Aurora DB cluster.\n\nThis action only applies to Aurora DB clusters.","ref":"AWS.RDS.html#delete_db_cluster_endpoint/3","title":"AWS.RDS.delete_db_cluster_endpoint/3","type":"function"},{"doc":"Deletes a specified DB cluster parameter group.\n\nThe DB cluster parameter group to be deleted can't be associated with any DB\nclusters.\n\nFor more information on Amazon Aurora, see [ What is Amazon Aurora?](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/CHAP_AuroraOverview.html)\nin the *Amazon Aurora User Guide*.\n\nFor more information on Multi-AZ DB clusters, see [ Multi-AZ DB cluster deployments](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/multi-az-db-clusters-concepts.html)\nin the *Amazon RDS User Guide*.","ref":"AWS.RDS.html#delete_db_cluster_parameter_group/3","title":"AWS.RDS.delete_db_cluster_parameter_group/3","type":"function"},{"doc":"Deletes a DB cluster snapshot.\n\nIf the snapshot is being copied, the copy operation is terminated.\n\nThe DB cluster snapshot must be in the `available` state to be deleted.\n\nFor more information on Amazon Aurora, see [ What is Amazon Aurora?](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/CHAP_AuroraOverview.html)\nin the *Amazon Aurora User Guide*.\n\nFor more information on Multi-AZ DB clusters, see [ Multi-AZ DB cluster deployments](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/multi-az-db-clusters-concepts.html)\nin the *Amazon RDS User Guide*.","ref":"AWS.RDS.html#delete_db_cluster_snapshot/3","title":"AWS.RDS.delete_db_cluster_snapshot/3","type":"function"},{"doc":"Deletes a previously provisioned DB instance.\n\nWhen you delete a DB instance, all automated backups for that instance are\ndeleted and can't be recovered. However, manual DB snapshots of the DB instance\naren't deleted.\n\nIf you request a final DB snapshot, the status of the Amazon RDS DB instance is\n`deleting` until the DB snapshot is created. This operation can't be canceled or\nreverted after it begins. To monitor the status of this operation, use\n`DescribeDBInstance`.\n\nWhen a DB instance is in a failure state and has a status of `failed`,\n`incompatible-restore`, or `incompatible-network`, you can only delete it when\nyou skip creation of the final snapshot with the `SkipFinalSnapshot` parameter.\n\nIf the specified DB instance is part of an Amazon Aurora DB cluster, you can't\ndelete the DB instance if both of the following conditions are true:\n\n  * The DB cluster is a read replica of another Amazon Aurora DB\ncluster.\n\n  * The DB instance is the only instance in the DB cluster.\n\nTo delete a DB instance in this case, first use the\n`PromoteReadReplicaDBCluster` operation to promote the DB cluster so that it's\nno longer a read replica. After the promotion completes, use the\n`DeleteDBInstance` operation to delete the final instance in the DB cluster.\n\nFor RDS Custom DB instances, deleting the DB instance permanently deletes the\nEC2 instance and the associated EBS volumes. Make sure that you don't terminate\nor delete these resources before you delete the DB instance. Otherwise, deleting\nthe DB instance and creation of the final snapshot might fail.","ref":"AWS.RDS.html#delete_db_instance/3","title":"AWS.RDS.delete_db_instance/3","type":"function"},{"doc":"Deletes automated backups using the `DbiResourceId` value of the source DB\ninstance or the Amazon Resource Name (ARN) of the automated backups.","ref":"AWS.RDS.html#delete_db_instance_automated_backup/3","title":"AWS.RDS.delete_db_instance_automated_backup/3","type":"function"},{"doc":"Deletes a specified DB parameter group.\n\nThe DB parameter group to be deleted can't be associated with any DB instances.","ref":"AWS.RDS.html#delete_db_parameter_group/3","title":"AWS.RDS.delete_db_parameter_group/3","type":"function"},{"doc":"Deletes an existing DB proxy.","ref":"AWS.RDS.html#delete_db_proxy/3","title":"AWS.RDS.delete_db_proxy/3","type":"function"},{"doc":"Deletes a `DBProxyEndpoint`.\n\nDoing so removes the ability to access the DB proxy using the endpoint that you\ndefined. The endpoint that you delete might have provided capabilities such as\nread/write or read-only operations, or using a different VPC than the DB proxy's\ndefault VPC.","ref":"AWS.RDS.html#delete_db_proxy_endpoint/3","title":"AWS.RDS.delete_db_proxy_endpoint/3","type":"function"},{"doc":"Deletes a DB security group.\n\nThe specified DB security group must not be associated with any DB instances.\n\nEC2-Classic was retired on August 15, 2022. If you haven't migrated from\nEC2-Classic to a VPC, we recommend that you migrate as soon as possible. For\nmore information, see [Migrate from EC2-Classic to a VPC](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/vpc-migrate.html) in\nthe *Amazon EC2 User Guide*, the blog [EC2-Classic Networking is Retiring – Here’s How to\nPrepare](http://aws.amazon.com/blogs/aws/ec2-classic-is-retiring-heres-how-to-prepare/),\nand [Moving a DB instance not in a VPC into a VPC](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_VPC.Non-VPC2VPC.html)\nin the *Amazon RDS User Guide*.","ref":"AWS.RDS.html#delete_db_security_group/3","title":"AWS.RDS.delete_db_security_group/3","type":"function"},{"doc":"Deletes an Aurora Limitless Database DB shard group.","ref":"AWS.RDS.html#delete_db_shard_group/3","title":"AWS.RDS.delete_db_shard_group/3","type":"function"},{"doc":"Deletes a DB snapshot.\n\nIf the snapshot is being copied, the copy operation is terminated.\n\nThe DB snapshot must be in the `available` state to be deleted.","ref":"AWS.RDS.html#delete_db_snapshot/3","title":"AWS.RDS.delete_db_snapshot/3","type":"function"},{"doc":"Deletes a DB subnet group.\n\nThe specified database subnet group must not be associated with any DB\ninstances.","ref":"AWS.RDS.html#delete_db_subnet_group/3","title":"AWS.RDS.delete_db_subnet_group/3","type":"function"},{"doc":"Deletes an RDS event notification subscription.","ref":"AWS.RDS.html#delete_event_subscription/3","title":"AWS.RDS.delete_event_subscription/3","type":"function"},{"doc":"Deletes a global database cluster.\n\nThe primary and secondary clusters must already be detached or destroyed first.\n\nThis action only applies to Aurora DB clusters.","ref":"AWS.RDS.html#delete_global_cluster/3","title":"AWS.RDS.delete_global_cluster/3","type":"function"},{"doc":"Deletes a zero-ETL integration with Amazon Redshift.","ref":"AWS.RDS.html#delete_integration/3","title":"AWS.RDS.delete_integration/3","type":"function"},{"doc":"Deletes an existing option group.","ref":"AWS.RDS.html#delete_option_group/3","title":"AWS.RDS.delete_option_group/3","type":"function"},{"doc":"Deletes a tenant database from your DB instance.\n\nThis command only applies to RDS for Oracle container database (CDB) instances.\n\nYou can't delete a tenant database when it is the only tenant in the DB\ninstance.","ref":"AWS.RDS.html#delete_tenant_database/3","title":"AWS.RDS.delete_tenant_database/3","type":"function"},{"doc":"Remove the association between one or more `DBProxyTarget` data structures and a\n`DBProxyTargetGroup`.","ref":"AWS.RDS.html#deregister_db_proxy_targets/3","title":"AWS.RDS.deregister_db_proxy_targets/3","type":"function"},{"doc":"Lists all of the attributes for a customer account.\n\nThe attributes include Amazon RDS quotas for the account, such as the number of\nDB instances allowed. The description for a quota includes the quota name,\ncurrent usage toward that quota, and the quota's maximum value.\n\nThis command doesn't take any parameters.","ref":"AWS.RDS.html#describe_account_attributes/3","title":"AWS.RDS.describe_account_attributes/3","type":"function"},{"doc":"Describes one or more blue/green deployments.\n\nFor more information, see [Using Amazon RDS Blue/Green Deployments for database updates](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/blue-green-deployments.html)\nin the *Amazon RDS User Guide* and [ Using Amazon RDS Blue/Green Deployments for database\nupdates](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/blue-green-deployments.html)\nin the *Amazon Aurora User Guide*.","ref":"AWS.RDS.html#describe_blue_green_deployments/3","title":"AWS.RDS.describe_blue_green_deployments/3","type":"function"},{"doc":"Lists the set of certificate authority (CA) certificates provided by Amazon RDS\nfor this Amazon Web Services account.\n\nFor more information, see [Using SSL/TLS to encrypt a connection to a DB instance](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/UsingWithRDS.SSL.html)\nin the *Amazon RDS User Guide* and [ Using SSL/TLS to encrypt a connection to a DB\ncluster](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/UsingWithRDS.SSL.html)\nin the *Amazon Aurora User Guide*.","ref":"AWS.RDS.html#describe_certificates/3","title":"AWS.RDS.describe_certificates/3","type":"function"},{"doc":"Displays backups for both current and deleted DB clusters.\n\nFor example, use this operation to find details about automated backups for\npreviously deleted clusters. Current clusters are returned for both the\n`DescribeDBClusterAutomatedBackups` and `DescribeDBClusters` operations.\n\nAll parameters are optional.","ref":"AWS.RDS.html#describe_db_cluster_automated_backups/3","title":"AWS.RDS.describe_db_cluster_automated_backups/3","type":"function"},{"doc":"Returns information about backtracks for a DB cluster.\n\nFor more information on Amazon Aurora, see [ What is Amazon Aurora?](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/CHAP_AuroraOverview.html)\nin the *Amazon Aurora User Guide*.\n\nThis action only applies to Aurora MySQL DB clusters.","ref":"AWS.RDS.html#describe_db_cluster_backtracks/3","title":"AWS.RDS.describe_db_cluster_backtracks/3","type":"function"},{"doc":"Returns information about endpoints for an Amazon Aurora DB cluster.\n\nThis action only applies to Aurora DB clusters.","ref":"AWS.RDS.html#describe_db_cluster_endpoints/3","title":"AWS.RDS.describe_db_cluster_endpoints/3","type":"function"},{"doc":"Returns a list of `DBClusterParameterGroup` descriptions.\n\nIf a `DBClusterParameterGroupName` parameter is specified, the list will contain\nonly the description of the specified DB cluster parameter group.\n\nFor more information on Amazon Aurora, see [ What is Amazon Aurora?](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/CHAP_AuroraOverview.html)\nin the *Amazon Aurora User Guide*.\n\nFor more information on Multi-AZ DB clusters, see [ Multi-AZ DB cluster deployments](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/multi-az-db-clusters-concepts.html)\nin the *Amazon RDS User Guide*.","ref":"AWS.RDS.html#describe_db_cluster_parameter_groups/3","title":"AWS.RDS.describe_db_cluster_parameter_groups/3","type":"function"},{"doc":"Returns the detailed parameter list for a particular DB cluster parameter group.\n\nFor more information on Amazon Aurora, see [ What is Amazon Aurora?](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/CHAP_AuroraOverview.html)\nin the *Amazon Aurora User Guide*.\n\nFor more information on Multi-AZ DB clusters, see [ Multi-AZ DB cluster deployments](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/multi-az-db-clusters-concepts.html)\nin the *Amazon RDS User Guide*.","ref":"AWS.RDS.html#describe_db_cluster_parameters/3","title":"AWS.RDS.describe_db_cluster_parameters/3","type":"function"},{"doc":"Returns a list of DB cluster snapshot attribute names and values for a manual DB\ncluster snapshot.\n\nWhen sharing snapshots with other Amazon Web Services accounts,\n`DescribeDBClusterSnapshotAttributes` returns the `restore` attribute and a list\nof IDs for the Amazon Web Services accounts that are authorized to copy or\nrestore the manual DB cluster snapshot. If `all` is included in the list of\nvalues for the `restore` attribute, then the manual DB cluster snapshot is\npublic and can be copied or restored by all Amazon Web Services accounts.\n\nTo add or remove access for an Amazon Web Services account to copy or restore a\nmanual DB cluster snapshot, or to make the manual DB cluster snapshot public or\nprivate, use the `ModifyDBClusterSnapshotAttribute` API action.","ref":"AWS.RDS.html#describe_db_cluster_snapshot_attributes/3","title":"AWS.RDS.describe_db_cluster_snapshot_attributes/3","type":"function"},{"doc":"Returns information about DB cluster snapshots.\n\nThis API action supports pagination.\n\nFor more information on Amazon Aurora DB clusters, see [ What is Amazon Aurora?](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/CHAP_AuroraOverview.html)\nin the *Amazon Aurora User Guide*.\n\nFor more information on Multi-AZ DB clusters, see [ Multi-AZ DB cluster deployments](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/multi-az-db-clusters-concepts.html)\nin the *Amazon RDS User Guide*.","ref":"AWS.RDS.html#describe_db_cluster_snapshots/3","title":"AWS.RDS.describe_db_cluster_snapshots/3","type":"function"},{"doc":"Describes existing Amazon Aurora DB clusters and Multi-AZ DB clusters.\n\nThis API supports pagination.\n\nFor more information on Amazon Aurora DB clusters, see [ What is Amazon Aurora?](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/CHAP_AuroraOverview.html)\nin the *Amazon Aurora User Guide*.\n\nFor more information on Multi-AZ DB clusters, see [ Multi-AZ DB cluster deployments](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/multi-az-db-clusters-concepts.html)\nin the *Amazon RDS User Guide*.\n\nThis operation can also return information for Amazon Neptune DB instances and\nAmazon DocumentDB instances.","ref":"AWS.RDS.html#describe_db_clusters/3","title":"AWS.RDS.describe_db_clusters/3","type":"function"},{"doc":"Describes the properties of specific versions of DB engines.","ref":"AWS.RDS.html#describe_db_engine_versions/3","title":"AWS.RDS.describe_db_engine_versions/3","type":"function"},{"doc":"Displays backups for both current and deleted instances.\n\nFor example, use this operation to find details about automated backups for\npreviously deleted instances. Current instances with retention periods greater\nthan zero (0) are returned for both the `DescribeDBInstanceAutomatedBackups` and\n`DescribeDBInstances` operations.\n\nAll parameters are optional.","ref":"AWS.RDS.html#describe_db_instance_automated_backups/3","title":"AWS.RDS.describe_db_instance_automated_backups/3","type":"function"},{"doc":"Describes provisioned RDS instances.\n\nThis API supports pagination.\n\nThis operation can also return information for Amazon Neptune DB instances and\nAmazon DocumentDB instances.","ref":"AWS.RDS.html#describe_db_instances/3","title":"AWS.RDS.describe_db_instances/3","type":"function"},{"doc":"Returns a list of DB log files for the DB instance.\n\nThis command doesn't apply to RDS Custom.","ref":"AWS.RDS.html#describe_db_log_files/3","title":"AWS.RDS.describe_db_log_files/3","type":"function"},{"doc":"Returns a list of `DBParameterGroup` descriptions.\n\nIf a `DBParameterGroupName` is specified, the list will contain only the\ndescription of the specified DB parameter group.","ref":"AWS.RDS.html#describe_db_parameter_groups/3","title":"AWS.RDS.describe_db_parameter_groups/3","type":"function"},{"doc":"Returns the detailed parameter list for a particular DB parameter group.","ref":"AWS.RDS.html#describe_db_parameters/3","title":"AWS.RDS.describe_db_parameters/3","type":"function"},{"doc":"Returns information about DB proxies.","ref":"AWS.RDS.html#describe_db_proxies/3","title":"AWS.RDS.describe_db_proxies/3","type":"function"},{"doc":"Returns information about DB proxy endpoints.","ref":"AWS.RDS.html#describe_db_proxy_endpoints/3","title":"AWS.RDS.describe_db_proxy_endpoints/3","type":"function"},{"doc":"Returns information about DB proxy target groups, represented by\n`DBProxyTargetGroup` data structures.","ref":"AWS.RDS.html#describe_db_proxy_target_groups/3","title":"AWS.RDS.describe_db_proxy_target_groups/3","type":"function"},{"doc":"Returns information about `DBProxyTarget` objects.\n\nThis API supports pagination.","ref":"AWS.RDS.html#describe_db_proxy_targets/3","title":"AWS.RDS.describe_db_proxy_targets/3","type":"function"},{"doc":"Describes the recommendations to resolve the issues for your DB instances, DB\nclusters, and DB parameter groups.","ref":"AWS.RDS.html#describe_db_recommendations/3","title":"AWS.RDS.describe_db_recommendations/3","type":"function"},{"doc":"Returns a list of `DBSecurityGroup` descriptions.\n\nIf a `DBSecurityGroupName` is specified, the list will contain only the\ndescriptions of the specified DB security group.\n\nEC2-Classic was retired on August 15, 2022. If you haven't migrated from\nEC2-Classic to a VPC, we recommend that you migrate as soon as possible. For\nmore information, see [Migrate from EC2-Classic to a VPC](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/vpc-migrate.html) in\nthe *Amazon EC2 User Guide*, the blog [EC2-Classic Networking is Retiring – Here’s How to\nPrepare](http://aws.amazon.com/blogs/aws/ec2-classic-is-retiring-heres-how-to-prepare/),\nand [Moving a DB instance not in a VPC into a VPC](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_VPC.Non-VPC2VPC.html)\nin the *Amazon RDS User Guide*.","ref":"AWS.RDS.html#describe_db_security_groups/3","title":"AWS.RDS.describe_db_security_groups/3","type":"function"},{"doc":"Describes existing Aurora Limitless Database DB shard groups.","ref":"AWS.RDS.html#describe_db_shard_groups/3","title":"AWS.RDS.describe_db_shard_groups/3","type":"function"},{"doc":"Returns a list of DB snapshot attribute names and values for a manual DB\nsnapshot.\n\nWhen sharing snapshots with other Amazon Web Services accounts,\n`DescribeDBSnapshotAttributes` returns the `restore` attribute and a list of IDs\nfor the Amazon Web Services accounts that are authorized to copy or restore the\nmanual DB snapshot. If `all` is included in the list of values for the `restore`\nattribute, then the manual DB snapshot is public and can be copied or restored\nby all Amazon Web Services accounts.\n\nTo add or remove access for an Amazon Web Services account to copy or restore a\nmanual DB snapshot, or to make the manual DB snapshot public or private, use the\n`ModifyDBSnapshotAttribute` API action.","ref":"AWS.RDS.html#describe_db_snapshot_attributes/3","title":"AWS.RDS.describe_db_snapshot_attributes/3","type":"function"},{"doc":"Describes the tenant databases that exist in a DB snapshot.\n\nThis command only applies to RDS for Oracle DB instances in the multi-tenant\nconfiguration.\n\nYou can use this command to inspect the tenant databases within a snapshot\nbefore restoring it. You can't directly interact with the tenant databases in a\nDB snapshot. If you restore a snapshot that was taken from DB instance using the\nmulti-tenant configuration, you restore all its tenant databases.","ref":"AWS.RDS.html#describe_db_snapshot_tenant_databases/3","title":"AWS.RDS.describe_db_snapshot_tenant_databases/3","type":"function"},{"doc":"Returns information about DB snapshots.\n\nThis API action supports pagination.","ref":"AWS.RDS.html#describe_db_snapshots/3","title":"AWS.RDS.describe_db_snapshots/3","type":"function"},{"doc":"Returns a list of DBSubnetGroup descriptions.\n\nIf a DBSubnetGroupName is specified, the list will contain only the descriptions\nof the specified DBSubnetGroup.\n\nFor an overview of CIDR ranges, go to the [Wikipedia Tutorial](http://en.wikipedia.org/wiki/Classless_Inter-Domain_Routing).","ref":"AWS.RDS.html#describe_db_subnet_groups/3","title":"AWS.RDS.describe_db_subnet_groups/3","type":"function"},{"doc":"Returns the default engine and system parameter information for the cluster\ndatabase engine.\n\nFor more information on Amazon Aurora, see [ What is Amazon Aurora?](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/CHAP_AuroraOverview.html)\nin the *Amazon Aurora User Guide*.","ref":"AWS.RDS.html#describe_engine_default_cluster_parameters/3","title":"AWS.RDS.describe_engine_default_cluster_parameters/3","type":"function"},{"doc":"Returns the default engine and system parameter information for the specified\ndatabase engine.","ref":"AWS.RDS.html#describe_engine_default_parameters/3","title":"AWS.RDS.describe_engine_default_parameters/3","type":"function"},{"doc":"Displays a list of categories for all event source types, or, if specified, for\na specified source type.\n\nYou can also see this list in the \"Amazon RDS event categories and event\nmessages\" section of the [ *Amazon RDS User Guide*\n](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_Events.Messages.html)\nor the [ *Amazon Aurora User Guide*\n](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/USER_Events.Messages.html).","ref":"AWS.RDS.html#describe_event_categories/3","title":"AWS.RDS.describe_event_categories/3","type":"function"},{"doc":"Lists all the subscription descriptions for a customer account.\n\nThe description for a subscription includes `SubscriptionName`, `SNSTopicARN`,\n`CustomerID`, `SourceType`, `SourceID`, `CreationTime`, and `Status`.\n\nIf you specify a `SubscriptionName`, lists the description for that\nsubscription.","ref":"AWS.RDS.html#describe_event_subscriptions/3","title":"AWS.RDS.describe_event_subscriptions/3","type":"function"},{"doc":"Returns events related to DB instances, DB clusters, DB parameter groups, DB\nsecurity groups, DB snapshots, DB cluster snapshots, and RDS Proxies for the\npast 14 days.\n\nEvents specific to a particular DB instance, DB cluster, DB parameter group, DB\nsecurity group, DB snapshot, DB cluster snapshot group, or RDS Proxy can be\nobtained by providing the name as a parameter.\n\nFor more information on working with events, see [Monitoring Amazon RDS events](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/working-with-events.html)\nin the *Amazon RDS User Guide* and [Monitoring Amazon Aurora events](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/working-with-events.html)\nin the *Amazon Aurora User Guide*.\n\nBy default, RDS returns events that were generated in the past hour.","ref":"AWS.RDS.html#describe_events/3","title":"AWS.RDS.describe_events/3","type":"function"},{"doc":"Returns information about a snapshot or cluster export to Amazon S3.\n\nThis API operation supports pagination.","ref":"AWS.RDS.html#describe_export_tasks/3","title":"AWS.RDS.describe_export_tasks/3","type":"function"},{"doc":"Returns information about Aurora global database clusters.\n\nThis API supports pagination.\n\nFor more information on Amazon Aurora, see [ What is Amazon Aurora?](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/CHAP_AuroraOverview.html)\nin the *Amazon Aurora User Guide*.\n\nThis action only applies to Aurora DB clusters.","ref":"AWS.RDS.html#describe_global_clusters/3","title":"AWS.RDS.describe_global_clusters/3","type":"function"},{"doc":"Describe one or more zero-ETL integrations with Amazon Redshift.","ref":"AWS.RDS.html#describe_integrations/3","title":"AWS.RDS.describe_integrations/3","type":"function"},{"doc":"Describes all available options for the specified engine.","ref":"AWS.RDS.html#describe_option_group_options/3","title":"AWS.RDS.describe_option_group_options/3","type":"function"},{"doc":"Describes the available option groups.","ref":"AWS.RDS.html#describe_option_groups/3","title":"AWS.RDS.describe_option_groups/3","type":"function"},{"doc":"Describes the orderable DB instance options for a specified DB engine.","ref":"AWS.RDS.html#describe_orderable_db_instance_options/3","title":"AWS.RDS.describe_orderable_db_instance_options/3","type":"function"},{"doc":"Returns a list of resources (for example, DB instances) that have at least one\npending maintenance action.","ref":"AWS.RDS.html#describe_pending_maintenance_actions/3","title":"AWS.RDS.describe_pending_maintenance_actions/3","type":"function"},{"doc":"Returns information about reserved DB instances for this account, or about a\nspecified reserved DB instance.","ref":"AWS.RDS.html#describe_reserved_db_instances/3","title":"AWS.RDS.describe_reserved_db_instances/3","type":"function"},{"doc":"Lists available reserved DB instance offerings.","ref":"AWS.RDS.html#describe_reserved_db_instances_offerings/3","title":"AWS.RDS.describe_reserved_db_instances_offerings/3","type":"function"},{"doc":"Returns a list of the source Amazon Web Services Regions where the current\nAmazon Web Services Region can create a read replica, copy a DB snapshot from,\nor replicate automated backups from.\n\nUse this operation to determine whether cross-Region features are supported\nbetween other Regions and your current Region. This operation supports\npagination.\n\nTo return information about the Regions that are enabled for your account, or\nall Regions, use the EC2 operation `DescribeRegions`. For more information, see\n[\nDescribeRegions](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeRegions.html)\nin the *Amazon EC2 API Reference*.","ref":"AWS.RDS.html#describe_source_regions/3","title":"AWS.RDS.describe_source_regions/3","type":"function"},{"doc":"Describes the tenant databases in a DB instance that uses the multi-tenant\nconfiguration.\n\nOnly RDS for Oracle CDB instances are supported.","ref":"AWS.RDS.html#describe_tenant_databases/3","title":"AWS.RDS.describe_tenant_databases/3","type":"function"},{"doc":"You can call `DescribeValidDBInstanceModifications` to learn what modifications\nyou can make to your DB instance.\n\nYou can use this information when you call `ModifyDBInstance`.\n\nThis command doesn't apply to RDS Custom.","ref":"AWS.RDS.html#describe_valid_db_instance_modifications/3","title":"AWS.RDS.describe_valid_db_instance_modifications/3","type":"function"},{"doc":"Disables the HTTP endpoint for the specified DB cluster.\n\nDisabling this endpoint disables RDS Data API.\n\nFor more information, see [Using RDS Data API](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/data-api.html)\nin the *Amazon Aurora User Guide*.\n\nThis operation applies only to Aurora PostgreSQL Serverless v2 and provisioned\nDB clusters. To disable the HTTP endpoint for Aurora Serverless v1 DB clusters,\nuse the `EnableHttpEndpoint` parameter of the `ModifyDBCluster` operation.","ref":"AWS.RDS.html#disable_http_endpoint/3","title":"AWS.RDS.disable_http_endpoint/3","type":"function"},{"doc":"Downloads all or a portion of the specified log file, up to 1 MB in size.\n\nThis command doesn't apply to RDS Custom.","ref":"AWS.RDS.html#download_db_log_file_portion/3","title":"AWS.RDS.download_db_log_file_portion/3","type":"function"},{"doc":"Enables the HTTP endpoint for the DB cluster.\n\nBy default, the HTTP endpoint isn't enabled.\n\nWhen enabled, this endpoint provides a connectionless web service API (RDS Data\nAPI) for running SQL queries on the Aurora DB cluster. You can also query your\ndatabase from inside the RDS console with the RDS query editor.\n\nFor more information, see [Using RDS Data API](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/data-api.html)\nin the *Amazon Aurora User Guide*.\n\nThis operation applies only to Aurora PostgreSQL Serverless v2 and provisioned\nDB clusters. To enable the HTTP endpoint for Aurora Serverless v1 DB clusters,\nuse the `EnableHttpEndpoint` parameter of the `ModifyDBCluster` operation.","ref":"AWS.RDS.html#enable_http_endpoint/3","title":"AWS.RDS.enable_http_endpoint/3","type":"function"},{"doc":"Forces a failover for a DB cluster.\n\nFor an Aurora DB cluster, failover for a DB cluster promotes one of the Aurora\nReplicas (read-only instances) in the DB cluster to be the primary DB instance\n(the cluster writer).\n\nFor a Multi-AZ DB cluster, after RDS terminates the primary DB instance, the\ninternal monitoring system detects that the primary DB instance is unhealthy and\npromotes a readable standby (read-only instances) in the DB cluster to be the\nprimary DB instance (the cluster writer). Failover times are typically less than\n35 seconds.\n\nAn Amazon Aurora DB cluster automatically fails over to an Aurora Replica, if\none exists, when the primary DB instance fails. A Multi-AZ DB cluster\nautomatically fails over to a readable standby DB instance when the primary DB\ninstance fails.\n\nTo simulate a failure of a primary instance for testing, you can force a\nfailover. Because each instance in a DB cluster has its own endpoint address,\nmake sure to clean up and re-establish any existing connections that use those\nendpoint addresses when the failover is complete.\n\nFor more information on Amazon Aurora DB clusters, see [ What is Amazon Aurora?](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/CHAP_AuroraOverview.html)\nin the *Amazon Aurora User Guide*.\n\nFor more information on Multi-AZ DB clusters, see [ Multi-AZ DB cluster deployments](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/multi-az-db-clusters-concepts.html)\nin the *Amazon RDS User Guide*.","ref":"AWS.RDS.html#failover_db_cluster/3","title":"AWS.RDS.failover_db_cluster/3","type":"function"},{"doc":"Promotes the specified secondary DB cluster to be the primary DB cluster in the\nglobal database cluster to fail over or switch over a global database.\n\nSwitchover operations were previously called \"managed planned failovers.\"\n\nAlthough this operation can be used either to fail over or to switch over a\nglobal database cluster, its intended use is for global database failover. To\nswitch over a global database cluster, we recommend that you use the\n`SwitchoverGlobalCluster` operation instead.\n\nHow you use this operation depends on whether you are failing over or switching\nover your global database cluster:\n\n  * Failing over - Specify the `AllowDataLoss` parameter and don't\nspecify the `Switchover` parameter.\n\n  * Switching over - Specify the `Switchover` parameter or omit it,\nbut don't specify the `AllowDataLoss` parameter.","ref":"AWS.RDS.html#failover_global_cluster/3","title":"AWS.RDS.failover_global_cluster/3","type":"function"},{"doc":"While failing over and switching over a global database cluster both change the\nprimary DB cluster, you use these operations for different reasons:\n\n  * *Failing over* - Use this operation to respond to an unplanned\nevent, such as a Regional disaster in the primary Region. Failing over can\nresult in a loss of write transaction data that wasn't replicated to the chosen\nsecondary before the failover event occurred. However, the recovery process that\npromotes a DB instance on the chosen seconday DB cluster to be the primary\nwriter DB instance guarantees that the data is in a transactionally consistent\nstate.\n\nFor more information about failing over an Amazon Aurora global database, see\n[Performing managed failovers for Aurora global databases](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/aurora-global-database-disaster-recovery.html#aurora-global-database-failover.managed-unplanned)\nin the *Amazon Aurora User Guide*.\n\n  * *Switching over* - Use this operation on a healthy global database\ncluster for planned events, such as Regional rotation or to fail back to the\noriginal primary DB cluster after a failover operation. With this operation,\nthere is no data loss.\n\nFor more information about switching over an Amazon Aurora global database, see\n[Performing switchovers for Aurora global databases](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/aurora-global-database-disaster-recovery.html#aurora-global-database-disaster-recovery.managed-failover)\nin the *Amazon Aurora User Guide*.","ref":"AWS.RDS.html#failover_global_cluster/3-about-failing-over-and-switching-over","title":"About failing over and switching over - AWS.RDS.failover_global_cluster/3","type":"function"},{"doc":"Lists all tags on an Amazon RDS resource.\n\nFor an overview on tagging an Amazon RDS resource, see [Tagging Amazon RDS Resources](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/Overview.Tagging.html)\nin the *Amazon RDS User Guide*.","ref":"AWS.RDS.html#list_tags_for_resource/3","title":"AWS.RDS.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.RDS.html#metadata/0","title":"AWS.RDS.metadata/0","type":"function"},{"doc":"Changes the audit policy state of a database activity stream to either locked\n(default) or unlocked.\n\nA locked policy is read-only, whereas an unlocked policy is read/write. If your\nactivity stream is started and locked, you can unlock it, customize your audit\npolicy, and then lock your activity stream. Restarting the activity stream isn't\nrequired. For more information, see [ Modifying a database activity stream](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/DBActivityStreams.Modifying.html)\nin the *Amazon RDS User Guide*.\n\nThis operation is supported for RDS for Oracle and Microsoft SQL Server.","ref":"AWS.RDS.html#modify_activity_stream/3","title":"AWS.RDS.modify_activity_stream/3","type":"function"},{"doc":"Override the system-default Secure Sockets Layer/Transport Layer Security\n(SSL/TLS) certificate for Amazon RDS for new DB instances, or remove the\noverride.\n\nBy using this operation, you can specify an RDS-approved SSL/TLS certificate for\nnew DB instances that is different from the default certificate provided by RDS.\nYou can also use this operation to remove the override, so that new DB instances\nuse the default certificate provided by RDS.\n\nYou might need to override the default certificate in the following situations:\n\n  * You already migrated your applications to support the latest\ncertificate authority (CA) certificate, but the new CA certificate is not yet\nthe RDS default CA certificate for the specified Amazon Web Services Region.\n\n  * RDS has already moved to a new default CA certificate for the\nspecified Amazon Web Services Region, but you are still in the process of\nsupporting the new CA certificate. In this case, you temporarily need additional\ntime to finish your application changes.\n\nFor more information about rotating your SSL/TLS certificate for RDS DB engines,\nsee [ Rotating Your SSL/TLS Certificate](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/UsingWithRDS.SSL-certificate-rotation.html)\nin the *Amazon RDS User Guide*.\n\nFor more information about rotating your SSL/TLS certificate for Aurora DB\nengines, see [ Rotating Your SSL/TLS Certificate](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/UsingWithRDS.SSL-certificate-rotation.html)\nin the *Amazon Aurora User Guide*.","ref":"AWS.RDS.html#modify_certificates/3","title":"AWS.RDS.modify_certificates/3","type":"function"},{"doc":"Set the capacity of an Aurora Serverless v1 DB cluster to a specific value.\n\nAurora Serverless v1 scales seamlessly based on the workload on the DB cluster.\nIn some cases, the capacity might not scale fast enough to meet a sudden change\nin workload, such as a large number of new transactions. Call\n`ModifyCurrentDBClusterCapacity` to set the capacity explicitly.\n\nAfter this call sets the DB cluster capacity, Aurora Serverless v1 can\nautomatically scale the DB cluster based on the cooldown period for scaling up\nand the cooldown period for scaling down.\n\nFor more information about Aurora Serverless v1, see [Using Amazon Aurora Serverless\nv1](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/aurora-serverless.html)\nin the *Amazon Aurora User Guide*.\n\nIf you call `ModifyCurrentDBClusterCapacity` with the default `TimeoutAction`,\nconnections that prevent Aurora Serverless v1 from finding a scaling point might\nbe dropped. For more information about scaling points, see [ Autoscaling for Aurora Serverless\nv1](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/aurora-serverless.how-it-works.html#aurora-serverless.how-it-works.auto-scaling)\nin the *Amazon Aurora User Guide*.\n\nThis operation only applies to Aurora Serverless v1 DB clusters.","ref":"AWS.RDS.html#modify_current_db_cluster_capacity/3","title":"AWS.RDS.modify_current_db_cluster_capacity/3","type":"function"},{"doc":"Modifies the status of a custom engine version (CEV).\n\nYou can find CEVs to modify by calling `DescribeDBEngineVersions`.\n\nThe MediaImport service that imports files from Amazon S3 to create CEVs isn't\nintegrated with Amazon Web Services CloudTrail. If you turn on data logging for\nAmazon RDS in CloudTrail, calls to the `ModifyCustomDbEngineVersion` event\naren't logged. However, you might see calls from the API gateway that accesses\nyour Amazon S3 bucket. These calls originate from the MediaImport service for\nthe `ModifyCustomDbEngineVersion` event.\n\nFor more information, see [Modifying CEV status](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/custom-cev.html#custom-cev.modify)\nin the *Amazon RDS User Guide*.","ref":"AWS.RDS.html#modify_custom_db_engine_version/3","title":"AWS.RDS.modify_custom_db_engine_version/3","type":"function"},{"doc":"Modifies the settings of an Amazon Aurora DB cluster or a Multi-AZ DB cluster.\n\nYou can change one or more settings by specifying these parameters and the new\nvalues in the request.\n\nFor more information on Amazon Aurora DB clusters, see [ What is Amazon Aurora?](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/CHAP_AuroraOverview.html)\nin the *Amazon Aurora User Guide*.\n\nFor more information on Multi-AZ DB clusters, see [ Multi-AZ DB cluster deployments](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/multi-az-db-clusters-concepts.html)\nin the *Amazon RDS User Guide*.","ref":"AWS.RDS.html#modify_db_cluster/3","title":"AWS.RDS.modify_db_cluster/3","type":"function"},{"doc":"Modifies the properties of an endpoint in an Amazon Aurora DB cluster.\n\nThis operation only applies to Aurora DB clusters.","ref":"AWS.RDS.html#modify_db_cluster_endpoint/3","title":"AWS.RDS.modify_db_cluster_endpoint/3","type":"function"},{"doc":"Modifies the parameters of a DB cluster parameter group.\n\nTo modify more than one parameter, submit a list of the following:\n`ParameterName`, `ParameterValue`, and `ApplyMethod`. A maximum of 20 parameters\ncan be modified in a single request.\n\nAfter you create a DB cluster parameter group, you should wait at least 5\nminutes before creating your first DB cluster that uses that DB cluster\nparameter group as the default parameter group. This allows Amazon RDS to fully\ncomplete the create operation before the parameter group is used as the default\nfor a new DB cluster. This is especially important for parameters that are\ncritical when creating the default database for a DB cluster, such as the\ncharacter set for the default database defined by the `character_set_database`\nparameter. You can use the *Parameter Groups* option of the [Amazon RDS console](https://console.aws.amazon.com/rds/) or the\n`DescribeDBClusterParameters` operation to verify that your DB cluster parameter\ngroup has been created or modified.\n\nIf the modified DB cluster parameter group is used by an Aurora Serverless v1\ncluster, Aurora applies the update immediately. The cluster restart might\ninterrupt your workload. In that case, your application must reopen any\nconnections and retry any transactions that were active when the parameter\nchanges took effect.\n\nFor more information on Amazon Aurora DB clusters, see [ What is Amazon Aurora?](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/CHAP_AuroraOverview.html)\nin the *Amazon Aurora User Guide*.\n\nFor more information on Multi-AZ DB clusters, see [ Multi-AZ DB cluster deployments](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/multi-az-db-clusters-concepts.html)\nin the *Amazon RDS User Guide.*","ref":"AWS.RDS.html#modify_db_cluster_parameter_group/3","title":"AWS.RDS.modify_db_cluster_parameter_group/3","type":"function"},{"doc":"Adds an attribute and values to, or removes an attribute and values from, a\nmanual DB cluster snapshot.\n\nTo share a manual DB cluster snapshot with other Amazon Web Services accounts,\nspecify `restore` as the `AttributeName` and use the `ValuesToAdd` parameter to\nadd a list of IDs of the Amazon Web Services accounts that are authorized to\nrestore the manual DB cluster snapshot. Use the value `all` to make the manual\nDB cluster snapshot public, which means that it can be copied or restored by all\nAmazon Web Services accounts.\n\nDon't add the `all` value for any manual DB cluster snapshots that contain\nprivate information that you don't want available to all Amazon Web Services\naccounts.\n\nIf a manual DB cluster snapshot is encrypted, it can be shared, but only by\nspecifying a list of authorized Amazon Web Services account IDs for the\n`ValuesToAdd` parameter. You can't use `all` as a value for that parameter in\nthis case.\n\nTo view which Amazon Web Services accounts have access to copy or restore a\nmanual DB cluster snapshot, or whether a manual DB cluster snapshot is public or\nprivate, use the `DescribeDBClusterSnapshotAttributes` API operation. The\naccounts are returned as values for the `restore` attribute.","ref":"AWS.RDS.html#modify_db_cluster_snapshot_attribute/3","title":"AWS.RDS.modify_db_cluster_snapshot_attribute/3","type":"function"},{"doc":"Modifies settings for a DB instance.\n\nYou can change one or more database configuration parameters by specifying these\nparameters and the new values in the request. To learn what modifications you\ncan make to your DB instance, call `DescribeValidDBInstanceModifications` before\nyou call `ModifyDBInstance`.","ref":"AWS.RDS.html#modify_db_instance/3","title":"AWS.RDS.modify_db_instance/3","type":"function"},{"doc":"Modifies the parameters of a DB parameter group.\n\nTo modify more than one parameter, submit a list of the following:\n`ParameterName`, `ParameterValue`, and `ApplyMethod`. A maximum of 20 parameters\ncan be modified in a single request.\n\nAfter you modify a DB parameter group, you should wait at least 5 minutes before\ncreating your first DB instance that uses that DB parameter group as the default\nparameter group. This allows Amazon RDS to fully complete the modify operation\nbefore the parameter group is used as the default for a new DB instance. This is\nespecially important for parameters that are critical when creating the default\ndatabase for a DB instance, such as the character set for the default database\ndefined by the `character_set_database` parameter. You can use the *Parameter\nGroups* option of the [Amazon RDS console](https://console.aws.amazon.com/rds/)\nor the *DescribeDBParameters* command to verify that your DB parameter group has\nbeen created or modified.","ref":"AWS.RDS.html#modify_db_parameter_group/3","title":"AWS.RDS.modify_db_parameter_group/3","type":"function"},{"doc":"Changes the settings for an existing DB proxy.","ref":"AWS.RDS.html#modify_db_proxy/3","title":"AWS.RDS.modify_db_proxy/3","type":"function"},{"doc":"Changes the settings for an existing DB proxy endpoint.","ref":"AWS.RDS.html#modify_db_proxy_endpoint/3","title":"AWS.RDS.modify_db_proxy_endpoint/3","type":"function"},{"doc":"Modifies the properties of a `DBProxyTargetGroup`.","ref":"AWS.RDS.html#modify_db_proxy_target_group/3","title":"AWS.RDS.modify_db_proxy_target_group/3","type":"function"},{"doc":"Updates the recommendation status and recommended action status for the\nspecified recommendation.","ref":"AWS.RDS.html#modify_db_recommendation/3","title":"AWS.RDS.modify_db_recommendation/3","type":"function"},{"doc":"Modifies the settings of an Aurora Limitless Database DB shard group.\n\nYou can change one or more settings by specifying these parameters and the new\nvalues in the request.","ref":"AWS.RDS.html#modify_db_shard_group/3","title":"AWS.RDS.modify_db_shard_group/3","type":"function"},{"doc":"Updates a manual DB snapshot with a new engine version.\n\nThe snapshot can be encrypted or unencrypted, but not shared or public.\n\nAmazon RDS supports upgrading DB snapshots for MySQL, PostgreSQL, and Oracle.\nThis operation doesn't apply to RDS Custom or RDS for Db2.","ref":"AWS.RDS.html#modify_db_snapshot/3","title":"AWS.RDS.modify_db_snapshot/3","type":"function"},{"doc":"Adds an attribute and values to, or removes an attribute and values from, a\nmanual DB snapshot.\n\nTo share a manual DB snapshot with other Amazon Web Services accounts, specify\n`restore` as the `AttributeName` and use the `ValuesToAdd` parameter to add a\nlist of IDs of the Amazon Web Services accounts that are authorized to restore\nthe manual DB snapshot. Uses the value `all` to make the manual DB snapshot\npublic, which means it can be copied or restored by all Amazon Web Services\naccounts.\n\nDon't add the `all` value for any manual DB snapshots that contain private\ninformation that you don't want available to all Amazon Web Services accounts.\n\nIf the manual DB snapshot is encrypted, it can be shared, but only by specifying\na list of authorized Amazon Web Services account IDs for the `ValuesToAdd`\nparameter. You can't use `all` as a value for that parameter in this case.\n\nTo view which Amazon Web Services accounts have access to copy or restore a\nmanual DB snapshot, or whether a manual DB snapshot public or private, use the\n`DescribeDBSnapshotAttributes` API operation. The accounts are returned as\nvalues for the `restore` attribute.","ref":"AWS.RDS.html#modify_db_snapshot_attribute/3","title":"AWS.RDS.modify_db_snapshot_attribute/3","type":"function"},{"doc":"Modifies an existing DB subnet group.\n\nDB subnet groups must contain at least one subnet in at least two AZs in the\nAmazon Web Services Region.","ref":"AWS.RDS.html#modify_db_subnet_group/3","title":"AWS.RDS.modify_db_subnet_group/3","type":"function"},{"doc":"Modifies an existing RDS event notification subscription.\n\nYou can't modify the source identifiers using this call. To change source\nidentifiers for a subscription, use the `AddSourceIdentifierToSubscription` and\n`RemoveSourceIdentifierFromSubscription` calls.\n\nYou can see a list of the event categories for a given source type\n(`SourceType`) in\n[Events](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_Events.html)\nin the *Amazon RDS User Guide* or by using the `DescribeEventCategories`\noperation.","ref":"AWS.RDS.html#modify_event_subscription/3","title":"AWS.RDS.modify_event_subscription/3","type":"function"},{"doc":"Modifies a setting for an Amazon Aurora global database cluster.\n\nYou can change one or more database configuration parameters by specifying these\nparameters and the new values in the request. For more information on Amazon\nAurora, see [ What is Amazon Aurora?](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/CHAP_AuroraOverview.html)\nin the *Amazon Aurora User Guide*.\n\nThis operation only applies to Aurora global database clusters.","ref":"AWS.RDS.html#modify_global_cluster/3","title":"AWS.RDS.modify_global_cluster/3","type":"function"},{"doc":"Modifies an existing option group.","ref":"AWS.RDS.html#modify_option_group/3","title":"AWS.RDS.modify_option_group/3","type":"function"},{"doc":"Modifies an existing tenant database in a DB instance.\n\nYou can change the tenant database name or the master user password. This\noperation is supported only for RDS for Oracle CDB instances using the\nmulti-tenant configuration.","ref":"AWS.RDS.html#modify_tenant_database/3","title":"AWS.RDS.modify_tenant_database/3","type":"function"},{"doc":"Promotes a read replica DB instance to a standalone DB instance.\n\n   Backup duration is a function of the amount of changes to the\ndatabase since the previous backup. If you plan to promote a read replica to a\nstandalone instance, we recommend that you enable backups and complete at least\none backup prior to promotion. In addition, a read replica cannot be promoted to\na standalone instance when it is in the `backing-up` status. If you have enabled\nbackups on your read replica, configure the automated backup window so that\ndaily backups do not interfere with read replica promotion.\n\n   This command doesn't apply to Aurora MySQL, Aurora PostgreSQL, or\nRDS Custom.","ref":"AWS.RDS.html#promote_read_replica/3","title":"AWS.RDS.promote_read_replica/3","type":"function"},{"doc":"Promotes a read replica DB cluster to a standalone DB cluster.","ref":"AWS.RDS.html#promote_read_replica_db_cluster/3","title":"AWS.RDS.promote_read_replica_db_cluster/3","type":"function"},{"doc":"Purchases a reserved DB instance offering.","ref":"AWS.RDS.html#purchase_reserved_db_instances_offering/3","title":"AWS.RDS.purchase_reserved_db_instances_offering/3","type":"function"},{"doc":"You might need to reboot your DB cluster, usually for maintenance reasons.\n\nFor example, if you make certain modifications, or if you change the DB cluster\nparameter group associated with the DB cluster, reboot the DB cluster for the\nchanges to take effect.\n\nRebooting a DB cluster restarts the database engine service. Rebooting a DB\ncluster results in a momentary outage, during which the DB cluster status is set\nto rebooting.\n\nUse this operation only for a non-Aurora Multi-AZ DB cluster.\n\nFor more information on Multi-AZ DB clusters, see [ Multi-AZ DB cluster deployments](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/multi-az-db-clusters-concepts.html)\nin the *Amazon RDS User Guide.*","ref":"AWS.RDS.html#reboot_db_cluster/3","title":"AWS.RDS.reboot_db_cluster/3","type":"function"},{"doc":"You might need to reboot your DB instance, usually for maintenance reasons.\n\nFor example, if you make certain modifications, or if you change the DB\nparameter group associated with the DB instance, you must reboot the instance\nfor the changes to take effect.\n\nRebooting a DB instance restarts the database engine service. Rebooting a DB\ninstance results in a momentary outage, during which the DB instance status is\nset to rebooting.\n\nFor more information about rebooting, see [Rebooting a DB Instance](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_RebootInstance.html)\nin the *Amazon RDS User Guide.*\n\nThis command doesn't apply to RDS Custom.\n\nIf your DB instance is part of a Multi-AZ DB cluster, you can reboot the DB\ncluster with the `RebootDBCluster` operation.","ref":"AWS.RDS.html#reboot_db_instance/3","title":"AWS.RDS.reboot_db_instance/3","type":"function"},{"doc":"You might need to reboot your DB shard group, usually for maintenance reasons.\n\nFor example, if you make certain modifications, reboot the DB shard group for\nthe changes to take effect.\n\nThis operation applies only to Aurora Limitless Database DBb shard groups.","ref":"AWS.RDS.html#reboot_db_shard_group/3","title":"AWS.RDS.reboot_db_shard_group/3","type":"function"},{"doc":"Associate one or more `DBProxyTarget` data structures with a\n`DBProxyTargetGroup`.","ref":"AWS.RDS.html#register_db_proxy_targets/3","title":"AWS.RDS.register_db_proxy_targets/3","type":"function"},{"doc":"Detaches an Aurora secondary cluster from an Aurora global database cluster.\n\nThe cluster becomes a standalone cluster with read-write capability instead of\nbeing read-only and receiving data from a primary cluster in a different Region.\n\nThis operation only applies to Aurora DB clusters.","ref":"AWS.RDS.html#remove_from_global_cluster/3","title":"AWS.RDS.remove_from_global_cluster/3","type":"function"},{"doc":"Removes the asssociation of an Amazon Web Services Identity and Access\nManagement (IAM) role from a DB cluster.\n\nFor more information on Amazon Aurora DB clusters, see [ What is Amazon Aurora?](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/CHAP_AuroraOverview.html)\nin the *Amazon Aurora User Guide*.\n\nFor more information on Multi-AZ DB clusters, see [ Multi-AZ DB cluster deployments](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/multi-az-db-clusters-concepts.html)\nin the *Amazon RDS User Guide.*","ref":"AWS.RDS.html#remove_role_from_db_cluster/3","title":"AWS.RDS.remove_role_from_db_cluster/3","type":"function"},{"doc":"Disassociates an Amazon Web Services Identity and Access Management (IAM) role\nfrom a DB instance.","ref":"AWS.RDS.html#remove_role_from_db_instance/3","title":"AWS.RDS.remove_role_from_db_instance/3","type":"function"},{"doc":"Removes a source identifier from an existing RDS event notification\nsubscription.","ref":"AWS.RDS.html#remove_source_identifier_from_subscription/3","title":"AWS.RDS.remove_source_identifier_from_subscription/3","type":"function"},{"doc":"Removes metadata tags from an Amazon RDS resource.\n\nFor an overview on tagging an Amazon RDS resource, see [Tagging Amazon RDS Resources](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/Overview.Tagging.html)\nin the *Amazon RDS User Guide.*","ref":"AWS.RDS.html#remove_tags_from_resource/3","title":"AWS.RDS.remove_tags_from_resource/3","type":"function"},{"doc":"Modifies the parameters of a DB cluster parameter group to the default value.\n\nTo reset specific parameters submit a list of the following: `ParameterName` and\n`ApplyMethod`. To reset the entire DB cluster parameter group, specify the\n`DBClusterParameterGroupName` and `ResetAllParameters` parameters.\n\nWhen resetting the entire group, dynamic parameters are updated immediately and\nstatic parameters are set to `pending-reboot` to take effect on the next DB\ninstance restart or `RebootDBInstance` request. You must call `RebootDBInstance`\nfor every DB instance in your DB cluster that you want the updated static\nparameter to apply to.\n\nFor more information on Amazon Aurora DB clusters, see [ What is Amazon Aurora?](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/CHAP_AuroraOverview.html)\nin the *Amazon Aurora User Guide*.\n\nFor more information on Multi-AZ DB clusters, see [ Multi-AZ DB cluster deployments](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/multi-az-db-clusters-concepts.html)\nin the *Amazon RDS User Guide.*","ref":"AWS.RDS.html#reset_db_cluster_parameter_group/3","title":"AWS.RDS.reset_db_cluster_parameter_group/3","type":"function"},{"doc":"Modifies the parameters of a DB parameter group to the engine/system default\nvalue.\n\nTo reset specific parameters, provide a list of the following: `ParameterName`\nand `ApplyMethod`. To reset the entire DB parameter group, specify the\n`DBParameterGroup` name and `ResetAllParameters` parameters. When resetting the\nentire group, dynamic parameters are updated immediately and static parameters\nare set to `pending-reboot` to take effect on the next DB instance restart or\n`RebootDBInstance` request.","ref":"AWS.RDS.html#reset_db_parameter_group/3","title":"AWS.RDS.reset_db_parameter_group/3","type":"function"},{"doc":"Creates an Amazon Aurora DB cluster from MySQL data stored in an Amazon S3\nbucket.\n\nAmazon RDS must be authorized to access the Amazon S3 bucket and the data must\nbe created using the Percona XtraBackup utility as described in [ Migrating Data from MySQL by Using an Amazon S3\nBucket](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/AuroraMySQL.Migrating.ExtMySQL.html#AuroraMySQL.Migrating.ExtMySQL.S3)\nin the *Amazon Aurora User Guide*.\n\nThis operation only restores the DB cluster, not the DB instances for that DB\ncluster. You must invoke the `CreateDBInstance` operation to create DB instances\nfor the restored DB cluster, specifying the identifier of the restored DB\ncluster in `DBClusterIdentifier`. You can create DB instances only after the\n`RestoreDBClusterFromS3` operation has completed and the DB cluster is\navailable.\n\nFor more information on Amazon Aurora, see [ What is Amazon Aurora?](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/CHAP_AuroraOverview.html)\nin the *Amazon Aurora User Guide*.\n\nThis operation only applies to Aurora DB clusters. The source DB engine must be\nMySQL.","ref":"AWS.RDS.html#restore_db_cluster_from_s3/3","title":"AWS.RDS.restore_db_cluster_from_s3/3","type":"function"},{"doc":"Creates a new DB cluster from a DB snapshot or DB cluster snapshot.\n\nThe target DB cluster is created from the source snapshot with a default\nconfiguration. If you don't specify a security group, the new DB cluster is\nassociated with the default security group.\n\nThis operation only restores the DB cluster, not the DB instances for that DB\ncluster. You must invoke the `CreateDBInstance` operation to create DB instances\nfor the restored DB cluster, specifying the identifier of the restored DB\ncluster in `DBClusterIdentifier`. You can create DB instances only after the\n`RestoreDBClusterFromSnapshot` operation has completed and the DB cluster is\navailable.\n\nFor more information on Amazon Aurora DB clusters, see [ What is Amazon Aurora?](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/CHAP_AuroraOverview.html)\nin the *Amazon Aurora User Guide*.\n\nFor more information on Multi-AZ DB clusters, see [ Multi-AZ DB cluster deployments](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/multi-az-db-clusters-concepts.html)\nin the *Amazon RDS User Guide.*","ref":"AWS.RDS.html#restore_db_cluster_from_snapshot/3","title":"AWS.RDS.restore_db_cluster_from_snapshot/3","type":"function"},{"doc":"Restores a DB cluster to an arbitrary point in time.\n\nUsers can restore to any point in time before `LatestRestorableTime` for up to\n`BackupRetentionPeriod` days. The target DB cluster is created from the source\nDB cluster with the same configuration as the original DB cluster, except that\nthe new DB cluster is created with the default DB security group.\n\nFor Aurora, this operation only restores the DB cluster, not the DB instances\nfor that DB cluster. You must invoke the `CreateDBInstance` operation to create\nDB instances for the restored DB cluster, specifying the identifier of the\nrestored DB cluster in `DBClusterIdentifier`. You can create DB instances only\nafter the `RestoreDBClusterToPointInTime` operation has completed and the DB\ncluster is available.\n\nFor more information on Amazon Aurora DB clusters, see [ What is Amazon Aurora?](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/CHAP_AuroraOverview.html)\nin the *Amazon Aurora User Guide*.\n\nFor more information on Multi-AZ DB clusters, see [ Multi-AZ DB cluster deployments](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/multi-az-db-clusters-concepts.html)\nin the *Amazon RDS User Guide.*","ref":"AWS.RDS.html#restore_db_cluster_to_point_in_time/3","title":"AWS.RDS.restore_db_cluster_to_point_in_time/3","type":"function"},{"doc":"Creates a new DB instance from a DB snapshot.\n\nThe target database is created from the source database restore point with most\nof the source's original configuration, including the default security group and\nDB parameter group. By default, the new DB instance is created as a Single-AZ\ndeployment, except when the instance is a SQL Server instance that has an option\ngroup associated with mirroring. In this case, the instance becomes a Multi-AZ\ndeployment, not a Single-AZ deployment.\n\nIf you want to replace your original DB instance with the new, restored DB\ninstance, then rename your original DB instance before you call the\n`RestoreDBInstanceFromDBSnapshot` operation. RDS doesn't allow two DB instances\nwith the same name. After you have renamed your original DB instance with a\ndifferent identifier, then you can pass the original name of the DB instance as\nthe `DBInstanceIdentifier` in the call to the `RestoreDBInstanceFromDBSnapshot`\noperation. The result is that you replace the original DB instance with the DB\ninstance created from the snapshot.\n\nIf you are restoring from a shared manual DB snapshot, the\n`DBSnapshotIdentifier` must be the ARN of the shared DB snapshot.\n\nThis command doesn't apply to Aurora MySQL and Aurora PostgreSQL. For Aurora,\nuse `RestoreDBClusterFromSnapshot`.","ref":"AWS.RDS.html#restore_db_instance_from_db_snapshot/3","title":"AWS.RDS.restore_db_instance_from_db_snapshot/3","type":"function"},{"doc":"Amazon Relational Database Service (Amazon RDS) supports importing MySQL\ndatabases by using backup files.\n\nYou can create a backup of your on-premises database, store it on Amazon Simple\nStorage Service (Amazon S3), and then restore the backup file onto a new Amazon\nRDS DB instance running MySQL. For more information, see [Importing Data into an Amazon RDS MySQL DB\nInstance](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/MySQL.Procedural.Importing.html)\nin the *Amazon RDS User Guide.*\n\nThis operation doesn't apply to RDS Custom.","ref":"AWS.RDS.html#restore_db_instance_from_s3/3","title":"AWS.RDS.restore_db_instance_from_s3/3","type":"function"},{"doc":"Restores a DB instance to an arbitrary point in time.\n\nYou can restore to any point in time before the time identified by the\n`LatestRestorableTime` property. You can restore to a point up to the number of\ndays specified by the `BackupRetentionPeriod` property.\n\nThe target database is created with most of the original configuration, but in a\nsystem-selected Availability Zone, with the default security group, the default\nsubnet group, and the default DB parameter group. By default, the new DB\ninstance is created as a single-AZ deployment except when the instance is a SQL\nServer instance that has an option group that is associated with mirroring; in\nthis case, the instance becomes a mirrored deployment and not a single-AZ\ndeployment.\n\nThis operation doesn't apply to Aurora MySQL and Aurora PostgreSQL. For Aurora,\nuse `RestoreDBClusterToPointInTime`.","ref":"AWS.RDS.html#restore_db_instance_to_point_in_time/3","title":"AWS.RDS.restore_db_instance_to_point_in_time/3","type":"function"},{"doc":"Revokes ingress from a DBSecurityGroup for previously authorized IP ranges or\nEC2 or VPC security groups.\n\nRequired parameters for this API are one of CIDRIP, EC2SecurityGroupId for VPC,\nor (EC2SecurityGroupOwnerId and either EC2SecurityGroupName or\nEC2SecurityGroupId).\n\nEC2-Classic was retired on August 15, 2022. If you haven't migrated from\nEC2-Classic to a VPC, we recommend that you migrate as soon as possible. For\nmore information, see [Migrate from EC2-Classic to a VPC](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/vpc-migrate.html) in\nthe *Amazon EC2 User Guide*, the blog [EC2-Classic Networking is Retiring – Here’s How to\nPrepare](http://aws.amazon.com/blogs/aws/ec2-classic-is-retiring-heres-how-to-prepare/),\nand [Moving a DB instance not in a VPC into a VPC](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_VPC.Non-VPC2VPC.html)\nin the *Amazon RDS User Guide*.","ref":"AWS.RDS.html#revoke_db_security_group_ingress/3","title":"AWS.RDS.revoke_db_security_group_ingress/3","type":"function"},{"doc":"Starts a database activity stream to monitor activity on the database.\n\nFor more information, see [ Monitoring Amazon Aurora with Database Activity Streams](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/DBActivityStreams.html)\nin the *Amazon Aurora User Guide* or [ Monitoring Amazon RDS with Database Activity\nStreams](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/DBActivityStreams.html)\nin the *Amazon RDS User Guide*.","ref":"AWS.RDS.html#start_activity_stream/3","title":"AWS.RDS.start_activity_stream/3","type":"function"},{"doc":"Starts an Amazon Aurora DB cluster that was stopped using the Amazon Web\nServices console, the stop-db-cluster CLI command, or the `StopDBCluster`\noperation.\n\nFor more information, see [ Stopping and Starting an Aurora Cluster](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/aurora-cluster-stop-start.html)\nin the *Amazon Aurora User Guide*.\n\nThis operation only applies to Aurora DB clusters.","ref":"AWS.RDS.html#start_db_cluster/3","title":"AWS.RDS.start_db_cluster/3","type":"function"},{"doc":"Starts an Amazon RDS DB instance that was stopped using the Amazon Web Services\nconsole, the stop-db-instance CLI command, or the `StopDBInstance` operation.\n\nFor more information, see [ Starting an Amazon RDS DB instance That Was Previously\nStopped](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_StartInstance.html)\nin the *Amazon RDS User Guide.*\n\nThis command doesn't apply to RDS Custom, Aurora MySQL, and Aurora PostgreSQL.\nFor Aurora DB clusters, use `StartDBCluster` instead.","ref":"AWS.RDS.html#start_db_instance/3","title":"AWS.RDS.start_db_instance/3","type":"function"},{"doc":"Enables replication of automated backups to a different Amazon Web Services\nRegion.\n\nThis command doesn't apply to RDS Custom.\n\nFor more information, see [ Replicating Automated Backups to Another Amazon Web Services\nRegion](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_ReplicateBackups.html)\nin the *Amazon RDS User Guide.*","ref":"AWS.RDS.html#start_db_instance_automated_backups_replication/3","title":"AWS.RDS.start_db_instance_automated_backups_replication/3","type":"function"},{"doc":"Starts an export of DB snapshot or DB cluster data to Amazon S3.\n\nThe provided IAM role must have access to the S3 bucket.\n\nYou can't export snapshot data from Db2 or RDS Custom DB instances.\n\nYou can't export cluster data from Multi-AZ DB clusters.\n\nFor more information on exporting DB snapshot data, see [Exporting DB snapshot data to Amazon\nS3](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_ExportSnapshot.html)\nin the *Amazon RDS User Guide* or [Exporting DB cluster snapshot data to Amazon S3](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/aurora-export-snapshot.html)\nin the *Amazon Aurora User Guide*.\n\nFor more information on exporting DB cluster data, see [Exporting DB cluster data to Amazon\nS3](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/export-cluster-data.html)\nin the *Amazon Aurora User Guide*.","ref":"AWS.RDS.html#start_export_task/3","title":"AWS.RDS.start_export_task/3","type":"function"},{"doc":"Stops a database activity stream that was started using the Amazon Web Services\nconsole, the `start-activity-stream` CLI command, or the `StartActivityStream`\noperation.\n\nFor more information, see [ Monitoring Amazon Aurora with Database Activity Streams](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/DBActivityStreams.html)\nin the *Amazon Aurora User Guide* or [ Monitoring Amazon RDS with Database Activity\nStreams](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/DBActivityStreams.html)\nin the *Amazon RDS User Guide*.","ref":"AWS.RDS.html#stop_activity_stream/3","title":"AWS.RDS.stop_activity_stream/3","type":"function"},{"doc":"Stops an Amazon Aurora DB cluster.\n\nWhen you stop a DB cluster, Aurora retains the DB cluster's metadata, including\nits endpoints and DB parameter groups. Aurora also retains the transaction logs\nso you can do a point-in-time restore if necessary.\n\nFor more information, see [ Stopping and Starting an Aurora Cluster](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/aurora-cluster-stop-start.html)\nin the *Amazon Aurora User Guide*.\n\nThis operation only applies to Aurora DB clusters.","ref":"AWS.RDS.html#stop_db_cluster/3","title":"AWS.RDS.stop_db_cluster/3","type":"function"},{"doc":"Stops an Amazon RDS DB instance.\n\nWhen you stop a DB instance, Amazon RDS retains the DB instance's metadata,\nincluding its endpoint, DB parameter group, and option group membership. Amazon\nRDS also retains the transaction logs so you can do a point-in-time restore if\nnecessary.\n\nFor more information, see [ Stopping an Amazon RDS DB Instance Temporarily](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_StopInstance.html)\nin the *Amazon RDS User Guide.*\n\nThis command doesn't apply to RDS Custom, Aurora MySQL, and Aurora PostgreSQL.\nFor Aurora clusters, use `StopDBCluster` instead.","ref":"AWS.RDS.html#stop_db_instance/3","title":"AWS.RDS.stop_db_instance/3","type":"function"},{"doc":"Stops automated backup replication for a DB instance.\n\nThis command doesn't apply to RDS Custom, Aurora MySQL, and Aurora PostgreSQL.\n\nFor more information, see [ Replicating Automated Backups to Another Amazon Web Services\nRegion](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_ReplicateBackups.html)\nin the *Amazon RDS User Guide.*","ref":"AWS.RDS.html#stop_db_instance_automated_backups_replication/3","title":"AWS.RDS.stop_db_instance_automated_backups_replication/3","type":"function"},{"doc":"Switches over a blue/green deployment.\n\nBefore you switch over, production traffic is routed to the databases in the\nblue environment. After you switch over, production traffic is routed to the\ndatabases in the green environment.\n\nFor more information, see [Using Amazon RDS Blue/Green Deployments for database updates](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/blue-green-deployments.html)\nin the *Amazon RDS User Guide* and [Using Amazon RDS Blue/Green Deployments for database\nupdates](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/blue-green-deployments.html)\nin the *Amazon Aurora User Guide*.","ref":"AWS.RDS.html#switchover_blue_green_deployment/3","title":"AWS.RDS.switchover_blue_green_deployment/3","type":"function"},{"doc":"Switches over the specified secondary DB cluster to be the new primary DB\ncluster in the global database cluster.\n\nSwitchover operations were previously called \"managed planned failovers.\"\n\nAurora promotes the specified secondary cluster to assume full read/write\ncapabilities and demotes the current primary cluster to a secondary (read-only)\ncluster, maintaining the orginal replication topology. All secondary clusters\nare synchronized with the primary at the beginning of the process so the new\nprimary continues operations for the Aurora global database without losing any\ndata. Your database is unavailable for a short time while the primary and\nselected secondary clusters are assuming their new roles. For more information\nabout switching over an Aurora global database, see [Performing switchovers for Amazon Aurora global\ndatabases](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/aurora-global-database-disaster-recovery.html#aurora-global-database-disaster-recovery.managed-failover)\nin the *Amazon Aurora User Guide*.\n\nThis operation is intended for controlled environments, for operations such as\n\"regional rotation\" or to fall back to the original primary after a global\ndatabase failover.","ref":"AWS.RDS.html#switchover_global_cluster/3","title":"AWS.RDS.switchover_global_cluster/3","type":"function"},{"doc":"Switches over an Oracle standby database in an Oracle Data Guard environment,\nmaking it the new primary database.\n\nIssue this command in the Region that hosts the current standby database.","ref":"AWS.RDS.html#switchover_read_replica/3","title":"AWS.RDS.switchover_read_replica/3","type":"function"},{"doc":"RDS Data API\n\nAmazon RDS provides an HTTP endpoint to run SQL statements on an Amazon Aurora\nDB cluster.\n\nTo run these statements, you use the RDS Data API (Data API).\n\nData API is available with the following types of Aurora databases:\n\n  * Aurora PostgreSQL - Serverless v2, Serverless v1, and provisioned\n\n  * Aurora MySQL - Serverless v1 only\n\nFor more information about the Data API, see [Using RDS Data API](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/data-api.html)\nin the *Amazon Aurora User Guide*.","ref":"AWS.RDSData.html","title":"AWS.RDSData","type":"module"},{"doc":"Runs a batch SQL statement over an array of data.\n\nYou can run bulk update and insert operations for multiple records using a DML\nstatement with different parameter sets. Bulk operations can provide a\nsignificant performance improvement over individual insert and update\noperations.\n\nIf a call isn't part of a transaction because it doesn't include the\n`transactionID` parameter, changes that result from the call are committed\nautomatically.\n\nThere isn't a fixed upper limit on the number of parameter sets. However, the\nmaximum size of the HTTP request submitted through the Data API is 4 MiB. If the\nrequest exceeds this limit, the Data API returns an error and doesn't process\nthe request. This 4-MiB limit includes the size of the HTTP headers and the JSON\nnotation in the request. Thus, the number of parameter sets that you can include\ndepends on a combination of factors, such as the size of the SQL statement and\nthe size of each parameter set.\n\nThe response size limit is 1 MiB. If the call returns more than 1 MiB of\nresponse data, the call is terminated.","ref":"AWS.RDSData.html#batch_execute_statement/3","title":"AWS.RDSData.batch_execute_statement/3","type":"function"},{"doc":"Starts a SQL transaction.\n\nA transaction can run for a maximum of 24 hours. A transaction is terminated and\nrolled back automatically after 24 hours.\n\nA transaction times out if no calls use its transaction ID in three minutes. If\na transaction times out before it's committed, it's rolled back automatically.\n\nDDL statements inside a transaction cause an implicit commit. We recommend that\nyou run each DDL statement in a separate `ExecuteStatement` call with\n`continueAfterTimeout` enabled.","ref":"AWS.RDSData.html#begin_transaction/3","title":"AWS.RDSData.begin_transaction/3","type":"function"},{"doc":"Ends a SQL transaction started with the `BeginTransaction` operation and commits\nthe changes.","ref":"AWS.RDSData.html#commit_transaction/3","title":"AWS.RDSData.commit_transaction/3","type":"function"},{"doc":"Runs one or more SQL statements.\n\nThis operation isn't supported for Aurora PostgreSQL Serverless v2 and\nprovisioned DB clusters, and for Aurora Serverless v1 DB clusters, the operation\nis deprecated. Use the `BatchExecuteStatement` or `ExecuteStatement` operation.","ref":"AWS.RDSData.html#execute_sql/3","title":"AWS.RDSData.execute_sql/3","type":"function"},{"doc":"Runs a SQL statement against a database.\n\nIf a call isn't part of a transaction because it doesn't include the\n`transactionID` parameter, changes that result from the call are committed\nautomatically.\n\nIf the binary response data from the database is more than 1 MB, the call is\nterminated.","ref":"AWS.RDSData.html#execute_statement/3","title":"AWS.RDSData.execute_statement/3","type":"function"},{"doc":"","ref":"AWS.RDSData.html#metadata/0","title":"AWS.RDSData.metadata/0","type":"function"},{"doc":"Performs a rollback of a transaction.\n\nRolling back a transaction cancels its changes.","ref":"AWS.RDSData.html#rollback_transaction/3","title":"AWS.RDSData.rollback_transaction/3","type":"function"},{"doc":"With Amazon CloudWatch RUM, you can perform real-user monitoring to collect\nclient-side data about your web application performance from actual user\nsessions in real time.\n\nThe data collected includes page load times, client-side errors, and user\nbehavior. When you view this data, you can see it all aggregated together and\nalso see breakdowns by the browsers and devices that your customers use.\n\nYou can use the collected data to quickly identify and debug client-side\nperformance issues. CloudWatch RUM helps you visualize anomalies in your\napplication performance and find relevant debugging data such as error messages,\nstack traces, and user sessions. You can also use RUM to understand the range of\nend-user impact including the number of users, geolocations, and browsers used.","ref":"AWS.RUM.html","title":"AWS.RUM","type":"module"},{"doc":"Specifies the extended metrics and custom metrics that you want a CloudWatch RUM\napp monitor to send to a destination.\n\nValid destinations include CloudWatch and Evidently.\n\nBy default, RUM app monitors send some metrics to CloudWatch. These default\nmetrics are listed in [CloudWatch metrics that you can collect with CloudWatch RUM](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch-RUM-metrics.html).\n\nIn addition to these default metrics, you can choose to send extended metrics or\ncustom metrics or both.\n\n  * Extended metrics enable you to send metrics with additional\ndimensions not included in the default metrics. You can also send extended\nmetrics to Evidently as well as CloudWatch. The valid dimension names for the\nadditional dimensions for extended metrics are `BrowserName`, `CountryCode`,\n`DeviceType`, `FileType`, `OSName`, and `PageId`. For more information, see [\nExtended metrics that you can send to CloudWatch and CloudWatch\nEvidently](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch-RUM-vended-metrics.html).\n\n  * Custom metrics are metrics that you define. You can send custom\nmetrics to CloudWatch or to CloudWatch Evidently or to both. With custom\nmetrics, you can use any metric name and namespace, and to derive the metrics\nyou can use any custom events, built-in events, custom attributes, or default\nattributes.\n\nYou can't send custom metrics to the `AWS/RUM` namespace. You must send custom\nmetrics to a custom namespace that you define. The namespace that you use can't\nstart with `AWS/`. CloudWatch RUM prepends `RUM/CustomMetrics/` to the custom\nnamespace that you define, so the final namespace for your metrics in CloudWatch\nis `RUM/CustomMetrics/*your-custom-namespace* `.\n\nThe maximum number of metric definitions that you can specify in one\n`BatchCreateRumMetricDefinitions` operation is 200.\n\nThe maximum number of metric definitions that one destination can contain is\n2000.\n\nExtended metrics sent to CloudWatch and RUM custom metrics are charged as\nCloudWatch custom metrics. Each combination of additional dimension name and\ndimension value counts as a custom metric. For more information, see [Amazon CloudWatch Pricing](https://aws.amazon.com/cloudwatch/pricing/).\n\nYou must have already created a destination for the metrics before you send\nthem. For more information, see\n[PutRumMetricsDestination](https://docs.aws.amazon.com/cloudwatchrum/latest/APIReference/API_PutRumMetricsDestination.html).\n\nIf some metric definitions specified in a `BatchCreateRumMetricDefinitions`\noperations are not valid, those metric definitions fail and return errors, but\nall valid metric definitions in the same operation still succeed.","ref":"AWS.RUM.html#batch_create_rum_metric_definitions/4","title":"AWS.RUM.batch_create_rum_metric_definitions/4","type":"function"},{"doc":"Removes the specified metrics from being sent to an extended metrics\ndestination.\n\nIf some metric definition IDs specified in a `BatchDeleteRumMetricDefinitions`\noperations are not valid, those metric definitions fail and return errors, but\nall valid metric definition IDs in the same operation are still deleted.\n\nThe maximum number of metric definitions that you can specify in one\n`BatchDeleteRumMetricDefinitions` operation is 200.","ref":"AWS.RUM.html#batch_delete_rum_metric_definitions/4","title":"AWS.RUM.batch_delete_rum_metric_definitions/4","type":"function"},{"doc":"Retrieves the list of metrics and dimensions that a RUM app monitor is sending\nto a single destination.","ref":"AWS.RUM.html#batch_get_rum_metric_definitions/7","title":"AWS.RUM.batch_get_rum_metric_definitions/7","type":"function"},{"doc":"Creates a Amazon CloudWatch RUM app monitor, which collects telemetry data from\nyour application and sends that data to RUM.\n\nThe data includes performance and reliability information such as page load\ntime, client-side errors, and user behavior.\n\nYou use this operation only to create a new app monitor. To update an existing\napp monitor, use\n[UpdateAppMonitor](https://docs.aws.amazon.com/cloudwatchrum/latest/APIReference/API_UpdateAppMonitor.html) instead.\n\nAfter you create an app monitor, sign in to the CloudWatch RUM console to get\nthe JavaScript code snippet to add to your web application. For more\ninformation, see [How do I find a code snippet that I've already\ngenerated?](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch-RUM-find-code-snippet.html)","ref":"AWS.RUM.html#create_app_monitor/3","title":"AWS.RUM.create_app_monitor/3","type":"function"},{"doc":"Deletes an existing app monitor.\n\nThis immediately stops the collection of data.","ref":"AWS.RUM.html#delete_app_monitor/4","title":"AWS.RUM.delete_app_monitor/4","type":"function"},{"doc":"Deletes a destination for CloudWatch RUM extended metrics, so that the specified\napp monitor stops sending extended metrics to that destination.","ref":"AWS.RUM.html#delete_rum_metrics_destination/4","title":"AWS.RUM.delete_rum_metrics_destination/4","type":"function"},{"doc":"Retrieves the complete configuration information for one app monitor.","ref":"AWS.RUM.html#get_app_monitor/3","title":"AWS.RUM.get_app_monitor/3","type":"function"},{"doc":"Retrieves the raw performance events that RUM has collected from your web\napplication, so that you can do your own processing or analysis of this data.","ref":"AWS.RUM.html#get_app_monitor_data/4","title":"AWS.RUM.get_app_monitor_data/4","type":"function"},{"doc":"Returns a list of the Amazon CloudWatch RUM app monitors in the account.","ref":"AWS.RUM.html#list_app_monitors/3","title":"AWS.RUM.list_app_monitors/3","type":"function"},{"doc":"Returns a list of destinations that you have created to receive RUM extended\nmetrics, for the specified app monitor.\n\nFor more information about extended metrics, see\n[AddRumMetrics](https://docs.aws.amazon.com/cloudwatchrum/latest/APIReference/API_AddRumMetrcs.html).","ref":"AWS.RUM.html#list_rum_metrics_destinations/5","title":"AWS.RUM.list_rum_metrics_destinations/5","type":"function"},{"doc":"Displays the tags associated with a CloudWatch RUM resource.","ref":"AWS.RUM.html#list_tags_for_resource/3","title":"AWS.RUM.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.RUM.html#metadata/0","title":"AWS.RUM.metadata/0","type":"function"},{"doc":"Sends telemetry events about your application performance and user behavior to\nCloudWatch RUM.\n\nThe code snippet that RUM generates for you to add to your application includes\n`PutRumEvents` operations to send this data to RUM.\n\nEach `PutRumEvents` operation can send a batch of events from one user session.","ref":"AWS.RUM.html#put_rum_events/4","title":"AWS.RUM.put_rum_events/4","type":"function"},{"doc":"Creates or updates a destination to receive extended metrics from CloudWatch\nRUM.\n\nYou can send extended metrics to CloudWatch or to a CloudWatch Evidently\nexperiment.\n\nFor more information about extended metrics, see\n[BatchCreateRumMetricDefinitions](https://docs.aws.amazon.com/cloudwatchrum/latest/APIReference/API_BatchCreateRumMetricDefinitions.html).","ref":"AWS.RUM.html#put_rum_metrics_destination/4","title":"AWS.RUM.put_rum_metrics_destination/4","type":"function"},{"doc":"Assigns one or more tags (key-value pairs) to the specified CloudWatch RUM\nresource.\n\nCurrently, the only resources that can be tagged app monitors.\n\nTags can help you organize and categorize your resources. You can also use them\nto scope user permissions by granting a user permission to access or change only\nresources with certain tag values.\n\nTags don't have any semantic meaning to Amazon Web Services and are interpreted\nstrictly as strings of characters.\n\nYou can use the `TagResource` action with a resource that already has tags. If\nyou specify a new tag key for the resource, this tag is appended to the list of\ntags associated with the alarm. If you specify a tag key that is already\nassociated with the resource, the new tag value that you specify replaces the\nprevious value for that tag.\n\nYou can associate as many as 50 tags with a resource.\n\nFor more information, see [Tagging Amazon Web Services resources](https://docs.aws.amazon.com/general/latest/gr/aws_tagging.html).","ref":"AWS.RUM.html#tag_resource/4","title":"AWS.RUM.tag_resource/4","type":"function"},{"doc":"Removes one or more tags from the specified resource.","ref":"AWS.RUM.html#untag_resource/4","title":"AWS.RUM.untag_resource/4","type":"function"},{"doc":"Updates the configuration of an existing app monitor.\n\nWhen you use this operation, only the parts of the app monitor configuration\nthat you specify in this operation are changed. For any parameters that you\nomit, the existing values are kept.\n\nYou can't use this operation to change the tags of an existing app monitor. To\nchange the tags of an existing app monitor, use\n[TagResource](https://docs.aws.amazon.com/cloudwatchrum/latest/APIReference/API_TagResource.html).  To create a new app monitor, use\n[CreateAppMonitor](https://docs.aws.amazon.com/cloudwatchrum/latest/APIReference/API_CreateAppMonitor.html).\n\nAfter you update an app monitor, sign in to the CloudWatch RUM console to get\nthe updated JavaScript code snippet to add to your web application. For more\ninformation, see [How do I find a code snippet that I've already generated?](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch-RUM-find-code-snippet.html)","ref":"AWS.RUM.html#update_app_monitor/4","title":"AWS.RUM.update_app_monitor/4","type":"function"},{"doc":"Modifies one existing metric definition for CloudWatch RUM extended metrics.\n\nFor more information about extended metrics, see\n[BatchCreateRumMetricsDefinitions](https://docs.aws.amazon.com/cloudwatchrum/latest/APIReference/API_BatchCreateRumMetricsDefinitions.html).","ref":"AWS.RUM.html#update_rum_metric_definition/4","title":"AWS.RUM.update_rum_metric_definition/4","type":"function"},{"doc":"This is the *Recycle Bin API Reference*.\n\nThis documentation provides descriptions and syntax for each of the actions and\ndata types in Recycle Bin.\n\nRecycle Bin is a resource recovery feature that enables you to restore\naccidentally deleted snapshots and EBS-backed AMIs. When using Recycle Bin, if\nyour resources are deleted, they are retained in the Recycle Bin for a time\nperiod that you specify.\n\nYou can restore a resource from the Recycle Bin at any time before its retention\nperiod expires. After you restore a resource from the Recycle Bin, the resource\nis removed from the Recycle Bin, and you can then use it in the same way you use\nany other resource of that type in your account. If the retention period expires\nand the resource is not restored, the resource is permanently deleted from the\nRecycle Bin and is no longer available for recovery. For more information about\nRecycle Bin, see [ Recycle Bin](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/recycle-bin.html) in\nthe *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.Rbin.html","title":"AWS.Rbin","type":"module"},{"doc":"Creates a Recycle Bin retention rule.\n\nFor more information, see [ Create Recycle Bin retention rules](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/recycle-bin-working-with-rules.html#recycle-bin-create-rule)\nin the *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.Rbin.html#create_rule/3","title":"AWS.Rbin.create_rule/3","type":"function"},{"doc":"Deletes a Recycle Bin retention rule.\n\nFor more information, see [ Delete Recycle Bin retention rules](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/recycle-bin-working-with-rules.html#recycle-bin-delete-rule)\nin the *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.Rbin.html#delete_rule/4","title":"AWS.Rbin.delete_rule/4","type":"function"},{"doc":"Gets information about a Recycle Bin retention rule.","ref":"AWS.Rbin.html#get_rule/3","title":"AWS.Rbin.get_rule/3","type":"function"},{"doc":"Lists the Recycle Bin retention rules in the Region.","ref":"AWS.Rbin.html#list_rules/3","title":"AWS.Rbin.list_rules/3","type":"function"},{"doc":"Lists the tags assigned to a retention rule.","ref":"AWS.Rbin.html#list_tags_for_resource/3","title":"AWS.Rbin.list_tags_for_resource/3","type":"function"},{"doc":"Locks a retention rule.\n\nA locked retention rule can't be modified or deleted.","ref":"AWS.Rbin.html#lock_rule/4","title":"AWS.Rbin.lock_rule/4","type":"function"},{"doc":"","ref":"AWS.Rbin.html#metadata/0","title":"AWS.Rbin.metadata/0","type":"function"},{"doc":"Assigns tags to the specified retention rule.","ref":"AWS.Rbin.html#tag_resource/4","title":"AWS.Rbin.tag_resource/4","type":"function"},{"doc":"Unlocks a retention rule.\n\nAfter a retention rule is unlocked, it can be modified or deleted only after the\nunlock delay period expires.","ref":"AWS.Rbin.html#unlock_rule/4","title":"AWS.Rbin.unlock_rule/4","type":"function"},{"doc":"Unassigns a tag from a retention rule.","ref":"AWS.Rbin.html#untag_resource/4","title":"AWS.Rbin.untag_resource/4","type":"function"},{"doc":"Updates an existing Recycle Bin retention rule.\n\nYou can update a retention rule's description, resource tags, and retention\nperiod at any time after creation. You can't update a retention rule's resource\ntype after creation. For more information, see [ Update Recycle Bin retention rules](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/recycle-bin-working-with-rules.html#recycle-bin-update-rule)\nin the *Amazon Elastic Compute Cloud User Guide*.","ref":"AWS.Rbin.html#update_rule/4","title":"AWS.Rbin.update_rule/4","type":"function"},{"doc":"Amazon Redshift","ref":"AWS.Redshift.html","title":"AWS.Redshift","type":"module"},{"doc":"This is an interface reference for Amazon Redshift.\n\nIt contains documentation for one of the programming or command line interfaces\nyou can use to manage Amazon Redshift clusters. Note that Amazon Redshift is\nasynchronous, which means that some interfaces may require techniques, such as\npolling or asynchronous callback handlers, to determine when a command has been\napplied. In this reference, the parameter descriptions indicate whether a change\nis applied immediately, on the next instance reboot, or during the next\nmaintenance window. For a summary of the Amazon Redshift cluster management\ninterfaces, go to [Using the Amazon Redshift Management Interfaces](https://docs.aws.amazon.com/redshift/latest/mgmt/using-aws-sdk.html).\n\nAmazon Redshift manages all the work of setting up, operating, and scaling a\ndata warehouse: provisioning capacity, monitoring and backing up the cluster,\nand applying patches and upgrades to the Amazon Redshift engine. You can focus\non using your data to acquire new insights for your business and customers.\n\nIf you are a first-time user of Amazon Redshift, we recommend that you begin by\nreading the [Amazon Redshift Getting Started Guide](https://docs.aws.amazon.com/redshift/latest/gsg/getting-started.html).\n\nIf you are a database developer, the [Amazon Redshift Database Developer Guide](https://docs.aws.amazon.com/redshift/latest/dg/welcome.html) explains how\nto design, build, query, and maintain the databases that make up your data\nwarehouse.","ref":"AWS.Redshift.html#module-overview","title":"Overview - AWS.Redshift","type":"module"},{"doc":"Exchanges a DC1 Reserved Node for a DC2 Reserved Node with no changes to the\nconfiguration (term, payment type, or number of nodes) and no additional costs.","ref":"AWS.Redshift.html#accept_reserved_node_exchange/3","title":"AWS.Redshift.accept_reserved_node_exchange/3","type":"function"},{"doc":"Adds a partner integration to a cluster.\n\nThis operation authorizes a partner to push status updates for the specified\ndatabase. To complete the integration, you also set up the integration on the\npartner website.","ref":"AWS.Redshift.html#add_partner/3","title":"AWS.Redshift.add_partner/3","type":"function"},{"doc":"From a datashare consumer account, associates a datashare with the account\n(AssociateEntireAccount) or the specified namespace (ConsumerArn).\n\nIf you make this association, the consumer can consume the datashare.","ref":"AWS.Redshift.html#associate_data_share_consumer/3","title":"AWS.Redshift.associate_data_share_consumer/3","type":"function"},{"doc":"Adds an inbound (ingress) rule to an Amazon Redshift security group.\n\nDepending on whether the application accessing your cluster is running on the\nInternet or an Amazon EC2 instance, you can authorize inbound access to either a\nClassless Interdomain Routing (CIDR)/Internet Protocol (IP) range or to an\nAmazon EC2 security group. You can add as many as 20 ingress rules to an Amazon\nRedshift security group.\n\nIf you authorize access to an Amazon EC2 security group, specify\n*EC2SecurityGroupName* and *EC2SecurityGroupOwnerId*. The Amazon EC2 security\ngroup and Amazon Redshift cluster must be in the same Amazon Web Services\nRegion.\n\nIf you authorize access to a CIDR/IP address range, specify *CIDRIP*. For an\noverview of CIDR blocks, see the Wikipedia article on [Classless Inter-Domain Routing](http://en.wikipedia.org/wiki/Classless_Inter-Domain_Routing).\n\nYou must also associate the security group with a cluster so that clients\nrunning on these IP addresses or the EC2 instance are authorized to connect to\nthe cluster. For information about managing security groups, go to [Working with Security\nGroups](https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-security-groups.html)\nin the *Amazon Redshift Cluster Management Guide*.","ref":"AWS.Redshift.html#authorize_cluster_security_group_ingress/3","title":"AWS.Redshift.authorize_cluster_security_group_ingress/3","type":"function"},{"doc":"From a data producer account, authorizes the sharing of a datashare with one or\nmore consumer accounts or managing entities.\n\nTo authorize a datashare for a data consumer, the producer account must have the\ncorrect access permissions.","ref":"AWS.Redshift.html#authorize_data_share/3","title":"AWS.Redshift.authorize_data_share/3","type":"function"},{"doc":"Grants access to a cluster.","ref":"AWS.Redshift.html#authorize_endpoint_access/3","title":"AWS.Redshift.authorize_endpoint_access/3","type":"function"},{"doc":"Authorizes the specified Amazon Web Services account to restore the specified\nsnapshot.\n\nFor more information about working with snapshots, go to [Amazon Redshift Snapshots](https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-snapshots.html)\nin the *Amazon Redshift Cluster Management Guide*.","ref":"AWS.Redshift.html#authorize_snapshot_access/3","title":"AWS.Redshift.authorize_snapshot_access/3","type":"function"},{"doc":"Deletes a set of cluster snapshots.","ref":"AWS.Redshift.html#batch_delete_cluster_snapshots/3","title":"AWS.Redshift.batch_delete_cluster_snapshots/3","type":"function"},{"doc":"Modifies the settings for a set of cluster snapshots.","ref":"AWS.Redshift.html#batch_modify_cluster_snapshots/3","title":"AWS.Redshift.batch_modify_cluster_snapshots/3","type":"function"},{"doc":"Cancels a resize operation for a cluster.","ref":"AWS.Redshift.html#cancel_resize/3","title":"AWS.Redshift.cancel_resize/3","type":"function"},{"doc":"Copies the specified automated cluster snapshot to a new manual cluster\nsnapshot.\n\nThe source must be an automated snapshot and it must be in the available state.\n\nWhen you delete a cluster, Amazon Redshift deletes any automated snapshots of\nthe cluster. Also, when the retention period of the snapshot expires, Amazon\nRedshift automatically deletes it. If you want to keep an automated snapshot for\na longer period, you can make a manual copy of the snapshot. Manual snapshots\nare retained until you delete them.\n\nFor more information about working with snapshots, go to [Amazon Redshift Snapshots](https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-snapshots.html)\nin the *Amazon Redshift Cluster Management Guide*.","ref":"AWS.Redshift.html#copy_cluster_snapshot/3","title":"AWS.Redshift.copy_cluster_snapshot/3","type":"function"},{"doc":"Creates an authentication profile with the specified parameters.","ref":"AWS.Redshift.html#create_authentication_profile/3","title":"AWS.Redshift.create_authentication_profile/3","type":"function"},{"doc":"Creates a new cluster with the specified parameters.\n\nTo create a cluster in Virtual Private Cloud (VPC), you must provide a cluster\nsubnet group name. The cluster subnet group identifies the subnets of your VPC\nthat Amazon Redshift uses when creating the cluster. For more information about\nmanaging clusters, go to [Amazon Redshift Clusters](https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-clusters.html)\nin the *Amazon Redshift Cluster Management Guide*.","ref":"AWS.Redshift.html#create_cluster/3","title":"AWS.Redshift.create_cluster/3","type":"function"},{"doc":"Creates an Amazon Redshift parameter group.\n\nCreating parameter groups is independent of creating clusters. You can associate\na cluster with a parameter group when you create the cluster. You can also\nassociate an existing cluster with a parameter group after the cluster is\ncreated by using `ModifyCluster`.\n\nParameters in the parameter group define specific behavior that applies to the\ndatabases you create on the cluster. For more information about parameters and\nparameter groups, go to [Amazon Redshift Parameter Groups](https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-parameter-groups.html)\nin the *Amazon Redshift Cluster Management Guide*.","ref":"AWS.Redshift.html#create_cluster_parameter_group/3","title":"AWS.Redshift.create_cluster_parameter_group/3","type":"function"},{"doc":"Creates a new Amazon Redshift security group.\n\nYou use security groups to control access to non-VPC clusters.\n\nFor information about managing security groups, go to [Amazon Redshift Cluster Security\nGroups](https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-security-groups.html)\nin the *Amazon Redshift Cluster Management Guide*.","ref":"AWS.Redshift.html#create_cluster_security_group/3","title":"AWS.Redshift.create_cluster_security_group/3","type":"function"},{"doc":"Creates a manual snapshot of the specified cluster.\n\nThe cluster must be in the `available` state.\n\nFor more information about working with snapshots, go to [Amazon Redshift Snapshots](https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-snapshots.html)\nin the *Amazon Redshift Cluster Management Guide*.","ref":"AWS.Redshift.html#create_cluster_snapshot/3","title":"AWS.Redshift.create_cluster_snapshot/3","type":"function"},{"doc":"Creates a new Amazon Redshift subnet group.\n\nYou must provide a list of one or more subnets in your existing Amazon Virtual\nPrivate Cloud (Amazon VPC) when creating Amazon Redshift subnet group.\n\nFor information about subnet groups, go to [Amazon Redshift Cluster Subnet Groups](https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-cluster-subnet-groups.html)\nin the *Amazon Redshift Cluster Management Guide*.","ref":"AWS.Redshift.html#create_cluster_subnet_group/3","title":"AWS.Redshift.create_cluster_subnet_group/3","type":"function"},{"doc":"Used to create a custom domain name for a cluster.\n\nProperties include the custom domain name, the cluster the custom domain is\nassociated with, and the certificate Amazon Resource Name (ARN).","ref":"AWS.Redshift.html#create_custom_domain_association/3","title":"AWS.Redshift.create_custom_domain_association/3","type":"function"},{"doc":"Creates a Redshift-managed VPC endpoint.","ref":"AWS.Redshift.html#create_endpoint_access/3","title":"AWS.Redshift.create_endpoint_access/3","type":"function"},{"doc":"Creates an Amazon Redshift event notification subscription.\n\nThis action requires an ARN (Amazon Resource Name) of an Amazon SNS topic\ncreated by either the Amazon Redshift console, the Amazon SNS console, or the\nAmazon SNS API. To obtain an ARN with Amazon SNS, you must create a topic in\nAmazon SNS and subscribe to the topic. The ARN is displayed in the SNS console.\n\nYou can specify the source type, and lists of Amazon Redshift source IDs, event\ncategories, and event severities. Notifications will be sent for all events you\nwant that match those criteria. For example, you can specify source type =\ncluster, source ID = my-cluster-1 and mycluster2, event categories =\nAvailability, Backup, and severity = ERROR. The subscription will only send\nnotifications for those ERROR events in the Availability and Backup categories\nfor the specified clusters.\n\nIf you specify both the source type and source IDs, such as source type =\ncluster and source identifier = my-cluster-1, notifications will be sent for all\nthe cluster events for my-cluster-1. If you specify a source type but do not\nspecify a source identifier, you will receive notice of the events for the\nobjects of that type in your Amazon Web Services account. If you do not specify\neither the SourceType nor the SourceIdentifier, you will be notified of events\ngenerated from all Amazon Redshift sources belonging to your Amazon Web Services\naccount. You must specify a source type if you specify a source ID.","ref":"AWS.Redshift.html#create_event_subscription/3","title":"AWS.Redshift.create_event_subscription/3","type":"function"},{"doc":"Creates an HSM client certificate that an Amazon Redshift cluster will use to\nconnect to the client's HSM in order to store and retrieve the keys used to\nencrypt the cluster databases.\n\nThe command returns a public key, which you must store in the HSM. In addition\nto creating the HSM certificate, you must create an Amazon Redshift HSM\nconfiguration that provides a cluster the information needed to store and use\nencryption keys in the HSM. For more information, go to [Hardware Security Modules](https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-db-encryption.html#working-with-HSM)\nin the *Amazon Redshift Cluster Management Guide*.","ref":"AWS.Redshift.html#create_hsm_client_certificate/3","title":"AWS.Redshift.create_hsm_client_certificate/3","type":"function"},{"doc":"Creates an HSM configuration that contains the information required by an Amazon\nRedshift cluster to store and use database encryption keys in a Hardware\nSecurity Module (HSM).\n\nAfter creating the HSM configuration, you can specify it as a parameter when\ncreating a cluster. The cluster will then store its encryption keys in the HSM.\n\nIn addition to creating an HSM configuration, you must also create an HSM client\ncertificate. For more information, go to [Hardware Security Modules](https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-HSM.html)\nin the Amazon Redshift Cluster Management Guide.","ref":"AWS.Redshift.html#create_hsm_configuration/3","title":"AWS.Redshift.create_hsm_configuration/3","type":"function"},{"doc":"Creates an Amazon Redshift application for use with IAM Identity Center.","ref":"AWS.Redshift.html#create_redshift_idc_application/3","title":"AWS.Redshift.create_redshift_idc_application/3","type":"function"},{"doc":"Creates a scheduled action.\n\nA scheduled action contains a schedule and an Amazon Redshift API action. For\nexample, you can create a schedule of when to run the `ResizeCluster` API\noperation.","ref":"AWS.Redshift.html#create_scheduled_action/3","title":"AWS.Redshift.create_scheduled_action/3","type":"function"},{"doc":"Creates a snapshot copy grant that permits Amazon Redshift to use an encrypted\nsymmetric key from Key Management Service (KMS) to encrypt copied snapshots in a\ndestination region.\n\nFor more information about managing snapshot copy grants, go to [Amazon Redshift Database\nEncryption](https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-db-encryption.html)\nin the *Amazon Redshift Cluster Management Guide*.","ref":"AWS.Redshift.html#create_snapshot_copy_grant/3","title":"AWS.Redshift.create_snapshot_copy_grant/3","type":"function"},{"doc":"Create a snapshot schedule that can be associated to a cluster and which\noverrides the default system backup schedule.","ref":"AWS.Redshift.html#create_snapshot_schedule/3","title":"AWS.Redshift.create_snapshot_schedule/3","type":"function"},{"doc":"Adds tags to a cluster.\n\nA resource can have up to 50 tags. If you try to create more than 50 tags for a\nresource, you will receive an error and the attempt will fail.\n\nIf you specify a key that already exists for the resource, the value for that\nkey will be updated with the new value.","ref":"AWS.Redshift.html#create_tags/3","title":"AWS.Redshift.create_tags/3","type":"function"},{"doc":"Creates a usage limit for a specified Amazon Redshift feature on a cluster.\n\nThe usage limit is identified by the returned usage limit identifier.","ref":"AWS.Redshift.html#create_usage_limit/3","title":"AWS.Redshift.create_usage_limit/3","type":"function"},{"doc":"From a datashare producer account, removes authorization from the specified\ndatashare.","ref":"AWS.Redshift.html#deauthorize_data_share/3","title":"AWS.Redshift.deauthorize_data_share/3","type":"function"},{"doc":"Deletes an authentication profile.","ref":"AWS.Redshift.html#delete_authentication_profile/3","title":"AWS.Redshift.delete_authentication_profile/3","type":"function"},{"doc":"Deletes a previously provisioned cluster without its final snapshot being\ncreated.\n\nA successful response from the web service indicates that the request was\nreceived correctly. Use `DescribeClusters` to monitor the status of the\ndeletion. The delete operation cannot be canceled or reverted once submitted.\nFor more information about managing clusters, go to [Amazon Redshift Clusters](https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-clusters.html)\nin the *Amazon Redshift Cluster Management Guide*.\n\nIf you want to shut down the cluster and retain it for future use, set\n*SkipFinalClusterSnapshot* to `false` and specify a name for\n*FinalClusterSnapshotIdentifier*. You can later restore this snapshot to resume\nusing the cluster. If a final cluster snapshot is requested, the status of the\ncluster will be \"final-snapshot\" while the snapshot is being taken, then it's\n\"deleting\" once Amazon Redshift begins deleting the cluster.\n\nFor more information about managing clusters, go to [Amazon Redshift Clusters](https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-clusters.html)\nin the *Amazon Redshift Cluster Management Guide*.","ref":"AWS.Redshift.html#delete_cluster/3","title":"AWS.Redshift.delete_cluster/3","type":"function"},{"doc":"Deletes a specified Amazon Redshift parameter group.\n\nYou cannot delete a parameter group if it is associated with a cluster.","ref":"AWS.Redshift.html#delete_cluster_parameter_group/3","title":"AWS.Redshift.delete_cluster_parameter_group/3","type":"function"},{"doc":"Deletes an Amazon Redshift security group.\n\nYou cannot delete a security group that is associated with any clusters. You\ncannot delete the default security group.\n\nFor information about managing security groups, go to [Amazon Redshift Cluster Security\nGroups](https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-security-groups.html)\nin the *Amazon Redshift Cluster Management Guide*.","ref":"AWS.Redshift.html#delete_cluster_security_group/3","title":"AWS.Redshift.delete_cluster_security_group/3","type":"function"},{"doc":"Deletes the specified manual snapshot.\n\nThe snapshot must be in the `available` state, with no other users authorized to\naccess the snapshot.\n\nUnlike automated snapshots, manual snapshots are retained even after you delete\nyour cluster. Amazon Redshift does not delete your manual snapshots. You must\ndelete manual snapshot explicitly to avoid getting charged. If other accounts\nare authorized to access the snapshot, you must revoke all of the authorizations\nbefore you can delete the snapshot.","ref":"AWS.Redshift.html#delete_cluster_snapshot/3","title":"AWS.Redshift.delete_cluster_snapshot/3","type":"function"},{"doc":"Deletes the specified cluster subnet group.","ref":"AWS.Redshift.html#delete_cluster_subnet_group/3","title":"AWS.Redshift.delete_cluster_subnet_group/3","type":"function"},{"doc":"Contains information about deleting a custom domain association for a cluster.","ref":"AWS.Redshift.html#delete_custom_domain_association/3","title":"AWS.Redshift.delete_custom_domain_association/3","type":"function"},{"doc":"Deletes a Redshift-managed VPC endpoint.","ref":"AWS.Redshift.html#delete_endpoint_access/3","title":"AWS.Redshift.delete_endpoint_access/3","type":"function"},{"doc":"Deletes an Amazon Redshift event notification subscription.","ref":"AWS.Redshift.html#delete_event_subscription/3","title":"AWS.Redshift.delete_event_subscription/3","type":"function"},{"doc":"Deletes the specified HSM client certificate.","ref":"AWS.Redshift.html#delete_hsm_client_certificate/3","title":"AWS.Redshift.delete_hsm_client_certificate/3","type":"function"},{"doc":"Deletes the specified Amazon Redshift HSM configuration.","ref":"AWS.Redshift.html#delete_hsm_configuration/3","title":"AWS.Redshift.delete_hsm_configuration/3","type":"function"},{"doc":"Deletes a partner integration from a cluster.\n\nData can still flow to the cluster until the integration is deleted at the\npartner's website.","ref":"AWS.Redshift.html#delete_partner/3","title":"AWS.Redshift.delete_partner/3","type":"function"},{"doc":"Deletes an Amazon Redshift IAM Identity Center application.","ref":"AWS.Redshift.html#delete_redshift_idc_application/3","title":"AWS.Redshift.delete_redshift_idc_application/3","type":"function"},{"doc":"Deletes the resource policy for a specified resource.","ref":"AWS.Redshift.html#delete_resource_policy/3","title":"AWS.Redshift.delete_resource_policy/3","type":"function"},{"doc":"Deletes a scheduled action.","ref":"AWS.Redshift.html#delete_scheduled_action/3","title":"AWS.Redshift.delete_scheduled_action/3","type":"function"},{"doc":"Deletes the specified snapshot copy grant.","ref":"AWS.Redshift.html#delete_snapshot_copy_grant/3","title":"AWS.Redshift.delete_snapshot_copy_grant/3","type":"function"},{"doc":"Deletes a snapshot schedule.","ref":"AWS.Redshift.html#delete_snapshot_schedule/3","title":"AWS.Redshift.delete_snapshot_schedule/3","type":"function"},{"doc":"Deletes tags from a resource.\n\nYou must provide the ARN of the resource from which you want to delete the tag\nor tags.","ref":"AWS.Redshift.html#delete_tags/3","title":"AWS.Redshift.delete_tags/3","type":"function"},{"doc":"Deletes a usage limit from a cluster.","ref":"AWS.Redshift.html#delete_usage_limit/3","title":"AWS.Redshift.delete_usage_limit/3","type":"function"},{"doc":"Returns a list of attributes attached to an account","ref":"AWS.Redshift.html#describe_account_attributes/3","title":"AWS.Redshift.describe_account_attributes/3","type":"function"},{"doc":"Describes an authentication profile.","ref":"AWS.Redshift.html#describe_authentication_profiles/3","title":"AWS.Redshift.describe_authentication_profiles/3","type":"function"},{"doc":"Returns an array of `ClusterDbRevision` objects.","ref":"AWS.Redshift.html#describe_cluster_db_revisions/3","title":"AWS.Redshift.describe_cluster_db_revisions/3","type":"function"},{"doc":"Returns a list of Amazon Redshift parameter groups, including parameter groups\nyou created and the default parameter group.\n\nFor each parameter group, the response includes the parameter group name,\ndescription, and parameter group family name. You can optionally specify a name\nto retrieve the description of a specific parameter group.\n\nFor more information about parameters and parameter groups, go to [Amazon Redshift Parameter\nGroups](https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-parameter-groups.html)\nin the *Amazon Redshift Cluster Management Guide*.\n\nIf you specify both tag keys and tag values in the same request, Amazon Redshift\nreturns all parameter groups that match any combination of the specified keys\nand values. For example, if you have `owner` and `environment` for tag keys, and\n`admin` and `test` for tag values, all parameter groups that have any\ncombination of those values are returned.\n\nIf both tag keys and values are omitted from the request, parameter groups are\nreturned regardless of whether they have tag keys or values associated with\nthem.","ref":"AWS.Redshift.html#describe_cluster_parameter_groups/3","title":"AWS.Redshift.describe_cluster_parameter_groups/3","type":"function"},{"doc":"Returns a detailed list of parameters contained within the specified Amazon\nRedshift parameter group.\n\nFor each parameter the response includes information such as parameter name,\ndescription, data type, value, whether the parameter value is modifiable, and so\non.\n\nYou can specify *source* filter to retrieve parameters of only specific type.\nFor example, to retrieve parameters that were modified by a user action such as\nfrom `ModifyClusterParameterGroup`, you can specify *source* equal to *user*.\n\nFor more information about parameters and parameter groups, go to [Amazon Redshift Parameter\nGroups](https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-parameter-groups.html)\nin the *Amazon Redshift Cluster Management Guide*.","ref":"AWS.Redshift.html#describe_cluster_parameters/3","title":"AWS.Redshift.describe_cluster_parameters/3","type":"function"},{"doc":"Returns information about Amazon Redshift security groups.\n\nIf the name of a security group is specified, the response will contain only\ninformation about only that security group.\n\nFor information about managing security groups, go to [Amazon Redshift Cluster Security\nGroups](https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-security-groups.html)\nin the *Amazon Redshift Cluster Management Guide*.\n\nIf you specify both tag keys and tag values in the same request, Amazon Redshift\nreturns all security groups that match any combination of the specified keys and\nvalues. For example, if you have `owner` and `environment` for tag keys, and\n`admin` and `test` for tag values, all security groups that have any combination\nof those values are returned.\n\nIf both tag keys and values are omitted from the request, security groups are\nreturned regardless of whether they have tag keys or values associated with\nthem.","ref":"AWS.Redshift.html#describe_cluster_security_groups/3","title":"AWS.Redshift.describe_cluster_security_groups/3","type":"function"},{"doc":"Returns one or more snapshot objects, which contain metadata about your cluster\nsnapshots.\n\nBy default, this operation returns information about all snapshots of all\nclusters that are owned by your Amazon Web Services account. No information is\nreturned for snapshots owned by inactive Amazon Web Services accounts.\n\nIf you specify both tag keys and tag values in the same request, Amazon Redshift\nreturns all snapshots that match any combination of the specified keys and\nvalues. For example, if you have `owner` and `environment` for tag keys, and\n`admin` and `test` for tag values, all snapshots that have any combination of\nthose values are returned. Only snapshots that you own are returned in the\nresponse; shared snapshots are not returned with the tag key and tag value\nrequest parameters.\n\nIf both tag keys and values are omitted from the request, snapshots are returned\nregardless of whether they have tag keys or values associated with them.","ref":"AWS.Redshift.html#describe_cluster_snapshots/3","title":"AWS.Redshift.describe_cluster_snapshots/3","type":"function"},{"doc":"Returns one or more cluster subnet group objects, which contain metadata about\nyour cluster subnet groups.\n\nBy default, this operation returns information about all cluster subnet groups\nthat are defined in your Amazon Web Services account.\n\nIf you specify both tag keys and tag values in the same request, Amazon Redshift\nreturns all subnet groups that match any combination of the specified keys and\nvalues. For example, if you have `owner` and `environment` for tag keys, and\n`admin` and `test` for tag values, all subnet groups that have any combination\nof those values are returned.\n\nIf both tag keys and values are omitted from the request, subnet groups are\nreturned regardless of whether they have tag keys or values associated with\nthem.","ref":"AWS.Redshift.html#describe_cluster_subnet_groups/3","title":"AWS.Redshift.describe_cluster_subnet_groups/3","type":"function"},{"doc":"Returns a list of all the available maintenance tracks.","ref":"AWS.Redshift.html#describe_cluster_tracks/3","title":"AWS.Redshift.describe_cluster_tracks/3","type":"function"},{"doc":"Returns descriptions of the available Amazon Redshift cluster versions.\n\nYou can call this operation even before creating any clusters to learn more\nabout the Amazon Redshift versions. For more information about managing\nclusters, go to [Amazon Redshift Clusters](https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-clusters.html)\nin the *Amazon Redshift Cluster Management Guide*.","ref":"AWS.Redshift.html#describe_cluster_versions/3","title":"AWS.Redshift.describe_cluster_versions/3","type":"function"},{"doc":"Returns properties of provisioned clusters including general cluster properties,\ncluster database properties, maintenance and backup properties, and security and\naccess properties.\n\nThis operation supports pagination. For more information about managing\nclusters, go to [Amazon Redshift Clusters](https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-clusters.html)\nin the *Amazon Redshift Cluster Management Guide*.\n\nIf you specify both tag keys and tag values in the same request, Amazon Redshift\nreturns all clusters that match any combination of the specified keys and\nvalues. For example, if you have `owner` and `environment` for tag keys, and\n`admin` and `test` for tag values, all clusters that have any combination of\nthose values are returned.\n\nIf both tag keys and values are omitted from the request, clusters are returned\nregardless of whether they have tag keys or values associated with them.","ref":"AWS.Redshift.html#describe_clusters/3","title":"AWS.Redshift.describe_clusters/3","type":"function"},{"doc":"Contains information about custom domain associations for a cluster.","ref":"AWS.Redshift.html#describe_custom_domain_associations/3","title":"AWS.Redshift.describe_custom_domain_associations/3","type":"function"},{"doc":"Shows the status of any inbound or outbound datashares available in the\nspecified account.","ref":"AWS.Redshift.html#describe_data_shares/3","title":"AWS.Redshift.describe_data_shares/3","type":"function"},{"doc":"Returns a list of datashares where the account identifier being called is a\nconsumer account identifier.","ref":"AWS.Redshift.html#describe_data_shares_for_consumer/3","title":"AWS.Redshift.describe_data_shares_for_consumer/3","type":"function"},{"doc":"Returns a list of datashares when the account identifier being called is a\nproducer account identifier.","ref":"AWS.Redshift.html#describe_data_shares_for_producer/3","title":"AWS.Redshift.describe_data_shares_for_producer/3","type":"function"},{"doc":"Returns a list of parameter settings for the specified parameter group family.\n\nFor more information about parameters and parameter groups, go to [Amazon Redshift Parameter\nGroups](https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-parameter-groups.html)\nin the *Amazon Redshift Cluster Management Guide*.","ref":"AWS.Redshift.html#describe_default_cluster_parameters/3","title":"AWS.Redshift.describe_default_cluster_parameters/3","type":"function"},{"doc":"Describes a Redshift-managed VPC endpoint.","ref":"AWS.Redshift.html#describe_endpoint_access/3","title":"AWS.Redshift.describe_endpoint_access/3","type":"function"},{"doc":"Describes an endpoint authorization.","ref":"AWS.Redshift.html#describe_endpoint_authorization/3","title":"AWS.Redshift.describe_endpoint_authorization/3","type":"function"},{"doc":"Displays a list of event categories for all event source types, or for a\nspecified source type.\n\nFor a list of the event categories and source types, go to [Amazon Redshift Event\nNotifications](https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-event-notifications.html).","ref":"AWS.Redshift.html#describe_event_categories/3","title":"AWS.Redshift.describe_event_categories/3","type":"function"},{"doc":"Lists descriptions of all the Amazon Redshift event notification subscriptions\nfor a customer account.\n\nIf you specify a subscription name, lists the description for that subscription.\n\nIf you specify both tag keys and tag values in the same request, Amazon Redshift\nreturns all event notification subscriptions that match any combination of the\nspecified keys and values. For example, if you have `owner` and `environment`\nfor tag keys, and `admin` and `test` for tag values, all subscriptions that have\nany combination of those values are returned.\n\nIf both tag keys and values are omitted from the request, subscriptions are\nreturned regardless of whether they have tag keys or values associated with\nthem.","ref":"AWS.Redshift.html#describe_event_subscriptions/3","title":"AWS.Redshift.describe_event_subscriptions/3","type":"function"},{"doc":"Returns events related to clusters, security groups, snapshots, and parameter\ngroups for the past 14 days.\n\nEvents specific to a particular cluster, security group, snapshot or parameter\ngroup can be obtained by providing the name as a parameter. By default, the past\nhour of events are returned.","ref":"AWS.Redshift.html#describe_events/3","title":"AWS.Redshift.describe_events/3","type":"function"},{"doc":"Returns information about the specified HSM client certificate.\n\nIf no certificate ID is specified, returns information about all the HSM\ncertificates owned by your Amazon Web Services account.\n\nIf you specify both tag keys and tag values in the same request, Amazon Redshift\nreturns all HSM client certificates that match any combination of the specified\nkeys and values. For example, if you have `owner` and `environment` for tag\nkeys, and `admin` and `test` for tag values, all HSM client certificates that\nhave any combination of those values are returned.\n\nIf both tag keys and values are omitted from the request, HSM client\ncertificates are returned regardless of whether they have tag keys or values\nassociated with them.","ref":"AWS.Redshift.html#describe_hsm_client_certificates/3","title":"AWS.Redshift.describe_hsm_client_certificates/3","type":"function"},{"doc":"Returns information about the specified Amazon Redshift HSM configuration.\n\nIf no configuration ID is specified, returns information about all the HSM\nconfigurations owned by your Amazon Web Services account.\n\nIf you specify both tag keys and tag values in the same request, Amazon Redshift\nreturns all HSM connections that match any combination of the specified keys and\nvalues. For example, if you have `owner` and `environment` for tag keys, and\n`admin` and `test` for tag values, all HSM connections that have any combination\nof those values are returned.\n\nIf both tag keys and values are omitted from the request, HSM connections are\nreturned regardless of whether they have tag keys or values associated with\nthem.","ref":"AWS.Redshift.html#describe_hsm_configurations/3","title":"AWS.Redshift.describe_hsm_configurations/3","type":"function"},{"doc":"Returns a list of inbound integrations.","ref":"AWS.Redshift.html#describe_inbound_integrations/3","title":"AWS.Redshift.describe_inbound_integrations/3","type":"function"},{"doc":"Describes whether information, such as queries and connection attempts, is being\nlogged for the specified Amazon Redshift cluster.","ref":"AWS.Redshift.html#describe_logging_status/3","title":"AWS.Redshift.describe_logging_status/3","type":"function"},{"doc":"Returns properties of possible node configurations such as node type, number of\nnodes, and disk usage for the specified action type.","ref":"AWS.Redshift.html#describe_node_configuration_options/3","title":"AWS.Redshift.describe_node_configuration_options/3","type":"function"},{"doc":"Returns a list of orderable cluster options.\n\nBefore you create a new cluster you can use this operation to find what options\nare available, such as the EC2 Availability Zones (AZ) in the specific Amazon\nWeb Services Region that you can specify, and the node types you can request.\nThe node types differ by available storage, memory, CPU and price. With the cost\ninvolved you might want to obtain a list of cluster options in the specific\nregion and specify values when creating a cluster. For more information about\nmanaging clusters, go to [Amazon Redshift Clusters](https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-clusters.html)\nin the *Amazon Redshift Cluster Management Guide*.","ref":"AWS.Redshift.html#describe_orderable_cluster_options/3","title":"AWS.Redshift.describe_orderable_cluster_options/3","type":"function"},{"doc":"Returns information about the partner integrations defined for a cluster.","ref":"AWS.Redshift.html#describe_partners/3","title":"AWS.Redshift.describe_partners/3","type":"function"},{"doc":"Lists the Amazon Redshift IAM Identity Center applications.","ref":"AWS.Redshift.html#describe_redshift_idc_applications/3","title":"AWS.Redshift.describe_redshift_idc_applications/3","type":"function"},{"doc":"Returns exchange status details and associated metadata for a reserved-node\nexchange.\n\nStatuses include such values as in progress and requested.","ref":"AWS.Redshift.html#describe_reserved_node_exchange_status/3","title":"AWS.Redshift.describe_reserved_node_exchange_status/3","type":"function"},{"doc":"Returns a list of the available reserved node offerings by Amazon Redshift with\ntheir descriptions including the node type, the fixed and recurring costs of\nreserving the node and duration the node will be reserved for you.\n\nThese descriptions help you determine which reserve node offering you want to\npurchase. You then use the unique offering ID in you call to\n`PurchaseReservedNodeOffering` to reserve one or more nodes for your Amazon\nRedshift cluster.\n\nFor more information about reserved node offerings, go to [Purchasing Reserved Nodes](https://docs.aws.amazon.com/redshift/latest/mgmt/purchase-reserved-node-instance.html)\nin the *Amazon Redshift Cluster Management Guide*.","ref":"AWS.Redshift.html#describe_reserved_node_offerings/3","title":"AWS.Redshift.describe_reserved_node_offerings/3","type":"function"},{"doc":"Returns the descriptions of the reserved nodes.","ref":"AWS.Redshift.html#describe_reserved_nodes/3","title":"AWS.Redshift.describe_reserved_nodes/3","type":"function"},{"doc":"Returns information about the last resize operation for the specified cluster.\n\nIf no resize operation has ever been initiated for the specified cluster, a\n`HTTP 404` error is returned. If a resize operation was initiated and completed,\nthe status of the resize remains as `SUCCEEDED` until the next resize.\n\nA resize operation can be requested using `ModifyCluster` and specifying a\ndifferent number or type of nodes for the cluster.","ref":"AWS.Redshift.html#describe_resize/3","title":"AWS.Redshift.describe_resize/3","type":"function"},{"doc":"Describes properties of scheduled actions.","ref":"AWS.Redshift.html#describe_scheduled_actions/3","title":"AWS.Redshift.describe_scheduled_actions/3","type":"function"},{"doc":"Returns a list of snapshot copy grants owned by the Amazon Web Services account\nin the destination region.\n\nFor more information about managing snapshot copy grants, go to [Amazon Redshift Database\nEncryption](https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-db-encryption.html)\nin the *Amazon Redshift Cluster Management Guide*.","ref":"AWS.Redshift.html#describe_snapshot_copy_grants/3","title":"AWS.Redshift.describe_snapshot_copy_grants/3","type":"function"},{"doc":"Returns a list of snapshot schedules.","ref":"AWS.Redshift.html#describe_snapshot_schedules/3","title":"AWS.Redshift.describe_snapshot_schedules/3","type":"function"},{"doc":"Returns account level backups storage size and provisional storage.","ref":"AWS.Redshift.html#describe_storage/3","title":"AWS.Redshift.describe_storage/3","type":"function"},{"doc":"Lists the status of one or more table restore requests made using the\n`RestoreTableFromClusterSnapshot` API action.\n\nIf you don't specify a value for the `TableRestoreRequestId` parameter, then\n`DescribeTableRestoreStatus` returns the status of all table restore requests\nordered by the date and time of the request in ascending order. Otherwise\n`DescribeTableRestoreStatus` returns the status of the table specified by\n`TableRestoreRequestId`.","ref":"AWS.Redshift.html#describe_table_restore_status/3","title":"AWS.Redshift.describe_table_restore_status/3","type":"function"},{"doc":"Returns a list of tags.\n\nYou can return tags from a specific resource by specifying an ARN, or you can\nreturn all tags for a given type of resource, such as clusters, snapshots, and\nso on.\n\nThe following are limitations for `DescribeTags`:\n\n  * You cannot specify an ARN and a resource-type value together in\nthe same request.\n\n  * You cannot use the `MaxRecords` and `Marker` parameters together\nwith the ARN parameter.\n\n  * The `MaxRecords` parameter can be a range from 10 to 50 results to\nreturn in a request.\n\nIf you specify both tag keys and tag values in the same request, Amazon Redshift\nreturns all resources that match any combination of the specified keys and\nvalues. For example, if you have `owner` and `environment` for tag keys, and\n`admin` and `test` for tag values, all resources that have any combination of\nthose values are returned.\n\nIf both tag keys and values are omitted from the request, resources are returned\nregardless of whether they have tag keys or values associated with them.","ref":"AWS.Redshift.html#describe_tags/3","title":"AWS.Redshift.describe_tags/3","type":"function"},{"doc":"Shows usage limits on a cluster.\n\nResults are filtered based on the combination of input usage limit identifier,\ncluster identifier, and feature type parameters:\n\n  * If usage limit identifier, cluster identifier, and feature type\nare not provided, then all usage limit objects for the current account in the\ncurrent region are returned.\n\n  * If usage limit identifier is provided, then the corresponding\nusage limit object is returned.\n\n  * If cluster identifier is provided, then all usage limit objects\nfor the specified cluster are returned.\n\n  * If cluster identifier and feature type are provided, then all\nusage limit objects for the combination of cluster and feature are returned.","ref":"AWS.Redshift.html#describe_usage_limits/3","title":"AWS.Redshift.describe_usage_limits/3","type":"function"},{"doc":"Stops logging information, such as queries and connection attempts, for the\nspecified Amazon Redshift cluster.","ref":"AWS.Redshift.html#disable_logging/3","title":"AWS.Redshift.disable_logging/3","type":"function"},{"doc":"Disables the automatic copying of snapshots from one region to another region\nfor a specified cluster.\n\nIf your cluster and its snapshots are encrypted using an encrypted symmetric key\nfrom Key Management Service, use `DeleteSnapshotCopyGrant` to delete the grant\nthat grants Amazon Redshift permission to the key in the destination region.","ref":"AWS.Redshift.html#disable_snapshot_copy/3","title":"AWS.Redshift.disable_snapshot_copy/3","type":"function"},{"doc":"From a datashare consumer account, remove association for the specified\ndatashare.","ref":"AWS.Redshift.html#disassociate_data_share_consumer/3","title":"AWS.Redshift.disassociate_data_share_consumer/3","type":"function"},{"doc":"Starts logging information, such as queries and connection attempts, for the\nspecified Amazon Redshift cluster.","ref":"AWS.Redshift.html#enable_logging/3","title":"AWS.Redshift.enable_logging/3","type":"function"},{"doc":"Enables the automatic copy of snapshots from one region to another region for a\nspecified cluster.","ref":"AWS.Redshift.html#enable_snapshot_copy/3","title":"AWS.Redshift.enable_snapshot_copy/3","type":"function"},{"doc":"Fails over the primary compute unit of the specified Multi-AZ cluster to another\nAvailability Zone.","ref":"AWS.Redshift.html#failover_primary_compute/3","title":"AWS.Redshift.failover_primary_compute/3","type":"function"},{"doc":"Returns a database user name and temporary password with temporary authorization\nto log on to an Amazon Redshift database.\n\nThe action returns the database user name prefixed with `IAM:` if `AutoCreate`\nis `False` or `IAMA:` if `AutoCreate` is `True`. You can optionally specify one\nor more database user groups that the user will join at log on. By default, the\ntemporary credentials expire in 900 seconds. You can optionally specify a\nduration between 900 seconds (15 minutes) and 3600 seconds (60 minutes). For\nmore information, see [Using IAM Authentication to Generate Database User Credentials](https://docs.aws.amazon.com/redshift/latest/mgmt/generating-user-credentials.html)\nin the Amazon Redshift Cluster Management Guide.\n\nThe Identity and Access Management (IAM) user or role that runs\nGetClusterCredentials must have an IAM policy attached that allows access to all\nnecessary actions and resources. For more information about permissions, see\n[Resource Policies for GetClusterCredentials](https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-iam-access-control-identity-based.html#redshift-policy-resources.getclustercredentials-resources)\nin the Amazon Redshift Cluster Management Guide.\n\nIf the `DbGroups` parameter is specified, the IAM policy must allow the\n`redshift:JoinGroup` action with access to the listed `dbgroups`.\n\nIn addition, if the `AutoCreate` parameter is set to `True`, then the policy\nmust include the `redshift:CreateClusterUser` permission.\n\nIf the `DbName` parameter is specified, the IAM policy must allow access to the\nresource `dbname` for the specified database name.","ref":"AWS.Redshift.html#get_cluster_credentials/3","title":"AWS.Redshift.get_cluster_credentials/3","type":"function"},{"doc":"Returns a database user name and temporary password with temporary authorization\nto log in to an Amazon Redshift database.\n\nThe database user is mapped 1:1 to the source Identity and Access Management\n(IAM) identity. For more information about IAM identities, see [IAM Identities (users, user groups, and\nroles)](https://docs.aws.amazon.com/IAM/latest/UserGuide/id.html) in the Amazon\nWeb Services Identity and Access Management User Guide.\n\nThe Identity and Access Management (IAM) identity that runs this operation must\nhave an IAM policy attached that allows access to all necessary actions and\nresources. For more information about permissions, see [Using identity-based policies (IAM\npolicies)](https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-iam-access-control-identity-based.html)\nin the Amazon Redshift Cluster Management Guide.","ref":"AWS.Redshift.html#get_cluster_credentials_with_iam/3","title":"AWS.Redshift.get_cluster_credentials_with_iam/3","type":"function"},{"doc":"Gets the configuration options for the reserved-node exchange.\n\nThese options include information about the source reserved node and target\nreserved node offering. Details include the node type, the price, the node\ncount, and the offering type.","ref":"AWS.Redshift.html#get_reserved_node_exchange_configuration_options/3","title":"AWS.Redshift.get_reserved_node_exchange_configuration_options/3","type":"function"},{"doc":"Returns an array of DC2 ReservedNodeOfferings that matches the payment type,\nterm, and usage price of the given DC1 reserved node.","ref":"AWS.Redshift.html#get_reserved_node_exchange_offerings/3","title":"AWS.Redshift.get_reserved_node_exchange_offerings/3","type":"function"},{"doc":"Get the resource policy for a specified resource.","ref":"AWS.Redshift.html#get_resource_policy/3","title":"AWS.Redshift.get_resource_policy/3","type":"function"},{"doc":"List the Amazon Redshift Advisor recommendations for one or multiple Amazon\nRedshift clusters in an Amazon Web Services account.","ref":"AWS.Redshift.html#list_recommendations/3","title":"AWS.Redshift.list_recommendations/3","type":"function"},{"doc":"","ref":"AWS.Redshift.html#metadata/0","title":"AWS.Redshift.metadata/0","type":"function"},{"doc":"This operation is retired.\n\nCalling this operation does not change AQUA configuration. Amazon Redshift\nautomatically determines whether to use AQUA (Advanced Query Accelerator).","ref":"AWS.Redshift.html#modify_aqua_configuration/3","title":"AWS.Redshift.modify_aqua_configuration/3","type":"function"},{"doc":"Modifies an authentication profile.","ref":"AWS.Redshift.html#modify_authentication_profile/3","title":"AWS.Redshift.modify_authentication_profile/3","type":"function"},{"doc":"Modifies the settings for a cluster.\n\nYou can also change node type and the number of nodes to scale up or down the\ncluster. When resizing a cluster, you must specify both the number of nodes and\nthe node type even if one of the parameters does not change.\n\nYou can add another security or parameter group, or change the admin user\npassword. Resetting a cluster password or modifying the security groups\nassociated with a cluster do not need a reboot. However, modifying a parameter\ngroup requires a reboot for parameters to take effect. For more information\nabout managing clusters, go to [Amazon Redshift Clusters](https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-clusters.html)\nin the *Amazon Redshift Cluster Management Guide*.","ref":"AWS.Redshift.html#modify_cluster/3","title":"AWS.Redshift.modify_cluster/3","type":"function"},{"doc":"Modifies the database revision of a cluster.\n\nThe database revision is a unique revision of the database running in a cluster.","ref":"AWS.Redshift.html#modify_cluster_db_revision/3","title":"AWS.Redshift.modify_cluster_db_revision/3","type":"function"},{"doc":"Modifies the list of Identity and Access Management (IAM) roles that can be used\nby the cluster to access other Amazon Web Services services.\n\nThe maximum number of IAM roles that you can associate is subject to a quota.\nFor more information, go to [Quotas and limits](https://docs.aws.amazon.com/redshift/latest/mgmt/amazon-redshift-limits.html)\nin the *Amazon Redshift Cluster Management Guide*.","ref":"AWS.Redshift.html#modify_cluster_iam_roles/3","title":"AWS.Redshift.modify_cluster_iam_roles/3","type":"function"},{"doc":"Modifies the maintenance settings of a cluster.","ref":"AWS.Redshift.html#modify_cluster_maintenance/3","title":"AWS.Redshift.modify_cluster_maintenance/3","type":"function"},{"doc":"Modifies the parameters of a parameter group.\n\nFor the parameters parameter, it can't contain ASCII characters.\n\nFor more information about parameters and parameter groups, go to [Amazon Redshift Parameter\nGroups](https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-parameter-groups.html)\nin the *Amazon Redshift Cluster Management Guide*.","ref":"AWS.Redshift.html#modify_cluster_parameter_group/3","title":"AWS.Redshift.modify_cluster_parameter_group/3","type":"function"},{"doc":"Modifies the settings for a snapshot.\n\nThis exanmple modifies the manual retention period setting for a cluster\nsnapshot.","ref":"AWS.Redshift.html#modify_cluster_snapshot/3","title":"AWS.Redshift.modify_cluster_snapshot/3","type":"function"},{"doc":"Modifies a snapshot schedule for a cluster.","ref":"AWS.Redshift.html#modify_cluster_snapshot_schedule/3","title":"AWS.Redshift.modify_cluster_snapshot_schedule/3","type":"function"},{"doc":"Modifies a cluster subnet group to include the specified list of VPC subnets.\n\nThe operation replaces the existing list of subnets with the new list of\nsubnets.","ref":"AWS.Redshift.html#modify_cluster_subnet_group/3","title":"AWS.Redshift.modify_cluster_subnet_group/3","type":"function"},{"doc":"Contains information for changing a custom domain association.","ref":"AWS.Redshift.html#modify_custom_domain_association/3","title":"AWS.Redshift.modify_custom_domain_association/3","type":"function"},{"doc":"Modifies a Redshift-managed VPC endpoint.","ref":"AWS.Redshift.html#modify_endpoint_access/3","title":"AWS.Redshift.modify_endpoint_access/3","type":"function"},{"doc":"Modifies an existing Amazon Redshift event notification subscription.","ref":"AWS.Redshift.html#modify_event_subscription/3","title":"AWS.Redshift.modify_event_subscription/3","type":"function"},{"doc":"Changes an existing Amazon Redshift IAM Identity Center application.","ref":"AWS.Redshift.html#modify_redshift_idc_application/3","title":"AWS.Redshift.modify_redshift_idc_application/3","type":"function"},{"doc":"Modifies a scheduled action.","ref":"AWS.Redshift.html#modify_scheduled_action/3","title":"AWS.Redshift.modify_scheduled_action/3","type":"function"},{"doc":"Modifies the number of days to retain snapshots in the destination Amazon Web\nServices Region after they are copied from the source Amazon Web Services\nRegion.\n\nBy default, this operation only changes the retention period of copied automated\nsnapshots. The retention periods for both new and existing copied automated\nsnapshots are updated with the new retention period. You can set the manual\noption to change only the retention periods of copied manual snapshots. If you\nset this option, only newly copied manual snapshots have the new retention\nperiod.","ref":"AWS.Redshift.html#modify_snapshot_copy_retention_period/3","title":"AWS.Redshift.modify_snapshot_copy_retention_period/3","type":"function"},{"doc":"Modifies a snapshot schedule.\n\nAny schedule associated with a cluster is modified asynchronously.","ref":"AWS.Redshift.html#modify_snapshot_schedule/3","title":"AWS.Redshift.modify_snapshot_schedule/3","type":"function"},{"doc":"Modifies a usage limit in a cluster.\n\nYou can't modify the feature type or period of a usage limit.","ref":"AWS.Redshift.html#modify_usage_limit/3","title":"AWS.Redshift.modify_usage_limit/3","type":"function"},{"doc":"Pauses a cluster.","ref":"AWS.Redshift.html#pause_cluster/3","title":"AWS.Redshift.pause_cluster/3","type":"function"},{"doc":"Allows you to purchase reserved nodes.\n\nAmazon Redshift offers a predefined set of reserved node offerings. You can\npurchase one or more of the offerings. You can call the\n`DescribeReservedNodeOfferings` API to obtain the available reserved node\nofferings. You can call this API by providing a specific reserved node offering\nand the number of nodes you want to reserve.\n\nFor more information about reserved node offerings, go to [Purchasing Reserved Nodes](https://docs.aws.amazon.com/redshift/latest/mgmt/purchase-reserved-node-instance.html)\nin the *Amazon Redshift Cluster Management Guide*.","ref":"AWS.Redshift.html#purchase_reserved_node_offering/3","title":"AWS.Redshift.purchase_reserved_node_offering/3","type":"function"},{"doc":"Updates the resource policy for a specified resource.","ref":"AWS.Redshift.html#put_resource_policy/3","title":"AWS.Redshift.put_resource_policy/3","type":"function"},{"doc":"Reboots a cluster.\n\nThis action is taken as soon as possible. It results in a momentary outage to\nthe cluster, during which the cluster status is set to `rebooting`. A cluster\nevent is created when the reboot is completed. Any pending cluster modifications\n(see `ModifyCluster`) are applied at this reboot. For more information about\nmanaging clusters, go to [Amazon Redshift Clusters](https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-clusters.html)\nin the *Amazon Redshift Cluster Management Guide*.","ref":"AWS.Redshift.html#reboot_cluster/3","title":"AWS.Redshift.reboot_cluster/3","type":"function"},{"doc":"From a datashare consumer account, rejects the specified datashare.","ref":"AWS.Redshift.html#reject_data_share/3","title":"AWS.Redshift.reject_data_share/3","type":"function"},{"doc":"Sets one or more parameters of the specified parameter group to their default\nvalues and sets the source values of the parameters to \"engine-default\".\n\nTo reset the entire parameter group specify the *ResetAllParameters* parameter.\nFor parameter changes to take effect you must reboot any associated clusters.","ref":"AWS.Redshift.html#reset_cluster_parameter_group/3","title":"AWS.Redshift.reset_cluster_parameter_group/3","type":"function"},{"doc":"Changes the size of the cluster.\n\nYou can change the cluster's type, or change the number or type of nodes. The\ndefault behavior is to use the elastic resize method. With an elastic resize,\nyour cluster is available for read and write operations more quickly than with\nthe classic resize method.\n\nElastic resize operations have the following restrictions:\n\n  * You can only resize clusters of the following types:\n\n    * dc1.large (if your cluster is in a VPC)\n\n    * dc1.8xlarge (if your cluster is in a VPC)\n\n    * dc2.large\n\n    * dc2.8xlarge\n\n    * ds2.xlarge\n\n    * ds2.8xlarge\n\n    * ra3.xlplus\n\n    * ra3.4xlarge\n\n    * ra3.16xlarge\n\n  * The type of nodes that you add must match the node type for the\ncluster.","ref":"AWS.Redshift.html#resize_cluster/3","title":"AWS.Redshift.resize_cluster/3","type":"function"},{"doc":"Creates a new cluster from a snapshot.\n\nBy default, Amazon Redshift creates the resulting cluster with the same\nconfiguration as the original cluster from which the snapshot was created,\nexcept that the new cluster is created with the default cluster security and\nparameter groups. After Amazon Redshift creates the cluster, you can use the\n`ModifyCluster` API to associate a different security group and different\nparameter group with the restored cluster. If you are using a DS node type, you\ncan also choose to change to another DS node type of the same size during\nrestore.\n\nIf you restore a cluster into a VPC, you must provide a cluster subnet group\nwhere you want the cluster restored.\n\nFor more information about working with snapshots, go to [Amazon Redshift Snapshots](https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-snapshots.html)\nin the *Amazon Redshift Cluster Management Guide*.","ref":"AWS.Redshift.html#restore_from_cluster_snapshot/3","title":"AWS.Redshift.restore_from_cluster_snapshot/3","type":"function"},{"doc":"Creates a new table from a table in an Amazon Redshift cluster snapshot.\n\nYou must create the new table within the Amazon Redshift cluster that the\nsnapshot was taken from.\n\nYou cannot use `RestoreTableFromClusterSnapshot` to restore a table with the\nsame name as an existing table in an Amazon Redshift cluster. That is, you\ncannot overwrite an existing table in a cluster with a restored table. If you\nwant to replace your original table with a new, restored table, then rename or\ndrop your original table before you call `RestoreTableFromClusterSnapshot`. When\nyou have renamed your original table, then you can pass the original name of the\ntable as the `NewTableName` parameter value in the call to\n`RestoreTableFromClusterSnapshot`. This way, you can replace the original table\nwith the table created from the snapshot.\n\nYou can't use this operation to restore tables with [interleaved sort keys](https://docs.aws.amazon.com/redshift/latest/dg/t_Sorting_data.html#t_Sorting_data-interleaved).","ref":"AWS.Redshift.html#restore_table_from_cluster_snapshot/3","title":"AWS.Redshift.restore_table_from_cluster_snapshot/3","type":"function"},{"doc":"Resumes a paused cluster.","ref":"AWS.Redshift.html#resume_cluster/3","title":"AWS.Redshift.resume_cluster/3","type":"function"},{"doc":"Revokes an ingress rule in an Amazon Redshift security group for a previously\nauthorized IP range or Amazon EC2 security group.\n\nTo add an ingress rule, see `AuthorizeClusterSecurityGroupIngress`. For\ninformation about managing security groups, go to [Amazon Redshift Cluster Security\nGroups](https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-security-groups.html)\nin the *Amazon Redshift Cluster Management Guide*.","ref":"AWS.Redshift.html#revoke_cluster_security_group_ingress/3","title":"AWS.Redshift.revoke_cluster_security_group_ingress/3","type":"function"},{"doc":"Revokes access to a cluster.","ref":"AWS.Redshift.html#revoke_endpoint_access/3","title":"AWS.Redshift.revoke_endpoint_access/3","type":"function"},{"doc":"Removes the ability of the specified Amazon Web Services account to restore the\nspecified snapshot.\n\nIf the account is currently restoring the snapshot, the restore will run to\ncompletion.\n\nFor more information about working with snapshots, go to [Amazon Redshift Snapshots](https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-snapshots.html)\nin the *Amazon Redshift Cluster Management Guide*.","ref":"AWS.Redshift.html#revoke_snapshot_access/3","title":"AWS.Redshift.revoke_snapshot_access/3","type":"function"},{"doc":"Rotates the encryption keys for a cluster.","ref":"AWS.Redshift.html#rotate_encryption_key/3","title":"AWS.Redshift.rotate_encryption_key/3","type":"function"},{"doc":"Updates the status of a partner integration.","ref":"AWS.Redshift.html#update_partner_status/3","title":"AWS.Redshift.update_partner_status/3","type":"function"},{"doc":"You can use the Amazon Redshift Data API to run queries on Amazon Redshift\ntables.\n\nYou can run SQL statements, which are committed if the statement succeeds.\n\nFor more information about the Amazon Redshift Data API and CLI usage examples,\nsee [Using the Amazon Redshift Data API](https://docs.aws.amazon.com/redshift/latest/mgmt/data-api.html) in the\n*Amazon Redshift Management Guide*.","ref":"AWS.RedshiftData.html","title":"AWS.RedshiftData","type":"module"},{"doc":"Runs one or more SQL statements, which can be data manipulation language (DML)\nor data definition language (DDL).\n\nDepending on the authorization method, use one of the following combinations of\nrequest parameters:\n\n  * Secrets Manager - when connecting to a cluster, provide the\n`secret-arn` of a secret stored in Secrets Manager which has `username` and\n`password`. The specified secret contains credentials to connect to the\n`database` you specify. When you are connecting to a cluster, you also supply\nthe database name, If you provide a cluster identifier (`dbClusterIdentifier`),\nit must match the cluster identifier stored in the secret. When you are\nconnecting to a serverless workgroup, you also supply the database name.\n\n  * Temporary credentials - when connecting to your data warehouse,\nchoose one of the following options:\n\n    * When connecting to a serverless workgroup, specify the\nworkgroup name and database name. The database user name is derived from the IAM\nidentity. For example, `arn:iam::123456789012:user:foo` has the database user\nname `IAM:foo`. Also, permission to call the\n`redshift-serverless:GetCredentials` operation is required.\n\n    * When connecting to a cluster as an IAM identity,\nspecify the cluster identifier and the database name. The database user name is\nderived from the IAM identity. For example, `arn:iam::123456789012:user:foo` has\nthe database user name `IAM:foo`. Also, permission to call the\n`redshift:GetClusterCredentialsWithIAM` operation is required.\n\n    * When connecting to a cluster as a database user,\nspecify the cluster identifier, the database name, and the database user name.\nAlso, permission to call the `redshift:GetClusterCredentials` operation is\nrequired.\n\nFor more information about the Amazon Redshift Data API and CLI usage examples,\nsee [Using the Amazon Redshift Data API](https://docs.aws.amazon.com/redshift/latest/mgmt/data-api.html) in the\n*Amazon Redshift Management Guide*.","ref":"AWS.RedshiftData.html#batch_execute_statement/3","title":"AWS.RedshiftData.batch_execute_statement/3","type":"function"},{"doc":"Cancels a running query.\n\nTo be canceled, a query must be running.\n\nFor more information about the Amazon Redshift Data API and CLI usage examples,\nsee [Using the Amazon Redshift Data API](https://docs.aws.amazon.com/redshift/latest/mgmt/data-api.html) in the\n*Amazon Redshift Management Guide*.","ref":"AWS.RedshiftData.html#cancel_statement/3","title":"AWS.RedshiftData.cancel_statement/3","type":"function"},{"doc":"Describes the details about a specific instance when a query was run by the\nAmazon Redshift Data API.\n\nThe information includes when the query started, when it finished, the query\nstatus, the number of rows returned, and the SQL statement.\n\nFor more information about the Amazon Redshift Data API and CLI usage examples,\nsee [Using the Amazon Redshift Data API](https://docs.aws.amazon.com/redshift/latest/mgmt/data-api.html) in the\n*Amazon Redshift Management Guide*.","ref":"AWS.RedshiftData.html#describe_statement/3","title":"AWS.RedshiftData.describe_statement/3","type":"function"},{"doc":"Describes the detailed information about a table from metadata in the cluster.\n\nThe information includes its columns. A token is returned to page through the\ncolumn list. Depending on the authorization method, use one of the following\ncombinations of request parameters:\n\n  * Secrets Manager - when connecting to a cluster, provide the\n`secret-arn` of a secret stored in Secrets Manager which has `username` and\n`password`. The specified secret contains credentials to connect to the\n`database` you specify. When you are connecting to a cluster, you also supply\nthe database name, If you provide a cluster identifier (`dbClusterIdentifier`),\nit must match the cluster identifier stored in the secret. When you are\nconnecting to a serverless workgroup, you also supply the database name.\n\n  * Temporary credentials - when connecting to your data warehouse,\nchoose one of the following options:\n\n    * When connecting to a serverless workgroup, specify the\nworkgroup name and database name. The database user name is derived from the IAM\nidentity. For example, `arn:iam::123456789012:user:foo` has the database user\nname `IAM:foo`. Also, permission to call the\n`redshift-serverless:GetCredentials` operation is required.\n\n    * When connecting to a cluster as an IAM identity,\nspecify the cluster identifier and the database name. The database user name is\nderived from the IAM identity. For example, `arn:iam::123456789012:user:foo` has\nthe database user name `IAM:foo`. Also, permission to call the\n`redshift:GetClusterCredentialsWithIAM` operation is required.\n\n    * When connecting to a cluster as a database user,\nspecify the cluster identifier, the database name, and the database user name.\nAlso, permission to call the `redshift:GetClusterCredentials` operation is\nrequired.\n\nFor more information about the Amazon Redshift Data API and CLI usage examples,\nsee [Using the Amazon Redshift Data API](https://docs.aws.amazon.com/redshift/latest/mgmt/data-api.html) in the\n*Amazon Redshift Management Guide*.","ref":"AWS.RedshiftData.html#describe_table/3","title":"AWS.RedshiftData.describe_table/3","type":"function"},{"doc":"Runs an SQL statement, which can be data manipulation language (DML) or data\ndefinition language (DDL).\n\nThis statement must be a single SQL statement. Depending on the authorization\nmethod, use one of the following combinations of request parameters:\n\n  * Secrets Manager - when connecting to a cluster, provide the\n`secret-arn` of a secret stored in Secrets Manager which has `username` and\n`password`. The specified secret contains credentials to connect to the\n`database` you specify. When you are connecting to a cluster, you also supply\nthe database name, If you provide a cluster identifier (`dbClusterIdentifier`),\nit must match the cluster identifier stored in the secret. When you are\nconnecting to a serverless workgroup, you also supply the database name.\n\n  * Temporary credentials - when connecting to your data warehouse,\nchoose one of the following options:\n\n    * When connecting to a serverless workgroup, specify the\nworkgroup name and database name. The database user name is derived from the IAM\nidentity. For example, `arn:iam::123456789012:user:foo` has the database user\nname `IAM:foo`. Also, permission to call the\n`redshift-serverless:GetCredentials` operation is required.\n\n    * When connecting to a cluster as an IAM identity,\nspecify the cluster identifier and the database name. The database user name is\nderived from the IAM identity. For example, `arn:iam::123456789012:user:foo` has\nthe database user name `IAM:foo`. Also, permission to call the\n`redshift:GetClusterCredentialsWithIAM` operation is required.\n\n    * When connecting to a cluster as a database user,\nspecify the cluster identifier, the database name, and the database user name.\nAlso, permission to call the `redshift:GetClusterCredentials` operation is\nrequired.\n\nFor more information about the Amazon Redshift Data API and CLI usage examples,\nsee [Using the Amazon Redshift Data API](https://docs.aws.amazon.com/redshift/latest/mgmt/data-api.html) in the\n*Amazon Redshift Management Guide*.","ref":"AWS.RedshiftData.html#execute_statement/3","title":"AWS.RedshiftData.execute_statement/3","type":"function"},{"doc":"Fetches the temporarily cached result of an SQL statement.\n\nA token is returned to page through the statement results.\n\nFor more information about the Amazon Redshift Data API and CLI usage examples,\nsee [Using the Amazon Redshift Data API](https://docs.aws.amazon.com/redshift/latest/mgmt/data-api.html) in the\n*Amazon Redshift Management Guide*.","ref":"AWS.RedshiftData.html#get_statement_result/3","title":"AWS.RedshiftData.get_statement_result/3","type":"function"},{"doc":"List the databases in a cluster.\n\nA token is returned to page through the database list. Depending on the\nauthorization method, use one of the following combinations of request\nparameters:\n\n  * Secrets Manager - when connecting to a cluster, provide the\n`secret-arn` of a secret stored in Secrets Manager which has `username` and\n`password`. The specified secret contains credentials to connect to the\n`database` you specify. When you are connecting to a cluster, you also supply\nthe database name, If you provide a cluster identifier (`dbClusterIdentifier`),\nit must match the cluster identifier stored in the secret. When you are\nconnecting to a serverless workgroup, you also supply the database name.\n\n  * Temporary credentials - when connecting to your data warehouse,\nchoose one of the following options:\n\n    * When connecting to a serverless workgroup, specify the\nworkgroup name and database name. The database user name is derived from the IAM\nidentity. For example, `arn:iam::123456789012:user:foo` has the database user\nname `IAM:foo`. Also, permission to call the\n`redshift-serverless:GetCredentials` operation is required.\n\n    * When connecting to a cluster as an IAM identity,\nspecify the cluster identifier and the database name. The database user name is\nderived from the IAM identity. For example, `arn:iam::123456789012:user:foo` has\nthe database user name `IAM:foo`. Also, permission to call the\n`redshift:GetClusterCredentialsWithIAM` operation is required.\n\n    * When connecting to a cluster as a database user,\nspecify the cluster identifier, the database name, and the database user name.\nAlso, permission to call the `redshift:GetClusterCredentials` operation is\nrequired.\n\nFor more information about the Amazon Redshift Data API and CLI usage examples,\nsee [Using the Amazon Redshift Data API](https://docs.aws.amazon.com/redshift/latest/mgmt/data-api.html) in the\n*Amazon Redshift Management Guide*.","ref":"AWS.RedshiftData.html#list_databases/3","title":"AWS.RedshiftData.list_databases/3","type":"function"},{"doc":"Lists the schemas in a database.\n\nA token is returned to page through the schema list. Depending on the\nauthorization method, use one of the following combinations of request\nparameters:\n\n  * Secrets Manager - when connecting to a cluster, provide the\n`secret-arn` of a secret stored in Secrets Manager which has `username` and\n`password`. The specified secret contains credentials to connect to the\n`database` you specify. When you are connecting to a cluster, you also supply\nthe database name, If you provide a cluster identifier (`dbClusterIdentifier`),\nit must match the cluster identifier stored in the secret. When you are\nconnecting to a serverless workgroup, you also supply the database name.\n\n  * Temporary credentials - when connecting to your data warehouse,\nchoose one of the following options:\n\n    * When connecting to a serverless workgroup, specify the\nworkgroup name and database name. The database user name is derived from the IAM\nidentity. For example, `arn:iam::123456789012:user:foo` has the database user\nname `IAM:foo`. Also, permission to call the\n`redshift-serverless:GetCredentials` operation is required.\n\n    * When connecting to a cluster as an IAM identity,\nspecify the cluster identifier and the database name. The database user name is\nderived from the IAM identity. For example, `arn:iam::123456789012:user:foo` has\nthe database user name `IAM:foo`. Also, permission to call the\n`redshift:GetClusterCredentialsWithIAM` operation is required.\n\n    * When connecting to a cluster as a database user,\nspecify the cluster identifier, the database name, and the database user name.\nAlso, permission to call the `redshift:GetClusterCredentials` operation is\nrequired.\n\nFor more information about the Amazon Redshift Data API and CLI usage examples,\nsee [Using the Amazon Redshift Data API](https://docs.aws.amazon.com/redshift/latest/mgmt/data-api.html) in the\n*Amazon Redshift Management Guide*.","ref":"AWS.RedshiftData.html#list_schemas/3","title":"AWS.RedshiftData.list_schemas/3","type":"function"},{"doc":"List of SQL statements.\n\nBy default, only finished statements are shown. A token is returned to page\nthrough the statement list.\n\nFor more information about the Amazon Redshift Data API and CLI usage examples,\nsee [Using the Amazon Redshift Data API](https://docs.aws.amazon.com/redshift/latest/mgmt/data-api.html) in the\n*Amazon Redshift Management Guide*.","ref":"AWS.RedshiftData.html#list_statements/3","title":"AWS.RedshiftData.list_statements/3","type":"function"},{"doc":"List the tables in a database.\n\nIf neither `SchemaPattern` nor `TablePattern` are specified, then all tables in\nthe database are returned. A token is returned to page through the table list.\nDepending on the authorization method, use one of the following combinations of\nrequest parameters:\n\n  * Secrets Manager - when connecting to a cluster, provide the\n`secret-arn` of a secret stored in Secrets Manager which has `username` and\n`password`. The specified secret contains credentials to connect to the\n`database` you specify. When you are connecting to a cluster, you also supply\nthe database name, If you provide a cluster identifier (`dbClusterIdentifier`),\nit must match the cluster identifier stored in the secret. When you are\nconnecting to a serverless workgroup, you also supply the database name.\n\n  * Temporary credentials - when connecting to your data warehouse,\nchoose one of the following options:\n\n    * When connecting to a serverless workgroup, specify the\nworkgroup name and database name. The database user name is derived from the IAM\nidentity. For example, `arn:iam::123456789012:user:foo` has the database user\nname `IAM:foo`. Also, permission to call the\n`redshift-serverless:GetCredentials` operation is required.\n\n    * When connecting to a cluster as an IAM identity,\nspecify the cluster identifier and the database name. The database user name is\nderived from the IAM identity. For example, `arn:iam::123456789012:user:foo` has\nthe database user name `IAM:foo`. Also, permission to call the\n`redshift:GetClusterCredentialsWithIAM` operation is required.\n\n    * When connecting to a cluster as a database user,\nspecify the cluster identifier, the database name, and the database user name.\nAlso, permission to call the `redshift:GetClusterCredentials` operation is\nrequired.\n\nFor more information about the Amazon Redshift Data API and CLI usage examples,\nsee [Using the Amazon Redshift Data API](https://docs.aws.amazon.com/redshift/latest/mgmt/data-api.html) in the\n*Amazon Redshift Management Guide*.","ref":"AWS.RedshiftData.html#list_tables/3","title":"AWS.RedshiftData.list_tables/3","type":"function"},{"doc":"","ref":"AWS.RedshiftData.html#metadata/0","title":"AWS.RedshiftData.metadata/0","type":"function"},{"doc":"This is an interface reference for Amazon Redshift Serverless.\n\nIt contains documentation for one of the programming or command line interfaces\nyou can use to manage Amazon Redshift Serverless.\n\nAmazon Redshift Serverless automatically provisions data warehouse capacity and\nintelligently scales the underlying resources based on workload demands. Amazon\nRedshift Serverless adjusts capacity in seconds to deliver consistently high\nperformance and simplified operations for even the most demanding and volatile\nworkloads. Amazon Redshift Serverless lets you focus on using your data to\nacquire new insights for your business and customers.\n\nTo learn more about Amazon Redshift Serverless, see [What is Amazon Redshift Serverless](https://docs.aws.amazon.com/redshift/latest/mgmt/serverless-whatis.html).","ref":"AWS.RedshiftServerless.html","title":"AWS.RedshiftServerless","type":"module"},{"doc":"Converts a recovery point to a snapshot.\n\nFor more information about recovery points and snapshots, see [Working with snapshots and recovery\npoints](https://docs.aws.amazon.com/redshift/latest/mgmt/serverless-snapshots-recovery.html).","ref":"AWS.RedshiftServerless.html#convert_recovery_point_to_snapshot/3","title":"AWS.RedshiftServerless.convert_recovery_point_to_snapshot/3","type":"function"},{"doc":"Creates a custom domain association for Amazon Redshift Serverless.","ref":"AWS.RedshiftServerless.html#create_custom_domain_association/3","title":"AWS.RedshiftServerless.create_custom_domain_association/3","type":"function"},{"doc":"Creates an Amazon Redshift Serverless managed VPC endpoint.","ref":"AWS.RedshiftServerless.html#create_endpoint_access/3","title":"AWS.RedshiftServerless.create_endpoint_access/3","type":"function"},{"doc":"Creates a namespace in Amazon Redshift Serverless.","ref":"AWS.RedshiftServerless.html#create_namespace/3","title":"AWS.RedshiftServerless.create_namespace/3","type":"function"},{"doc":"Creates a scheduled action.\n\nA scheduled action contains a schedule and an Amazon Redshift API action. For\nexample, you can create a schedule of when to run the `CreateSnapshot` API\noperation.","ref":"AWS.RedshiftServerless.html#create_scheduled_action/3","title":"AWS.RedshiftServerless.create_scheduled_action/3","type":"function"},{"doc":"Creates a snapshot of all databases in a namespace.\n\nFor more information about snapshots, see [ Working with snapshots and recovery points](https://docs.aws.amazon.com/redshift/latest/mgmt/serverless-snapshots-recovery.html).","ref":"AWS.RedshiftServerless.html#create_snapshot/3","title":"AWS.RedshiftServerless.create_snapshot/3","type":"function"},{"doc":"Creates a snapshot copy configuration that lets you copy snapshots to another\nAmazon Web Services Region.","ref":"AWS.RedshiftServerless.html#create_snapshot_copy_configuration/3","title":"AWS.RedshiftServerless.create_snapshot_copy_configuration/3","type":"function"},{"doc":"Creates a usage limit for a specified Amazon Redshift Serverless usage type.\n\nThe usage limit is identified by the returned usage limit identifier.","ref":"AWS.RedshiftServerless.html#create_usage_limit/3","title":"AWS.RedshiftServerless.create_usage_limit/3","type":"function"},{"doc":"Creates an workgroup in Amazon Redshift Serverless.","ref":"AWS.RedshiftServerless.html#create_workgroup/3","title":"AWS.RedshiftServerless.create_workgroup/3","type":"function"},{"doc":"Deletes a custom domain association for Amazon Redshift Serverless.","ref":"AWS.RedshiftServerless.html#delete_custom_domain_association/3","title":"AWS.RedshiftServerless.delete_custom_domain_association/3","type":"function"},{"doc":"Deletes an Amazon Redshift Serverless managed VPC endpoint.","ref":"AWS.RedshiftServerless.html#delete_endpoint_access/3","title":"AWS.RedshiftServerless.delete_endpoint_access/3","type":"function"},{"doc":"Deletes a namespace from Amazon Redshift Serverless.\n\nBefore you delete the namespace, you can create a final snapshot that has all of\nthe data within the namespace.","ref":"AWS.RedshiftServerless.html#delete_namespace/3","title":"AWS.RedshiftServerless.delete_namespace/3","type":"function"},{"doc":"Deletes the specified resource policy.","ref":"AWS.RedshiftServerless.html#delete_resource_policy/3","title":"AWS.RedshiftServerless.delete_resource_policy/3","type":"function"},{"doc":"Deletes a scheduled action.","ref":"AWS.RedshiftServerless.html#delete_scheduled_action/3","title":"AWS.RedshiftServerless.delete_scheduled_action/3","type":"function"},{"doc":"Deletes a snapshot from Amazon Redshift Serverless.","ref":"AWS.RedshiftServerless.html#delete_snapshot/3","title":"AWS.RedshiftServerless.delete_snapshot/3","type":"function"},{"doc":"Deletes a snapshot copy configuration","ref":"AWS.RedshiftServerless.html#delete_snapshot_copy_configuration/3","title":"AWS.RedshiftServerless.delete_snapshot_copy_configuration/3","type":"function"},{"doc":"Deletes a usage limit from Amazon Redshift Serverless.","ref":"AWS.RedshiftServerless.html#delete_usage_limit/3","title":"AWS.RedshiftServerless.delete_usage_limit/3","type":"function"},{"doc":"Deletes a workgroup.","ref":"AWS.RedshiftServerless.html#delete_workgroup/3","title":"AWS.RedshiftServerless.delete_workgroup/3","type":"function"},{"doc":"Returns a database user name and temporary password with temporary authorization\nto log in to Amazon Redshift Serverless.\n\nBy default, the temporary credentials expire in 900 seconds. You can optionally\nspecify a duration between 900 seconds (15 minutes) and 3600 seconds (60\nminutes).\n\n` The Identity and Access Management (IAM) user or role that runs GetCredentials\nmust have an IAM policy attached that allows access to all necessary actions and\nresources.\n\nIf the `DbName` parameter is specified, the IAM policy must allow access to the\nresource dbname for the specified database name.\n\n`","ref":"AWS.RedshiftServerless.html#get_credentials/3","title":"AWS.RedshiftServerless.get_credentials/3","type":"function"},{"doc":"Gets information about a specific custom domain association.","ref":"AWS.RedshiftServerless.html#get_custom_domain_association/3","title":"AWS.RedshiftServerless.get_custom_domain_association/3","type":"function"},{"doc":"Returns information, such as the name, about a VPC endpoint.","ref":"AWS.RedshiftServerless.html#get_endpoint_access/3","title":"AWS.RedshiftServerless.get_endpoint_access/3","type":"function"},{"doc":"Returns information about a namespace in Amazon Redshift Serverless.","ref":"AWS.RedshiftServerless.html#get_namespace/3","title":"AWS.RedshiftServerless.get_namespace/3","type":"function"},{"doc":"Returns information about a recovery point.","ref":"AWS.RedshiftServerless.html#get_recovery_point/3","title":"AWS.RedshiftServerless.get_recovery_point/3","type":"function"},{"doc":"Returns a resource policy.","ref":"AWS.RedshiftServerless.html#get_resource_policy/3","title":"AWS.RedshiftServerless.get_resource_policy/3","type":"function"},{"doc":"Returns information about a scheduled action.","ref":"AWS.RedshiftServerless.html#get_scheduled_action/3","title":"AWS.RedshiftServerless.get_scheduled_action/3","type":"function"},{"doc":"Returns information about a specific snapshot.","ref":"AWS.RedshiftServerless.html#get_snapshot/3","title":"AWS.RedshiftServerless.get_snapshot/3","type":"function"},{"doc":"Returns information about a `TableRestoreStatus` object.","ref":"AWS.RedshiftServerless.html#get_table_restore_status/3","title":"AWS.RedshiftServerless.get_table_restore_status/3","type":"function"},{"doc":"Returns information about a usage limit.","ref":"AWS.RedshiftServerless.html#get_usage_limit/3","title":"AWS.RedshiftServerless.get_usage_limit/3","type":"function"},{"doc":"Returns information about a specific workgroup.","ref":"AWS.RedshiftServerless.html#get_workgroup/3","title":"AWS.RedshiftServerless.get_workgroup/3","type":"function"},{"doc":"Lists custom domain associations for Amazon Redshift Serverless.","ref":"AWS.RedshiftServerless.html#list_custom_domain_associations/3","title":"AWS.RedshiftServerless.list_custom_domain_associations/3","type":"function"},{"doc":"Returns an array of `EndpointAccess` objects and relevant information.","ref":"AWS.RedshiftServerless.html#list_endpoint_access/3","title":"AWS.RedshiftServerless.list_endpoint_access/3","type":"function"},{"doc":"Returns information about a list of specified namespaces.","ref":"AWS.RedshiftServerless.html#list_namespaces/3","title":"AWS.RedshiftServerless.list_namespaces/3","type":"function"},{"doc":"Returns an array of recovery points.","ref":"AWS.RedshiftServerless.html#list_recovery_points/3","title":"AWS.RedshiftServerless.list_recovery_points/3","type":"function"},{"doc":"Returns a list of scheduled actions.\n\nYou can use the flags to filter the list of returned scheduled actions.","ref":"AWS.RedshiftServerless.html#list_scheduled_actions/3","title":"AWS.RedshiftServerless.list_scheduled_actions/3","type":"function"},{"doc":"Returns a list of snapshot copy configurations.","ref":"AWS.RedshiftServerless.html#list_snapshot_copy_configurations/3","title":"AWS.RedshiftServerless.list_snapshot_copy_configurations/3","type":"function"},{"doc":"Returns a list of snapshots.","ref":"AWS.RedshiftServerless.html#list_snapshots/3","title":"AWS.RedshiftServerless.list_snapshots/3","type":"function"},{"doc":"Returns information about an array of `TableRestoreStatus` objects.","ref":"AWS.RedshiftServerless.html#list_table_restore_status/3","title":"AWS.RedshiftServerless.list_table_restore_status/3","type":"function"},{"doc":"Lists the tags assigned to a resource.","ref":"AWS.RedshiftServerless.html#list_tags_for_resource/3","title":"AWS.RedshiftServerless.list_tags_for_resource/3","type":"function"},{"doc":"Lists all usage limits within Amazon Redshift Serverless.","ref":"AWS.RedshiftServerless.html#list_usage_limits/3","title":"AWS.RedshiftServerless.list_usage_limits/3","type":"function"},{"doc":"Returns information about a list of specified workgroups.","ref":"AWS.RedshiftServerless.html#list_workgroups/3","title":"AWS.RedshiftServerless.list_workgroups/3","type":"function"},{"doc":"","ref":"AWS.RedshiftServerless.html#metadata/0","title":"AWS.RedshiftServerless.metadata/0","type":"function"},{"doc":"Creates or updates a resource policy.\n\nCurrently, you can use policies to share snapshots across Amazon Web Services\naccounts.","ref":"AWS.RedshiftServerless.html#put_resource_policy/3","title":"AWS.RedshiftServerless.put_resource_policy/3","type":"function"},{"doc":"Restore the data from a recovery point.","ref":"AWS.RedshiftServerless.html#restore_from_recovery_point/3","title":"AWS.RedshiftServerless.restore_from_recovery_point/3","type":"function"},{"doc":"Restores a namespace from a snapshot.","ref":"AWS.RedshiftServerless.html#restore_from_snapshot/3","title":"AWS.RedshiftServerless.restore_from_snapshot/3","type":"function"},{"doc":"Restores a table from a recovery point to your Amazon Redshift Serverless\ninstance.\n\nYou can't use this operation to restore tables with interleaved sort keys.","ref":"AWS.RedshiftServerless.html#restore_table_from_recovery_point/3","title":"AWS.RedshiftServerless.restore_table_from_recovery_point/3","type":"function"},{"doc":"Restores a table from a snapshot to your Amazon Redshift Serverless instance.\n\nYou can't use this operation to restore tables with [interleaved sort keys](https://docs.aws.amazon.com/redshift/latest/dg/t_Sorting_data.html#t_Sorting_data-interleaved).","ref":"AWS.RedshiftServerless.html#restore_table_from_snapshot/3","title":"AWS.RedshiftServerless.restore_table_from_snapshot/3","type":"function"},{"doc":"Assigns one or more tags to a resource.","ref":"AWS.RedshiftServerless.html#tag_resource/3","title":"AWS.RedshiftServerless.tag_resource/3","type":"function"},{"doc":"Removes a tag or set of tags from a resource.","ref":"AWS.RedshiftServerless.html#untag_resource/3","title":"AWS.RedshiftServerless.untag_resource/3","type":"function"},{"doc":"Updates an Amazon Redshift Serverless certificate associated with a custom\ndomain.","ref":"AWS.RedshiftServerless.html#update_custom_domain_association/3","title":"AWS.RedshiftServerless.update_custom_domain_association/3","type":"function"},{"doc":"Updates an Amazon Redshift Serverless managed endpoint.","ref":"AWS.RedshiftServerless.html#update_endpoint_access/3","title":"AWS.RedshiftServerless.update_endpoint_access/3","type":"function"},{"doc":"Updates a namespace with the specified settings.\n\nUnless required, you can't update multiple parameters in one request. For\nexample, you must specify both `adminUsername` and `adminUserPassword` to update\neither field, but you can't update both `kmsKeyId` and `logExports` in a single\nrequest.","ref":"AWS.RedshiftServerless.html#update_namespace/3","title":"AWS.RedshiftServerless.update_namespace/3","type":"function"},{"doc":"Updates a scheduled action.","ref":"AWS.RedshiftServerless.html#update_scheduled_action/3","title":"AWS.RedshiftServerless.update_scheduled_action/3","type":"function"},{"doc":"Updates a snapshot.","ref":"AWS.RedshiftServerless.html#update_snapshot/3","title":"AWS.RedshiftServerless.update_snapshot/3","type":"function"},{"doc":"Updates a snapshot copy configuration.","ref":"AWS.RedshiftServerless.html#update_snapshot_copy_configuration/3","title":"AWS.RedshiftServerless.update_snapshot_copy_configuration/3","type":"function"},{"doc":"Update a usage limit in Amazon Redshift Serverless.\n\nYou can't update the usage type or period of a usage limit.","ref":"AWS.RedshiftServerless.html#update_usage_limit/3","title":"AWS.RedshiftServerless.update_usage_limit/3","type":"function"},{"doc":"Updates a workgroup with the specified configuration settings.\n\nYou can't update multiple parameters in one request. For example, you can update\n`baseCapacity` or `port` in a single request, but you can't update both in the\nsame request.","ref":"AWS.RedshiftServerless.html#update_workgroup/3","title":"AWS.RedshiftServerless.update_workgroup/3","type":"function"},{"doc":"This is the API Reference for [Amazon Rekognition Image](https://docs.aws.amazon.com/rekognition/latest/dg/images.html), [Amazon Rekognition Custom\nLabels](https://docs.aws.amazon.com/rekognition/latest/customlabels-dg/what-is.html),\n[Amazon Rekognition Stored Video](https://docs.aws.amazon.com/rekognition/latest/dg/video.html), [Amazon Rekognition Streaming\nVideo](https://docs.aws.amazon.com/rekognition/latest/dg/streaming-video.html).\n\nIt provides descriptions of actions, data types, common parameters, and common\nerrors.","ref":"AWS.Rekognition.html","title":"AWS.Rekognition","type":"module"},{"doc":"*\n[AssociateFaces](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_AssociateFaces.html)     *\n[CompareFaces](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_CompareFaces.html)\n\n  *\n[CreateCollection](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_CreateCollection.html)     *\n[CreateUser](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_CreateUser.html)\n\n  *\n[DeleteCollection](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_DeleteCollection.html)     *\n[DeleteFaces](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_DeleteFaces.html)\n\n  *\n[DeleteUser](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_DeleteUser.html)     *\n[DescribeCollection](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_DescribeCollection.html)\n\n  *\n[DetectFaces](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_DetectFaces.html)     *\n[DetectLabels](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_DetectLabels.html)\n\n  *\n[DetectModerationLabels](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_DetectModerationLabels.html)     *\n[DetectProtectiveEquipment](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_DetectProtectiveEquipment.html)\n\n  *\n[DetectText](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_DetectText.html)     *\n[DisassociateFaces](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_DisassociateFaces.html)\n\n  *\n[GetCelebrityInfo](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_GetCelebrityInfo.html)     *\n[GetMediaAnalysisJob](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_GetMediaAnalysisJob.html)\n\n  *\n[IndexFaces](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_IndexFaces.html)     *\n[ListCollections](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_ListCollections.html)\n\n  *\n[ListMediaAnalysisJob](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_ListMediaAnalysisJob.html)     *\n[ListFaces](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_ListFaces.html)\n\n  *\n[ListUsers](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_ListFaces.html)     *\n[RecognizeCelebrities](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_RecognizeCelebrities.html)\n\n  *\n[SearchFaces](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_SearchFaces.html)     *\n[SearchFacesByImage](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_SearchFacesByImage.html)\n\n  *\n[SearchUsers](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_SearchUsers.html)     *\n[SearchUsersByImage](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_SearchUsersByImage.html)\n\n  *\n[StartMediaAnalysisJob](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_StartMediaAnalysisJob.html)","ref":"AWS.Rekognition.html#module-amazon-rekognition-image","title":"Amazon Rekognition Image - AWS.Rekognition","type":"module"},{"doc":"*\n[CopyProjectVersion](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_CopyProjectVersion.html)\n\n  *\n[CreateDataset](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_CreateDataset.html)     *\n[CreateProject](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_CreateProject.html)\n\n  *\n[CreateProjectVersion](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_CreateProjectVersion.html)     *\n[DeleteDataset](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_DeleteDataset.html)\n\n  *\n[DeleteProject](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_DeleteProject.html)     *\n[DeleteProjectPolicy](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_DeleteProjectPolicy.html)\n\n  *\n[DeleteProjectVersion](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_DeleteProjectVersion.html)     *\n[DescribeDataset](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_DescribeDataset.html)\n\n  *\n[DescribeProjects](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_DescribeProjects.html)     *\n[DescribeProjectVersions](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_DescribeProjectVersions.html)\n\n  *\n[DetectCustomLabels](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_DetectCustomLabels.html)     *\n[DistributeDatasetEntries](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_DistributeDatasetEntries.html)\n\n  *\n[ListDatasetEntries](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_ListDatasetEntries.html)     *\n[ListDatasetLabels](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_ListDatasetLabels.html)\n\n  *\n[ListProjectPolicies](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_ListProjectPolicies.html)     *\n[PutProjectPolicy](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_PutProjectPolicy.html)\n\n  *\n[StartProjectVersion](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_StartProjectVersion.html)     *\n[StopProjectVersion](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_StopProjectVersion.html)\n\n  *\n[UpdateDatasetEntries](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_UpdateDatasetEntries.html)","ref":"AWS.Rekognition.html#module-amazon-rekognition-custom-labels","title":"Amazon Rekognition Custom Labels - AWS.Rekognition","type":"module"},{"doc":"*\n[GetCelebrityRecognition](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_GetCelebrityRecognition.html)\n\n  *\n[GetContentModeration](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_GetContentModeration.html)     *\n[GetFaceDetection](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_GetFaceDetection.html)\n\n  *\n[GetFaceSearch](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_GetFaceSearch.html)     *\n[GetLabelDetection](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_GetLabelDetection.html)\n\n  *\n[GetPersonTracking](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_GetPersonTracking.html)     *\n[GetSegmentDetection](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_GetSegmentDetection.html)\n\n  *\n[GetTextDetection](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_GetTextDetection.html)     *\n[StartCelebrityRecognition](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_StartCelebrityRecognition.html)\n\n  *\n[StartContentModeration](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_StartContentModeration.html)     *\n[StartFaceDetection](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_StartFaceDetection.html)\n\n  *\n[StartFaceSearch](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_StartFaceSearch.html)     *\n[StartLabelDetection](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_StartLabelDetection.html)\n\n  *\n[StartPersonTracking](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_StartPersonTracking.html)     *\n[StartSegmentDetection](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_StartSegmentDetection.html)\n\n  *\n[StartTextDetection](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_StartTextDetection.html)","ref":"AWS.Rekognition.html#module-amazon-rekognition-video-stored-video","title":"Amazon Rekognition Video Stored Video - AWS.Rekognition","type":"module"},{"doc":"*\n[CreateStreamProcessor](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_CreateStreamProcessor.html)\n\n  *\n[DeleteStreamProcessor](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_DeleteStreamProcessor.html)     *\n[DescribeStreamProcessor](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_DescribeStreamProcessor.html)\n\n  *\n[ListStreamProcessors](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_ListStreamProcessors.html)     *\n[StartStreamProcessor](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_StartStreamProcessor.html)\n\n  *\n[StopStreamProcessor](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_StopStreamProcessor.html)     *\n[UpdateStreamProcessor](https://docs.aws.amazon.com/rekognition/latest/APIReference/API_UpdateStreamProcessor.html)","ref":"AWS.Rekognition.html#module-amazon-rekognition-video-streaming-video","title":"Amazon Rekognition Video Streaming Video - AWS.Rekognition","type":"module"},{"doc":"Associates one or more faces with an existing UserID.\n\nTakes an array of `FaceIds`. Each `FaceId` that are present in the `FaceIds`\nlist is associated with the provided UserID. The maximum number of total\n`FaceIds` per UserID is 100.\n\nThe `UserMatchThreshold` parameter specifies the minimum user match confidence\nrequired for the face to be associated with a UserID that has at least one\n`FaceID` already associated. This ensures that the `FaceIds` are associated with\nthe right UserID. The value ranges from 0-100 and default value is 75.\n\nIf successful, an array of `AssociatedFace` objects containing the associated\n`FaceIds` is returned. If a given face is already associated with the given\n`UserID`, it will be ignored and will not be returned in the response. If a\ngiven face is already associated to a different `UserID`, isn't found in the\ncollection, doesn’t meet the `UserMatchThreshold`, or there are already 100\nfaces associated with the `UserID`, it will be returned as part of an array of\n`UnsuccessfulFaceAssociations.`\n\nThe `UserStatus` reflects the status of an operation which updates a UserID\nrepresentation with a list of given faces. The `UserStatus` can be:\n\n  * ACTIVE - All associations or disassociations of FaceID(s) for a\nUserID are complete.\n\n  * CREATED - A UserID has been created, but has no FaceID(s)\nassociated with it.\n\n  * UPDATING - A UserID is being updated and there are current\nassociations or disassociations of FaceID(s) taking place.","ref":"AWS.Rekognition.html#associate_faces/3","title":"AWS.Rekognition.associate_faces/3","type":"function"},{"doc":"Compares a face in the *source* input image with each of the 100 largest faces\ndetected in the *target* input image.\n\nIf the source image contains multiple faces, the service detects the largest\nface and compares it with each face detected in the target image.\n\nCompareFaces uses machine learning algorithms, which are probabilistic. A false\nnegative is an incorrect prediction that a face in the target image has a low\nsimilarity confidence score when compared to the face in the source image. To\nreduce the probability of false negatives, we recommend that you compare the\ntarget image against multiple source images. If you plan to use `CompareFaces`\nto make a decision that impacts an individual's rights, privacy, or access to\nservices, we recommend that you pass the result to a human for review and\nfurther validation before taking action.\n\nYou pass the input and target images either as base64-encoded image bytes or as\nreferences to images in an Amazon S3 bucket. If you use the AWS CLI to call\nAmazon Rekognition operations, passing image bytes isn't supported. The image\nmust be formatted as a PNG or JPEG file.\n\nIn response, the operation returns an array of face matches ordered by\nsimilarity score in descending order. For each face match, the response provides\na bounding box of the face, facial landmarks, pose details (pitch, roll, and\nyaw), quality (brightness and sharpness), and confidence value (indicating the\nlevel of confidence that the bounding box contains a face). The response also\nprovides a similarity score, which indicates how closely the faces match.\n\nBy default, only faces with a similarity score of greater than or equal to 80%\nare returned in the response. You can change this value by specifying the\n`SimilarityThreshold` parameter.\n\n`CompareFaces` also returns an array of faces that don't match the source image.\nFor each face, it returns a bounding box, confidence value, landmarks, pose\ndetails, and quality. The response also returns information about the face in\nthe source image, including the bounding box of the face and confidence value.\n\nThe `QualityFilter` input parameter allows you to filter out detected faces that\ndon’t meet a required quality bar. The quality bar is based on a variety of\ncommon use cases. Use `QualityFilter` to set the quality bar by specifying\n`LOW`, `MEDIUM`, or `HIGH`. If you do not want to filter detected faces, specify\n`NONE`. The default value is `NONE`.\n\nIf the image doesn't contain Exif metadata, `CompareFaces` returns orientation\ninformation for the source and target images. Use these values to display the\nimages with the correct image orientation.\n\nIf no faces are detected in the source or target images, `CompareFaces` returns\nan `InvalidParameterException` error.\n\nThis is a stateless API operation. That is, data returned by this operation\ndoesn't persist.\n\nFor an example, see Comparing Faces in Images in the Amazon Rekognition\nDeveloper Guide.\n\nThis operation requires permissions to perform the `rekognition:CompareFaces`\naction.","ref":"AWS.Rekognition.html#compare_faces/3","title":"AWS.Rekognition.compare_faces/3","type":"function"},{"doc":"This operation applies only to Amazon Rekognition Custom Labels.\n\nCopies a version of an Amazon Rekognition Custom Labels model from a source\nproject to a destination project. The source and destination projects can be in\ndifferent AWS accounts but must be in the same AWS Region. You can't copy a\nmodel to another AWS service.\n\nTo copy a model version to a different AWS account, you need to create a\nresource-based policy known as a *project policy*. You attach the project policy\nto the source project by calling `PutProjectPolicy`. The project policy gives\npermission to copy the model version from a trusting AWS account to a trusted\naccount.\n\nFor more information creating and attaching a project policy, see Attaching a\nproject policy (SDK) in the *Amazon Rekognition Custom Labels Developer Guide*.\n\nIf you are copying a model version to a project in the same AWS account, you\ndon't need to create a project policy.\n\nCopying project versions is supported only for Custom Labels models.\n\nTo copy a model, the destination project, source project, and source model\nversion must already exist.\n\nCopying a model version takes a while to complete. To get the current status,\ncall `DescribeProjectVersions` and check the value of `Status` in the\n`ProjectVersionDescription` object. The copy operation has finished when the\nvalue of `Status` is `COPYING_COMPLETED`.\n\nThis operation requires permissions to perform the\n`rekognition:CopyProjectVersion` action.","ref":"AWS.Rekognition.html#copy_project_version/3","title":"AWS.Rekognition.copy_project_version/3","type":"function"},{"doc":"Creates a collection in an AWS Region.\n\nYou can add faces to the collection using the `IndexFaces` operation.\n\nFor example, you might create collections, one for each of your application\nusers. A user can then index faces using the `IndexFaces` operation and persist\nresults in a specific collection. Then, a user can search the collection for\nfaces in the user-specific container.\n\nWhen you create a collection, it is associated with the latest version of the\nface model version.\n\nCollection names are case-sensitive.\n\nThis operation requires permissions to perform the\n`rekognition:CreateCollection` action. If you want to tag your collection, you\nalso require permission to perform the `rekognition:TagResource` operation.","ref":"AWS.Rekognition.html#create_collection/3","title":"AWS.Rekognition.create_collection/3","type":"function"},{"doc":"This operation applies only to Amazon Rekognition Custom Labels.\n\nCreates a new Amazon Rekognition Custom Labels dataset. You can create a dataset\nby using an Amazon Sagemaker format manifest file or by copying an existing\nAmazon Rekognition Custom Labels dataset.\n\nTo create a training dataset for a project, specify `TRAIN` for the value of\n`DatasetType`. To create the test dataset for a project, specify `TEST` for the\nvalue of `DatasetType`.\n\nThe response from `CreateDataset` is the Amazon Resource Name (ARN) for the\ndataset. Creating a dataset takes a while to complete. Use `DescribeDataset` to\ncheck the current status. The dataset created successfully if the value of\n`Status` is `CREATE_COMPLETE`.\n\nTo check if any non-terminal errors occurred, call `ListDatasetEntries` and\ncheck for the presence of `errors` lists in the JSON Lines.\n\nDataset creation fails if a terminal error occurs (`Status` = `CREATE_FAILED`).\nCurrently, you can't access the terminal error information.\n\nFor more information, see Creating dataset in the *Amazon Rekognition Custom\nLabels Developer Guide*.\n\nThis operation requires permissions to perform the `rekognition:CreateDataset`\naction. If you want to copy an existing dataset, you also require permission to\nperform the `rekognition:ListDatasetEntries` action.","ref":"AWS.Rekognition.html#create_dataset/3","title":"AWS.Rekognition.create_dataset/3","type":"function"},{"doc":"This API operation initiates a Face Liveness session.\n\nIt returns a `SessionId`, which you can use to start streaming Face Liveness\nvideo and get the results for a Face Liveness session.\n\nYou can use the `OutputConfig` option in the Settings parameter to provide an\nAmazon S3 bucket location. The Amazon S3 bucket stores reference images and\naudit images. If no Amazon S3 bucket is defined, raw bytes are sent instead.\n\nYou can use `AuditImagesLimit` to limit the number of audit images returned when\n`GetFaceLivenessSessionResults` is called. This number is between 0 and 4. By\ndefault, it is set to 0. The limit is best effort and based on the duration of\nthe selfie-video.","ref":"AWS.Rekognition.html#create_face_liveness_session/3","title":"AWS.Rekognition.create_face_liveness_session/3","type":"function"},{"doc":"Creates a new Amazon Rekognition project.\n\nA project is a group of resources (datasets, model versions) that you use to\ncreate and manage a Amazon Rekognition Custom Labels Model or custom adapter.\nYou can specify a feature to create the project with, if no feature is specified\nthen Custom Labels is used by default. For adapters, you can also choose whether\nor not to have the project auto update by using the AutoUpdate argument. This\noperation requires permissions to perform the `rekognition:CreateProject`\naction.","ref":"AWS.Rekognition.html#create_project/3","title":"AWS.Rekognition.create_project/3","type":"function"},{"doc":"Creates a new version of Amazon Rekognition project (like a Custom Labels model\nor a custom adapter) and begins training.\n\nModels and adapters are managed as part of a Rekognition project. The response\nfrom `CreateProjectVersion` is an Amazon Resource Name (ARN) for the project\nversion.\n\nThe FeatureConfig operation argument allows you to configure specific model or\nadapter settings. You can provide a description to the project version by using\nthe VersionDescription argment. Training can take a while to complete. You can\nget the current status by calling `DescribeProjectVersions`. Training completed\nsuccessfully if the value of the `Status` field is `TRAINING_COMPLETED`. Once\ntraining has successfully completed, call `DescribeProjectVersions` to get the\ntraining results and evaluate the model.\n\nThis operation requires permissions to perform the\n`rekognition:CreateProjectVersion` action.\n\n*The following applies only to projects with Amazon Rekognition Custom Labels as\nthe chosen feature:*\n\nYou can train a model in a project that doesn't have associated datasets by\nspecifying manifest files in the `TrainingData` and `TestingData` fields.\n\nIf you open the console after training a model with manifest files, Amazon\nRekognition Custom Labels creates the datasets for you using the most recent\nmanifest files. You can no longer train a model version for the project by\nspecifying manifest files.\n\nInstead of training with a project without associated datasets, we recommend\nthat you use the manifest files to create training and test datasets for the\nproject.","ref":"AWS.Rekognition.html#create_project_version/3","title":"AWS.Rekognition.create_project_version/3","type":"function"},{"doc":"Creates an Amazon Rekognition stream processor that you can use to detect and\nrecognize faces or to detect labels in a streaming video.\n\nAmazon Rekognition Video is a consumer of live video from Amazon Kinesis Video\nStreams. There are two different settings for stream processors in Amazon\nRekognition: detecting faces and detecting labels.\n\n  * If you are creating a stream processor for detecting faces, you\nprovide as input a Kinesis video stream (`Input`) and a Kinesis data stream\n(`Output`) stream for receiving the output. You must use the `FaceSearch` option\nin `Settings`, specifying the collection that contains the faces you want to\nrecognize. After you have finished analyzing a streaming video, use\n`StopStreamProcessor` to stop processing.\n\n  * If you are creating a stream processor to detect labels, you\nprovide as input a Kinesis video stream (`Input`), Amazon S3 bucket information\n(`Output`), and an Amazon SNS topic ARN (`NotificationChannel`). You can also\nprovide a KMS key ID to encrypt the data sent to your Amazon S3 bucket. You\nspecify what you want to detect by using the `ConnectedHome` option in settings,\nand selecting one of the following: `PERSON`, `PET`, `PACKAGE`, `ALL` You can\nalso specify where in the frame you want Amazon Rekognition to monitor with\n`RegionsOfInterest`. When you run the `StartStreamProcessor` operation on a\nlabel detection stream processor, you input start and stop information to\ndetermine the length of the processing time.\n\nUse `Name` to assign an identifier for the stream processor. You use `Name` to\nmanage the stream processor. For example, you can start processing the source\nvideo by calling `StartStreamProcessor` with the `Name` field.\n\nThis operation requires permissions to perform the\n`rekognition:CreateStreamProcessor` action. If you want to tag your stream\nprocessor, you also require permission to perform the `rekognition:TagResource`\noperation.","ref":"AWS.Rekognition.html#create_stream_processor/3","title":"AWS.Rekognition.create_stream_processor/3","type":"function"},{"doc":"Creates a new User within a collection specified by `CollectionId`.\n\nTakes `UserId` as a parameter, which is a user provided ID which should be\nunique within the collection. The provided `UserId` will alias the system\ngenerated UUID to make the `UserId` more user friendly.\n\nUses a `ClientToken`, an idempotency token that ensures a call to `CreateUser`\ncompletes only once. If the value is not supplied, the AWS SDK generates an\nidempotency token for the requests. This prevents retries after a network error\nresults from making multiple `CreateUser` calls.","ref":"AWS.Rekognition.html#create_user/3","title":"AWS.Rekognition.create_user/3","type":"function"},{"doc":"Deletes the specified collection.\n\nNote that this operation removes all faces in the collection. For an example,\nsee [Deleting a collection](https://docs.aws.amazon.com/rekognition/latest/dg/delete-collection-procedure.html).\n\nThis operation requires permissions to perform the\n`rekognition:DeleteCollection` action.","ref":"AWS.Rekognition.html#delete_collection/3","title":"AWS.Rekognition.delete_collection/3","type":"function"},{"doc":"This operation applies only to Amazon Rekognition Custom Labels.\n\nDeletes an existing Amazon Rekognition Custom Labels dataset. Deleting a dataset\nmight take while. Use `DescribeDataset` to check the current status. The dataset\nis still deleting if the value of `Status` is `DELETE_IN_PROGRESS`. If you try\nto access the dataset after it is deleted, you get a `ResourceNotFoundException`\nexception.\n\nYou can't delete a dataset while it is creating (`Status` =\n`CREATE_IN_PROGRESS`) or if the dataset is updating (`Status` =\n`UPDATE_IN_PROGRESS`).\n\nThis operation requires permissions to perform the `rekognition:DeleteDataset`\naction.","ref":"AWS.Rekognition.html#delete_dataset/3","title":"AWS.Rekognition.delete_dataset/3","type":"function"},{"doc":"Deletes faces from a collection.\n\nYou specify a collection ID and an array of face IDs to remove from the\ncollection.\n\nThis operation requires permissions to perform the `rekognition:DeleteFaces`\naction.","ref":"AWS.Rekognition.html#delete_faces/3","title":"AWS.Rekognition.delete_faces/3","type":"function"},{"doc":"Deletes a Amazon Rekognition project.\n\nTo delete a project you must first delete all models or adapters associated with\nthe project. To delete a model or adapter, see `DeleteProjectVersion`.\n\n`DeleteProject` is an asynchronous operation. To check if the project is\ndeleted, call `DescribeProjects`. The project is deleted when the project no\nlonger appears in the response. Be aware that deleting a given project will also\ndelete any `ProjectPolicies` associated with that project.\n\nThis operation requires permissions to perform the `rekognition:DeleteProject`\naction.","ref":"AWS.Rekognition.html#delete_project/3","title":"AWS.Rekognition.delete_project/3","type":"function"},{"doc":"This operation applies only to Amazon Rekognition Custom Labels.\n\nDeletes an existing project policy.\n\nTo get a list of project policies attached to a project, call\n`ListProjectPolicies`. To attach a project policy to a project, call\n`PutProjectPolicy`.\n\nThis operation requires permissions to perform the\n`rekognition:DeleteProjectPolicy` action.","ref":"AWS.Rekognition.html#delete_project_policy/3","title":"AWS.Rekognition.delete_project_policy/3","type":"function"},{"doc":"Deletes a Rekognition project model or project version, like a Amazon\nRekognition Custom Labels model or a custom adapter.\n\nYou can't delete a project version if it is running or if it is training. To\ncheck the status of a project version, use the Status field returned from\n`DescribeProjectVersions`. To stop a project version call `StopProjectVersion`.\nIf the project version is training, wait until it finishes.\n\nThis operation requires permissions to perform the\n`rekognition:DeleteProjectVersion` action.","ref":"AWS.Rekognition.html#delete_project_version/3","title":"AWS.Rekognition.delete_project_version/3","type":"function"},{"doc":"Deletes the stream processor identified by `Name`.\n\nYou assign the value for `Name` when you create the stream processor with\n`CreateStreamProcessor`. You might not be able to use the same name for a stream\nprocessor for a few seconds after calling `DeleteStreamProcessor`.","ref":"AWS.Rekognition.html#delete_stream_processor/3","title":"AWS.Rekognition.delete_stream_processor/3","type":"function"},{"doc":"Deletes the specified UserID within the collection.\n\nFaces that are associated with the UserID are disassociated from the UserID\nbefore deleting the specified UserID. If the specified `Collection` or `UserID`\nis already deleted or not found, a `ResourceNotFoundException` will be thrown.\nIf the action is successful with a 200 response, an empty HTTP body is returned.","ref":"AWS.Rekognition.html#delete_user/3","title":"AWS.Rekognition.delete_user/3","type":"function"},{"doc":"Describes the specified collection.\n\nYou can use `DescribeCollection` to get information, such as the number of faces\nindexed into a collection and the version of the model used by the collection\nfor face detection.\n\nFor more information, see Describing a Collection in the Amazon Rekognition\nDeveloper Guide.","ref":"AWS.Rekognition.html#describe_collection/3","title":"AWS.Rekognition.describe_collection/3","type":"function"},{"doc":"This operation applies only to Amazon Rekognition Custom Labels.\n\nDescribes an Amazon Rekognition Custom Labels dataset. You can get information\nsuch as the current status of a dataset and statistics about the images and\nlabels in a dataset.\n\nThis operation requires permissions to perform the `rekognition:DescribeDataset`\naction.","ref":"AWS.Rekognition.html#describe_dataset/3","title":"AWS.Rekognition.describe_dataset/3","type":"function"},{"doc":"Lists and describes the versions of an Amazon Rekognition project.\n\nYou can specify up to 10 model or adapter versions in `ProjectVersionArns`. If\nyou don't specify a value, descriptions for all model/adapter versions in the\nproject are returned.\n\nThis operation requires permissions to perform the\n`rekognition:DescribeProjectVersions` action.","ref":"AWS.Rekognition.html#describe_project_versions/3","title":"AWS.Rekognition.describe_project_versions/3","type":"function"},{"doc":"Gets information about your Rekognition projects.\n\nThis operation requires permissions to perform the\n`rekognition:DescribeProjects` action.","ref":"AWS.Rekognition.html#describe_projects/3","title":"AWS.Rekognition.describe_projects/3","type":"function"},{"doc":"Provides information about a stream processor created by\n`CreateStreamProcessor`.\n\nYou can get information about the input and output streams, the input parameters\nfor the face recognition being performed, and the current status of the stream\nprocessor.","ref":"AWS.Rekognition.html#describe_stream_processor/3","title":"AWS.Rekognition.describe_stream_processor/3","type":"function"},{"doc":"This operation applies only to Amazon Rekognition Custom Labels.\n\nDetects custom labels in a supplied image by using an Amazon Rekognition Custom\nLabels model.\n\nYou specify which version of a model version to use by using the\n`ProjectVersionArn` input parameter.\n\nYou pass the input image as base64-encoded image bytes or as a reference to an\nimage in an Amazon S3 bucket. If you use the AWS CLI to call Amazon Rekognition\noperations, passing image bytes is not supported. The image must be either a PNG\nor JPEG formatted file.\n\nFor each object that the model version detects on an image, the API returns a\n(`CustomLabel`) object in an array (`CustomLabels`). Each `CustomLabel` object\nprovides the label name (`Name`), the level of confidence that the image\ncontains the object (`Confidence`), and object location information, if it\nexists, for the label on the image (`Geometry`). Note that for the\n`DetectCustomLabelsLabels` operation, `Polygons` are not returned in the\n`Geometry` section of the response.\n\nTo filter labels that are returned, specify a value for `MinConfidence`.\n`DetectCustomLabelsLabels` only returns labels with a confidence that's higher\nthan the specified value. The value of `MinConfidence` maps to the assumed\nthreshold values created during training. For more information, see *Assumed\nthreshold* in the Amazon Rekognition Custom Labels Developer Guide. Amazon\nRekognition Custom Labels metrics expresses an assumed threshold as a floating\npoint value between 0-1. The range of `MinConfidence` normalizes the threshold\nvalue to a percentage value (0-100). Confidence responses from\n`DetectCustomLabels` are also returned as a percentage. You can use\n`MinConfidence` to change the precision and recall or your model. For more\ninformation, see *Analyzing an image* in the Amazon Rekognition Custom Labels\nDeveloper Guide.\n\nIf you don't specify a value for `MinConfidence`, `DetectCustomLabels` returns\nlabels based on the assumed threshold of each label.\n\nThis is a stateless API operation. That is, the operation does not persist any\ndata.\n\nThis operation requires permissions to perform the\n`rekognition:DetectCustomLabels` action.\n\nFor more information, see *Analyzing an image* in the Amazon Rekognition Custom\nLabels Developer Guide.","ref":"AWS.Rekognition.html#detect_custom_labels/3","title":"AWS.Rekognition.detect_custom_labels/3","type":"function"},{"doc":"Detects faces within an image that is provided as input.\n\n`DetectFaces` detects the 100 largest faces in the image. For each face\ndetected, the operation returns face details. These details include a bounding\nbox of the face, a confidence value (that the bounding box contains a face), and\na fixed set of attributes such as facial landmarks (for example, coordinates of\neye and mouth), pose, presence of facial occlusion, and so on.\n\nThe face-detection algorithm is most effective on frontal faces. For non-frontal\nor obscured faces, the algorithm might not detect the faces or might detect\nfaces with lower confidence.\n\nYou pass the input image either as base64-encoded image bytes or as a reference\nto an image in an Amazon S3 bucket. If you use the AWS CLI to call Amazon\nRekognition operations, passing image bytes is not supported. The image must be\neither a PNG or JPEG formatted file.\n\nThis is a stateless API operation. That is, the operation does not persist any\ndata.\n\nThis operation requires permissions to perform the `rekognition:DetectFaces`\naction.","ref":"AWS.Rekognition.html#detect_faces/3","title":"AWS.Rekognition.detect_faces/3","type":"function"},{"doc":"Detects instances of real-world entities within an image (JPEG or PNG) provided\nas input.\n\nThis includes objects like flower, tree, and table; events like wedding,\ngraduation, and birthday party; and concepts like landscape, evening, and\nnature.\n\nFor an example, see Analyzing images stored in an Amazon S3 bucket in the Amazon\nRekognition Developer Guide.\n\nYou pass the input image as base64-encoded image bytes or as a reference to an\nimage in an Amazon S3 bucket. If you use the AWS CLI to call Amazon Rekognition\noperations, passing image bytes is not supported. The image must be either a PNG\nor JPEG formatted file.","ref":"AWS.Rekognition.html#detect_labels/3","title":"AWS.Rekognition.detect_labels/3","type":"function"},{"doc":"You can specify one or both of the `GENERAL_LABELS` and `IMAGE_PROPERTIES`\nfeature types when calling the DetectLabels API. Including `GENERAL_LABELS` will\nensure the response includes the labels detected in the input image, while\nincluding `IMAGE_PROPERTIES `will ensure the response includes information about\nthe image quality and color.\n\nWhen using `GENERAL_LABELS` and/or `IMAGE_PROPERTIES` you can provide filtering\ncriteria to the Settings parameter. You can filter with sets of individual\nlabels or with label categories. You can specify inclusive filters, exclusive\nfilters, or a combination of inclusive and exclusive filters. For more\ninformation on filtering see [Detecting Labels in an Image](https://docs.aws.amazon.com/rekognition/latest/dg/labels-detect-labels-image.html).\n\nWhen getting labels, you can specify `MinConfidence` to control the confidence\nthreshold for the labels returned. The default is 55%. You can also add the\n`MaxLabels` parameter to limit the number of labels returned. The default and\nupper limit is 1000 labels. These arguments are only valid when supplying\nGENERAL_LABELS as a feature type.","ref":"AWS.Rekognition.html#detect_labels/3-optional-parameters","title":"Optional Parameters - AWS.Rekognition.detect_labels/3","type":"function"},{"doc":"For each object, scene, and concept the API returns one or more labels. The API\nreturns the following types of information about labels:\n\n  * Name - The name of the detected label.\n\n  * Confidence - The level of confidence in the label assigned to a\ndetected object.\n\n  * Parents - The ancestor labels for a detected label. DetectLabels\nreturns a hierarchical taxonomy of detected labels. For example, a detected car\nmight be assigned the label car. The label car has two parent labels: Vehicle\n(its parent) and Transportation (its grandparent). The response includes the all\nancestors for a label, where every ancestor is a unique label. In the previous\nexample, Car, Vehicle, and Transportation are returned as unique labels in the\nresponse.\n\n  * Aliases - Possible Aliases for the label.\n\n  * Categories - The label categories that the detected label belongs\nto.\n\n  * BoundingBox — Bounding boxes are described for all instances of\ndetected common object labels, returned in an array of Instance objects. An\nInstance object contains a BoundingBox object, describing the location of the\nlabel on the input image. It also includes the confidence for the accuracy of\nthe detected bounding box.\n\nThe API returns the following information regarding the image, as part of the\nImageProperties structure:\n\n  * Quality - Information about the Sharpness, Brightness, and\nContrast of the input image, scored between 0 to 100. Image quality is returned\nfor the entire image, as well as the background and the foreground.\n\n  * Dominant Color - An array of the dominant colors in the image.\n\n  * Foreground - Information about the sharpness, brightness, and\ndominant colors of the input image’s foreground.\n\n  * Background - Information about the sharpness, brightness, and\ndominant colors of the input image’s background.\n\nThe list of returned labels will include at least one label for every detected\nobject, along with information about that label. In the following example,\nsuppose the input image has a lighthouse, the sea, and a rock. The response\nincludes all three labels, one for each object, as well as the confidence in the\nlabel:\n\n`{Name: lighthouse, Confidence: 98.4629}`\n\n`{Name: rock,Confidence: 79.2097}`\n\n` {Name: sea,Confidence: 75.061}`\n\nThe list of labels can include multiple labels for the same object. For example,\nif the input image shows a flower (for example, a tulip), the operation might\nreturn the following three labels.\n\n`{Name: flower,Confidence: 99.0562}`\n\n`{Name: plant,Confidence: 99.0562}`\n\n`{Name: tulip,Confidence: 99.0562}`\n\nIn this example, the detection algorithm more precisely identifies the flower as\na tulip.\n\nIf the object detected is a person, the operation doesn't provide the same\nfacial details that the `DetectFaces` operation provides.\n\nThis is a stateless API operation that doesn't return any data.\n\nThis operation requires permissions to perform the `rekognition:DetectLabels`\naction.","ref":"AWS.Rekognition.html#detect_labels/3-response-elements","title":"Response Elements - AWS.Rekognition.detect_labels/3","type":"function"},{"doc":"Detects unsafe content in a specified JPEG or PNG format image.\n\nUse `DetectModerationLabels` to moderate images depending on your requirements.\nFor example, you might want to filter images that contain nudity, but not images\ncontaining suggestive content.\n\nTo filter images, use the labels returned by `DetectModerationLabels` to\ndetermine which types of content are appropriate.\n\nFor information about moderation labels, see Detecting Unsafe Content in the\nAmazon Rekognition Developer Guide.\n\nYou pass the input image either as base64-encoded image bytes or as a reference\nto an image in an Amazon S3 bucket. If you use the AWS CLI to call Amazon\nRekognition operations, passing image bytes is not supported. The image must be\neither a PNG or JPEG formatted file.\n\nYou can specify an adapter to use when retrieving label predictions by providing\na `ProjectVersionArn` to the `ProjectVersion` argument.","ref":"AWS.Rekognition.html#detect_moderation_labels/3","title":"AWS.Rekognition.detect_moderation_labels/3","type":"function"},{"doc":"Detects Personal Protective Equipment (PPE) worn by people detected in an image.\n\nAmazon Rekognition can detect the following types of PPE.\n\n  * Face cover\n\n  * Hand cover\n\n  * Head cover\n\nYou pass the input image as base64-encoded image bytes or as a reference to an\nimage in an Amazon S3 bucket. The image must be either a PNG or JPG formatted\nfile.\n\n`DetectProtectiveEquipment` detects PPE worn by up to 15 persons detected in an\nimage.\n\nFor each person detected in the image the API returns an array of body parts\n(face, head, left-hand, right-hand). For each body part, an array of detected\nitems of PPE is returned, including an indicator of whether or not the PPE\ncovers the body part. The API returns the confidence it has in each detection\n(person, PPE, body part and body part coverage). It also returns a bounding box\n(`BoundingBox`) for each detected person and each detected item of PPE.\n\nYou can optionally request a summary of detected PPE items with the\n`SummarizationAttributes` input parameter. The summary provides the following\ninformation.\n\n  * The persons detected as wearing all of the types of PPE that you\nspecify.\n\n  * The persons detected as not wearing all of the types PPE that you\nspecify.\n\n  * The persons detected where PPE adornment could not be determined.\n\nThis is a stateless API operation. That is, the operation does not persist any\ndata.\n\nThis operation requires permissions to perform the\n`rekognition:DetectProtectiveEquipment` action.","ref":"AWS.Rekognition.html#detect_protective_equipment/3","title":"AWS.Rekognition.detect_protective_equipment/3","type":"function"},{"doc":"Detects text in the input image and converts it into machine-readable text.\n\nPass the input image as base64-encoded image bytes or as a reference to an image\nin an Amazon S3 bucket. If you use the AWS CLI to call Amazon Rekognition\noperations, you must pass it as a reference to an image in an Amazon S3 bucket.\nFor the AWS CLI, passing image bytes is not supported. The image must be either\na .png or .jpeg formatted file.\n\nThe `DetectText` operation returns text in an array of `TextDetection` elements,\n`TextDetections`. Each `TextDetection` element provides information about a\nsingle word or line of text that was detected in the image.\n\nA word is one or more script characters that are not separated by spaces.\n`DetectText` can detect up to 100 words in an image.\n\nA line is a string of equally spaced words. A line isn't necessarily a complete\nsentence. For example, a driver's license number is detected as a line. A line\nends when there is no aligned text after it. Also, a line ends when there is a\nlarge gap between words, relative to the length of the words. This means,\ndepending on the gap between words, Amazon Rekognition may detect multiple lines\nin text aligned in the same direction. Periods don't represent the end of a\nline. If a sentence spans multiple lines, the `DetectText` operation returns\nmultiple lines.\n\nTo determine whether a `TextDetection` element is a line of text or a word, use\nthe `TextDetection` object `Type` field.\n\nTo be detected, text must be within +/- 90 degrees orientation of the horizontal\naxis.\n\nFor more information, see Detecting text in the Amazon Rekognition Developer\nGuide.","ref":"AWS.Rekognition.html#detect_text/3","title":"AWS.Rekognition.detect_text/3","type":"function"},{"doc":"Removes the association between a `Face` supplied in an array of `FaceIds` and\nthe User.\n\nIf the User is not present already, then a `ResourceNotFound` exception is\nthrown. If successful, an array of faces that are disassociated from the User is\nreturned. If a given face is already disassociated from the given UserID, it\nwill be ignored and not be returned in the response. If a given face is already\nassociated with a different User or not found in the collection it will be\nreturned as part of `UnsuccessfulDisassociations`. You can remove 1 - 100 face\nIDs from a user at one time.","ref":"AWS.Rekognition.html#disassociate_faces/3","title":"AWS.Rekognition.disassociate_faces/3","type":"function"},{"doc":"This operation applies only to Amazon Rekognition Custom Labels.\n\nDistributes the entries (images) in a training dataset across the training\ndataset and the test dataset for a project. `DistributeDatasetEntries` moves 20%\nof the training dataset images to the test dataset. An entry is a JSON Line that\ndescribes an image.\n\nYou supply the Amazon Resource Names (ARN) of a project's training dataset and\ntest dataset. The training dataset must contain the images that you want to\nsplit. The test dataset must be empty. The datasets must belong to the same\nproject. To create training and test datasets for a project, call\n`CreateDataset`.\n\nDistributing a dataset takes a while to complete. To check the status call\n`DescribeDataset`. The operation is complete when the `Status` field for the\ntraining dataset and the test dataset is `UPDATE_COMPLETE`. If the dataset split\nfails, the value of `Status` is `UPDATE_FAILED`.\n\nThis operation requires permissions to perform the\n`rekognition:DistributeDatasetEntries` action.","ref":"AWS.Rekognition.html#distribute_dataset_entries/3","title":"AWS.Rekognition.distribute_dataset_entries/3","type":"function"},{"doc":"Gets the name and additional information about a celebrity based on their Amazon\nRekognition ID.\n\nThe additional information is returned as an array of URLs. If there is no\nadditional information about the celebrity, this list is empty.\n\nFor more information, see Getting information about a celebrity in the Amazon\nRekognition Developer Guide.\n\nThis operation requires permissions to perform the\n`rekognition:GetCelebrityInfo` action.","ref":"AWS.Rekognition.html#get_celebrity_info/3","title":"AWS.Rekognition.get_celebrity_info/3","type":"function"},{"doc":"Gets the celebrity recognition results for a Amazon Rekognition Video analysis\nstarted by `StartCelebrityRecognition`.\n\nCelebrity recognition in a video is an asynchronous operation. Analysis is\nstarted by a call to `StartCelebrityRecognition` which returns a job identifier\n(`JobId`).\n\nWhen the celebrity recognition operation finishes, Amazon Rekognition Video\npublishes a completion status to the Amazon Simple Notification Service topic\nregistered in the initial call to `StartCelebrityRecognition`. To get the\nresults of the celebrity recognition analysis, first check that the status value\npublished to the Amazon SNS topic is `SUCCEEDED`. If so, call\n`GetCelebrityDetection` and pass the job identifier (`JobId`) from the initial\ncall to `StartCelebrityDetection`.\n\nFor more information, see Working With Stored Videos in the Amazon Rekognition\nDeveloper Guide.\n\n`GetCelebrityRecognition` returns detected celebrities and the time(s) they are\ndetected in an array (`Celebrities`) of `CelebrityRecognition` objects. Each\n`CelebrityRecognition` contains information about the celebrity in a\n`CelebrityDetail` object and the time, `Timestamp`, the celebrity was detected.\nThis `CelebrityDetail` object stores information about the detected celebrity's\nface attributes, a face bounding box, known gender, the celebrity's name, and a\nconfidence estimate.\n\n`GetCelebrityRecognition` only returns the default facial attributes\n(`BoundingBox`, `Confidence`, `Landmarks`, `Pose`, and `Quality`). The\n`BoundingBox` field only applies to the detected face instance. The other facial\nattributes listed in the `Face` object of the following response syntax are not\nreturned. For more information, see FaceDetail in the Amazon Rekognition\nDeveloper Guide.\n\nBy default, the `Celebrities` array is sorted by time (milliseconds from the\nstart of the video). You can also sort the array by celebrity by specifying the\nvalue `ID` in the `SortBy` input parameter.\n\nThe `CelebrityDetail` object includes the celebrity identifer and additional\ninformation urls. If you don't store the additional information urls, you can\nget them later by calling `GetCelebrityInfo` with the celebrity identifer.\n\nNo information is returned for faces not recognized as celebrities.\n\nUse MaxResults parameter to limit the number of labels returned. If there are\nmore results than specified in `MaxResults`, the value of `NextToken` in the\noperation response contains a pagination token for getting the next set of\nresults. To get the next page of results, call `GetCelebrityDetection` and\npopulate the `NextToken` request parameter with the token value returned from\nthe previous call to `GetCelebrityRecognition`.","ref":"AWS.Rekognition.html#get_celebrity_recognition/3","title":"AWS.Rekognition.get_celebrity_recognition/3","type":"function"},{"doc":"Gets the inappropriate, unwanted, or offensive content analysis results for a\nAmazon Rekognition Video analysis started by `StartContentModeration`.\n\nFor a list of moderation labels in Amazon Rekognition, see [Using the image and video moderation\nAPIs](https://docs.aws.amazon.com/rekognition/latest/dg/moderation.html#moderation-api).\n\nAmazon Rekognition Video inappropriate or offensive content detection in a\nstored video is an asynchronous operation. You start analysis by calling\n`StartContentModeration` which returns a job identifier (`JobId`). When analysis\nfinishes, Amazon Rekognition Video publishes a completion status to the Amazon\nSimple Notification Service topic registered in the initial call to\n`StartContentModeration`. To get the results of the content analysis, first\ncheck that the status value published to the Amazon SNS topic is `SUCCEEDED`. If\nso, call `GetContentModeration` and pass the job identifier (`JobId`) from the\ninitial call to `StartContentModeration`.\n\nFor more information, see Working with Stored Videos in the Amazon Rekognition\nDevlopers Guide.\n\n`GetContentModeration` returns detected inappropriate, unwanted, or offensive\ncontent moderation labels, and the time they are detected, in an array,\n`ModerationLabels`, of `ContentModerationDetection` objects.\n\nBy default, the moderated labels are returned sorted by time, in milliseconds\nfrom the start of the video. You can also sort them by moderated label by\nspecifying `NAME` for the `SortBy` input parameter.\n\nSince video analysis can return a large number of results, use the `MaxResults`\nparameter to limit the number of labels returned in a single call to\n`GetContentModeration`. If there are more results than specified in\n`MaxResults`, the value of `NextToken` in the operation response contains a\npagination token for getting the next set of results. To get the next page of\nresults, call `GetContentModeration` and populate the `NextToken` request\nparameter with the value of `NextToken` returned from the previous call to\n`GetContentModeration`.\n\nFor more information, see moderating content in the Amazon Rekognition Developer\nGuide.","ref":"AWS.Rekognition.html#get_content_moderation/3","title":"AWS.Rekognition.get_content_moderation/3","type":"function"},{"doc":"Gets face detection results for a Amazon Rekognition Video analysis started by\n`StartFaceDetection`.\n\nFace detection with Amazon Rekognition Video is an asynchronous operation. You\nstart face detection by calling `StartFaceDetection` which returns a job\nidentifier (`JobId`). When the face detection operation finishes, Amazon\nRekognition Video publishes a completion status to the Amazon Simple\nNotification Service topic registered in the initial call to\n`StartFaceDetection`. To get the results of the face detection operation, first\ncheck that the status value published to the Amazon SNS topic is `SUCCEEDED`. If\nso, call `GetFaceDetection` and pass the job identifier (`JobId`) from the\ninitial call to `StartFaceDetection`.\n\n`GetFaceDetection` returns an array of detected faces (`Faces`) sorted by the\ntime the faces were detected.\n\nUse MaxResults parameter to limit the number of labels returned. If there are\nmore results than specified in `MaxResults`, the value of `NextToken` in the\noperation response contains a pagination token for getting the next set of\nresults. To get the next page of results, call `GetFaceDetection` and populate\nthe `NextToken` request parameter with the token value returned from the\nprevious call to `GetFaceDetection`.\n\nNote that for the `GetFaceDetection` operation, the returned values for\n`FaceOccluded` and `EyeDirection` will always be \"null\".","ref":"AWS.Rekognition.html#get_face_detection/3","title":"AWS.Rekognition.get_face_detection/3","type":"function"},{"doc":"Retrieves the results of a specific Face Liveness session.\n\nIt requires the `sessionId` as input, which was created using\n`CreateFaceLivenessSession`. Returns the corresponding Face Liveness confidence\nscore, a reference image that includes a face bounding box, and audit images\nthat also contain face bounding boxes. The Face Liveness confidence score ranges\nfrom 0 to 100.\n\nThe number of audit images returned by `GetFaceLivenessSessionResults` is\ndefined by the `AuditImagesLimit` paramater when calling\n`CreateFaceLivenessSession`. Reference images are always returned when possible.","ref":"AWS.Rekognition.html#get_face_liveness_session_results/3","title":"AWS.Rekognition.get_face_liveness_session_results/3","type":"function"},{"doc":"Gets the face search results for Amazon Rekognition Video face search started by\n`StartFaceSearch`.\n\nThe search returns faces in a collection that match the faces of persons\ndetected in a video. It also includes the time(s) that faces are matched in the\nvideo.\n\nFace search in a video is an asynchronous operation. You start face search by\ncalling to `StartFaceSearch` which returns a job identifier (`JobId`). When the\nsearch operation finishes, Amazon Rekognition Video publishes a completion\nstatus to the Amazon Simple Notification Service topic registered in the initial\ncall to `StartFaceSearch`. To get the search results, first check that the\nstatus value published to the Amazon SNS topic is `SUCCEEDED`. If so, call\n`GetFaceSearch` and pass the job identifier (`JobId`) from the initial call to\n`StartFaceSearch`.\n\nFor more information, see Searching Faces in a Collection in the Amazon\nRekognition Developer Guide.\n\nThe search results are retured in an array, `Persons`, of `PersonMatch` objects.\nEach`PersonMatch` element contains details about the matching faces in the input\ncollection, person information (facial attributes, bounding boxes, and person\nidentifer) for the matched person, and the time the person was matched in the\nvideo.\n\n`GetFaceSearch` only returns the default facial attributes (`BoundingBox`,\n`Confidence`, `Landmarks`, `Pose`, and `Quality`). The other facial attributes\nlisted in the `Face` object of the following response syntax are not returned.\nFor more information, see FaceDetail in the Amazon Rekognition Developer Guide.\n\nBy default, the `Persons` array is sorted by the time, in milliseconds from the\nstart of the video, persons are matched. You can also sort by persons by\nspecifying `INDEX` for the `SORTBY` input parameter.","ref":"AWS.Rekognition.html#get_face_search/3","title":"AWS.Rekognition.get_face_search/3","type":"function"},{"doc":"Gets the label detection results of a Amazon Rekognition Video analysis started\nby `StartLabelDetection`.\n\nThe label detection operation is started by a call to `StartLabelDetection`\nwhich returns a job identifier (`JobId`). When the label detection operation\nfinishes, Amazon Rekognition publishes a completion status to the Amazon Simple\nNotification Service topic registered in the initial call to\n`StartlabelDetection`.\n\nTo get the results of the label detection operation, first check that the status\nvalue published to the Amazon SNS topic is `SUCCEEDED`. If so, call\n`GetLabelDetection` and pass the job identifier (`JobId`) from the initial call\nto `StartLabelDetection`.\n\n`GetLabelDetection` returns an array of detected labels (`Labels`) sorted by the\ntime the labels were detected. You can also sort by the label name by specifying\n`NAME` for the `SortBy` input parameter. If there is no `NAME` specified, the\ndefault sort is by timestamp.\n\nYou can select how results are aggregated by using the `AggregateBy` input\nparameter. The default aggregation method is `TIMESTAMPS`. You can also\naggregate by `SEGMENTS`, which aggregates all instances of labels detected in a\ngiven segment.\n\nThe returned Labels array may include the following attributes:\n\n  * Name - The name of the detected label.\n\n  * Confidence - The level of confidence in the label assigned to a\ndetected object.\n\n  * Parents - The ancestor labels for a detected label.\nGetLabelDetection returns a hierarchical taxonomy of detected labels. For\nexample, a detected car might be assigned the label car. The label car has two\nparent labels: Vehicle (its parent) and Transportation (its grandparent). The\nresponse includes the all ancestors for a label, where every ancestor is a\nunique label. In the previous example, Car, Vehicle, and Transportation are\nreturned as unique labels in the response.\n\n  * Aliases - Possible Aliases for the label.\n\n  * Categories - The label categories that the detected label belongs\nto.\n\n  * BoundingBox — Bounding boxes are described for all instances of\ndetected common object labels, returned in an array of Instance objects. An\nInstance object contains a BoundingBox object, describing the location of the\nlabel on the input image. It also includes the confidence for the accuracy of\nthe detected bounding box.\n\n  * Timestamp - Time, in milliseconds from the start of the video,\nthat the label was detected. For aggregation by `SEGMENTS`, the\n`StartTimestampMillis`, `EndTimestampMillis`, and `DurationMillis` structures\nare what define a segment. Although the “Timestamp” structure is still returned\nwith each label, its value is set to be the same as `StartTimestampMillis`.\n\nTimestamp and Bounding box information are returned for detected Instances, only\nif aggregation is done by `TIMESTAMPS`. If aggregating by `SEGMENTS`,\ninformation about detected instances isn’t returned.\n\nThe version of the label model used for the detection is also returned.","ref":"AWS.Rekognition.html#get_label_detection/3","title":"AWS.Rekognition.get_label_detection/3","type":"function"},{"doc":"part of the response in the sample seen below.\n\nUse `MaxResults` parameter to limit the number of labels returned. If there are\nmore results than specified in `MaxResults`, the value of `NextToken` in the\noperation response contains a pagination token for getting the next set of\nresults. To get the next page of results, call `GetlabelDetection` and populate\nthe `NextToken` request parameter with the token value returned from the\nprevious call to `GetLabelDetection`.","ref":"AWS.Rekognition.html#get_label_detection/3-note-dominantcolors-isn-t-returned-for-instances-although-it-is-shown-as","title":"Note `DominantColors` isn't returned for `Instances`, although it is shown as - AWS.Rekognition.get_label_detection/3","type":"function"},{"doc":"Retrieves the results for a given media analysis job.\n\nTakes a `JobId` returned by StartMediaAnalysisJob.","ref":"AWS.Rekognition.html#get_media_analysis_job/3","title":"AWS.Rekognition.get_media_analysis_job/3","type":"function"},{"doc":"Gets the path tracking results of a Amazon Rekognition Video analysis started by\n`StartPersonTracking`.\n\nThe person path tracking operation is started by a call to `StartPersonTracking`\nwhich returns a job identifier (`JobId`). When the operation finishes, Amazon\nRekognition Video publishes a completion status to the Amazon Simple\nNotification Service topic registered in the initial call to\n`StartPersonTracking`.\n\nTo get the results of the person path tracking operation, first check that the\nstatus value published to the Amazon SNS topic is `SUCCEEDED`. If so, call\n`GetPersonTracking` and pass the job identifier (`JobId`) from the initial call\nto `StartPersonTracking`.\n\n`GetPersonTracking` returns an array, `Persons`, of tracked persons and the\ntime(s) their paths were tracked in the video.\n\n`GetPersonTracking` only returns the default facial attributes (`BoundingBox`,\n`Confidence`, `Landmarks`, `Pose`, and `Quality`). The other facial attributes\nlisted in the `Face` object of the following response syntax are not returned.\n\nFor more information, see FaceDetail in the Amazon Rekognition Developer Guide.\n\nBy default, the array is sorted by the time(s) a person's path is tracked in the\nvideo. You can sort by tracked persons by specifying `INDEX` for the `SortBy`\ninput parameter.\n\nUse the `MaxResults` parameter to limit the number of items returned. If there\nare more results than specified in `MaxResults`, the value of `NextToken` in the\noperation response contains a pagination token for getting the next set of\nresults. To get the next page of results, call `GetPersonTracking` and populate\nthe `NextToken` request parameter with the token value returned from the\nprevious call to `GetPersonTracking`.","ref":"AWS.Rekognition.html#get_person_tracking/3","title":"AWS.Rekognition.get_person_tracking/3","type":"function"},{"doc":"Gets the segment detection results of a Amazon Rekognition Video analysis\nstarted by `StartSegmentDetection`.\n\nSegment detection with Amazon Rekognition Video is an asynchronous operation.\nYou start segment detection by calling `StartSegmentDetection` which returns a\njob identifier (`JobId`). When the segment detection operation finishes, Amazon\nRekognition publishes a completion status to the Amazon Simple Notification\nService topic registered in the initial call to `StartSegmentDetection`. To get\nthe results of the segment detection operation, first check that the status\nvalue published to the Amazon SNS topic is `SUCCEEDED`. if so, call\n`GetSegmentDetection` and pass the job identifier (`JobId`) from the initial\ncall of `StartSegmentDetection`.\n\n`GetSegmentDetection` returns detected segments in an array (`Segments`) of\n`SegmentDetection` objects. `Segments` is sorted by the segment types specified\nin the `SegmentTypes` input parameter of `StartSegmentDetection`. Each element\nof the array includes the detected segment, the precentage confidence in the\nacuracy of the detected segment, the type of the segment, and the frame in which\nthe segment was detected.\n\nUse `SelectedSegmentTypes` to find out the type of segment detection requested\nin the call to `StartSegmentDetection`.\n\nUse the `MaxResults` parameter to limit the number of segment detections\nreturned. If there are more results than specified in `MaxResults`, the value of\n`NextToken` in the operation response contains a pagination token for getting\nthe next set of results. To get the next page of results, call\n`GetSegmentDetection` and populate the `NextToken` request parameter with the\ntoken value returned from the previous call to `GetSegmentDetection`.\n\nFor more information, see Detecting video segments in stored video in the Amazon\nRekognition Developer Guide.","ref":"AWS.Rekognition.html#get_segment_detection/3","title":"AWS.Rekognition.get_segment_detection/3","type":"function"},{"doc":"Gets the text detection results of a Amazon Rekognition Video analysis started\nby `StartTextDetection`.\n\nText detection with Amazon Rekognition Video is an asynchronous operation. You\nstart text detection by calling `StartTextDetection` which returns a job\nidentifier (`JobId`) When the text detection operation finishes, Amazon\nRekognition publishes a completion status to the Amazon Simple Notification\nService topic registered in the initial call to `StartTextDetection`. To get the\nresults of the text detection operation, first check that the status value\npublished to the Amazon SNS topic is `SUCCEEDED`. if so, call `GetTextDetection`\nand pass the job identifier (`JobId`) from the initial call of\n`StartLabelDetection`.\n\n`GetTextDetection` returns an array of detected text (`TextDetections`) sorted\nby the time the text was detected, up to 100 words per frame of video.\n\nEach element of the array includes the detected text, the precentage confidence\nin the acuracy of the detected text, the time the text was detected, bounding\nbox information for where the text was located, and unique identifiers for words\nand their lines.\n\nUse MaxResults parameter to limit the number of text detections returned. If\nthere are more results than specified in `MaxResults`, the value of `NextToken`\nin the operation response contains a pagination token for getting the next set\nof results. To get the next page of results, call `GetTextDetection` and\npopulate the `NextToken` request parameter with the token value returned from\nthe previous call to `GetTextDetection`.","ref":"AWS.Rekognition.html#get_text_detection/3","title":"AWS.Rekognition.get_text_detection/3","type":"function"},{"doc":"Detects faces in the input image and adds them to the specified collection.\n\nAmazon Rekognition doesn't save the actual faces that are detected. Instead, the\nunderlying detection algorithm first detects the faces in the input image. For\neach face, the algorithm extracts facial features into a feature vector, and\nstores it in the backend database. Amazon Rekognition uses feature vectors when\nit performs face match and search operations using the `SearchFaces` and\n`SearchFacesByImage` operations.\n\nFor more information, see Adding faces to a collection in the Amazon Rekognition\nDeveloper Guide.\n\nTo get the number of faces in a collection, call `DescribeCollection`.\n\nIf you're using version 1.0 of the face detection model, `IndexFaces` indexes\nthe 15 largest faces in the input image. Later versions of the face detection\nmodel index the 100 largest faces in the input image.\n\nIf you're using version 4 or later of the face model, image orientation\ninformation is not returned in the `OrientationCorrection` field.\n\nTo determine which version of the model you're using, call `DescribeCollection`\nand supply the collection ID. You can also get the model version from the value\nof `FaceModelVersion` in the response from `IndexFaces`\n\nFor more information, see Model Versioning in the Amazon Rekognition Developer\nGuide.\n\nIf you provide the optional `ExternalImageId` for the input image you provided,\nAmazon Rekognition associates this ID with all faces that it detects. When you\ncall the `ListFaces` operation, the response returns the external ID. You can\nuse this external image ID to create a client-side index to associate the faces\nwith each image. You can then use the index to find all faces in an image.\n\nYou can specify the maximum number of faces to index with the `MaxFaces` input\nparameter. This is useful when you want to index the largest faces in an image\nand don't want to index smaller faces, such as those belonging to people\nstanding in the background.\n\nThe `QualityFilter` input parameter allows you to filter out detected faces that\ndon’t meet a required quality bar. The quality bar is based on a variety of\ncommon use cases. By default, `IndexFaces` chooses the quality bar that's used\nto filter faces. You can also explicitly choose the quality bar. Use\n`QualityFilter`, to set the quality bar by specifying `LOW`, `MEDIUM`, or\n`HIGH`. If you do not want to filter detected faces, specify `NONE`.\n\nTo use quality filtering, you need a collection associated with version 3 of the\nface model or higher. To get the version of the face model associated with a\ncollection, call `DescribeCollection`.\n\nInformation about faces detected in an image, but not indexed, is returned in an\narray of `UnindexedFace` objects, `UnindexedFaces`. Faces aren't indexed for\nreasons such as:\n\n  * The number of faces detected exceeds the value of the `MaxFaces`\nrequest parameter.\n\n  * The face is too small compared to the image dimensions.\n\n  * The face is too blurry.\n\n  * The image is too dark.\n\n  * The face has an extreme pose.\n\n  * The face doesn’t have enough detail to be suitable for face\nsearch.\n\nIn response, the `IndexFaces` operation returns an array of metadata for all\ndetected faces, `FaceRecords`. This includes:\n\n  * The bounding box, `BoundingBox`, of the detected face.\n\n  * A confidence value, `Confidence`, which indicates the confidence\nthat the bounding box contains a face.\n\n  * A face ID, `FaceId`, assigned by the service for each face that's\ndetected and stored.\n\n  * An image ID, `ImageId`, assigned by the service for the input\nimage.\n\nIf you request `ALL` or specific facial attributes (e.g., `FACE_OCCLUDED`) by\nusing the detectionAttributes parameter, Amazon Rekognition returns detailed\nfacial attributes, such as facial landmarks (for example, location of eye and\nmouth), facial occlusion, and other facial attributes.\n\nIf you provide the same image, specify the same collection, and use the same\nexternal ID in the `IndexFaces` operation, Amazon Rekognition doesn't save\nduplicate face metadata.\n\nThe input image is passed either as base64-encoded image bytes, or as a\nreference to an image in an Amazon S3 bucket. If you use the AWS CLI to call\nAmazon Rekognition operations, passing image bytes isn't supported. The image\nmust be formatted as a PNG or JPEG file.\n\nThis operation requires permissions to perform the `rekognition:IndexFaces`\naction.","ref":"AWS.Rekognition.html#index_faces/3","title":"AWS.Rekognition.index_faces/3","type":"function"},{"doc":"Returns list of collection IDs in your account.\n\nIf the result is truncated, the response also provides a `NextToken` that you\ncan use in the subsequent request to fetch the next set of collection IDs.\n\nFor an example, see Listing collections in the Amazon Rekognition Developer\nGuide.\n\nThis operation requires permissions to perform the `rekognition:ListCollections`\naction.","ref":"AWS.Rekognition.html#list_collections/3","title":"AWS.Rekognition.list_collections/3","type":"function"},{"doc":"This operation applies only to Amazon Rekognition Custom Labels.\n\nLists the entries (images) within a dataset. An entry is a JSON Line that\ncontains the information for a single image, including the image location,\nassigned labels, and object location bounding boxes. For more information, see\n[Creating a manifest file](https://docs.aws.amazon.com/rekognition/latest/customlabels-dg/md-manifest-files.html).\n\nJSON Lines in the response include information about non-terminal errors found\nin the dataset. Non terminal errors are reported in `errors` lists within each\nJSON Line. The same information is reported in the training and testing\nvalidation result manifests that Amazon Rekognition Custom Labels creates during\nmodel training.\n\nYou can filter the response in variety of ways, such as choosing which labels to\nreturn and returning JSON Lines created after a specific date.\n\nThis operation requires permissions to perform the\n`rekognition:ListDatasetEntries` action.","ref":"AWS.Rekognition.html#list_dataset_entries/3","title":"AWS.Rekognition.list_dataset_entries/3","type":"function"},{"doc":"This operation applies only to Amazon Rekognition Custom Labels.\n\nLists the labels in a dataset. Amazon Rekognition Custom Labels uses labels to\ndescribe images. For more information, see [Labeling images](https://docs.aws.amazon.com/rekognition/latest/customlabels-dg/md-labeling-images.html).\n\nLists the labels in a dataset. Amazon Rekognition Custom Labels uses labels to\ndescribe images. For more information, see Labeling images in the *Amazon\nRekognition Custom Labels Developer Guide*.","ref":"AWS.Rekognition.html#list_dataset_labels/3","title":"AWS.Rekognition.list_dataset_labels/3","type":"function"},{"doc":"Returns metadata for faces in the specified collection.\n\nThis metadata includes information such as the bounding box coordinates, the\nconfidence (that the bounding box contains a face), and face ID. For an example,\nsee Listing Faces in a Collection in the Amazon Rekognition Developer Guide.\n\nThis operation requires permissions to perform the `rekognition:ListFaces`\naction.","ref":"AWS.Rekognition.html#list_faces/3","title":"AWS.Rekognition.list_faces/3","type":"function"},{"doc":"Returns a list of media analysis jobs.\n\nResults are sorted by `CreationTimestamp` in descending order.","ref":"AWS.Rekognition.html#list_media_analysis_jobs/3","title":"AWS.Rekognition.list_media_analysis_jobs/3","type":"function"},{"doc":"This operation applies only to Amazon Rekognition Custom Labels.\n\nGets a list of the project policies attached to a project.\n\nTo attach a project policy to a project, call `PutProjectPolicy`. To remove a\nproject policy from a project, call `DeleteProjectPolicy`.\n\nThis operation requires permissions to perform the\n`rekognition:ListProjectPolicies` action.","ref":"AWS.Rekognition.html#list_project_policies/3","title":"AWS.Rekognition.list_project_policies/3","type":"function"},{"doc":"Gets a list of stream processors that you have created with\n`CreateStreamProcessor`.","ref":"AWS.Rekognition.html#list_stream_processors/3","title":"AWS.Rekognition.list_stream_processors/3","type":"function"},{"doc":"Returns a list of tags in an Amazon Rekognition collection, stream processor, or\nCustom Labels model.\n\nThis operation requires permissions to perform the\n`rekognition:ListTagsForResource` action.","ref":"AWS.Rekognition.html#list_tags_for_resource/3","title":"AWS.Rekognition.list_tags_for_resource/3","type":"function"},{"doc":"Returns metadata of the User such as `UserID` in the specified collection.\n\nAnonymous User (to reserve faces without any identity) is not returned as part\nof this request. The results are sorted by system generated primary key ID. If\nthe response is truncated, `NextToken` is returned in the response that can be\nused in the subsequent request to retrieve the next set of identities.","ref":"AWS.Rekognition.html#list_users/3","title":"AWS.Rekognition.list_users/3","type":"function"},{"doc":"","ref":"AWS.Rekognition.html#metadata/0","title":"AWS.Rekognition.metadata/0","type":"function"},{"doc":"This operation applies only to Amazon Rekognition Custom Labels.\n\nAttaches a project policy to a Amazon Rekognition Custom Labels project in a\ntrusting AWS account. A project policy specifies that a trusted AWS account can\ncopy a model version from a trusting AWS account to a project in the trusted AWS\naccount. To copy a model version you use the `CopyProjectVersion` operation.\nOnly applies to Custom Labels projects.\n\nFor more information about the format of a project policy document, see\nAttaching a project policy (SDK) in the *Amazon Rekognition Custom Labels\nDeveloper Guide*.\n\nThe response from `PutProjectPolicy` is a revision ID for the project policy.\nYou can attach multiple project policies to a project. You can also update an\nexisting project policy by specifying the policy revision ID of the existing\npolicy.\n\nTo remove a project policy from a project, call `DeleteProjectPolicy`. To get a\nlist of project policies attached to a project, call `ListProjectPolicies`.\n\nYou copy a model version by calling `CopyProjectVersion`.\n\nThis operation requires permissions to perform the\n`rekognition:PutProjectPolicy` action.","ref":"AWS.Rekognition.html#put_project_policy/3","title":"AWS.Rekognition.put_project_policy/3","type":"function"},{"doc":"Returns an array of celebrities recognized in the input image.\n\nFor more information, see Recognizing celebrities in the Amazon Rekognition\nDeveloper Guide.\n\n`RecognizeCelebrities` returns the 64 largest faces in the image. It lists the\nrecognized celebrities in the `CelebrityFaces` array and any unrecognized faces\nin the `UnrecognizedFaces` array. `RecognizeCelebrities` doesn't return\ncelebrities whose faces aren't among the largest 64 faces in the image.\n\nFor each celebrity recognized, `RecognizeCelebrities` returns a `Celebrity`\nobject. The `Celebrity` object contains the celebrity name, ID, URL links to\nadditional information, match confidence, and a `ComparedFace` object that you\ncan use to locate the celebrity's face on the image.\n\nAmazon Rekognition doesn't retain information about which images a celebrity has\nbeen recognized in. Your application must store this information and use the\n`Celebrity` ID property as a unique identifier for the celebrity. If you don't\nstore the celebrity name or additional information URLs returned by\n`RecognizeCelebrities`, you will need the ID to identify the celebrity in a call\nto the `GetCelebrityInfo` operation.\n\nYou pass the input image either as base64-encoded image bytes or as a reference\nto an image in an Amazon S3 bucket. If you use the AWS CLI to call Amazon\nRekognition operations, passing image bytes is not supported. The image must be\neither a PNG or JPEG formatted file.\n\nFor an example, see Recognizing celebrities in an image in the Amazon\nRekognition Developer Guide.\n\nThis operation requires permissions to perform the\n`rekognition:RecognizeCelebrities` operation.","ref":"AWS.Rekognition.html#recognize_celebrities/3","title":"AWS.Rekognition.recognize_celebrities/3","type":"function"},{"doc":"For a given input face ID, searches for matching faces in the collection the\nface belongs to.\n\nYou get a face ID when you add a face to the collection using the `IndexFaces`\noperation. The operation compares the features of the input face with faces in\nthe specified collection.\n\nYou can also search faces without indexing faces by using the\n`SearchFacesByImage` operation.\n\nThe operation response returns an array of faces that match, ordered by\nsimilarity score with the highest similarity first. More specifically, it is an\narray of metadata for each face match that is found. Along with the metadata,\nthe response also includes a `confidence` value for each face match, indicating\nthe confidence that the specific face matches the input face.\n\nFor an example, see Searching for a face using its face ID in the Amazon\nRekognition Developer Guide.\n\nThis operation requires permissions to perform the `rekognition:SearchFaces`\naction.","ref":"AWS.Rekognition.html#search_faces/3","title":"AWS.Rekognition.search_faces/3","type":"function"},{"doc":"For a given input image, first detects the largest face in the image, and then\nsearches the specified collection for matching faces.\n\nThe operation compares the features of the input face with faces in the\nspecified collection.\n\nTo search for all faces in an input image, you might first call the `IndexFaces`\noperation, and then use the face IDs returned in subsequent calls to the\n`SearchFaces` operation.\n\nYou can also call the `DetectFaces` operation and use the bounding boxes in the\nresponse to make face crops, which then you can pass in to the\n`SearchFacesByImage` operation.\n\nYou pass the input image either as base64-encoded image bytes or as a reference\nto an image in an Amazon S3 bucket. If you use the AWS CLI to call Amazon\nRekognition operations, passing image bytes is not supported. The image must be\neither a PNG or JPEG formatted file.\n\nThe response returns an array of faces that match, ordered by similarity score\nwith the highest similarity first. More specifically, it is an array of metadata\nfor each face match found. Along with the metadata, the response also includes a\n`similarity` indicating how similar the face is to the input face. In the\nresponse, the operation also returns the bounding box (and a confidence level\nthat the bounding box contains a face) of the face that Amazon Rekognition used\nfor the input image.\n\nIf no faces are detected in the input image, `SearchFacesByImage` returns an\n`InvalidParameterException` error.\n\nFor an example, Searching for a Face Using an Image in the Amazon Rekognition\nDeveloper Guide.\n\nThe `QualityFilter` input parameter allows you to filter out detected faces that\ndon’t meet a required quality bar. The quality bar is based on a variety of\ncommon use cases. Use `QualityFilter` to set the quality bar for filtering by\nspecifying `LOW`, `MEDIUM`, or `HIGH`. If you do not want to filter detected\nfaces, specify `NONE`. The default value is `NONE`.\n\nTo use quality filtering, you need a collection associated with version 3 of the\nface model or higher. To get the version of the face model associated with a\ncollection, call `DescribeCollection`.\n\nThis operation requires permissions to perform the\n`rekognition:SearchFacesByImage` action.","ref":"AWS.Rekognition.html#search_faces_by_image/3","title":"AWS.Rekognition.search_faces_by_image/3","type":"function"},{"doc":"Searches for UserIDs within a collection based on a `FaceId` or `UserId`.\n\nThis API can be used to find the closest UserID (with a highest similarity) to\nassociate a face. The request must be provided with either `FaceId` or `UserId`.\nThe operation returns an array of UserID that match the `FaceId` or `UserId`,\nordered by similarity score with the highest similarity first.","ref":"AWS.Rekognition.html#search_users/3","title":"AWS.Rekognition.search_users/3","type":"function"},{"doc":"Searches for UserIDs using a supplied image.\n\nIt first detects the largest face in the image, and then searches a specified\ncollection for matching UserIDs.\n\nThe operation returns an array of UserIDs that match the face in the supplied\nimage, ordered by similarity score with the highest similarity first. It also\nreturns a bounding box for the face found in the input image.\n\nInformation about faces detected in the supplied image, but not used for the\nsearch, is returned in an array of `UnsearchedFace` objects. If no valid face is\ndetected in the image, the response will contain an empty `UserMatches` list and\nno `SearchedFace` object.","ref":"AWS.Rekognition.html#search_users_by_image/3","title":"AWS.Rekognition.search_users_by_image/3","type":"function"},{"doc":"Starts asynchronous recognition of celebrities in a stored video.\n\nAmazon Rekognition Video can detect celebrities in a video must be stored in an\nAmazon S3 bucket. Use `Video` to specify the bucket name and the filename of the\nvideo. `StartCelebrityRecognition` returns a job identifier (`JobId`) which you\nuse to get the results of the analysis. When celebrity recognition analysis is\nfinished, Amazon Rekognition Video publishes a completion status to the Amazon\nSimple Notification Service topic that you specify in `NotificationChannel`. To\nget the results of the celebrity recognition analysis, first check that the\nstatus value published to the Amazon SNS topic is `SUCCEEDED`. If so, call\n`GetCelebrityRecognition` and pass the job identifier (`JobId`) from the initial\ncall to `StartCelebrityRecognition`.\n\nFor more information, see Recognizing celebrities in the Amazon Rekognition\nDeveloper Guide.","ref":"AWS.Rekognition.html#start_celebrity_recognition/3","title":"AWS.Rekognition.start_celebrity_recognition/3","type":"function"},{"doc":"Starts asynchronous detection of inappropriate, unwanted, or offensive content\nin a stored video.\n\nFor a list of moderation labels in Amazon Rekognition, see [Using the image and video moderation\nAPIs](https://docs.aws.amazon.com/rekognition/latest/dg/moderation.html#moderation-api).\n\nAmazon Rekognition Video can moderate content in a video stored in an Amazon S3\nbucket. Use `Video` to specify the bucket name and the filename of the video.\n`StartContentModeration` returns a job identifier (`JobId`) which you use to get\nthe results of the analysis. When content analysis is finished, Amazon\nRekognition Video publishes a completion status to the Amazon Simple\nNotification Service topic that you specify in `NotificationChannel`.\n\nTo get the results of the content analysis, first check that the status value\npublished to the Amazon SNS topic is `SUCCEEDED`. If so, call\n`GetContentModeration` and pass the job identifier (`JobId`) from the initial\ncall to `StartContentModeration`.\n\nFor more information, see Moderating content in the Amazon Rekognition Developer\nGuide.","ref":"AWS.Rekognition.html#start_content_moderation/3","title":"AWS.Rekognition.start_content_moderation/3","type":"function"},{"doc":"Starts asynchronous detection of faces in a stored video.\n\nAmazon Rekognition Video can detect faces in a video stored in an Amazon S3\nbucket. Use `Video` to specify the bucket name and the filename of the video.\n`StartFaceDetection` returns a job identifier (`JobId`) that you use to get the\nresults of the operation. When face detection is finished, Amazon Rekognition\nVideo publishes a completion status to the Amazon Simple Notification Service\ntopic that you specify in `NotificationChannel`. To get the results of the face\ndetection operation, first check that the status value published to the Amazon\nSNS topic is `SUCCEEDED`. If so, call `GetFaceDetection` and pass the job\nidentifier (`JobId`) from the initial call to `StartFaceDetection`.\n\nFor more information, see Detecting faces in a stored video in the Amazon\nRekognition Developer Guide.","ref":"AWS.Rekognition.html#start_face_detection/3","title":"AWS.Rekognition.start_face_detection/3","type":"function"},{"doc":"Starts the asynchronous search for faces in a collection that match the faces of\npersons detected in a stored video.\n\nThe video must be stored in an Amazon S3 bucket. Use `Video` to specify the\nbucket name and the filename of the video. `StartFaceSearch` returns a job\nidentifier (`JobId`) which you use to get the search results once the search has\ncompleted. When searching is finished, Amazon Rekognition Video publishes a\ncompletion status to the Amazon Simple Notification Service topic that you\nspecify in `NotificationChannel`. To get the search results, first check that\nthe status value published to the Amazon SNS topic is `SUCCEEDED`. If so, call\n`GetFaceSearch` and pass the job identifier (`JobId`) from the initial call to\n`StartFaceSearch`. For more information, see [Searching stored videos for faces](https://docs.aws.amazon.com/rekognition/latest/dg/procedure-person-search-videos.html).","ref":"AWS.Rekognition.html#start_face_search/3","title":"AWS.Rekognition.start_face_search/3","type":"function"},{"doc":"Starts asynchronous detection of labels in a stored video.\n\nAmazon Rekognition Video can detect labels in a video. Labels are instances of\nreal-world entities. This includes objects like flower, tree, and table; events\nlike wedding, graduation, and birthday party; concepts like landscape, evening,\nand nature; and activities like a person getting out of a car or a person\nskiing.\n\nThe video must be stored in an Amazon S3 bucket. Use `Video` to specify the\nbucket name and the filename of the video. `StartLabelDetection` returns a job\nidentifier (`JobId`) which you use to get the results of the operation. When\nlabel detection is finished, Amazon Rekognition Video publishes a completion\nstatus to the Amazon Simple Notification Service topic that you specify in\n`NotificationChannel`.\n\nTo get the results of the label detection operation, first check that the status\nvalue published to the Amazon SNS topic is `SUCCEEDED`. If so, call\n`GetLabelDetection` and pass the job identifier (`JobId`) from the initial call\nto `StartLabelDetection`.\n\n*Optional Parameters*\n\n`StartLabelDetection` has the `GENERAL_LABELS` Feature applied by default. This\nfeature allows you to provide filtering criteria to the `Settings` parameter.\nYou can filter with sets of individual labels or with label categories. You can\nspecify inclusive filters, exclusive filters, or a combination of inclusive and\nexclusive filters. For more information on filtering, see [Detecting labels in a video](https://docs.aws.amazon.com/rekognition/latest/dg/labels-detecting-labels-video.html).\n\nYou can specify `MinConfidence` to control the confidence threshold for the\nlabels returned. The default is 50.","ref":"AWS.Rekognition.html#start_label_detection/3","title":"AWS.Rekognition.start_label_detection/3","type":"function"},{"doc":"Initiates a new media analysis job.\n\nAccepts a manifest file in an Amazon S3 bucket. The output is a manifest file\nand a summary of the manifest stored in the Amazon S3 bucket.","ref":"AWS.Rekognition.html#start_media_analysis_job/3","title":"AWS.Rekognition.start_media_analysis_job/3","type":"function"},{"doc":"Starts the asynchronous tracking of a person's path in a stored video.\n\nAmazon Rekognition Video can track the path of people in a video stored in an\nAmazon S3 bucket. Use `Video` to specify the bucket name and the filename of the\nvideo. `StartPersonTracking` returns a job identifier (`JobId`) which you use to\nget the results of the operation. When label detection is finished, Amazon\nRekognition publishes a completion status to the Amazon Simple Notification\nService topic that you specify in `NotificationChannel`.\n\nTo get the results of the person detection operation, first check that the\nstatus value published to the Amazon SNS topic is `SUCCEEDED`. If so, call\n`GetPersonTracking` and pass the job identifier (`JobId`) from the initial call\nto `StartPersonTracking`.","ref":"AWS.Rekognition.html#start_person_tracking/3","title":"AWS.Rekognition.start_person_tracking/3","type":"function"},{"doc":"This operation applies only to Amazon Rekognition Custom Labels.\n\nStarts the running of the version of a model. Starting a model takes a while to\ncomplete. To check the current state of the model, use\n`DescribeProjectVersions`.\n\nOnce the model is running, you can detect custom labels in new images by calling\n`DetectCustomLabels`.\n\nYou are charged for the amount of time that the model is running. To stop a\nrunning model, call `StopProjectVersion`.\n\nThis operation requires permissions to perform the\n`rekognition:StartProjectVersion` action.","ref":"AWS.Rekognition.html#start_project_version/3","title":"AWS.Rekognition.start_project_version/3","type":"function"},{"doc":"Starts asynchronous detection of segment detection in a stored video.\n\nAmazon Rekognition Video can detect segments in a video stored in an Amazon S3\nbucket. Use `Video` to specify the bucket name and the filename of the video.\n`StartSegmentDetection` returns a job identifier (`JobId`) which you use to get\nthe results of the operation. When segment detection is finished, Amazon\nRekognition Video publishes a completion status to the Amazon Simple\nNotification Service topic that you specify in `NotificationChannel`.\n\nYou can use the `Filters` (`StartSegmentDetectionFilters`) input parameter to\nspecify the minimum detection confidence returned in the response. Within\n`Filters`, use `ShotFilter` (`StartShotDetectionFilter`) to filter detected\nshots. Use `TechnicalCueFilter` (`StartTechnicalCueDetectionFilter`) to filter\ntechnical cues.\n\nTo get the results of the segment detection operation, first check that the\nstatus value published to the Amazon SNS topic is `SUCCEEDED`. if so, call\n`GetSegmentDetection` and pass the job identifier (`JobId`) from the initial\ncall to `StartSegmentDetection`.\n\nFor more information, see Detecting video segments in stored video in the Amazon\nRekognition Developer Guide.","ref":"AWS.Rekognition.html#start_segment_detection/3","title":"AWS.Rekognition.start_segment_detection/3","type":"function"},{"doc":"Starts processing a stream processor.\n\nYou create a stream processor by calling `CreateStreamProcessor`. To tell\n`StartStreamProcessor` which stream processor to start, use the value of the\n`Name` field specified in the call to `CreateStreamProcessor`.\n\nIf you are using a label detection stream processor to detect labels, you need\nto provide a `Start selector` and a `Stop selector` to determine the length of\nthe stream processing time.","ref":"AWS.Rekognition.html#start_stream_processor/3","title":"AWS.Rekognition.start_stream_processor/3","type":"function"},{"doc":"Starts asynchronous detection of text in a stored video.\n\nAmazon Rekognition Video can detect text in a video stored in an Amazon S3\nbucket. Use `Video` to specify the bucket name and the filename of the video.\n`StartTextDetection` returns a job identifier (`JobId`) which you use to get the\nresults of the operation. When text detection is finished, Amazon Rekognition\nVideo publishes a completion status to the Amazon Simple Notification Service\ntopic that you specify in `NotificationChannel`.\n\nTo get the results of the text detection operation, first check that the status\nvalue published to the Amazon SNS topic is `SUCCEEDED`. if so, call\n`GetTextDetection` and pass the job identifier (`JobId`) from the initial call\nto `StartTextDetection`.","ref":"AWS.Rekognition.html#start_text_detection/3","title":"AWS.Rekognition.start_text_detection/3","type":"function"},{"doc":"This operation applies only to Amazon Rekognition Custom Labels.\n\nStops a running model. The operation might take a while to complete. To check\nthe current status, call `DescribeProjectVersions`. Only applies to Custom\nLabels projects.\n\nThis operation requires permissions to perform the\n`rekognition:StopProjectVersion` action.","ref":"AWS.Rekognition.html#stop_project_version/3","title":"AWS.Rekognition.stop_project_version/3","type":"function"},{"doc":"Stops a running stream processor that was created by `CreateStreamProcessor`.","ref":"AWS.Rekognition.html#stop_stream_processor/3","title":"AWS.Rekognition.stop_stream_processor/3","type":"function"},{"doc":"Adds one or more key-value tags to an Amazon Rekognition collection, stream\nprocessor, or Custom Labels model.\n\nFor more information, see [Tagging AWS Resources](https://docs.aws.amazon.com/general/latest/gr/aws_tagging.html).\n\nThis operation requires permissions to perform the `rekognition:TagResource`\naction.","ref":"AWS.Rekognition.html#tag_resource/3","title":"AWS.Rekognition.tag_resource/3","type":"function"},{"doc":"Removes one or more tags from an Amazon Rekognition collection, stream\nprocessor, or Custom Labels model.\n\nThis operation requires permissions to perform the `rekognition:UntagResource`\naction.","ref":"AWS.Rekognition.html#untag_resource/3","title":"AWS.Rekognition.untag_resource/3","type":"function"},{"doc":"This operation applies only to Amazon Rekognition Custom Labels.\n\nAdds or updates one or more entries (images) in a dataset. An entry is a JSON\nLine which contains the information for a single image, including the image\nlocation, assigned labels, and object location bounding boxes. For more\ninformation, see Image-Level labels in manifest files and Object localization in\nmanifest files in the *Amazon Rekognition Custom Labels Developer Guide*.\n\nIf the `source-ref` field in the JSON line references an existing image, the\nexisting image in the dataset is updated. If `source-ref` field doesn't\nreference an existing image, the image is added as a new image to the dataset.\n\nYou specify the changes that you want to make in the `Changes` input parameter.\nThere isn't a limit to the number JSON Lines that you can change, but the size\nof `Changes` must be less than 5MB.\n\n`UpdateDatasetEntries` returns immediatly, but the dataset update might take a\nwhile to complete. Use `DescribeDataset` to check the current status. The\ndataset updated successfully if the value of `Status` is `UPDATE_COMPLETE`.\n\nTo check if any non-terminal errors occured, call `ListDatasetEntries` and check\nfor the presence of `errors` lists in the JSON Lines.\n\nDataset update fails if a terminal error occurs (`Status` = `UPDATE_FAILED`).\nCurrently, you can't access the terminal error information from the Amazon\nRekognition Custom Labels SDK.\n\nThis operation requires permissions to perform the\n`rekognition:UpdateDatasetEntries` action.","ref":"AWS.Rekognition.html#update_dataset_entries/3","title":"AWS.Rekognition.update_dataset_entries/3","type":"function"},{"doc":"Allows you to update a stream processor.\n\nYou can change some settings and regions of interest and delete certain\nparameters.","ref":"AWS.Rekognition.html#update_stream_processor/3","title":"AWS.Rekognition.update_stream_processor/3","type":"function"},{"doc":"AWS re:Post Private is a private version of AWS re:Post for enterprises with\nEnterprise Support or Enterprise On-Ramp Support plans.\n\nIt provides access to knowledge and experts to accelerate cloud adoption and\nincrease developer productivity. With your organization-specific private\nre:Post, you can build an organization-specific developer community that drives\nefficiencies at scale and provides access to valuable knowledge resources.\nAdditionally, re:Post Private centralizes trusted AWS technical content and\noffers private discussion forums to improve how your teams collaborate\ninternally and with AWS to remove technical obstacles, accelerate innovation,\nand scale more efficiently in the cloud.","ref":"AWS.Repostspace.html","title":"AWS.Repostspace","type":"module"},{"doc":"Creates an AWS re:Post Private private re:Post.","ref":"AWS.Repostspace.html#create_space/3","title":"AWS.Repostspace.create_space/3","type":"function"},{"doc":"Deletes an AWS re:Post Private private re:Post.","ref":"AWS.Repostspace.html#delete_space/4","title":"AWS.Repostspace.delete_space/4","type":"function"},{"doc":"Removes the user or group from the list of administrators of the private\nre:Post.","ref":"AWS.Repostspace.html#deregister_admin/5","title":"AWS.Repostspace.deregister_admin/5","type":"function"},{"doc":"Displays information about the AWS re:Post Private private re:Post.","ref":"AWS.Repostspace.html#get_space/3","title":"AWS.Repostspace.get_space/3","type":"function"},{"doc":"Returns a list of AWS re:Post Private private re:Posts in the account with some\ninformation about each private re:Post.","ref":"AWS.Repostspace.html#list_spaces/4","title":"AWS.Repostspace.list_spaces/4","type":"function"},{"doc":"Returns the tags that are associated with the AWS re:Post Private resource\nspecified by the resourceArn.\n\nThe only resource that can be tagged is a private re:Post.","ref":"AWS.Repostspace.html#list_tags_for_resource/3","title":"AWS.Repostspace.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.Repostspace.html#metadata/0","title":"AWS.Repostspace.metadata/0","type":"function"},{"doc":"Adds a user or group to the list of administrators of the private re:Post.","ref":"AWS.Repostspace.html#register_admin/5","title":"AWS.Repostspace.register_admin/5","type":"function"},{"doc":"Sends an invitation email to selected users and groups.","ref":"AWS.Repostspace.html#send_invites/4","title":"AWS.Repostspace.send_invites/4","type":"function"},{"doc":"Associates tags with an AWS re:Post Private resource.\n\nCurrently, the only resource that can be tagged is the private re:Post. If you\nspecify a new tag key for the resource, the tag is appended to the list of tags\nthat are associated with the resource. If you specify a tag key that’s already\nassociated with the resource, the new tag value that you specify replaces the\nprevious value for that tag.","ref":"AWS.Repostspace.html#tag_resource/4","title":"AWS.Repostspace.tag_resource/4","type":"function"},{"doc":"Removes the association of the tag with the AWS re:Post Private resource.","ref":"AWS.Repostspace.html#untag_resource/4","title":"AWS.Repostspace.untag_resource/4","type":"function"},{"doc":"Modifies an existing AWS re:Post Private private re:Post.","ref":"AWS.Repostspace.html#update_space/4","title":"AWS.Repostspace.update_space/4","type":"function"},{"doc":"Resilience Hub helps you proactively prepare and protect your Amazon Web\nServices applications from disruptions.\n\nIt offers continual resiliency assessment and validation that integrates into\nyour software development lifecycle. This enables you to uncover resiliency\nweaknesses, ensure recovery time objective (RTO) and recovery point objective\n(RPO) targets for your applications are met, and resolve issues before they are\nreleased into production.","ref":"AWS.Resiliencehub.html","title":"AWS.Resiliencehub","type":"module"},{"doc":"Adds the source of resource-maps to the draft version of an application.\n\nDuring assessment, Resilience Hub will use these resource-maps to resolve the\nlatest physical ID for each resource in the application template. For more\ninformation about different types of resources suported by Resilience Hub and\nhow to add them in your application, see [Step 2: How is your application managed?](https://docs.aws.amazon.com/resilience-hub/latest/userguide/how-app-manage.html)\nin the Resilience Hub User Guide.","ref":"AWS.Resiliencehub.html#add_draft_app_version_resource_mappings/3","title":"AWS.Resiliencehub.add_draft_app_version_resource_mappings/3","type":"function"},{"doc":"Enables you to include or exclude one or more operational recommendations.","ref":"AWS.Resiliencehub.html#batch_update_recommendation_status/3","title":"AWS.Resiliencehub.batch_update_recommendation_status/3","type":"function"},{"doc":"Creates an Resilience Hub application.\n\nAn Resilience Hub application is a collection of Amazon Web Services resources\nstructured to prevent and recover Amazon Web Services application disruptions.\nTo describe a Resilience Hub application, you provide an application name,\nresources from one or more CloudFormation stacks, Resource Groups, Terraform\nstate files, AppRegistry applications, and an appropriate resiliency policy. In\naddition, you can also add resources that are located on Amazon Elastic\nKubernetes Service (Amazon EKS) clusters as optional resources. For more\ninformation about the number of resources supported per application, see\n[Service quotas](https://docs.aws.amazon.com/general/latest/gr/resiliencehub.html#limits_resiliencehub).\n\nAfter you create an Resilience Hub application, you publish it so that you can\nrun a resiliency assessment on it. You can then use recommendations from the\nassessment to improve resiliency by running another assessment, comparing\nresults, and then iterating the process until you achieve your goals for\nrecovery time objective (RTO) and recovery point objective (RPO).","ref":"AWS.Resiliencehub.html#create_app/3","title":"AWS.Resiliencehub.create_app/3","type":"function"},{"doc":"Creates a new Application Component in the Resilience Hub application.\n\nThis API updates the Resilience Hub application draft version. To use this\nApplication Component for running assessments, you must publish the Resilience\nHub application using the `PublishAppVersion` API.","ref":"AWS.Resiliencehub.html#create_app_version_app_component/3","title":"AWS.Resiliencehub.create_app_version_app_component/3","type":"function"},{"doc":"Adds a resource to the Resilience Hub application and assigns it to the\nspecified Application Components.\n\nIf you specify a new Application Component, Resilience Hub will automatically\ncreate the Application Component.\n\n   This action has no effect outside Resilience Hub.\n\n   This API updates the Resilience Hub application draft version. To\nuse this resource for running resiliency assessments, you must publish the\nResilience Hub application using the `PublishAppVersion` API.\n\n   To update application version with new `physicalResourceID`, you\nmust call `ResolveAppVersionResources` API.","ref":"AWS.Resiliencehub.html#create_app_version_resource/3","title":"AWS.Resiliencehub.create_app_version_resource/3","type":"function"},{"doc":"Creates a new recommendation template for the Resilience Hub application.","ref":"AWS.Resiliencehub.html#create_recommendation_template/3","title":"AWS.Resiliencehub.create_recommendation_template/3","type":"function"},{"doc":"Creates a resiliency policy for an application.\n\nResilience Hub allows you to provide a value of zero for `rtoInSecs` and\n`rpoInSecs` of your resiliency policy. But, while assessing your application,\nthe lowest possible assessment result is near zero. Hence, if you provide value\nzero for `rtoInSecs` and `rpoInSecs`, the estimated workload RTO and estimated\nworkload RPO result will be near zero and the **Compliance status** for your\napplication will be set to **Policy breached**.","ref":"AWS.Resiliencehub.html#create_resiliency_policy/3","title":"AWS.Resiliencehub.create_resiliency_policy/3","type":"function"},{"doc":"Deletes an Resilience Hub application.\n\nThis is a destructive action that can't be undone.","ref":"AWS.Resiliencehub.html#delete_app/3","title":"AWS.Resiliencehub.delete_app/3","type":"function"},{"doc":"Deletes an Resilience Hub application assessment.\n\nThis is a destructive action that can't be undone.","ref":"AWS.Resiliencehub.html#delete_app_assessment/3","title":"AWS.Resiliencehub.delete_app_assessment/3","type":"function"},{"doc":"Deletes the input source and all of its imported resources from the Resilience\nHub application.","ref":"AWS.Resiliencehub.html#delete_app_input_source/3","title":"AWS.Resiliencehub.delete_app_input_source/3","type":"function"},{"doc":"Deletes an Application Component from the Resilience Hub application.\n\n   This API updates the Resilience Hub application draft version. To\nuse this Application Component for running assessments, you must publish the\nResilience Hub application using the `PublishAppVersion` API.\n\n   You will not be able to delete an Application Component if it has\nresources associated with it.","ref":"AWS.Resiliencehub.html#delete_app_version_app_component/3","title":"AWS.Resiliencehub.delete_app_version_app_component/3","type":"function"},{"doc":"Deletes a resource from the Resilience Hub application.\n\n   You can only delete a manually added resource. To exclude\nnon-manually added resources, use the `UpdateAppVersionResource` API.\n\n   This action has no effect outside Resilience Hub.\n\n   This API updates the Resilience Hub application draft version. To\nuse this resource for running resiliency assessments, you must publish the\nResilience Hub application using the `PublishAppVersion` API.","ref":"AWS.Resiliencehub.html#delete_app_version_resource/3","title":"AWS.Resiliencehub.delete_app_version_resource/3","type":"function"},{"doc":"Deletes a recommendation template.\n\nThis is a destructive action that can't be undone.","ref":"AWS.Resiliencehub.html#delete_recommendation_template/3","title":"AWS.Resiliencehub.delete_recommendation_template/3","type":"function"},{"doc":"Deletes a resiliency policy.\n\nThis is a destructive action that can't be undone.","ref":"AWS.Resiliencehub.html#delete_resiliency_policy/3","title":"AWS.Resiliencehub.delete_resiliency_policy/3","type":"function"},{"doc":"Describes an Resilience Hub application.","ref":"AWS.Resiliencehub.html#describe_app/3","title":"AWS.Resiliencehub.describe_app/3","type":"function"},{"doc":"Describes an assessment for an Resilience Hub application.","ref":"AWS.Resiliencehub.html#describe_app_assessment/3","title":"AWS.Resiliencehub.describe_app_assessment/3","type":"function"},{"doc":"Describes the Resilience Hub application version.","ref":"AWS.Resiliencehub.html#describe_app_version/3","title":"AWS.Resiliencehub.describe_app_version/3","type":"function"},{"doc":"Describes an Application Component in the Resilience Hub application.","ref":"AWS.Resiliencehub.html#describe_app_version_app_component/3","title":"AWS.Resiliencehub.describe_app_version_app_component/3","type":"function"},{"doc":"Describes a resource of the Resilience Hub application.\n\nThis API accepts only one of the following parameters to descibe the resource:\n\n   `resourceName`\n\n   `logicalResourceId`\n\n   `physicalResourceId` (Along with `physicalResourceId`, you can also\nprovide `awsAccountId`, and `awsRegion`)","ref":"AWS.Resiliencehub.html#describe_app_version_resource/3","title":"AWS.Resiliencehub.describe_app_version_resource/3","type":"function"},{"doc":"Returns the resolution status for the specified resolution identifier for an\napplication version.\n\nIf `resolutionId` is not specified, the current resolution status is returned.","ref":"AWS.Resiliencehub.html#describe_app_version_resources_resolution_status/3","title":"AWS.Resiliencehub.describe_app_version_resources_resolution_status/3","type":"function"},{"doc":"Describes details about an Resilience Hub application.","ref":"AWS.Resiliencehub.html#describe_app_version_template/3","title":"AWS.Resiliencehub.describe_app_version_template/3","type":"function"},{"doc":"Describes the status of importing resources to an application version.\n\nIf you get a 404 error with `ResourceImportStatusNotFoundAppMetadataException`,\nyou must call `importResourcesToDraftAppVersion` after creating the application\nand before calling `describeDraftAppVersionResourcesImportStatus` to obtain the\nstatus.","ref":"AWS.Resiliencehub.html#describe_draft_app_version_resources_import_status/3","title":"AWS.Resiliencehub.describe_draft_app_version_resources_import_status/3","type":"function"},{"doc":"Describes a specified resiliency policy for an Resilience Hub application.\n\nThe returned policy object includes creation time, data location constraints,\nthe Amazon Resource Name (ARN) for the policy, tags, tier, and more.","ref":"AWS.Resiliencehub.html#describe_resiliency_policy/3","title":"AWS.Resiliencehub.describe_resiliency_policy/3","type":"function"},{"doc":"Imports resources to Resilience Hub application draft version from different\ninput sources.\n\nFor more information about the input sources supported by Resilience Hub, see\n[Discover the structure and describe your Resilience Hub application](https://docs.aws.amazon.com/resilience-hub/latest/userguide/discover-structure.html).","ref":"AWS.Resiliencehub.html#import_resources_to_draft_app_version/3","title":"AWS.Resiliencehub.import_resources_to_draft_app_version/3","type":"function"},{"doc":"Lists the alarm recommendations for an Resilience Hub application.","ref":"AWS.Resiliencehub.html#list_alarm_recommendations/3","title":"AWS.Resiliencehub.list_alarm_recommendations/3","type":"function"},{"doc":"List of compliance drifts that were detected while running an assessment.","ref":"AWS.Resiliencehub.html#list_app_assessment_compliance_drifts/3","title":"AWS.Resiliencehub.list_app_assessment_compliance_drifts/3","type":"function"},{"doc":"Lists the assessments for an Resilience Hub application.\n\nYou can use request parameters to refine the results for the response object.","ref":"AWS.Resiliencehub.html#list_app_assessments/10","title":"AWS.Resiliencehub.list_app_assessments/10","type":"function"},{"doc":"Lists the compliances for an Resilience Hub Application Component.","ref":"AWS.Resiliencehub.html#list_app_component_compliances/3","title":"AWS.Resiliencehub.list_app_component_compliances/3","type":"function"},{"doc":"Lists the recommendations for an Resilience Hub Application Component.","ref":"AWS.Resiliencehub.html#list_app_component_recommendations/3","title":"AWS.Resiliencehub.list_app_component_recommendations/3","type":"function"},{"doc":"Lists all the input sources of the Resilience Hub application.\n\nFor more information about the input sources supported by Resilience Hub, see\n[Discover the structure and describe your Resilience Hub application](https://docs.aws.amazon.com/resilience-hub/latest/userguide/discover-structure.html).","ref":"AWS.Resiliencehub.html#list_app_input_sources/3","title":"AWS.Resiliencehub.list_app_input_sources/3","type":"function"},{"doc":"Lists all the Application Components in the Resilience Hub application.","ref":"AWS.Resiliencehub.html#list_app_version_app_components/3","title":"AWS.Resiliencehub.list_app_version_app_components/3","type":"function"},{"doc":"Lists how the resources in an application version are mapped/sourced from.\n\nMappings can be physical resource identifiers, CloudFormation stacks,\nresource-groups, or an application registry app.","ref":"AWS.Resiliencehub.html#list_app_version_resource_mappings/3","title":"AWS.Resiliencehub.list_app_version_resource_mappings/3","type":"function"},{"doc":"Lists all the resources in an Resilience Hub application.","ref":"AWS.Resiliencehub.html#list_app_version_resources/3","title":"AWS.Resiliencehub.list_app_version_resources/3","type":"function"},{"doc":"Lists the different versions for the Resilience Hub applications.","ref":"AWS.Resiliencehub.html#list_app_versions/3","title":"AWS.Resiliencehub.list_app_versions/3","type":"function"},{"doc":"Lists your Resilience Hub applications.\n\nYou can filter applications using only one filter at a time or without using any\nfilter. If you try to filter applications using multiple filters, you will get\nthe following error:\n\n`An error occurred (ValidationException) when calling the ListApps operation:\nOnly one filter is supported for this operation.`","ref":"AWS.Resiliencehub.html#list_apps/9","title":"AWS.Resiliencehub.list_apps/9","type":"function"},{"doc":"Lists the recommendation templates for the Resilience Hub applications.","ref":"AWS.Resiliencehub.html#list_recommendation_templates/9","title":"AWS.Resiliencehub.list_recommendation_templates/9","type":"function"},{"doc":"Lists the resiliency policies for the Resilience Hub applications.","ref":"AWS.Resiliencehub.html#list_resiliency_policies/5","title":"AWS.Resiliencehub.list_resiliency_policies/5","type":"function"},{"doc":"Lists the standard operating procedure (SOP) recommendations for the Resilience\nHub applications.","ref":"AWS.Resiliencehub.html#list_sop_recommendations/3","title":"AWS.Resiliencehub.list_sop_recommendations/3","type":"function"},{"doc":"Lists the suggested resiliency policies for the Resilience Hub applications.","ref":"AWS.Resiliencehub.html#list_suggested_resiliency_policies/4","title":"AWS.Resiliencehub.list_suggested_resiliency_policies/4","type":"function"},{"doc":"Lists the tags for your resources in your Resilience Hub applications.","ref":"AWS.Resiliencehub.html#list_tags_for_resource/3","title":"AWS.Resiliencehub.list_tags_for_resource/3","type":"function"},{"doc":"Lists the test recommendations for the Resilience Hub application.","ref":"AWS.Resiliencehub.html#list_test_recommendations/3","title":"AWS.Resiliencehub.list_test_recommendations/3","type":"function"},{"doc":"Lists the resources that are not currently supported in Resilience Hub.\n\nAn unsupported resource is a resource that exists in the object that was used to\ncreate an app, but is not supported by Resilience Hub.","ref":"AWS.Resiliencehub.html#list_unsupported_app_version_resources/3","title":"AWS.Resiliencehub.list_unsupported_app_version_resources/3","type":"function"},{"doc":"","ref":"AWS.Resiliencehub.html#metadata/0","title":"AWS.Resiliencehub.metadata/0","type":"function"},{"doc":"Publishes a new version of a specific Resilience Hub application.","ref":"AWS.Resiliencehub.html#publish_app_version/3","title":"AWS.Resiliencehub.publish_app_version/3","type":"function"},{"doc":"Adds or updates the app template for an Resilience Hub application draft\nversion.","ref":"AWS.Resiliencehub.html#put_draft_app_version_template/3","title":"AWS.Resiliencehub.put_draft_app_version_template/3","type":"function"},{"doc":"Removes resource mappings from a draft application version.","ref":"AWS.Resiliencehub.html#remove_draft_app_version_resource_mappings/3","title":"AWS.Resiliencehub.remove_draft_app_version_resource_mappings/3","type":"function"},{"doc":"Resolves the resources for an application version.","ref":"AWS.Resiliencehub.html#resolve_app_version_resources/3","title":"AWS.Resiliencehub.resolve_app_version_resources/3","type":"function"},{"doc":"Creates a new application assessment for an application.","ref":"AWS.Resiliencehub.html#start_app_assessment/3","title":"AWS.Resiliencehub.start_app_assessment/3","type":"function"},{"doc":"Applies one or more tags to a resource.","ref":"AWS.Resiliencehub.html#tag_resource/4","title":"AWS.Resiliencehub.tag_resource/4","type":"function"},{"doc":"Removes one or more tags from a resource.","ref":"AWS.Resiliencehub.html#untag_resource/4","title":"AWS.Resiliencehub.untag_resource/4","type":"function"},{"doc":"Updates an application.","ref":"AWS.Resiliencehub.html#update_app/3","title":"AWS.Resiliencehub.update_app/3","type":"function"},{"doc":"Updates the Resilience Hub application version.\n\nThis API updates the Resilience Hub application draft version. To use this\ninformation for running resiliency assessments, you must publish the Resilience\nHub application using the `PublishAppVersion` API.","ref":"AWS.Resiliencehub.html#update_app_version/3","title":"AWS.Resiliencehub.update_app_version/3","type":"function"},{"doc":"Updates an existing Application Component in the Resilience Hub application.\n\nThis API updates the Resilience Hub application draft version. To use this\nApplication Component for running assessments, you must publish the Resilience\nHub application using the `PublishAppVersion` API.","ref":"AWS.Resiliencehub.html#update_app_version_app_component/3","title":"AWS.Resiliencehub.update_app_version_app_component/3","type":"function"},{"doc":"Updates the resource details in the Resilience Hub application.\n\n   This action has no effect outside Resilience Hub.\n\n   This API updates the Resilience Hub application draft version. To\nuse this resource for running resiliency assessments, you must publish the\nResilience Hub application using the `PublishAppVersion` API.\n\n   To update application version with new `physicalResourceID`, you\nmust call `ResolveAppVersionResources` API.","ref":"AWS.Resiliencehub.html#update_app_version_resource/3","title":"AWS.Resiliencehub.update_app_version_resource/3","type":"function"},{"doc":"Updates a resiliency policy.\n\nResilience Hub allows you to provide a value of zero for `rtoInSecs` and\n`rpoInSecs` of your resiliency policy. But, while assessing your application,\nthe lowest possible assessment result is near zero. Hence, if you provide value\nzero for `rtoInSecs` and `rpoInSecs`, the estimated workload RTO and estimated\nworkload RPO result will be near zero and the **Compliance status** for your\napplication will be set to **Policy breached**.","ref":"AWS.Resiliencehub.html#update_resiliency_policy/3","title":"AWS.Resiliencehub.update_resiliency_policy/3","type":"function"},{"doc":"Amazon Web Services Resource Explorer is a resource search and discovery\nservice.\n\nBy using Resource Explorer, you can explore your resources using an internet\nsearch engine-like experience. Examples of resources include Amazon Relational\nDatabase Service (Amazon RDS) instances, Amazon Simple Storage Service (Amazon\nS3) buckets, or Amazon DynamoDB tables. You can search for your resources using\nresource metadata like names, tags, and IDs. Resource Explorer can search across\nall of the Amazon Web Services Regions in your account in which you turn the\nservice on, to simplify your cross-Region workloads.\n\nResource Explorer scans the resources in each of the Amazon Web Services Regions\nin your Amazon Web Services account in which you turn on Resource Explorer.\nResource Explorer [creates and maintains an index](https://docs.aws.amazon.com/resource-explorer/latest/userguide/getting-started-terms-and-concepts.html#term-index)\nin each Region, with the details of that Region's resources.\n\nYou can [search across all of the indexed Regions in your account](https://docs.aws.amazon.com/resource-explorer/latest/userguide/manage-aggregator-region.html)\nby designating one of your Amazon Web Services Regions to contain the aggregator\nindex for the account. When you [promote a local index in a Region to become the aggregator index for the\naccount](https://docs.aws.amazon.com/resource-explorer/latest/userguide/manage-aggregator-region-turn-on.html),\nResource Explorer automatically replicates the index information from all local\nindexes in the other Regions to the aggregator index. Therefore, the Region with\nthe aggregator index has a copy of all resource information for all Regions in\nthe account where you turned on Resource Explorer. As a result, views in the\naggregator index Region include resources from all of the indexed Regions in\nyour account.\n\nFor more information about Amazon Web Services Resource Explorer, including how\nto enable and configure the service, see the [Amazon Web Services Resource Explorer User\nGuide](https://docs.aws.amazon.com/resource-explorer/latest/userguide/).","ref":"AWS.ResourceExplorer2.html","title":"AWS.ResourceExplorer2","type":"module"},{"doc":"Sets the specified view as the default for the Amazon Web Services Region in\nwhich you call this operation.\n\nWhen a user performs a `Search` that doesn't explicitly specify which view to\nuse, then Amazon Web Services Resource Explorer automatically chooses this\ndefault view for searches performed in this Amazon Web Services Region.\n\nIf an Amazon Web Services Region doesn't have a default view configured, then\nusers must explicitly specify a view with every `Search` operation performed in\nthat Region.","ref":"AWS.ResourceExplorer2.html#associate_default_view/3","title":"AWS.ResourceExplorer2.associate_default_view/3","type":"function"},{"doc":"Retrieves details about a list of views.","ref":"AWS.ResourceExplorer2.html#batch_get_view/3","title":"AWS.ResourceExplorer2.batch_get_view/3","type":"function"},{"doc":"Turns on Amazon Web Services Resource Explorer in the Amazon Web Services Region\nin which you called this operation by creating an index.\n\nResource Explorer begins discovering the resources in this Region and stores the\ndetails about the resources in the index so that they can be queried by using\nthe `Search` operation. You can create only one index in a Region.\n\nThis operation creates only a *local* index. To promote the local index in one\nAmazon Web Services Region into the aggregator index for the Amazon Web Services\naccount, use the `UpdateIndexType` operation. For more information, see [Turning on cross-Region search by creating an aggregator\nindex](https://docs.aws.amazon.com/resource-explorer/latest/userguide/manage-aggregator-region.html)\nin the *Amazon Web Services Resource Explorer User Guide*.\n\nFor more details about what happens when you turn on Resource Explorer in an\nAmazon Web Services Region, see [Turn on Resource Explorer to index your resources in an Amazon Web Services\nRegion](https://docs.aws.amazon.com/resource-explorer/latest/userguide/manage-service-activate.html)\nin the *Amazon Web Services Resource Explorer User Guide*.\n\nIf this is the first Amazon Web Services Region in which you've created an index\nfor Resource Explorer, then this operation also [creates a service-linked role](https://docs.aws.amazon.com/resource-explorer/latest/userguide/security_iam_service-linked-roles.html)\nin your Amazon Web Services account that allows Resource Explorer to enumerate\nyour resources to populate the index.\n\n  * **Action**: `resource-explorer-2:CreateIndex`\n\n**Resource**: The ARN of the index (as it will exist after the operation\ncompletes) in the Amazon Web Services Region and account in which you're trying\nto create the index. Use the wildcard character (`*`) at the end of the string\nto match the eventual UUID. For example, the following `Resource` element\nrestricts the role or user to creating an index in only the `us-east-2` Region\nof the specified account.\n\n`\"Resource\": \"arn:aws:resource-explorer-2:us-west-2:* *:index/*\"`\n\nAlternatively, you can use `\"Resource\": \"*\"` to allow the role or user to create\nan index in any Region.\n\n  * **Action**: `iam:CreateServiceLinkedRole`\n\n**Resource**: No specific resource (*).\n\nThis permission is required only the first time you create an index to turn on\nResource Explorer in the account. Resource Explorer uses this to create the\n[service-linked role needed to index the resources in your account](https://docs.aws.amazon.com/resource-explorer/latest/userguide/security_iam_service-linked-roles.html).\nResource Explorer uses the same service-linked role for all additional indexes\nyou create afterwards.","ref":"AWS.ResourceExplorer2.html#create_index/3","title":"AWS.ResourceExplorer2.create_index/3","type":"function"},{"doc":"Creates a view that users can query by using the `Search` operation.\n\nResults from queries that you make using this view include only resources that\nmatch the view's `Filters`. For more information about Amazon Web Services\nResource Explorer views, see [Managing views](https://docs.aws.amazon.com/resource-explorer/latest/userguide/manage-views.html)\nin the *Amazon Web Services Resource Explorer User Guide*.\n\nOnly the principals with an IAM identity-based policy that grants `Allow` to the\n`Search` action on a `Resource` with the [Amazon resource name (ARN)](https://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html)\nof this view can `Search` using views you create with this operation.","ref":"AWS.ResourceExplorer2.html#create_view/3","title":"AWS.ResourceExplorer2.create_view/3","type":"function"},{"doc":"Deletes the specified index and turns off Amazon Web Services Resource Explorer\nin the specified Amazon Web Services Region.\n\nWhen you delete an index, Resource Explorer stops discovering and indexing\nresources in that Region. Resource Explorer also deletes all views in that\nRegion. These actions occur as asynchronous background tasks. You can check to\nsee when the actions are complete by using the `GetIndex` operation and checking\nthe `Status` response value.\n\nIf the index you delete is the aggregator index for the Amazon Web Services\naccount, you must wait 24 hours before you can promote another local index to be\nthe aggregator index for the account. Users can't perform account-wide searches\nusing Resource Explorer until another aggregator index is configured.","ref":"AWS.ResourceExplorer2.html#delete_index/3","title":"AWS.ResourceExplorer2.delete_index/3","type":"function"},{"doc":"Deletes the specified view.\n\nIf the specified view is the default view for its Amazon Web Services Region,\nthen all `Search` operations in that Region must explicitly specify the view to\nuse until you configure a new default by calling the `AssociateDefaultView`\noperation.","ref":"AWS.ResourceExplorer2.html#delete_view/3","title":"AWS.ResourceExplorer2.delete_view/3","type":"function"},{"doc":"After you call this operation, the affected Amazon Web Services Region no longer\nhas a default view.\n\nAll `Search` operations in that Region must explicitly specify a view or the\noperation fails. You can configure a new default by calling the\n`AssociateDefaultView` operation.\n\nIf an Amazon Web Services Region doesn't have a default view configured, then\nusers must explicitly specify a view with every `Search` operation performed in\nthat Region.","ref":"AWS.ResourceExplorer2.html#disassociate_default_view/3","title":"AWS.ResourceExplorer2.disassociate_default_view/3","type":"function"},{"doc":"Retrieves the status of your account's Amazon Web Services service access, and\nvalidates the service linked role required to access the multi-account search\nfeature.\n\nOnly the management account or a delegated administrator with service access\nenabled can invoke this API call.","ref":"AWS.ResourceExplorer2.html#get_account_level_service_configuration/3","title":"AWS.ResourceExplorer2.get_account_level_service_configuration/3","type":"function"},{"doc":"Retrieves the Amazon Resource Name (ARN) of the view that is the default for the\nAmazon Web Services Region in which you call this operation.\n\nYou can then call `GetView` to retrieve the details of that view.","ref":"AWS.ResourceExplorer2.html#get_default_view/3","title":"AWS.ResourceExplorer2.get_default_view/3","type":"function"},{"doc":"Retrieves details about the Amazon Web Services Resource Explorer index in the\nAmazon Web Services Region in which you invoked the operation.","ref":"AWS.ResourceExplorer2.html#get_index/3","title":"AWS.ResourceExplorer2.get_index/3","type":"function"},{"doc":"Retrieves details of the specified view.","ref":"AWS.ResourceExplorer2.html#get_view/3","title":"AWS.ResourceExplorer2.get_view/3","type":"function"},{"doc":"Retrieves a list of all of the indexes in Amazon Web Services Regions that are\ncurrently collecting resource information for Amazon Web Services Resource\nExplorer.","ref":"AWS.ResourceExplorer2.html#list_indexes/3","title":"AWS.ResourceExplorer2.list_indexes/3","type":"function"},{"doc":"Retrieves a list of a member's indexes in all Amazon Web Services Regions that\nare currently collecting resource information for Amazon Web Services Resource\nExplorer.\n\nOnly the management account or a delegated administrator with service access\nenabled can invoke this API call.","ref":"AWS.ResourceExplorer2.html#list_indexes_for_members/3","title":"AWS.ResourceExplorer2.list_indexes_for_members/3","type":"function"},{"doc":"Retrieves a list of all resource types currently supported by Amazon Web\nServices Resource Explorer.","ref":"AWS.ResourceExplorer2.html#list_supported_resource_types/3","title":"AWS.ResourceExplorer2.list_supported_resource_types/3","type":"function"},{"doc":"Lists the tags that are attached to the specified resource.","ref":"AWS.ResourceExplorer2.html#list_tags_for_resource/3","title":"AWS.ResourceExplorer2.list_tags_for_resource/3","type":"function"},{"doc":"Lists the [Amazon resource names (ARNs)](https://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html)\nof the views available in the Amazon Web Services Region in which you call this\noperation.\n\nAlways check the `NextToken` response parameter for a `null` value when calling\na paginated operation. These operations can occasionally return an empty set of\nresults even when there are more results available. The `NextToken` response\nparameter value is `null` *only* when there are no more results to display.","ref":"AWS.ResourceExplorer2.html#list_views/3","title":"AWS.ResourceExplorer2.list_views/3","type":"function"},{"doc":"","ref":"AWS.ResourceExplorer2.html#metadata/0","title":"AWS.ResourceExplorer2.metadata/0","type":"function"},{"doc":"Searches for resources and displays details about all resources that match the\nspecified criteria.\n\nYou must specify a query string.\n\nAll search queries must use a view. If you don't explicitly specify a view, then\nAmazon Web Services Resource Explorer uses the default view for the Amazon Web\nServices Region in which you call this operation. The results are the logical\nintersection of the results that match both the `QueryString` parameter supplied\nto this operation and the `SearchFilter` parameter attached to the view.\n\nFor the complete syntax supported by the `QueryString` parameter, see [Search query syntax reference for Resource\nExplorer](https://docs.aws.amazon.com/resource-explorer/latest/APIReference/about-query-syntax.html).\n\nIf your search results are empty, or are missing results that you think should\nbe there, see [Troubleshooting Resource Explorer search](https://docs.aws.amazon.com/resource-explorer/latest/userguide/troubleshooting_search.html).","ref":"AWS.ResourceExplorer2.html#search/3","title":"AWS.ResourceExplorer2.search/3","type":"function"},{"doc":"Adds one or more tag key and value pairs to an Amazon Web Services Resource\nExplorer view or index.","ref":"AWS.ResourceExplorer2.html#tag_resource/4","title":"AWS.ResourceExplorer2.tag_resource/4","type":"function"},{"doc":"Removes one or more tag key and value pairs from an Amazon Web Services Resource\nExplorer view or index.","ref":"AWS.ResourceExplorer2.html#untag_resource/4","title":"AWS.ResourceExplorer2.untag_resource/4","type":"function"},{"doc":"Changes the type of the index from one of the following types to the other.\n\nFor more information about indexes and the role they perform in Amazon Web\nServices Resource Explorer, see [Turning on cross-Region search by creating an aggregator\nindex](https://docs.aws.amazon.com/resource-explorer/latest/userguide/manage-aggregator-region.html)\nin the *Amazon Web Services Resource Explorer User Guide*.\n\n  * ##  `AGGREGATOR` index type\n\nThe index contains information about resources from all Amazon Web Services\nRegions in the Amazon Web Services account in which you've created a Resource\nExplorer index. Resource information from all other Regions is replicated to\nthis Region's index.\n\nWhen you change the index type to `AGGREGATOR`, Resource Explorer turns on\nreplication of all discovered resource information from the other Amazon Web\nServices Regions in your account to this index. You can then, from this Region\nonly, perform resource search queries that span all Amazon Web Services Regions\nin the Amazon Web Services account. Turning on replication from all other\nRegions is performed by asynchronous background tasks. You can check the status\nof the asynchronous tasks by using the `GetIndex` operation. When the\nasynchronous tasks complete, the `Status` response of that operation changes\nfrom `UPDATING` to `ACTIVE`. After that, you can start to see results from other\nAmazon Web Services Regions in query results. However, it can take several hours\nfor replication from all other Regions to complete.\n\nYou can have only one aggregator index per Amazon Web Services account. Before\nyou can promote a different index to be the aggregator index for the account,\nyou must first demote the existing aggregator index to type `LOCAL`.\n\n  * ##  `LOCAL` index type\n\nThe index contains information about resources in only the Amazon Web Services\nRegion in which the index exists. If an aggregator index in another Region\nexists, then information in this local index is replicated to the aggregator\nindex.\n\nWhen you change the index type to `LOCAL`, Resource Explorer turns off the\nreplication of resource information from all other Amazon Web Services Regions\nin the Amazon Web Services account to this Region. The aggregator index remains\nin the `UPDATING` state until all replication with other Regions successfully\nstops. You can check the status of the asynchronous task by using the `GetIndex`\noperation. When Resource Explorer successfully stops all replication with other\nRegions, the `Status` response of that operation changes from `UPDATING` to\n`ACTIVE`. Separately, the resource information from other Regions that was\npreviously stored in the index is deleted within 30 days by another background\ntask. Until that asynchronous task completes, some results from other Regions\ncan continue to appear in search results.\n\nAfter you demote an aggregator index to a local index, you must wait 24 hours\nbefore you can promote another index to be the new aggregator index for the\naccount.","ref":"AWS.ResourceExplorer2.html#update_index_type/3","title":"AWS.ResourceExplorer2.update_index_type/3","type":"function"},{"doc":"Modifies some of the details of a view.\n\nYou can change the filter string and the list of included properties. You can't\nchange the name of the view.","ref":"AWS.ResourceExplorer2.html#update_view/3","title":"AWS.ResourceExplorer2.update_view/3","type":"function"},{"doc":"Resource Groups lets you organize Amazon Web Services resources such as Amazon\nElastic Compute Cloud instances, Amazon Relational Database Service databases,\nand Amazon Simple Storage Service buckets into groups using criteria that you\ndefine as tags.\n\nA resource group is a collection of resources that match the resource types\nspecified in a query, and share one or more tags or portions of tags. You can\ncreate a group of resources based on their roles in your cloud infrastructure,\nlifecycle stages, regions, application layers, or virtually any criteria.\nResource Groups enable you to automate management tasks, such as those in Amazon\nWeb Services Systems Manager Automation documents, on tag-related resources in\nAmazon Web Services Systems Manager. Groups of tagged resources also let you\nquickly view a custom console in Amazon Web Services Systems Manager that shows\nConfig compliance and other monitoring data about member resources.\n\nTo create a resource group, build a resource query, and specify tags that\nidentify the criteria that members of the group have in common. Tags are\nkey-value pairs.\n\nFor more information about Resource Groups, see the [Resource Groups User Guide](https://docs.aws.amazon.com/ARG/latest/userguide/welcome.html).\n\nResource Groups uses a REST-compliant API that you can use to perform the\nfollowing types of operations.\n\n  * Create, Read, Update, and Delete (CRUD) operations on resource\ngroups and resource query entities\n\n  * Applying, editing, and removing tags from resource groups\n\n  * Resolving resource group member ARNs so they can be returned as\nsearch results\n\n  * Getting data about resources that are members of a group\n\n  * Searching Amazon Web Services resources based on a resource query","ref":"AWS.ResourceGroups.html","title":"AWS.ResourceGroups","type":"module"},{"doc":"Creates a resource group with the specified name and description.\n\nYou can optionally include either a resource query or a service configuration.\nFor more information about constructing a resource query, see [Build queries and groups in Resource\nGroups](https://docs.aws.amazon.com/ARG/latest/userguide/getting_started-query.html)\nin the *Resource Groups User Guide*. For more information about service-linked\ngroups and service configurations, see [Service configurations for Resource Groups](https://docs.aws.amazon.com/ARG/latest/APIReference/about-slg.html).","ref":"AWS.ResourceGroups.html#create_group/3","title":"AWS.ResourceGroups.create_group/3","type":"function"},{"doc":"To run this command, you must have the following permissions:\n\n  * `resource-groups:CreateGroup`","ref":"AWS.ResourceGroups.html#create_group/3-minimum-permissions","title":"Minimum permissions - AWS.ResourceGroups.create_group/3","type":"function"},{"doc":"Deletes the specified resource group.\n\nDeleting a resource group does not delete any resources that are members of the\ngroup; it only deletes the group structure.","ref":"AWS.ResourceGroups.html#delete_group/3","title":"AWS.ResourceGroups.delete_group/3","type":"function"},{"doc":"To run this command, you must have the following permissions:\n\n  * `resource-groups:DeleteGroup`","ref":"AWS.ResourceGroups.html#delete_group/3-minimum-permissions","title":"Minimum permissions - AWS.ResourceGroups.delete_group/3","type":"function"},{"doc":"Retrieves the current status of optional features in Resource Groups.","ref":"AWS.ResourceGroups.html#get_account_settings/3","title":"AWS.ResourceGroups.get_account_settings/3","type":"function"},{"doc":"Returns information about a specified resource group.","ref":"AWS.ResourceGroups.html#get_group/3","title":"AWS.ResourceGroups.get_group/3","type":"function"},{"doc":"To run this command, you must have the following permissions:\n\n  * `resource-groups:GetGroup`","ref":"AWS.ResourceGroups.html#get_group/3-minimum-permissions","title":"Minimum permissions - AWS.ResourceGroups.get_group/3","type":"function"},{"doc":"Retrieves the service configuration associated with the specified resource\ngroup.\n\nFor details about the service configuration syntax, see [Service configurations for Resource\nGroups](https://docs.aws.amazon.com/ARG/latest/APIReference/about-slg.html).","ref":"AWS.ResourceGroups.html#get_group_configuration/3","title":"AWS.ResourceGroups.get_group_configuration/3","type":"function"},{"doc":"To run this command, you must have the following permissions:\n\n  * `resource-groups:GetGroupConfiguration`","ref":"AWS.ResourceGroups.html#get_group_configuration/3-minimum-permissions","title":"Minimum permissions - AWS.ResourceGroups.get_group_configuration/3","type":"function"},{"doc":"Retrieves the resource query associated with the specified resource group.\n\nFor more information about resource queries, see [Create a tag-based group in Resource\nGroups](https://docs.aws.amazon.com/ARG/latest/userguide/gettingstarted-query.html#gettingstarted-query-cli-tag).","ref":"AWS.ResourceGroups.html#get_group_query/3","title":"AWS.ResourceGroups.get_group_query/3","type":"function"},{"doc":"To run this command, you must have the following permissions:\n\n  * `resource-groups:GetGroupQuery`","ref":"AWS.ResourceGroups.html#get_group_query/3-minimum-permissions","title":"Minimum permissions - AWS.ResourceGroups.get_group_query/3","type":"function"},{"doc":"Returns a list of tags that are associated with a resource group, specified by\nan ARN.","ref":"AWS.ResourceGroups.html#get_tags/3","title":"AWS.ResourceGroups.get_tags/3","type":"function"},{"doc":"To run this command, you must have the following permissions:\n\n  * `resource-groups:GetTags`","ref":"AWS.ResourceGroups.html#get_tags/3-minimum-permissions","title":"Minimum permissions - AWS.ResourceGroups.get_tags/3","type":"function"},{"doc":"Adds the specified resources to the specified group.\n\nYou can use this operation with only resource groups that are configured with\nthe following types:\n\n   `AWS::EC2::HostManagement`\n\n   `AWS::EC2::CapacityReservationPool`\n\nOther resource group type and resource types aren't currently supported by this\noperation.","ref":"AWS.ResourceGroups.html#group_resources/3","title":"AWS.ResourceGroups.group_resources/3","type":"function"},{"doc":"To run this command, you must have the following permissions:\n\n  * `resource-groups:GroupResources`","ref":"AWS.ResourceGroups.html#group_resources/3-minimum-permissions","title":"Minimum permissions - AWS.ResourceGroups.group_resources/3","type":"function"},{"doc":"Returns a list of ARNs of the resources that are members of a specified resource\ngroup.","ref":"AWS.ResourceGroups.html#list_group_resources/3","title":"AWS.ResourceGroups.list_group_resources/3","type":"function"},{"doc":"To run this command, you must have the following permissions:\n\n  * `resource-groups:ListGroupResources`\n\n  * `cloudformation:DescribeStacks`\n\n  * `cloudformation:ListStackResources`\n\n  * `tag:GetResources`","ref":"AWS.ResourceGroups.html#list_group_resources/3-minimum-permissions","title":"Minimum permissions - AWS.ResourceGroups.list_group_resources/3","type":"function"},{"doc":"Returns a list of existing Resource Groups in your account.","ref":"AWS.ResourceGroups.html#list_groups/3","title":"AWS.ResourceGroups.list_groups/3","type":"function"},{"doc":"To run this command, you must have the following permissions:\n\n  * `resource-groups:ListGroups`","ref":"AWS.ResourceGroups.html#list_groups/3-minimum-permissions","title":"Minimum permissions - AWS.ResourceGroups.list_groups/3","type":"function"},{"doc":"","ref":"AWS.ResourceGroups.html#metadata/0","title":"AWS.ResourceGroups.metadata/0","type":"function"},{"doc":"Attaches a service configuration to the specified group.\n\nThis occurs asynchronously, and can take time to complete. You can use\n`GetGroupConfiguration` to check the status of the update.","ref":"AWS.ResourceGroups.html#put_group_configuration/3","title":"AWS.ResourceGroups.put_group_configuration/3","type":"function"},{"doc":"To run this command, you must have the following permissions:\n\n  * `resource-groups:PutGroupConfiguration`","ref":"AWS.ResourceGroups.html#put_group_configuration/3-minimum-permissions","title":"Minimum permissions - AWS.ResourceGroups.put_group_configuration/3","type":"function"},{"doc":"Returns a list of Amazon Web Services resource identifiers that matches the\nspecified query.\n\nThe query uses the same format as a resource query in a `CreateGroup` or\n`UpdateGroupQuery` operation.","ref":"AWS.ResourceGroups.html#search_resources/3","title":"AWS.ResourceGroups.search_resources/3","type":"function"},{"doc":"To run this command, you must have the following permissions:\n\n  * `resource-groups:SearchResources`\n\n  * `cloudformation:DescribeStacks`\n\n  * `cloudformation:ListStackResources`\n\n  * `tag:GetResources`","ref":"AWS.ResourceGroups.html#search_resources/3-minimum-permissions","title":"Minimum permissions - AWS.ResourceGroups.search_resources/3","type":"function"},{"doc":"Adds tags to a resource group with the specified ARN.\n\nExisting tags on a resource group are not changed if they are not specified in\nthe request parameters.\n\nDo not store personally identifiable information (PII) or other confidential or\nsensitive information in tags. We use tags to provide you with billing and\nadministration services. Tags are not intended to be used for private or\nsensitive data.","ref":"AWS.ResourceGroups.html#tag/4","title":"AWS.ResourceGroups.tag/4","type":"function"},{"doc":"To run this command, you must have the following permissions:\n\n  * `resource-groups:Tag`","ref":"AWS.ResourceGroups.html#tag/4-minimum-permissions","title":"Minimum permissions - AWS.ResourceGroups.tag/4","type":"function"},{"doc":"Removes the specified resources from the specified group.\n\nThis operation works only with static groups that you populated using the\n`GroupResources` operation. It doesn't work with any resource groups that are\nautomatically populated by tag-based or CloudFormation stack-based queries.","ref":"AWS.ResourceGroups.html#ungroup_resources/3","title":"AWS.ResourceGroups.ungroup_resources/3","type":"function"},{"doc":"To run this command, you must have the following permissions:\n\n  * `resource-groups:UngroupResources`","ref":"AWS.ResourceGroups.html#ungroup_resources/3-minimum-permissions","title":"Minimum permissions - AWS.ResourceGroups.ungroup_resources/3","type":"function"},{"doc":"Deletes tags from a specified resource group.","ref":"AWS.ResourceGroups.html#untag/4","title":"AWS.ResourceGroups.untag/4","type":"function"},{"doc":"To run this command, you must have the following permissions:\n\n  * `resource-groups:Untag`","ref":"AWS.ResourceGroups.html#untag/4-minimum-permissions","title":"Minimum permissions - AWS.ResourceGroups.untag/4","type":"function"},{"doc":"Turns on or turns off optional features in Resource Groups.\n\nThe preceding example shows that the request to turn on group lifecycle events\nis `IN_PROGRESS`. You can call the `GetAccountSettings` operation to check for\ncompletion by looking for `GroupLifecycleEventsStatus` to change to `ACTIVE`.","ref":"AWS.ResourceGroups.html#update_account_settings/3","title":"AWS.ResourceGroups.update_account_settings/3","type":"function"},{"doc":"Updates the description for an existing group.\n\nYou cannot update the name of a resource group.","ref":"AWS.ResourceGroups.html#update_group/3","title":"AWS.ResourceGroups.update_group/3","type":"function"},{"doc":"To run this command, you must have the following permissions:\n\n  * `resource-groups:UpdateGroup`","ref":"AWS.ResourceGroups.html#update_group/3-minimum-permissions","title":"Minimum permissions - AWS.ResourceGroups.update_group/3","type":"function"},{"doc":"Updates the resource query of a group.\n\nFor more information about resource queries, see [Create a tag-based group in Resource\nGroups](https://docs.aws.amazon.com/ARG/latest/userguide/gettingstarted-query.html#gettingstarted-query-cli-tag).","ref":"AWS.ResourceGroups.html#update_group_query/3","title":"AWS.ResourceGroups.update_group_query/3","type":"function"},{"doc":"To run this command, you must have the following permissions:\n\n  * `resource-groups:UpdateGroupQuery`","ref":"AWS.ResourceGroups.html#update_group_query/3-minimum-permissions","title":"Minimum permissions - AWS.ResourceGroups.update_group_query/3","type":"function"},{"doc":"Resource Groups Tagging API","ref":"AWS.ResourceGroupsTaggingAPI.html","title":"AWS.ResourceGroupsTaggingAPI","type":"module"},{"doc":"Describes the status of the `StartReportCreation` operation.\n\nYou can call this operation only from the organization's management account and\nfrom the us-east-1 Region.","ref":"AWS.ResourceGroupsTaggingAPI.html#describe_report_creation/3","title":"AWS.ResourceGroupsTaggingAPI.describe_report_creation/3","type":"function"},{"doc":"Returns a table that shows counts of resources that are noncompliant with their\ntag policies.\n\nFor more information on tag policies, see [Tag Policies](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_policies_tag-policies.html)\nin the *Organizations User Guide.*\n\nYou can call this operation only from the organization's management account and\nfrom the us-east-1 Region.\n\nThis operation supports pagination, where the response can be sent in multiple\npages. You should check the `PaginationToken` response parameter to determine if\nthere are additional results available to return. Repeat the query, passing the\n`PaginationToken` response parameter value as an input to the next request until\nyou recieve a `null` value. A null value for `PaginationToken` indicates that\nthere are no more results waiting to be returned.","ref":"AWS.ResourceGroupsTaggingAPI.html#get_compliance_summary/3","title":"AWS.ResourceGroupsTaggingAPI.get_compliance_summary/3","type":"function"},{"doc":"Returns all the tagged or previously tagged resources that are located in the\nspecified Amazon Web Services Region for the account.\n\nDepending on what information you want returned, you can also specify the\nfollowing:\n\n  * *Filters* that specify what tags and resource types you want\nreturned. The response includes all tags that are associated with the requested\nresources.\n\n  * Information about compliance with the account's effective tag\npolicy. For more information on tag policies, see [Tag Policies](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_policies_tag-policies.html)\nin the *Organizations User Guide.*\n\nThis operation supports pagination, where the response can be sent in multiple\npages. You should check the `PaginationToken` response parameter to determine if\nthere are additional results available to return. Repeat the query, passing the\n`PaginationToken` response parameter value as an input to the next request until\nyou recieve a `null` value. A null value for `PaginationToken` indicates that\nthere are no more results waiting to be returned.","ref":"AWS.ResourceGroupsTaggingAPI.html#get_resources/3","title":"AWS.ResourceGroupsTaggingAPI.get_resources/3","type":"function"},{"doc":"Returns all tag keys currently in use in the specified Amazon Web Services\nRegion for the calling account.\n\nThis operation supports pagination, where the response can be sent in multiple\npages. You should check the `PaginationToken` response parameter to determine if\nthere are additional results available to return. Repeat the query, passing the\n`PaginationToken` response parameter value as an input to the next request until\nyou recieve a `null` value. A null value for `PaginationToken` indicates that\nthere are no more results waiting to be returned.","ref":"AWS.ResourceGroupsTaggingAPI.html#get_tag_keys/3","title":"AWS.ResourceGroupsTaggingAPI.get_tag_keys/3","type":"function"},{"doc":"Returns all tag values for the specified key that are used in the specified\nAmazon Web Services Region for the calling account.\n\nThis operation supports pagination, where the response can be sent in multiple\npages. You should check the `PaginationToken` response parameter to determine if\nthere are additional results available to return. Repeat the query, passing the\n`PaginationToken` response parameter value as an input to the next request until\nyou recieve a `null` value. A null value for `PaginationToken` indicates that\nthere are no more results waiting to be returned.","ref":"AWS.ResourceGroupsTaggingAPI.html#get_tag_values/3","title":"AWS.ResourceGroupsTaggingAPI.get_tag_values/3","type":"function"},{"doc":"","ref":"AWS.ResourceGroupsTaggingAPI.html#metadata/0","title":"AWS.ResourceGroupsTaggingAPI.metadata/0","type":"function"},{"doc":"Generates a report that lists all tagged resources in the accounts across your\norganization and tells whether each resource is compliant with the effective tag\npolicy.\n\nCompliance data is refreshed daily. The report is generated asynchronously.\n\nThe generated report is saved to the following location:\n\n`s3://example-bucket/AwsTagPolicies/o-exampleorgid/YYYY-MM-ddTHH:mm:ssZ/report.csv`\n\nYou can call this operation only from the organization's management account and\nfrom the us-east-1 Region.","ref":"AWS.ResourceGroupsTaggingAPI.html#start_report_creation/3","title":"AWS.ResourceGroupsTaggingAPI.start_report_creation/3","type":"function"},{"doc":"Applies one or more tags to the specified resources.\n\nNote the following:\n\n  * Not all resources can have tags. For a list of services with\nresources that support tagging using this operation, see [Services that support the Resource Groups Tagging\nAPI](https://docs.aws.amazon.com/resourcegroupstagging/latest/APIReference/supported-services.html).\nIf the resource doesn't yet support this operation, the resource's service might\nsupport tagging using its own API operations. For more information, refer to the\ndocumentation for that service.\n\n  * Each resource can have up to 50 tags. For other limits, see [Tag Naming and Usage\nConventions](https://docs.aws.amazon.com/general/latest/gr/aws_tagging.html#tag-conventions)\nin the *Amazon Web Services General Reference.*\n\n  * You can only tag resources that are located in the specified\nAmazon Web Services Region for the Amazon Web Services account.\n\n  * To add tags to a resource, you need the necessary permissions for\nthe service that the resource belongs to as well as permissions for adding tags.\nFor more information, see the documentation for each service.\n\nDo not store personally identifiable information (PII) or other confidential or\nsensitive information in tags. We use tags to provide you with billing and\nadministration services. Tags are not intended to be used for private or\nsensitive data.","ref":"AWS.ResourceGroupsTaggingAPI.html#tag_resources/3","title":"AWS.ResourceGroupsTaggingAPI.tag_resources/3","type":"function"},{"doc":"In addition to the `tag:TagResources` permission required by this operation, you\nmust also have the tagging permission defined by the service that created the\nresource. For example, to tag an Amazon EC2 instance using the `TagResources`\noperation, you must have both of the following permissions:\n\n  * `tag:TagResource`\n\n  * `ec2:CreateTags`","ref":"AWS.ResourceGroupsTaggingAPI.html#tag_resources/3-minimum-permissions","title":"Minimum permissions - AWS.ResourceGroupsTaggingAPI.tag_resources/3","type":"function"},{"doc":"Removes the specified tags from the specified resources.\n\nWhen you specify a tag key, the action removes both that key and its associated\nvalue. The operation succeeds even if you attempt to remove tags from a resource\nthat were already removed. Note the following:\n\n  * To remove tags from a resource, you need the necessary permissions\nfor the service that the resource belongs to as well as permissions for removing\ntags. For more information, see the documentation for the service whose resource\nyou want to untag.\n\n  * You can only tag resources that are located in the specified\nAmazon Web Services Region for the calling Amazon Web Services account.","ref":"AWS.ResourceGroupsTaggingAPI.html#untag_resources/3","title":"AWS.ResourceGroupsTaggingAPI.untag_resources/3","type":"function"},{"doc":"In addition to the `tag:UntagResources` permission required by this operation,\nyou must also have the remove tags permission defined by the service that\ncreated the resource. For example, to remove the tags from an Amazon EC2\ninstance using the `UntagResources` operation, you must have both of the\nfollowing permissions:\n\n  * `tag:UntagResource`\n\n  * `ec2:DeleteTags`","ref":"AWS.ResourceGroupsTaggingAPI.html#untag_resources/3-minimum-permissions","title":"Minimum permissions - AWS.ResourceGroupsTaggingAPI.untag_resources/3","type":"function"},{"doc":"This section provides documentation for the AWS RoboMaker API operations.","ref":"AWS.RoboMaker.html","title":"AWS.RoboMaker","type":"module"},{"doc":"Deletes one or more worlds in a batch operation.","ref":"AWS.RoboMaker.html#batch_delete_worlds/3","title":"AWS.RoboMaker.batch_delete_worlds/3","type":"function"},{"doc":"Describes one or more simulation jobs.","ref":"AWS.RoboMaker.html#batch_describe_simulation_job/3","title":"AWS.RoboMaker.batch_describe_simulation_job/3","type":"function"},{"doc":"Cancels the specified deployment job.\n\nThis API will no longer be supported as of May 2, 2022. Use it to remove\nresources that were created for Deployment Service.","ref":"AWS.RoboMaker.html#cancel_deployment_job/3","title":"AWS.RoboMaker.cancel_deployment_job/3","type":"function"},{"doc":"Cancels the specified simulation job.","ref":"AWS.RoboMaker.html#cancel_simulation_job/3","title":"AWS.RoboMaker.cancel_simulation_job/3","type":"function"},{"doc":"Cancels a simulation job batch.\n\nWhen you cancel a simulation job batch, you are also cancelling all of the\nactive simulation jobs created as part of the batch.","ref":"AWS.RoboMaker.html#cancel_simulation_job_batch/3","title":"AWS.RoboMaker.cancel_simulation_job_batch/3","type":"function"},{"doc":"Cancels the specified export job.","ref":"AWS.RoboMaker.html#cancel_world_export_job/3","title":"AWS.RoboMaker.cancel_world_export_job/3","type":"function"},{"doc":"Cancels the specified world generator job.","ref":"AWS.RoboMaker.html#cancel_world_generation_job/3","title":"AWS.RoboMaker.cancel_world_generation_job/3","type":"function"},{"doc":"Deploys a specific version of a robot application to robots in a fleet.\n\nThis API is no longer supported and will throw an error if used.\n\nThe robot application must have a numbered `applicationVersion` for consistency\nreasons. To create a new version, use `CreateRobotApplicationVersion` or see\n[Creating a Robot Application Version](https://docs.aws.amazon.com/robomaker/latest/dg/create-robot-application-version.html).\n\nAfter 90 days, deployment jobs expire and will be deleted. They will no longer\nbe accessible.","ref":"AWS.RoboMaker.html#create_deployment_job/3","title":"AWS.RoboMaker.create_deployment_job/3","type":"function"},{"doc":"Creates a fleet, a logical group of robots running the same robot application.\n\nThis API is no longer supported and will throw an error if used.","ref":"AWS.RoboMaker.html#create_fleet/3","title":"AWS.RoboMaker.create_fleet/3","type":"function"},{"doc":"Creates a robot.\n\nThis API is no longer supported and will throw an error if used.","ref":"AWS.RoboMaker.html#create_robot/3","title":"AWS.RoboMaker.create_robot/3","type":"function"},{"doc":"Creates a robot application.","ref":"AWS.RoboMaker.html#create_robot_application/3","title":"AWS.RoboMaker.create_robot_application/3","type":"function"},{"doc":"Creates a version of a robot application.","ref":"AWS.RoboMaker.html#create_robot_application_version/3","title":"AWS.RoboMaker.create_robot_application_version/3","type":"function"},{"doc":"Creates a simulation application.","ref":"AWS.RoboMaker.html#create_simulation_application/3","title":"AWS.RoboMaker.create_simulation_application/3","type":"function"},{"doc":"Creates a simulation application with a specific revision id.","ref":"AWS.RoboMaker.html#create_simulation_application_version/3","title":"AWS.RoboMaker.create_simulation_application_version/3","type":"function"},{"doc":"Creates a simulation job.\n\nAfter 90 days, simulation jobs expire and will be deleted. They will no longer\nbe accessible.","ref":"AWS.RoboMaker.html#create_simulation_job/3","title":"AWS.RoboMaker.create_simulation_job/3","type":"function"},{"doc":"Creates a world export job.","ref":"AWS.RoboMaker.html#create_world_export_job/3","title":"AWS.RoboMaker.create_world_export_job/3","type":"function"},{"doc":"Creates worlds using the specified template.","ref":"AWS.RoboMaker.html#create_world_generation_job/3","title":"AWS.RoboMaker.create_world_generation_job/3","type":"function"},{"doc":"Creates a world template.","ref":"AWS.RoboMaker.html#create_world_template/3","title":"AWS.RoboMaker.create_world_template/3","type":"function"},{"doc":"Deletes a fleet.\n\nThis API will no longer be supported as of May 2, 2022. Use it to remove\nresources that were created for Deployment Service.","ref":"AWS.RoboMaker.html#delete_fleet/3","title":"AWS.RoboMaker.delete_fleet/3","type":"function"},{"doc":"Deletes a robot.\n\nThis API will no longer be supported as of May 2, 2022. Use it to remove\nresources that were created for Deployment Service.","ref":"AWS.RoboMaker.html#delete_robot/3","title":"AWS.RoboMaker.delete_robot/3","type":"function"},{"doc":"Deletes a robot application.","ref":"AWS.RoboMaker.html#delete_robot_application/3","title":"AWS.RoboMaker.delete_robot_application/3","type":"function"},{"doc":"Deletes a simulation application.","ref":"AWS.RoboMaker.html#delete_simulation_application/3","title":"AWS.RoboMaker.delete_simulation_application/3","type":"function"},{"doc":"Deletes a world template.","ref":"AWS.RoboMaker.html#delete_world_template/3","title":"AWS.RoboMaker.delete_world_template/3","type":"function"},{"doc":"Deregisters a robot.\n\nThis API will no longer be supported as of May 2, 2022. Use it to remove\nresources that were created for Deployment Service.","ref":"AWS.RoboMaker.html#deregister_robot/3","title":"AWS.RoboMaker.deregister_robot/3","type":"function"},{"doc":"Describes a deployment job.\n\nThis API will no longer be supported as of May 2, 2022. Use it to remove\nresources that were created for Deployment Service.","ref":"AWS.RoboMaker.html#describe_deployment_job/3","title":"AWS.RoboMaker.describe_deployment_job/3","type":"function"},{"doc":"Describes a fleet.\n\nThis API will no longer be supported as of May 2, 2022. Use it to remove\nresources that were created for Deployment Service.","ref":"AWS.RoboMaker.html#describe_fleet/3","title":"AWS.RoboMaker.describe_fleet/3","type":"function"},{"doc":"Describes a robot.\n\nThis API will no longer be supported as of May 2, 2022. Use it to remove\nresources that were created for Deployment Service.","ref":"AWS.RoboMaker.html#describe_robot/3","title":"AWS.RoboMaker.describe_robot/3","type":"function"},{"doc":"Describes a robot application.","ref":"AWS.RoboMaker.html#describe_robot_application/3","title":"AWS.RoboMaker.describe_robot_application/3","type":"function"},{"doc":"Describes a simulation application.","ref":"AWS.RoboMaker.html#describe_simulation_application/3","title":"AWS.RoboMaker.describe_simulation_application/3","type":"function"},{"doc":"Describes a simulation job.","ref":"AWS.RoboMaker.html#describe_simulation_job/3","title":"AWS.RoboMaker.describe_simulation_job/3","type":"function"},{"doc":"Describes a simulation job batch.","ref":"AWS.RoboMaker.html#describe_simulation_job_batch/3","title":"AWS.RoboMaker.describe_simulation_job_batch/3","type":"function"},{"doc":"Describes a world.","ref":"AWS.RoboMaker.html#describe_world/3","title":"AWS.RoboMaker.describe_world/3","type":"function"},{"doc":"Describes a world export job.","ref":"AWS.RoboMaker.html#describe_world_export_job/3","title":"AWS.RoboMaker.describe_world_export_job/3","type":"function"},{"doc":"Describes a world generation job.","ref":"AWS.RoboMaker.html#describe_world_generation_job/3","title":"AWS.RoboMaker.describe_world_generation_job/3","type":"function"},{"doc":"Describes a world template.","ref":"AWS.RoboMaker.html#describe_world_template/3","title":"AWS.RoboMaker.describe_world_template/3","type":"function"},{"doc":"Gets the world template body.","ref":"AWS.RoboMaker.html#get_world_template_body/3","title":"AWS.RoboMaker.get_world_template_body/3","type":"function"},{"doc":"Returns a list of deployment jobs for a fleet.\n\nYou can optionally provide filters to retrieve specific deployment jobs.\n\nThis API will no longer be supported as of May 2, 2022. Use it to remove\nresources that were created for Deployment Service.","ref":"AWS.RoboMaker.html#list_deployment_jobs/3","title":"AWS.RoboMaker.list_deployment_jobs/3","type":"function"},{"doc":"Returns a list of fleets.\n\nYou can optionally provide filters to retrieve specific fleets.\n\nThis API will no longer be supported as of May 2, 2022. Use it to remove\nresources that were created for Deployment Service.","ref":"AWS.RoboMaker.html#list_fleets/3","title":"AWS.RoboMaker.list_fleets/3","type":"function"},{"doc":"Returns a list of robot application.\n\nYou can optionally provide filters to retrieve specific robot applications.","ref":"AWS.RoboMaker.html#list_robot_applications/3","title":"AWS.RoboMaker.list_robot_applications/3","type":"function"},{"doc":"Returns a list of robots.\n\nYou can optionally provide filters to retrieve specific robots.\n\nThis API will no longer be supported as of May 2, 2022. Use it to remove\nresources that were created for Deployment Service.","ref":"AWS.RoboMaker.html#list_robots/3","title":"AWS.RoboMaker.list_robots/3","type":"function"},{"doc":"Returns a list of simulation applications.\n\nYou can optionally provide filters to retrieve specific simulation applications.","ref":"AWS.RoboMaker.html#list_simulation_applications/3","title":"AWS.RoboMaker.list_simulation_applications/3","type":"function"},{"doc":"Returns a list simulation job batches.\n\nYou can optionally provide filters to retrieve specific simulation batch jobs.","ref":"AWS.RoboMaker.html#list_simulation_job_batches/3","title":"AWS.RoboMaker.list_simulation_job_batches/3","type":"function"},{"doc":"Returns a list of simulation jobs.\n\nYou can optionally provide filters to retrieve specific simulation jobs.","ref":"AWS.RoboMaker.html#list_simulation_jobs/3","title":"AWS.RoboMaker.list_simulation_jobs/3","type":"function"},{"doc":"Lists all tags on a AWS RoboMaker resource.","ref":"AWS.RoboMaker.html#list_tags_for_resource/3","title":"AWS.RoboMaker.list_tags_for_resource/3","type":"function"},{"doc":"Lists world export jobs.","ref":"AWS.RoboMaker.html#list_world_export_jobs/3","title":"AWS.RoboMaker.list_world_export_jobs/3","type":"function"},{"doc":"Lists world generator jobs.","ref":"AWS.RoboMaker.html#list_world_generation_jobs/3","title":"AWS.RoboMaker.list_world_generation_jobs/3","type":"function"},{"doc":"Lists world templates.","ref":"AWS.RoboMaker.html#list_world_templates/3","title":"AWS.RoboMaker.list_world_templates/3","type":"function"},{"doc":"Lists worlds.","ref":"AWS.RoboMaker.html#list_worlds/3","title":"AWS.RoboMaker.list_worlds/3","type":"function"},{"doc":"","ref":"AWS.RoboMaker.html#metadata/0","title":"AWS.RoboMaker.metadata/0","type":"function"},{"doc":"Registers a robot with a fleet.\n\nThis API is no longer supported and will throw an error if used.","ref":"AWS.RoboMaker.html#register_robot/3","title":"AWS.RoboMaker.register_robot/3","type":"function"},{"doc":"Restarts a running simulation job.","ref":"AWS.RoboMaker.html#restart_simulation_job/3","title":"AWS.RoboMaker.restart_simulation_job/3","type":"function"},{"doc":"Starts a new simulation job batch.\n\nThe batch is defined using one or more `SimulationJobRequest` objects.","ref":"AWS.RoboMaker.html#start_simulation_job_batch/3","title":"AWS.RoboMaker.start_simulation_job_batch/3","type":"function"},{"doc":"Syncrhonizes robots in a fleet to the latest deployment.\n\nThis is helpful if robots were added after a deployment.\n\nThis API will no longer be supported as of May 2, 2022. Use it to remove\nresources that were created for Deployment Service.","ref":"AWS.RoboMaker.html#sync_deployment_job/3","title":"AWS.RoboMaker.sync_deployment_job/3","type":"function"},{"doc":"Adds or edits tags for a AWS RoboMaker resource.\n\nEach tag consists of a tag key and a tag value. Tag keys and tag values are both\nrequired, but tag values can be empty strings.\n\nFor information about the rules that apply to tag keys and tag values, see\n[User-Defined Tag Restrictions](https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/allocation-tag-restrictions.html)\nin the *AWS Billing and Cost Management User Guide*.","ref":"AWS.RoboMaker.html#tag_resource/4","title":"AWS.RoboMaker.tag_resource/4","type":"function"},{"doc":"Removes the specified tags from the specified AWS RoboMaker resource.\n\nTo remove a tag, specify the tag key. To change the tag value of an existing tag\nkey, use [ `TagResource`\n](https://docs.aws.amazon.com/robomaker/latest/dg/API_TagResource.html).","ref":"AWS.RoboMaker.html#untag_resource/4","title":"AWS.RoboMaker.untag_resource/4","type":"function"},{"doc":"Updates a robot application.","ref":"AWS.RoboMaker.html#update_robot_application/3","title":"AWS.RoboMaker.update_robot_application/3","type":"function"},{"doc":"Updates a simulation application.","ref":"AWS.RoboMaker.html#update_simulation_application/3","title":"AWS.RoboMaker.update_simulation_application/3","type":"function"},{"doc":"Updates a world template.","ref":"AWS.RoboMaker.html#update_world_template/3","title":"AWS.RoboMaker.update_world_template/3","type":"function"},{"doc":"Identity and Access Management Roles Anywhere provides a secure way for your\nworkloads such as servers, containers, and applications that run outside of\nAmazon Web Services to obtain temporary Amazon Web Services credentials.\n\nYour workloads can use the same IAM policies and roles you have for native\nAmazon Web Services applications to access Amazon Web Services resources. Using\nIAM Roles Anywhere eliminates the need to manage long-term credentials for\nworkloads running outside of Amazon Web Services.\n\nTo use IAM Roles Anywhere, your workloads must use X.509 certificates issued by\ntheir certificate authority (CA). You register the CA with IAM Roles Anywhere as\na trust anchor to establish trust between your public key infrastructure (PKI)\nand IAM Roles Anywhere. If you don't manage your own PKI system, you can use\nPrivate Certificate Authority to create a CA and then use that to establish\ntrust with IAM Roles Anywhere.\n\nThis guide describes the IAM Roles Anywhere operations that you can call\nprogrammatically. For more information about IAM Roles Anywhere, see the [IAM Roles Anywhere User\nGuide](https://docs.aws.amazon.com/rolesanywhere/latest/userguide/introduction.html).","ref":"AWS.RolesAnywhere.html","title":"AWS.RolesAnywhere","type":"module"},{"doc":"Creates a *profile*, a list of the roles that Roles Anywhere service is trusted\nto assume.\n\nYou use profiles to intersect permissions with IAM managed policies.\n\n**Required permissions: ** `rolesanywhere:CreateProfile`.","ref":"AWS.RolesAnywhere.html#create_profile/3","title":"AWS.RolesAnywhere.create_profile/3","type":"function"},{"doc":"Creates a trust anchor to establish trust between IAM Roles Anywhere and your\ncertificate authority (CA).\n\nYou can define a trust anchor as a reference to an Private Certificate Authority\n(Private CA) or by uploading a CA certificate. Your Amazon Web Services\nworkloads can authenticate with the trust anchor using certificates issued by\nthe CA in exchange for temporary Amazon Web Services credentials.\n\n**Required permissions: ** `rolesanywhere:CreateTrustAnchor`.","ref":"AWS.RolesAnywhere.html#create_trust_anchor/3","title":"AWS.RolesAnywhere.create_trust_anchor/3","type":"function"},{"doc":"Deletes a certificate revocation list (CRL).\n\n**Required permissions: ** `rolesanywhere:DeleteCrl`.","ref":"AWS.RolesAnywhere.html#delete_crl/4","title":"AWS.RolesAnywhere.delete_crl/4","type":"function"},{"doc":"Deletes a profile.\n\n**Required permissions: ** `rolesanywhere:DeleteProfile`.","ref":"AWS.RolesAnywhere.html#delete_profile/4","title":"AWS.RolesAnywhere.delete_profile/4","type":"function"},{"doc":"Deletes a trust anchor.\n\n**Required permissions: ** `rolesanywhere:DeleteTrustAnchor`.","ref":"AWS.RolesAnywhere.html#delete_trust_anchor/4","title":"AWS.RolesAnywhere.delete_trust_anchor/4","type":"function"},{"doc":"Disables a certificate revocation list (CRL).\n\n**Required permissions: ** `rolesanywhere:DisableCrl`.","ref":"AWS.RolesAnywhere.html#disable_crl/4","title":"AWS.RolesAnywhere.disable_crl/4","type":"function"},{"doc":"Disables a profile.\n\nWhen disabled, temporary credential requests with this profile fail.\n\n**Required permissions: ** `rolesanywhere:DisableProfile`.","ref":"AWS.RolesAnywhere.html#disable_profile/4","title":"AWS.RolesAnywhere.disable_profile/4","type":"function"},{"doc":"Disables a trust anchor.\n\nWhen disabled, temporary credential requests specifying this trust anchor are\nunauthorized.\n\n**Required permissions: ** `rolesanywhere:DisableTrustAnchor`.","ref":"AWS.RolesAnywhere.html#disable_trust_anchor/4","title":"AWS.RolesAnywhere.disable_trust_anchor/4","type":"function"},{"doc":"Enables a certificate revocation list (CRL).\n\nWhen enabled, certificates stored in the CRL are unauthorized to receive session\ncredentials.\n\n**Required permissions: ** `rolesanywhere:EnableCrl`.","ref":"AWS.RolesAnywhere.html#enable_crl/4","title":"AWS.RolesAnywhere.enable_crl/4","type":"function"},{"doc":"Enables temporary credential requests for a profile.\n\n**Required permissions: ** `rolesanywhere:EnableProfile`.","ref":"AWS.RolesAnywhere.html#enable_profile/4","title":"AWS.RolesAnywhere.enable_profile/4","type":"function"},{"doc":"Enables a trust anchor.\n\nWhen enabled, certificates in the trust anchor chain are authorized for trust\nvalidation.\n\n**Required permissions: ** `rolesanywhere:EnableTrustAnchor`.","ref":"AWS.RolesAnywhere.html#enable_trust_anchor/4","title":"AWS.RolesAnywhere.enable_trust_anchor/4","type":"function"},{"doc":"Gets a certificate revocation list (CRL).\n\n**Required permissions: ** `rolesanywhere:GetCrl`.","ref":"AWS.RolesAnywhere.html#get_crl/3","title":"AWS.RolesAnywhere.get_crl/3","type":"function"},{"doc":"Gets a profile.\n\n**Required permissions: ** `rolesanywhere:GetProfile`.","ref":"AWS.RolesAnywhere.html#get_profile/3","title":"AWS.RolesAnywhere.get_profile/3","type":"function"},{"doc":"Gets a *subject*, which associates a certificate identity with authentication\nattempts.\n\nThe subject stores auditing information such as the status of the last\nauthentication attempt, the certificate data used in the attempt, and the last\ntime the associated identity attempted authentication.\n\n**Required permissions: ** `rolesanywhere:GetSubject`.","ref":"AWS.RolesAnywhere.html#get_subject/3","title":"AWS.RolesAnywhere.get_subject/3","type":"function"},{"doc":"Gets a trust anchor.\n\n**Required permissions: ** `rolesanywhere:GetTrustAnchor`.","ref":"AWS.RolesAnywhere.html#get_trust_anchor/3","title":"AWS.RolesAnywhere.get_trust_anchor/3","type":"function"},{"doc":"Imports the certificate revocation list (CRL).\n\nA CRL is a list of certificates that have been revoked by the issuing\ncertificate Authority (CA). IAM Roles Anywhere validates against the CRL before\nissuing credentials.\n\n**Required permissions: ** `rolesanywhere:ImportCrl`.","ref":"AWS.RolesAnywhere.html#import_crl/3","title":"AWS.RolesAnywhere.import_crl/3","type":"function"},{"doc":"Lists all certificate revocation lists (CRL) in the authenticated account and\nAmazon Web Services Region.\n\n**Required permissions: ** `rolesanywhere:ListCrls`.","ref":"AWS.RolesAnywhere.html#list_crls/4","title":"AWS.RolesAnywhere.list_crls/4","type":"function"},{"doc":"Lists all profiles in the authenticated account and Amazon Web Services Region.\n\n**Required permissions: ** `rolesanywhere:ListProfiles`.","ref":"AWS.RolesAnywhere.html#list_profiles/4","title":"AWS.RolesAnywhere.list_profiles/4","type":"function"},{"doc":"Lists the subjects in the authenticated account and Amazon Web Services Region.\n\n**Required permissions: ** `rolesanywhere:ListSubjects`.","ref":"AWS.RolesAnywhere.html#list_subjects/4","title":"AWS.RolesAnywhere.list_subjects/4","type":"function"},{"doc":"Lists the tags attached to the resource.\n\n**Required permissions: ** `rolesanywhere:ListTagsForResource`.","ref":"AWS.RolesAnywhere.html#list_tags_for_resource/3","title":"AWS.RolesAnywhere.list_tags_for_resource/3","type":"function"},{"doc":"Lists the trust anchors in the authenticated account and Amazon Web Services\nRegion.\n\n**Required permissions: ** `rolesanywhere:ListTrustAnchors`.","ref":"AWS.RolesAnywhere.html#list_trust_anchors/4","title":"AWS.RolesAnywhere.list_trust_anchors/4","type":"function"},{"doc":"","ref":"AWS.RolesAnywhere.html#metadata/0","title":"AWS.RolesAnywhere.metadata/0","type":"function"},{"doc":"Attaches a list of *notification settings* to a trust anchor.\n\nA notification setting includes information such as event name, threshold,\nstatus of the notification setting, and the channel to notify.\n\n**Required permissions: ** `rolesanywhere:PutNotificationSettings`.","ref":"AWS.RolesAnywhere.html#put_notification_settings/3","title":"AWS.RolesAnywhere.put_notification_settings/3","type":"function"},{"doc":"Resets the *custom notification setting* to IAM Roles Anywhere default setting.\n\n**Required permissions: ** `rolesanywhere:ResetNotificationSettings`.","ref":"AWS.RolesAnywhere.html#reset_notification_settings/3","title":"AWS.RolesAnywhere.reset_notification_settings/3","type":"function"},{"doc":"Attaches tags to a resource.\n\n**Required permissions: ** `rolesanywhere:TagResource`.","ref":"AWS.RolesAnywhere.html#tag_resource/3","title":"AWS.RolesAnywhere.tag_resource/3","type":"function"},{"doc":"Removes tags from the resource.\n\n**Required permissions: ** `rolesanywhere:UntagResource`.","ref":"AWS.RolesAnywhere.html#untag_resource/3","title":"AWS.RolesAnywhere.untag_resource/3","type":"function"},{"doc":"Updates the certificate revocation list (CRL).\n\nA CRL is a list of certificates that have been revoked by the issuing\ncertificate authority (CA). IAM Roles Anywhere validates against the CRL before\nissuing credentials.\n\n**Required permissions: ** `rolesanywhere:UpdateCrl`.","ref":"AWS.RolesAnywhere.html#update_crl/4","title":"AWS.RolesAnywhere.update_crl/4","type":"function"},{"doc":"Updates a *profile*, a list of the roles that IAM Roles Anywhere service is\ntrusted to assume.\n\nYou use profiles to intersect permissions with IAM managed policies.\n\n**Required permissions: ** `rolesanywhere:UpdateProfile`.","ref":"AWS.RolesAnywhere.html#update_profile/4","title":"AWS.RolesAnywhere.update_profile/4","type":"function"},{"doc":"Updates a trust anchor.\n\nYou establish trust between IAM Roles Anywhere and your certificate authority\n(CA) by configuring a trust anchor. You can define a trust anchor as a reference\nto an Private Certificate Authority (Private CA) or by uploading a CA\ncertificate. Your Amazon Web Services workloads can authenticate with the trust\nanchor using certificates issued by the CA in exchange for temporary Amazon Web\nServices credentials.\n\n**Required permissions: ** `rolesanywhere:UpdateTrustAnchor`.","ref":"AWS.RolesAnywhere.html#update_trust_anchor/4","title":"AWS.RolesAnywhere.update_trust_anchor/4","type":"function"},{"doc":"Amazon Route 53 is a highly available and scalable Domain Name System (DNS) web\nservice.\n\nYou can use Route 53 to:\n\n  * Register domain names.\n\nFor more information, see [How domain registration works](https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/welcome-domain-registration.html).\n\n  * Route internet traffic to the resources for your domain\n\nFor more information, see [How internet traffic is routed to your website or web application](https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/welcome-dns-service.html).\n\n  * Check the health of your resources.\n\nFor more information, see [How Route 53 checks the health of your resources](https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/welcome-health-checks.html).","ref":"AWS.Route53.html","title":"AWS.Route53","type":"module"},{"doc":"Activates a key-signing key (KSK) so that it can be used for signing by DNSSEC.\n\nThis operation changes the KSK status to `ACTIVE`.","ref":"AWS.Route53.html#activate_key_signing_key/5","title":"AWS.Route53.activate_key_signing_key/5","type":"function"},{"doc":"Associates an Amazon VPC with a private hosted zone.\n\nTo perform the association, the VPC and the private hosted zone must already\nexist. You can't convert a public hosted zone into a private hosted zone.\n\nIf you want to associate a VPC that was created by using one Amazon Web Services\naccount with a private hosted zone that was created by using a different\naccount, the Amazon Web Services account that created the private hosted zone\nmust first submit a `CreateVPCAssociationAuthorization` request. Then the\naccount that created the VPC must submit an `AssociateVPCWithHostedZone`\nrequest.\n\nWhen granting access, the hosted zone and the Amazon VPC must belong to the same\npartition. A partition is a group of Amazon Web Services Regions. Each Amazon\nWeb Services account is scoped to one partition.\n\nThe following are the supported partitions:\n\n   `aws` - Amazon Web Services Regions\n\n   `aws-cn` - China Regions\n\n   `aws-us-gov` - Amazon Web Services GovCloud (US) Region\n\nFor more information, see [Access Management](https://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html)\nin the *Amazon Web Services General Reference*.","ref":"AWS.Route53.html#associate_vpc_with_hosted_zone/4","title":"AWS.Route53.associate_vpc_with_hosted_zone/4","type":"function"},{"doc":"Creates, changes, or deletes CIDR blocks within a collection.\n\nContains authoritative IP information mapping blocks to one or multiple\nlocations.\n\nA change request can update multiple locations in a collection at a time, which\nis helpful if you want to move one or more CIDR blocks from one location to\nanother in one transaction, without downtime.","ref":"AWS.Route53.html#change_cidr_collection/4","title":"AWS.Route53.change_cidr_collection/4","type":"function"},{"doc":"The max number of CIDR blocks included in the request is 1000. As a result, big\nupdates require multiple API calls.\n\n##  PUT and DELETE_IF_EXISTS\n\nUse `ChangeCidrCollection` to perform the following actions:\n\n  * `PUT`: Create a CIDR block within the specified collection.\n\n  * ` DELETE_IF_EXISTS`: Delete an existing CIDR block from the\ncollection.","ref":"AWS.Route53.html#change_cidr_collection/4-limits","title":"Limits - AWS.Route53.change_cidr_collection/4","type":"function"},{"doc":"Creates, changes, or deletes a resource record set, which contains authoritative\nDNS information for a specified domain name or subdomain name.\n\nFor example, you can use `ChangeResourceRecordSets` to create a resource record\nset that routes traffic for test.example.com to a web server that has an IP\naddress of 192.0.2.44.","ref":"AWS.Route53.html#change_resource_record_sets/4","title":"AWS.Route53.change_resource_record_sets/4","type":"function"},{"doc":"To delete a resource record set, you must specify all the same values that you\nspecified when you created it.","ref":"AWS.Route53.html#change_resource_record_sets/4-deleting-resource-record-sets","title":"Deleting Resource Record Sets - AWS.Route53.change_resource_record_sets/4","type":"function"},{"doc":"The request body must include a document with a\n`ChangeResourceRecordSetsRequest` element. The request body contains a list of\nchange items, known as a change batch. Change batches are considered\ntransactional changes. Route 53 validates the changes in the request and then\neither makes all or none of the changes in the change batch request. This\nensures that DNS routing isn't adversely affected by partial changes to the\nresource record sets in a hosted zone.\n\nFor example, suppose a change batch request contains two changes: it deletes the\n`CNAME` resource record set for www.example.com and creates an alias resource\nrecord set for www.example.com. If validation for both records succeeds, Route\n53 deletes the first resource record set and creates the second resource record\nset in a single operation. If validation for either the `DELETE` or the `CREATE`\naction fails, then the request is canceled, and the original `CNAME` record\ncontinues to exist.\n\nIf you try to delete the same resource record set more than once in a single\nchange batch, Route 53 returns an `InvalidChangeBatch` error.","ref":"AWS.Route53.html#change_resource_record_sets/4-change-batches-and-transactional-changes","title":"Change Batches and Transactional Changes - AWS.Route53.change_resource_record_sets/4","type":"function"},{"doc":"To create resource record sets for complex routing configurations, use either\nthe traffic flow visual editor in the Route 53 console or the API actions for\ntraffic policies and traffic policy instances. Save the configuration as a\ntraffic policy, then associate the traffic policy with one or more domain names\n(such as example.com) or subdomain names (such as www.example.com), in the same\nhosted zone or in multiple hosted zones. You can roll back the updates if the\nnew configuration isn't performing as expected. For more information, see [Using Traffic Flow to Route DNS\nTraffic](https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/traffic-flow.html)\nin the *Amazon Route 53 Developer Guide*.","ref":"AWS.Route53.html#change_resource_record_sets/4-traffic-flow","title":"Traffic Flow - AWS.Route53.change_resource_record_sets/4","type":"function"},{"doc":"Use `ChangeResourceRecordsSetsRequest` to perform the following actions:\n\n  * `CREATE`: Creates a resource record set that has the specified\nvalues.\n\n  * `DELETE`: Deletes an existing resource record set that has the\nspecified values.\n\n  * `UPSERT`: If a resource set doesn't exist, Route 53 creates it. If\na resource set exists Route 53 updates it with the values in the request.","ref":"AWS.Route53.html#change_resource_record_sets/4-create-delete-and-upsert","title":"Create, Delete, and Upsert - AWS.Route53.change_resource_record_sets/4","type":"function"},{"doc":"The syntax for a request depends on the type of resource record set that you\nwant to create, delete, or update, such as weighted, alias, or failover. The XML\nelements in your request must appear in the order listed in the syntax.\n\nFor an example for each type of resource record set, see \"Examples.\"\n\nDon't refer to the syntax in the \"Parameter Syntax\" section, which includes all\nof the elements for every kind of resource record set that you can create,\ndelete, or update by using `ChangeResourceRecordSets`.","ref":"AWS.Route53.html#change_resource_record_sets/4-syntaxes-for-creating-updating-and-deleting-resource-record-sets","title":"Syntaxes for Creating, Updating, and Deleting Resource Record Sets - AWS.Route53.change_resource_record_sets/4","type":"function"},{"doc":"When you submit a `ChangeResourceRecordSets` request, Route 53 propagates your\nchanges to all of the Route 53 authoritative DNS servers managing the hosted\nzone. While your changes are propagating, `GetChange` returns a status of\n`PENDING`. When propagation is complete, `GetChange` returns a status of\n`INSYNC`. Changes generally propagate to all Route 53 name servers managing the\nhosted zone within 60 seconds. For more information, see\n[GetChange](https://docs.aws.amazon.com/Route53/latest/APIReference/API_GetChange.html).","ref":"AWS.Route53.html#change_resource_record_sets/4-change-propagation-to-route-53-dns-servers","title":"Change Propagation to Route 53 DNS Servers - AWS.Route53.change_resource_record_sets/4","type":"function"},{"doc":"For information about the limits on a `ChangeResourceRecordSets` request, see\n[Limits](https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/DNSLimitations.html)\nin the *Amazon Route 53 Developer Guide*.","ref":"AWS.Route53.html#change_resource_record_sets/4-limits-on-changeresourcerecordsets-requests","title":"Limits on ChangeResourceRecordSets Requests - AWS.Route53.change_resource_record_sets/4","type":"function"},{"doc":"Adds, edits, or deletes tags for a health check or a hosted zone.\n\nFor information about using tags for cost allocation, see [Using Cost Allocation Tags](https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/cost-alloc-tags.html)\nin the *Billing and Cost Management User Guide*.","ref":"AWS.Route53.html#change_tags_for_resource/5","title":"AWS.Route53.change_tags_for_resource/5","type":"function"},{"doc":"Creates a CIDR collection in the current Amazon Web Services account.","ref":"AWS.Route53.html#create_cidr_collection/3","title":"AWS.Route53.create_cidr_collection/3","type":"function"},{"doc":"Creates a new health check.\n\nFor information about adding health checks to resource record sets, see\n[HealthCheckId](https://docs.aws.amazon.com/Route53/latest/APIReference/API_ResourceRecordSet.html#Route53-Type-ResourceRecordSet-HealthCheckId) in\n[ChangeResourceRecordSets](https://docs.aws.amazon.com/Route53/latest/APIReference/API_ChangeResourceRecordSets.html).","ref":"AWS.Route53.html#create_health_check/3","title":"AWS.Route53.create_health_check/3","type":"function"},{"doc":"If you're registering EC2 instances with an Elastic Load Balancing (ELB) load\nbalancer, do not create Amazon Route 53 health checks for the EC2 instances.\nWhen you register an EC2 instance with a load balancer, you configure settings\nfor an ELB health check, which performs a similar function to a Route 53 health\ncheck.","ref":"AWS.Route53.html#create_health_check/3-elb-load-balancers","title":"ELB Load Balancers - AWS.Route53.create_health_check/3","type":"function"},{"doc":"You can associate health checks with failover resource record sets in a private\nhosted zone. Note the following:\n\n  * Route 53 health checkers are outside the VPC. To check the health\nof an endpoint within a VPC by IP address, you must assign a public IP address\nto the instance in the VPC.\n\n  * You can configure a health checker to check the health of an\nexternal resource that the instance relies on, such as a database server.\n\n  * You can create a CloudWatch metric, associate an alarm with the\nmetric, and then create a health check that is based on the state of the alarm.\nFor example, you might create a CloudWatch metric that checks the status of the\nAmazon EC2 `StatusCheckFailed` metric, add an alarm to the metric, and then\ncreate a health check that is based on the state of the alarm. For information\nabout creating CloudWatch metrics and alarms by using the CloudWatch console,\nsee the [Amazon CloudWatch User Guide](https://docs.aws.amazon.com/AmazonCloudWatch/latest/DeveloperGuide/WhatIsCloudWatch.html).","ref":"AWS.Route53.html#create_health_check/3-private-hosted-zones","title":"Private Hosted Zones - AWS.Route53.create_health_check/3","type":"function"},{"doc":"Creates a new public or private hosted zone.\n\nYou create records in a public hosted zone to define how you want to route\ntraffic on the internet for a domain, such as example.com, and its subdomains\n(apex.example.com, acme.example.com). You create records in a private hosted\nzone to define how you want to route traffic for a domain and its subdomains\nwithin one or more Amazon Virtual Private Clouds (Amazon VPCs).\n\nYou can't convert a public hosted zone to a private hosted zone or vice versa.\nInstead, you must create a new hosted zone with the same name and create new\nresource record sets.\n\nFor more information about charges for hosted zones, see [Amazon Route 53 Pricing](http://aws.amazon.com/route53/pricing/).\n\nNote the following:\n\n  * You can't create a hosted zone for a top-level domain (TLD) such\nas .com.\n\n  * For public hosted zones, Route 53 automatically creates a default\nSOA record and four NS records for the zone. For more information about SOA and\nNS records, see [NS and SOA Records that Route 53 Creates for a Hosted Zone](https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/SOA-NSrecords.html)\nin the *Amazon Route 53 Developer Guide*.\n\nIf you want to use the same name servers for multiple public hosted zones, you\ncan optionally associate a reusable delegation set with the hosted zone. See the\n`DelegationSetId` element.\n\n  * If your domain is registered with a registrar other than Route 53,\nyou must update the name servers with your registrar to make Route 53 the DNS\nservice for the domain. For more information, see [Migrating DNS Service for an Existing Domain to Amazon\nRoute 53](https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/MigratingDNS.html)\nin the *Amazon Route 53 Developer Guide*.\n\nWhen you submit a `CreateHostedZone` request, the initial status of the hosted\nzone is `PENDING`. For public hosted zones, this means that the NS and SOA\nrecords are not yet available on all Route 53 DNS servers. When the NS and SOA\nrecords are available, the status of the zone changes to `INSYNC`.\n\nThe `CreateHostedZone` request requires the caller to have an `ec2:DescribeVpcs`\npermission.\n\nWhen creating private hosted zones, the Amazon VPC must belong to the same\npartition where the hosted zone is created. A partition is a group of Amazon Web\nServices Regions. Each Amazon Web Services account is scoped to one partition.\n\nThe following are the supported partitions:\n\n   `aws` - Amazon Web Services Regions\n\n   `aws-cn` - China Regions\n\n   `aws-us-gov` - Amazon Web Services GovCloud (US) Region\n\nFor more information, see [Access Management](https://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html)\nin the *Amazon Web Services General Reference*.","ref":"AWS.Route53.html#create_hosted_zone/3","title":"AWS.Route53.create_hosted_zone/3","type":"function"},{"doc":"Creates a new key-signing key (KSK) associated with a hosted zone.\n\nYou can only have two KSKs per hosted zone.","ref":"AWS.Route53.html#create_key_signing_key/3","title":"AWS.Route53.create_key_signing_key/3","type":"function"},{"doc":"Creates a configuration for DNS query logging.\n\nAfter you create a query logging configuration, Amazon Route 53 begins to\npublish log data to an Amazon CloudWatch Logs log group.\n\nDNS query logs contain information about the queries that Route 53 receives for\na specified public hosted zone, such as the following:\n\n  * Route 53 edge location that responded to the DNS query\n\n  * Domain or subdomain that was requested\n\n  * DNS record type, such as A or AAAA\n\n  * DNS response code, such as `NoError` or `ServFail`","ref":"AWS.Route53.html#create_query_logging_config/3","title":"AWS.Route53.create_query_logging_config/3","type":"function"},{"doc":"#","ref":"AWS.Route53.html#create_query_logging_config/3-definitions","title":"Definitions - AWS.Route53.create_query_logging_config/3","type":"function"},{"doc":"Before you create a query logging configuration, perform the following\noperations.\n\nIf you create a query logging configuration using the Route 53 console, Route 53\nperforms these operations automatically.\n\n   Create a CloudWatch Logs log group, and make note of the ARN, which\nyou specify when you create a query logging configuration. Note the following:\n\n     You must create the log group in the us-east-1 region.\n\n     You must use the same Amazon Web Services account to\ncreate the log group and the hosted zone that you want to configure query\nlogging for.\n\n     When you create log groups for query logging, we\nrecommend that you use a consistent prefix, for example:\n\n`/aws/route53/*hosted zone name* `\n\nIn the next step, you'll create a resource policy, which controls access to one\nor more log groups and the associated Amazon Web Services resources, such as\nRoute 53 hosted zones. There's a limit on the number of resource policies that\nyou can create, so we recommend that you use a consistent prefix so you can use\nthe same resource policy for all the log groups that you create for query\nlogging.\n\n   Create a CloudWatch Logs resource policy, and give it the\npermissions that Route 53 needs to create log streams and to send query logs to\nlog streams. For the value of `Resource`, specify the ARN for the log group that\nyou created in the previous step. To use the same resource policy for all the\nCloudWatch Logs log groups that you created for query logging configurations,\nreplace the hosted zone name with `*`, for example:\n\n`arn:aws:logs:us-east-1:123412341234:log-group:/aws/route53/*`\n\nTo avoid the confused deputy problem, a security issue where an entity without a\npermission for an action can coerce a more-privileged entity to perform it, you\ncan optionally limit the permissions that a service has to a resource in a\nresource-based policy by supplying the following values:\n\n     For `aws:SourceArn`, supply the hosted zone ARN used in\ncreating the query logging configuration. For example, `aws:SourceArn:\narn:aws:route53:::hostedzone/hosted zone ID`.\n\n     For `aws:SourceAccount`, supply the account ID for the\naccount that creates the query logging configuration. For example,\n`aws:SourceAccount:111111111111`.\n\nFor more information, see [The confused deputy problem](https://docs.aws.amazon.com/IAM/latest/UserGuide/confused-deputy.html)\nin the *Amazon Web Services IAM User Guide*.\n\nYou can't use the CloudWatch console to create or edit a resource policy. You\nmust use the CloudWatch API, one of the Amazon Web Services SDKs, or the CLI.\n\n#","ref":"AWS.Route53.html#create_query_logging_config/3-log-group-and-resource-policy","title":"Log Group and Resource Policy - AWS.Route53.create_query_logging_config/3","type":"function"},{"doc":"When Route 53 finishes creating the configuration for DNS query logging, it does\nthe following:\n\n   Creates a log stream for an edge location the first time that the\nedge location responds to DNS queries for the specified hosted zone. That log\nstream is used to log all queries that Route 53 responds to for that edge\nlocation.\n\n   Begins to send query logs to the applicable log stream.\n\nThe name of each log stream is in the following format:\n\n` *hosted zone ID*/*edge location code* `\n\nThe edge location code is a three-letter code and an arbitrarily assigned\nnumber, for example, DFW3. The three-letter code typically corresponds with the\nInternational Air Transport Association airport code for an airport near the\nedge location. (These abbreviations might change in the future.) For a list of\nedge locations, see \"The Route 53 Global Network\" on the [Route 53 Product Details](http://aws.amazon.com/route53/details/) page.\n\n#","ref":"AWS.Route53.html#create_query_logging_config/3-log-streams-and-edge-locations","title":"Log Streams and Edge Locations - AWS.Route53.create_query_logging_config/3","type":"function"},{"doc":"Query logs contain only the queries that DNS resolvers forward to Route 53. If a\nDNS resolver has already cached the response to a query (such as the IP address\nfor a load balancer for example.com), the resolver will continue to return the\ncached response. It doesn't forward another query to Route 53 until the TTL for\nthe corresponding resource record set expires. Depending on how many DNS queries\nare submitted for a resource record set, and depending on the TTL for that\nresource record set, query logs might contain information about only one query\nout of every several thousand queries that are submitted to DNS. For more\ninformation about how DNS works, see [Routing Internet Traffic to Your Website or Web\nApplication](https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/welcome-dns-service.html)\nin the *Amazon Route 53 Developer Guide*.\n\n#","ref":"AWS.Route53.html#create_query_logging_config/3-queries-that-are-logged","title":"Queries That Are Logged - AWS.Route53.create_query_logging_config/3","type":"function"},{"doc":"For a list of the values in each query log and the format of each value, see\n[Logging DNS Queries](https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/query-logs.html)\nin the *Amazon Route 53 Developer Guide*.\n\n#","ref":"AWS.Route53.html#create_query_logging_config/3-log-file-format","title":"Log File Format - AWS.Route53.create_query_logging_config/3","type":"function"},{"doc":"For information about charges for query logs, see [Amazon CloudWatch Pricing](http://aws.amazon.com/cloudwatch/pricing/).\n\n#","ref":"AWS.Route53.html#create_query_logging_config/3-pricing","title":"Pricing - AWS.Route53.create_query_logging_config/3","type":"function"},{"doc":"If you want Route 53 to stop sending query logs to CloudWatch Logs, delete the\nquery logging configuration. For more information, see\n[DeleteQueryLoggingConfig](https://docs.aws.amazon.com/Route53/latest/APIReference/API_DeleteQueryLoggingConfig.html).","ref":"AWS.Route53.html#create_query_logging_config/3-how-to-stop-logging","title":"How to Stop Logging - AWS.Route53.create_query_logging_config/3","type":"function"},{"doc":"Creates a delegation set (a group of four name servers) that can be reused by\nmultiple hosted zones that were created by the same Amazon Web Services account.\n\nYou can also create a reusable delegation set that uses the four name servers\nthat are associated with an existing hosted zone. Specify the hosted zone ID in\nthe `CreateReusableDelegationSet` request.\n\nYou can't associate a reusable delegation set with a private hosted zone.\n\nFor information about using a reusable delegation set to configure white label\nname servers, see [Configuring White Label Name Servers](https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/white-label-name-servers.html).\n\nThe process for migrating existing hosted zones to use a reusable delegation set\nis comparable to the process for configuring white label name servers. You need\nto perform the following steps:\n\n  1. Create a reusable delegation set.\n\n  2. Recreate hosted zones, and reduce the TTL to 60 seconds or less.\n\n  3. Recreate resource record sets in the new hosted zones.\n\n  4. Change the registrar's name servers to use the name servers for\nthe new hosted zones.\n\n  5. Monitor traffic for the website or application.\n\n  6. Change TTLs back to their original values.\n\nIf you want to migrate existing hosted zones to use a reusable delegation set,\nthe existing hosted zones can't use any of the name servers that are assigned to\nthe reusable delegation set. If one or more hosted zones do use one or more name\nservers that are assigned to the reusable delegation set, you can do one of the\nfollowing:\n\n  * For small numbers of hosted zones—up to a few hundred—it's\nrelatively easy to create reusable delegation sets until you get one that has\nfour name servers that don't overlap with any of the name servers in your hosted\nzones.\n\n  * For larger numbers of hosted zones, the easiest solution is to use\nmore than one reusable delegation set.\n\n  * For larger numbers of hosted zones, you can also migrate hosted\nzones that have overlapping name servers to hosted zones that don't have\noverlapping name servers, then migrate the hosted zones again to use the\nreusable delegation set.","ref":"AWS.Route53.html#create_reusable_delegation_set/3","title":"AWS.Route53.create_reusable_delegation_set/3","type":"function"},{"doc":"Creates a traffic policy, which you use to create multiple DNS resource record\nsets for one domain name (such as example.com) or one subdomain name (such as\nwww.example.com).","ref":"AWS.Route53.html#create_traffic_policy/3","title":"AWS.Route53.create_traffic_policy/3","type":"function"},{"doc":"Creates resource record sets in a specified hosted zone based on the settings in\na specified traffic policy version.\n\nIn addition, `CreateTrafficPolicyInstance` associates the resource record sets\nwith a specified domain name (such as example.com) or subdomain name (such as\nwww.example.com). Amazon Route 53 responds to DNS queries for the domain or\nsubdomain name by using the resource record sets that\n`CreateTrafficPolicyInstance` created.\n\nAfter you submit an `CreateTrafficPolicyInstance` request, there's a brief delay\nwhile Amazon Route 53 creates the resource record sets that are specified in the\ntraffic policy definition. Use `GetTrafficPolicyInstance` with the `id` of new\ntraffic policy instance to confirm that the `CreateTrafficPolicyInstance`\nrequest completed successfully. For more information, see the `State` response\nelement.","ref":"AWS.Route53.html#create_traffic_policy_instance/3","title":"AWS.Route53.create_traffic_policy_instance/3","type":"function"},{"doc":"Creates a new version of an existing traffic policy.\n\nWhen you create a new version of a traffic policy, you specify the ID of the\ntraffic policy that you want to update and a JSON-formatted document that\ndescribes the new version. You use traffic policies to create multiple DNS\nresource record sets for one domain name (such as example.com) or one subdomain\nname (such as www.example.com). You can create a maximum of 1000 versions of a\ntraffic policy. If you reach the limit and need to create another version,\nyou'll need to start a new traffic policy.","ref":"AWS.Route53.html#create_traffic_policy_version/4","title":"AWS.Route53.create_traffic_policy_version/4","type":"function"},{"doc":"Authorizes the Amazon Web Services account that created a specified VPC to\nsubmit an `AssociateVPCWithHostedZone` request to associate the VPC with a\nspecified hosted zone that was created by a different account.\n\nTo submit a `CreateVPCAssociationAuthorization` request, you must use the\naccount that created the hosted zone. After you authorize the association, use\nthe account that created the VPC to submit an `AssociateVPCWithHostedZone`\nrequest.\n\nIf you want to associate multiple VPCs that you created by using one account\nwith a hosted zone that you created by using a different account, you must\nsubmit one authorization request for each VPC.","ref":"AWS.Route53.html#create_vpc_association_authorization/4","title":"AWS.Route53.create_vpc_association_authorization/4","type":"function"},{"doc":"Deactivates a key-signing key (KSK) so that it will not be used for signing by\nDNSSEC.\n\nThis operation changes the KSK status to `INACTIVE`.","ref":"AWS.Route53.html#deactivate_key_signing_key/5","title":"AWS.Route53.deactivate_key_signing_key/5","type":"function"},{"doc":"Deletes a CIDR collection in the current Amazon Web Services account.\n\nThe collection must be empty before it can be deleted.","ref":"AWS.Route53.html#delete_cidr_collection/4","title":"AWS.Route53.delete_cidr_collection/4","type":"function"},{"doc":"Deletes a health check.\n\nAmazon Route 53 does not prevent you from deleting a health check even if the\nhealth check is associated with one or more resource record sets. If you delete\na health check and you don't update the associated resource record sets, the\nfuture status of the health check can't be predicted and may change. This will\naffect the routing of DNS queries for your DNS failover configuration. For more\ninformation, see [Replacing and Deleting Health Checks](https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/health-checks-creating-deleting.html#health-checks-deleting.html)\nin the *Amazon Route 53 Developer Guide*.\n\nIf you're using Cloud Map and you configured Cloud Map to create a Route 53\nhealth check when you register an instance, you can't use the Route 53\n`DeleteHealthCheck` command to delete the health check. The health check is\ndeleted automatically when you deregister the instance; there can be a delay of\nseveral hours before the health check is deleted from Route 53.","ref":"AWS.Route53.html#delete_health_check/4","title":"AWS.Route53.delete_health_check/4","type":"function"},{"doc":"Deletes a hosted zone.\n\nIf the hosted zone was created by another service, such as Cloud Map, see\n[Deleting Public Hosted Zones That Were Created by Another Service](https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/DeleteHostedZone.html#delete-public-hosted-zone-created-by-another-service)\nin the *Amazon Route 53 Developer Guide* for information about how to delete it.\n(The process is the same for public and private hosted zones that were created\nby another service.)\n\nIf you want to keep your domain registration but you want to stop routing\ninternet traffic to your website or web application, we recommend that you\ndelete resource record sets in the hosted zone instead of deleting the hosted\nzone.\n\nIf you delete a hosted zone, you can't undelete it. You must create a new hosted\nzone and update the name servers for your domain registration, which can require\nup to 48 hours to take effect. (If you delegated responsibility for a subdomain\nto a hosted zone and you delete the child hosted zone, you must update the name\nservers in the parent hosted zone.) In addition, if you delete a hosted zone,\nsomeone could hijack the domain and route traffic to their own resources using\nyour domain name.\n\nIf you want to avoid the monthly charge for the hosted zone, you can transfer\nDNS service for the domain to a free DNS service. When you transfer DNS service,\nyou have to update the name servers for the domain registration. If the domain\nis registered with Route 53, see\n[UpdateDomainNameservers](https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_UpdateDomainNameservers.html) for information about how to replace Route 53 name servers with name servers for\nthe new DNS service. If the domain is registered with another registrar, use the\nmethod provided by the registrar to update name servers for the domain\nregistration. For more information, perform an internet search on \"free DNS\nservice.\"\n\nYou can delete a hosted zone only if it contains only the default SOA record and\nNS resource record sets. If the hosted zone contains other resource record sets,\nyou must delete them before you can delete the hosted zone. If you try to delete\na hosted zone that contains other resource record sets, the request fails, and\nRoute 53 returns a `HostedZoneNotEmpty` error. For information about deleting\nrecords from your hosted zone, see\n[ChangeResourceRecordSets](https://docs.aws.amazon.com/Route53/latest/APIReference/API_ChangeResourceRecordSets.html).\n\nTo verify that the hosted zone has been deleted, do one of the following:\n\n  * Use the `GetHostedZone` action to request information about the\nhosted zone.\n\n  * Use the `ListHostedZones` action to get a list of the hosted zones\nassociated with the current Amazon Web Services account.","ref":"AWS.Route53.html#delete_hosted_zone/4","title":"AWS.Route53.delete_hosted_zone/4","type":"function"},{"doc":"Deletes a key-signing key (KSK).\n\nBefore you can delete a KSK, you must deactivate it. The KSK must be deactivated\nbefore you can delete it regardless of whether the hosted zone is enabled for\nDNSSEC signing.\n\nYou can use\n[DeactivateKeySigningKey](https://docs.aws.amazon.com/Route53/latest/APIReference/API_DeactivateKeySigningKey.html) to deactivate the key before you delete it.\n\nUse\n[GetDNSSEC](https://docs.aws.amazon.com/Route53/latest/APIReference/API_GetDNSSEC.html)\nto verify that the KSK is in an `INACTIVE` status.","ref":"AWS.Route53.html#delete_key_signing_key/5","title":"AWS.Route53.delete_key_signing_key/5","type":"function"},{"doc":"Deletes a configuration for DNS query logging.\n\nIf you delete a configuration, Amazon Route 53 stops sending query logs to\nCloudWatch Logs. Route 53 doesn't delete any logs that are already in CloudWatch\nLogs.\n\nFor more information about DNS query logs, see\n[CreateQueryLoggingConfig](https://docs.aws.amazon.com/Route53/latest/APIReference/API_CreateQueryLoggingConfig.html).","ref":"AWS.Route53.html#delete_query_logging_config/4","title":"AWS.Route53.delete_query_logging_config/4","type":"function"},{"doc":"Deletes a reusable delegation set.\n\nYou can delete a reusable delegation set only if it isn't associated with any\nhosted zones.\n\nTo verify that the reusable delegation set is not associated with any hosted\nzones, submit a\n[GetReusableDelegationSet](https://docs.aws.amazon.com/Route53/latest/APIReference/API_GetReusableDelegationSet.html)\nrequest and specify the ID of the reusable delegation set that you want to\ndelete.","ref":"AWS.Route53.html#delete_reusable_delegation_set/4","title":"AWS.Route53.delete_reusable_delegation_set/4","type":"function"},{"doc":"Deletes a traffic policy.\n\nWhen you delete a traffic policy, Route 53 sets a flag on the policy to indicate\nthat it has been deleted. However, Route 53 never fully deletes the traffic\npolicy. Note the following:\n\n  * Deleted traffic policies aren't listed if you run\n[ListTrafficPolicies](https://docs.aws.amazon.com/Route53/latest/APIReference/API_ListTrafficPolicies.html).     * There's no way to get a list of deleted policies.\n\n  * If you retain the ID of the policy, you can get information about\nthe policy, including the traffic policy document, by running\n[GetTrafficPolicy](https://docs.aws.amazon.com/Route53/latest/APIReference/API_GetTrafficPolicy.html).","ref":"AWS.Route53.html#delete_traffic_policy/5","title":"AWS.Route53.delete_traffic_policy/5","type":"function"},{"doc":"Deletes a traffic policy instance and all of the resource record sets that\nAmazon Route 53 created when you created the instance.\n\nIn the Route 53 console, traffic policy instances are known as policy records.","ref":"AWS.Route53.html#delete_traffic_policy_instance/4","title":"AWS.Route53.delete_traffic_policy_instance/4","type":"function"},{"doc":"Removes authorization to submit an `AssociateVPCWithHostedZone` request to\nassociate a specified VPC with a hosted zone that was created by a different\naccount.\n\nYou must use the account that created the hosted zone to submit a\n`DeleteVPCAssociationAuthorization` request.\n\nSending this request only prevents the Amazon Web Services account that created\nthe VPC from associating the VPC with the Amazon Route 53 hosted zone in the\nfuture. If the VPC is already associated with the hosted zone,\n`DeleteVPCAssociationAuthorization` won't disassociate the VPC from the hosted\nzone. If you want to delete an existing association, use\n`DisassociateVPCFromHostedZone`.","ref":"AWS.Route53.html#delete_vpc_association_authorization/4","title":"AWS.Route53.delete_vpc_association_authorization/4","type":"function"},{"doc":"Disables DNSSEC signing in a specific hosted zone.\n\nThis action does not deactivate any key-signing keys (KSKs) that are active in\nthe hosted zone.","ref":"AWS.Route53.html#disable_hosted_zone_dns_sec/4","title":"AWS.Route53.disable_hosted_zone_dns_sec/4","type":"function"},{"doc":"Disassociates an Amazon Virtual Private Cloud (Amazon VPC) from an Amazon Route\n53 private hosted zone.\n\nNote the following:\n\n  * You can't disassociate the last Amazon VPC from a private hosted\nzone.\n\n  * You can't convert a private hosted zone into a public hosted zone.\n\n  * You can submit a `DisassociateVPCFromHostedZone` request using\neither the account that created the hosted zone or the account that created the\nAmazon VPC.\n\n  * Some services, such as Cloud Map and Amazon Elastic File System\n(Amazon EFS) automatically create hosted zones and associate VPCs with the\nhosted zones. A service can create a hosted zone using your account or using its\nown account. You can disassociate a VPC from a hosted zone only if the service\ncreated the hosted zone using your account.\n\nWhen you run\n[DisassociateVPCFromHostedZone](https://docs.aws.amazon.com/Route53/latest/APIReference/API_ListHostedZonesByVPC.html), if the hosted zone has a value for `OwningAccount`, you can use\n`DisassociateVPCFromHostedZone`. If the hosted zone has a value for\n`OwningService`, you can't use `DisassociateVPCFromHostedZone`.\n\nWhen revoking access, the hosted zone and the Amazon VPC must belong to the same\npartition. A partition is a group of Amazon Web Services Regions. Each Amazon\nWeb Services account is scoped to one partition.\n\nThe following are the supported partitions:\n\n   `aws` - Amazon Web Services Regions\n\n   `aws-cn` - China Regions\n\n   `aws-us-gov` - Amazon Web Services GovCloud (US) Region\n\nFor more information, see [Access\nManagement](https://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html)\nin the *Amazon Web Services General Reference*.","ref":"AWS.Route53.html#disassociate_vpc_from_hosted_zone/4","title":"AWS.Route53.disassociate_vpc_from_hosted_zone/4","type":"function"},{"doc":"Enables DNSSEC signing in a specific hosted zone.","ref":"AWS.Route53.html#enable_hosted_zone_dns_sec/4","title":"AWS.Route53.enable_hosted_zone_dns_sec/4","type":"function"},{"doc":"Gets the specified limit for the current account, for example, the maximum\nnumber of health checks that you can create using the account.\n\nFor the default limit, see\n[Limits](https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/DNSLimitations.html) in the *Amazon Route 53 Developer Guide*. To request a higher limit, [open a\ncase](https://console.aws.amazon.com/support/home#/case/create?issueType=service-limit-increase&limitType=service-code-route53).\n\nYou can also view account limits in Amazon Web Services Trusted Advisor. Sign in\nto the Amazon Web Services Management Console and open the Trusted Advisor\nconsole at\n[https://console.aws.amazon.com/trustedadvisor/](https://console.aws.amazon.com/trustedadvisor).\nThen choose **Service limits** in the navigation pane.","ref":"AWS.Route53.html#get_account_limit/3","title":"AWS.Route53.get_account_limit/3","type":"function"},{"doc":"Returns the current status of a change batch request.\n\nThe status is one of the following values:\n\n  * `PENDING` indicates that the changes in this request have not\npropagated to all Amazon Route 53 DNS servers managing the hosted zone. This is\nthe initial status of all change batch requests.\n\n  * `INSYNC` indicates that the changes have propagated to all Route\n53 DNS servers managing the hosted zone.","ref":"AWS.Route53.html#get_change/3","title":"AWS.Route53.get_change/3","type":"function"},{"doc":"Route 53 does not perform authorization for this API because it retrieves\ninformation that is already available to the public.\n\n`GetCheckerIpRanges` still works, but we recommend that you download\nip-ranges.json, which includes IP address ranges for all Amazon Web Services\nservices. For more information, see [IP Address Ranges of Amazon Route 53 Servers](https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/route-53-ip-addresses.html)\nin the *Amazon Route 53 Developer Guide*.","ref":"AWS.Route53.html#get_checker_ip_ranges/2","title":"AWS.Route53.get_checker_ip_ranges/2","type":"function"},{"doc":"Returns information about DNSSEC for a specific hosted zone, including the\nkey-signing keys (KSKs) in the hosted zone.","ref":"AWS.Route53.html#get_dns_sec/3","title":"AWS.Route53.get_dns_sec/3","type":"function"},{"doc":"Gets information about whether a specified geographic location is supported for\nAmazon Route 53 geolocation resource record sets.\n\nRoute 53 does not perform authorization for this API because it retrieves\ninformation that is already available to the public.\n\nUse the following syntax to determine whether a continent is supported for\ngeolocation:\n\n`GET /2013-04-01/geolocation?continentcode=*two-letter abbreviation for a\ncontinent* `\n\nUse the following syntax to determine whether a country is supported for\ngeolocation:\n\n`GET /2013-04-01/geolocation?countrycode=*two-character country code* `\n\nUse the following syntax to determine whether a subdivision of a country is\nsupported for geolocation:\n\n`GET /2013-04-01/geolocation?countrycode=*two-character country\ncode*&subdivisioncode=*subdivision code* `","ref":"AWS.Route53.html#get_geo_location/5","title":"AWS.Route53.get_geo_location/5","type":"function"},{"doc":"Gets information about a specified health check.","ref":"AWS.Route53.html#get_health_check/3","title":"AWS.Route53.get_health_check/3","type":"function"},{"doc":"Retrieves the number of health checks that are associated with the current\nAmazon Web Services account.","ref":"AWS.Route53.html#get_health_check_count/2","title":"AWS.Route53.get_health_check_count/2","type":"function"},{"doc":"Gets the reason that a specified health check failed most recently.","ref":"AWS.Route53.html#get_health_check_last_failure_reason/3","title":"AWS.Route53.get_health_check_last_failure_reason/3","type":"function"},{"doc":"Gets status of a specified health check.\n\nThis API is intended for use during development to diagnose behavior. It doesn’t\nsupport production use-cases with high query rates that require immediate and\nactionable responses.","ref":"AWS.Route53.html#get_health_check_status/3","title":"AWS.Route53.get_health_check_status/3","type":"function"},{"doc":"Gets information about a specified hosted zone including the four name servers\nassigned to the hosted zone.","ref":"AWS.Route53.html#get_hosted_zone/3","title":"AWS.Route53.get_hosted_zone/3","type":"function"},{"doc":"Retrieves the number of hosted zones that are associated with the current Amazon\nWeb Services account.","ref":"AWS.Route53.html#get_hosted_zone_count/2","title":"AWS.Route53.get_hosted_zone_count/2","type":"function"},{"doc":"Gets the specified limit for a specified hosted zone, for example, the maximum\nnumber of records that you can create in the hosted zone.\n\nFor the default limit, see\n[Limits](https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/DNSLimitations.html) in the *Amazon Route 53 Developer Guide*. To request a higher limit, [open a\ncase](https://console.aws.amazon.com/support/home#/case/create?issueType=service-limit-increase&limitType=service-code-route53).","ref":"AWS.Route53.html#get_hosted_zone_limit/4","title":"AWS.Route53.get_hosted_zone_limit/4","type":"function"},{"doc":"Gets information about a specified configuration for DNS query logging.\n\nFor more information about DNS query logs, see\n[CreateQueryLoggingConfig](https://docs.aws.amazon.com/Route53/latest/APIReference/API_CreateQueryLoggingConfig.html) and [Logging DNS\nQueries](https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/query-logs.html).","ref":"AWS.Route53.html#get_query_logging_config/3","title":"AWS.Route53.get_query_logging_config/3","type":"function"},{"doc":"Retrieves information about a specified reusable delegation set, including the\nfour name servers that are assigned to the delegation set.","ref":"AWS.Route53.html#get_reusable_delegation_set/3","title":"AWS.Route53.get_reusable_delegation_set/3","type":"function"},{"doc":"Gets the maximum number of hosted zones that you can associate with the\nspecified reusable delegation set.\n\nFor the default limit, see\n[Limits](https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/DNSLimitations.html) in the *Amazon Route 53 Developer Guide*. To request a higher limit, [open a\ncase](https://console.aws.amazon.com/support/home#/case/create?issueType=service-limit-increase&limitType=service-code-route53).","ref":"AWS.Route53.html#get_reusable_delegation_set_limit/4","title":"AWS.Route53.get_reusable_delegation_set_limit/4","type":"function"},{"doc":"Gets information about a specific traffic policy version.\n\nFor information about how of deleting a traffic policy affects the response from\n`GetTrafficPolicy`, see\n[DeleteTrafficPolicy](https://docs.aws.amazon.com/Route53/latest/APIReference/API_DeleteTrafficPolicy.html).","ref":"AWS.Route53.html#get_traffic_policy/4","title":"AWS.Route53.get_traffic_policy/4","type":"function"},{"doc":"Gets information about a specified traffic policy instance.\n\nUse `GetTrafficPolicyInstance` with the `id` of new traffic policy instance to\nconfirm that the `CreateTrafficPolicyInstance` or an\n`UpdateTrafficPolicyInstance` request completed successfully. For more\ninformation, see the `State` response element.\n\nIn the Route 53 console, traffic policy instances are known as policy records.","ref":"AWS.Route53.html#get_traffic_policy_instance/3","title":"AWS.Route53.get_traffic_policy_instance/3","type":"function"},{"doc":"Gets the number of traffic policy instances that are associated with the current\nAmazon Web Services account.","ref":"AWS.Route53.html#get_traffic_policy_instance_count/2","title":"AWS.Route53.get_traffic_policy_instance_count/2","type":"function"},{"doc":"Returns a paginated list of location objects and their CIDR blocks.","ref":"AWS.Route53.html#list_cidr_blocks/6","title":"AWS.Route53.list_cidr_blocks/6","type":"function"},{"doc":"Returns a paginated list of CIDR collections in the Amazon Web Services account\n(metadata only).","ref":"AWS.Route53.html#list_cidr_collections/4","title":"AWS.Route53.list_cidr_collections/4","type":"function"},{"doc":"Returns a paginated list of CIDR locations for the given collection (metadata\nonly, does not include CIDR blocks).","ref":"AWS.Route53.html#list_cidr_locations/5","title":"AWS.Route53.list_cidr_locations/5","type":"function"},{"doc":"Retrieves a list of supported geographic locations.\n\nCountries are listed first, and continents are listed last. If Amazon Route 53\nsupports subdivisions for a country (for example, states or provinces), the\nsubdivisions for that country are listed in alphabetical order immediately after\nthe corresponding country.\n\nRoute 53 does not perform authorization for this API because it retrieves\ninformation that is already available to the public.\n\nFor a list of supported geolocation codes, see the\n[GeoLocation](https://docs.aws.amazon.com/Route53/latest/APIReference/API_GeoLocation.html)\ndata type.","ref":"AWS.Route53.html#list_geo_locations/6","title":"AWS.Route53.list_geo_locations/6","type":"function"},{"doc":"Retrieve a list of the health checks that are associated with the current Amazon\nWeb Services account.","ref":"AWS.Route53.html#list_health_checks/4","title":"AWS.Route53.list_health_checks/4","type":"function"},{"doc":"Retrieves a list of the public and private hosted zones that are associated with\nthe current Amazon Web Services account.\n\nThe response includes a `HostedZones` child element for each hosted zone.\n\nAmazon Route 53 returns a maximum of 100 items in each response. If you have a\nlot of hosted zones, you can use the `maxitems` parameter to list them in groups\nof up to 100.","ref":"AWS.Route53.html#list_hosted_zones/6","title":"AWS.Route53.list_hosted_zones/6","type":"function"},{"doc":"Retrieves a list of your hosted zones in lexicographic order.\n\nThe response includes a `HostedZones` child element for each hosted zone created\nby the current Amazon Web Services account.\n\n`ListHostedZonesByName` sorts hosted zones by name with the labels reversed. For\nexample:\n\n`com.example.www.`\n\nNote the trailing dot, which can change the sort order in some circumstances.\n\nIf the domain name includes escape characters or Punycode,\n`ListHostedZonesByName` alphabetizes the domain name using the escaped or\nPunycoded value, which is the format that Amazon Route 53 saves in its database.\nFor example, to create a hosted zone for exämple.com, you specify ex344mple.com\nfor the domain name. `ListHostedZonesByName` alphabetizes it as:\n\n`com.ex344mple.`\n\nThe labels are reversed and alphabetized using the escaped value. For more\ninformation about valid domain name formats, including internationalized domain\nnames, see [DNS Domain Name Format](https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/DomainNameFormat.html)\nin the *Amazon Route 53 Developer Guide*.\n\nRoute 53 returns up to 100 items in each response. If you have a lot of hosted\nzones, use the `MaxItems` parameter to list them in groups of up to 100. The\nresponse includes values that help navigate from one group of `MaxItems` hosted\nzones to the next:\n\n  * The `DNSName` and `HostedZoneId` elements in the response contain\nthe values, if any, specified for the `dnsname` and `hostedzoneid` parameters in\nthe request that produced the current response.\n\n  * The `MaxItems` element in the response contains the value, if any,\nthat you specified for the `maxitems` parameter in the request that produced the\ncurrent response.\n\n  * If the value of `IsTruncated` in the response is true, there are\nmore hosted zones associated with the current Amazon Web Services account.\n\nIf `IsTruncated` is false, this response includes the last hosted zone that is\nassociated with the current account. The `NextDNSName` element and\n`NextHostedZoneId` elements are omitted from the response.\n\n  * The `NextDNSName` and `NextHostedZoneId` elements in the response\ncontain the domain name and the hosted zone ID of the next hosted zone that is\nassociated with the current Amazon Web Services account. If you want to list\nmore hosted zones, make another call to `ListHostedZonesByName`, and specify the\nvalue of `NextDNSName` and `NextHostedZoneId` in the `dnsname` and\n`hostedzoneid` parameters, respectively.","ref":"AWS.Route53.html#list_hosted_zones_by_name/5","title":"AWS.Route53.list_hosted_zones_by_name/5","type":"function"},{"doc":"Lists all the private hosted zones that a specified VPC is associated with,\nregardless of which Amazon Web Services account or Amazon Web Services service\nowns the hosted zones.\n\nThe `HostedZoneOwner` structure in the response contains one of the following\nvalues:\n\n  * An `OwningAccount` element, which contains the account number of\neither the current Amazon Web Services account or another Amazon Web Services\naccount. Some services, such as Cloud Map, create hosted zones using the current\naccount.\n\n  * An `OwningService` element, which identifies the Amazon Web\nServices service that created and owns the hosted zone. For example, if a hosted\nzone was created by Amazon Elastic File System (Amazon EFS), the value of\n`Owner` is `efs.amazonaws.com`.\n\nWhen listing private hosted zones, the hosted zone and the Amazon VPC must\nbelong to the same partition where the hosted zones were created. A partition is\na group of Amazon Web Services Regions. Each Amazon Web Services account is\nscoped to one partition.\n\nThe following are the supported partitions:\n\n   `aws` - Amazon Web Services Regions\n\n   `aws-cn` - China Regions\n\n   `aws-us-gov` - Amazon Web Services GovCloud (US) Region\n\nFor more information, see [Access Management](https://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html)\nin the *Amazon Web Services General Reference*.","ref":"AWS.Route53.html#list_hosted_zones_by_vpc/6","title":"AWS.Route53.list_hosted_zones_by_vpc/6","type":"function"},{"doc":"Lists the configurations for DNS query logging that are associated with the\ncurrent Amazon Web Services account or the configuration that is associated with\na specified hosted zone.\n\nFor more information about DNS query logs, see\n[CreateQueryLoggingConfig](https://docs.aws.amazon.com/Route53/latest/APIReference/API_CreateQueryLoggingConfig.html). Additional information, including the format of DNS query logs, appears in\n[Logging DNS\nQueries](https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/query-logs.html)\nin the *Amazon Route 53 Developer Guide*.","ref":"AWS.Route53.html#list_query_logging_configs/5","title":"AWS.Route53.list_query_logging_configs/5","type":"function"},{"doc":"Lists the resource record sets in a specified hosted zone.\n\n`ListResourceRecordSets` returns up to 300 resource record sets at a time in\nASCII order, beginning at a position specified by the `name` and `type`\nelements.","ref":"AWS.Route53.html#list_resource_record_sets/7","title":"AWS.Route53.list_resource_record_sets/7","type":"function"},{"doc":"`ListResourceRecordSets` sorts results first by DNS name with the labels\nreversed, for example:\n\n`com.example.www.`\n\nNote the trailing dot, which can change the sort order when the record name\ncontains characters that appear before `.` (decimal 46) in the ASCII table.\nThese characters include the following: `! \" # $ % & ' ( ) * + , -`\n\nWhen multiple records have the same DNS name, `ListResourceRecordSets` sorts\nresults by the record type.","ref":"AWS.Route53.html#list_resource_record_sets/7-sort-order","title":"Sort order - AWS.Route53.list_resource_record_sets/7","type":"function"},{"doc":"You can use the name and type elements to specify the resource record set that\nthe list begins with:","ref":"AWS.Route53.html#list_resource_record_sets/7-specifying-where-to-start-listing-records","title":"Specifying where to start listing records - AWS.Route53.list_resource_record_sets/7","type":"function"},{"doc":"#","ref":"AWS.Route53.html#list_resource_record_sets/7-definitions","title":"Definitions - AWS.Route53.list_resource_record_sets/7","type":"function"},{"doc":"The results begin with the first resource record set that the hosted zone\ncontains.\n\n#","ref":"AWS.Route53.html#list_resource_record_sets/7-if-you-do-not-specify-name-or-type","title":"If you do not specify Name or Type - AWS.Route53.list_resource_record_sets/7","type":"function"},{"doc":"The results begin with the first resource record set in the list whose name is\ngreater than or equal to `Name`.\n\n#","ref":"AWS.Route53.html#list_resource_record_sets/7-if-you-specify-name-but-not-type","title":"If you specify Name but not Type - AWS.Route53.list_resource_record_sets/7","type":"function"},{"doc":"Amazon Route 53 returns the `InvalidInput` error.\n\n#","ref":"AWS.Route53.html#list_resource_record_sets/7-if-you-specify-type-but-not-name","title":"If you specify Type but not Name - AWS.Route53.list_resource_record_sets/7","type":"function"},{"doc":"The results begin with the first resource record set in the list whose name is\ngreater than or equal to `Name`, and whose type is greater than or equal to\n`Type`.","ref":"AWS.Route53.html#list_resource_record_sets/7-if-you-specify-both-name-and-type","title":"If you specify both Name and Type - AWS.Route53.list_resource_record_sets/7","type":"function"},{"doc":"This action returns the most current version of the records. This includes\nrecords that are `PENDING`, and that are not yet available on all Route 53 DNS\nservers.","ref":"AWS.Route53.html#list_resource_record_sets/7-resource-record-sets-that-are-pending","title":"Resource record sets that are PENDING - AWS.Route53.list_resource_record_sets/7","type":"function"},{"doc":"To ensure that you get an accurate listing of the resource record sets for a\nhosted zone at a point in time, do not submit a `ChangeResourceRecordSets`\nrequest while you're paging through the results of a `ListResourceRecordSets`\nrequest. If you do, some pages may display results without the latest changes\nwhile other pages display results with the latest changes.","ref":"AWS.Route53.html#list_resource_record_sets/7-changing-resource-record-sets","title":"Changing resource record sets - AWS.Route53.list_resource_record_sets/7","type":"function"},{"doc":"If a `ListResourceRecordSets` command returns more than one page of results, the\nvalue of `IsTruncated` is `true`. To display the next page of results, get the\nvalues of `NextRecordName`, `NextRecordType`, and `NextRecordIdentifier` (if\nany) from the response. Then submit another `ListResourceRecordSets` request,\nand specify those values for `StartRecordName`, `StartRecordType`, and\n`StartRecordIdentifier`.","ref":"AWS.Route53.html#list_resource_record_sets/7-displaying-the-next-page-of-results","title":"Displaying the next page of results - AWS.Route53.list_resource_record_sets/7","type":"function"},{"doc":"Retrieves a list of the reusable delegation sets that are associated with the\ncurrent Amazon Web Services account.","ref":"AWS.Route53.html#list_reusable_delegation_sets/4","title":"AWS.Route53.list_reusable_delegation_sets/4","type":"function"},{"doc":"Lists tags for one health check or hosted zone.\n\nFor information about using tags for cost allocation, see [Using Cost Allocation Tags](https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/cost-alloc-tags.html)\nin the *Billing and Cost Management User Guide*.","ref":"AWS.Route53.html#list_tags_for_resource/4","title":"AWS.Route53.list_tags_for_resource/4","type":"function"},{"doc":"Lists tags for up to 10 health checks or hosted zones.\n\nFor information about using tags for cost allocation, see [Using Cost Allocation Tags](https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/cost-alloc-tags.html)\nin the *Billing and Cost Management User Guide*.","ref":"AWS.Route53.html#list_tags_for_resources/4","title":"AWS.Route53.list_tags_for_resources/4","type":"function"},{"doc":"Gets information about the latest version for every traffic policy that is\nassociated with the current Amazon Web Services account.\n\nPolicies are listed in the order that they were created in.\n\nFor information about how of deleting a traffic policy affects the response from\n`ListTrafficPolicies`, see\n[DeleteTrafficPolicy](https://docs.aws.amazon.com/Route53/latest/APIReference/API_DeleteTrafficPolicy.html).","ref":"AWS.Route53.html#list_traffic_policies/4","title":"AWS.Route53.list_traffic_policies/4","type":"function"},{"doc":"Gets information about the traffic policy instances that you created by using\nthe current Amazon Web Services account.\n\nAfter you submit an `UpdateTrafficPolicyInstance` request, there's a brief delay\nwhile Amazon Route 53 creates the resource record sets that are specified in the\ntraffic policy definition. For more information, see the `State` response\nelement.\n\nRoute 53 returns a maximum of 100 items in each response. If you have a lot of\ntraffic policy instances, you can use the `MaxItems` parameter to list them in\ngroups of up to 100.","ref":"AWS.Route53.html#list_traffic_policy_instances/6","title":"AWS.Route53.list_traffic_policy_instances/6","type":"function"},{"doc":"Gets information about the traffic policy instances that you created in a\nspecified hosted zone.\n\nAfter you submit a `CreateTrafficPolicyInstance` or an\n`UpdateTrafficPolicyInstance` request, there's a brief delay while Amazon Route\n53 creates the resource record sets that are specified in the traffic policy\ndefinition. For more information, see the `State` response element.\n\nRoute 53 returns a maximum of 100 items in each response. If you have a lot of\ntraffic policy instances, you can use the `MaxItems` parameter to list them in\ngroups of up to 100.","ref":"AWS.Route53.html#list_traffic_policy_instances_by_hosted_zone/6","title":"AWS.Route53.list_traffic_policy_instances_by_hosted_zone/6","type":"function"},{"doc":"Gets information about the traffic policy instances that you created by using a\nspecify traffic policy version.\n\nAfter you submit a `CreateTrafficPolicyInstance` or an\n`UpdateTrafficPolicyInstance` request, there's a brief delay while Amazon Route\n53 creates the resource record sets that are specified in the traffic policy\ndefinition. For more information, see the `State` response element.\n\nRoute 53 returns a maximum of 100 items in each response. If you have a lot of\ntraffic policy instances, you can use the `MaxItems` parameter to list them in\ngroups of up to 100.","ref":"AWS.Route53.html#list_traffic_policy_instances_by_policy/8","title":"AWS.Route53.list_traffic_policy_instances_by_policy/8","type":"function"},{"doc":"Gets information about all of the versions for a specified traffic policy.\n\nTraffic policy versions are listed in numerical order by `VersionNumber`.","ref":"AWS.Route53.html#list_traffic_policy_versions/5","title":"AWS.Route53.list_traffic_policy_versions/5","type":"function"},{"doc":"Gets a list of the VPCs that were created by other accounts and that can be\nassociated with a specified hosted zone because you've submitted one or more\n`CreateVPCAssociationAuthorization` requests.\n\nThe response includes a `VPCs` element with a `VPC` child element for each VPC\nthat can be associated with the hosted zone.","ref":"AWS.Route53.html#list_vpc_association_authorizations/5","title":"AWS.Route53.list_vpc_association_authorizations/5","type":"function"},{"doc":"","ref":"AWS.Route53.html#metadata/0","title":"AWS.Route53.metadata/0","type":"function"},{"doc":"Gets the value that Amazon Route 53 returns in response to a DNS request for a\nspecified record name and type.\n\nYou can optionally specify the IP address of a DNS resolver, an EDNS0 client\nsubnet IP address, and a subnet mask.\n\nThis call only supports querying public hosted zones.\n\nThe `TestDnsAnswer ` returns information similar to what you would expect from\nthe answer section of the `dig` command. Therefore, if you query for the name\nservers of a subdomain that point to the parent name servers, those will not be\nreturned.","ref":"AWS.Route53.html#test_dns_answer/8","title":"AWS.Route53.test_dns_answer/8","type":"function"},{"doc":"Updates an existing health check.\n\nNote that some values can't be updated.\n\nFor more information about updating health checks, see [Creating, Updating, and Deleting Health\nChecks](https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/health-checks-creating-deleting.html)\nin the *Amazon Route 53 Developer Guide*.","ref":"AWS.Route53.html#update_health_check/4","title":"AWS.Route53.update_health_check/4","type":"function"},{"doc":"Updates the comment for a specified hosted zone.","ref":"AWS.Route53.html#update_hosted_zone_comment/4","title":"AWS.Route53.update_hosted_zone_comment/4","type":"function"},{"doc":"Updates the comment for a specified traffic policy version.","ref":"AWS.Route53.html#update_traffic_policy_comment/5","title":"AWS.Route53.update_traffic_policy_comment/5","type":"function"},{"doc":"After you submit a `UpdateTrafficPolicyInstance` request, there's a brief delay\nwhile Route 53 creates the resource record sets that are specified in the\ntraffic policy definition.\n\nUse `GetTrafficPolicyInstance` with the `id` of updated traffic policy instance\nconfirm that the `UpdateTrafficPolicyInstance` request completed successfully.\nFor more information, see the `State` response element.\n\nUpdates the resource record sets in a specified hosted zone that were created\nbased on the settings in a specified traffic policy version.\n\nWhen you update a traffic policy instance, Amazon Route 53 continues to respond\nto DNS queries for the root resource record set name (such as example.com) while\nit replaces one group of resource record sets with another. Route 53 performs\nthe following operations:\n\n  1. Route 53 creates a new group of resource record sets based on the\nspecified traffic policy. This is true regardless of how significant the\ndifferences are between the existing resource record sets and the new resource\nrecord sets.\n\n  2. When all of the new resource record sets have been created, Route\n53 starts to respond to DNS queries for the root resource record set name (such\nas example.com) by using the new resource record sets.\n\n  3. Route 53 deletes the old group of resource record sets that are\nassociated with the root resource record set name.","ref":"AWS.Route53.html#update_traffic_policy_instance/4","title":"AWS.Route53.update_traffic_policy_instance/4","type":"function"},{"doc":"Amazon Route 53 API actions let you register domain names and perform related\noperations.","ref":"AWS.Route53Domains.html","title":"AWS.Route53Domains","type":"module"},{"doc":"Accepts the transfer of a domain from another Amazon Web Services account to the\ncurrentAmazon Web Services account.\n\nYou initiate a transfer between Amazon Web Services accounts using\n[TransferDomainToAnotherAwsAccount](https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_TransferDomainToAnotherAwsAccount.html).  If you use the CLI command at\n[accept-domain-transfer-from-another-aws-account](https://docs.aws.amazon.com/cli/latest/reference/route53domains/accept-domain-transfer-from-another-aws-account.html),\nuse JSON format as input instead of text because otherwise CLI will throw an\nerror from domain transfer input that includes single quotes.\n\nUse either\n[ListOperations](https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_ListOperations.html) or\n[GetOperationDetail](https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_GetOperationDetail.html)\nto determine whether the operation succeeded.\n[GetOperationDetail](https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_GetOperationDetail.html)\nprovides additional information, for example, `Domain Transfer from Aws Account\n111122223333 has been cancelled`.","ref":"AWS.Route53Domains.html#accept_domain_transfer_from_another_aws_account/3","title":"AWS.Route53Domains.accept_domain_transfer_from_another_aws_account/3","type":"function"},{"doc":"Creates a delegation signer (DS) record in the registry zone for this domain\nname.\n\nNote that creating DS record at the registry impacts DNSSEC validation of your\nDNS records. This action may render your domain name unavailable on the internet\nif the steps are completed in the wrong order, or with incorrect timing. For\nmore information about DNSSEC signing, see [Configuring DNSSEC signing](https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/dns-configuring-dnssec.html)\nin the *Route 53 developer guide*.","ref":"AWS.Route53Domains.html#associate_delegation_signer_to_domain/3","title":"AWS.Route53Domains.associate_delegation_signer_to_domain/3","type":"function"},{"doc":"Cancels the transfer of a domain from the current Amazon Web Services account to\nanother Amazon Web Services account.\n\nYou initiate a transfer betweenAmazon Web Services accounts using\n[TransferDomainToAnotherAwsAccount](https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_TransferDomainToAnotherAwsAccount.html).  You must cancel the transfer before the other Amazon Web Services account\naccepts the transfer using\n[AcceptDomainTransferFromAnotherAwsAccount](https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_AcceptDomainTransferFromAnotherAwsAccount.html).\n\nUse either\n[ListOperations](https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_ListOperations.html) or\n[GetOperationDetail](https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_GetOperationDetail.html)\nto determine whether the operation succeeded.\n[GetOperationDetail](https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_GetOperationDetail.html)\nprovides additional information, for example, `Domain Transfer from Aws Account\n111122223333 has been cancelled`.","ref":"AWS.Route53Domains.html#cancel_domain_transfer_to_another_aws_account/3","title":"AWS.Route53Domains.cancel_domain_transfer_to_another_aws_account/3","type":"function"},{"doc":"This operation checks the availability of one domain name.\n\nNote that if the availability status of a domain is pending, you must submit\nanother request to determine the availability of the domain name.","ref":"AWS.Route53Domains.html#check_domain_availability/3","title":"AWS.Route53Domains.check_domain_availability/3","type":"function"},{"doc":"Checks whether a domain name can be transferred to Amazon Route 53.","ref":"AWS.Route53Domains.html#check_domain_transferability/3","title":"AWS.Route53Domains.check_domain_transferability/3","type":"function"},{"doc":"This operation deletes the specified domain.\n\nThis action is permanent. For more information, see [Deleting a domain name registration](https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/domain-delete.html).\n\nTo transfer the domain registration to another registrar, use the transfer\nprocess that’s provided by the registrar to which you want to transfer the\nregistration. Otherwise, the following apply:\n\n  1. You can’t get a refund for the cost of a deleted domain\nregistration.\n\n  2. The registry for the top-level domain might hold the domain name\nfor a brief time before releasing it for other users to register (varies by\nregistry).\n\n  3. When the registration has been deleted, we'll send you a\nconfirmation to the registrant contact. The email will come from\n`noreply@domainnameverification.net` or `noreply@registrar.amazon.com`.","ref":"AWS.Route53Domains.html#delete_domain/3","title":"AWS.Route53Domains.delete_domain/3","type":"function"},{"doc":"This operation deletes the specified tags for a domain.\n\nAll tag operations are eventually consistent; subsequent operations might not\nimmediately represent all issued operations.","ref":"AWS.Route53Domains.html#delete_tags_for_domain/3","title":"AWS.Route53Domains.delete_tags_for_domain/3","type":"function"},{"doc":"This operation disables automatic renewal of domain registration for the\nspecified domain.","ref":"AWS.Route53Domains.html#disable_domain_auto_renew/3","title":"AWS.Route53Domains.disable_domain_auto_renew/3","type":"function"},{"doc":"This operation removes the transfer lock on the domain (specifically the\n`clientTransferProhibited` status) to allow domain transfers.\n\nWe recommend you refrain from performing this action unless you intend to\ntransfer the domain to a different registrar. Successful submission returns an\noperation ID that you can use to track the progress and completion of the\naction. If the request is not completed successfully, the domain registrant will\nbe notified by email.","ref":"AWS.Route53Domains.html#disable_domain_transfer_lock/3","title":"AWS.Route53Domains.disable_domain_transfer_lock/3","type":"function"},{"doc":"Deletes a delegation signer (DS) record in the registry zone for this domain\nname.","ref":"AWS.Route53Domains.html#disassociate_delegation_signer_from_domain/3","title":"AWS.Route53Domains.disassociate_delegation_signer_from_domain/3","type":"function"},{"doc":"This operation configures Amazon Route 53 to automatically renew the specified\ndomain before the domain registration expires.\n\nThe cost of renewing your domain registration is billed to your Amazon Web\nServices account.\n\nThe period during which you can renew a domain name varies by TLD. For a list of\nTLDs and their renewal policies, see [Domains That You Can Register with Amazon Route\n53](https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/registrar-tld-list.html)\nin the *Amazon Route 53 Developer Guide*. Route 53 requires that you renew\nbefore the end of the renewal period so we can complete processing before the\ndeadline.","ref":"AWS.Route53Domains.html#enable_domain_auto_renew/3","title":"AWS.Route53Domains.enable_domain_auto_renew/3","type":"function"},{"doc":"This operation sets the transfer lock on the domain (specifically the\n`clientTransferProhibited` status) to prevent domain transfers.\n\nSuccessful submission returns an operation ID that you can use to track the\nprogress and completion of the action. If the request is not completed\nsuccessfully, the domain registrant will be notified by email.","ref":"AWS.Route53Domains.html#enable_domain_transfer_lock/3","title":"AWS.Route53Domains.enable_domain_transfer_lock/3","type":"function"},{"doc":"For operations that require confirmation that the email address for the\nregistrant contact is valid, such as registering a new domain, this operation\nreturns information about whether the registrant contact has responded.\n\nIf you want us to resend the email, use the `ResendContactReachabilityEmail`\noperation.","ref":"AWS.Route53Domains.html#get_contact_reachability_status/3","title":"AWS.Route53Domains.get_contact_reachability_status/3","type":"function"},{"doc":"This operation returns detailed information about a specified domain that is\nassociated with the current Amazon Web Services account.\n\nContact information for the domain is also returned as part of the output.","ref":"AWS.Route53Domains.html#get_domain_detail/3","title":"AWS.Route53Domains.get_domain_detail/3","type":"function"},{"doc":"The GetDomainSuggestions operation returns a list of suggested domain names.","ref":"AWS.Route53Domains.html#get_domain_suggestions/3","title":"AWS.Route53Domains.get_domain_suggestions/3","type":"function"},{"doc":"This operation returns the current status of an operation that is not completed.","ref":"AWS.Route53Domains.html#get_operation_detail/3","title":"AWS.Route53Domains.get_operation_detail/3","type":"function"},{"doc":"This operation returns all the domain names registered with Amazon Route 53 for\nthe current Amazon Web Services account if no filtering conditions are used.","ref":"AWS.Route53Domains.html#list_domains/3","title":"AWS.Route53Domains.list_domains/3","type":"function"},{"doc":"Returns information about all of the operations that return an operation ID and\nthat have ever been performed on domains that were registered by the current\naccount.\n\nThis command runs only in the us-east-1 Region.","ref":"AWS.Route53Domains.html#list_operations/3","title":"AWS.Route53Domains.list_operations/3","type":"function"},{"doc":"Lists the following prices for either all the TLDs supported by Route 53, or the\nspecified TLD:\n\n  * Registration\n\n  * Transfer\n\n  * Owner change\n\n  * Domain renewal\n\n  * Domain restoration","ref":"AWS.Route53Domains.html#list_prices/3","title":"AWS.Route53Domains.list_prices/3","type":"function"},{"doc":"This operation returns all of the tags that are associated with the specified\ndomain.\n\nAll tag operations are eventually consistent; subsequent operations might not\nimmediately represent all issued operations.","ref":"AWS.Route53Domains.html#list_tags_for_domain/3","title":"AWS.Route53Domains.list_tags_for_domain/3","type":"function"},{"doc":"","ref":"AWS.Route53Domains.html#metadata/0","title":"AWS.Route53Domains.metadata/0","type":"function"},{"doc":"Moves a domain from Amazon Web Services to another registrar.\n\nSupported actions:\n\n  * Changes the IPS tags of a .uk domain, and pushes it to transit.\nTransit means that the domain is ready to be transferred to another registrar.","ref":"AWS.Route53Domains.html#push_domain/3","title":"AWS.Route53Domains.push_domain/3","type":"function"},{"doc":"This operation registers a domain.\n\nFor some top-level domains (TLDs), this operation requires extra parameters.\n\nWhen you register a domain, Amazon Route 53 does the following:\n\n  * Creates a Route 53 hosted zone that has the same name as the\ndomain. Route 53 assigns four name servers to your hosted zone and automatically\nupdates your domain registration with the names of these name servers.\n\n  * Enables auto renew, so your domain registration will renew\nautomatically each year. We'll notify you in advance of the renewal date so you\ncan choose whether to renew the registration.\n\n  * Optionally enables privacy protection, so WHOIS queries return\ncontact for the registrar or the phrase \"REDACTED FOR PRIVACY\", or \"On behalf of\n  owner.\" If you don't enable privacy protection, WHOIS queries\nreturn the information that you entered for the administrative, registrant, and\ntechnical contacts.\n\nWhile some domains may allow different privacy settings per contact, we\nrecommend specifying the same privacy setting for all contacts.\n\n  * If registration is successful, returns an operation ID that you\ncan use to track the progress and completion of the action. If the request is\nnot completed successfully, the domain registrant is notified by email.\n\n  * Charges your Amazon Web Services account an amount based on the\ntop-level domain. For more information, see [Amazon Route 53 Pricing](http://aws.amazon.com/route53/pricing/).","ref":"AWS.Route53Domains.html#register_domain/3","title":"AWS.Route53Domains.register_domain/3","type":"function"},{"doc":"Rejects the transfer of a domain from another Amazon Web Services account to the\ncurrent Amazon Web Services account.\n\nYou initiate a transfer betweenAmazon Web Services accounts using\n[TransferDomainToAnotherAwsAccount](https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_TransferDomainToAnotherAwsAccount.html).  Use either\n[ListOperations](https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_ListOperations.html)\nor\n[GetOperationDetail](https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_GetOperationDetail.html) to determine whether the operation succeeded.\n[GetOperationDetail](https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_GetOperationDetail.html)\nprovides additional information, for example, `Domain Transfer from Aws Account\n111122223333 has been cancelled`.","ref":"AWS.Route53Domains.html#reject_domain_transfer_from_another_aws_account/3","title":"AWS.Route53Domains.reject_domain_transfer_from_another_aws_account/3","type":"function"},{"doc":"This operation renews a domain for the specified number of years.\n\nThe cost of renewing your domain is billed to your Amazon Web Services account.\n\nWe recommend that you renew your domain several weeks before the expiration\ndate. Some TLD registries delete domains before the expiration date if you\nhaven't renewed far enough in advance. For more information about renewing\ndomain registration, see [Renewing Registration for a Domain](https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/domain-renew.html)\nin the *Amazon Route 53 Developer Guide*.","ref":"AWS.Route53Domains.html#renew_domain/3","title":"AWS.Route53Domains.renew_domain/3","type":"function"},{"doc":"For operations that require confirmation that the email address for the\nregistrant contact is valid, such as registering a new domain, this operation\nresends the confirmation email to the current email address for the registrant\ncontact.","ref":"AWS.Route53Domains.html#resend_contact_reachability_email/3","title":"AWS.Route53Domains.resend_contact_reachability_email/3","type":"function"},{"doc":"Resend the form of authorization email for this operation.","ref":"AWS.Route53Domains.html#resend_operation_authorization/3","title":"AWS.Route53Domains.resend_operation_authorization/3","type":"function"},{"doc":"This operation returns the authorization code for the domain.\n\nTo transfer a domain to another registrar, you provide this value to the new\nregistrar.","ref":"AWS.Route53Domains.html#retrieve_domain_auth_code/3","title":"AWS.Route53Domains.retrieve_domain_auth_code/3","type":"function"},{"doc":"Transfers a domain from another registrar to Amazon Route 53.\n\nFor more information about transferring domains, see the following topics:\n\n  * For transfer requirements, a detailed procedure, and information\nabout viewing the status of a domain that you're transferring to Route 53, see\n[Transferring Registration for a Domain to Amazon Route 53](https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/domain-transfer-to-route-53.html)\nin the *Amazon Route 53 Developer Guide*.\n\n  * For information about how to transfer a domain from one Amazon Web\nServices account to another, see\n[TransferDomainToAnotherAwsAccount](https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_TransferDomainToAnotherAwsAccount.html).     * For information about how to transfer a domain to another domain\nregistrar, see [Transferring a Domain from Amazon Route 53 to Another\nRegistrar](https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/domain-transfer-from-route-53.html)\nin the *Amazon Route 53 Developer Guide*.\n\nDuring the transfer of any country code top-level domains (ccTLDs) to Route 53,\nexcept for .cc and .tv, updates to the owner contact are ignored and the owner\ncontact data from the registry is used. You can update the owner contact after\nthe transfer is complete. For more information, see\n[UpdateDomainContact](https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_UpdateDomainContact.html).\n\nIf the registrar for your domain is also the DNS service provider for the\ndomain, we highly recommend that you transfer your DNS service to Route 53 or to\nanother DNS service provider before you transfer your registration. Some\nregistrars provide free DNS service when you purchase a domain registration.\nWhen you transfer the registration, the previous registrar will not renew your\ndomain registration and could end your DNS service at any time.\n\nIf the registrar for your domain is also the DNS service provider for the domain\nand you don't transfer DNS service to another provider, your website, email, and\nthe web applications associated with the domain might become unavailable.\n\nIf the transfer is successful, this method returns an operation ID that you can\nuse to track the progress and completion of the action. If the transfer doesn't\ncomplete successfully, the domain registrant will be notified by email.","ref":"AWS.Route53Domains.html#transfer_domain/3","title":"AWS.Route53Domains.transfer_domain/3","type":"function"},{"doc":"Transfers a domain from the current Amazon Web Services account to another\nAmazon Web Services account.\n\nNote the following:\n\n  * The Amazon Web Services account that you're transferring the\ndomain to must accept the transfer. If the other account doesn't accept the\ntransfer within 3 days, we cancel the transfer. See\n[AcceptDomainTransferFromAnotherAwsAccount](https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_AcceptDomainTransferFromAnotherAwsAccount.html).     * You can cancel the transfer before the other account accepts it.\nSee\n[CancelDomainTransferToAnotherAwsAccount](https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_CancelDomainTransferToAnotherAwsAccount.html).\n\n  * The other account can reject the transfer. See\n[RejectDomainTransferFromAnotherAwsAccount](https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_RejectDomainTransferFromAnotherAwsAccount.html). \n\nWhen you transfer a domain from one Amazon Web Services account to another,\nRoute 53 doesn't transfer the hosted zone that is associated with the domain.\nDNS resolution isn't affected if the domain and the hosted zone are owned by\nseparate accounts, so transferring the hosted zone is optional. For information\nabout transferring the hosted zone to another Amazon Web Services account, see\n[Migrating a Hosted Zone to a Different Amazon Web Services\nAccount](https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/hosted-zones-migrating.html)\nin the *Amazon Route 53 Developer Guide*.\n\nUse either\n[ListOperations](https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_ListOperations.html) or\n[GetOperationDetail](https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_GetOperationDetail.html)\nto determine whether the operation succeeded.\n[GetOperationDetail](https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_GetOperationDetail.html)\nprovides additional information, for example, `Domain Transfer from Aws Account\n111122223333 has been cancelled`.","ref":"AWS.Route53Domains.html#transfer_domain_to_another_aws_account/3","title":"AWS.Route53Domains.transfer_domain_to_another_aws_account/3","type":"function"},{"doc":"This operation updates the contact information for a particular domain.\n\nYou must specify information for at least one contact: registrant,\nadministrator, or technical.\n\nIf the update is successful, this method returns an operation ID that you can\nuse to track the progress and completion of the operation. If the request is not\ncompleted successfully, the domain registrant will be notified by email.","ref":"AWS.Route53Domains.html#update_domain_contact/3","title":"AWS.Route53Domains.update_domain_contact/3","type":"function"},{"doc":"This operation updates the specified domain contact's privacy setting.\n\nWhen privacy protection is enabled, your contact information is replaced with\ncontact information for the registrar or with the phrase \"REDACTED FOR PRIVACY\",\nor \"On behalf of   owner.\"\n\nWhile some domains may allow different privacy settings per contact, we\nrecommend specifying the same privacy setting for all contacts.\n\nThis operation affects only the contact information for the specified contact\ntype (administrative, registrant, or technical). If the request succeeds, Amazon\nRoute 53 returns an operation ID that you can use with\n[GetOperationDetail](https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_GetOperationDetail.html) to track the progress and completion of the action. If the request doesn't\ncomplete successfully, the domain registrant will be notified by email.\n\nBy disabling the privacy service via API, you consent to the publication of the\ncontact information provided for this domain via the public WHOIS database. You\ncertify that you are the registrant of this domain name and have the authority\nto make this decision. You may withdraw your consent at any time by enabling\nprivacy protection using either `UpdateDomainContactPrivacy` or the Route 53\nconsole. Enabling privacy protection removes the contact information provided\nfor this domain from the WHOIS database. For more information on our privacy\npractices, see\n[https://aws.amazon.com/privacy/](https://aws.amazon.com/privacy/).","ref":"AWS.Route53Domains.html#update_domain_contact_privacy/3","title":"AWS.Route53Domains.update_domain_contact_privacy/3","type":"function"},{"doc":"This operation replaces the current set of name servers for the domain with the\nspecified set of name servers.\n\nIf you use Amazon Route 53 as your DNS service, specify the four name servers in\nthe delegation set for the hosted zone for the domain.\n\nIf successful, this operation returns an operation ID that you can use to track\nthe progress and completion of the action. If the request is not completed\nsuccessfully, the domain registrant will be notified by email.","ref":"AWS.Route53Domains.html#update_domain_nameservers/3","title":"AWS.Route53Domains.update_domain_nameservers/3","type":"function"},{"doc":"This operation adds or updates tags for a specified domain.\n\nAll tag operations are eventually consistent; subsequent operations might not\nimmediately represent all issued operations.","ref":"AWS.Route53Domains.html#update_tags_for_domain/3","title":"AWS.Route53Domains.update_tags_for_domain/3","type":"function"},{"doc":"Returns all the domain-related billing records for the current Amazon Web\nServices account for a specified period","ref":"AWS.Route53Domains.html#view_billing/3","title":"AWS.Route53Domains.view_billing/3","type":"function"},{"doc":"Welcome to the Routing Control (Recovery Cluster) API Reference Guide for Amazon\nRoute 53 Application Recovery Controller.\n\nWith Route 53 ARC, you can use routing control with extreme reliability to\nrecover applications by rerouting traffic across Availability Zones or Amazon\nWeb Services Regions. Routing controls are simple on/off switches hosted on a\nhighly available cluster in Route 53 ARC. A cluster provides a set of five\nredundant Regional endpoints against which you can run API calls to get or\nupdate the state of routing controls. To implement failover, you set one routing\ncontrol to ON and another one to OFF, to reroute traffic from one Availability\nZone or Amazon Web Services Region to another.\n\n*Be aware that you must specify a Regional endpoint for a cluster when you work\nwith API cluster operations to get or update routing control states in Route 53\nARC.* In addition, you must specify the US West (Oregon) Region for Route 53 ARC\nAPI calls. For example, use the parameter `--region us-west-2` with AWS CLI\ncommands. For more information, see [ Get and update routing control states using the\nAPI](https://docs.aws.amazon.com/r53recovery/latest/dg/routing-control.update.api.html)\nin the Amazon Route 53 Application Recovery Controller Developer Guide.\n\nThis API guide includes information about the API operations for how to get and\nupdate routing control states in Route 53 ARC. To work with routing control in\nRoute 53 ARC, you must first create the required components (clusters, control\npanels, and routing controls) using the recovery cluster configuration API.\n\nFor more information about working with routing control in Route 53 ARC, see the\nfollowing:\n\n  * Create clusters, control panels, and routing controls by using API\noperations. For more information, see the [Recovery Control Configuration API Reference Guide for Amazon Route 53 Application Recovery\nController](https://docs.aws.amazon.com/recovery-cluster/latest/api/).\n\n  * Learn about the components in recovery control, including\nclusters, routing controls, and control panels, and how to work with Route 53\nARC in the Amazon Web Services console. For more information, see [ Recovery control\ncomponents](https://docs.aws.amazon.com/r53recovery/latest/dg/introduction-components.html#introduction-components-routing)\nin the Amazon Route 53 Application Recovery Controller Developer Guide.\n\n  * Route 53 ARC also provides readiness checks that continually audit\nresources to help make sure that your applications are scaled and ready to\nhandle failover traffic. For more information about the related API operations,\nsee the [Recovery Readiness API Reference Guide for Amazon Route 53 Application Recovery\nController](https://docs.aws.amazon.com/recovery-readiness/latest/api/).\n\n  * For more information about creating resilient applications and\npreparing for recovery readiness with Route 53 ARC, see the [Amazon Route 53 Application Recovery Controller Developer\nGuide](https://docs.aws.amazon.com/r53recovery/latest/dg/).","ref":"AWS.Route53RecoveryCluster.html","title":"AWS.Route53RecoveryCluster","type":"module"},{"doc":"Get the state for a routing control.\n\nA routing control is a simple on/off switch that you can use to route traffic to\ncells. When a routing control state is set to ON, traffic flows to a cell. When\nthe state is set to OFF, traffic does not flow.\n\nBefore you can create a routing control, you must first create a cluster, and\nthen host the control in a control panel on the cluster. For more information,\nsee [ Create routing control structures](https://docs.aws.amazon.com/r53recovery/latest/dg/routing-control.create.html)\nin the Amazon Route 53 Application Recovery Controller Developer Guide. You\naccess one of the endpoints for the cluster to get or update the routing control\nstate to redirect traffic for your application.\n\n*You must specify Regional endpoints when you work with API cluster operations\nto get or update routing control states in Route 53 ARC.*\n\nTo see a code example for getting a routing control state, including accessing\nRegional cluster endpoints in sequence, see [API examples](https://docs.aws.amazon.com/r53recovery/latest/dg/service_code_examples_actions.html)\nin the Amazon Route 53 Application Recovery Controller Developer Guide.\n\nLearn more about working with routing controls in the following topics in the\nAmazon Route 53 Application Recovery Controller Developer Guide:\n\n  * [ Viewing and updating routing control states](https://docs.aws.amazon.com/r53recovery/latest/dg/routing-control.update.html)\n\n  * [Working with routing controls in Route 53 ARC](https://docs.aws.amazon.com/r53recovery/latest/dg/routing-control.html)","ref":"AWS.Route53RecoveryCluster.html#get_routing_control_state/3","title":"AWS.Route53RecoveryCluster.get_routing_control_state/3","type":"function"},{"doc":"List routing control names and Amazon Resource Names (ARNs), as well as the\nrouting control state for each routing control, along with the control panel\nname and control panel ARN for the routing controls.\n\nIf you specify a control panel ARN, this call lists the routing controls in the\ncontrol panel. Otherwise, it lists all the routing controls in the cluster.\n\nA routing control is a simple on/off switch in Route 53 ARC that you can use to\nroute traffic to cells. When a routing control state is set to ON, traffic flows\nto a cell. When the state is set to OFF, traffic does not flow.\n\nBefore you can create a routing control, you must first create a cluster, and\nthen host the control in a control panel on the cluster. For more information,\nsee [ Create routing control structures](https://docs.aws.amazon.com/r53recovery/latest/dg/routing-control.create.html)\nin the Amazon Route 53 Application Recovery Controller Developer Guide. You\naccess one of the endpoints for the cluster to get or update the routing control\nstate to redirect traffic for your application.\n\n*You must specify Regional endpoints when you work with API cluster operations\nto use this API operation to list routing controls in Route 53 ARC.*\n\nLearn more about working with routing controls in the following topics in the\nAmazon Route 53 Application Recovery Controller Developer Guide:\n\n  * [ Viewing and updating routing control states](https://docs.aws.amazon.com/r53recovery/latest/dg/routing-control.update.html)\n\n  * [Working with routing controls in Route 53 ARC](https://docs.aws.amazon.com/r53recovery/latest/dg/routing-control.html)","ref":"AWS.Route53RecoveryCluster.html#list_routing_controls/3","title":"AWS.Route53RecoveryCluster.list_routing_controls/3","type":"function"},{"doc":"","ref":"AWS.Route53RecoveryCluster.html#metadata/0","title":"AWS.Route53RecoveryCluster.metadata/0","type":"function"},{"doc":"Set the state of the routing control to reroute traffic.\n\nYou can set the value to ON or OFF. When the state is ON, traffic flows to a\ncell. When the state is OFF, traffic does not flow.\n\nWith Route 53 ARC, you can add safety rules for routing controls, which are\nsafeguards for routing control state updates that help prevent unexpected\noutcomes, like fail open traffic routing. However, there are scenarios when you\nmight want to bypass the routing control safeguards that are enforced with\nsafety rules that you've configured. For example, you might want to fail over\nquickly for disaster recovery, and one or more safety rules might be\nunexpectedly preventing you from updating a routing control state to reroute\ntraffic. In a \"break glass\" scenario like this, you can override one or more\nsafety rules to change a routing control state and fail over your application.\n\nThe `SafetyRulesToOverride` property enables you override one or more safety\nrules and update routing control states. For more information, see [ Override safety rules to reroute\ntraffic](https://docs.aws.amazon.com/r53recovery/latest/dg/routing-control.override-safety-rule.html)\nin the Amazon Route 53 Application Recovery Controller Developer Guide.\n\n*You must specify Regional endpoints when you work with API cluster operations\nto get or update routing control states in Route 53 ARC.*\n\nTo see a code example for getting a routing control state, including accessing\nRegional cluster endpoints in sequence, see [API examples](https://docs.aws.amazon.com/r53recovery/latest/dg/service_code_examples_actions.html)\nin the Amazon Route 53 Application Recovery Controller Developer Guide.\n\n  * [ Viewing and updating routing control states](https://docs.aws.amazon.com/r53recovery/latest/dg/routing-control.update.html)\n\n  * [Working with routing controls overall](https://docs.aws.amazon.com/r53recovery/latest/dg/routing-control.html)","ref":"AWS.Route53RecoveryCluster.html#update_routing_control_state/3","title":"AWS.Route53RecoveryCluster.update_routing_control_state/3","type":"function"},{"doc":"Set multiple routing control states.\n\nYou can set the value for each state to be ON or OFF. When the state is ON,\ntraffic flows to a cell. When it's OFF, traffic does not flow.\n\nWith Route 53 ARC, you can add safety rules for routing controls, which are\nsafeguards for routing control state updates that help prevent unexpected\noutcomes, like fail open traffic routing. However, there are scenarios when you\nmight want to bypass the routing control safeguards that are enforced with\nsafety rules that you've configured. For example, you might want to fail over\nquickly for disaster recovery, and one or more safety rules might be\nunexpectedly preventing you from updating a routing control state to reroute\ntraffic. In a \"break glass\" scenario like this, you can override one or more\nsafety rules to change a routing control state and fail over your application.\n\nThe `SafetyRulesToOverride` property enables you override one or more safety\nrules and update routing control states. For more information, see [ Override safety rules to reroute\ntraffic](https://docs.aws.amazon.com/r53recovery/latest/dg/routing-control.override-safety-rule.html)\nin the Amazon Route 53 Application Recovery Controller Developer Guide.\n\n*You must specify Regional endpoints when you work with API cluster operations\nto get or update routing control states in Route 53 ARC.*\n\nTo see a code example for getting a routing control state, including accessing\nRegional cluster endpoints in sequence, see [API examples](https://docs.aws.amazon.com/r53recovery/latest/dg/service_code_examples_actions.html)\nin the Amazon Route 53 Application Recovery Controller Developer Guide.\n\n  * [ Viewing and updating routing control states](https://docs.aws.amazon.com/r53recovery/latest/dg/routing-control.update.html)\n\n  * [Working with routing controls overall](https://docs.aws.amazon.com/r53recovery/latest/dg/routing-control.html)","ref":"AWS.Route53RecoveryCluster.html#update_routing_control_states/3","title":"AWS.Route53RecoveryCluster.update_routing_control_states/3","type":"function"},{"doc":"Recovery Control Configuration API Reference for Amazon Route 53 Application\nRecovery Controller","ref":"AWS.Route53RecoveryControlConfig.html","title":"AWS.Route53RecoveryControlConfig","type":"module"},{"doc":"Create a new cluster.\n\nA cluster is a set of redundant Regional endpoints against which you can run API\ncalls to update or get the state of one or more routing controls. Each cluster\nhas a name, status, Amazon Resource Name (ARN), and an array of the five cluster\nendpoints (one for each supported Amazon Web Services Region) that you can use\nwith API calls to the cluster data plane.","ref":"AWS.Route53RecoveryControlConfig.html#create_cluster/3","title":"AWS.Route53RecoveryControlConfig.create_cluster/3","type":"function"},{"doc":"Creates a new control panel.\n\nA control panel represents a group of routing controls that can be changed\ntogether in a single transaction. You can use a control panel to centrally view\nthe operational status of applications across your organization, and trigger\nmulti-app failovers in a single transaction, for example, to fail over an\nAvailability Zone or Amazon Web Services Region.","ref":"AWS.Route53RecoveryControlConfig.html#create_control_panel/3","title":"AWS.Route53RecoveryControlConfig.create_control_panel/3","type":"function"},{"doc":"Creates a new routing control.\n\nA routing control has one of two states: ON and OFF. You can map the routing\ncontrol state to the state of an Amazon Route 53 health check, which can be used\nto control traffic routing.\n\nTo get or update the routing control state, see the Recovery Cluster (data\nplane) API actions for Amazon Route 53 Application Recovery Controller.","ref":"AWS.Route53RecoveryControlConfig.html#create_routing_control/3","title":"AWS.Route53RecoveryControlConfig.create_routing_control/3","type":"function"},{"doc":"Creates a safety rule in a control panel.\n\nSafety rules let you add safeguards around changing routing control states, and\nfor enabling and disabling routing controls, to help prevent unexpected\noutcomes.\n\nThere are two types of safety rules: assertion rules and gating rules.\n\nAssertion rule: An assertion rule enforces that, when you change a routing\ncontrol state, that a certain criteria is met. For example, the criteria might\nbe that at least one routing control state is On after the transaction so that\ntraffic continues to flow to at least one cell for the application. This ensures\nthat you avoid a fail-open scenario.\n\nGating rule: A gating rule lets you configure a gating routing control as an\noverall \"on/off\" switch for a group of routing controls. Or, you can configure\nmore complex gating scenarios, for example by configuring multiple gating\nrouting controls.\n\nFor more information, see [Safety rules](https://docs.aws.amazon.com/r53recovery/latest/dg/routing-control.safety-rules.html)\nin the Amazon Route 53 Application Recovery Controller Developer Guide.","ref":"AWS.Route53RecoveryControlConfig.html#create_safety_rule/3","title":"AWS.Route53RecoveryControlConfig.create_safety_rule/3","type":"function"},{"doc":"Delete a cluster.","ref":"AWS.Route53RecoveryControlConfig.html#delete_cluster/4","title":"AWS.Route53RecoveryControlConfig.delete_cluster/4","type":"function"},{"doc":"Deletes a control panel.","ref":"AWS.Route53RecoveryControlConfig.html#delete_control_panel/4","title":"AWS.Route53RecoveryControlConfig.delete_control_panel/4","type":"function"},{"doc":"Deletes a routing control.","ref":"AWS.Route53RecoveryControlConfig.html#delete_routing_control/4","title":"AWS.Route53RecoveryControlConfig.delete_routing_control/4","type":"function"},{"doc":"Deletes a safety rule.\n\n/>","ref":"AWS.Route53RecoveryControlConfig.html#delete_safety_rule/4","title":"AWS.Route53RecoveryControlConfig.delete_safety_rule/4","type":"function"},{"doc":"Display the details about a cluster.\n\nThe response includes the cluster name, endpoints, status, and Amazon Resource\nName (ARN).","ref":"AWS.Route53RecoveryControlConfig.html#describe_cluster/3","title":"AWS.Route53RecoveryControlConfig.describe_cluster/3","type":"function"},{"doc":"Displays details about a control panel.","ref":"AWS.Route53RecoveryControlConfig.html#describe_control_panel/3","title":"AWS.Route53RecoveryControlConfig.describe_control_panel/3","type":"function"},{"doc":"Displays details about a routing control.\n\nA routing control has one of two states: ON and OFF. You can map the routing\ncontrol state to the state of an Amazon Route 53 health check, which can be used\nto control routing.\n\nTo get or update the routing control state, see the Recovery Cluster (data\nplane) API actions for Amazon Route 53 Application Recovery Controller.","ref":"AWS.Route53RecoveryControlConfig.html#describe_routing_control/3","title":"AWS.Route53RecoveryControlConfig.describe_routing_control/3","type":"function"},{"doc":"Returns information about a safety rule.","ref":"AWS.Route53RecoveryControlConfig.html#describe_safety_rule/3","title":"AWS.Route53RecoveryControlConfig.describe_safety_rule/3","type":"function"},{"doc":"Get information about the resource policy for a cluster.","ref":"AWS.Route53RecoveryControlConfig.html#get_resource_policy/3","title":"AWS.Route53RecoveryControlConfig.get_resource_policy/3","type":"function"},{"doc":"Returns an array of all Amazon Route 53 health checks associated with a specific\nrouting control.","ref":"AWS.Route53RecoveryControlConfig.html#list_associated_route53_health_checks/5","title":"AWS.Route53RecoveryControlConfig.list_associated_route53_health_checks/5","type":"function"},{"doc":"Returns an array of all the clusters in an account.","ref":"AWS.Route53RecoveryControlConfig.html#list_clusters/4","title":"AWS.Route53RecoveryControlConfig.list_clusters/4","type":"function"},{"doc":"Returns an array of control panels in an account or in a cluster.","ref":"AWS.Route53RecoveryControlConfig.html#list_control_panels/5","title":"AWS.Route53RecoveryControlConfig.list_control_panels/5","type":"function"},{"doc":"Returns an array of routing controls for a control panel.\n\nA routing control is an Amazon Route 53 Application Recovery Controller\nconstruct that has one of two states: ON and OFF. You can map the routing\ncontrol state to the state of an Amazon Route 53 health check, which can be used\nto control routing.","ref":"AWS.Route53RecoveryControlConfig.html#list_routing_controls/5","title":"AWS.Route53RecoveryControlConfig.list_routing_controls/5","type":"function"},{"doc":"List the safety rules (the assertion rules and gating rules) that you've defined\nfor the routing controls in a control panel.","ref":"AWS.Route53RecoveryControlConfig.html#list_safety_rules/5","title":"AWS.Route53RecoveryControlConfig.list_safety_rules/5","type":"function"},{"doc":"Lists the tags for a resource.","ref":"AWS.Route53RecoveryControlConfig.html#list_tags_for_resource/3","title":"AWS.Route53RecoveryControlConfig.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.Route53RecoveryControlConfig.html#metadata/0","title":"AWS.Route53RecoveryControlConfig.metadata/0","type":"function"},{"doc":"Adds a tag to a resource.","ref":"AWS.Route53RecoveryControlConfig.html#tag_resource/4","title":"AWS.Route53RecoveryControlConfig.tag_resource/4","type":"function"},{"doc":"Removes a tag from a resource.","ref":"AWS.Route53RecoveryControlConfig.html#untag_resource/4","title":"AWS.Route53RecoveryControlConfig.untag_resource/4","type":"function"},{"doc":"Updates a control panel.\n\nThe only update you can make to a control panel is to change the name of the\ncontrol panel.","ref":"AWS.Route53RecoveryControlConfig.html#update_control_panel/3","title":"AWS.Route53RecoveryControlConfig.update_control_panel/3","type":"function"},{"doc":"Updates a routing control.\n\nYou can only update the name of the routing control. To get or update the\nrouting control state, see the Recovery Cluster (data plane) API actions for\nAmazon Route 53 Application Recovery Controller.","ref":"AWS.Route53RecoveryControlConfig.html#update_routing_control/3","title":"AWS.Route53RecoveryControlConfig.update_routing_control/3","type":"function"},{"doc":"Update a safety rule (an assertion rule or gating rule).\n\nYou can only update the name and the waiting period for a safety rule. To make\nother updates, delete the safety rule and create a new one.","ref":"AWS.Route53RecoveryControlConfig.html#update_safety_rule/3","title":"AWS.Route53RecoveryControlConfig.update_safety_rule/3","type":"function"},{"doc":"Recovery readiness","ref":"AWS.Route53RecoveryReadiness.html","title":"AWS.Route53RecoveryReadiness","type":"module"},{"doc":"Creates a cell in an account.","ref":"AWS.Route53RecoveryReadiness.html#create_cell/3","title":"AWS.Route53RecoveryReadiness.create_cell/3","type":"function"},{"doc":"Creates a cross-account readiness authorization.\n\nThis lets you authorize another account to work with Route 53 Application\nRecovery Controller, for example, to check the readiness status of resources in\na separate account.","ref":"AWS.Route53RecoveryReadiness.html#create_cross_account_authorization/3","title":"AWS.Route53RecoveryReadiness.create_cross_account_authorization/3","type":"function"},{"doc":"Creates a readiness check in an account.\n\nA readiness check monitors a resource set in your application, such as a set of\nAmazon Aurora instances, that Application Recovery Controller is auditing\nrecovery readiness for. The audits run once every minute on every resource\nthat's associated with a readiness check.","ref":"AWS.Route53RecoveryReadiness.html#create_readiness_check/3","title":"AWS.Route53RecoveryReadiness.create_readiness_check/3","type":"function"},{"doc":"Creates a recovery group in an account.\n\nA recovery group corresponds to an application and includes a list of the cells\nthat make up the application.","ref":"AWS.Route53RecoveryReadiness.html#create_recovery_group/3","title":"AWS.Route53RecoveryReadiness.create_recovery_group/3","type":"function"},{"doc":"Creates a resource set.\n\nA resource set is a set of resources of one type that span multiple cells. You\ncan associate a resource set with a readiness check to monitor the resources for\nfailover readiness.","ref":"AWS.Route53RecoveryReadiness.html#create_resource_set/3","title":"AWS.Route53RecoveryReadiness.create_resource_set/3","type":"function"},{"doc":"Delete a cell.\n\nWhen successful, the response code is 204, with no response body.","ref":"AWS.Route53RecoveryReadiness.html#delete_cell/4","title":"AWS.Route53RecoveryReadiness.delete_cell/4","type":"function"},{"doc":"Deletes cross account readiness authorization.","ref":"AWS.Route53RecoveryReadiness.html#delete_cross_account_authorization/4","title":"AWS.Route53RecoveryReadiness.delete_cross_account_authorization/4","type":"function"},{"doc":"Deletes a readiness check.","ref":"AWS.Route53RecoveryReadiness.html#delete_readiness_check/4","title":"AWS.Route53RecoveryReadiness.delete_readiness_check/4","type":"function"},{"doc":"Deletes a recovery group.","ref":"AWS.Route53RecoveryReadiness.html#delete_recovery_group/4","title":"AWS.Route53RecoveryReadiness.delete_recovery_group/4","type":"function"},{"doc":"Deletes a resource set.","ref":"AWS.Route53RecoveryReadiness.html#delete_resource_set/4","title":"AWS.Route53RecoveryReadiness.delete_resource_set/4","type":"function"},{"doc":"Gets recommendations about architecture designs for improving resiliency for an\napplication, based on a recovery group.","ref":"AWS.Route53RecoveryReadiness.html#get_architecture_recommendations/5","title":"AWS.Route53RecoveryReadiness.get_architecture_recommendations/5","type":"function"},{"doc":"Gets information about a cell including cell name, cell Amazon Resource Name\n(ARN), ARNs of nested cells for this cell, and a list of those cell ARNs with\ntheir associated recovery group ARNs.","ref":"AWS.Route53RecoveryReadiness.html#get_cell/3","title":"AWS.Route53RecoveryReadiness.get_cell/3","type":"function"},{"doc":"Gets readiness for a cell.\n\nAggregates the readiness of all the resources that are associated with the cell\ninto a single value.","ref":"AWS.Route53RecoveryReadiness.html#get_cell_readiness_summary/5","title":"AWS.Route53RecoveryReadiness.get_cell_readiness_summary/5","type":"function"},{"doc":"Gets details about a readiness check.","ref":"AWS.Route53RecoveryReadiness.html#get_readiness_check/3","title":"AWS.Route53RecoveryReadiness.get_readiness_check/3","type":"function"},{"doc":"Gets individual readiness status for a readiness check.\n\nTo see the overall readiness status for a recovery group, that considers the\nreadiness status for all the readiness checks in the recovery group, use\nGetRecoveryGroupReadinessSummary.","ref":"AWS.Route53RecoveryReadiness.html#get_readiness_check_resource_status/6","title":"AWS.Route53RecoveryReadiness.get_readiness_check_resource_status/6","type":"function"},{"doc":"Gets the readiness status for an individual readiness check.\n\nTo see the overall readiness status for a recovery group, that considers the\nreadiness status for all the readiness checks in a recovery group, use\nGetRecoveryGroupReadinessSummary.","ref":"AWS.Route53RecoveryReadiness.html#get_readiness_check_status/5","title":"AWS.Route53RecoveryReadiness.get_readiness_check_status/5","type":"function"},{"doc":"Gets details about a recovery group, including a list of the cells that are\nincluded in it.","ref":"AWS.Route53RecoveryReadiness.html#get_recovery_group/3","title":"AWS.Route53RecoveryReadiness.get_recovery_group/3","type":"function"},{"doc":"Displays a summary of information about a recovery group's readiness status.\n\nIncludes the readiness checks for resources in the recovery group and the\nreadiness status of each one.","ref":"AWS.Route53RecoveryReadiness.html#get_recovery_group_readiness_summary/5","title":"AWS.Route53RecoveryReadiness.get_recovery_group_readiness_summary/5","type":"function"},{"doc":"Displays the details about a resource set, including a list of the resources in\nthe set.","ref":"AWS.Route53RecoveryReadiness.html#get_resource_set/3","title":"AWS.Route53RecoveryReadiness.get_resource_set/3","type":"function"},{"doc":"Lists the cells for an account.","ref":"AWS.Route53RecoveryReadiness.html#list_cells/4","title":"AWS.Route53RecoveryReadiness.list_cells/4","type":"function"},{"doc":"Lists the cross-account readiness authorizations that are in place for an\naccount.","ref":"AWS.Route53RecoveryReadiness.html#list_cross_account_authorizations/4","title":"AWS.Route53RecoveryReadiness.list_cross_account_authorizations/4","type":"function"},{"doc":"Lists the readiness checks for an account.","ref":"AWS.Route53RecoveryReadiness.html#list_readiness_checks/4","title":"AWS.Route53RecoveryReadiness.list_readiness_checks/4","type":"function"},{"doc":"Lists the recovery groups in an account.","ref":"AWS.Route53RecoveryReadiness.html#list_recovery_groups/4","title":"AWS.Route53RecoveryReadiness.list_recovery_groups/4","type":"function"},{"doc":"Lists the resource sets in an account.","ref":"AWS.Route53RecoveryReadiness.html#list_resource_sets/4","title":"AWS.Route53RecoveryReadiness.list_resource_sets/4","type":"function"},{"doc":"Lists all readiness rules, or lists the readiness rules for a specific resource\ntype.","ref":"AWS.Route53RecoveryReadiness.html#list_rules/5","title":"AWS.Route53RecoveryReadiness.list_rules/5","type":"function"},{"doc":"Lists the tags for a resource.","ref":"AWS.Route53RecoveryReadiness.html#list_tags_for_resources/3","title":"AWS.Route53RecoveryReadiness.list_tags_for_resources/3","type":"function"},{"doc":"","ref":"AWS.Route53RecoveryReadiness.html#metadata/0","title":"AWS.Route53RecoveryReadiness.metadata/0","type":"function"},{"doc":"Adds a tag to a resource.","ref":"AWS.Route53RecoveryReadiness.html#tag_resource/4","title":"AWS.Route53RecoveryReadiness.tag_resource/4","type":"function"},{"doc":"Removes a tag from a resource.","ref":"AWS.Route53RecoveryReadiness.html#untag_resource/4","title":"AWS.Route53RecoveryReadiness.untag_resource/4","type":"function"},{"doc":"Updates a cell to replace the list of nested cells with a new list of nested\ncells.","ref":"AWS.Route53RecoveryReadiness.html#update_cell/4","title":"AWS.Route53RecoveryReadiness.update_cell/4","type":"function"},{"doc":"Updates a readiness check.","ref":"AWS.Route53RecoveryReadiness.html#update_readiness_check/4","title":"AWS.Route53RecoveryReadiness.update_readiness_check/4","type":"function"},{"doc":"Updates a recovery group.","ref":"AWS.Route53RecoveryReadiness.html#update_recovery_group/4","title":"AWS.Route53RecoveryReadiness.update_recovery_group/4","type":"function"},{"doc":"Updates a resource set.","ref":"AWS.Route53RecoveryReadiness.html#update_resource_set/4","title":"AWS.Route53RecoveryReadiness.update_resource_set/4","type":"function"},{"doc":"When you create a VPC using Amazon VPC, you automatically get DNS resolution\nwithin the VPC from Route 53 Resolver.\n\nBy default, Resolver answers DNS queries for VPC domain names such as domain\nnames for EC2 instances or Elastic Load Balancing load balancers. Resolver\nperforms recursive lookups against public name servers for all other domain\nnames.\n\nYou can also configure DNS resolution between your VPC and your network over a\nDirect Connect or VPN connection:","ref":"AWS.Route53Resolver.html","title":"AWS.Route53Resolver","type":"module"},{"doc":"DNS resolvers on your network can forward DNS queries to Resolver in a specified\nVPC. This allows your DNS resolvers to easily resolve domain names for Amazon\nWeb Services resources such as EC2 instances or records in a Route 53 private\nhosted zone. For more information, see [How DNS Resolvers on Your Network Forward DNS Queries to Route 53\nResolver](https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/resolver.html#resolver-overview-forward-network-to-vpc)\nin the *Amazon Route 53 Developer Guide*.","ref":"AWS.Route53Resolver.html#module-forward-dns-queries-from-resolvers-on-your-network-to-route-53-resolver","title":"Forward DNS queries from resolvers on your network to Route 53 Resolver - AWS.Route53Resolver","type":"module"},{"doc":"You can configure Resolver to forward queries that it receives from EC2\ninstances in your VPCs to DNS resolvers on your network. To forward selected\nqueries, you create Resolver rules that specify the domain names for the DNS\nqueries that you want to forward (such as example.com), and the IP addresses of\nthe DNS resolvers on your network that you want to forward the queries to. If a\nquery matches multiple rules (example.com, acme.example.com), Resolver chooses\nthe rule with the most specific match (acme.example.com) and forwards the query\nto the IP addresses that you specified in that rule. For more information, see\n[How Route 53 Resolver Forwards DNS Queries from Your VPCs to Your Network](https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/resolver.html#resolver-overview-forward-vpc-to-network)\nin the *Amazon Route 53 Developer Guide*.\n\nLike Amazon VPC, Resolver is Regional. In each Region where you have VPCs, you\ncan choose whether to forward queries from your VPCs to your network (outbound\nqueries), from your network to your VPCs (inbound queries), or both.","ref":"AWS.Route53Resolver.html#module-conditionally-forward-queries-from-a-vpc-to-resolvers-on-your-network","title":"Conditionally forward queries from a VPC to resolvers on your network - AWS.Route53Resolver","type":"module"},{"doc":"Associates a `FirewallRuleGroup` with a VPC, to provide DNS filtering for the\nVPC.","ref":"AWS.Route53Resolver.html#associate_firewall_rule_group/3","title":"AWS.Route53Resolver.associate_firewall_rule_group/3","type":"function"},{"doc":"Adds IP addresses to an inbound or an outbound Resolver endpoint.\n\nIf you want to add more than one IP address, submit one\n`AssociateResolverEndpointIpAddress` request for each IP address.\n\nTo remove an IP address from an endpoint, see\n[DisassociateResolverEndpointIpAddress](https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_DisassociateResolverEndpointIpAddress.html).","ref":"AWS.Route53Resolver.html#associate_resolver_endpoint_ip_address/3","title":"AWS.Route53Resolver.associate_resolver_endpoint_ip_address/3","type":"function"},{"doc":"Associates an Amazon VPC with a specified query logging configuration.\n\nRoute 53 Resolver logs DNS queries that originate in all of the Amazon VPCs that\nare associated with a specified query logging configuration. To associate more\nthan one VPC with a configuration, submit one `AssociateResolverQueryLogConfig`\nrequest for each VPC.\n\nThe VPCs that you associate with a query logging configuration must be in the\nsame Region as the configuration.\n\nTo remove a VPC from a query logging configuration, see\n[DisassociateResolverQueryLogConfig](https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_DisassociateResolverQueryLogConfig.html).","ref":"AWS.Route53Resolver.html#associate_resolver_query_log_config/3","title":"AWS.Route53Resolver.associate_resolver_query_log_config/3","type":"function"},{"doc":"Associates a Resolver rule with a VPC.\n\nWhen you associate a rule with a VPC, Resolver forwards all DNS queries for the\ndomain name that is specified in the rule and that originate in the VPC. The\nqueries are forwarded to the IP addresses for the DNS resolvers that are\nspecified in the rule. For more information about rules, see\n[CreateResolverRule](https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_CreateResolverRule.html).","ref":"AWS.Route53Resolver.html#associate_resolver_rule/3","title":"AWS.Route53Resolver.associate_resolver_rule/3","type":"function"},{"doc":"Creates an empty firewall domain list for use in DNS Firewall rules.\n\nYou can populate the domains for the new list with a file, using\n`ImportFirewallDomains`, or with domain strings, using `UpdateFirewallDomains`.","ref":"AWS.Route53Resolver.html#create_firewall_domain_list/3","title":"AWS.Route53Resolver.create_firewall_domain_list/3","type":"function"},{"doc":"Creates a single DNS Firewall rule in the specified rule group, using the\nspecified domain list.","ref":"AWS.Route53Resolver.html#create_firewall_rule/3","title":"AWS.Route53Resolver.create_firewall_rule/3","type":"function"},{"doc":"Creates an empty DNS Firewall rule group for filtering DNS network traffic in a\nVPC.\n\nYou can add rules to the new rule group by calling `CreateFirewallRule`.","ref":"AWS.Route53Resolver.html#create_firewall_rule_group/3","title":"AWS.Route53Resolver.create_firewall_rule_group/3","type":"function"},{"doc":"Creates a Route 53 Resolver on an Outpost.","ref":"AWS.Route53Resolver.html#create_outpost_resolver/3","title":"AWS.Route53Resolver.create_outpost_resolver/3","type":"function"},{"doc":"Creates a Resolver endpoint.\n\nThere are two types of Resolver endpoints, inbound and outbound:\n\n  * An *inbound Resolver endpoint* forwards DNS queries to the DNS\nservice for a VPC from your network.\n\n  * An *outbound Resolver endpoint* forwards DNS queries from the DNS\nservice for a VPC to your network.","ref":"AWS.Route53Resolver.html#create_resolver_endpoint/3","title":"AWS.Route53Resolver.create_resolver_endpoint/3","type":"function"},{"doc":"Creates a Resolver query logging configuration, which defines where you want\nResolver to save DNS query logs that originate in your VPCs.\n\nResolver can log queries only for VPCs that are in the same Region as the query\nlogging configuration.\n\nTo specify which VPCs you want to log queries for, you use\n`AssociateResolverQueryLogConfig`. For more information, see\n[AssociateResolverQueryLogConfig](https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_AssociateResolverQueryLogConfig.html).\n\nYou can optionally use Resource Access Manager (RAM) to share a query logging\nconfiguration with other Amazon Web Services accounts. The other accounts can\nthen associate VPCs with the configuration. The query logs that Resolver creates\nfor a configuration include all DNS queries that originate in all VPCs that are\nassociated with the configuration.","ref":"AWS.Route53Resolver.html#create_resolver_query_log_config/3","title":"AWS.Route53Resolver.create_resolver_query_log_config/3","type":"function"},{"doc":"For DNS queries that originate in your VPCs, specifies which Resolver endpoint\nthe queries pass through, one domain name that you want to forward to your\nnetwork, and the IP addresses of the DNS resolvers in your network.","ref":"AWS.Route53Resolver.html#create_resolver_rule/3","title":"AWS.Route53Resolver.create_resolver_rule/3","type":"function"},{"doc":"Deletes the specified domain list.","ref":"AWS.Route53Resolver.html#delete_firewall_domain_list/3","title":"AWS.Route53Resolver.delete_firewall_domain_list/3","type":"function"},{"doc":"Deletes the specified firewall rule.","ref":"AWS.Route53Resolver.html#delete_firewall_rule/3","title":"AWS.Route53Resolver.delete_firewall_rule/3","type":"function"},{"doc":"Deletes the specified firewall rule group.","ref":"AWS.Route53Resolver.html#delete_firewall_rule_group/3","title":"AWS.Route53Resolver.delete_firewall_rule_group/3","type":"function"},{"doc":"Deletes a Resolver on the Outpost.","ref":"AWS.Route53Resolver.html#delete_outpost_resolver/3","title":"AWS.Route53Resolver.delete_outpost_resolver/3","type":"function"},{"doc":"Deletes a Resolver endpoint.\n\nThe effect of deleting a Resolver endpoint depends on whether it's an inbound or\nan outbound Resolver endpoint:\n\n  * **Inbound**: DNS queries from your network are no longer routed to\nthe DNS service for the specified VPC.\n\n  * **Outbound**: DNS queries from a VPC are no longer routed to your\nnetwork.","ref":"AWS.Route53Resolver.html#delete_resolver_endpoint/3","title":"AWS.Route53Resolver.delete_resolver_endpoint/3","type":"function"},{"doc":"Deletes a query logging configuration.\n\nWhen you delete a configuration, Resolver stops logging DNS queries for all of\nthe Amazon VPCs that are associated with the configuration. This also applies if\nthe query logging configuration is shared with other Amazon Web Services\naccounts, and the other accounts have associated VPCs with the shared\nconfiguration.\n\nBefore you can delete a query logging configuration, you must first disassociate\nall VPCs from the configuration. See\n[DisassociateResolverQueryLogConfig](https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_DisassociateResolverQueryLogConfig.html).\n\nIf you used Resource Access Manager (RAM) to share a query logging configuration\nwith other accounts, you must stop sharing the configuration before you can\ndelete a configuration. The accounts that you shared the configuration with can\nfirst disassociate VPCs that they associated with the configuration, but that's\nnot necessary. If you stop sharing the configuration, those VPCs are\nautomatically disassociated from the configuration.","ref":"AWS.Route53Resolver.html#delete_resolver_query_log_config/3","title":"AWS.Route53Resolver.delete_resolver_query_log_config/3","type":"function"},{"doc":"Deletes a Resolver rule.\n\nBefore you can delete a Resolver rule, you must disassociate it from all the\nVPCs that you associated the Resolver rule with. For more information, see\n[DisassociateResolverRule](https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_DisassociateResolverRule.html).","ref":"AWS.Route53Resolver.html#delete_resolver_rule/3","title":"AWS.Route53Resolver.delete_resolver_rule/3","type":"function"},{"doc":"Disassociates a `FirewallRuleGroup` from a VPC, to remove DNS filtering from the\nVPC.","ref":"AWS.Route53Resolver.html#disassociate_firewall_rule_group/3","title":"AWS.Route53Resolver.disassociate_firewall_rule_group/3","type":"function"},{"doc":"Removes IP addresses from an inbound or an outbound Resolver endpoint.\n\nIf you want to remove more than one IP address, submit one\n`DisassociateResolverEndpointIpAddress` request for each IP address.\n\nTo add an IP address to an endpoint, see\n[AssociateResolverEndpointIpAddress](https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_AssociateResolverEndpointIpAddress.html).","ref":"AWS.Route53Resolver.html#disassociate_resolver_endpoint_ip_address/3","title":"AWS.Route53Resolver.disassociate_resolver_endpoint_ip_address/3","type":"function"},{"doc":"Disassociates a VPC from a query logging configuration.\n\nBefore you can delete a query logging configuration, you must first disassociate\nall VPCs from the configuration. If you used Resource Access Manager (RAM) to\nshare a query logging configuration with other accounts, VPCs can be\ndisassociated from the configuration in the following ways:\n\n   The accounts that you shared the configuration with can\ndisassociate VPCs from the configuration.\n\n   You can stop sharing the configuration.","ref":"AWS.Route53Resolver.html#disassociate_resolver_query_log_config/3","title":"AWS.Route53Resolver.disassociate_resolver_query_log_config/3","type":"function"},{"doc":"Removes the association between a specified Resolver rule and a specified VPC.\n\nIf you disassociate a Resolver rule from a VPC, Resolver stops forwarding DNS\nqueries for the domain name that you specified in the Resolver rule.","ref":"AWS.Route53Resolver.html#disassociate_resolver_rule/3","title":"AWS.Route53Resolver.disassociate_resolver_rule/3","type":"function"},{"doc":"Retrieves the configuration of the firewall behavior provided by DNS Firewall\nfor a single VPC from Amazon Virtual Private Cloud (Amazon VPC).","ref":"AWS.Route53Resolver.html#get_firewall_config/3","title":"AWS.Route53Resolver.get_firewall_config/3","type":"function"},{"doc":"Retrieves the specified firewall domain list.","ref":"AWS.Route53Resolver.html#get_firewall_domain_list/3","title":"AWS.Route53Resolver.get_firewall_domain_list/3","type":"function"},{"doc":"Retrieves the specified firewall rule group.","ref":"AWS.Route53Resolver.html#get_firewall_rule_group/3","title":"AWS.Route53Resolver.get_firewall_rule_group/3","type":"function"},{"doc":"Retrieves a firewall rule group association, which enables DNS filtering for a\nVPC with one rule group.\n\nA VPC can have more than one firewall rule group association, and a rule group\ncan be associated with more than one VPC.","ref":"AWS.Route53Resolver.html#get_firewall_rule_group_association/3","title":"AWS.Route53Resolver.get_firewall_rule_group_association/3","type":"function"},{"doc":"Returns the Identity and Access Management (Amazon Web Services IAM) policy for\nsharing the specified rule group.\n\nYou can use the policy to share the rule group using Resource Access Manager\n(RAM).","ref":"AWS.Route53Resolver.html#get_firewall_rule_group_policy/3","title":"AWS.Route53Resolver.get_firewall_rule_group_policy/3","type":"function"},{"doc":"Gets information about a specified Resolver on the Outpost, such as its instance\ncount and type, name, and the current status of the Resolver.","ref":"AWS.Route53Resolver.html#get_outpost_resolver/3","title":"AWS.Route53Resolver.get_outpost_resolver/3","type":"function"},{"doc":"Retrieves the behavior configuration of Route 53 Resolver behavior for a single\nVPC from Amazon Virtual Private Cloud.","ref":"AWS.Route53Resolver.html#get_resolver_config/3","title":"AWS.Route53Resolver.get_resolver_config/3","type":"function"},{"doc":"Gets DNSSEC validation information for a specified resource.","ref":"AWS.Route53Resolver.html#get_resolver_dnssec_config/3","title":"AWS.Route53Resolver.get_resolver_dnssec_config/3","type":"function"},{"doc":"Gets information about a specified Resolver endpoint, such as whether it's an\ninbound or an outbound Resolver endpoint, and the current status of the\nendpoint.","ref":"AWS.Route53Resolver.html#get_resolver_endpoint/3","title":"AWS.Route53Resolver.get_resolver_endpoint/3","type":"function"},{"doc":"Gets information about a specified Resolver query logging configuration, such as\nthe number of VPCs that the configuration is logging queries for and the\nlocation that logs are sent to.","ref":"AWS.Route53Resolver.html#get_resolver_query_log_config/3","title":"AWS.Route53Resolver.get_resolver_query_log_config/3","type":"function"},{"doc":"Gets information about a specified association between a Resolver query logging\nconfiguration and an Amazon VPC.\n\nWhen you associate a VPC with a query logging configuration, Resolver logs DNS\nqueries that originate in that VPC.","ref":"AWS.Route53Resolver.html#get_resolver_query_log_config_association/3","title":"AWS.Route53Resolver.get_resolver_query_log_config_association/3","type":"function"},{"doc":"Gets information about a query logging policy.\n\nA query logging policy specifies the Resolver query logging operations and\nresources that you want to allow another Amazon Web Services account to be able\nto use.","ref":"AWS.Route53Resolver.html#get_resolver_query_log_config_policy/3","title":"AWS.Route53Resolver.get_resolver_query_log_config_policy/3","type":"function"},{"doc":"Gets information about a specified Resolver rule, such as the domain name that\nthe rule forwards DNS queries for and the ID of the outbound Resolver endpoint\nthat the rule is associated with.","ref":"AWS.Route53Resolver.html#get_resolver_rule/3","title":"AWS.Route53Resolver.get_resolver_rule/3","type":"function"},{"doc":"Gets information about an association between a specified Resolver rule and a\nVPC.\n\nYou associate a Resolver rule and a VPC using\n[AssociateResolverRule](https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_AssociateResolverRule.html).","ref":"AWS.Route53Resolver.html#get_resolver_rule_association/3","title":"AWS.Route53Resolver.get_resolver_rule_association/3","type":"function"},{"doc":"Gets information about the Resolver rule policy for a specified rule.\n\nA Resolver rule policy includes the rule that you want to share with another\naccount, the account that you want to share the rule with, and the Resolver\noperations that you want to allow the account to use.","ref":"AWS.Route53Resolver.html#get_resolver_rule_policy/3","title":"AWS.Route53Resolver.get_resolver_rule_policy/3","type":"function"},{"doc":"Imports domain names from a file into a domain list, for use in a DNS firewall\nrule group.\n\nEach domain specification in your domain list must satisfy the following\nrequirements:\n\n  * It can optionally start with `*` (asterisk).\n\n  * With the exception of the optional starting asterisk, it must only\ncontain the following characters: `A-Z`, `a-z`, `0-9`, `-` (hyphen).\n\n  * It must be from 1-255 characters in length.","ref":"AWS.Route53Resolver.html#import_firewall_domains/3","title":"AWS.Route53Resolver.import_firewall_domains/3","type":"function"},{"doc":"Retrieves the firewall configurations that you have defined.\n\nDNS Firewall uses the configurations to manage firewall behavior for your VPCs.\n\nA single call might return only a partial list of the configurations. For\ninformation, see `MaxResults`.","ref":"AWS.Route53Resolver.html#list_firewall_configs/3","title":"AWS.Route53Resolver.list_firewall_configs/3","type":"function"},{"doc":"Retrieves the firewall domain lists that you have defined.\n\nFor each firewall domain list, you can retrieve the domains that are defined for\na list by calling `ListFirewallDomains`.\n\nA single call to this list operation might return only a partial list of the\ndomain lists. For information, see `MaxResults`.","ref":"AWS.Route53Resolver.html#list_firewall_domain_lists/3","title":"AWS.Route53Resolver.list_firewall_domain_lists/3","type":"function"},{"doc":"Retrieves the domains that you have defined for the specified firewall domain\nlist.\n\nA single call might return only a partial list of the domains. For information,\nsee `MaxResults`.","ref":"AWS.Route53Resolver.html#list_firewall_domains/3","title":"AWS.Route53Resolver.list_firewall_domains/3","type":"function"},{"doc":"Retrieves the firewall rule group associations that you have defined.\n\nEach association enables DNS filtering for a VPC with one rule group.\n\nA single call might return only a partial list of the associations. For\ninformation, see `MaxResults`.","ref":"AWS.Route53Resolver.html#list_firewall_rule_group_associations/3","title":"AWS.Route53Resolver.list_firewall_rule_group_associations/3","type":"function"},{"doc":"Retrieves the minimal high-level information for the rule groups that you have\ndefined.\n\nA single call might return only a partial list of the rule groups. For\ninformation, see `MaxResults`.","ref":"AWS.Route53Resolver.html#list_firewall_rule_groups/3","title":"AWS.Route53Resolver.list_firewall_rule_groups/3","type":"function"},{"doc":"Retrieves the firewall rules that you have defined for the specified firewall\nrule group.\n\nDNS Firewall uses the rules in a rule group to filter DNS network traffic for a\nVPC.\n\nA single call might return only a partial list of the rules. For information,\nsee `MaxResults`.","ref":"AWS.Route53Resolver.html#list_firewall_rules/3","title":"AWS.Route53Resolver.list_firewall_rules/3","type":"function"},{"doc":"Lists all the Resolvers on Outposts that were created using the current Amazon\nWeb Services account.","ref":"AWS.Route53Resolver.html#list_outpost_resolvers/3","title":"AWS.Route53Resolver.list_outpost_resolvers/3","type":"function"},{"doc":"Retrieves the Resolver configurations that you have defined.\n\nRoute 53 Resolver uses the configurations to manage DNS resolution behavior for\nyour VPCs.","ref":"AWS.Route53Resolver.html#list_resolver_configs/3","title":"AWS.Route53Resolver.list_resolver_configs/3","type":"function"},{"doc":"Lists the configurations for DNSSEC validation that are associated with the\ncurrent Amazon Web Services account.","ref":"AWS.Route53Resolver.html#list_resolver_dnssec_configs/3","title":"AWS.Route53Resolver.list_resolver_dnssec_configs/3","type":"function"},{"doc":"Gets the IP addresses for a specified Resolver endpoint.","ref":"AWS.Route53Resolver.html#list_resolver_endpoint_ip_addresses/3","title":"AWS.Route53Resolver.list_resolver_endpoint_ip_addresses/3","type":"function"},{"doc":"Lists all the Resolver endpoints that were created using the current Amazon Web\nServices account.","ref":"AWS.Route53Resolver.html#list_resolver_endpoints/3","title":"AWS.Route53Resolver.list_resolver_endpoints/3","type":"function"},{"doc":"Lists information about associations between Amazon VPCs and query logging\nconfigurations.","ref":"AWS.Route53Resolver.html#list_resolver_query_log_config_associations/3","title":"AWS.Route53Resolver.list_resolver_query_log_config_associations/3","type":"function"},{"doc":"Lists information about the specified query logging configurations.\n\nEach configuration defines where you want Resolver to save DNS query logs and\nspecifies the VPCs that you want to log queries for.","ref":"AWS.Route53Resolver.html#list_resolver_query_log_configs/3","title":"AWS.Route53Resolver.list_resolver_query_log_configs/3","type":"function"},{"doc":"Lists the associations that were created between Resolver rules and VPCs using\nthe current Amazon Web Services account.","ref":"AWS.Route53Resolver.html#list_resolver_rule_associations/3","title":"AWS.Route53Resolver.list_resolver_rule_associations/3","type":"function"},{"doc":"Lists the Resolver rules that were created using the current Amazon Web Services\naccount.","ref":"AWS.Route53Resolver.html#list_resolver_rules/3","title":"AWS.Route53Resolver.list_resolver_rules/3","type":"function"},{"doc":"Lists the tags that you associated with the specified resource.","ref":"AWS.Route53Resolver.html#list_tags_for_resource/3","title":"AWS.Route53Resolver.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.Route53Resolver.html#metadata/0","title":"AWS.Route53Resolver.metadata/0","type":"function"},{"doc":"Attaches an Identity and Access Management (Amazon Web Services IAM) policy for\nsharing the rule group.\n\nYou can use the policy to share the rule group using Resource Access Manager\n(RAM).","ref":"AWS.Route53Resolver.html#put_firewall_rule_group_policy/3","title":"AWS.Route53Resolver.put_firewall_rule_group_policy/3","type":"function"},{"doc":"Specifies an Amazon Web Services account that you want to share a query logging\nconfiguration with, the query logging configuration that you want to share, and\nthe operations that you want the account to be able to perform on the\nconfiguration.","ref":"AWS.Route53Resolver.html#put_resolver_query_log_config_policy/3","title":"AWS.Route53Resolver.put_resolver_query_log_config_policy/3","type":"function"},{"doc":"Specifies an Amazon Web Services rule that you want to share with another\naccount, the account that you want to share the rule with, and the operations\nthat you want the account to be able to perform on the rule.","ref":"AWS.Route53Resolver.html#put_resolver_rule_policy/3","title":"AWS.Route53Resolver.put_resolver_rule_policy/3","type":"function"},{"doc":"Adds one or more tags to a specified resource.","ref":"AWS.Route53Resolver.html#tag_resource/3","title":"AWS.Route53Resolver.tag_resource/3","type":"function"},{"doc":"Removes one or more tags from a specified resource.","ref":"AWS.Route53Resolver.html#untag_resource/3","title":"AWS.Route53Resolver.untag_resource/3","type":"function"},{"doc":"Updates the configuration of the firewall behavior provided by DNS Firewall for\na single VPC from Amazon Virtual Private Cloud (Amazon VPC).","ref":"AWS.Route53Resolver.html#update_firewall_config/3","title":"AWS.Route53Resolver.update_firewall_config/3","type":"function"},{"doc":"Updates the firewall domain list from an array of domain specifications.","ref":"AWS.Route53Resolver.html#update_firewall_domains/3","title":"AWS.Route53Resolver.update_firewall_domains/3","type":"function"},{"doc":"Updates the specified firewall rule.","ref":"AWS.Route53Resolver.html#update_firewall_rule/3","title":"AWS.Route53Resolver.update_firewall_rule/3","type":"function"},{"doc":"Changes the association of a `FirewallRuleGroup` with a VPC.\n\nThe association enables DNS filtering for the VPC.","ref":"AWS.Route53Resolver.html#update_firewall_rule_group_association/3","title":"AWS.Route53Resolver.update_firewall_rule_group_association/3","type":"function"},{"doc":"You can use `UpdateOutpostResolver` to update the instance count, type, or name\nof a Resolver on an Outpost.","ref":"AWS.Route53Resolver.html#update_outpost_resolver/3","title":"AWS.Route53Resolver.update_outpost_resolver/3","type":"function"},{"doc":"Updates the behavior configuration of Route 53 Resolver behavior for a single\nVPC from Amazon Virtual Private Cloud.","ref":"AWS.Route53Resolver.html#update_resolver_config/3","title":"AWS.Route53Resolver.update_resolver_config/3","type":"function"},{"doc":"Updates an existing DNSSEC validation configuration.\n\nIf there is no existing DNSSEC validation configuration, one is created.","ref":"AWS.Route53Resolver.html#update_resolver_dnssec_config/3","title":"AWS.Route53Resolver.update_resolver_dnssec_config/3","type":"function"},{"doc":"Updates the name, or endpoint type for an inbound or an outbound Resolver\nendpoint.\n\nYou can only update between IPV4 and DUALSTACK, IPV6 endpoint type can't be\nupdated to other type.","ref":"AWS.Route53Resolver.html#update_resolver_endpoint/3","title":"AWS.Route53Resolver.update_resolver_endpoint/3","type":"function"},{"doc":"Updates settings for a specified Resolver rule.\n\n`ResolverRuleId` is required, and all other parameters are optional. If you\ndon't specify a parameter, it retains its current value.","ref":"AWS.Route53Resolver.html#update_resolver_rule/3","title":"AWS.Route53Resolver.update_resolver_rule/3","type":"function"},{"doc":"","ref":"AWS.S3.html","title":"AWS.S3","type":"module"},{"doc":"This operation aborts a multipart upload.\n\nAfter a multipart upload is aborted, no additional parts can be uploaded using\nthat upload ID. The storage consumed by any previously uploaded parts will be\nfreed. However, if any part uploads are currently in progress, those part\nuploads might or might not succeed. As a result, it might be necessary to abort\na given multipart upload multiple times in order to completely free all storage\nconsumed by all parts.\n\nTo verify that all parts have been removed and prevent getting charged for the\npart storage, you should call the\n[ListParts](https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListParts.html) API operation and ensure that the parts list is empty.\n\n**Directory buckets** - For directory buckets, you must make requests for this\nAPI operation to the Zonal endpoint. These endpoints support\nvirtual-hosted-style requests in the format\n`https://*bucket_name*.s3express-*az_id*.*region*.amazonaws.com/*key-name* `.\nPath-style requests are not supported. For more information, see [Regional and\nZonal\nendpoints](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-express-Regions-and-Zones.html)\nin the *Amazon S3 User Guide*.","ref":"AWS.S3.html#abort_multipart_upload/5","title":"AWS.S3.abort_multipart_upload/5","type":"function"},{"doc":"#","ref":"AWS.S3.html#abort_multipart_upload/5-definitions","title":"Definitions - AWS.S3.abort_multipart_upload/5","type":"function"},{"doc":"**General purpose bucket permissions** - For information about\npermissions required to use the multipart upload, see [Multipart Upload and Permissions](https://docs.aws.amazon.com/AmazonS3/latest/dev/mpuAndPermissions.html)\nin the *Amazon S3 User Guide*.\n\n   **Directory bucket permissions** - To grant access to this API\noperation on a directory bucket, we recommend that you use the [ `CreateSession`\n](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateSession.html) API\noperation for session-based authorization. Specifically, you grant the\n`s3express:CreateSession` permission to the directory bucket in a bucket policy\nor an IAM identity-based policy. Then, you make the `CreateSession` API call on\nthe bucket to obtain a session token. With the session token in your request\nheader, you can make API requests to this operation. After the session token\nexpires, you make another `CreateSession` API call to generate a new session\ntoken for use. Amazon Web Services CLI or SDKs create session and refresh the\nsession token automatically to avoid service interruptions when a session\nexpires. For more information about authorization, see [ `CreateSession`\n](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateSession.html).\n\n#","ref":"AWS.S3.html#abort_multipart_upload/5-permissions","title":"Permissions - AWS.S3.abort_multipart_upload/5","type":"function"},{"doc":"**Directory buckets ** - The HTTP Host header syntax is `\n*Bucket_name*.s3express-*az_id*.*region*.amazonaws.com`.\n\nThe following operations are related to `AbortMultipartUpload`:\n\n  *\n[CreateMultipartUpload](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateMultipartUpload.html)     *\n[UploadPart](https://docs.aws.amazon.com/AmazonS3/latest/API/API_UploadPart.html)\n\n  *\n[CompleteMultipartUpload](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CompleteMultipartUpload.html)     *\n[ListParts](https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListParts.html)\n\n  *\n[ListMultipartUploads](https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListMultipartUploads.html)","ref":"AWS.S3.html#abort_multipart_upload/5-http-host-header-syntax","title":"HTTP Host header syntax - AWS.S3.abort_multipart_upload/5","type":"function"},{"doc":"Completes a multipart upload by assembling previously uploaded parts.\n\nYou first initiate the multipart upload and then upload all parts using the\n[UploadPart](https://docs.aws.amazon.com/AmazonS3/latest/API/API_UploadPart.html) operation or the\n[UploadPartCopy](https://docs.aws.amazon.com/AmazonS3/latest/API/API_UploadPartCopy.html)\noperation. After successfully uploading all relevant parts of an upload, you\ncall this `CompleteMultipartUpload` operation to complete the upload. Upon\nreceiving this request, Amazon S3 concatenates all the parts in ascending order\nby part number to create a new object. In the CompleteMultipartUpload request,\nyou must provide the parts list and ensure that the parts list is complete. The\nCompleteMultipartUpload API operation concatenates the parts that you provide in\nthe list. For each part in the list, you must provide the `PartNumber` value and\nthe `ETag` value that are returned after that part was uploaded.\n\nThe processing of a CompleteMultipartUpload request could take several minutes\nto finalize. After Amazon S3 begins processing the request, it sends an HTTP\nresponse header that specifies a `200 OK` response. While processing is in\nprogress, Amazon S3 periodically sends white space characters to keep the\nconnection from timing out. A request could fail after the initial `200 OK`\nresponse has been sent. This means that a `200 OK` response can contain either a\nsuccess or an error. The error response might be embedded in the `200 OK`\nresponse. If you call this API operation directly, make sure to design your\napplication to parse the contents of the response and handle it appropriately.\nIf you use Amazon Web Services SDKs, SDKs handle this condition. The SDKs detect\nthe embedded error and apply error handling per your configuration settings\n(including automatically retrying the request as appropriate). If the condition\npersists, the SDKs throw an exception (or, for the SDKs that don't use\nexceptions, they return an error).\n\nNote that if `CompleteMultipartUpload` fails, applications should be prepared to\nretry the failed requests. For more information, see [Amazon S3 Error Best Practices](https://docs.aws.amazon.com/AmazonS3/latest/dev/ErrorBestPractices.html).\n\nYou can't use `Content-Type: application/x-www-form-urlencoded` for the\nCompleteMultipartUpload requests. Also, if you don't provide a `Content-Type`\nheader, `CompleteMultipartUpload` can still return a `200 OK` response.\n\nFor more information about multipart uploads, see [Uploading Objects Using Multipart\nUpload](https://docs.aws.amazon.com/AmazonS3/latest/dev/uploadobjusingmpu.html)\nin the *Amazon S3 User Guide*.\n\n**Directory buckets** - For directory buckets, you must make requests for this\nAPI operation to the Zonal endpoint. These endpoints support\nvirtual-hosted-style requests in the format\n`https://*bucket_name*.s3express-*az_id*.*region*.amazonaws.com/*key-name* `.\nPath-style requests are not supported. For more information, see [Regional and Zonal\nendpoints](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-express-Regions-and-Zones.html)\nin the *Amazon S3 User Guide*.","ref":"AWS.S3.html#complete_multipart_upload/5","title":"AWS.S3.complete_multipart_upload/5","type":"function"},{"doc":"#","ref":"AWS.S3.html#complete_multipart_upload/5-definitions","title":"Definitions - AWS.S3.complete_multipart_upload/5","type":"function"},{"doc":"**General purpose bucket permissions** - For information about\npermissions required to use the multipart upload API, see [Multipart Upload and Permissions](https://docs.aws.amazon.com/AmazonS3/latest/dev/mpuAndPermissions.html)\nin the *Amazon S3 User Guide*.\n\n   **Directory bucket permissions** - To grant access to this API\noperation on a directory bucket, we recommend that you use the [ `CreateSession`\n](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateSession.html) API\noperation for session-based authorization. Specifically, you grant the\n`s3express:CreateSession` permission to the directory bucket in a bucket policy\nor an IAM identity-based policy. Then, you make the `CreateSession` API call on\nthe bucket to obtain a session token. With the session token in your request\nheader, you can make API requests to this operation. After the session token\nexpires, you make another `CreateSession` API call to generate a new session\ntoken for use. Amazon Web Services CLI or SDKs create session and refresh the\nsession token automatically to avoid service interruptions when a session\nexpires. For more information about authorization, see [ `CreateSession`\n](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateSession.html).\n\n#","ref":"AWS.S3.html#complete_multipart_upload/5-permissions","title":"Permissions - AWS.S3.complete_multipart_upload/5","type":"function"},{"doc":"Error Code: `EntityTooSmall`\n\n     Description: Your proposed upload is smaller than the\nminimum allowed object size. Each part must be at least 5 MB in size, except the\nlast part.\n\n     HTTP Status Code: 400 Bad Request\n\n   Error Code: `InvalidPart`\n\n     Description: One or more of the specified parts could\nnot be found. The part might not have been uploaded, or the specified ETag might\nnot have matched the uploaded part's ETag.\n\n     HTTP Status Code: 400 Bad Request\n\n   Error Code: `InvalidPartOrder`\n\n     Description: The list of parts was not in ascending\norder. The parts list must be specified in order by part number.\n\n     HTTP Status Code: 400 Bad Request\n\n   Error Code: `NoSuchUpload`\n\n     Description: The specified multipart upload does not\nexist. The upload ID might be invalid, or the multipart upload might have been\naborted or completed.\n\n     HTTP Status Code: 404 Not Found\n\n#","ref":"AWS.S3.html#complete_multipart_upload/5-special-errors","title":"Special errors - AWS.S3.complete_multipart_upload/5","type":"function"},{"doc":"**Directory buckets ** - The HTTP Host header syntax is `\n*Bucket_name*.s3express-*az_id*.*region*.amazonaws.com`.\n\nThe following operations are related to `CompleteMultipartUpload`:\n\n  *\n[CreateMultipartUpload](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateMultipartUpload.html)     *\n[UploadPart](https://docs.aws.amazon.com/AmazonS3/latest/API/API_UploadPart.html)\n\n  *\n[AbortMultipartUpload](https://docs.aws.amazon.com/AmazonS3/latest/API/API_AbortMultipartUpload.html)     *\n[ListParts](https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListParts.html)\n\n  *\n[ListMultipartUploads](https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListMultipartUploads.html)","ref":"AWS.S3.html#complete_multipart_upload/5-http-host-header-syntax","title":"HTTP Host header syntax - AWS.S3.complete_multipart_upload/5","type":"function"},{"doc":"Creates a copy of an object that is already stored in Amazon S3.\n\nYou can store individual objects of up to 5 TB in Amazon S3. You create a copy\nof your object up to 5 GB in size in a single atomic action using this API.\nHowever, to copy an object greater than 5 GB, you must use the multipart upload\nUpload Part - Copy (UploadPartCopy) API. For more information, see [Copy Object Using the REST Multipart Upload\nAPI](https://docs.aws.amazon.com/AmazonS3/latest/dev/CopyingObjctsUsingRESTMPUapi.html).\n\nYou can copy individual objects between general purpose buckets, between\ndirectory buckets, and between general purpose buckets and directory buckets.\n\n**Directory buckets ** - For directory buckets, you must make requests for this\nAPI operation to the Zonal endpoint. These endpoints support\nvirtual-hosted-style requests in the format\n`https://*bucket_name*.s3express-*az_id*.*region*.amazonaws.com/*key-name* `.\nPath-style requests are not supported. For more information, see [Regional and Zonal\nendpoints](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-express-Regions-and-Zones.html)\nin the *Amazon S3 User Guide*.\n\nBoth the Region that you want to copy the object from and the Region that you\nwant to copy the object to must be enabled for your account.\n\nAmazon S3 transfer acceleration does not support cross-Region copies. If you\nrequest a cross-Region copy using a transfer acceleration endpoint, you get a\n`400 Bad Request` error. For more information, see [Transfer Acceleration](https://docs.aws.amazon.com/AmazonS3/latest/dev/transfer-acceleration.html).","ref":"AWS.S3.html#copy_object/5","title":"AWS.S3.copy_object/5","type":"function"},{"doc":"#","ref":"AWS.S3.html#copy_object/5-definitions","title":"Definitions - AWS.S3.copy_object/5","type":"function"},{"doc":"All `CopyObject` requests must be authenticated and signed by using IAM\ncredentials (access key ID and secret access key for the IAM identities). All\nheaders with the `x-amz-` prefix, including `x-amz-copy-source`, must be signed.\nFor more information, see [REST Authentication](https://docs.aws.amazon.com/AmazonS3/latest/dev/RESTAuthentication.html).\n\n**Directory buckets** - You must use the IAM credentials to authenticate and\nauthorize your access to the `CopyObject` API operation, instead of using the\ntemporary security credentials through the `CreateSession` API operation.\n\nAmazon Web Services CLI or SDKs handles authentication and authorization on your\nbehalf.\n\n#","ref":"AWS.S3.html#copy_object/5-authentication-and-authorization","title":"Authentication and authorization - AWS.S3.copy_object/5","type":"function"},{"doc":"You must have *read* access to the source object and *write* access to the\ndestination bucket.\n\n   **General purpose bucket permissions** - You must have permissions\nin an IAM policy based on the source and destination bucket types in a\n`CopyObject` operation.\n\n     If the source object is in a general purpose bucket,\nyou must have ** `s3:GetObject` ** permission to read the source object that is\nbeing copied.\n\n     If the destination bucket is a general purpose bucket,\nyou must have ** `s3:PubObject` ** permission to write the object copy to the\ndestination bucket.\n\n   **Directory bucket permissions** - You must have permissions in a\nbucket policy or an IAM identity-based policy based on the source and\ndestination bucket types in a `CopyObject` operation.\n\n     If the source object that you want to copy is in a\ndirectory bucket, you must have the ** `s3express:CreateSession` ** permission\nin the `Action` element of a policy to read the object. By default, the session\nis in the `ReadWrite` mode. If you want to restrict the access, you can\nexplicitly set the `s3express:SessionMode` condition key to `ReadOnly` on the\ncopy source bucket.\n\n     If the copy destination is a directory bucket, you must\nhave the ** `s3express:CreateSession` ** permission in the `Action` element of a\npolicy to write the object to the destination. The `s3express:SessionMode`\ncondition key can't be set to `ReadOnly` on the copy destination bucket.\n\nFor example policies, see [Example bucket policies for S3 Express One Zone](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-express-security-iam-example-bucket-policies.html)\nand [Amazon Web Services Identity and Access Management (IAM) identity-based policies for S3 Express One\nZone](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-express-security-iam-identity-policies.html)\nin the *Amazon S3 User Guide*.\n\n#","ref":"AWS.S3.html#copy_object/5-permissions","title":"Permissions - AWS.S3.copy_object/5","type":"function"},{"doc":"When the request is an HTTP 1.1 request, the response is chunk encoded. When the\nrequest is not an HTTP 1.1 request, the response would not contain the\n`Content-Length`. You always need to read the entire response body to check if\nthe copy succeeds. to keep the connection alive while we copy the data.\n\n   If the copy is successful, you receive a response with information\nabout the copied object.\n\n   A copy request might return an error when Amazon S3 receives the\ncopy request or while Amazon S3 is copying the files. A `200 OK` response can\ncontain either a success or an error.\n\n     If the error occurs before the copy action starts, you\nreceive a standard Amazon S3 error.\n\n     If the error occurs during the copy operation, the\nerror response is embedded in the `200 OK` response. For example, in a\ncross-region copy, you may encounter throttling and receive a `200 OK` response.\nFor more information, see [Resolve the Error 200 response when copying objects to Amazon S3](repost.aws/knowledge-center/s3-resolve-200-internalerror). The\n`200 OK` status code means the copy was accepted, but it doesn't mean the copy\nis complete. Another example is when you disconnect from Amazon S3 before the\ncopy is complete, Amazon S3 might cancel the copy and you may receive a `200 OK`\nresponse. You must stay connected to Amazon S3 until the entire response is\nsuccessfully received and processed.\n\nIf you call this API operation directly, make sure to design your application to\nparse the content of the response and handle it appropriately. If you use Amazon\nWeb Services SDKs, SDKs handle this condition. The SDKs detect the embedded\nerror and apply error handling per your configuration settings (including\nautomatically retrying the request as appropriate). If the condition persists,\nthe SDKs throw an exception (or, for the SDKs that don't use exceptions, they\nreturn an error).\n\n#","ref":"AWS.S3.html#copy_object/5-response-and-special-errors","title":"Response and special errors - AWS.S3.copy_object/5","type":"function"},{"doc":"The copy request charge is based on the storage class and Region that you\nspecify for the destination object. The request can also result in a data\nretrieval charge for the source if the source storage class bills for data\nretrieval. For pricing information, see [Amazon S3 pricing](http://aws.amazon.com/s3/pricing/).\n\n#","ref":"AWS.S3.html#copy_object/5-charge","title":"Charge - AWS.S3.copy_object/5","type":"function"},{"doc":"**Directory buckets ** - The HTTP Host header syntax is `\n*Bucket_name*.s3express-*az_id*.*region*.amazonaws.com`.\n\nThe following operations are related to `CopyObject`:\n\n  *\n[PutObject](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObject.html)     *\n[GetObject](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObject.html)","ref":"AWS.S3.html#copy_object/5-http-host-header-syntax","title":"HTTP Host header syntax - AWS.S3.copy_object/5","type":"function"},{"doc":"This action creates an Amazon S3 bucket.\n\nTo create an Amazon S3 on Outposts bucket, see [ `CreateBucket`\n](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_CreateBucket.html).\n\nCreates a new S3 bucket. To create a bucket, you must set up Amazon S3 and have\na valid Amazon Web Services Access Key ID to authenticate requests. Anonymous\nrequests are never allowed to create buckets. By creating the bucket, you become\nthe bucket owner.\n\nThere are two types of buckets: general purpose buckets and directory buckets.\nFor more information about these bucket types, see [Creating, configuring, and working with Amazon S3\nbuckets](https://docs.aws.amazon.com/AmazonS3/latest/userguide/creating-buckets-s3.html)\nin the *Amazon S3 User Guide*.\n\n   **General purpose buckets** - If you send your `CreateBucket`\nrequest to the `s3.amazonaws.com` global endpoint, the request goes to the\n`us-east-1` Region. So the signature calculations in Signature Version 4 must\nuse `us-east-1` as the Region, even if the location constraint in the request\nspecifies another Region where the bucket is to be created. If you create a\nbucket in a Region other than US East (N. Virginia), your application must be\nable to handle 307 redirect. For more information, see [Virtual hosting of buckets](https://docs.aws.amazon.com/AmazonS3/latest/dev/VirtualHosting.html) in\nthe *Amazon S3 User Guide*.\n\n   **Directory buckets ** - For directory buckets, you must make\nrequests for this API operation to the Regional endpoint. These endpoints\nsupport path-style requests in the format\n`https://s3express-control.*region_code*.amazonaws.com/*bucket-name* `.\nVirtual-hosted-style requests aren't supported. For more information, see\n[Regional and Zonal endpoints](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-express-Regions-and-Zones.html)\nin the *Amazon S3 User Guide*.","ref":"AWS.S3.html#create_bucket/4","title":"AWS.S3.create_bucket/4","type":"function"},{"doc":"#","ref":"AWS.S3.html#create_bucket/4-definitions","title":"Definitions - AWS.S3.create_bucket/4","type":"function"},{"doc":"**General purpose bucket permissions** - In addition to the\n`s3:CreateBucket` permission, the following permissions are required in a policy\nwhen your `CreateBucket` request includes specific headers:\n\n     **Access control lists (ACLs)** - In your\n`CreateBucket` request, if you specify an access control list (ACL) and set it\nto `public-read`, `public-read-write`, `authenticated-read`, or if you\nexplicitly specify any other custom ACLs, both `s3:CreateBucket` and\n`s3:PutBucketAcl` permissions are required. In your `CreateBucket` request, if\nyou set the ACL to `private`, or if you don't specify any ACLs, only the\n`s3:CreateBucket` permission is required.\n\n     **Object Lock** - In your `CreateBucket` request, if\nyou set `x-amz-bucket-object-lock-enabled` to true, the\n`s3:PutBucketObjectLockConfiguration` and `s3:PutBucketVersioning` permissions\nare required.\n\n     **S3 Object Ownership** - If your `CreateBucket`\nrequest includes the `x-amz-object-ownership` header, then the\n`s3:PutBucketOwnershipControls` permission is required.\n\nIf your `CreateBucket` request sets `BucketOwnerEnforced` for Amazon S3 Object\nOwnership and specifies a bucket ACL that provides access to an external Amazon\nWeb Services account, your request fails with a `400` error and returns the\n`InvalidBucketAcLWithObjectOwnership` error code. For more information, see\n[Setting Object Ownership on an existing bucket\n](https://docs.aws.amazon.com/AmazonS3/latest/userguide/object-ownership-existing-bucket.html)\nin the *Amazon S3 User Guide*.\n\n     **S3 Block Public Access** - If your specific use case\nrequires granting public access to your S3 resources, you can disable Block\nPublic Access. Specifically, you can create a new bucket with Block Public\nAccess enabled, then separately call the [ `DeletePublicAccessBlock`\n](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeletePublicAccessBlock.html)\nAPI. To use this operation, you must have the `s3:PutBucketPublicAccessBlock`\npermission. For more information about S3 Block Public Access, see [Blocking public access to your Amazon S3 storage\n](https://docs.aws.amazon.com/AmazonS3/latest/userguide/access-control-block-public-access.html)\nin the *Amazon S3 User Guide*.\n\n   **Directory bucket permissions** - You must have the\n`s3express:CreateBucket` permission in an IAM identity-based policy instead of a\nbucket policy. Cross-account access to this API operation isn't supported. This\noperation can only be performed by the Amazon Web Services account that owns the\nresource. For more information about directory bucket policies and permissions,\nsee [Amazon Web Services Identity and Access Management (IAM) for S3 Express One Zone](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-express-security-iam.html)\nin the *Amazon S3 User Guide*.\n\nThe permissions for ACLs, Object Lock, S3 Object Ownership, and S3 Block Public\nAccess are not supported for directory buckets. For directory buckets, all Block\nPublic Access settings are enabled at the bucket level and S3 Object Ownership\nis set to Bucket owner enforced (ACLs disabled). These settings can't be\nmodified.\n\nFor more information about permissions for creating and working with directory\nbuckets, see [Directory buckets](https://docs.aws.amazon.com/AmazonS3/latest/userguide/directory-buckets-overview.html)\nin the *Amazon S3 User Guide*. For more information about supported S3 features\nfor directory buckets, see [Features of S3 Express One Zone](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-express-one-zone.html#s3-express-features)\nin the *Amazon S3 User Guide*.\n\n#","ref":"AWS.S3.html#create_bucket/4-permissions","title":"Permissions - AWS.S3.create_bucket/4","type":"function"},{"doc":"**Directory buckets ** - The HTTP Host header syntax is\n`s3express-control.*region*.amazonaws.com`.\n\nThe following operations are related to `CreateBucket`:\n\n  *\n[PutObject](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObject.html)     *\n[DeleteBucket](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteBucket.html)","ref":"AWS.S3.html#create_bucket/4-http-host-header-syntax","title":"HTTP Host header syntax - AWS.S3.create_bucket/4","type":"function"},{"doc":"This action initiates a multipart upload and returns an upload ID.\n\nThis upload ID is used to associate all of the parts in the specific multipart\nupload. You specify this upload ID in each of your subsequent upload part\nrequests (see\n[UploadPart](https://docs.aws.amazon.com/AmazonS3/latest/API/API_UploadPart.html)). You also include this upload ID in the final request to either complete or abort\nthe multipart upload request. For more information about multipart uploads, see\n[Multipart Upload\nOverview](https://docs.aws.amazon.com/AmazonS3/latest/dev/mpuoverview.html) in\nthe *Amazon S3 User Guide*.\n\nAfter you initiate a multipart upload and upload one or more parts, to stop\nbeing charged for storing the uploaded parts, you must either complete or abort\nthe multipart upload. Amazon S3 frees up the space used to store the parts and\nstops charging you for storing them only after you either complete or abort a\nmultipart upload.\n\nIf you have configured a lifecycle rule to abort incomplete multipart uploads,\nthe created multipart upload must be completed within the number of days\nspecified in the bucket lifecycle configuration. Otherwise, the incomplete\nmultipart upload becomes eligible for an abort action and Amazon S3 aborts the\nmultipart upload. For more information, see [Aborting Incomplete Multipart Uploads Using a Bucket Lifecycle\nConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/dev/mpuoverview.html#mpu-abort-incomplete-mpu-lifecycle-config).\n\n   **Directory buckets ** - S3 Lifecycle is not supported by directory\nbuckets.\n\n   **Directory buckets ** - For directory buckets, you must make\nrequests for this API operation to the Zonal endpoint. These endpoints support\nvirtual-hosted-style requests in the format\n`https://*bucket_name*.s3express-*az_id*.*region*.amazonaws.com/*key-name* `.\nPath-style requests are not supported. For more information, see [Regional and Zonal\nendpoints](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-express-Regions-and-Zones.html)\nin the *Amazon S3 User Guide*.","ref":"AWS.S3.html#create_multipart_upload/5","title":"AWS.S3.create_multipart_upload/5","type":"function"},{"doc":"#","ref":"AWS.S3.html#create_multipart_upload/5-definitions","title":"Definitions - AWS.S3.create_multipart_upload/5","type":"function"},{"doc":"For request signing, multipart upload is just a series of regular requests. You\ninitiate a multipart upload, send one or more requests to upload parts, and then\ncomplete the multipart upload process. You sign each request individually. There\nis nothing special about signing multipart upload requests. For more information\nabout signing, see [Authenticating Requests (Amazon Web Services Signature Version\n4)](https://docs.aws.amazon.com/AmazonS3/latest/API/sig-v4-authenticating-requests.html)\nin the *Amazon S3 User Guide*.\n\n#","ref":"AWS.S3.html#create_multipart_upload/5-request-signing","title":"Request signing - AWS.S3.create_multipart_upload/5","type":"function"},{"doc":"**General purpose bucket permissions** - For information about the\npermissions required to use the multipart upload API, see [Multipart upload and permissions](https://docs.aws.amazon.com/AmazonS3/latest/dev/mpuAndPermissions.html)\nin the *Amazon S3 User Guide*.\n\nTo perform a multipart upload with encryption by using an Amazon Web Services\nKMS key, the requester must have permission to the `kms:Decrypt` and\n`kms:GenerateDataKey*` actions on the key. These permissions are required\nbecause Amazon S3 must decrypt and read data from the encrypted file parts\nbefore it completes the multipart upload. For more information, see [Multipart upload API and\npermissions](https://docs.aws.amazon.com/AmazonS3/latest/userguide/mpuoverview.html#mpuAndPermissions)\nand [Protecting data using server-side encryption with Amazon Web Services KMS](https://docs.aws.amazon.com/AmazonS3/latest/userguide/UsingKMSEncryption.html)\nin the *Amazon S3 User Guide*.\n\n   **Directory bucket permissions** - To grant access to this API\noperation on a directory bucket, we recommend that you use the [ `CreateSession`\n](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateSession.html) API\noperation for session-based authorization. Specifically, you grant the\n`s3express:CreateSession` permission to the directory bucket in a bucket policy\nor an IAM identity-based policy. Then, you make the `CreateSession` API call on\nthe bucket to obtain a session token. With the session token in your request\nheader, you can make API requests to this operation. After the session token\nexpires, you make another `CreateSession` API call to generate a new session\ntoken for use. Amazon Web Services CLI or SDKs create session and refresh the\nsession token automatically to avoid service interruptions when a session\nexpires. For more information about authorization, see [ `CreateSession`\n](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateSession.html).\n\n#","ref":"AWS.S3.html#create_multipart_upload/5-permissions","title":"Permissions - AWS.S3.create_multipart_upload/5","type":"function"},{"doc":"**General purpose buckets** - Server-side encryption is for data\nencryption at rest. Amazon S3 encrypts your data as it writes it to disks in its\ndata centers and decrypts it when you access it. Amazon S3 automatically\nencrypts all new objects that are uploaded to an S3 bucket. When doing a\nmultipart upload, if you don't specify encryption information in your request,\nthe encryption setting of the uploaded parts is set to the default encryption\nconfiguration of the destination bucket. By default, all buckets have a base\nlevel of encryption configuration that uses server-side encryption with Amazon\nS3 managed keys (SSE-S3). If the destination bucket has a default encryption\nconfiguration that uses server-side encryption with an Key Management Service\n(KMS) key (SSE-KMS), or a customer-provided encryption key (SSE-C), Amazon S3\nuses the corresponding KMS key, or a customer-provided key to encrypt the\nuploaded parts. When you perform a CreateMultipartUpload operation, if you want\nto use a different type of encryption setting for the uploaded parts, you can\nrequest that Amazon S3 encrypts the object with a different encryption key (such\nas an Amazon S3 managed key, a KMS key, or a customer-provided key). When the\nencryption setting in your request is different from the default encryption\nconfiguration of the destination bucket, the encryption setting in your request\ntakes precedence. If you choose to provide your own encryption key, the request\nheaders you provide in\n[UploadPart](https://docs.aws.amazon.com/AmazonS3/latest/API/API_UploadPart.html) and\n[UploadPartCopy](https://docs.aws.amazon.com/AmazonS3/latest/API/API_UploadPartCopy.html)\nrequests must match the headers you used in the `CreateMultipartUpload` request.\n\n     Use KMS keys (SSE-KMS) that include the Amazon Web\nServices managed key (`aws/s3`) and KMS customer managed keys stored in Key\nManagement Service (KMS) – If you want Amazon Web Services to manage the keys\nused to encrypt data, specify the following headers in the request.\n\n       `x-amz-server-side-encryption`\n\n      \n`x-amz-server-side-encryption-aws-kms-key-id`\n\n       `x-amz-server-side-encryption-context`\n\n   If you specify `x-amz-server-side-encryption:aws:kms`, but don't\nprovide `x-amz-server-side-encryption-aws-kms-key-id`, Amazon S3 uses the Amazon\nWeb Services managed key (`aws/s3` key) in KMS to protect the data.\n\n   To perform a multipart upload with encryption by using an Amazon\nWeb Services KMS key, the requester must have permission to the `kms:Decrypt`\nand `kms:GenerateDataKey*` actions on the key. These permissions are required\nbecause Amazon S3 must decrypt and read data from the encrypted file parts\nbefore it completes the multipart upload. For more information, see [Multipart upload API and\npermissions](https://docs.aws.amazon.com/AmazonS3/latest/userguide/mpuoverview.html#mpuAndPermissions)\nand [Protecting data using server-side encryption with Amazon Web Services KMS](https://docs.aws.amazon.com/AmazonS3/latest/userguide/UsingKMSEncryption.html)\nin the *Amazon S3 User Guide*.\n\n   If your Identity and Access Management (IAM) user or role is in the\nsame Amazon Web Services account as the KMS key, then you must have these\npermissions on the key policy. If your IAM user or role is in a different\naccount from the key, then you must have the permissions on both the key policy\nand your IAM user or role.\n\n   All `GET` and `PUT` requests for an object protected by KMS fail if\nyou don't make them by using Secure Sockets Layer (SSL), Transport Layer\nSecurity (TLS), or Signature Version 4. For information about configuring any of\nthe officially supported Amazon Web Services SDKs and Amazon Web Services CLI,\nsee [Specifying the Signature Version in Request Authentication](https://docs.aws.amazon.com/AmazonS3/latest/dev/UsingAWSSDK.html#specify-signature-version)\nin the *Amazon S3 User Guide*.\n\nFor more information about server-side encryption with KMS keys (SSE-KMS), see\n[Protecting Data Using Server-Side Encryption with KMS keys](https://docs.aws.amazon.com/AmazonS3/latest/userguide/UsingKMSEncryption.html)\nin the *Amazon S3 User Guide*.\n\n     Use customer-provided encryption keys (SSE-C) – If you\nwant to manage your own encryption keys, provide all the following headers in\nthe request.\n\n      \n`x-amz-server-side-encryption-customer-algorithm`\n\n       `x-amz-server-side-encryption-customer-key`\n\n      \n`x-amz-server-side-encryption-customer-key-MD5`\n\nFor more information about server-side encryption with customer-provided\nencryption keys (SSE-C), see [ Protecting data using server-side encryption with customer-provided encryption keys\n(SSE-C)](https://docs.aws.amazon.com/AmazonS3/latest/userguide/ServerSideEncryptionCustomerKeys.html)\nin the *Amazon S3 User Guide*.\n\n   **Directory buckets** -For directory buckets, only server-side\nencryption with Amazon S3 managed keys (SSE-S3) (`AES256`) is supported.\n\n#","ref":"AWS.S3.html#create_multipart_upload/5-encryption","title":"Encryption - AWS.S3.create_multipart_upload/5","type":"function"},{"doc":"**Directory buckets ** - The HTTP Host header syntax is `\n*Bucket_name*.s3express-*az_id*.*region*.amazonaws.com`.\n\nThe following operations are related to `CreateMultipartUpload`:\n\n  *\n[UploadPart](https://docs.aws.amazon.com/AmazonS3/latest/API/API_UploadPart.html)     *\n[CompleteMultipartUpload](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CompleteMultipartUpload.html)\n\n  *\n[AbortMultipartUpload](https://docs.aws.amazon.com/AmazonS3/latest/API/API_AbortMultipartUpload.html)     *\n[ListParts](https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListParts.html)\n\n  *\n[ListMultipartUploads](https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListMultipartUploads.html)","ref":"AWS.S3.html#create_multipart_upload/5-http-host-header-syntax","title":"HTTP Host header syntax - AWS.S3.create_multipart_upload/5","type":"function"},{"doc":"Creates a session that establishes temporary security credentials to support\nfast authentication and authorization for the Zonal endpoint APIs on directory\nbuckets.\n\nFor more information about Zonal endpoint APIs that include the Availability\nZone in the request endpoint, see [S3 Express One Zone APIs](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-express-APIs.html)\nin the *Amazon S3 User Guide*.\n\nTo make Zonal endpoint API requests on a directory bucket, use the\n`CreateSession` API operation. Specifically, you grant `s3express:CreateSession`\npermission to a bucket in a bucket policy or an IAM identity-based policy. Then,\nyou use IAM credentials to make the `CreateSession` API request on the bucket,\nwhich returns temporary security credentials that include the access key ID,\nsecret access key, session token, and expiration. These credentials have\nassociated permissions to access the Zonal endpoint APIs. After the session is\ncreated, you don’t need to use other policies to grant permissions to each Zonal\nendpoint API individually. Instead, in your Zonal endpoint API requests, you\nsign your requests by applying the temporary security credentials of the session\nto the request headers and following the SigV4 protocol for authentication. You\nalso apply the session token to the `x-amz-s3session-token` request header for\nauthorization. Temporary security credentials are scoped to the bucket and\nexpire after 5 minutes. After the expiration time, any calls that you make with\nthose credentials will fail. You must use IAM credentials again to make a\n`CreateSession` API request that generates a new set of temporary credentials\nfor use. Temporary credentials cannot be extended or refreshed beyond the\noriginal specified interval.\n\nIf you use Amazon Web Services SDKs, SDKs handle the session token refreshes\nautomatically to avoid service interruptions when a session expires. We\nrecommend that you use the Amazon Web Services SDKs to initiate and manage\nrequests to the CreateSession API. For more information, see [Performance guidelines and design\npatterns](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-express-optimizing-performance-guidelines-design-patterns.html#s3-express-optimizing-performance-session-authentication)\nin the *Amazon S3 User Guide*.\n\n   You must make requests for this API operation to the Zonal\nendpoint. These endpoints support virtual-hosted-style requests in the format\n`https://*bucket_name*.s3express-*az_id*.*region*.amazonaws.com`. Path-style\nrequests are not supported. For more information, see [Regional and Zonal endpoints](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-express-Regions-and-Zones.html)\nin the *Amazon S3 User Guide*.\n\n   ** `CopyObject` API operation** - Unlike other Zonal endpoint APIs,\nthe `CopyObject` API operation doesn't use the temporary security credentials\nreturned from the `CreateSession` API operation for authentication and\nauthorization. For information about authentication and authorization of the\n`CopyObject` API operation on directory buckets, see\n[CopyObject](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CopyObject.html).     ** `HeadBucket` API operation** - Unlike other Zonal endpoint APIs,\nthe `HeadBucket` API operation doesn't use the temporary security credentials\nreturned from the `CreateSession` API operation for authentication and\nauthorization. For information about authentication and authorization of the\n`HeadBucket` API operation on directory buckets, see\n[HeadBucket](https://docs.aws.amazon.com/AmazonS3/latest/API/API_HeadBucket.html).","ref":"AWS.S3.html#create_session/4","title":"AWS.S3.create_session/4","type":"function"},{"doc":"#","ref":"AWS.S3.html#create_session/4-definitions","title":"Definitions - AWS.S3.create_session/4","type":"function"},{"doc":"To obtain temporary security credentials, you must create a bucket policy or an\nIAM identity-based policy that grants `s3express:CreateSession` permission to\nthe bucket. In a policy, you can have the `s3express:SessionMode` condition key\nto control who can create a `ReadWrite` or `ReadOnly` session. For more\ninformation about `ReadWrite` or `ReadOnly` sessions, see [\n`x-amz-create-session-mode`\n](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateSession.html#API_CreateSession_RequestParameters).\nFor example policies, see [Example bucket policies for S3 Express One Zone](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-express-security-iam-example-bucket-policies.html)\nand [Amazon Web Services Identity and Access Management (IAM) identity-based policies for S3 Express One\nZone](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-express-security-iam-identity-policies.html)\nin the *Amazon S3 User Guide*.\n\nTo grant cross-account access to Zonal endpoint APIs, the bucket policy should\nalso grant both accounts the `s3express:CreateSession` permission.\n\n#","ref":"AWS.S3.html#create_session/4-permissions","title":"Permissions - AWS.S3.create_session/4","type":"function"},{"doc":"**Directory buckets ** - The HTTP Host header syntax is `\n*Bucket_name*.s3express-*az_id*.*region*.amazonaws.com`.","ref":"AWS.S3.html#create_session/4-http-host-header-syntax","title":"HTTP Host header syntax - AWS.S3.create_session/4","type":"function"},{"doc":"Deletes the S3 bucket.\n\nAll objects (including all object versions and delete markers) in the bucket\nmust be deleted before the bucket itself can be deleted.\n\n   **Directory buckets** - If multipart uploads in a directory bucket\nare in progress, you can't delete the bucket until all the in-progress multipart\nuploads are aborted or completed.\n\n   **Directory buckets ** - For directory buckets, you must make\nrequests for this API operation to the Regional endpoint. These endpoints\nsupport path-style requests in the format\n`https://s3express-control.*region_code*.amazonaws.com/*bucket-name* `.\nVirtual-hosted-style requests aren't supported. For more information, see\n[Regional and Zonal endpoints](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-express-Regions-and-Zones.html)\nin the *Amazon S3 User Guide*.","ref":"AWS.S3.html#delete_bucket/4","title":"AWS.S3.delete_bucket/4","type":"function"},{"doc":"#","ref":"AWS.S3.html#delete_bucket/4-definitions","title":"Definitions - AWS.S3.delete_bucket/4","type":"function"},{"doc":"**General purpose bucket permissions** - You must have the\n`s3:DeleteBucket` permission on the specified bucket in a policy.\n\n   **Directory bucket permissions** - You must have the\n`s3express:DeleteBucket` permission in an IAM identity-based policy instead of a\nbucket policy. Cross-account access to this API operation isn't supported. This\noperation can only be performed by the Amazon Web Services account that owns the\nresource. For more information about directory bucket policies and permissions,\nsee [Amazon Web Services Identity and Access Management (IAM) for S3 Express One Zone](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-express-security-iam.html)\nin the *Amazon S3 User Guide*.\n\n#","ref":"AWS.S3.html#delete_bucket/4-permissions","title":"Permissions - AWS.S3.delete_bucket/4","type":"function"},{"doc":"**Directory buckets ** - The HTTP Host header syntax is\n`s3express-control.*region*.amazonaws.com`.\n\nThe following operations are related to `DeleteBucket`:\n\n  *\n[CreateBucket](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateBucket.html)     *\n[DeleteObject](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteObject.html)","ref":"AWS.S3.html#delete_bucket/4-http-host-header-syntax","title":"HTTP Host header syntax - AWS.S3.delete_bucket/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nDeletes an analytics configuration for the bucket (specified by the analytics\nconfiguration ID).\n\nTo use this operation, you must have permissions to perform the\n`s3:PutAnalyticsConfiguration` action. The bucket owner has this permission by\ndefault. The bucket owner can grant this permission to others. For more\ninformation about permissions, see [Permissions Related to Bucket Subresource Operations](https://docs.aws.amazon.com/AmazonS3/latest/userguide/using-with-s3-actions.html#using-with-s3-actions-related-to-bucket-subresources)\nand [Managing Access Permissions to Your Amazon S3 Resources](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-access-control.html).\n\nFor information about the Amazon S3 analytics feature, see [Amazon S3 Analytics – Storage Class\nAnalysis](https://docs.aws.amazon.com/AmazonS3/latest/dev/analytics-storage-class.html).\n\nThe following operations are related to `DeleteBucketAnalyticsConfiguration`:\n\n  *\n[GetBucketAnalyticsConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketAnalyticsConfiguration.html)     *\n[ListBucketAnalyticsConfigurations](https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListBucketAnalyticsConfigurations.html)\n\n  *\n[PutBucketAnalyticsConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketAnalyticsConfiguration.html)","ref":"AWS.S3.html#delete_bucket_analytics_configuration/4","title":"AWS.S3.delete_bucket_analytics_configuration/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nDeletes the `cors` configuration information set for the bucket.\n\nTo use this operation, you must have permission to perform the\n`s3:PutBucketCORS` action. The bucket owner has this permission by default and\ncan grant this permission to others.\n\nFor information about `cors`, see [Enabling Cross-Origin Resource Sharing](https://docs.aws.amazon.com/AmazonS3/latest/dev/cors.html) in the\n*Amazon S3 User Guide*.","ref":"AWS.S3.html#delete_bucket_cors/4","title":"AWS.S3.delete_bucket_cors/4","type":"function"},{"doc":"*\n[PutBucketCors](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketCors.html)     *\n[RESTOPTIONSobject](https://docs.aws.amazon.com/AmazonS3/latest/API/RESTOPTIONSobject.html)","ref":"AWS.S3.html#delete_bucket_cors/4-related-resources","title":"Related Resources - AWS.S3.delete_bucket_cors/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nThis implementation of the DELETE action resets the default encryption for the\nbucket as server-side encryption with Amazon S3 managed keys (SSE-S3). For\ninformation about the bucket default encryption feature, see [Amazon S3 Bucket Default\nEncryption](https://docs.aws.amazon.com/AmazonS3/latest/dev/bucket-encryption.html)\nin the *Amazon S3 User Guide*.\n\nTo use this operation, you must have permissions to perform the\n`s3:PutEncryptionConfiguration` action. The bucket owner has this permission by\ndefault. The bucket owner can grant this permission to others. For more\ninformation about permissions, see [Permissions Related to Bucket Subresource Operations](https://docs.aws.amazon.com/AmazonS3/latest/userguide/using-with-s3-actions.html#using-with-s3-actions-related-to-bucket-subresources)\nand [Managing Access Permissions to your Amazon S3 Resources](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-access-control.html)\nin the *Amazon S3 User Guide*.\n\nThe following operations are related to `DeleteBucketEncryption`:\n\n  *\n[PutBucketEncryption](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketEncryption.html)     *\n[GetBucketEncryption](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketEncryption.html)","ref":"AWS.S3.html#delete_bucket_encryption/4","title":"AWS.S3.delete_bucket_encryption/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nDeletes the S3 Intelligent-Tiering configuration from the specified bucket.\n\nThe S3 Intelligent-Tiering storage class is designed to optimize storage costs\nby automatically moving data to the most cost-effective storage access tier,\nwithout performance impact or operational overhead. S3 Intelligent-Tiering\ndelivers automatic cost savings in three low latency and high throughput access\ntiers. To get the lowest storage cost on data that can be accessed in minutes to\nhours, you can choose to activate additional archiving capabilities.\n\nThe S3 Intelligent-Tiering storage class is the ideal storage class for data\nwith unknown, changing, or unpredictable access patterns, independent of object\nsize or retention period. If the size of an object is less than 128 KB, it is\nnot monitored and not eligible for auto-tiering. Smaller objects can be stored,\nbut they are always charged at the Frequent Access tier rates in the S3\nIntelligent-Tiering storage class.\n\nFor more information, see [Storage class for automatically optimizing frequently and infrequently accessed\nobjects](https://docs.aws.amazon.com/AmazonS3/latest/dev/storage-class-intro.html#sc-dynamic-data-access).\n\nOperations related to `DeleteBucketIntelligentTieringConfiguration` include:\n\n  *\n[GetBucketIntelligentTieringConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketIntelligentTieringConfiguration.html)     *\n[PutBucketIntelligentTieringConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketIntelligentTieringConfiguration.html)\n\n  *\n[ListBucketIntelligentTieringConfigurations](https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListBucketIntelligentTieringConfigurations.html)","ref":"AWS.S3.html#delete_bucket_intelligent_tiering_configuration/4","title":"AWS.S3.delete_bucket_intelligent_tiering_configuration/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nDeletes an inventory configuration (identified by the inventory ID) from the\nbucket.\n\nTo use this operation, you must have permissions to perform the\n`s3:PutInventoryConfiguration` action. The bucket owner has this permission by\ndefault. The bucket owner can grant this permission to others. For more\ninformation about permissions, see [Permissions Related to Bucket Subresource Operations](https://docs.aws.amazon.com/AmazonS3/latest/userguide/using-with-s3-actions.html#using-with-s3-actions-related-to-bucket-subresources)\nand [Managing Access Permissions to Your Amazon S3 Resources](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-access-control.html).\n\nFor information about the Amazon S3 inventory feature, see [Amazon S3 Inventory](https://docs.aws.amazon.com/AmazonS3/latest/dev/storage-inventory.html).\n\nOperations related to `DeleteBucketInventoryConfiguration` include:\n\n  *\n[GetBucketInventoryConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketInventoryConfiguration.html)     *\n[PutBucketInventoryConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketInventoryConfiguration.html)\n\n  *\n[ListBucketInventoryConfigurations](https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListBucketInventoryConfigurations.html)","ref":"AWS.S3.html#delete_bucket_inventory_configuration/4","title":"AWS.S3.delete_bucket_inventory_configuration/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nDeletes the lifecycle configuration from the specified bucket. Amazon S3 removes\nall the lifecycle configuration rules in the lifecycle subresource associated\nwith the bucket. Your objects never expire, and Amazon S3 no longer\nautomatically deletes any objects on the basis of rules contained in the deleted\nlifecycle configuration.\n\nTo use this operation, you must have permission to perform the\n`s3:PutLifecycleConfiguration` action. By default, the bucket owner has this\npermission and the bucket owner can grant this permission to others.\n\nThere is usually some time lag before lifecycle configuration deletion is fully\npropagated to all the Amazon S3 systems.\n\nFor more information about the object expiration, see [Elements to Describe Lifecycle\nActions](https://docs.aws.amazon.com/AmazonS3/latest/dev/intro-lifecycle-rules.html#intro-lifecycle-rules-actions).\n\nRelated actions include:\n\n  *\n[PutBucketLifecycleConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketLifecycleConfiguration.html)     *\n[GetBucketLifecycleConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketLifecycleConfiguration.html)","ref":"AWS.S3.html#delete_bucket_lifecycle/4","title":"AWS.S3.delete_bucket_lifecycle/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nDeletes a metrics configuration for the Amazon CloudWatch request metrics\n(specified by the metrics configuration ID) from the bucket. Note that this\ndoesn't include the daily storage metrics.\n\nTo use this operation, you must have permissions to perform the\n`s3:PutMetricsConfiguration` action. The bucket owner has this permission by\ndefault. The bucket owner can grant this permission to others. For more\ninformation about permissions, see [Permissions Related to Bucket Subresource Operations](https://docs.aws.amazon.com/AmazonS3/latest/userguide/using-with-s3-actions.html#using-with-s3-actions-related-to-bucket-subresources)\nand [Managing Access Permissions to Your Amazon S3 Resources](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-access-control.html).\n\nFor information about CloudWatch request metrics for Amazon S3, see [Monitoring Metrics with Amazon\nCloudWatch](https://docs.aws.amazon.com/AmazonS3/latest/dev/cloudwatch-monitoring.html).\n\nThe following operations are related to `DeleteBucketMetricsConfiguration`:\n\n  *\n[GetBucketMetricsConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketMetricsConfiguration.html)     *\n[PutBucketMetricsConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketMetricsConfiguration.html)\n\n  *\n[ListBucketMetricsConfigurations](https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListBucketMetricsConfigurations.html)     * [Monitoring Metrics with Amazon\nCloudWatch](https://docs.aws.amazon.com/AmazonS3/latest/dev/cloudwatch-monitoring.html)","ref":"AWS.S3.html#delete_bucket_metrics_configuration/4","title":"AWS.S3.delete_bucket_metrics_configuration/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nRemoves `OwnershipControls` for an Amazon S3 bucket. To use this operation, you\nmust have the `s3:PutBucketOwnershipControls` permission. For more information\nabout Amazon S3 permissions, see [Specifying Permissions in a Policy](https://docs.aws.amazon.com/AmazonS3/latest/dev/using-with-s3-actions.html).\n\nFor information about Amazon S3 Object Ownership, see [Using Object Ownership](https://docs.aws.amazon.com/AmazonS3/latest/dev/about-object-ownership.html).\n\nThe following operations are related to `DeleteBucketOwnershipControls`:\n\n  * `GetBucketOwnershipControls`\n\n  * `PutBucketOwnershipControls`","ref":"AWS.S3.html#delete_bucket_ownership_controls/4","title":"AWS.S3.delete_bucket_ownership_controls/4","type":"function"},{"doc":"Deletes the policy of a specified bucket.\n\n**Directory buckets ** - For directory buckets, you must make requests for this\nAPI operation to the Regional endpoint. These endpoints support path-style\nrequests in the format\n`https://s3express-control.*region_code*.amazonaws.com/*bucket-name* `.\nVirtual-hosted-style requests aren't supported. For more information, see\n[Regional and Zonal endpoints](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-express-Regions-and-Zones.html)\nin the *Amazon S3 User Guide*.","ref":"AWS.S3.html#delete_bucket_policy/4","title":"AWS.S3.delete_bucket_policy/4","type":"function"},{"doc":"#","ref":"AWS.S3.html#delete_bucket_policy/4-definitions","title":"Definitions - AWS.S3.delete_bucket_policy/4","type":"function"},{"doc":"If you are using an identity other than the root user of the Amazon Web Services\naccount that owns the bucket, the calling identity must both have the\n`DeleteBucketPolicy` permissions on the specified bucket and belong to the\nbucket owner's account in order to use this operation.\n\nIf you don't have `DeleteBucketPolicy` permissions, Amazon S3 returns a `403\nAccess Denied` error. If you have the correct permissions, but you're not using\nan identity that belongs to the bucket owner's account, Amazon S3 returns a `405\nMethod Not Allowed` error.\n\nTo ensure that bucket owners don't inadvertently lock themselves out of their\nown buckets, the root principal in a bucket owner's Amazon Web Services account\ncan perform the `GetBucketPolicy`, `PutBucketPolicy`, and `DeleteBucketPolicy`\nAPI actions, even if their bucket policy explicitly denies the root principal's\naccess. Bucket owner root principals can only be blocked from performing these\nAPI actions by VPC endpoint policies and Amazon Web Services Organizations\npolicies.\n\n   **General purpose bucket permissions** - The\n`s3:DeleteBucketPolicy` permission is required in a policy. For more information\nabout general purpose buckets bucket policies, see [Using Bucket Policies and User\nPolicies](https://docs.aws.amazon.com/AmazonS3/latest/dev/using-iam-policies.html)\nin the *Amazon S3 User Guide*.\n\n   **Directory bucket permissions** - To grant access to this API\noperation, you must have the `s3express:DeleteBucketPolicy` permission in an IAM\nidentity-based policy instead of a bucket policy. Cross-account access to this\nAPI operation isn't supported. This operation can only be performed by the\nAmazon Web Services account that owns the resource. For more information about\ndirectory bucket policies and permissions, see [Amazon Web Services Identity and Access Management (IAM) for S3 Express One\nZone](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-express-security-iam.html)\nin the *Amazon S3 User Guide*.\n\n#","ref":"AWS.S3.html#delete_bucket_policy/4-permissions","title":"Permissions - AWS.S3.delete_bucket_policy/4","type":"function"},{"doc":"**Directory buckets ** - The HTTP Host header syntax is\n`s3express-control.*region*.amazonaws.com`.\n\nThe following operations are related to `DeleteBucketPolicy`\n\n  *\n[CreateBucket](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateBucket.html)     *\n[DeleteObject](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteObject.html)","ref":"AWS.S3.html#delete_bucket_policy/4-http-host-header-syntax","title":"HTTP Host header syntax - AWS.S3.delete_bucket_policy/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nDeletes the replication configuration from the bucket.\n\nTo use this operation, you must have permissions to perform the\n`s3:PutReplicationConfiguration` action. The bucket owner has these permissions\nby default and can grant it to others. For more information about permissions,\nsee [Permissions Related to Bucket Subresource Operations](https://docs.aws.amazon.com/AmazonS3/latest/userguide/using-with-s3-actions.html#using-with-s3-actions-related-to-bucket-subresources)\nand [Managing Access Permissions to Your Amazon S3 Resources](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-access-control.html).\n\nIt can take a while for the deletion of a replication configuration to fully\npropagate.\n\nFor information about replication configuration, see\n[Replication](https://docs.aws.amazon.com/AmazonS3/latest/dev/replication.html) in the *Amazon S3 User Guide*.\n\nThe following operations are related to `DeleteBucketReplication`:\n\n  *\n[PutBucketReplication](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketReplication.html)\n\n  *\n[GetBucketReplication](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketReplication.html)","ref":"AWS.S3.html#delete_bucket_replication/4","title":"AWS.S3.delete_bucket_replication/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nDeletes the tags from the bucket.\n\nTo use this operation, you must have permission to perform the\n`s3:PutBucketTagging` action. By default, the bucket owner has this permission\nand can grant this permission to others.\n\nThe following operations are related to `DeleteBucketTagging`:\n\n  *\n[GetBucketTagging](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketTagging.html)     *\n[PutBucketTagging](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketTagging.html)","ref":"AWS.S3.html#delete_bucket_tagging/4","title":"AWS.S3.delete_bucket_tagging/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nThis action removes the website configuration for a bucket. Amazon S3 returns a\n`200 OK` response upon successfully deleting a website configuration on the\nspecified bucket. You will get a `200 OK` response if the website configuration\nyou are trying to delete does not exist on the bucket. Amazon S3 returns a `404`\nresponse if the bucket specified in the request does not exist.\n\nThis DELETE action requires the `S3:DeleteBucketWebsite` permission. By default,\nonly the bucket owner can delete the website configuration attached to a bucket.\nHowever, bucket owners can grant other users permission to delete the website\nconfiguration by writing a bucket policy granting them the\n`S3:DeleteBucketWebsite` permission.\n\nFor more information about hosting websites, see [Hosting Websites on Amazon S3](https://docs.aws.amazon.com/AmazonS3/latest/dev/WebsiteHosting.html).\n\nThe following operations are related to `DeleteBucketWebsite`:\n\n  *\n[GetBucketWebsite](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketWebsite.html)     *\n[PutBucketWebsite](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketWebsite.html)","ref":"AWS.S3.html#delete_bucket_website/4","title":"AWS.S3.delete_bucket_website/4","type":"function"},{"doc":"Removes an object from a bucket.\n\nThe behavior depends on the bucket's versioning state:\n\n  * If versioning is enabled, the operation removes the null version\n(if there is one) of an object and inserts a delete marker, which becomes the\nlatest version of the object. If there isn't a null version, Amazon S3 does not\nremove any objects but will still respond that the command was successful.\n\n  * If versioning is suspended or not enabled, the operation\npermanently deletes the object.\n\n   **Directory buckets** - S3 Versioning isn't enabled and supported\nfor directory buckets. For this API operation, only the `null` value of the\nversion ID is supported by directory buckets. You can only specify `null` to the\n`versionId` query parameter in the request.\n\n   **Directory buckets** - For directory buckets, you must make\nrequests for this API operation to the Zonal endpoint. These endpoints support\nvirtual-hosted-style requests in the format\n`https://*bucket_name*.s3express-*az_id*.*region*.amazonaws.com/*key-name* `.\nPath-style requests are not supported. For more information, see [Regional and Zonal\nendpoints](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-express-Regions-and-Zones.html)\nin the *Amazon S3 User Guide*.\n\nTo remove a specific version, you must use the `versionId` query parameter.\nUsing this query parameter permanently deletes the version. If the object\ndeleted is a delete marker, Amazon S3 sets the response header\n`x-amz-delete-marker` to true.\n\nIf the object you want to delete is in a bucket where the bucket versioning\nconfiguration is MFA Delete enabled, you must include the `x-amz-mfa` request\nheader in the DELETE `versionId` request. Requests that include `x-amz-mfa` must\nuse HTTPS. For more information about MFA Delete, see [Using MFA Delete](https://docs.aws.amazon.com/AmazonS3/latest/dev/UsingMFADelete.html) in\nthe *Amazon S3 User Guide*. To see sample requests that use versioning, see\n[Sample Request](https://docs.aws.amazon.com/AmazonS3/latest/API/RESTObjectDELETE.html#ExampleVersionObjectDelete).\n\n**Directory buckets** - MFA delete is not supported by directory buckets.\n\nYou can delete objects by explicitly calling DELETE Object or calling\n([PutBucketLifecycle](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketLifecycle.html)) to enable Amazon S3 to remove them for you. If you want to block users or\naccounts from removing or deleting objects from your bucket, you must deny them\nthe `s3:DeleteObject`, `s3:DeleteObjectVersion`, and\n`s3:PutLifeCycleConfiguration` actions.\n\n**Directory buckets** - S3 Lifecycle is not supported by directory buckets.","ref":"AWS.S3.html#delete_object/5","title":"AWS.S3.delete_object/5","type":"function"},{"doc":"#","ref":"AWS.S3.html#delete_object/5-definitions","title":"Definitions - AWS.S3.delete_object/5","type":"function"},{"doc":"**General purpose bucket permissions** - The following permissions\nare required in your policies when your `DeleteObjects` request includes\nspecific headers.\n\n     ** `s3:DeleteObject` ** - To delete an object from a\nbucket, you must always have the `s3:DeleteObject` permission.\n\n     ** `s3:DeleteObjectVersion` ** - To delete a specific\nversion of an object from a versiong-enabled bucket, you must have the\n`s3:DeleteObjectVersion` permission.\n\n   **Directory bucket permissions** - To grant access to this API\noperation on a directory bucket, we recommend that you use the [ `CreateSession`\n](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateSession.html) API\noperation for session-based authorization. Specifically, you grant the\n`s3express:CreateSession` permission to the directory bucket in a bucket policy\nor an IAM identity-based policy. Then, you make the `CreateSession` API call on\nthe bucket to obtain a session token. With the session token in your request\nheader, you can make API requests to this operation. After the session token\nexpires, you make another `CreateSession` API call to generate a new session\ntoken for use. Amazon Web Services CLI or SDKs create session and refresh the\nsession token automatically to avoid service interruptions when a session\nexpires. For more information about authorization, see [ `CreateSession`\n](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateSession.html).\n\n#","ref":"AWS.S3.html#delete_object/5-permissions","title":"Permissions - AWS.S3.delete_object/5","type":"function"},{"doc":"**Directory buckets ** - The HTTP Host header syntax is `\n*Bucket_name*.s3express-*az_id*.*region*.amazonaws.com`.\n\nThe following action is related to `DeleteObject`:\n\n  *\n[PutObject](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObject.html)","ref":"AWS.S3.html#delete_object/5-http-host-header-syntax","title":"HTTP Host header syntax - AWS.S3.delete_object/5","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nRemoves the entire tag set from the specified object. For more information about\nmanaging object tags, see [ Object Tagging](https://docs.aws.amazon.com/AmazonS3/latest/dev/object-tagging.html).\n\nTo use this operation, you must have permission to perform the\n`s3:DeleteObjectTagging` action.\n\nTo delete tags of a specific object version, add the `versionId` query parameter\nin the request. You will need permission for the `s3:DeleteObjectVersionTagging`\naction.\n\nThe following operations are related to `DeleteObjectTagging`:\n\n  *\n[PutObjectTagging](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObjectTagging.html)     *\n[GetObjectTagging](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectTagging.html)","ref":"AWS.S3.html#delete_object_tagging/5","title":"AWS.S3.delete_object_tagging/5","type":"function"},{"doc":"This operation enables you to delete multiple objects from a bucket using a\nsingle HTTP request.\n\nIf you know the object keys that you want to delete, then this operation\nprovides a suitable alternative to sending individual delete requests, reducing\nper-request overhead.\n\nThe request can contain a list of up to 1000 keys that you want to delete. In\nthe XML, you provide the object key names, and optionally, version IDs if you\nwant to delete a specific version of the object from a versioning-enabled\nbucket. For each key, Amazon S3 performs a delete operation and returns the\nresult of that delete, success or failure, in the response. Note that if the\nobject specified in the request is not found, Amazon S3 returns the result as\ndeleted.\n\n   **Directory buckets** - S3 Versioning isn't enabled and supported\nfor directory buckets.\n\n   **Directory buckets** - For directory buckets, you must make\nrequests for this API operation to the Zonal endpoint. These endpoints support\nvirtual-hosted-style requests in the format\n`https://*bucket_name*.s3express-*az_id*.*region*.amazonaws.com/*key-name* `.\nPath-style requests are not supported. For more information, see [Regional and Zonal\nendpoints](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-express-Regions-and-Zones.html)\nin the *Amazon S3 User Guide*.\n\nThe operation supports two modes for the response: verbose and quiet. By\ndefault, the operation uses verbose mode in which the response includes the\nresult of deletion of each key in your request. In quiet mode the response\nincludes only keys where the delete operation encountered an error. For a\nsuccessful deletion in a quiet mode, the operation does not return any\ninformation about the delete in the response body.\n\nWhen performing this action on an MFA Delete enabled bucket, that attempts to\ndelete any versioned objects, you must include an MFA token. If you do not\nprovide one, the entire request will fail, even if there are non-versioned\nobjects you are trying to delete. If you provide an invalid token, whether there\nare versioned keys in the request or not, the entire Multi-Object Delete request\nwill fail. For information about MFA Delete, see [MFA Delete](https://docs.aws.amazon.com/AmazonS3/latest/dev/Versioning.html#MultiFactorAuthenticationDelete)\nin the *Amazon S3 User Guide*.\n\n**Directory buckets** - MFA delete is not supported by directory buckets.","ref":"AWS.S3.html#delete_objects/4","title":"AWS.S3.delete_objects/4","type":"function"},{"doc":"#","ref":"AWS.S3.html#delete_objects/4-definitions","title":"Definitions - AWS.S3.delete_objects/4","type":"function"},{"doc":"**General purpose bucket permissions** - The following permissions\nare required in your policies when your `DeleteObjects` request includes\nspecific headers.\n\n     ** `s3:DeleteObject` ** - To delete an object from a\nbucket, you must always specify the `s3:DeleteObject` permission.\n\n     ** `s3:DeleteObjectVersion` ** - To delete a specific\nversion of an object from a versiong-enabled bucket, you must specify the\n`s3:DeleteObjectVersion` permission.\n\n   **Directory bucket permissions** - To grant access to this API\noperation on a directory bucket, we recommend that you use the [ `CreateSession`\n](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateSession.html) API\noperation for session-based authorization. Specifically, you grant the\n`s3express:CreateSession` permission to the directory bucket in a bucket policy\nor an IAM identity-based policy. Then, you make the `CreateSession` API call on\nthe bucket to obtain a session token. With the session token in your request\nheader, you can make API requests to this operation. After the session token\nexpires, you make another `CreateSession` API call to generate a new session\ntoken for use. Amazon Web Services CLI or SDKs create session and refresh the\nsession token automatically to avoid service interruptions when a session\nexpires. For more information about authorization, see [ `CreateSession`\n](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateSession.html).\n\n#","ref":"AWS.S3.html#delete_objects/4-permissions","title":"Permissions - AWS.S3.delete_objects/4","type":"function"},{"doc":"**General purpose bucket** - The Content-MD5 request header is\nrequired for all Multi-Object Delete requests. Amazon S3 uses the header value\nto ensure that your request body has not been altered in transit.\n\n   **Directory bucket** - The Content-MD5 request header or a\nadditional checksum request header (including `x-amz-checksum-crc32`,\n`x-amz-checksum-crc32c`, `x-amz-checksum-sha1`, or `x-amz-checksum-sha256`) is\nrequired for all Multi-Object Delete requests.\n\n#","ref":"AWS.S3.html#delete_objects/4-content-md5-request-header","title":"Content-MD5 request header - AWS.S3.delete_objects/4","type":"function"},{"doc":"**Directory buckets ** - The HTTP Host header syntax is `\n*Bucket_name*.s3express-*az_id*.*region*.amazonaws.com`.\n\nThe following operations are related to `DeleteObjects`:\n\n  *\n[CreateMultipartUpload](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateMultipartUpload.html)     *\n[UploadPart](https://docs.aws.amazon.com/AmazonS3/latest/API/API_UploadPart.html)\n\n  *\n[CompleteMultipartUpload](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CompleteMultipartUpload.html)     *\n[ListParts](https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListParts.html)\n\n  *\n[AbortMultipartUpload](https://docs.aws.amazon.com/AmazonS3/latest/API/API_AbortMultipartUpload.html)","ref":"AWS.S3.html#delete_objects/4-http-host-header-syntax","title":"HTTP Host header syntax - AWS.S3.delete_objects/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nRemoves the `PublicAccessBlock` configuration for an Amazon S3 bucket. To use\nthis operation, you must have the `s3:PutBucketPublicAccessBlock` permission.\nFor more information about permissions, see [Permissions Related to Bucket Subresource\nOperations](https://docs.aws.amazon.com/AmazonS3/latest/userguide/using-with-s3-actions.html#using-with-s3-actions-related-to-bucket-subresources)\nand [Managing Access Permissions to Your Amazon S3 Resources](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-access-control.html).\n\nThe following operations are related to `DeletePublicAccessBlock`:\n\n  * [Using Amazon S3 Block Public Access](https://docs.aws.amazon.com/AmazonS3/latest/dev/access-control-block-public-access.html)\n\n  *\n[GetPublicAccessBlock](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetPublicAccessBlock.html)     *\n[PutPublicAccessBlock](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutPublicAccessBlock.html)\n\n  *\n[GetBucketPolicyStatus](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketPolicyStatus.html)","ref":"AWS.S3.html#delete_public_access_block/4","title":"AWS.S3.delete_public_access_block/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nThis implementation of the GET action uses the `accelerate` subresource to\nreturn the Transfer Acceleration state of a bucket, which is either `Enabled` or\n`Suspended`. Amazon S3 Transfer Acceleration is a bucket-level feature that\nenables you to perform faster data transfers to and from Amazon S3.\n\nTo use this operation, you must have permission to perform the\n`s3:GetAccelerateConfiguration` action. The bucket owner has this permission by\ndefault. The bucket owner can grant this permission to others. For more\ninformation about permissions, see [Permissions Related to Bucket Subresource Operations](https://docs.aws.amazon.com/AmazonS3/latest/userguide/using-with-s3-actions.html#using-with-s3-actions-related-to-bucket-subresources)\nand [Managing Access Permissions to your Amazon S3 Resources](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-access-control.html)\nin the *Amazon S3 User Guide*.\n\nYou set the Transfer Acceleration state of an existing bucket to `Enabled` or\n`Suspended` by using the\n[PutBucketAccelerateConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketAccelerateConfiguration.html) operation.\n\nA GET `accelerate` request does not return a state value for a bucket that has\nno transfer acceleration state. A bucket has no Transfer Acceleration state if a\nstate has never been set on the bucket.\n\nFor more information about transfer acceleration, see [Transfer\nAcceleration](https://docs.aws.amazon.com/AmazonS3/latest/dev/transfer-acceleration.html)\nin the Amazon S3 User Guide.\n\nThe following operations are related to `GetBucketAccelerateConfiguration`:\n\n  *\n[PutBucketAccelerateConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketAccelerateConfiguration.html)","ref":"AWS.S3.html#get_bucket_accelerate_configuration/5","title":"AWS.S3.get_bucket_accelerate_configuration/5","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nThis implementation of the `GET` action uses the `acl` subresource to return the\naccess control list (ACL) of a bucket. To use `GET` to return the ACL of the\nbucket, you must have the `READ_ACP` access to the bucket. If `READ_ACP`\npermission is granted to the anonymous user, you can return the ACL of the\nbucket without using an authorization header.\n\nWhen you use this API operation with an access point, provide the alias of the\naccess point in place of the bucket name.\n\nWhen you use this API operation with an Object Lambda access point, provide the\nalias of the Object Lambda access point in place of the bucket name. If the\nObject Lambda access point alias in a request is not valid, the error code\n`InvalidAccessPointAliasError` is returned. For more information about\n`InvalidAccessPointAliasError`, see [List of Error Codes](https://docs.aws.amazon.com/AmazonS3/latest/API/ErrorResponses.html#ErrorCodeList).\n\nIf your bucket uses the bucket owner enforced setting for S3 Object Ownership,\nrequests to read ACLs are still supported and return the\n`bucket-owner-full-control` ACL with the owner being the account that created\nthe bucket. For more information, see [ Controlling object ownership and disabling\nACLs](https://docs.aws.amazon.com/AmazonS3/latest/userguide/about-object-ownership.html)\nin the *Amazon S3 User Guide*.\n\nThe following operations are related to `GetBucketAcl`:\n\n  *\n[ListObjects](https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListObjects.html)","ref":"AWS.S3.html#get_bucket_acl/4","title":"AWS.S3.get_bucket_acl/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nThis implementation of the GET action returns an analytics configuration\n(identified by the analytics configuration ID) from the bucket.\n\nTo use this operation, you must have permissions to perform the\n`s3:GetAnalyticsConfiguration` action. The bucket owner has this permission by\ndefault. The bucket owner can grant this permission to others. For more\ninformation about permissions, see [ Permissions Related to Bucket Subresource Operations](https://docs.aws.amazon.com/AmazonS3/latest/userguide/using-with-s3-actions.html#using-with-s3-actions-related-to-bucket-subresources)\nand [Managing Access Permissions to Your Amazon S3 Resources](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-access-control.html)\nin the *Amazon S3 User Guide*.\n\nFor information about Amazon S3 analytics feature, see [Amazon S3 Analytics – Storage Class\nAnalysis](https://docs.aws.amazon.com/AmazonS3/latest/dev/analytics-storage-class.html)\nin the *Amazon S3 User Guide*.\n\nThe following operations are related to `GetBucketAnalyticsConfiguration`:\n\n  *\n[DeleteBucketAnalyticsConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteBucketAnalyticsConfiguration.html)     *\n[ListBucketAnalyticsConfigurations](https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListBucketAnalyticsConfigurations.html)\n\n  *\n[PutBucketAnalyticsConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketAnalyticsConfiguration.html)","ref":"AWS.S3.html#get_bucket_analytics_configuration/5","title":"AWS.S3.get_bucket_analytics_configuration/5","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nReturns the Cross-Origin Resource Sharing (CORS) configuration information set\nfor the bucket.\n\nTo use this operation, you must have permission to perform the\n`s3:GetBucketCORS` action. By default, the bucket owner has this permission and\ncan grant it to others.\n\nWhen you use this API operation with an access point, provide the alias of the\naccess point in place of the bucket name.\n\nWhen you use this API operation with an Object Lambda access point, provide the\nalias of the Object Lambda access point in place of the bucket name. If the\nObject Lambda access point alias in a request is not valid, the error code\n`InvalidAccessPointAliasError` is returned. For more information about\n`InvalidAccessPointAliasError`, see [List of Error Codes](https://docs.aws.amazon.com/AmazonS3/latest/API/ErrorResponses.html#ErrorCodeList).\n\nFor more information about CORS, see [ Enabling Cross-Origin Resource Sharing](https://docs.aws.amazon.com/AmazonS3/latest/dev/cors.html).\n\nThe following operations are related to `GetBucketCors`:\n\n  *\n[PutBucketCors](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketCors.html)     *\n[DeleteBucketCors](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteBucketCors.html)","ref":"AWS.S3.html#get_bucket_cors/4","title":"AWS.S3.get_bucket_cors/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nReturns the default encryption configuration for an Amazon S3 bucket. By\ndefault, all buckets have a default encryption configuration that uses\nserver-side encryption with Amazon S3 managed keys (SSE-S3). For information\nabout the bucket default encryption feature, see [Amazon S3 Bucket Default Encryption](https://docs.aws.amazon.com/AmazonS3/latest/dev/bucket-encryption.html)\nin the *Amazon S3 User Guide*.\n\nTo use this operation, you must have permission to perform the\n`s3:GetEncryptionConfiguration` action. The bucket owner has this permission by\ndefault. The bucket owner can grant this permission to others. For more\ninformation about permissions, see [Permissions Related to Bucket Subresource Operations](https://docs.aws.amazon.com/AmazonS3/latest/userguide/using-with-s3-actions.html#using-with-s3-actions-related-to-bucket-subresources)\nand [Managing Access Permissions to Your Amazon S3 Resources](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-access-control.html).\n\nThe following operations are related to `GetBucketEncryption`:\n\n  *\n[PutBucketEncryption](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketEncryption.html)     *\n[DeleteBucketEncryption](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteBucketEncryption.html)","ref":"AWS.S3.html#get_bucket_encryption/4","title":"AWS.S3.get_bucket_encryption/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nGets the S3 Intelligent-Tiering configuration from the specified bucket.\n\nThe S3 Intelligent-Tiering storage class is designed to optimize storage costs\nby automatically moving data to the most cost-effective storage access tier,\nwithout performance impact or operational overhead. S3 Intelligent-Tiering\ndelivers automatic cost savings in three low latency and high throughput access\ntiers. To get the lowest storage cost on data that can be accessed in minutes to\nhours, you can choose to activate additional archiving capabilities.\n\nThe S3 Intelligent-Tiering storage class is the ideal storage class for data\nwith unknown, changing, or unpredictable access patterns, independent of object\nsize or retention period. If the size of an object is less than 128 KB, it is\nnot monitored and not eligible for auto-tiering. Smaller objects can be stored,\nbut they are always charged at the Frequent Access tier rates in the S3\nIntelligent-Tiering storage class.\n\nFor more information, see [Storage class for automatically optimizing frequently and infrequently accessed\nobjects](https://docs.aws.amazon.com/AmazonS3/latest/dev/storage-class-intro.html#sc-dynamic-data-access).\n\nOperations related to `GetBucketIntelligentTieringConfiguration` include:\n\n  *\n[DeleteBucketIntelligentTieringConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteBucketIntelligentTieringConfiguration.html)     *\n[PutBucketIntelligentTieringConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketIntelligentTieringConfiguration.html)\n\n  *\n[ListBucketIntelligentTieringConfigurations](https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListBucketIntelligentTieringConfigurations.html)","ref":"AWS.S3.html#get_bucket_intelligent_tiering_configuration/4","title":"AWS.S3.get_bucket_intelligent_tiering_configuration/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nReturns an inventory configuration (identified by the inventory configuration\nID) from the bucket.\n\nTo use this operation, you must have permissions to perform the\n`s3:GetInventoryConfiguration` action. The bucket owner has this permission by\ndefault and can grant this permission to others. For more information about\npermissions, see [Permissions Related to Bucket Subresource Operations](https://docs.aws.amazon.com/AmazonS3/latest/userguide/using-with-s3-actions.html#using-with-s3-actions-related-to-bucket-subresources)\nand [Managing Access Permissions to Your Amazon S3 Resources](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-access-control.html).\n\nFor information about the Amazon S3 inventory feature, see [Amazon S3 Inventory](https://docs.aws.amazon.com/AmazonS3/latest/dev/storage-inventory.html).\n\nThe following operations are related to `GetBucketInventoryConfiguration`:\n\n  *\n[DeleteBucketInventoryConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteBucketInventoryConfiguration.html)     *\n[ListBucketInventoryConfigurations](https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListBucketInventoryConfigurations.html)\n\n  *\n[PutBucketInventoryConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketInventoryConfiguration.html)","ref":"AWS.S3.html#get_bucket_inventory_configuration/5","title":"AWS.S3.get_bucket_inventory_configuration/5","type":"function"},{"doc":"For an updated version of this API, see\n[GetBucketLifecycleConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketLifecycleConfiguration.html).  If you configured a bucket lifecycle using the `filter` element, you should see\nthe updated version of this topic. This topic is provided for backward\ncompatibility.\n\nThis operation is not supported by directory buckets.\n\nReturns the lifecycle configuration information set on the bucket. For\ninformation about lifecycle configuration, see [Object Lifecycle\nManagement](https://docs.aws.amazon.com/AmazonS3/latest/dev/object-lifecycle-mgmt.html).\n\nTo use this operation, you must have permission to perform the\n`s3:GetLifecycleConfiguration` action. The bucket owner has this permission by\ndefault. The bucket owner can grant this permission to others. For more\ninformation about permissions, see [Permissions Related to Bucket Subresource Operations](https://docs.aws.amazon.com/AmazonS3/latest/userguide/using-with-s3-actions.html#using-with-s3-actions-related-to-bucket-subresources)\nand [Managing Access Permissions to Your Amazon S3 Resources](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-access-control.html).\n\n`GetBucketLifecycle` has the following special error:\n\n  * Error code: `NoSuchLifecycleConfiguration`\n\n    * Description: The lifecycle configuration does not\nexist.\n\n    * HTTP Status Code: 404 Not Found\n\n    * SOAP Fault Code Prefix: Client\n\nThe following operations are related to `GetBucketLifecycle`:\n\n  *\n[GetBucketLifecycleConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketLifecycleConfiguration.html)     *\n[PutBucketLifecycle](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketLifecycle.html)\n\n  *\n[DeleteBucketLifecycle](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteBucketLifecycle.html)","ref":"AWS.S3.html#get_bucket_lifecycle/4","title":"AWS.S3.get_bucket_lifecycle/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nBucket lifecycle configuration now supports specifying a lifecycle rule using an\nobject key name prefix, one or more object tags, or a combination of both.\nAccordingly, this section describes the latest API. The response describes the\nnew filter element that you can use to specify a filter to select a subset of\nobjects to which the rule applies. If you are using a previous version of the\nlifecycle configuration, it still works. For the earlier action, see\n[GetBucketLifecycle](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketLifecycle.html). \nReturns the lifecycle configuration information set on the bucket. For\ninformation about lifecycle configuration, see [Object Lifecycle\nManagement](https://docs.aws.amazon.com/AmazonS3/latest/dev/object-lifecycle-mgmt.html).\n\nTo use this operation, you must have permission to perform the\n`s3:GetLifecycleConfiguration` action. The bucket owner has this permission, by\ndefault. The bucket owner can grant this permission to others. For more\ninformation about permissions, see [Permissions Related to Bucket Subresource Operations](https://docs.aws.amazon.com/AmazonS3/latest/userguide/using-with-s3-actions.html#using-with-s3-actions-related-to-bucket-subresources)\nand [Managing Access Permissions to Your Amazon S3 Resources](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-access-control.html).\n\n`GetBucketLifecycleConfiguration` has the following special error:\n\n  * Error code: `NoSuchLifecycleConfiguration`\n\n    * Description: The lifecycle configuration does not\nexist.\n\n    * HTTP Status Code: 404 Not Found\n\n    * SOAP Fault Code Prefix: Client\n\nThe following operations are related to `GetBucketLifecycleConfiguration`:\n\n  *\n[GetBucketLifecycle](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketLifecycle.html)     *\n[PutBucketLifecycle](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketLifecycle.html)\n\n  *\n[DeleteBucketLifecycle](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteBucketLifecycle.html)","ref":"AWS.S3.html#get_bucket_lifecycle_configuration/4","title":"AWS.S3.get_bucket_lifecycle_configuration/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nReturns the Region the bucket resides in. You set the bucket's Region using the\n`LocationConstraint` request parameter in a `CreateBucket` request. For more\ninformation, see\n[CreateBucket](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateBucket.html).  When you use this API operation with an access point, provide the alias of the\naccess point in place of the bucket name.\n\nWhen you use this API operation with an Object Lambda access point, provide the\nalias of the Object Lambda access point in place of the bucket name. If the\nObject Lambda access point alias in a request is not valid, the error code\n`InvalidAccessPointAliasError` is returned. For more information about\n`InvalidAccessPointAliasError`, see [List of Error\nCodes](https://docs.aws.amazon.com/AmazonS3/latest/API/ErrorResponses.html#ErrorCodeList).\n\nWe recommend that you use\n[HeadBucket](https://docs.aws.amazon.com/AmazonS3/latest/API/API_HeadBucket.html) to return the Region that a bucket resides in. For backward compatibility,\nAmazon S3 continues to support GetBucketLocation.\n\nThe following operations are related to `GetBucketLocation`:\n\n  *\n[GetObject](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObject.html)\n\n  *\n[CreateBucket](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateBucket.html)","ref":"AWS.S3.html#get_bucket_location/4","title":"AWS.S3.get_bucket_location/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nReturns the logging status of a bucket and the permissions users have to view\nand modify that status.\n\nThe following operations are related to `GetBucketLogging`:\n\n  *\n[CreateBucket](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateBucket.html)     *\n[PutBucketLogging](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketLogging.html)","ref":"AWS.S3.html#get_bucket_logging/4","title":"AWS.S3.get_bucket_logging/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nGets a metrics configuration (specified by the metrics configuration ID) from\nthe bucket. Note that this doesn't include the daily storage metrics.\n\nTo use this operation, you must have permissions to perform the\n`s3:GetMetricsConfiguration` action. The bucket owner has this permission by\ndefault. The bucket owner can grant this permission to others. For more\ninformation about permissions, see [Permissions Related to Bucket Subresource Operations](https://docs.aws.amazon.com/AmazonS3/latest/userguide/using-with-s3-actions.html#using-with-s3-actions-related-to-bucket-subresources)\nand [Managing Access Permissions to Your Amazon S3 Resources](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-access-control.html).\n\nFor information about CloudWatch request metrics for Amazon S3, see [Monitoring Metrics with Amazon\nCloudWatch](https://docs.aws.amazon.com/AmazonS3/latest/dev/cloudwatch-monitoring.html).\n\nThe following operations are related to `GetBucketMetricsConfiguration`:\n\n  *\n[PutBucketMetricsConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketMetricsConfiguration.html)     *\n[DeleteBucketMetricsConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteBucketMetricsConfiguration.html)\n\n  *\n[ListBucketMetricsConfigurations](https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListBucketMetricsConfigurations.html)     * [Monitoring Metrics with Amazon\nCloudWatch](https://docs.aws.amazon.com/AmazonS3/latest/dev/cloudwatch-monitoring.html)","ref":"AWS.S3.html#get_bucket_metrics_configuration/5","title":"AWS.S3.get_bucket_metrics_configuration/5","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nNo longer used, see\n[GetBucketNotificationConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketNotificationConfiguration.html).","ref":"AWS.S3.html#get_bucket_notification/4","title":"AWS.S3.get_bucket_notification/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nReturns the notification configuration of a bucket.\n\nIf notifications are not enabled on the bucket, the action returns an empty\n`NotificationConfiguration` element.\n\nBy default, you must be the bucket owner to read the notification configuration\nof a bucket. However, the bucket owner can use a bucket policy to grant\npermission to other users to read this configuration with the\n`s3:GetBucketNotification` permission.\n\nWhen you use this API operation with an access point, provide the alias of the\naccess point in place of the bucket name.\n\nWhen you use this API operation with an Object Lambda access point, provide the\nalias of the Object Lambda access point in place of the bucket name. If the\nObject Lambda access point alias in a request is not valid, the error code\n`InvalidAccessPointAliasError` is returned. For more information about\n`InvalidAccessPointAliasError`, see [List of Error Codes](https://docs.aws.amazon.com/AmazonS3/latest/API/ErrorResponses.html#ErrorCodeList).\n\nFor more information about setting and reading the notification configuration on\na bucket, see [Setting Up Notification of Bucket Events](https://docs.aws.amazon.com/AmazonS3/latest/dev/NotificationHowTo.html).\nFor more information about bucket policies, see [Using Bucket Policies](https://docs.aws.amazon.com/AmazonS3/latest/dev/using-iam-policies.html).\n\nThe following action is related to `GetBucketNotification`:\n\n  *\n[PutBucketNotification](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketNotification.html)","ref":"AWS.S3.html#get_bucket_notification_configuration/4","title":"AWS.S3.get_bucket_notification_configuration/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nRetrieves `OwnershipControls` for an Amazon S3 bucket. To use this operation,\nyou must have the `s3:GetBucketOwnershipControls` permission. For more\ninformation about Amazon S3 permissions, see [Specifying permissions in a policy](https://docs.aws.amazon.com/AmazonS3/latest/userguide/using-with-s3-actions.html).\n\nFor information about Amazon S3 Object Ownership, see [Using Object Ownership](https://docs.aws.amazon.com/AmazonS3/latest/userguide/about-object-ownership.html).\n\nThe following operations are related to `GetBucketOwnershipControls`:\n\n  * `PutBucketOwnershipControls`\n\n  * `DeleteBucketOwnershipControls`","ref":"AWS.S3.html#get_bucket_ownership_controls/4","title":"AWS.S3.get_bucket_ownership_controls/4","type":"function"},{"doc":"Returns the policy of a specified bucket.\n\n**Directory buckets ** - For directory buckets, you must make requests for this\nAPI operation to the Regional endpoint. These endpoints support path-style\nrequests in the format\n`https://s3express-control.*region_code*.amazonaws.com/*bucket-name* `.\nVirtual-hosted-style requests aren't supported. For more information, see\n[Regional and Zonal endpoints](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-express-Regions-and-Zones.html)\nin the *Amazon S3 User Guide*.","ref":"AWS.S3.html#get_bucket_policy/4","title":"AWS.S3.get_bucket_policy/4","type":"function"},{"doc":"#","ref":"AWS.S3.html#get_bucket_policy/4-definitions","title":"Definitions - AWS.S3.get_bucket_policy/4","type":"function"},{"doc":"If you are using an identity other than the root user of the Amazon Web Services\naccount that owns the bucket, the calling identity must both have the\n`GetBucketPolicy` permissions on the specified bucket and belong to the bucket\nowner's account in order to use this operation.\n\nIf you don't have `GetBucketPolicy` permissions, Amazon S3 returns a `403 Access\nDenied` error. If you have the correct permissions, but you're not using an\nidentity that belongs to the bucket owner's account, Amazon S3 returns a `405\nMethod Not Allowed` error.\n\nTo ensure that bucket owners don't inadvertently lock themselves out of their\nown buckets, the root principal in a bucket owner's Amazon Web Services account\ncan perform the `GetBucketPolicy`, `PutBucketPolicy`, and `DeleteBucketPolicy`\nAPI actions, even if their bucket policy explicitly denies the root principal's\naccess. Bucket owner root principals can only be blocked from performing these\nAPI actions by VPC endpoint policies and Amazon Web Services Organizations\npolicies.\n\n   **General purpose bucket permissions** - The `s3:GetBucketPolicy`\npermission is required in a policy. For more information about general purpose\nbuckets bucket policies, see [Using Bucket Policies and User Policies](https://docs.aws.amazon.com/AmazonS3/latest/dev/using-iam-policies.html)\nin the *Amazon S3 User Guide*.\n\n   **Directory bucket permissions** - To grant access to this API\noperation, you must have the `s3express:GetBucketPolicy` permission in an IAM\nidentity-based policy instead of a bucket policy. Cross-account access to this\nAPI operation isn't supported. This operation can only be performed by the\nAmazon Web Services account that owns the resource. For more information about\ndirectory bucket policies and permissions, see [Amazon Web Services Identity and Access Management (IAM) for S3 Express One\nZone](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-express-security-iam.html)\nin the *Amazon S3 User Guide*.\n\n#","ref":"AWS.S3.html#get_bucket_policy/4-permissions","title":"Permissions - AWS.S3.get_bucket_policy/4","type":"function"},{"doc":"**General purpose buckets example bucket policies** - See [Bucket policy examples](https://docs.aws.amazon.com/AmazonS3/latest/userguide/example-bucket-policies.html)\nin the *Amazon S3 User Guide*.\n\n**Directory bucket example bucket policies** - See [Example bucket policies for S3 Express One\nZone](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-express-security-iam-example-bucket-policies.html)\nin the *Amazon S3 User Guide*.\n\n#","ref":"AWS.S3.html#get_bucket_policy/4-example-bucket-policies","title":"Example bucket policies - AWS.S3.get_bucket_policy/4","type":"function"},{"doc":"**Directory buckets ** - The HTTP Host header syntax is\n`s3express-control.*region*.amazonaws.com`.\n\nThe following action is related to `GetBucketPolicy`:\n\n  *\n[GetObject](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObject.html)","ref":"AWS.S3.html#get_bucket_policy/4-http-host-header-syntax","title":"HTTP Host header syntax - AWS.S3.get_bucket_policy/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nRetrieves the policy status for an Amazon S3 bucket, indicating whether the\nbucket is public. In order to use this operation, you must have the\n`s3:GetBucketPolicyStatus` permission. For more information about Amazon S3\npermissions, see [Specifying Permissions in a Policy](https://docs.aws.amazon.com/AmazonS3/latest/dev/using-with-s3-actions.html).\n\nFor more information about when Amazon S3 considers a bucket public, see [The Meaning of\n\"Public\"](https://docs.aws.amazon.com/AmazonS3/latest/dev/access-control-block-public-access.html#access-control-block-public-access-policy-status).\n\nThe following operations are related to `GetBucketPolicyStatus`:\n\n  * [Using Amazon S3 Block Public Access](https://docs.aws.amazon.com/AmazonS3/latest/dev/access-control-block-public-access.html)\n\n  *\n[GetPublicAccessBlock](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetPublicAccessBlock.html)     *\n[PutPublicAccessBlock](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutPublicAccessBlock.html)\n\n  *\n[DeletePublicAccessBlock](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeletePublicAccessBlock.html)","ref":"AWS.S3.html#get_bucket_policy_status/4","title":"AWS.S3.get_bucket_policy_status/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nReturns the replication configuration of a bucket.\n\nIt can take a while to propagate the put or delete a replication configuration\nto all Amazon S3 systems. Therefore, a get request soon after put or delete can\nreturn a wrong result.\n\nFor information about replication configuration, see\n[Replication](https://docs.aws.amazon.com/AmazonS3/latest/dev/replication.html) in the *Amazon S3 User Guide*.\n\nThis action requires permissions for the `s3:GetReplicationConfiguration`\naction. For more information about permissions, see [Using Bucket Policies and\nUser\nPolicies](https://docs.aws.amazon.com/AmazonS3/latest/dev/using-iam-policies.html).\n\nIf you include the `Filter` element in a replication configuration, you must\nalso include the `DeleteMarkerReplication` and `Priority` elements. The response\nalso returns those elements.\n\nFor information about `GetBucketReplication` errors, see [List of replication-related error\ncodes](https://docs.aws.amazon.com/AmazonS3/latest/API/ErrorResponses.html#ReplicationErrorCodeList)\n\nThe following operations are related to `GetBucketReplication`:\n\n  *\n[PutBucketReplication](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketReplication.html)     *\n[DeleteBucketReplication](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteBucketReplication.html)","ref":"AWS.S3.html#get_bucket_replication/4","title":"AWS.S3.get_bucket_replication/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nReturns the request payment configuration of a bucket. To use this version of\nthe operation, you must be the bucket owner. For more information, see\n[Requester Pays Buckets](https://docs.aws.amazon.com/AmazonS3/latest/dev/RequesterPaysBuckets.html).\n\nThe following operations are related to `GetBucketRequestPayment`:\n\n  *\n[ListObjects](https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListObjects.html)","ref":"AWS.S3.html#get_bucket_request_payment/4","title":"AWS.S3.get_bucket_request_payment/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nReturns the tag set associated with the bucket.\n\nTo use this operation, you must have permission to perform the\n`s3:GetBucketTagging` action. By default, the bucket owner has this permission\nand can grant this permission to others.\n\n`GetBucketTagging` has the following special error:\n\n  * Error code: `NoSuchTagSet`\n\n    * Description: There is no tag set associated with the\nbucket.\n\nThe following operations are related to `GetBucketTagging`:\n\n  *\n[PutBucketTagging](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketTagging.html)     *\n[DeleteBucketTagging](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteBucketTagging.html)","ref":"AWS.S3.html#get_bucket_tagging/4","title":"AWS.S3.get_bucket_tagging/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nReturns the versioning state of a bucket.\n\nTo retrieve the versioning state of a bucket, you must be the bucket owner.\n\nThis implementation also returns the MFA Delete status of the versioning state.\nIf the MFA Delete status is `enabled`, the bucket owner must use an\nauthentication device to change the versioning state of the bucket.\n\nThe following operations are related to `GetBucketVersioning`:\n\n  *\n[GetObject](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObject.html)     *\n[PutObject](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObject.html)\n\n  *\n[DeleteObject](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteObject.html)","ref":"AWS.S3.html#get_bucket_versioning/4","title":"AWS.S3.get_bucket_versioning/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nReturns the website configuration for a bucket. To host website on Amazon S3,\nyou can configure a bucket as website by adding a website configuration. For\nmore information about hosting websites, see [Hosting Websites on Amazon S3](https://docs.aws.amazon.com/AmazonS3/latest/dev/WebsiteHosting.html).\n\nThis GET action requires the `S3:GetBucketWebsite` permission. By default, only\nthe bucket owner can read the bucket website configuration. However, bucket\nowners can allow other users to read the website configuration by writing a\nbucket policy granting them the `S3:GetBucketWebsite` permission.\n\nThe following operations are related to `GetBucketWebsite`:\n\n  *\n[DeleteBucketWebsite](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteBucketWebsite.html)     *\n[PutBucketWebsite](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketWebsite.html)","ref":"AWS.S3.html#get_bucket_website/4","title":"AWS.S3.get_bucket_website/4","type":"function"},{"doc":"Retrieves an object from Amazon S3.\n\nIn the `GetObject` request, specify the full key name for the object.\n\n**General purpose buckets** - Both the virtual-hosted-style requests and the\npath-style requests are supported. For a virtual hosted-style request example,\nif you have the object `photos/2006/February/sample.jpg`, specify the object key\nname as `/photos/2006/February/sample.jpg`. For a path-style request example, if\nyou have the object `photos/2006/February/sample.jpg` in the bucket named\n`examplebucket`, specify the object key name as\n`/examplebucket/photos/2006/February/sample.jpg`. For more information about\nrequest types, see [HTTP Host Header Bucket Specification](https://docs.aws.amazon.com/AmazonS3/latest/dev/VirtualHosting.html#VirtualHostingSpecifyBucket)\nin the *Amazon S3 User Guide*.\n\n**Directory buckets** - Only virtual-hosted-style requests are supported. For a\nvirtual hosted-style request example, if you have the object\n`photos/2006/February/sample.jpg` in the bucket named\n`examplebucket--use1-az5--x-s3`, specify the object key name as\n`/photos/2006/February/sample.jpg`. Also, when you make requests to this API\noperation, your requests are sent to the Zonal endpoint. These endpoints support\nvirtual-hosted-style requests in the format\n`https://*bucket_name*.s3express-*az_id*.*region*.amazonaws.com/*key-name* `.\nPath-style requests are not supported. For more information, see [Regional and Zonal\nendpoints](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-express-Regions-and-Zones.html)\nin the *Amazon S3 User Guide*.","ref":"AWS.S3.html#get_object/23","title":"AWS.S3.get_object/23","type":"function"},{"doc":"#","ref":"AWS.S3.html#get_object/23-definitions","title":"Definitions - AWS.S3.get_object/23","type":"function"},{"doc":"**General purpose bucket permissions** - You must have the required\npermissions in a policy. To use `GetObject`, you must have the `READ` access to\nthe object (or version). If you grant `READ` access to the anonymous user, the\n`GetObject` operation returns the object without using an authorization header.\nFor more information, see [Specifying permissions in a policy](https://docs.aws.amazon.com/AmazonS3/latest/dev/using-with-s3-actions.html)\nin the *Amazon S3 User Guide*.\n\nIf you include a `versionId` in your request header, you must have the\n`s3:GetObjectVersion` permission to access a specific version of an object. The\n`s3:GetObject` permission is not required in this scenario.\n\nIf you request the current version of an object without a specific `versionId`\nin the request header, only the `s3:GetObject` permission is required. The\n`s3:GetObjectVersion` permission is not required in this scenario.\n\nIf the object that you request doesn’t exist, the error that Amazon S3 returns\ndepends on whether you also have the `s3:ListBucket` permission.\n\n     If you have the `s3:ListBucket` permission on the\nbucket, Amazon S3 returns an HTTP status code `404 Not Found` error.\n\n     If you don’t have the `s3:ListBucket` permission,\nAmazon S3 returns an HTTP status code `403 Access Denied` error.\n\n   **Directory bucket permissions** - To grant access to this API\noperation on a directory bucket, we recommend that you use the [ `CreateSession`\n](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateSession.html) API\noperation for session-based authorization. Specifically, you grant the\n`s3express:CreateSession` permission to the directory bucket in a bucket policy\nor an IAM identity-based policy. Then, you make the `CreateSession` API call on\nthe bucket to obtain a session token. With the session token in your request\nheader, you can make API requests to this operation. After the session token\nexpires, you make another `CreateSession` API call to generate a new session\ntoken for use. Amazon Web Services CLI or SDKs create session and refresh the\nsession token automatically to avoid service interruptions when a session\nexpires. For more information about authorization, see [ `CreateSession`\n](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateSession.html).\n\n#","ref":"AWS.S3.html#get_object/23-permissions","title":"Permissions - AWS.S3.get_object/23","type":"function"},{"doc":"If the object you are retrieving is stored in the S3 Glacier Flexible Retrieval\nstorage class, the S3 Glacier Deep Archive storage class, the S3\nIntelligent-Tiering Archive Access tier, or the S3 Intelligent-Tiering Deep\nArchive Access tier, before you can retrieve the object you must first restore a\ncopy using\n[RestoreObject](https://docs.aws.amazon.com/AmazonS3/latest/API/API_RestoreObject.html). Otherwise, this operation returns an `InvalidObjectState` error. For information\nabout restoring archived objects, see [Restoring Archived\nObjects](https://docs.aws.amazon.com/AmazonS3/latest/dev/restoring-objects.html)\nin the *Amazon S3 User Guide*.\n\n**Directory buckets ** - For directory buckets, only the S3 Express One Zone\nstorage class is supported to store newly created objects. Unsupported storage\nclass values won't write a destination object and will respond with the HTTP\nstatus code `400 Bad Request`.\n\n#","ref":"AWS.S3.html#get_object/23-storage-classes","title":"Storage classes - AWS.S3.get_object/23","type":"function"},{"doc":"Encryption request headers, like `x-amz-server-side-encryption`, should not be\nsent for the `GetObject` requests, if your object uses server-side encryption\nwith Amazon S3 managed encryption keys (SSE-S3), server-side encryption with Key\nManagement Service (KMS) keys (SSE-KMS), or dual-layer server-side encryption\nwith Amazon Web Services KMS keys (DSSE-KMS). If you include the header in your\n`GetObject` requests for the object that uses these types of keys, you’ll get an\nHTTP `400 Bad Request` error.\n\n#","ref":"AWS.S3.html#get_object/23-encryption","title":"Encryption - AWS.S3.get_object/23","type":"function"},{"doc":"There are times when you want to override certain response header values of a\n`GetObject` response. For example, you might override the `Content-Disposition`\nresponse header value through your `GetObject` request.\n\nYou can override values for a set of response headers. These modified response\nheader values are included only in a successful response, that is, when the HTTP\nstatus code `200 OK` is returned. The headers you can override using the\nfollowing query parameters in the request are a subset of the headers that\nAmazon S3 accepts when you create an object.\n\nThe response headers that you can override for the `GetObject` response are\n`Cache-Control`, `Content-Disposition`, `Content-Encoding`, `Content-Language`,\n`Content-Type`, and `Expires`.\n\nTo override values for a set of response headers in the `GetObject` response,\nyou can use the following query parameters in the request.\n\n   `response-cache-control`\n\n   `response-content-disposition`\n\n   `response-content-encoding`\n\n   `response-content-language`\n\n   `response-content-type`\n\n   `response-expires`\n\nWhen you use these parameters, you must sign the request by using either an\nAuthorization header or a presigned URL. These parameters cannot be used with an\nunsigned (anonymous) request.\n\n#","ref":"AWS.S3.html#get_object/23-overriding-response-header-values-through-the-request","title":"Overriding response header values through the request - AWS.S3.get_object/23","type":"function"},{"doc":"**Directory buckets ** - The HTTP Host header syntax is `\n*Bucket_name*.s3express-*az_id*.*region*.amazonaws.com`.\n\nThe following operations are related to `GetObject`:\n\n  *\n[ListBuckets](https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListBuckets.html)     *\n[GetObjectAcl](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectAcl.html)","ref":"AWS.S3.html#get_object/23-http-host-header-syntax","title":"HTTP Host header syntax - AWS.S3.get_object/23","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nReturns the access control list (ACL) of an object. To use this operation, you\nmust have `s3:GetObjectAcl` permissions or `READ_ACP` access to the object. For\nmore information, see [Mapping of ACL permissions and access policy permissions](https://docs.aws.amazon.com/AmazonS3/latest/userguide/acl-overview.html#acl-access-policy-permission-mapping)\nin the *Amazon S3 User Guide*\n\nThis functionality is not supported for Amazon S3 on Outposts.\n\nBy default, GET returns ACL information about the current version of an object.\nTo return ACL information about a different version, use the versionId\nsubresource.\n\nIf your bucket uses the bucket owner enforced setting for S3 Object Ownership,\nrequests to read ACLs are still supported and return the\n`bucket-owner-full-control` ACL with the owner being the account that created\nthe bucket. For more information, see [ Controlling object ownership and disabling\nACLs](https://docs.aws.amazon.com/AmazonS3/latest/userguide/about-object-ownership.html)\nin the *Amazon S3 User Guide*.\n\nThe following operations are related to `GetObjectAcl`:\n\n  *\n[GetObject](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObject.html)     *\n[GetObjectAttributes](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectAttributes.html)\n\n  *\n[DeleteObject](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteObject.html)     *\n[PutObject](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObject.html)","ref":"AWS.S3.html#get_object_acl/7","title":"AWS.S3.get_object_acl/7","type":"function"},{"doc":"Retrieves all the metadata from an object without returning the object itself.\n\nThis operation is useful if you're interested only in an object's metadata.\n\n`GetObjectAttributes` combines the functionality of `HeadObject` and\n`ListParts`. All of the data returned with each of those individual calls can be\nreturned with a single call to `GetObjectAttributes`.\n\n**Directory buckets** - For directory buckets, you must make requests for this\nAPI operation to the Zonal endpoint. These endpoints support\nvirtual-hosted-style requests in the format\n`https://*bucket_name*.s3express-*az_id*.*region*.amazonaws.com/*key-name* `.\nPath-style requests are not supported. For more information, see [Regional and Zonal\nendpoints](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-express-Regions-and-Zones.html)\nin the *Amazon S3 User Guide*.","ref":"AWS.S3.html#get_object_attributes/13","title":"AWS.S3.get_object_attributes/13","type":"function"},{"doc":"#","ref":"AWS.S3.html#get_object_attributes/13-definitions","title":"Definitions - AWS.S3.get_object_attributes/13","type":"function"},{"doc":"**General purpose bucket permissions** - To use\n`GetObjectAttributes`, you must have READ access to the object. The permissions\nthat you need to use this operation with depend on whether the bucket is\nversioned. If the bucket is versioned, you need both the `s3:GetObjectVersion`\nand `s3:GetObjectVersionAttributes` permissions for this operation. If the\nbucket is not versioned, you need the `s3:GetObject` and\n`s3:GetObjectAttributes` permissions. For more information, see [Specifying Permissions in a\nPolicy](https://docs.aws.amazon.com/AmazonS3/latest/dev/using-with-s3-actions.html)\nin the *Amazon S3 User Guide*. If the object that you request does not exist,\nthe error Amazon S3 returns depends on whether you also have the `s3:ListBucket`\npermission.\n\n     If you have the `s3:ListBucket` permission on the\nbucket, Amazon S3 returns an HTTP status code `404 Not Found` (\"no such key\")\nerror.\n\n     If you don't have the `s3:ListBucket` permission,\nAmazon S3 returns an HTTP status code `403 Forbidden` (\"access denied\") error.\n\n   **Directory bucket permissions** - To grant access to this API\noperation on a directory bucket, we recommend that you use the [ `CreateSession`\n](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateSession.html) API\noperation for session-based authorization. Specifically, you grant the\n`s3express:CreateSession` permission to the directory bucket in a bucket policy\nor an IAM identity-based policy. Then, you make the `CreateSession` API call on\nthe bucket to obtain a session token. With the session token in your request\nheader, you can make API requests to this operation. After the session token\nexpires, you make another `CreateSession` API call to generate a new session\ntoken for use. Amazon Web Services CLI or SDKs create session and refresh the\nsession token automatically to avoid service interruptions when a session\nexpires. For more information about authorization, see [ `CreateSession`\n](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateSession.html).\n\n#","ref":"AWS.S3.html#get_object_attributes/13-permissions","title":"Permissions - AWS.S3.get_object_attributes/13","type":"function"},{"doc":"Encryption request headers, like `x-amz-server-side-encryption`, should not be\nsent for `HEAD` requests if your object uses server-side encryption with Key\nManagement Service (KMS) keys (SSE-KMS), dual-layer server-side encryption with\nAmazon Web Services KMS keys (DSSE-KMS), or server-side encryption with Amazon\nS3 managed encryption keys (SSE-S3). The `x-amz-server-side-encryption` header\nis used when you `PUT` an object to S3 and want to specify the encryption\nmethod. If you include this header in a `GET` request for an object that uses\nthese types of keys, you’ll get an HTTP `400 Bad Request` error. It's because\nthe encryption method can't be changed when you retrieve the object.\n\nIf you encrypt an object by using server-side encryption with customer-provided\nencryption keys (SSE-C) when you store the object in Amazon S3, then when you\nretrieve the metadata from the object, you must use the following headers to\nprovide the encryption key for the server to be able to retrieve the object's\nmetadata. The headers are:\n\n   `x-amz-server-side-encryption-customer-algorithm`\n\n   `x-amz-server-side-encryption-customer-key`\n\n   `x-amz-server-side-encryption-customer-key-MD5`\n\nFor more information about SSE-C, see [Server-Side Encryption (Using Customer-Provided Encryption\nKeys)](https://docs.aws.amazon.com/AmazonS3/latest/dev/ServerSideEncryptionCustomerKeys.html)\nin the *Amazon S3 User Guide*.\n\n**Directory bucket permissions** - For directory buckets, only server-side\nencryption with Amazon S3 managed keys (SSE-S3) (`AES256`) is supported.\n\n#","ref":"AWS.S3.html#get_object_attributes/13-encryption","title":"Encryption - AWS.S3.get_object_attributes/13","type":"function"},{"doc":"**Directory buckets** - S3 Versioning isn't enabled and supported for directory\nbuckets. For this API operation, only the `null` value of the version ID is\nsupported by directory buckets. You can only specify `null` to the `versionId`\nquery parameter in the request.\n\n#","ref":"AWS.S3.html#get_object_attributes/13-versioning","title":"Versioning - AWS.S3.get_object_attributes/13","type":"function"},{"doc":"Consider the following when using request headers:\n\n   If both of the `If-Match` and `If-Unmodified-Since` headers are\npresent in the request as follows, then Amazon S3 returns the HTTP status code\n`200 OK` and the data requested:\n\n     `If-Match` condition evaluates to `true`.\n\n     `If-Unmodified-Since` condition evaluates to `false`.\n\nFor more information about conditional requests, see [RFC 7232](https://tools.ietf.org/html/rfc7232).\n\n   If both of the `If-None-Match` and `If-Modified-Since` headers are\npresent in the request as follows, then Amazon S3 returns the HTTP status code\n`304 Not Modified`:\n\n     `If-None-Match` condition evaluates to `false`.\n\n     `If-Modified-Since` condition evaluates to `true`.\n\nFor more information about conditional requests, see [RFC 7232](https://tools.ietf.org/html/rfc7232).\n\n#","ref":"AWS.S3.html#get_object_attributes/13-conditional-request-headers","title":"Conditional request headers - AWS.S3.get_object_attributes/13","type":"function"},{"doc":"**Directory buckets ** - The HTTP Host header syntax is `\n*Bucket_name*.s3express-*az_id*.*region*.amazonaws.com`.\n\nThe following actions are related to `GetObjectAttributes`:\n\n  *\n[GetObject](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObject.html)     *\n[GetObjectAcl](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectAcl.html)\n\n  *\n[GetObjectLegalHold](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectLegalHold.html)     *\n[GetObjectLockConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectLockConfiguration.html)\n\n  *\n[GetObjectRetention](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectRetention.html)     *\n[GetObjectTagging](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectTagging.html)\n\n  *\n[HeadObject](https://docs.aws.amazon.com/AmazonS3/latest/API/API_HeadObject.html)     *\n[ListParts](https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListParts.html)","ref":"AWS.S3.html#get_object_attributes/13-http-host-header-syntax","title":"HTTP Host header syntax - AWS.S3.get_object_attributes/13","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nGets an object's current legal hold status. For more information, see [Locking Objects](https://docs.aws.amazon.com/AmazonS3/latest/dev/object-lock.html).\n\nThis functionality is not supported for Amazon S3 on Outposts.\n\nThe following action is related to `GetObjectLegalHold`:\n\n  *\n[GetObjectAttributes](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectAttributes.html)","ref":"AWS.S3.html#get_object_legal_hold/7","title":"AWS.S3.get_object_legal_hold/7","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nGets the Object Lock configuration for a bucket. The rule specified in the\nObject Lock configuration will be applied by default to every new object placed\nin the specified bucket. For more information, see [Locking Objects](https://docs.aws.amazon.com/AmazonS3/latest/dev/object-lock.html).\n\nThe following action is related to `GetObjectLockConfiguration`:\n\n  *\n[GetObjectAttributes](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectAttributes.html)","ref":"AWS.S3.html#get_object_lock_configuration/4","title":"AWS.S3.get_object_lock_configuration/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nRetrieves an object's retention settings. For more information, see [Locking Objects](https://docs.aws.amazon.com/AmazonS3/latest/dev/object-lock.html).\n\nThis functionality is not supported for Amazon S3 on Outposts.\n\nThe following action is related to `GetObjectRetention`:\n\n  *\n[GetObjectAttributes](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectAttributes.html)","ref":"AWS.S3.html#get_object_retention/7","title":"AWS.S3.get_object_retention/7","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nReturns the tag-set of an object. You send the GET request against the tagging\nsubresource associated with the object.\n\nTo use this operation, you must have permission to perform the\n`s3:GetObjectTagging` action. By default, the GET action returns information\nabout current version of an object. For a versioned bucket, you can have\nmultiple versions of an object in your bucket. To retrieve tags of any other\nversion, use the versionId query parameter. You also need permission for the\n`s3:GetObjectVersionTagging` action.\n\nBy default, the bucket owner has this permission and can grant this permission\nto others.\n\nFor information about the Amazon S3 object tagging feature, see [Object Tagging](https://docs.aws.amazon.com/AmazonS3/latest/dev/object-tagging.html).\n\nThe following actions are related to `GetObjectTagging`:\n\n  *\n[DeleteObjectTagging](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteObjectTagging.html)     *\n[GetObjectAttributes](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectAttributes.html)\n\n  *\n[PutObjectTagging](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObjectTagging.html)","ref":"AWS.S3.html#get_object_tagging/7","title":"AWS.S3.get_object_tagging/7","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nReturns torrent files from a bucket. BitTorrent can save you bandwidth when\nyou're distributing large files.\n\nYou can get torrent only for objects that are less than 5 GB in size, and that\nare not encrypted using server-side encryption with a customer-provided\nencryption key.\n\nTo use GET, you must have READ access to the object.\n\nThis functionality is not supported for Amazon S3 on Outposts.\n\nThe following action is related to `GetObjectTorrent`:\n\n  *\n[GetObject](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObject.html)","ref":"AWS.S3.html#get_object_torrent/6","title":"AWS.S3.get_object_torrent/6","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nRetrieves the `PublicAccessBlock` configuration for an Amazon S3 bucket. To use\nthis operation, you must have the `s3:GetBucketPublicAccessBlock` permission.\nFor more information about Amazon S3 permissions, see [Specifying Permissions in a\nPolicy](https://docs.aws.amazon.com/AmazonS3/latest/dev/using-with-s3-actions.html).\n\nWhen Amazon S3 evaluates the `PublicAccessBlock` configuration for a bucket or\nan object, it checks the `PublicAccessBlock` configuration for both the bucket\n(or the bucket that contains the object) and the bucket owner's account. If the\n`PublicAccessBlock` settings are different between the bucket and the account,\nAmazon S3 uses the most restrictive combination of the bucket-level and\naccount-level settings.\n\nFor more information about when Amazon S3 considers a bucket or an object\npublic, see [The Meaning of \"Public\"](https://docs.aws.amazon.com/AmazonS3/latest/dev/access-control-block-public-access.html#access-control-block-public-access-policy-status).\n\nThe following operations are related to `GetPublicAccessBlock`:\n\n  * [Using Amazon S3 Block Public Access](https://docs.aws.amazon.com/AmazonS3/latest/dev/access-control-block-public-access.html)\n\n  *\n[PutPublicAccessBlock](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutPublicAccessBlock.html)     *\n[GetPublicAccessBlock](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetPublicAccessBlock.html)\n\n  *\n[DeletePublicAccessBlock](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeletePublicAccessBlock.html)","ref":"AWS.S3.html#get_public_access_block/4","title":"AWS.S3.get_public_access_block/4","type":"function"},{"doc":"You can use this operation to determine if a bucket exists and if you have\npermission to access it.\n\nThe action returns a `200 OK` if the bucket exists and you have permission to\naccess it.\n\nIf the bucket does not exist or you do not have permission to access it, the\n`HEAD` request returns a generic `400 Bad Request`, `403 Forbidden` or `404 Not\nFound` code. A message body is not included, so you cannot determine the\nexception beyond these error codes.\n\n**Directory buckets ** - You must make requests for this API operation to the\nZonal endpoint. These endpoints support virtual-hosted-style requests in the\nformat `https://*bucket_name*.s3express-*az_id*.*region*.amazonaws.com`.\nPath-style requests are not supported. For more information, see [Regional and Zonal\nendpoints](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-express-Regions-and-Zones.html)\nin the *Amazon S3 User Guide*.","ref":"AWS.S3.html#head_bucket/4","title":"AWS.S3.head_bucket/4","type":"function"},{"doc":"#","ref":"AWS.S3.html#head_bucket/4-definitions","title":"Definitions - AWS.S3.head_bucket/4","type":"function"},{"doc":"All `HeadBucket` requests must be authenticated and signed by using IAM\ncredentials (access key ID and secret access key for the IAM identities). All\nheaders with the `x-amz-` prefix, including `x-amz-copy-source`, must be signed.\nFor more information, see [REST Authentication](https://docs.aws.amazon.com/AmazonS3/latest/dev/RESTAuthentication.html).\n\n**Directory bucket** - You must use IAM credentials to authenticate and\nauthorize your access to the `HeadBucket` API operation, instead of using the\ntemporary security credentials through the `CreateSession` API operation.\n\nAmazon Web Services CLI or SDKs handles authentication and authorization on your\nbehalf.\n\n#","ref":"AWS.S3.html#head_bucket/4-authentication-and-authorization","title":"Authentication and authorization - AWS.S3.head_bucket/4","type":"function"},{"doc":"**General purpose bucket permissions** - To use this operation, you\nmust have permissions to perform the `s3:ListBucket` action. The bucket owner\nhas this permission by default and can grant this permission to others. For more\ninformation about permissions, see [Managing access permissions to your Amazon S3\nresources](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-access-control.html)\nin the *Amazon S3 User Guide*.\n\n   **Directory bucket permissions##  - You must have the \n`s3express:CreateSession` ** permission in the `Action` element of a policy. By\ndefault, the session is in the `ReadWrite` mode. If you want to restrict the\naccess, you can explicitly set the `s3express:SessionMode` condition key to\n`ReadOnly` on the bucket.\n\nFor more information about example bucket policies, see [Example bucket policies for S3 Express One\nZone](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-express-security-iam-example-bucket-policies.html)\nand [Amazon Web Services Identity and Access Management (IAM) identity-based policies for S3 Express One\nZone](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-express-security-iam-identity-policies.html)\nin the *Amazon S3 User Guide*.\n\n#","ref":"AWS.S3.html#head_bucket/4-permissions","title":"Permissions - AWS.S3.head_bucket/4","type":"function"},{"doc":"**Directory buckets ** - The HTTP Host header syntax is `\n*Bucket_name*.s3express-*az_id*.*region*.amazonaws.com`.","ref":"AWS.S3.html#head_bucket/4-http-host-header-syntax","title":"HTTP Host header syntax - AWS.S3.head_bucket/4","type":"function"},{"doc":"The `HEAD` operation retrieves metadata from an object without returning the\nobject itself.\n\nThis operation is useful if you're interested only in an object's metadata.\n\nA `HEAD` request has the same options as a `GET` operation on an object. The\nresponse is identical to the `GET` response except that there is no response\nbody. Because of this, if the `HEAD` request generates an error, it returns a\ngeneric code, such as `400 Bad Request`, `403 Forbidden`, `404 Not Found`, `405\nMethod Not Allowed`, `412 Precondition Failed`, or `304 Not Modified`. It's not\npossible to retrieve the exact exception of these error codes.\n\nRequest headers are limited to 8 KB in size. For more information, see [Common Request\nHeaders](https://docs.aws.amazon.com/AmazonS3/latest/API/RESTCommonRequestHeaders.html).\n\n**Directory buckets** - For directory buckets, you must make requests for this\nAPI operation to the Zonal endpoint. These endpoints support\nvirtual-hosted-style requests in the format\n`https://*bucket_name*.s3express-*az_id*.*region*.amazonaws.com/*key-name* `.\nPath-style requests are not supported. For more information, see [Regional and Zonal\nendpoints](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-express-Regions-and-Zones.html)\nin the *Amazon S3 User Guide*.","ref":"AWS.S3.html#head_object/5","title":"AWS.S3.head_object/5","type":"function"},{"doc":"#","ref":"AWS.S3.html#head_object/5-definitions","title":"Definitions - AWS.S3.head_object/5","type":"function"},{"doc":"**General purpose bucket permissions** - To use `HEAD`, you must\nhave the `s3:GetObject` permission. You need the relevant read object (or\nversion) permission for this operation. For more information, see [Actions, resources, and condition keys for Amazon\nS3](https://docs.aws.amazon.com/AmazonS3/latest/dev/list_amazons3.html) in the\n*Amazon S3 User Guide*.\n\nIf the object you request doesn't exist, the error that Amazon S3 returns\ndepends on whether you also have the `s3:ListBucket` permission.\n\n     If you have the `s3:ListBucket` permission on the\nbucket, Amazon S3 returns an HTTP status code `404 Not Found` error.\n\n     If you don’t have the `s3:ListBucket` permission,\nAmazon S3 returns an HTTP status code `403 Forbidden` error.\n\n   **Directory bucket permissions** - To grant access to this API\noperation on a directory bucket, we recommend that you use the [ `CreateSession`\n](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateSession.html) API\noperation for session-based authorization. Specifically, you grant the\n`s3express:CreateSession` permission to the directory bucket in a bucket policy\nor an IAM identity-based policy. Then, you make the `CreateSession` API call on\nthe bucket to obtain a session token. With the session token in your request\nheader, you can make API requests to this operation. After the session token\nexpires, you make another `CreateSession` API call to generate a new session\ntoken for use. Amazon Web Services CLI or SDKs create session and refresh the\nsession token automatically to avoid service interruptions when a session\nexpires. For more information about authorization, see [ `CreateSession`\n](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateSession.html).\n\n#","ref":"AWS.S3.html#head_object/5-permissions","title":"Permissions - AWS.S3.head_object/5","type":"function"},{"doc":"Encryption request headers, like `x-amz-server-side-encryption`, should not be\nsent for `HEAD` requests if your object uses server-side encryption with Key\nManagement Service (KMS) keys (SSE-KMS), dual-layer server-side encryption with\nAmazon Web Services KMS keys (DSSE-KMS), or server-side encryption with Amazon\nS3 managed encryption keys (SSE-S3). The `x-amz-server-side-encryption` header\nis used when you `PUT` an object to S3 and want to specify the encryption\nmethod. If you include this header in a `HEAD` request for an object that uses\nthese types of keys, you’ll get an HTTP `400 Bad Request` error. It's because\nthe encryption method can't be changed when you retrieve the object.\n\nIf you encrypt an object by using server-side encryption with customer-provided\nencryption keys (SSE-C) when you store the object in Amazon S3, then when you\nretrieve the metadata from the object, you must use the following headers to\nprovide the encryption key for the server to be able to retrieve the object's\nmetadata. The headers are:\n\n   `x-amz-server-side-encryption-customer-algorithm`\n\n   `x-amz-server-side-encryption-customer-key`\n\n   `x-amz-server-side-encryption-customer-key-MD5`\n\nFor more information about SSE-C, see [Server-Side Encryption (Using Customer-Provided Encryption\nKeys)](https://docs.aws.amazon.com/AmazonS3/latest/dev/ServerSideEncryptionCustomerKeys.html)\nin the *Amazon S3 User Guide*.\n\n**Directory bucket permissions** - For directory buckets, only server-side\nencryption with Amazon S3 managed keys (SSE-S3) (`AES256`) is supported.\n\n#","ref":"AWS.S3.html#head_object/5-encryption","title":"Encryption - AWS.S3.head_object/5","type":"function"},{"doc":"If the current version of the object is a delete marker, Amazon S3\nbehaves as if the object was deleted and includes `x-amz-delete-marker: true` in\nthe response.\n\n   If the specified version is a delete marker, the response returns a\n`405 Method Not Allowed` error and the `Last-Modified: timestamp` response\nheader.\n\n   **Directory buckets** - Delete marker is not supported by directory\nbuckets.\n\n   **Directory buckets** - S3 Versioning isn't enabled and supported\nfor directory buckets. For this API operation, only the `null` value of the\nversion ID is supported by directory buckets. You can only specify `null` to the\n`versionId` query parameter in the request.\n\n#","ref":"AWS.S3.html#head_object/5-versioning","title":"Versioning - AWS.S3.head_object/5","type":"function"},{"doc":"**Directory buckets ** - The HTTP Host header syntax is `\n*Bucket_name*.s3express-*az_id*.*region*.amazonaws.com`.\n\nThe following actions are related to `HeadObject`:\n\n  *\n[GetObject](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObject.html)     *\n[GetObjectAttributes](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectAttributes.html)","ref":"AWS.S3.html#head_object/5-http-host-header-syntax","title":"HTTP Host header syntax - AWS.S3.head_object/5","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nLists the analytics configurations for the bucket. You can have up to 1,000\nanalytics configurations per bucket.\n\nThis action supports list pagination and does not return more than 100\nconfigurations at a time. You should always check the `IsTruncated` element in\nthe response. If there are no more configurations to list, `IsTruncated` is set\nto false. If there are more configurations to list, `IsTruncated` is set to\ntrue, and there will be a value in `NextContinuationToken`. You use the\n`NextContinuationToken` value to continue the pagination of the list by passing\nthe value in continuation-token in the request to `GET` the next page.\n\nTo use this operation, you must have permissions to perform the\n`s3:GetAnalyticsConfiguration` action. The bucket owner has this permission by\ndefault. The bucket owner can grant this permission to others. For more\ninformation about permissions, see [Permissions Related to Bucket Subresource Operations](https://docs.aws.amazon.com/AmazonS3/latest/userguide/using-with-s3-actions.html#using-with-s3-actions-related-to-bucket-subresources)\nand [Managing Access Permissions to Your Amazon S3 Resources](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-access-control.html).\n\nFor information about Amazon S3 analytics feature, see [Amazon S3 Analytics – Storage Class\nAnalysis](https://docs.aws.amazon.com/AmazonS3/latest/dev/analytics-storage-class.html).\n\nThe following operations are related to `ListBucketAnalyticsConfigurations`:\n\n  *\n[GetBucketAnalyticsConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketAnalyticsConfiguration.html)     *\n[DeleteBucketAnalyticsConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteBucketAnalyticsConfiguration.html)\n\n  *\n[PutBucketAnalyticsConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketAnalyticsConfiguration.html)","ref":"AWS.S3.html#list_bucket_analytics_configurations/5","title":"AWS.S3.list_bucket_analytics_configurations/5","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nLists the S3 Intelligent-Tiering configuration from the specified bucket.\n\nThe S3 Intelligent-Tiering storage class is designed to optimize storage costs\nby automatically moving data to the most cost-effective storage access tier,\nwithout performance impact or operational overhead. S3 Intelligent-Tiering\ndelivers automatic cost savings in three low latency and high throughput access\ntiers. To get the lowest storage cost on data that can be accessed in minutes to\nhours, you can choose to activate additional archiving capabilities.\n\nThe S3 Intelligent-Tiering storage class is the ideal storage class for data\nwith unknown, changing, or unpredictable access patterns, independent of object\nsize or retention period. If the size of an object is less than 128 KB, it is\nnot monitored and not eligible for auto-tiering. Smaller objects can be stored,\nbut they are always charged at the Frequent Access tier rates in the S3\nIntelligent-Tiering storage class.\n\nFor more information, see [Storage class for automatically optimizing frequently and infrequently accessed\nobjects](https://docs.aws.amazon.com/AmazonS3/latest/dev/storage-class-intro.html#sc-dynamic-data-access).\n\nOperations related to `ListBucketIntelligentTieringConfigurations` include:\n\n  *\n[DeleteBucketIntelligentTieringConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteBucketIntelligentTieringConfiguration.html)     *\n[PutBucketIntelligentTieringConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketIntelligentTieringConfiguration.html)\n\n  *\n[GetBucketIntelligentTieringConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketIntelligentTieringConfiguration.html)","ref":"AWS.S3.html#list_bucket_intelligent_tiering_configurations/4","title":"AWS.S3.list_bucket_intelligent_tiering_configurations/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nReturns a list of inventory configurations for the bucket. You can have up to\n1,000 analytics configurations per bucket.\n\nThis action supports list pagination and does not return more than 100\nconfigurations at a time. Always check the `IsTruncated` element in the\nresponse. If there are no more configurations to list, `IsTruncated` is set to\nfalse. If there are more configurations to list, `IsTruncated` is set to true,\nand there is a value in `NextContinuationToken`. You use the\n`NextContinuationToken` value to continue the pagination of the list by passing\nthe value in continuation-token in the request to `GET` the next page.\n\nTo use this operation, you must have permissions to perform the\n`s3:GetInventoryConfiguration` action. The bucket owner has this permission by\ndefault. The bucket owner can grant this permission to others. For more\ninformation about permissions, see [Permissions Related to Bucket Subresource Operations](https://docs.aws.amazon.com/AmazonS3/latest/userguide/using-with-s3-actions.html#using-with-s3-actions-related-to-bucket-subresources)\nand [Managing Access Permissions to Your Amazon S3 Resources](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-access-control.html).\n\nFor information about the Amazon S3 inventory feature, see [Amazon S3 Inventory](https://docs.aws.amazon.com/AmazonS3/latest/dev/storage-inventory.html)\n\nThe following operations are related to `ListBucketInventoryConfigurations`:\n\n  *\n[GetBucketInventoryConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketInventoryConfiguration.html)     *\n[DeleteBucketInventoryConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteBucketInventoryConfiguration.html)\n\n  *\n[PutBucketInventoryConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketInventoryConfiguration.html)","ref":"AWS.S3.html#list_bucket_inventory_configurations/5","title":"AWS.S3.list_bucket_inventory_configurations/5","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nLists the metrics configurations for the bucket. The metrics configurations are\nonly for the request metrics of the bucket and do not provide information on\ndaily storage metrics. You can have up to 1,000 configurations per bucket.\n\nThis action supports list pagination and does not return more than 100\nconfigurations at a time. Always check the `IsTruncated` element in the\nresponse. If there are no more configurations to list, `IsTruncated` is set to\nfalse. If there are more configurations to list, `IsTruncated` is set to true,\nand there is a value in `NextContinuationToken`. You use the\n`NextContinuationToken` value to continue the pagination of the list by passing\nthe value in `continuation-token` in the request to `GET` the next page.\n\nTo use this operation, you must have permissions to perform the\n`s3:GetMetricsConfiguration` action. The bucket owner has this permission by\ndefault. The bucket owner can grant this permission to others. For more\ninformation about permissions, see [Permissions Related to Bucket Subresource Operations](https://docs.aws.amazon.com/AmazonS3/latest/userguide/using-with-s3-actions.html#using-with-s3-actions-related-to-bucket-subresources)\nand [Managing Access Permissions to Your Amazon S3 Resources](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-access-control.html).\n\nFor more information about metrics configurations and CloudWatch request\nmetrics, see [Monitoring Metrics with Amazon CloudWatch](https://docs.aws.amazon.com/AmazonS3/latest/dev/cloudwatch-monitoring.html).\n\nThe following operations are related to `ListBucketMetricsConfigurations`:\n\n  *\n[PutBucketMetricsConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketMetricsConfiguration.html)     *\n[GetBucketMetricsConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketMetricsConfiguration.html)\n\n  *\n[DeleteBucketMetricsConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteBucketMetricsConfiguration.html)","ref":"AWS.S3.html#list_bucket_metrics_configurations/5","title":"AWS.S3.list_bucket_metrics_configurations/5","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nReturns a list of all buckets owned by the authenticated sender of the request.\nTo use this operation, you must have the `s3:ListAllMyBuckets` permission.\n\nFor information about Amazon S3 buckets, see [Creating, configuring, and working with Amazon S3\nbuckets](https://docs.aws.amazon.com/AmazonS3/latest/userguide/creating-buckets-s3.html).","ref":"AWS.S3.html#list_buckets/2","title":"AWS.S3.list_buckets/2","type":"function"},{"doc":"Returns a list of all Amazon S3 directory buckets owned by the authenticated\nsender of the request.\n\nFor more information about directory buckets, see [Directory buckets](https://docs.aws.amazon.com/AmazonS3/latest/userguide/directory-buckets-overview.html)\nin the *Amazon S3 User Guide*.\n\n**Directory buckets ** - For directory buckets, you must make requests for this\nAPI operation to the Regional endpoint. These endpoints support path-style\nrequests in the format\n`https://s3express-control.*region_code*.amazonaws.com/*bucket-name* `.\nVirtual-hosted-style requests aren't supported. For more information, see\n[Regional and Zonal endpoints](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-express-Regions-and-Zones.html)\nin the *Amazon S3 User Guide*.","ref":"AWS.S3.html#list_directory_buckets/4","title":"AWS.S3.list_directory_buckets/4","type":"function"},{"doc":"#","ref":"AWS.S3.html#list_directory_buckets/4-definitions","title":"Definitions - AWS.S3.list_directory_buckets/4","type":"function"},{"doc":"You must have the `s3express:ListAllMyDirectoryBuckets` permission in an IAM\nidentity-based policy instead of a bucket policy. Cross-account access to this\nAPI operation isn't supported. This operation can only be performed by the\nAmazon Web Services account that owns the resource. For more information about\ndirectory bucket policies and permissions, see [Amazon Web Services Identity and Access Management (IAM) for S3 Express One\nZone](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-express-security-iam.html)\nin the *Amazon S3 User Guide*.\n\n#","ref":"AWS.S3.html#list_directory_buckets/4-permissions","title":"Permissions - AWS.S3.list_directory_buckets/4","type":"function"},{"doc":"**Directory buckets ** - The HTTP Host header syntax is\n`s3express-control.*region*.amazonaws.com`.","ref":"AWS.S3.html#list_directory_buckets/4-http-host-header-syntax","title":"HTTP Host header syntax - AWS.S3.list_directory_buckets/4","type":"function"},{"doc":"This operation lists in-progress multipart uploads in a bucket.\n\nAn in-progress multipart upload is a multipart upload that has been initiated by\nthe `CreateMultipartUpload` request, but has not yet been completed or aborted.\n\n**Directory buckets** - If multipart uploads in a directory bucket are in\nprogress, you can't delete the bucket until all the in-progress multipart\nuploads are aborted or completed.\n\nThe `ListMultipartUploads` operation returns a maximum of 1,000 multipart\nuploads in the response. The limit of 1,000 multipart uploads is also the\ndefault value. You can further limit the number of uploads in a response by\nspecifying the `max-uploads` request parameter. If there are more than 1,000\nmultipart uploads that satisfy your `ListMultipartUploads` request, the response\nreturns an `IsTruncated` element with the value of `true`, a `NextKeyMarker`\nelement, and a `NextUploadIdMarker` element. To list the remaining multipart\nuploads, you need to make subsequent `ListMultipartUploads` requests. In these\nrequests, include two query parameters: `key-marker` and `upload-id-marker`. Set\nthe value of `key-marker` to the `NextKeyMarker` value from the previous\nresponse. Similarly, set the value of `upload-id-marker` to the\n`NextUploadIdMarker` value from the previous response.\n\n**Directory buckets** - The `upload-id-marker` element and the\n`NextUploadIdMarker` element aren't supported by directory buckets. To list the\nadditional multipart uploads, you only need to set the value of `key-marker` to\nthe `NextKeyMarker` value from the previous response.\n\nFor more information about multipart uploads, see [Uploading Objects Using Multipart\nUpload](https://docs.aws.amazon.com/AmazonS3/latest/dev/uploadobjusingmpu.html)\nin the *Amazon S3 User Guide*.\n\n**Directory buckets** - For directory buckets, you must make requests for this\nAPI operation to the Zonal endpoint. These endpoints support\nvirtual-hosted-style requests in the format\n`https://*bucket_name*.s3express-*az_id*.*region*.amazonaws.com/*key-name* `.\nPath-style requests are not supported. For more information, see [Regional and Zonal\nendpoints](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-express-Regions-and-Zones.html)\nin the *Amazon S3 User Guide*.","ref":"AWS.S3.html#list_multipart_uploads/11","title":"AWS.S3.list_multipart_uploads/11","type":"function"},{"doc":"#","ref":"AWS.S3.html#list_multipart_uploads/11-definitions","title":"Definitions - AWS.S3.list_multipart_uploads/11","type":"function"},{"doc":"**General purpose bucket permissions** - For information about\npermissions required to use the multipart upload API, see [Multipart Upload and Permissions](https://docs.aws.amazon.com/AmazonS3/latest/dev/mpuAndPermissions.html)\nin the *Amazon S3 User Guide*.\n\n   **Directory bucket permissions** - To grant access to this API\noperation on a directory bucket, we recommend that you use the [ `CreateSession`\n](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateSession.html) API\noperation for session-based authorization. Specifically, you grant the\n`s3express:CreateSession` permission to the directory bucket in a bucket policy\nor an IAM identity-based policy. Then, you make the `CreateSession` API call on\nthe bucket to obtain a session token. With the session token in your request\nheader, you can make API requests to this operation. After the session token\nexpires, you make another `CreateSession` API call to generate a new session\ntoken for use. Amazon Web Services CLI or SDKs create session and refresh the\nsession token automatically to avoid service interruptions when a session\nexpires. For more information about authorization, see [ `CreateSession`\n](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateSession.html).\n\n#","ref":"AWS.S3.html#list_multipart_uploads/11-permissions","title":"Permissions - AWS.S3.list_multipart_uploads/11","type":"function"},{"doc":"**General purpose bucket** - In the `ListMultipartUploads`\nresponse, the multipart uploads are sorted based on two criteria:\n\n     Key-based sorting - Multipart uploads are initially\nsorted in ascending order based on their object keys.\n\n     Time-based sorting - For uploads that share the same\nobject key, they are further sorted in ascending order based on the upload\ninitiation time. Among uploads with the same key, the one that was initiated\nfirst will appear before the ones that were initiated later.\n\n   **Directory bucket** - In the `ListMultipartUploads` response, the\nmultipart uploads aren't sorted lexicographically based on the object keys.\n\n#","ref":"AWS.S3.html#list_multipart_uploads/11-sorting-of-multipart-uploads-in-response","title":"Sorting of multipart uploads in response - AWS.S3.list_multipart_uploads/11","type":"function"},{"doc":"**Directory buckets ** - The HTTP Host header syntax is `\n*Bucket_name*.s3express-*az_id*.*region*.amazonaws.com`.\n\nThe following operations are related to `ListMultipartUploads`:\n\n  *\n[CreateMultipartUpload](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateMultipartUpload.html)     *\n[UploadPart](https://docs.aws.amazon.com/AmazonS3/latest/API/API_UploadPart.html)\n\n  *\n[CompleteMultipartUpload](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CompleteMultipartUpload.html)     *\n[ListParts](https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListParts.html)\n\n  *\n[AbortMultipartUpload](https://docs.aws.amazon.com/AmazonS3/latest/API/API_AbortMultipartUpload.html)","ref":"AWS.S3.html#list_multipart_uploads/11-http-host-header-syntax","title":"HTTP Host header syntax - AWS.S3.list_multipart_uploads/11","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nReturns metadata about all versions of the objects in a bucket. You can also use\nrequest parameters as selection criteria to return metadata about a subset of\nall the object versions.\n\nTo use this operation, you must have permission to perform the\n`s3:ListBucketVersions` action. Be aware of the name difference.\n\nA `200 OK` response can contain valid or invalid XML. Make sure to design your\napplication to parse the contents of the response and handle it appropriately.\n\nTo use this operation, you must have READ access to the bucket.\n\nThe following operations are related to `ListObjectVersions`:\n\n  *\n[ListObjectsV2](https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListObjectsV2.html)     *\n[GetObject](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObject.html)\n\n  *\n[PutObject](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObject.html)     *\n[DeleteObject](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteObject.html)","ref":"AWS.S3.html#list_object_versions/12","title":"AWS.S3.list_object_versions/12","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nReturns some or all (up to 1,000) of the objects in a bucket. You can use the\nrequest parameters as selection criteria to return a subset of the objects in a\nbucket. A 200 OK response can contain valid or invalid XML. Be sure to design\nyour application to parse the contents of the response and handle it\nappropriately.\n\nThis action has been revised. We recommend that you use the newer version,\n[ListObjectsV2](https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListObjectsV2.html), when developing applications. For backward compatibility, Amazon S3 continues to\nsupport `ListObjects`.\n\nThe following operations are related to `ListObjects`:\n\n  *\n[ListObjectsV2](https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListObjectsV2.html)\n\n  *\n[GetObject](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObject.html)     *\n[PutObject](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObject.html)\n\n  *\n[CreateBucket](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateBucket.html)     *\n[ListBuckets](https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListBuckets.html)","ref":"AWS.S3.html#list_objects/11","title":"AWS.S3.list_objects/11","type":"function"},{"doc":"Returns some or all (up to 1,000) of the objects in a bucket with each request.\n\nYou can use the request parameters as selection criteria to return a subset of\nthe objects in a bucket. A `200 OK` response can contain valid or invalid XML.\nMake sure to design your application to parse the contents of the response and\nhandle it appropriately. For more information about listing objects, see\n[Listing object keys programmatically](https://docs.aws.amazon.com/AmazonS3/latest/userguide/ListingKeysUsingAPIs.html)\nin the *Amazon S3 User Guide*. To get a list of your buckets, see\n[ListBuckets](https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListBuckets.html).  **Directory buckets** - For directory buckets, you must make requests for this\nAPI operation to the Zonal endpoint. These endpoints support\nvirtual-hosted-style requests in the format\n`https://*bucket_name*.s3express-*az_id*.*region*.amazonaws.com/*key-name* `.\nPath-style requests are not supported. For more information, see [Regional and\nZonal\nendpoints](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-express-Regions-and-Zones.html)\nin the *Amazon S3 User Guide*.","ref":"AWS.S3.html#list_objects_v2/13","title":"AWS.S3.list_objects_v2/13","type":"function"},{"doc":"#","ref":"AWS.S3.html#list_objects_v2/13-definitions","title":"Definitions - AWS.S3.list_objects_v2/13","type":"function"},{"doc":"**General purpose bucket permissions** - To use this operation, you\nmust have READ access to the bucket. You must have permission to perform the\n`s3:ListBucket` action. The bucket owner has this permission by default and can\ngrant this permission to others. For more information about permissions, see\n[Permissions Related to Bucket Subresource Operations](https://docs.aws.amazon.com/AmazonS3/latest/userguide/using-with-s3-actions.html#using-with-s3-actions-related-to-bucket-subresources)\nand [Managing Access Permissions to Your Amazon S3 Resources](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-access-control.html)\nin the *Amazon S3 User Guide*.\n\n   **Directory bucket permissions** - To grant access to this API\noperation on a directory bucket, we recommend that you use the [ `CreateSession`\n](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateSession.html) API\noperation for session-based authorization. Specifically, you grant the\n`s3express:CreateSession` permission to the directory bucket in a bucket policy\nor an IAM identity-based policy. Then, you make the `CreateSession` API call on\nthe bucket to obtain a session token. With the session token in your request\nheader, you can make API requests to this operation. After the session token\nexpires, you make another `CreateSession` API call to generate a new session\ntoken for use. Amazon Web Services CLI or SDKs create session and refresh the\nsession token automatically to avoid service interruptions when a session\nexpires. For more information about authorization, see [ `CreateSession`\n](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateSession.html).\n\n#","ref":"AWS.S3.html#list_objects_v2/13-permissions","title":"Permissions - AWS.S3.list_objects_v2/13","type":"function"},{"doc":"**General purpose bucket** - For general purpose buckets,\n`ListObjectsV2` returns objects in lexicographical order based on their key\nnames.\n\n   **Directory bucket** - For directory buckets, `ListObjectsV2` does\nnot return objects in lexicographical order.\n\n#","ref":"AWS.S3.html#list_objects_v2/13-sorting-order-of-returned-objects","title":"Sorting order of returned objects - AWS.S3.list_objects_v2/13","type":"function"},{"doc":"**Directory buckets ** - The HTTP Host header syntax is `\n*Bucket_name*.s3express-*az_id*.*region*.amazonaws.com`.\n\nThis section describes the latest revision of this action. We recommend that you\nuse this revised API operation for application development. For backward\ncompatibility, Amazon S3 continues to support the prior version of this API\noperation,\n[ListObjects](https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListObjects.html). \nThe following operations are related to `ListObjectsV2`:\n\n  *\n[GetObject](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObject.html)\n\n  *\n[PutObject](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObject.html)     *\n[CreateBucket](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateBucket.html)","ref":"AWS.S3.html#list_objects_v2/13-http-host-header-syntax","title":"HTTP Host header syntax - AWS.S3.list_objects_v2/13","type":"function"},{"doc":"Lists the parts that have been uploaded for a specific multipart upload.\n\nTo use this operation, you must provide the `upload ID` in the request. You\nobtain this uploadID by sending the initiate multipart upload request through\n[CreateMultipartUpload](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateMultipartUpload.html).  The `ListParts` request returns a maximum of 1,000 uploaded parts. The limit of\n1,000 parts is also the default value. You can restrict the number of parts in a\nresponse by specifying the `max-parts` request parameter. If your multipart\nupload consists of more than 1,000 parts, the response returns an `IsTruncated`\nfield with the value of `true`, and a `NextPartNumberMarker` element. To list\nremaining uploaded parts, in subsequent `ListParts` requests, include the\n`part-number-marker` query string parameter and set its value to the\n`NextPartNumberMarker` field value from the previous response.\n\nFor more information on multipart uploads, see [Uploading Objects Using\nMultipart\nUpload](https://docs.aws.amazon.com/AmazonS3/latest/dev/uploadobjusingmpu.html)\nin the *Amazon S3 User Guide*.\n\n**Directory buckets** - For directory buckets, you must make requests for this\nAPI operation to the Zonal endpoint. These endpoints support\nvirtual-hosted-style requests in the format\n`https://*bucket_name*.s3express-*az_id*.*region*.amazonaws.com/*key-name* `.\nPath-style requests are not supported. For more information, see [Regional and Zonal\nendpoints](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-express-Regions-and-Zones.html)\nin the *Amazon S3 User Guide*.","ref":"AWS.S3.html#list_parts/12","title":"AWS.S3.list_parts/12","type":"function"},{"doc":"#","ref":"AWS.S3.html#list_parts/12-definitions","title":"Definitions - AWS.S3.list_parts/12","type":"function"},{"doc":"**General purpose bucket permissions** - For information about\npermissions required to use the multipart upload API, see [Multipart Upload and Permissions](https://docs.aws.amazon.com/AmazonS3/latest/dev/mpuAndPermissions.html)\nin the *Amazon S3 User Guide*.\n\nIf the upload was created using server-side encryption with Key Management\nService (KMS) keys (SSE-KMS) or dual-layer server-side encryption with Amazon\nWeb Services KMS keys (DSSE-KMS), you must have permission to the `kms:Decrypt`\naction for the `ListParts` request to succeed.\n\n   **Directory bucket permissions** - To grant access to this API\noperation on a directory bucket, we recommend that you use the [ `CreateSession`\n](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateSession.html) API\noperation for session-based authorization. Specifically, you grant the\n`s3express:CreateSession` permission to the directory bucket in a bucket policy\nor an IAM identity-based policy. Then, you make the `CreateSession` API call on\nthe bucket to obtain a session token. With the session token in your request\nheader, you can make API requests to this operation. After the session token\nexpires, you make another `CreateSession` API call to generate a new session\ntoken for use. Amazon Web Services CLI or SDKs create session and refresh the\nsession token automatically to avoid service interruptions when a session\nexpires. For more information about authorization, see [ `CreateSession`\n](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateSession.html).\n\n#","ref":"AWS.S3.html#list_parts/12-permissions","title":"Permissions - AWS.S3.list_parts/12","type":"function"},{"doc":"**Directory buckets ** - The HTTP Host header syntax is `\n*Bucket_name*.s3express-*az_id*.*region*.amazonaws.com`.\n\nThe following operations are related to `ListParts`:\n\n  *\n[CreateMultipartUpload](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateMultipartUpload.html)     *\n[UploadPart](https://docs.aws.amazon.com/AmazonS3/latest/API/API_UploadPart.html)\n\n  *\n[CompleteMultipartUpload](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CompleteMultipartUpload.html)     *\n[AbortMultipartUpload](https://docs.aws.amazon.com/AmazonS3/latest/API/API_AbortMultipartUpload.html)\n\n  *\n[GetObjectAttributes](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectAttributes.html)     *\n[ListMultipartUploads](https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListMultipartUploads.html)","ref":"AWS.S3.html#list_parts/12-http-host-header-syntax","title":"HTTP Host header syntax - AWS.S3.list_parts/12","type":"function"},{"doc":"","ref":"AWS.S3.html#metadata/0","title":"AWS.S3.metadata/0","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nSets the accelerate configuration of an existing bucket. Amazon S3 Transfer\nAcceleration is a bucket-level feature that enables you to perform faster data\ntransfers to Amazon S3.\n\nTo use this operation, you must have permission to perform the\n`s3:PutAccelerateConfiguration` action. The bucket owner has this permission by\ndefault. The bucket owner can grant this permission to others. For more\ninformation about permissions, see [Permissions Related to Bucket Subresource Operations](https://docs.aws.amazon.com/AmazonS3/latest/userguide/using-with-s3-actions.html#using-with-s3-actions-related-to-bucket-subresources)\nand [Managing Access Permissions to Your Amazon S3 Resources](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-access-control.html).\n\nThe Transfer Acceleration state of a bucket can be set to one of the following\ntwo values:\n\n  * Enabled – Enables accelerated data transfers to the bucket.\n\n  * Suspended – Disables accelerated data transfers to the bucket.\n\nThe\n[GetBucketAccelerateConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketAccelerateConfiguration.html) action returns the transfer acceleration state of a bucket.\n\nAfter setting the Transfer Acceleration state of a bucket to Enabled, it might\ntake up to thirty minutes before the data transfer rates to the bucket increase.\n\nThe name of the bucket used for Transfer Acceleration must be DNS-compliant and\nmust not contain periods (\".\").\n\nFor more information about transfer acceleration, see [Transfer\nAcceleration](https://docs.aws.amazon.com/AmazonS3/latest/dev/transfer-acceleration.html).\n\nThe following operations are related to `PutBucketAccelerateConfiguration`:\n\n  *\n[GetBucketAccelerateConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketAccelerateConfiguration.html)     *\n[CreateBucket](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateBucket.html)","ref":"AWS.S3.html#put_bucket_accelerate_configuration/4","title":"AWS.S3.put_bucket_accelerate_configuration/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nSets the permissions on an existing bucket using access control lists (ACL). For\nmore information, see [Using ACLs](https://docs.aws.amazon.com/AmazonS3/latest/dev/S3_ACLs_UsingACLs.html).\nTo set the ACL of a bucket, you must have the `WRITE_ACP` permission.\n\nYou can use one of the following two ways to set a bucket's permissions:\n\n  * Specify the ACL in the request body\n\n  * Specify permissions using request headers\n\nYou cannot specify access permission using both the body and the request\nheaders.\n\nDepending on your application needs, you may choose to set the ACL on a bucket\nusing either the request body or the headers. For example, if you have an\nexisting application that updates a bucket ACL using the request body, then you\ncan continue to use that approach.\n\nIf your bucket uses the bucket owner enforced setting for S3 Object Ownership,\nACLs are disabled and no longer affect permissions. You must use policies to\ngrant access to your bucket and the objects in it. Requests to set ACLs or\nupdate ACLs fail and return the `AccessControlListNotSupported` error code.\nRequests to read ACLs are still supported. For more information, see\n[Controlling object ownership](https://docs.aws.amazon.com/AmazonS3/latest/userguide/about-object-ownership.html)\nin the *Amazon S3 User Guide*.","ref":"AWS.S3.html#put_bucket_acl/4","title":"AWS.S3.put_bucket_acl/4","type":"function"},{"doc":"#","ref":"AWS.S3.html#put_bucket_acl/4-definitions","title":"Definitions - AWS.S3.put_bucket_acl/4","type":"function"},{"doc":"You can set access permissions by using one of the following methods:\n\n   Specify a canned ACL with the `x-amz-acl` request header. Amazon S3\nsupports a set of predefined ACLs, known as *canned ACLs*. Each canned ACL has a\npredefined set of grantees and permissions. Specify the canned ACL name as the\nvalue of `x-amz-acl`. If you use this header, you cannot use other access\ncontrol-specific headers in your request. For more information, see [Canned ACL](https://docs.aws.amazon.com/AmazonS3/latest/dev/acl-overview.html#CannedACL).\n\n   Specify access permissions explicitly with the `x-amz-grant-read`,\n`x-amz-grant-read-acp`, `x-amz-grant-write-acp`, and `x-amz-grant-full-control`\nheaders. When using these headers, you specify explicit access permissions and\ngrantees (Amazon Web Services accounts or Amazon S3 groups) who will receive the\npermission. If you use these ACL-specific headers, you cannot use the\n`x-amz-acl` header to set a canned ACL. These parameters map to the set of\npermissions that Amazon S3 supports in an ACL. For more information, see [Access Control List (ACL)\nOverview](https://docs.aws.amazon.com/AmazonS3/latest/dev/acl-overview.html).\n\nYou specify each grantee as a type=value pair, where the type is one of the\nfollowing:\n\n     `id` – if the value specified is the canonical user ID\nof an Amazon Web Services account\n\n     `uri` – if you are granting permissions to a predefined\ngroup\n\n     `emailAddress` – if the value specified is the email\naddress of an Amazon Web Services account\n\nUsing email addresses to specify a grantee is only supported in the following\nAmazon Web Services Regions:\n\n   US East (N. Virginia)\n\n   US West (N. California)\n\n   US West (Oregon)\n\n   Asia Pacific (Singapore)\n\n   Asia Pacific (Sydney)\n\n   Asia Pacific (Tokyo)\n\n   Europe (Ireland)\n\n   South America (São Paulo)\n\nFor a list of all the Amazon S3 supported Regions and endpoints, see [Regions and\nEndpoints](https://docs.aws.amazon.com/general/latest/gr/rande.html#s3_region)\nin the Amazon Web Services General Reference.\n\nFor example, the following `x-amz-grant-write` header grants create, overwrite,\nand delete objects permission to LogDelivery group predefined by Amazon S3 and\ntwo Amazon Web Services accounts identified by their email addresses.\n\n`x-amz-grant-write: uri=\"http://acs.amazonaws.com/groups/s3/LogDelivery\",\nid=\"111122223333\", id=\"555566667777\" `\n\nYou can use either a canned ACL or specify access permissions explicitly. You\ncannot do both.\n\n#","ref":"AWS.S3.html#put_bucket_acl/4-permissions","title":"Permissions - AWS.S3.put_bucket_acl/4","type":"function"},{"doc":"You can specify the person (grantee) to whom you're assigning access rights\n(using request elements) in the following ways:\n\n   By the person's ID:\n\n`  <>ID<>  <>GranteesEmail<> \n `\n\nDisplayName is optional and ignored in the request\n\n   By URI:\n\n`  <>http://acs.amazonaws.com/groups/global/AuthenticatedUsers<>  `\n\n   By Email address:\n\n`  <>Grantees@email.com<> & `\n\nThe grantee is resolved to the CanonicalUser and, in a response to a GET Object\nacl request, appears as the CanonicalUser.\n\nUsing email addresses to specify a grantee is only supported in the following\nAmazon Web Services Regions:\n\n   US East (N. Virginia)\n\n   US West (N. California)\n\n   US West (Oregon)\n\n   Asia Pacific (Singapore)\n\n   Asia Pacific (Sydney)\n\n   Asia Pacific (Tokyo)\n\n   Europe (Ireland)\n\n   South America (São Paulo)\n\nFor a list of all the Amazon S3 supported Regions and endpoints, see [Regions and\nEndpoints](https://docs.aws.amazon.com/general/latest/gr/rande.html#s3_region)\nin the Amazon Web Services General Reference.\n\nThe following operations are related to `PutBucketAcl`:\n\n  *\n[CreateBucket](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateBucket.html)     *\n[DeleteBucket](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteBucket.html)\n\n  *\n[GetObjectAcl](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectAcl.html)","ref":"AWS.S3.html#put_bucket_acl/4-grantee-values","title":"Grantee Values - AWS.S3.put_bucket_acl/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nSets an analytics configuration for the bucket (specified by the analytics\nconfiguration ID). You can have up to 1,000 analytics configurations per bucket.\n\nYou can choose to have storage class analysis export analysis reports sent to a\ncomma-separated values (CSV) flat file. See the `DataExport` request element.\nReports are updated daily and are based on the object filters that you\nconfigure. When selecting data export, you specify a destination bucket and an\noptional destination prefix where the file is written. You can export the data\nto a destination bucket in a different account. However, the destination bucket\nmust be in the same Region as the bucket that you are making the PUT analytics\nconfiguration to. For more information, see [Amazon S3 Analytics – Storage Class Analysis](https://docs.aws.amazon.com/AmazonS3/latest/dev/analytics-storage-class.html).\n\nYou must create a bucket policy on the destination bucket where the exported\nfile is written to grant permissions to Amazon S3 to write objects to the\nbucket. For an example policy, see [Granting Permissions for Amazon S3 Inventory and Storage Class\nAnalysis](https://docs.aws.amazon.com/AmazonS3/latest/dev/example-bucket-policies.html#example-bucket-policies-use-case-9).\n\nTo use this operation, you must have permissions to perform the\n`s3:PutAnalyticsConfiguration` action. The bucket owner has this permission by\ndefault. The bucket owner can grant this permission to others. For more\ninformation about permissions, see [Permissions Related to Bucket Subresource Operations](https://docs.aws.amazon.com/AmazonS3/latest/userguide/using-with-s3-actions.html#using-with-s3-actions-related-to-bucket-subresources)\nand [Managing Access Permissions to Your Amazon S3 Resources](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-access-control.html).\n\n`PutBucketAnalyticsConfiguration` has the following special errors:\n\n  *     * *HTTP Error: HTTP 400 Bad Request*\n\n    * *Code: InvalidArgument*\n\n    * *Cause: Invalid argument.*\n\n  *     * *HTTP Error: HTTP 400 Bad Request*\n\n    * *Code: TooManyConfigurations*\n\n    * *Cause: You are attempting to create a new\nconfiguration but have already reached the 1,000-configuration limit.*\n\n  *     * *HTTP Error: HTTP 403 Forbidden*\n\n    * *Code: AccessDenied*\n\n    * *Cause: You are not the owner of the specified bucket,\nor you do not have the s3:PutAnalyticsConfiguration bucket permission to set the\nconfiguration on the bucket.*\n\nThe following operations are related to `PutBucketAnalyticsConfiguration`:\n\n  *\n[GetBucketAnalyticsConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketAnalyticsConfiguration.html)     *\n[DeleteBucketAnalyticsConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteBucketAnalyticsConfiguration.html)\n\n  *\n[ListBucketAnalyticsConfigurations](https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListBucketAnalyticsConfigurations.html)","ref":"AWS.S3.html#put_bucket_analytics_configuration/4","title":"AWS.S3.put_bucket_analytics_configuration/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nSets the `cors` configuration for your bucket. If the configuration exists,\nAmazon S3 replaces it.\n\nTo use this operation, you must be allowed to perform the `s3:PutBucketCORS`\naction. By default, the bucket owner has this permission and can grant it to\nothers.\n\nYou set this configuration on a bucket so that the bucket can service\ncross-origin requests. For example, you might want to enable a request whose\norigin is `http://www.example.com` to access your Amazon S3 bucket at\n`my.example.bucket.com` by using the browser's `XMLHttpRequest` capability.\n\nTo enable cross-origin resource sharing (CORS) on a bucket, you add the `cors`\nsubresource to the bucket. The `cors` subresource is an XML document in which\nyou configure rules that identify origins and the HTTP methods that can be\nexecuted on your bucket. The document is limited to 64 KB in size.\n\nWhen Amazon S3 receives a cross-origin request (or a pre-flight OPTIONS request)\nagainst a bucket, it evaluates the `cors` configuration on the bucket and uses\nthe first `CORSRule` rule that matches the incoming browser request to enable a\ncross-origin request. For a rule to match, the following conditions must be met:\n\n  * The request's `Origin` header must match `AllowedOrigin` elements.\n\n  * The request method (for example, GET, PUT, HEAD, and so on) or the\n`Access-Control-Request-Method` header in case of a pre-flight `OPTIONS` request\nmust be one of the `AllowedMethod` elements.\n\n  * Every header specified in the `Access-Control-Request-Headers`\nrequest header of a pre-flight request must match an `AllowedHeader` element.\n\nFor more information about CORS, go to [Enabling Cross-Origin Resource Sharing](https://docs.aws.amazon.com/AmazonS3/latest/dev/cors.html) in the\n*Amazon S3 User Guide*.\n\nThe following operations are related to `PutBucketCors`:\n\n  *\n[GetBucketCors](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketCors.html)     *\n[DeleteBucketCors](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteBucketCors.html)\n\n  *\n[RESTOPTIONSobject](https://docs.aws.amazon.com/AmazonS3/latest/API/RESTOPTIONSobject.html)","ref":"AWS.S3.html#put_bucket_cors/4","title":"AWS.S3.put_bucket_cors/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nThis action uses the `encryption` subresource to configure default encryption\nand Amazon S3 Bucket Keys for an existing bucket.\n\nBy default, all buckets have a default encryption configuration that uses\nserver-side encryption with Amazon S3 managed keys (SSE-S3). You can optionally\nconfigure default encryption for a bucket by using server-side encryption with\nKey Management Service (KMS) keys (SSE-KMS) or dual-layer server-side encryption\nwith Amazon Web Services KMS keys (DSSE-KMS). If you specify default encryption\nby using SSE-KMS, you can also configure [Amazon S3 Bucket Keys](https://docs.aws.amazon.com/AmazonS3/latest/dev/bucket-key.html). If you\nuse PutBucketEncryption to set your [default bucket encryption](https://docs.aws.amazon.com/AmazonS3/latest/dev/bucket-encryption.html)\nto SSE-KMS, you should verify that your KMS key ID is correct. Amazon S3 does\nnot validate the KMS key ID provided in PutBucketEncryption requests.\n\nThis action requires Amazon Web Services Signature Version 4. For more\ninformation, see [ Authenticating Requests (Amazon Web Services Signature Version\n4)](https://docs.aws.amazon.com/AmazonS3/latest/API/sig-v4-authenticating-requests.html).\n\nTo use this operation, you must have permission to perform the\n`s3:PutEncryptionConfiguration` action. The bucket owner has this permission by\ndefault. The bucket owner can grant this permission to others. For more\ninformation about permissions, see [Permissions Related to Bucket Subresource Operations](https://docs.aws.amazon.com/AmazonS3/latest/userguide/using-with-s3-actions.html#using-with-s3-actions-related-to-bucket-subresources)\nand [Managing Access Permissions to Your Amazon S3 Resources](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-access-control.html)\nin the *Amazon S3 User Guide*.\n\nThe following operations are related to `PutBucketEncryption`:\n\n  *\n[GetBucketEncryption](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketEncryption.html)     *\n[DeleteBucketEncryption](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteBucketEncryption.html)","ref":"AWS.S3.html#put_bucket_encryption/4","title":"AWS.S3.put_bucket_encryption/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nPuts a S3 Intelligent-Tiering configuration to the specified bucket. You can\nhave up to 1,000 S3 Intelligent-Tiering configurations per bucket.\n\nThe S3 Intelligent-Tiering storage class is designed to optimize storage costs\nby automatically moving data to the most cost-effective storage access tier,\nwithout performance impact or operational overhead. S3 Intelligent-Tiering\ndelivers automatic cost savings in three low latency and high throughput access\ntiers. To get the lowest storage cost on data that can be accessed in minutes to\nhours, you can choose to activate additional archiving capabilities.\n\nThe S3 Intelligent-Tiering storage class is the ideal storage class for data\nwith unknown, changing, or unpredictable access patterns, independent of object\nsize or retention period. If the size of an object is less than 128 KB, it is\nnot monitored and not eligible for auto-tiering. Smaller objects can be stored,\nbut they are always charged at the Frequent Access tier rates in the S3\nIntelligent-Tiering storage class.\n\nFor more information, see [Storage class for automatically optimizing frequently and infrequently accessed\nobjects](https://docs.aws.amazon.com/AmazonS3/latest/dev/storage-class-intro.html#sc-dynamic-data-access).\n\nOperations related to `PutBucketIntelligentTieringConfiguration` include:\n\n  *\n[DeleteBucketIntelligentTieringConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteBucketIntelligentTieringConfiguration.html)     *\n[GetBucketIntelligentTieringConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketIntelligentTieringConfiguration.html)\n\n  *\n[ListBucketIntelligentTieringConfigurations](https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListBucketIntelligentTieringConfigurations.html)\n\nYou only need S3 Intelligent-Tiering enabled on a bucket if you want to\nautomatically move objects stored in the S3 Intelligent-Tiering storage class to\nthe Archive Access or Deep Archive Access tier.\n\n`PutBucketIntelligentTieringConfiguration` has the following special errors:","ref":"AWS.S3.html#put_bucket_intelligent_tiering_configuration/4","title":"AWS.S3.put_bucket_intelligent_tiering_configuration/4","type":"function"},{"doc":"#","ref":"AWS.S3.html#put_bucket_intelligent_tiering_configuration/4-definitions","title":"Definitions - AWS.S3.put_bucket_intelligent_tiering_configuration/4","type":"function"},{"doc":"*Code:* InvalidArgument\n\n*Cause:* Invalid Argument\n\n#","ref":"AWS.S3.html#put_bucket_intelligent_tiering_configuration/4-http-400-bad-request-error","title":"HTTP 400 Bad Request Error - AWS.S3.put_bucket_intelligent_tiering_configuration/4","type":"function"},{"doc":"*Code:* TooManyConfigurations\n\n*Cause:* You are attempting to create a new configuration but have already\nreached the 1,000-configuration limit.\n\n#","ref":"AWS.S3.html#put_bucket_intelligent_tiering_configuration/4-http-400-bad-request-error","title":"HTTP 400 Bad Request Error - AWS.S3.put_bucket_intelligent_tiering_configuration/4","type":"function"},{"doc":"*Cause:* You are not the owner of the specified bucket, or you do not have the\n`s3:PutIntelligentTieringConfiguration` bucket permission to set the\nconfiguration on the bucket.","ref":"AWS.S3.html#put_bucket_intelligent_tiering_configuration/4-http-403-forbidden-error","title":"HTTP 403 Forbidden Error - AWS.S3.put_bucket_intelligent_tiering_configuration/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nThis implementation of the `PUT` action adds an inventory configuration\n(identified by the inventory ID) to the bucket. You can have up to 1,000\ninventory configurations per bucket.\n\nAmazon S3 inventory generates inventories of the objects in the bucket on a\ndaily or weekly basis, and the results are published to a flat file. The bucket\nthat is inventoried is called the *source* bucket, and the bucket where the\ninventory flat file is stored is called the *destination* bucket. The\n*destination* bucket must be in the same Amazon Web Services Region as the\n*source* bucket.\n\nWhen you configure an inventory for a *source* bucket, you specify the\n*destination* bucket where you want the inventory to be stored, and whether to\ngenerate the inventory daily or weekly. You can also configure what object\nmetadata to include and whether to inventory all object versions or only current\nversions. For more information, see [Amazon S3 Inventory](https://docs.aws.amazon.com/AmazonS3/latest/dev/storage-inventory.html)\nin the Amazon S3 User Guide.\n\nYou must create a bucket policy on the *destination* bucket to grant permissions\nto Amazon S3 to write objects to the bucket in the defined location. For an\nexample policy, see [ Granting Permissions for Amazon S3 Inventory and Storage Class\nAnalysis](https://docs.aws.amazon.com/AmazonS3/latest/dev/example-bucket-policies.html#example-bucket-policies-use-case-9).","ref":"AWS.S3.html#put_bucket_inventory_configuration/4","title":"AWS.S3.put_bucket_inventory_configuration/4","type":"function"},{"doc":"#","ref":"AWS.S3.html#put_bucket_inventory_configuration/4-definitions","title":"Definitions - AWS.S3.put_bucket_inventory_configuration/4","type":"function"},{"doc":"To use this operation, you must have permission to perform the\n`s3:PutInventoryConfiguration` action. The bucket owner has this permission by\ndefault and can grant this permission to others.\n\nThe `s3:PutInventoryConfiguration` permission allows a user to create an [S3 Inventory](https://docs.aws.amazon.com/AmazonS3/latest/userguide/storage-inventory.html)\nreport that includes all object metadata fields available and to specify the\ndestination bucket to store the inventory. A user with read access to objects in\nthe destination bucket can also access all object metadata fields that are\navailable in the inventory report.\n\nTo restrict access to an inventory report, see [Restricting access to an Amazon S3 Inventory\nreport](https://docs.aws.amazon.com/AmazonS3/latest/userguide/example-bucket-policies.html#example-bucket-policies-use-case-10)\nin the *Amazon S3 User Guide*. For more information about the metadata fields\navailable in S3 Inventory, see [Amazon S3 Inventory lists](https://docs.aws.amazon.com/AmazonS3/latest/userguide/storage-inventory.html#storage-inventory-contents)\nin the *Amazon S3 User Guide*. For more information about permissions, see\n[Permissions related to bucket subresource operations](https://docs.aws.amazon.com/AmazonS3/latest/userguide/using-with-s3-actions.html#using-with-s3-actions-related-to-bucket-subresources)\nand [Identity and access management in Amazon S3](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-access-control.html)\nin the *Amazon S3 User Guide*.\n\n`PutBucketInventoryConfiguration` has the following special errors:","ref":"AWS.S3.html#put_bucket_inventory_configuration/4-permissions","title":"Permissions - AWS.S3.put_bucket_inventory_configuration/4","type":"function"},{"doc":"#","ref":"AWS.S3.html#put_bucket_inventory_configuration/4-definitions","title":"Definitions - AWS.S3.put_bucket_inventory_configuration/4","type":"function"},{"doc":"*Code:* InvalidArgument\n\n*Cause:* Invalid Argument\n\n#","ref":"AWS.S3.html#put_bucket_inventory_configuration/4-http-400-bad-request-error","title":"HTTP 400 Bad Request Error - AWS.S3.put_bucket_inventory_configuration/4","type":"function"},{"doc":"*Code:* TooManyConfigurations\n\n*Cause:* You are attempting to create a new configuration but have already\nreached the 1,000-configuration limit.\n\n#","ref":"AWS.S3.html#put_bucket_inventory_configuration/4-http-400-bad-request-error","title":"HTTP 400 Bad Request Error - AWS.S3.put_bucket_inventory_configuration/4","type":"function"},{"doc":"*Cause:* You are not the owner of the specified bucket, or you do not have the\n`s3:PutInventoryConfiguration` bucket permission to set the configuration on the\nbucket.\n\nThe following operations are related to `PutBucketInventoryConfiguration`:\n\n  *\n[GetBucketInventoryConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketInventoryConfiguration.html)     *\n[DeleteBucketInventoryConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteBucketInventoryConfiguration.html)\n\n  *\n[ListBucketInventoryConfigurations](https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListBucketInventoryConfigurations.html)","ref":"AWS.S3.html#put_bucket_inventory_configuration/4-http-403-forbidden-error","title":"HTTP 403 Forbidden Error - AWS.S3.put_bucket_inventory_configuration/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nFor an updated version of this API, see\n[PutBucketLifecycleConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketLifecycleConfiguration.html). This version has been deprecated. Existing lifecycle configurations will work.\nFor new lifecycle configurations, use the updated API.\n\nCreates a new lifecycle configuration for the bucket or replaces an existing\nlifecycle configuration. For information about lifecycle configuration, see\n[Object Lifecycle\nManagement](https://docs.aws.amazon.com/AmazonS3/latest/dev/object-lifecycle-mgmt.html)\nin the *Amazon S3 User Guide*.\n\nBy default, all Amazon S3 resources, including buckets, objects, and related\nsubresources (for example, lifecycle configuration and website configuration)\nare private. Only the resource owner, the Amazon Web Services account that\ncreated the resource, can access it. The resource owner can optionally grant\naccess permissions to others by writing an access policy. For this operation,\nusers must get the `s3:PutLifecycleConfiguration` permission.\n\nYou can also explicitly deny permissions. Explicit denial also supersedes any\nother permissions. If you want to prevent users or accounts from removing or\ndeleting objects from your bucket, you must deny them permissions for the\nfollowing actions:\n\n  * `s3:DeleteObject`\n\n  * `s3:DeleteObjectVersion`\n\n  * `s3:PutLifecycleConfiguration`\n\nFor more information about permissions, see [Managing Access Permissions to your Amazon S3\nResources](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-access-control.html)\nin the *Amazon S3 User Guide*.\n\nFor more examples of transitioning objects to storage classes such as\nSTANDARD_IA or ONEZONE_IA, see [Examples of Lifecycle Configuration](https://docs.aws.amazon.com/AmazonS3/latest/dev/intro-lifecycle-rules.html#lifecycle-configuration-examples).\n\nThe following operations are related to `PutBucketLifecycle`:\n\n  *\n[GetBucketLifecycle](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketLifecycle.html)(Deprecated)     *\n[GetBucketLifecycleConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketLifecycleConfiguration.html)\n\n  *\n[RestoreObject](https://docs.aws.amazon.com/AmazonS3/latest/API/API_RestoreObject.html)     * By default, a resource owner—in this case, a bucket owner, which\nis the Amazon Web Services account that created the bucket—can perform any of\nthe operations. A resource owner can also grant others permission to perform the\noperation. For more information, see the following topics in the Amazon S3 User\nGuide:\n\n    * [Specifying Permissions in a\nPolicy](https://docs.aws.amazon.com/AmazonS3/latest/dev/using-with-s3-actions.html)\n\n    * [Managing Access Permissions to your Amazon S3 Resources](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-access-control.html)","ref":"AWS.S3.html#put_bucket_lifecycle/4","title":"AWS.S3.put_bucket_lifecycle/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nCreates a new lifecycle configuration for the bucket or replaces an existing\nlifecycle configuration. Keep in mind that this will overwrite an existing\nlifecycle configuration, so if you want to retain any configuration details,\nthey must be included in the new lifecycle configuration. For information about\nlifecycle configuration, see [Managing your storage lifecycle](https://docs.aws.amazon.com/AmazonS3/latest/userguide/object-lifecycle-mgmt.html).\n\nBucket lifecycle configuration now supports specifying a lifecycle rule using an\nobject key name prefix, one or more object tags, or a combination of both.\nAccordingly, this section describes the latest API. The previous version of the\nAPI supported filtering based only on an object key name prefix, which is\nsupported for backward compatibility. For the related API description, see\n[PutBucketLifecycle](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketLifecycle.html).","ref":"AWS.S3.html#put_bucket_lifecycle_configuration/4","title":"AWS.S3.put_bucket_lifecycle_configuration/4","type":"function"},{"doc":"#","ref":"AWS.S3.html#put_bucket_lifecycle_configuration/4-definitions","title":"Definitions - AWS.S3.put_bucket_lifecycle_configuration/4","type":"function"},{"doc":"You specify the lifecycle configuration in your request body. The lifecycle\nconfiguration is specified as XML consisting of one or more rules. An Amazon S3\nLifecycle configuration can have up to 1,000 rules. This limit is not\nadjustable. Each rule consists of the following:\n\n   A filter identifying a subset of objects to which the rule applies.\nThe filter can be based on a key name prefix, object tags, or a combination of\nboth.\n\n   A status indicating whether the rule is in effect.\n\n   One or more lifecycle transition and expiration actions that you\nwant Amazon S3 to perform on the objects identified by the filter. If the state\nof your bucket is versioning-enabled or versioning-suspended, you can have many\nversions of the same object (one current version and zero or more noncurrent\nversions). Amazon S3 provides predefined actions that you can specify for\ncurrent and noncurrent object versions.\n\nFor more information, see [Object Lifecycle\nManagement](https://docs.aws.amazon.com/AmazonS3/latest/dev/object-lifecycle-mgmt.html)\nand [Lifecycle Configuration Elements](https://docs.aws.amazon.com/AmazonS3/latest/dev/intro-lifecycle-rules.html).\n\n#","ref":"AWS.S3.html#put_bucket_lifecycle_configuration/4-rules","title":"Rules - AWS.S3.put_bucket_lifecycle_configuration/4","type":"function"},{"doc":"By default, all Amazon S3 resources are private, including buckets, objects, and\nrelated subresources (for example, lifecycle configuration and website\nconfiguration). Only the resource owner (that is, the Amazon Web Services\naccount that created it) can access the resource. The resource owner can\noptionally grant access permissions to others by writing an access policy. For\nthis operation, a user must get the `s3:PutLifecycleConfiguration` permission.\n\nYou can also explicitly deny permissions. An explicit deny also supersedes any\nother permissions. If you want to block users or accounts from removing or\ndeleting objects from your bucket, you must deny them permissions for the\nfollowing actions:\n\n   `s3:DeleteObject`\n\n   `s3:DeleteObjectVersion`\n\n   `s3:PutLifecycleConfiguration`\n\nFor more information about permissions, see [Managing Access Permissions to Your Amazon S3\nResources](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-access-control.html).\n\nThe following operations are related to `PutBucketLifecycleConfiguration`:\n\n  * [Examples of Lifecycle Configuration](https://docs.aws.amazon.com/AmazonS3/latest/dev/lifecycle-configuration-examples.html)\n\n  *\n[GetBucketLifecycleConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketLifecycleConfiguration.html)     *\n[DeleteBucketLifecycle](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteBucketLifecycle.html)","ref":"AWS.S3.html#put_bucket_lifecycle_configuration/4-permissions","title":"Permissions - AWS.S3.put_bucket_lifecycle_configuration/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nSet the logging parameters for a bucket and to specify permissions for who can\nview and modify the logging parameters. All logs are saved to buckets in the\nsame Amazon Web Services Region as the source bucket. To set the logging status\nof a bucket, you must be the bucket owner.\n\nThe bucket owner is automatically granted FULL_CONTROL to all logs. You use the\n`Grantee` request element to grant access to other people. The `Permissions`\nrequest element specifies the kind of access the grantee has to the logs.\n\nIf the target bucket for log delivery uses the bucket owner enforced setting for\nS3 Object Ownership, you can't use the `Grantee` request element to grant access\nto others. Permissions can only be granted using policies. For more information,\nsee [Permissions for server access log delivery](https://docs.aws.amazon.com/AmazonS3/latest/userguide/enable-server-access-logging.html#grant-log-delivery-permissions-general)\nin the *Amazon S3 User Guide*.","ref":"AWS.S3.html#put_bucket_logging/4","title":"AWS.S3.put_bucket_logging/4","type":"function"},{"doc":"#","ref":"AWS.S3.html#put_bucket_logging/4-definitions","title":"Definitions - AWS.S3.put_bucket_logging/4","type":"function"},{"doc":"You can specify the person (grantee) to whom you're assigning access rights (by\nusing request elements) in the following ways:\n\n   By the person's ID:\n\n`  <>ID<>  <>GranteesEmail<> \n `\n\n`DisplayName` is optional and ignored in the request.\n\n   By Email address:\n\n`   <>Grantees@email.com<>  `\n\nThe grantee is resolved to the `CanonicalUser` and, in a response to a\n`GETObjectAcl` request, appears as the CanonicalUser.\n\n   By URI:\n\n`  <>http://acs.amazonaws.com/groups/global/AuthenticatedUsers<>  `\n\nTo enable logging, you use `LoggingEnabled` and its children request elements.\nTo disable logging, you use an empty `BucketLoggingStatus` request element:\n\n` `\n\nFor more information about server access logging, see [Server Access Logging](https://docs.aws.amazon.com/AmazonS3/latest/userguide/ServerLogs.html)\nin the *Amazon S3 User Guide*.\n\nFor more information about creating a bucket, see\n[CreateBucket](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateBucket.html). For more information about returning the logging status of a bucket, see\n[GetBucketLogging](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketLogging.html).\n\nThe following operations are related to `PutBucketLogging`:\n\n  *\n[PutObject](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObject.html)     *\n[DeleteBucket](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteBucket.html)\n\n  *\n[CreateBucket](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateBucket.html)     *\n[GetBucketLogging](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketLogging.html)","ref":"AWS.S3.html#put_bucket_logging/4-grantee-values","title":"Grantee Values - AWS.S3.put_bucket_logging/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nSets a metrics configuration (specified by the metrics configuration ID) for the\nbucket. You can have up to 1,000 metrics configurations per bucket. If you're\nupdating an existing metrics configuration, note that this is a full replacement\nof the existing metrics configuration. If you don't include the elements you\nwant to keep, they are erased.\n\nTo use this operation, you must have permissions to perform the\n`s3:PutMetricsConfiguration` action. The bucket owner has this permission by\ndefault. The bucket owner can grant this permission to others. For more\ninformation about permissions, see [Permissions Related to Bucket Subresource Operations](https://docs.aws.amazon.com/AmazonS3/latest/userguide/using-with-s3-actions.html#using-with-s3-actions-related-to-bucket-subresources)\nand [Managing Access Permissions to Your Amazon S3 Resources](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-access-control.html).\n\nFor information about CloudWatch request metrics for Amazon S3, see [Monitoring Metrics with Amazon\nCloudWatch](https://docs.aws.amazon.com/AmazonS3/latest/dev/cloudwatch-monitoring.html).\n\nThe following operations are related to `PutBucketMetricsConfiguration`:\n\n  *\n[DeleteBucketMetricsConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteBucketMetricsConfiguration.html)     *\n[GetBucketMetricsConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketMetricsConfiguration.html)\n\n  *\n[ListBucketMetricsConfigurations](https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListBucketMetricsConfigurations.html)\n\n`PutBucketMetricsConfiguration` has the following special error:\n\n  * Error code: `TooManyConfigurations`\n\n    * Description: You are attempting to create a new\nconfiguration but have already reached the 1,000-configuration limit.\n\n    * HTTP Status Code: HTTP 400 Bad Request","ref":"AWS.S3.html#put_bucket_metrics_configuration/4","title":"AWS.S3.put_bucket_metrics_configuration/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nNo longer used, see the\n[PutBucketNotificationConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketNotificationConfiguration.html)\noperation.","ref":"AWS.S3.html#put_bucket_notification/4","title":"AWS.S3.put_bucket_notification/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nEnables notifications of specified events for a bucket. For more information\nabout event notifications, see [Configuring Event Notifications](https://docs.aws.amazon.com/AmazonS3/latest/dev/NotificationHowTo.html).\n\nUsing this API, you can replace an existing notification configuration. The\nconfiguration is an XML file that defines the event types that you want Amazon\nS3 to publish and the destination where you want Amazon S3 to publish an event\nnotification when it detects an event of the specified type.\n\nBy default, your bucket has no event notifications configured. That is, the\nnotification configuration will be an empty `NotificationConfiguration`.\n\n` `\n\n` `\n\nThis action replaces the existing notification configuration with the\nconfiguration you include in the request body.\n\nAfter Amazon S3 receives this request, it first verifies that any Amazon Simple\nNotification Service (Amazon SNS) or Amazon Simple Queue Service (Amazon SQS)\ndestination exists, and that the bucket owner has permission to publish to it by\nsending a test notification. In the case of Lambda destinations, Amazon S3\nverifies that the Lambda function permissions grant Amazon S3 permission to\ninvoke the function from the Amazon S3 bucket. For more information, see\n[Configuring Notifications for Amazon S3 Events](https://docs.aws.amazon.com/AmazonS3/latest/dev/NotificationHowTo.html).\n\nYou can disable notifications by adding the empty NotificationConfiguration\nelement.\n\nFor more information about the number of event notification configurations that\nyou can create per bucket, see [Amazon S3 service quotas](https://docs.aws.amazon.com/general/latest/gr/s3.html#limits_s3) in\n*Amazon Web Services General Reference*.\n\nBy default, only the bucket owner can configure notifications on a bucket.\nHowever, bucket owners can use a bucket policy to grant permission to other\nusers to set this configuration with the required `s3:PutBucketNotification`\npermission.\n\nThe PUT notification is an atomic operation. For example, suppose your\nnotification configuration includes SNS topic, SQS queue, and Lambda function\nconfigurations. When you send a PUT request with this configuration, Amazon S3\nsends test messages to your SNS topic. If the message fails, the entire PUT\naction will fail, and Amazon S3 will not add the configuration to your bucket.\n\nIf the configuration in the request body includes only one `TopicConfiguration`\nspecifying only the `s3:ReducedRedundancyLostObject` event type, the response\nwill also include the `x-amz-sns-test-message-id` header containing the message\nID of the test notification sent to the topic.\n\nThe following action is related to `PutBucketNotificationConfiguration`:\n\n  *\n[GetBucketNotificationConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketNotificationConfiguration.html)","ref":"AWS.S3.html#put_bucket_notification_configuration/4","title":"AWS.S3.put_bucket_notification_configuration/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nCreates or modifies `OwnershipControls` for an Amazon S3 bucket. To use this\noperation, you must have the `s3:PutBucketOwnershipControls` permission. For\nmore information about Amazon S3 permissions, see [Specifying permissions in a policy](https://docs.aws.amazon.com/AmazonS3/latest/user-guide/using-with-s3-actions.html).\n\nFor information about Amazon S3 Object Ownership, see [Using object ownership](https://docs.aws.amazon.com/AmazonS3/latest/user-guide/about-object-ownership.html).\n\nThe following operations are related to `PutBucketOwnershipControls`:\n\n  * `GetBucketOwnershipControls`\n\n  * `DeleteBucketOwnershipControls`","ref":"AWS.S3.html#put_bucket_ownership_controls/4","title":"AWS.S3.put_bucket_ownership_controls/4","type":"function"},{"doc":"Applies an Amazon S3 bucket policy to an Amazon S3 bucket.\n\n**Directory buckets ** - For directory buckets, you must make requests for this\nAPI operation to the Regional endpoint. These endpoints support path-style\nrequests in the format\n`https://s3express-control.*region_code*.amazonaws.com/*bucket-name* `.\nVirtual-hosted-style requests aren't supported. For more information, see\n[Regional and Zonal endpoints](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-express-Regions-and-Zones.html)\nin the *Amazon S3 User Guide*.","ref":"AWS.S3.html#put_bucket_policy/4","title":"AWS.S3.put_bucket_policy/4","type":"function"},{"doc":"#","ref":"AWS.S3.html#put_bucket_policy/4-definitions","title":"Definitions - AWS.S3.put_bucket_policy/4","type":"function"},{"doc":"If you are using an identity other than the root user of the Amazon Web Services\naccount that owns the bucket, the calling identity must both have the\n`PutBucketPolicy` permissions on the specified bucket and belong to the bucket\nowner's account in order to use this operation.\n\nIf you don't have `PutBucketPolicy` permissions, Amazon S3 returns a `403 Access\nDenied` error. If you have the correct permissions, but you're not using an\nidentity that belongs to the bucket owner's account, Amazon S3 returns a `405\nMethod Not Allowed` error.\n\nTo ensure that bucket owners don't inadvertently lock themselves out of their\nown buckets, the root principal in a bucket owner's Amazon Web Services account\ncan perform the `GetBucketPolicy`, `PutBucketPolicy`, and `DeleteBucketPolicy`\nAPI actions, even if their bucket policy explicitly denies the root principal's\naccess. Bucket owner root principals can only be blocked from performing these\nAPI actions by VPC endpoint policies and Amazon Web Services Organizations\npolicies.\n\n   **General purpose bucket permissions** - The `s3:PutBucketPolicy`\npermission is required in a policy. For more information about general purpose\nbuckets bucket policies, see [Using Bucket Policies and User Policies](https://docs.aws.amazon.com/AmazonS3/latest/dev/using-iam-policies.html)\nin the *Amazon S3 User Guide*.\n\n   **Directory bucket permissions** - To grant access to this API\noperation, you must have the `s3express:PutBucketPolicy` permission in an IAM\nidentity-based policy instead of a bucket policy. Cross-account access to this\nAPI operation isn't supported. This operation can only be performed by the\nAmazon Web Services account that owns the resource. For more information about\ndirectory bucket policies and permissions, see [Amazon Web Services Identity and Access Management (IAM) for S3 Express One\nZone](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-express-security-iam.html)\nin the *Amazon S3 User Guide*.\n\n#","ref":"AWS.S3.html#put_bucket_policy/4-permissions","title":"Permissions - AWS.S3.put_bucket_policy/4","type":"function"},{"doc":"**General purpose buckets example bucket policies** - See [Bucket policy examples](https://docs.aws.amazon.com/AmazonS3/latest/userguide/example-bucket-policies.html)\nin the *Amazon S3 User Guide*.\n\n**Directory bucket example bucket policies** - See [Example bucket policies for S3 Express One\nZone](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-express-security-iam-example-bucket-policies.html)\nin the *Amazon S3 User Guide*.\n\n#","ref":"AWS.S3.html#put_bucket_policy/4-example-bucket-policies","title":"Example bucket policies - AWS.S3.put_bucket_policy/4","type":"function"},{"doc":"**Directory buckets ** - The HTTP Host header syntax is\n`s3express-control.*region*.amazonaws.com`.\n\nThe following operations are related to `PutBucketPolicy`:\n\n  *\n[CreateBucket](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateBucket.html)     *\n[DeleteBucket](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteBucket.html)","ref":"AWS.S3.html#put_bucket_policy/4-http-host-header-syntax","title":"HTTP Host header syntax - AWS.S3.put_bucket_policy/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nCreates a replication configuration or replaces an existing one. For more\ninformation, see\n[Replication](https://docs.aws.amazon.com/AmazonS3/latest/dev/replication.html) in the *Amazon S3 User Guide*.\n\nSpecify the replication configuration in the request body. In the replication\nconfiguration, you provide the name of the destination bucket or buckets where\nyou want Amazon S3 to replicate objects, the IAM role that Amazon S3 can assume\nto replicate objects on your behalf, and other relevant information. You can\ninvoke this request for a specific Amazon Web Services Region by using the [\n`aws:RequestedRegion`\n](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-requestedregion)\ncondition key.\n\nA replication configuration must include at least one rule, and can contain a\nmaximum of 1,000. Each rule identifies a subset of objects to replicate by\nfiltering the objects in the source bucket. To choose additional subsets of\nobjects to replicate, add a rule for each subset.\n\nTo specify a subset of the objects in the source bucket to apply a replication\nrule to, add the Filter element as a child of the Rule element. You can filter\nobjects based on an object key prefix, one or more object tags, or both. When\nyou add the Filter element in the configuration, you must also add the following\nelements: `DeleteMarkerReplication`, `Status`, and `Priority`.\n\nIf you are using an earlier version of the replication configuration, Amazon S3\nhandles replication of delete markers differently. For more information, see\n[Backward Compatibility](https://docs.aws.amazon.com/AmazonS3/latest/dev/replication-add-config.html#replication-backward-compat-considerations).\n\nFor information about enabling versioning on a bucket, see [Using Versioning](https://docs.aws.amazon.com/AmazonS3/latest/dev/Versioning.html).","ref":"AWS.S3.html#put_bucket_replication/4","title":"AWS.S3.put_bucket_replication/4","type":"function"},{"doc":"#","ref":"AWS.S3.html#put_bucket_replication/4-definitions","title":"Definitions - AWS.S3.put_bucket_replication/4","type":"function"},{"doc":"By default, Amazon S3 doesn't replicate objects that are stored at rest using\nserver-side encryption with KMS keys. To replicate Amazon Web Services\nKMS-encrypted objects, add the following: `SourceSelectionCriteria`,\n`SseKmsEncryptedObjects`, `Status`, `EncryptionConfiguration`, and\n`ReplicaKmsKeyID`. For information about replication configuration, see\n[Replicating Objects Created with SSE Using KMS keys](https://docs.aws.amazon.com/AmazonS3/latest/dev/replication-config-for-kms-objects.html).\n\nFor information on `PutBucketReplication` errors, see [List of replication-related error\ncodes](https://docs.aws.amazon.com/AmazonS3/latest/API/ErrorResponses.html#ReplicationErrorCodeList)\n\n#","ref":"AWS.S3.html#put_bucket_replication/4-handling-replication-of-encrypted-objects","title":"Handling Replication of Encrypted Objects - AWS.S3.put_bucket_replication/4","type":"function"},{"doc":"To create a `PutBucketReplication` request, you must have\n`s3:PutReplicationConfiguration` permissions for the bucket.\n\nBy default, a resource owner, in this case the Amazon Web Services account that\ncreated the bucket, can perform this operation. The resource owner can also\ngrant others permissions to perform the operation. For more information about\npermissions, see [Specifying Permissions in a Policy](https://docs.aws.amazon.com/AmazonS3/latest/dev/using-with-s3-actions.html)\nand [Managing Access Permissions to Your Amazon S3 Resources](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-access-control.html).\n\nTo perform this operation, the user or role performing the action must have the\n[iam:PassRole](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_use_passrole.html) permission.\n\nThe following operations are related to `PutBucketReplication`:\n\n  *\n[GetBucketReplication](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketReplication.html)\n\n  *\n[DeleteBucketReplication](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteBucketReplication.html)","ref":"AWS.S3.html#put_bucket_replication/4-permissions","title":"Permissions - AWS.S3.put_bucket_replication/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nSets the request payment configuration for a bucket. By default, the bucket\nowner pays for downloads from the bucket. This configuration parameter enables\nthe bucket owner (only) to specify that the person requesting the download will\nbe charged for the download. For more information, see [Requester Pays Buckets](https://docs.aws.amazon.com/AmazonS3/latest/dev/RequesterPaysBuckets.html).\n\nThe following operations are related to `PutBucketRequestPayment`:\n\n  *\n[CreateBucket](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateBucket.html)     *\n[GetBucketRequestPayment](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketRequestPayment.html)","ref":"AWS.S3.html#put_bucket_request_payment/4","title":"AWS.S3.put_bucket_request_payment/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nSets the tags for a bucket.\n\nUse tags to organize your Amazon Web Services bill to reflect your own cost\nstructure. To do this, sign up to get your Amazon Web Services account bill with\ntag key values included. Then, to see the cost of combined resources, organize\nyour billing information according to resources with the same tag key values.\nFor example, you can tag several resources with a specific application name, and\nthen organize your billing information to see the total cost of that application\nacross several services. For more information, see [Cost Allocation and Tagging](https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/cost-alloc-tags.html)\nand [Using Cost Allocation in Amazon S3 Bucket Tags](https://docs.aws.amazon.com/AmazonS3/latest/userguide/CostAllocTagging.html).\n\nWhen this operation sets the tags for a bucket, it will overwrite any current\ntags the bucket already has. You cannot use this operation to add tags to an\nexisting list of tags.\n\nTo use this operation, you must have permissions to perform the\n`s3:PutBucketTagging` action. The bucket owner has this permission by default\nand can grant this permission to others. For more information about permissions,\nsee [Permissions Related to Bucket Subresource Operations](https://docs.aws.amazon.com/AmazonS3/latest/userguide/using-with-s3-actions.html#using-with-s3-actions-related-to-bucket-subresources)\nand [Managing Access Permissions to Your Amazon S3 Resources](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-access-control.html).\n\n`PutBucketTagging` has the following special errors. For more Amazon S3 errors\nsee, [Error Responses](https://docs.aws.amazon.com/AmazonS3/latest/API/ErrorResponses.html).\n\n  * `InvalidTag` - The tag provided was not a valid tag. This error\ncan occur if the tag did not pass input validation. For more information, see\n[Using Cost Allocation in Amazon S3 Bucket Tags](https://docs.aws.amazon.com/AmazonS3/latest/userguide/CostAllocTagging.html).\n\n  * `MalformedXML` - The XML provided does not match the schema.\n\n  * `OperationAborted` - A conflicting conditional action is currently\nin progress against this resource. Please try again.\n\n  * `InternalError` - The service was unable to apply the provided tag\nto the bucket.\n\nThe following operations are related to `PutBucketTagging`:\n\n  *\n[GetBucketTagging](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketTagging.html)     *\n[DeleteBucketTagging](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteBucketTagging.html)","ref":"AWS.S3.html#put_bucket_tagging/4","title":"AWS.S3.put_bucket_tagging/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nSets the versioning state of an existing bucket.\n\nYou can set the versioning state with one of the following values:\n\n**Enabled**—Enables versioning for the objects in the bucket. All objects added\nto the bucket receive a unique version ID.\n\n**Suspended**—Disables versioning for the objects in the bucket. All objects\nadded to the bucket receive the version ID null.\n\nIf the versioning state has never been set on a bucket, it has no versioning\nstate; a\n[GetBucketVersioning](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketVersioning.html) request does not return a versioning state value.\n\nIn order to enable MFA Delete, you must be the bucket owner. If you are the\nbucket owner and want to enable MFA Delete in the bucket versioning\nconfiguration, you must include the `x-amz-mfa request` header and the `Status`\nand the `MfaDelete` request elements in a request to set the versioning state of\nthe bucket.\n\nIf you have an object expiration lifecycle configuration in your non-versioned\nbucket and you want to maintain the same permanent delete behavior when you\nenable versioning, you must add a noncurrent expiration policy. The noncurrent\nexpiration lifecycle configuration will manage the deletes of the noncurrent\nobject versions in the version-enabled bucket. (A version-enabled bucket\nmaintains one current and zero or more noncurrent object versions.) For more\ninformation, see [Lifecycle and\nVersioning](https://docs.aws.amazon.com/AmazonS3/latest/dev/object-lifecycle-mgmt.html#lifecycle-and-other-bucket-config).\n\nThe following operations are related to `PutBucketVersioning`:\n\n  *\n[CreateBucket](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateBucket.html)     *\n[DeleteBucket](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteBucket.html)\n\n  *\n[GetBucketVersioning](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketVersioning.html)","ref":"AWS.S3.html#put_bucket_versioning/4","title":"AWS.S3.put_bucket_versioning/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nSets the configuration of the website that is specified in the `website`\nsubresource. To configure a bucket as a website, you can add this subresource on\nthe bucket with website configuration information such as the file name of the\nindex document and any redirect rules. For more information, see [Hosting Websites on Amazon\nS3](https://docs.aws.amazon.com/AmazonS3/latest/dev/WebsiteHosting.html).\n\nThis PUT action requires the `S3:PutBucketWebsite` permission. By default, only\nthe bucket owner can configure the website attached to a bucket; however, bucket\nowners can allow other users to set the website configuration by writing a\nbucket policy that grants them the `S3:PutBucketWebsite` permission.\n\nTo redirect all website requests sent to the bucket's website endpoint, you add\na website configuration with the following elements. Because all requests are\nsent to another website, you don't need to provide index document name for the\nbucket.\n\n  * `WebsiteConfiguration`\n\n  * `RedirectAllRequestsTo`\n\n  * `HostName`\n\n  * `Protocol`\n\nIf you want granular control over redirects, you can use the following elements\nto add routing rules that describe conditions for redirecting requests and\ninformation about the redirect destination. In this case, the website\nconfiguration must provide an index document for the bucket, because some\nrequests might not be redirected.\n\n  * `WebsiteConfiguration`\n\n  * `IndexDocument`\n\n  * `Suffix`\n\n  * `ErrorDocument`\n\n  * `Key`\n\n  * `RoutingRules`\n\n  * `RoutingRule`\n\n  * `Condition`\n\n  * `HttpErrorCodeReturnedEquals`\n\n  * `KeyPrefixEquals`\n\n  * `Redirect`\n\n  * `Protocol`\n\n  * `HostName`\n\n  * `ReplaceKeyPrefixWith`\n\n  * `ReplaceKeyWith`\n\n  * `HttpRedirectCode`\n\nAmazon S3 has a limitation of 50 routing rules per website configuration. If you\nrequire more than 50 routing rules, you can use object redirect. For more\ninformation, see [Configuring an Object Redirect](https://docs.aws.amazon.com/AmazonS3/latest/dev/how-to-page-redirect.html)\nin the *Amazon S3 User Guide*.\n\nThe maximum request length is limited to 128 KB.","ref":"AWS.S3.html#put_bucket_website/4","title":"AWS.S3.put_bucket_website/4","type":"function"},{"doc":"Adds an object to a bucket.\n\n   Amazon S3 never adds partial objects; if you receive a success\nresponse, Amazon S3 added the entire object to the bucket. You cannot use\n`PutObject` to only update a single piece of metadata for an existing object.\nYou must put the entire object with updated metadata if you want to update some\nvalues.\n\n   If your bucket uses the bucket owner enforced setting for Object\nOwnership, ACLs are disabled and no longer affect permissions. All objects\nwritten to the bucket by any account will be owned by the bucket owner.\n\n   **Directory buckets** - For directory buckets, you must make\nrequests for this API operation to the Zonal endpoint. These endpoints support\nvirtual-hosted-style requests in the format\n`https://*bucket_name*.s3express-*az_id*.*region*.amazonaws.com/*key-name* `.\nPath-style requests are not supported. For more information, see [Regional and Zonal\nendpoints](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-express-Regions-and-Zones.html)\nin the *Amazon S3 User Guide*.\n\nAmazon S3 is a distributed system. If it receives multiple write requests for\nthe same object simultaneously, it overwrites all but the last object written.\nHowever, Amazon S3 provides features that can modify this behavior:\n\n  * **S3 Object Lock** - To prevent objects from being deleted or\noverwritten, you can use [Amazon S3 Object Lock](https://docs.aws.amazon.com/AmazonS3/latest/userguide/object-lock.html) in\nthe *Amazon S3 User Guide*.\n\nThis functionality is not supported for directory buckets.\n\n  * **S3 Versioning** - When you enable versioning for a bucket, if\nAmazon S3 receives multiple write requests for the same object simultaneously,\nit stores all versions of the objects. For each write request that is made to\nthe same object, Amazon S3 automatically generates a unique version ID of that\nobject being stored in Amazon S3. You can retrieve, replace, or delete any\nversion of the object. For more information about versioning, see [Adding Objects to Versioning-Enabled\nBuckets](https://docs.aws.amazon.com/AmazonS3/latest/dev/AddingObjectstoVersioningEnabledBuckets.html)\nin the *Amazon S3 User Guide*. For information about returning the versioning\nstate of a bucket, see\n[GetBucketVersioning](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketVersioning.html).  This functionality is not supported for directory buckets.","ref":"AWS.S3.html#put_object/5","title":"AWS.S3.put_object/5","type":"function"},{"doc":"#","ref":"AWS.S3.html#put_object/5-definitions","title":"Definitions - AWS.S3.put_object/5","type":"function"},{"doc":"**General purpose bucket permissions** - The following permissions\nare required in your policies when your `PutObject` request includes specific\nheaders.\n\n     ** `s3:PutObject` ** - To successfully complete the\n`PutObject` request, you must always have the `s3:PutObject` permission on a\nbucket to add an object to it.\n\n     ** `s3:PutObjectAcl` ** - To successfully change the\nobjects ACL of your `PutObject` request, you must have the `s3:PutObjectAcl`.\n\n     ** `s3:PutObjectTagging` ** - To successfully set the\ntag-set with your `PutObject` request, you must have the `s3:PutObjectTagging`.\n\n   **Directory bucket permissions** - To grant access to this API\noperation on a directory bucket, we recommend that you use the [ `CreateSession`\n](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateSession.html) API\noperation for session-based authorization. Specifically, you grant the\n`s3express:CreateSession` permission to the directory bucket in a bucket policy\nor an IAM identity-based policy. Then, you make the `CreateSession` API call on\nthe bucket to obtain a session token. With the session token in your request\nheader, you can make API requests to this operation. After the session token\nexpires, you make another `CreateSession` API call to generate a new session\ntoken for use. Amazon Web Services CLI or SDKs create session and refresh the\nsession token automatically to avoid service interruptions when a session\nexpires. For more information about authorization, see [ `CreateSession`\n](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateSession.html).\n\n#","ref":"AWS.S3.html#put_object/5-permissions","title":"Permissions - AWS.S3.put_object/5","type":"function"},{"doc":"**General purpose bucket** - To ensure that data is not corrupted\ntraversing the network, use the `Content-MD5` header. When you use this header,\nAmazon S3 checks the object against the provided MD5 value and, if they do not\nmatch, Amazon S3 returns an error. Alternatively, when the object's ETag is its\nMD5 digest, you can calculate the MD5 while putting the object to Amazon S3 and\ncompare the returned ETag to the calculated MD5 value.\n\n   **Directory bucket** - This functionality is not supported for\ndirectory buckets.\n\n#","ref":"AWS.S3.html#put_object/5-data-integrity-with-content-md5","title":"Data integrity with Content-MD5 - AWS.S3.put_object/5","type":"function"},{"doc":"**Directory buckets ** - The HTTP Host header syntax is `\n*Bucket_name*.s3express-*az_id*.*region*.amazonaws.com`.\n\nFor more information about related Amazon S3 APIs, see the following:\n\n  *\n[CopyObject](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CopyObject.html)     *\n[DeleteObject](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteObject.html)","ref":"AWS.S3.html#put_object/5-http-host-header-syntax","title":"HTTP Host header syntax - AWS.S3.put_object/5","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nUses the `acl` subresource to set the access control list (ACL) permissions for\na new or existing object in an S3 bucket. You must have the `WRITE_ACP`\npermission to set the ACL of an object. For more information, see [What permissions can I\ngrant?](https://docs.aws.amazon.com/AmazonS3/latest/dev/acl-overview.html#permissions)\nin the *Amazon S3 User Guide*.\n\nThis functionality is not supported for Amazon S3 on Outposts.\n\nDepending on your application needs, you can choose to set the ACL on an object\nusing either the request body or the headers. For example, if you have an\nexisting application that updates a bucket ACL using the request body, you can\ncontinue to use that approach. For more information, see [Access Control List (ACL)\nOverview](https://docs.aws.amazon.com/AmazonS3/latest/dev/acl-overview.html) in\nthe *Amazon S3 User Guide*.\n\nIf your bucket uses the bucket owner enforced setting for S3 Object Ownership,\nACLs are disabled and no longer affect permissions. You must use policies to\ngrant access to your bucket and the objects in it. Requests to set ACLs or\nupdate ACLs fail and return the `AccessControlListNotSupported` error code.\nRequests to read ACLs are still supported. For more information, see\n[Controlling object ownership](https://docs.aws.amazon.com/AmazonS3/latest/userguide/about-object-ownership.html)\nin the *Amazon S3 User Guide*.","ref":"AWS.S3.html#put_object_acl/5","title":"AWS.S3.put_object_acl/5","type":"function"},{"doc":"#","ref":"AWS.S3.html#put_object_acl/5-definitions","title":"Definitions - AWS.S3.put_object_acl/5","type":"function"},{"doc":"You can set access permissions using one of the following methods:\n\n   Specify a canned ACL with the `x-amz-acl` request header. Amazon S3\nsupports a set of predefined ACLs, known as canned ACLs. Each canned ACL has a\npredefined set of grantees and permissions. Specify the canned ACL name as the\nvalue of `x-amz-ac`l. If you use this header, you cannot use other access\ncontrol-specific headers in your request. For more information, see [Canned ACL](https://docs.aws.amazon.com/AmazonS3/latest/dev/acl-overview.html#CannedACL).\n\n   Specify access permissions explicitly with the `x-amz-grant-read`,\n`x-amz-grant-read-acp`, `x-amz-grant-write-acp`, and `x-amz-grant-full-control`\nheaders. When using these headers, you specify explicit access permissions and\ngrantees (Amazon Web Services accounts or Amazon S3 groups) who will receive the\npermission. If you use these ACL-specific headers, you cannot use `x-amz-acl`\nheader to set a canned ACL. These parameters map to the set of permissions that\nAmazon S3 supports in an ACL. For more information, see [Access Control List (ACL)\nOverview](https://docs.aws.amazon.com/AmazonS3/latest/dev/acl-overview.html).\n\nYou specify each grantee as a type=value pair, where the type is one of the\nfollowing:\n\n     `id` – if the value specified is the canonical user ID\nof an Amazon Web Services account\n\n     `uri` – if you are granting permissions to a predefined\ngroup\n\n     `emailAddress` – if the value specified is the email\naddress of an Amazon Web Services account\n\nUsing email addresses to specify a grantee is only supported in the following\nAmazon Web Services Regions:\n\n   US East (N. Virginia)\n\n   US West (N. California)\n\n   US West (Oregon)\n\n   Asia Pacific (Singapore)\n\n   Asia Pacific (Sydney)\n\n   Asia Pacific (Tokyo)\n\n   Europe (Ireland)\n\n   South America (São Paulo)\n\nFor a list of all the Amazon S3 supported Regions and endpoints, see [Regions and\nEndpoints](https://docs.aws.amazon.com/general/latest/gr/rande.html#s3_region)\nin the Amazon Web Services General Reference.\n\nFor example, the following `x-amz-grant-read` header grants list objects\npermission to the two Amazon Web Services accounts identified by their email\naddresses.\n\n`x-amz-grant-read: emailAddress=\"xyz@amazon.com\", emailAddress=\"abc@amazon.com\"\n`\n\nYou can use either a canned ACL or specify access permissions explicitly. You\ncannot do both.\n\n#","ref":"AWS.S3.html#put_object_acl/5-permissions","title":"Permissions - AWS.S3.put_object_acl/5","type":"function"},{"doc":"You can specify the person (grantee) to whom you're assigning access rights\n(using request elements) in the following ways:\n\n   By the person's ID:\n\n`  <>ID<>  <>GranteesEmail<> \n `\n\nDisplayName is optional and ignored in the request.\n\n   By URI:\n\n`  <>http://acs.amazonaws.com/groups/global/AuthenticatedUsers<>  `\n\n   By Email address:\n\n`  <>Grantees@email.com<> lt;/Grantee>`\n\nThe grantee is resolved to the CanonicalUser and, in a response to a GET Object\nacl request, appears as the CanonicalUser.\n\nUsing email addresses to specify a grantee is only supported in the following\nAmazon Web Services Regions:\n\n   US East (N. Virginia)\n\n   US West (N. California)\n\n   US West (Oregon)\n\n   Asia Pacific (Singapore)\n\n   Asia Pacific (Sydney)\n\n   Asia Pacific (Tokyo)\n\n   Europe (Ireland)\n\n   South America (São Paulo)\n\nFor a list of all the Amazon S3 supported Regions and endpoints, see [Regions and\nEndpoints](https://docs.aws.amazon.com/general/latest/gr/rande.html#s3_region)\nin the Amazon Web Services General Reference.\n\n#","ref":"AWS.S3.html#put_object_acl/5-grantee-values","title":"Grantee Values - AWS.S3.put_object_acl/5","type":"function"},{"doc":"The ACL of an object is set at the object version level. By default, PUT sets\nthe ACL of the current version of an object. To set the ACL of a different\nversion, use the `versionId` subresource.\n\nThe following operations are related to `PutObjectAcl`:\n\n  *\n[CopyObject](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CopyObject.html)     *\n[GetObject](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObject.html)","ref":"AWS.S3.html#put_object_acl/5-versioning","title":"Versioning - AWS.S3.put_object_acl/5","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nApplies a legal hold configuration to the specified object. For more\ninformation, see [Locking Objects](https://docs.aws.amazon.com/AmazonS3/latest/dev/object-lock.html).\n\nThis functionality is not supported for Amazon S3 on Outposts.","ref":"AWS.S3.html#put_object_legal_hold/5","title":"AWS.S3.put_object_legal_hold/5","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nPlaces an Object Lock configuration on the specified bucket. The rule specified\nin the Object Lock configuration will be applied by default to every new object\nplaced in the specified bucket. For more information, see [Locking Objects](https://docs.aws.amazon.com/AmazonS3/latest/dev/object-lock.html).\n\n   The `DefaultRetention` settings require both a mode and a period.\n\n   The `DefaultRetention` period can be either `Days` or `Years` but\nyou must select one. You cannot specify `Days` and `Years` at the same time.\n\n   You can enable Object Lock for new or existing buckets. For more\ninformation, see [Configuring Object Lock](https://docs.aws.amazon.com/AmazonS3/latest/userguide/object-lock-configure.html).","ref":"AWS.S3.html#put_object_lock_configuration/4","title":"AWS.S3.put_object_lock_configuration/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nPlaces an Object Retention configuration on an object. For more information, see\n[Locking Objects](https://docs.aws.amazon.com/AmazonS3/latest/dev/object-lock.html).\nUsers or accounts require the `s3:PutObjectRetention` permission in order to\nplace an Object Retention configuration on objects. Bypassing a Governance\nRetention configuration requires the `s3:BypassGovernanceRetention` permission.\n\nThis functionality is not supported for Amazon S3 on Outposts.","ref":"AWS.S3.html#put_object_retention/5","title":"AWS.S3.put_object_retention/5","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nSets the supplied tag-set to an object that already exists in a bucket. A tag is\na key-value pair. For more information, see [Object Tagging](https://docs.aws.amazon.com/AmazonS3/latest/userguide/object-tagging.html).\n\nYou can associate tags with an object by sending a PUT request against the\ntagging subresource that is associated with the object. You can retrieve tags by\nsending a GET request. For more information, see\n[GetObjectTagging](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectTagging.html).  For tagging-related restrictions related to characters and encodings, see [Tag\nRestrictions](https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/allocation-tag-restrictions.html).\nNote that Amazon S3 limits the maximum number of tags to 10 tags per object.\n\nTo use this operation, you must have permission to perform the\n`s3:PutObjectTagging` action. By default, the bucket owner has this permission\nand can grant this permission to others.\n\nTo put tags of any other version, use the `versionId` query parameter. You also\nneed permission for the `s3:PutObjectVersionTagging` action.\n\n`PutObjectTagging` has the following special errors. For more Amazon S3 errors\nsee, [Error Responses](https://docs.aws.amazon.com/AmazonS3/latest/API/ErrorResponses.html).\n\n  * `InvalidTag` - The tag provided was not a valid tag. This error\ncan occur if the tag did not pass input validation. For more information, see\n[Object Tagging](https://docs.aws.amazon.com/AmazonS3/latest/userguide/object-tagging.html).\n\n  * `MalformedXML` - The XML provided does not match the schema.\n\n  * `OperationAborted` - A conflicting conditional action is currently\nin progress against this resource. Please try again.\n\n  * `InternalError` - The service was unable to apply the provided tag\nto the object.\n\nThe following operations are related to `PutObjectTagging`:\n\n  *\n[GetObjectTagging](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectTagging.html)     *\n[DeleteObjectTagging](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteObjectTagging.html)","ref":"AWS.S3.html#put_object_tagging/5","title":"AWS.S3.put_object_tagging/5","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nCreates or modifies the `PublicAccessBlock` configuration for an Amazon S3\nbucket. To use this operation, you must have the `s3:PutBucketPublicAccessBlock`\npermission. For more information about Amazon S3 permissions, see [Specifying Permissions in a\nPolicy](https://docs.aws.amazon.com/AmazonS3/latest/dev/using-with-s3-actions.html).\n\nWhen Amazon S3 evaluates the `PublicAccessBlock` configuration for a bucket or\nan object, it checks the `PublicAccessBlock` configuration for both the bucket\n(or the bucket that contains the object) and the bucket owner's account. If the\n`PublicAccessBlock` configurations are different between the bucket and the\naccount, Amazon S3 uses the most restrictive combination of the bucket-level and\naccount-level settings.\n\nFor more information about when Amazon S3 considers a bucket or an object\npublic, see [The Meaning of \"Public\"](https://docs.aws.amazon.com/AmazonS3/latest/dev/access-control-block-public-access.html#access-control-block-public-access-policy-status).\n\nThe following operations are related to `PutPublicAccessBlock`:\n\n  *\n[GetPublicAccessBlock](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetPublicAccessBlock.html)     *\n[DeletePublicAccessBlock](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeletePublicAccessBlock.html)\n\n  *\n[GetBucketPolicyStatus](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketPolicyStatus.html)     * [Using Amazon S3 Block Public\nAccess](https://docs.aws.amazon.com/AmazonS3/latest/dev/access-control-block-public-access.html)","ref":"AWS.S3.html#put_public_access_block/4","title":"AWS.S3.put_public_access_block/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nRestores an archived copy of an object back into Amazon S3\n\nThis functionality is not supported for Amazon S3 on Outposts.\n\nThis action performs the following types of requests:\n\n  * `select` - Perform a select query on an archived object\n\n  * `restore an archive` - Restore an archived object\n\nFor more information about the `S3` structure in the request body, see the\nfollowing:\n\n  *\n[PutObject](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObject.html)     * [Managing Access with\nACLs](https://docs.aws.amazon.com/AmazonS3/latest/dev/S3_ACLs_UsingACLs.html) in\nthe *Amazon S3 User Guide*\n\n  * [Protecting Data Using Server-Side Encryption](https://docs.aws.amazon.com/AmazonS3/latest/dev/serv-side-encryption.html)\nin the *Amazon S3 User Guide*\n\nDefine the SQL expression for the `SELECT` type of restoration for your query in\nthe request body's `SelectParameters` structure. You can use expressions like\nthe following examples.\n\n  * The following expression returns all records from the specified\nobject.\n\n`SELECT * FROM Object`\n\n  * Assuming that you are not using any headers for data stored in the\nobject, you can specify columns with positional headers.\n\n`SELECT s._1, s._2 FROM Object s WHERE s._3 > 100`\n\n  * If you have headers and you set the `fileHeaderInfo` in the `CSV`\nstructure in the request body to `USE`, you can specify headers in the query.\n(If you set the `fileHeaderInfo` field to `IGNORE`, the first row is skipped for\nthe query.) You cannot mix ordinal positions with header column names.\n\n`SELECT s.Id, s.FirstName, s.SSN FROM S3Object s`\n\nWhen making a select request, you can also do the following:\n\n  * To expedite your queries, specify the `Expedited` tier. For more\ninformation about tiers, see \"Restoring Archives,\" later in this topic.\n\n  * Specify details about the data serialization format of both the\ninput object that is being queried and the serialization of the CSV-encoded\nquery results.\n\nThe following are additional important facts about the select feature:\n\n  * The output results are new Amazon S3 objects. Unlike archive\nretrievals, they are stored until explicitly deleted-manually or through a\nlifecycle configuration.\n\n  * You can issue more than one select request on the same Amazon S3\nobject. Amazon S3 doesn't duplicate requests, so avoid issuing duplicate\nrequests.\n\n  * Amazon S3 accepts a select request even if the object has already\nbeen restored. A select request doesn’t return error response `409`.","ref":"AWS.S3.html#restore_object/5","title":"AWS.S3.restore_object/5","type":"function"},{"doc":"#","ref":"AWS.S3.html#restore_object/5-definitions","title":"Definitions - AWS.S3.restore_object/5","type":"function"},{"doc":"To use this operation, you must have permissions to perform the\n`s3:RestoreObject` action. The bucket owner has this permission by default and\ncan grant this permission to others. For more information about permissions, see\n[Permissions Related to Bucket Subresource Operations](https://docs.aws.amazon.com/AmazonS3/latest/userguide/using-with-s3-actions.html#using-with-s3-actions-related-to-bucket-subresources)\nand [Managing Access Permissions to Your Amazon S3 Resources](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-access-control.html)\nin the *Amazon S3 User Guide*.\n\n#","ref":"AWS.S3.html#restore_object/5-permissions","title":"Permissions - AWS.S3.restore_object/5","type":"function"},{"doc":"Objects that you archive to the S3 Glacier Flexible Retrieval Flexible Retrieval\nor S3 Glacier Deep Archive storage class, and S3 Intelligent-Tiering Archive or\nS3 Intelligent-Tiering Deep Archive tiers, are not accessible in real time. For\nobjects in the S3 Glacier Flexible Retrieval Flexible Retrieval or S3 Glacier\nDeep Archive storage classes, you must first initiate a restore request, and\nthen wait until a temporary copy of the object is available. If you want a\npermanent copy of the object, create a copy of it in the Amazon S3 Standard\nstorage class in your S3 bucket. To access an archived object, you must restore\nthe object for the duration (number of days) that you specify. For objects in\nthe Archive Access or Deep Archive Access tiers of S3 Intelligent-Tiering, you\nmust first initiate a restore request, and then wait until the object is moved\ninto the Frequent Access tier.\n\nTo restore a specific object version, you can provide a version ID. If you don't\nprovide a version ID, Amazon S3 restores the current version.\n\nWhen restoring an archived object, you can specify one of the following data\naccess tier options in the `Tier` element of the request body:\n\n   `Expedited` - Expedited retrievals allow you to quickly access your\ndata stored in the S3 Glacier Flexible Retrieval Flexible Retrieval storage\nclass or S3 Intelligent-Tiering Archive tier when occasional urgent requests for\nrestoring archives are required. For all but the largest archived objects (250\nMB+), data accessed using Expedited retrievals is typically made available\nwithin 1–5 minutes. Provisioned capacity ensures that retrieval capacity for\nExpedited retrievals is available when you need it. Expedited retrievals and\nprovisioned capacity are not available for objects stored in the S3 Glacier Deep\nArchive storage class or S3 Intelligent-Tiering Deep Archive tier.\n\n   `Standard` - Standard retrievals allow you to access any of your\narchived objects within several hours. This is the default option for retrieval\nrequests that do not specify the retrieval option. Standard retrievals typically\nfinish within 3–5 hours for objects stored in the S3 Glacier Flexible Retrieval\nFlexible Retrieval storage class or S3 Intelligent-Tiering Archive tier. They\ntypically finish within 12 hours for objects stored in the S3 Glacier Deep\nArchive storage class or S3 Intelligent-Tiering Deep Archive tier. Standard\nretrievals are free for objects stored in S3 Intelligent-Tiering.\n\n   `Bulk` - Bulk retrievals free for objects stored in the S3 Glacier\nFlexible Retrieval and S3 Intelligent-Tiering storage classes, enabling you to\nretrieve large amounts, even petabytes, of data at no cost. Bulk retrievals\ntypically finish within 5–12 hours for objects stored in the S3 Glacier Flexible\nRetrieval Flexible Retrieval storage class or S3 Intelligent-Tiering Archive\ntier. Bulk retrievals are also the lowest-cost retrieval option when restoring\nobjects from S3 Glacier Deep Archive. They typically finish within 48 hours for\nobjects stored in the S3 Glacier Deep Archive storage class or S3\nIntelligent-Tiering Deep Archive tier.\n\nFor more information about archive retrieval options and provisioned capacity\nfor `Expedited` data access, see [Restoring Archived Objects](https://docs.aws.amazon.com/AmazonS3/latest/dev/restoring-objects.html)\nin the *Amazon S3 User Guide*.\n\nYou can use Amazon S3 restore speed upgrade to change the restore speed to a\nfaster speed while it is in progress. For more information, see [ Upgrading the speed of an in-progress\nrestore](https://docs.aws.amazon.com/AmazonS3/latest/dev/restoring-objects.html#restoring-objects-upgrade-tier.title.html)\nin the *Amazon S3 User Guide*.\n\nTo get the status of object restoration, you can send a `HEAD` request.\nOperations return the `x-amz-restore` header, which provides information about\nthe restoration status, in the response. You can use Amazon S3 event\nnotifications to notify you when a restore is initiated or completed. For more\ninformation, see [Configuring Amazon S3 Event Notifications](https://docs.aws.amazon.com/AmazonS3/latest/dev/NotificationHowTo.html)\nin the *Amazon S3 User Guide*.\n\nAfter restoring an archived object, you can update the restoration period by\nreissuing the request with a new period. Amazon S3 updates the restoration\nperiod relative to the current time and charges only for the request-there are\nno data transfer charges. You cannot update the restoration period when Amazon\nS3 is actively processing your current restore request for the object.\n\nIf your bucket has a lifecycle configuration with a rule that includes an\nexpiration action, the object expiration overrides the life span that you\nspecify in a restore request. For example, if you restore an object copy for 10\ndays, but the object is scheduled to expire in 3 days, Amazon S3 deletes the\nobject in 3 days. For more information about lifecycle configuration, see\n[PutBucketLifecycleConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketLifecycleConfiguration.html) and [Object Lifecycle\nManagement](https://docs.aws.amazon.com/AmazonS3/latest/dev/object-lifecycle-mgmt.html)\nin *Amazon S3 User Guide*.\n\n#","ref":"AWS.S3.html#restore_object/5-restoring-objects","title":"Restoring objects - AWS.S3.restore_object/5","type":"function"},{"doc":"A successful action returns either the `200 OK` or `202 Accepted` status code.\n\n   If the object is not previously restored, then Amazon S3 returns\n`202 Accepted` in the response.\n\n   If the object is previously restored, Amazon S3 returns `200 OK` in\nthe response.\n\n   Special errors:\n\n     *Code: RestoreAlreadyInProgress*\n\n     *Cause: Object restore is already in progress. (This\nerror does not apply to SELECT type requests.)*\n\n     *HTTP Status Code: 409 Conflict*\n\n     *SOAP Fault Code Prefix: Client*\n\n        *Code:\nGlacierExpeditedRetrievalNotAvailable*\n\n     *Cause: expedited retrievals are currently not\navailable. Try again later. (Returned if there is insufficient capacity to\nprocess the Expedited request. This error applies only to Expedited retrievals\nand not to S3 Standard or Bulk retrievals.)*\n\n     *HTTP Status Code: 503*\n\n     *SOAP Fault Code Prefix: N/A*\n\nThe following operations are related to `RestoreObject`:\n\n  *\n[PutBucketLifecycleConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketLifecycleConfiguration.html)     *\n[GetBucketNotificationConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketNotificationConfiguration.html)","ref":"AWS.S3.html#restore_object/5-responses","title":"Responses - AWS.S3.restore_object/5","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nThis action filters the contents of an Amazon S3 object based on a simple\nstructured query language (SQL) statement. In the request, along with the SQL\nexpression, you must also specify a data serialization format (JSON, CSV, or\nApache Parquet) of the object. Amazon S3 uses this format to parse object data\ninto records, and returns only records that match the specified SQL expression.\nYou must also specify the data serialization format for the response.\n\nThis functionality is not supported for Amazon S3 on Outposts.\n\nFor more information about Amazon S3 Select, see [Selecting Content from Objects](https://docs.aws.amazon.com/AmazonS3/latest/dev/selecting-content-from-objects.html)\nand [SELECT Command](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-glacier-select-sql-reference-select.html)\nin the *Amazon S3 User Guide*.","ref":"AWS.S3.html#select_object_content/5","title":"AWS.S3.select_object_content/5","type":"function"},{"doc":"#","ref":"AWS.S3.html#select_object_content/5-definitions","title":"Definitions - AWS.S3.select_object_content/5","type":"function"},{"doc":"You must have the `s3:GetObject` permission for this operation. Amazon S3 Select\ndoes not support anonymous access. For more information about permissions, see\n[Specifying Permissions in a Policy](https://docs.aws.amazon.com/AmazonS3/latest/dev/using-with-s3-actions.html)\nin the *Amazon S3 User Guide*.\n\n#","ref":"AWS.S3.html#select_object_content/5-permissions","title":"Permissions - AWS.S3.select_object_content/5","type":"function"},{"doc":"You can use Amazon S3 Select to query objects that have the following format\nproperties:\n\n   *CSV, JSON, and Parquet* - Objects must be in CSV, JSON, or Parquet\nformat.\n\n   *UTF-8* - UTF-8 is the only encoding type Amazon S3 Select\nsupports.\n\n   *GZIP or BZIP2* - CSV and JSON files can be compressed using GZIP\nor BZIP2. GZIP and BZIP2 are the only compression formats that Amazon S3 Select\nsupports for CSV and JSON files. Amazon S3 Select supports columnar compression\nfor Parquet using GZIP or Snappy. Amazon S3 Select does not support whole-object\ncompression for Parquet objects.\n\n   *Server-side encryption* - Amazon S3 Select supports querying\nobjects that are protected with server-side encryption.\n\nFor objects that are encrypted with customer-provided encryption keys (SSE-C),\nyou must use HTTPS, and you must use the headers that are documented in the\n[GetObject](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObject.html). For more information about SSE-C, see [Server-Side Encryption (Using\nCustomer-Provided Encryption\nKeys)](https://docs.aws.amazon.com/AmazonS3/latest/dev/ServerSideEncryptionCustomerKeys.html)\nin the *Amazon S3 User Guide*.\n\nFor objects that are encrypted with Amazon S3 managed keys (SSE-S3) and Amazon\nWeb Services KMS keys (SSE-KMS), server-side encryption is handled\ntransparently, so you don't need to specify anything. For more information about\nserver-side encryption, including SSE-S3 and SSE-KMS, see [Protecting Data Using Server-Side\nEncryption](https://docs.aws.amazon.com/AmazonS3/latest/dev/serv-side-encryption.html)\nin the *Amazon S3 User Guide*.\n\n#","ref":"AWS.S3.html#select_object_content/5-object-data-formats","title":"Object Data Formats - AWS.S3.select_object_content/5","type":"function"},{"doc":"Given the response size is unknown, Amazon S3 Select streams the response as a\nseries of messages and includes a `Transfer-Encoding` header with `chunked` as\nits value in the response. For more information, see [Appendix: SelectObjectContent\nResponse](https://docs.aws.amazon.com/AmazonS3/latest/API/RESTSelectObjectAppendix.html).\n\n#","ref":"AWS.S3.html#select_object_content/5-working-with-the-response-body","title":"Working with the Response Body - AWS.S3.select_object_content/5","type":"function"},{"doc":"The `SelectObjectContent` action does not support the following `GetObject`\nfunctionality. For more information, see\n[GetObject](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObject.html).     `Range`: Although you can specify a scan range for an Amazon S3\nSelect request (see [SelectObjectContentRequest -\nScanRange](https://docs.aws.amazon.com/AmazonS3/latest/API/API_SelectObjectContent.html#AmazonS3-SelectObjectContent-request-ScanRange)\nin the request parameters), you cannot specify the range of bytes of an object\nto return.\n\n   The `GLACIER`, `DEEP_ARCHIVE`, and `REDUCED_REDUNDANCY` storage\nclasses, or the `ARCHIVE_ACCESS` and `DEEP_ARCHIVE_ACCESS` access tiers of the\n`INTELLIGENT_TIERING` storage class: You cannot query objects in the `GLACIER`,\n`DEEP_ARCHIVE`, or `REDUCED_REDUNDANCY` storage classes, nor objects in the\n`ARCHIVE_ACCESS` or `DEEP_ARCHIVE_ACCESS` access tiers of the\n`INTELLIGENT_TIERING` storage class. For more information about storage classes,\nsee [Using Amazon S3 storage classes](https://docs.aws.amazon.com/AmazonS3/latest/userguide/storage-class-intro.html)\nin the *Amazon S3 User Guide*.\n\n#","ref":"AWS.S3.html#select_object_content/5-getobject-support","title":"GetObject Support - AWS.S3.select_object_content/5","type":"function"},{"doc":"For a list of special errors for this operation, see [List of SELECT Object Content Error\nCodes](https://docs.aws.amazon.com/AmazonS3/latest/API/ErrorResponses.html#SelectObjectContentErrorCodeList)\n\nThe following operations are related to `SelectObjectContent`:\n\n  *\n[GetObject](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObject.html)     *\n[GetBucketLifecycleConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketLifecycleConfiguration.html)\n\n  *\n[PutBucketLifecycleConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketLifecycleConfiguration.html)","ref":"AWS.S3.html#select_object_content/5-special-errors","title":"Special Errors - AWS.S3.select_object_content/5","type":"function"},{"doc":"Uploads a part in a multipart upload.\n\nIn this operation, you provide new data as a part of an object in your request.\nHowever, you have an option to specify your existing Amazon S3 object as a data\nsource for the part you are uploading. To upload a part from an existing object,\nyou use the\n[UploadPartCopy](https://docs.aws.amazon.com/AmazonS3/latest/API/API_UploadPartCopy.html) operation.\n\nYou must initiate a multipart upload (see\n[CreateMultipartUpload](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateMultipartUpload.html))\nbefore you can upload any part. In response to your initiate request, Amazon S3\nreturns an upload ID, a unique identifier that you must include in your upload\npart request.\n\nPart numbers can be any number from 1 to 10,000, inclusive. A part number\nuniquely identifies a part and also defines its position within the object being\ncreated. If you upload a new part using the same part number that was used with\na previous part, the previously uploaded part is overwritten.\n\nFor information about maximum and minimum part sizes and other multipart upload\nspecifications, see [Multipart upload limits](https://docs.aws.amazon.com/AmazonS3/latest/userguide/qfacts.html) in\nthe *Amazon S3 User Guide*.\n\nAfter you initiate multipart upload and upload one or more parts, you must\neither complete or abort multipart upload in order to stop getting charged for\nstorage of the uploaded parts. Only after you either complete or abort multipart\nupload, Amazon S3 frees up the parts storage and stops charging you for the\nparts storage.\n\nFor more information on multipart uploads, go to [Multipart Upload Overview](https://docs.aws.amazon.com/AmazonS3/latest/dev/mpuoverview.html) in\nthe *Amazon S3 User Guide *.\n\n**Directory buckets** - For directory buckets, you must make requests for this\nAPI operation to the Zonal endpoint. These endpoints support\nvirtual-hosted-style requests in the format\n`https://*bucket_name*.s3express-*az_id*.*region*.amazonaws.com/*key-name* `.\nPath-style requests are not supported. For more information, see [Regional and Zonal\nendpoints](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-express-Regions-and-Zones.html)\nin the *Amazon S3 User Guide*.","ref":"AWS.S3.html#upload_part/5","title":"AWS.S3.upload_part/5","type":"function"},{"doc":"#","ref":"AWS.S3.html#upload_part/5-definitions","title":"Definitions - AWS.S3.upload_part/5","type":"function"},{"doc":"**General purpose bucket permissions** - For information on the\npermissions required to use the multipart upload API, see [Multipart Upload and Permissions](https://docs.aws.amazon.com/AmazonS3/latest/dev/mpuAndPermissions.html)\nin the *Amazon S3 User Guide*.\n\n   **Directory bucket permissions** - To grant access to this API\noperation on a directory bucket, we recommend that you use the [ `CreateSession`\n](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateSession.html) API\noperation for session-based authorization. Specifically, you grant the\n`s3express:CreateSession` permission to the directory bucket in a bucket policy\nor an IAM identity-based policy. Then, you make the `CreateSession` API call on\nthe bucket to obtain a session token. With the session token in your request\nheader, you can make API requests to this operation. After the session token\nexpires, you make another `CreateSession` API call to generate a new session\ntoken for use. Amazon Web Services CLI or SDKs create session and refresh the\nsession token automatically to avoid service interruptions when a session\nexpires. For more information about authorization, see [ `CreateSession`\n](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateSession.html).\n\n#","ref":"AWS.S3.html#upload_part/5-permissions","title":"Permissions - AWS.S3.upload_part/5","type":"function"},{"doc":"**General purpose bucket** - To ensure that data is not corrupted traversing the\nnetwork, specify the `Content-MD5` header in the upload part request. Amazon S3\nchecks the part data against the provided MD5 value. If they do not match,\nAmazon S3 returns an error. If the upload request is signed with Signature\nVersion 4, then Amazon Web Services S3 uses the `x-amz-content-sha256` header as\na checksum instead of `Content-MD5`. For more information see [Authenticating Requests: Using the Authorization Header (Amazon Web Services Signature Version\n4)](https://docs.aws.amazon.com/AmazonS3/latest/API/sigv4-auth-using-authorization-header.html).\n\n**Directory buckets** - MD5 is not supported by directory buckets. You can use\nchecksum algorithms to check object integrity.\n\n#","ref":"AWS.S3.html#upload_part/5-data-integrity","title":"Data integrity - AWS.S3.upload_part/5","type":"function"},{"doc":"**General purpose bucket** - Server-side encryption is for data\nencryption at rest. Amazon S3 encrypts your data as it writes it to disks in its\ndata centers and decrypts it when you access it. You have mutually exclusive\noptions to protect data using server-side encryption in Amazon S3, depending on\nhow you choose to manage the encryption keys. Specifically, the encryption key\noptions are Amazon S3 managed keys (SSE-S3), Amazon Web Services KMS keys\n(SSE-KMS), and Customer-Provided Keys (SSE-C). Amazon S3 encrypts data with\nserver-side encryption using Amazon S3 managed keys (SSE-S3) by default. You can\noptionally tell Amazon S3 to encrypt data at rest using server-side encryption\nwith other key options. The option you use depends on whether you want to use\nKMS keys (SSE-KMS) or provide your own encryption key (SSE-C).\n\nServer-side encryption is supported by the S3 Multipart Upload operations.\nUnless you are using a customer-provided encryption key (SSE-C), you don't need\nto specify the encryption parameters in each UploadPart request. Instead, you\nonly need to specify the server-side encryption parameters in the initial\nInitiate Multipart request. For more information, see\n[CreateMultipartUpload](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateMultipartUpload.html).  If you request server-side encryption using a customer-provided encryption key\n(SSE-C) in your initiate multipart upload request, you must provide identical\nencryption information in each part upload using the following request headers.\n\n     x-amz-server-side-encryption-customer-algorithm\n\n     x-amz-server-side-encryption-customer-key\n\n     x-amz-server-side-encryption-customer-key-MD5\n\n   **Directory bucket** - For directory buckets, only server-side\nencryption with Amazon S3 managed keys (SSE-S3) (`AES256`) is supported.\n\nFor more information, see [Using Server-Side\nEncryption](https://docs.aws.amazon.com/AmazonS3/latest/dev/UsingServerSideEncryption.html)\nin the *Amazon S3 User Guide*.\n\n#","ref":"AWS.S3.html#upload_part/5-encryption","title":"Encryption - AWS.S3.upload_part/5","type":"function"},{"doc":"Error Code: `NoSuchUpload`\n\n     Description: The specified multipart upload does not\nexist. The upload ID might be invalid, or the multipart upload might have been\naborted or completed.\n\n     HTTP Status Code: 404 Not Found\n\n     SOAP Fault Code Prefix: Client\n\n#","ref":"AWS.S3.html#upload_part/5-special-errors","title":"Special errors - AWS.S3.upload_part/5","type":"function"},{"doc":"**Directory buckets ** - The HTTP Host header syntax is `\n*Bucket_name*.s3express-*az_id*.*region*.amazonaws.com`.\n\nThe following operations are related to `UploadPart`:\n\n  *\n[CreateMultipartUpload](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateMultipartUpload.html)     *\n[CompleteMultipartUpload](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CompleteMultipartUpload.html)\n\n  *\n[AbortMultipartUpload](https://docs.aws.amazon.com/AmazonS3/latest/API/API_AbortMultipartUpload.html)     *\n[ListParts](https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListParts.html)\n\n  *\n[ListMultipartUploads](https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListMultipartUploads.html)","ref":"AWS.S3.html#upload_part/5-http-host-header-syntax","title":"HTTP Host header syntax - AWS.S3.upload_part/5","type":"function"},{"doc":"Uploads a part by copying data from an existing object as data source.\n\nTo specify the data source, you add the request header `x-amz-copy-source` in\nyour request. To specify a byte range, you add the request header\n`x-amz-copy-source-range` in your request.\n\nFor information about maximum and minimum part sizes and other multipart upload\nspecifications, see [Multipart upload limits](https://docs.aws.amazon.com/AmazonS3/latest/userguide/qfacts.html) in\nthe *Amazon S3 User Guide*.\n\nInstead of copying data from an existing object as part data, you might use the\n[UploadPart](https://docs.aws.amazon.com/AmazonS3/latest/API/API_UploadPart.html) action to upload new data as a part of an object in your request.\n\nYou must initiate a multipart upload before you can upload any part. In response\nto your initiate request, Amazon S3 returns the upload ID, a unique identifier\nthat you must include in your upload part request.\n\nFor conceptual information about multipart uploads, see [Uploading Objects Using\nMultipart\nUpload](https://docs.aws.amazon.com/AmazonS3/latest/dev/uploadobjusingmpu.html)\nin the *Amazon S3 User Guide*. For information about copying objects using a\nsingle atomic action vs. a multipart upload, see [Operations on Objects](https://docs.aws.amazon.com/AmazonS3/latest/dev/ObjectOperations.html)\nin the *Amazon S3 User Guide*.\n\n**Directory buckets** - For directory buckets, you must make requests for this\nAPI operation to the Zonal endpoint. These endpoints support\nvirtual-hosted-style requests in the format\n`https://*bucket_name*.s3express-*az_id*.*region*.amazonaws.com/*key-name* `.\nPath-style requests are not supported. For more information, see [Regional and Zonal\nendpoints](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-express-Regions-and-Zones.html)\nin the *Amazon S3 User Guide*.","ref":"AWS.S3.html#upload_part_copy/5","title":"AWS.S3.upload_part_copy/5","type":"function"},{"doc":"#","ref":"AWS.S3.html#upload_part_copy/5-definitions","title":"Definitions - AWS.S3.upload_part_copy/5","type":"function"},{"doc":"All `UploadPartCopy` requests must be authenticated and signed by using IAM\ncredentials (access key ID and secret access key for the IAM identities). All\nheaders with the `x-amz-` prefix, including `x-amz-copy-source`, must be signed.\nFor more information, see [REST Authentication](https://docs.aws.amazon.com/AmazonS3/latest/dev/RESTAuthentication.html).\n\n**Directory buckets** - You must use IAM credentials to authenticate and\nauthorize your access to the `UploadPartCopy` API operation, instead of using\nthe temporary security credentials through the `CreateSession` API operation.\n\nAmazon Web Services CLI or SDKs handles authentication and authorization on your\nbehalf.\n\n#","ref":"AWS.S3.html#upload_part_copy/5-authentication-and-authorization","title":"Authentication and authorization - AWS.S3.upload_part_copy/5","type":"function"},{"doc":"You must have `READ` access to the source object and `WRITE` access to the\ndestination bucket.\n\n   **General purpose bucket permissions** - You must have the\npermissions in a policy based on the bucket types of your source bucket and\ndestination bucket in an `UploadPartCopy` operation.\n\n     If the source object is in a general purpose bucket,\nyou must have the ** `s3:GetObject` ** permission to read the source object that\nis being copied.\n\n     If the destination bucket is a general purpose bucket,\nyou must have the ** `s3:PubObject` ** permission to write the object copy to\nthe destination bucket.\n\nFor information about permissions required to use the multipart upload API, see\n[Multipart Upload and Permissions](https://docs.aws.amazon.com/AmazonS3/latest/dev/mpuAndPermissions.html)\nin the *Amazon S3 User Guide*.\n\n   **Directory bucket permissions** - You must have permissions in a\nbucket policy or an IAM identity-based policy based on the source and\ndestination bucket types in an `UploadPartCopy` operation.\n\n     If the source object that you want to copy is in a\ndirectory bucket, you must have the ** `s3express:CreateSession` ** permission\nin the `Action` element of a policy to read the object . By default, the session\nis in the `ReadWrite` mode. If you want to restrict the access, you can\nexplicitly set the `s3express:SessionMode` condition key to `ReadOnly` on the\ncopy source bucket.\n\n     If the copy destination is a directory bucket, you must\nhave the ** `s3express:CreateSession` ** permission in the `Action` element of a\npolicy to write the object to the destination. The `s3express:SessionMode`\ncondition key cannot be set to `ReadOnly` on the copy destination.\n\nFor example policies, see [Example bucket policies for S3 Express One Zone](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-express-security-iam-example-bucket-policies.html)\nand [Amazon Web Services Identity and Access Management (IAM) identity-based policies for S3 Express One\nZone](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-express-security-iam-identity-policies.html)\nin the *Amazon S3 User Guide*.\n\n#","ref":"AWS.S3.html#upload_part_copy/5-permissions","title":"Permissions - AWS.S3.upload_part_copy/5","type":"function"},{"doc":"**General purpose buckets ** - For information about using\nserver-side encryption with customer-provided encryption keys with the\n`UploadPartCopy` operation, see\n[CopyObject](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CopyObject.html) and\n[UploadPart](https://docs.aws.amazon.com/AmazonS3/latest/API/API_UploadPart.html).\n\n   **Directory buckets ** - For directory buckets, only server-side\nencryption with Amazon S3 managed keys (SSE-S3) (`AES256`) is supported.\n\n#","ref":"AWS.S3.html#upload_part_copy/5-encryption","title":"Encryption - AWS.S3.upload_part_copy/5","type":"function"},{"doc":"Error Code: `NoSuchUpload`\n\n     Description: The specified multipart upload does not\nexist. The upload ID might be invalid, or the multipart upload might have been\naborted or completed.\n\n     HTTP Status Code: 404 Not Found\n\n   Error Code: `InvalidRequest`\n\n     Description: The specified copy source is not supported\nas a byte-range copy source.\n\n     HTTP Status Code: 400 Bad Request\n\n#","ref":"AWS.S3.html#upload_part_copy/5-special-errors","title":"Special errors - AWS.S3.upload_part_copy/5","type":"function"},{"doc":"**Directory buckets ** - The HTTP Host header syntax is `\n*Bucket_name*.s3express-*az_id*.*region*.amazonaws.com`.\n\nThe following operations are related to `UploadPartCopy`:\n\n  *\n[CreateMultipartUpload](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateMultipartUpload.html)     *\n[UploadPart](https://docs.aws.amazon.com/AmazonS3/latest/API/API_UploadPart.html)\n\n  *\n[CompleteMultipartUpload](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CompleteMultipartUpload.html)     *\n[AbortMultipartUpload](https://docs.aws.amazon.com/AmazonS3/latest/API/API_AbortMultipartUpload.html)\n\n  *\n[ListParts](https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListParts.html)     *\n[ListMultipartUploads](https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListMultipartUploads.html)","ref":"AWS.S3.html#upload_part_copy/5-http-host-header-syntax","title":"HTTP Host header syntax - AWS.S3.upload_part_copy/5","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nPasses transformed objects to a `GetObject` operation when using Object Lambda\naccess points. For information about Object Lambda access points, see\n[Transforming objects with Object Lambda access points](https://docs.aws.amazon.com/AmazonS3/latest/userguide/transforming-objects.html)\nin the *Amazon S3 User Guide*.\n\nThis operation supports metadata that can be returned by\n[GetObject](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObject.html), in addition to `RequestRoute`, `RequestToken`, `StatusCode`, `ErrorCode`, and\n`ErrorMessage`. The `GetObject` response metadata is supported so that the\n`WriteGetObjectResponse` caller, typically an Lambda function, can provide the\nsame metadata when it internally invokes `GetObject`. When\n`WriteGetObjectResponse` is called by a customer-owned Lambda function, the\nmetadata returned to the end user `GetObject` call might differ from what Amazon\nS3 would normally return.\n\nYou can include any number of metadata headers. When including a metadata\nheader, it should be prefaced with `x-amz-meta`. For example,\n`x-amz-meta-my-custom-header: MyCustomValue`. The primary use case for this is\nto forward `GetObject` metadata.\n\nAmazon Web Services provides some prebuilt Lambda functions that you can use\nwith S3 Object Lambda to detect and redact personally identifiable information\n(PII) and decompress S3 objects. These Lambda functions are available in the\nAmazon Web Services Serverless Application Repository, and can be selected\nthrough the Amazon Web Services Management Console when you create your Object\nLambda access point.\n\nExample 1: PII Access Control - This Lambda function uses Amazon Comprehend, a\nnatural language processing (NLP) service using machine learning to find\ninsights and relationships in text. It automatically detects personally\nidentifiable information (PII) such as names, addresses, dates, credit card\nnumbers, and social security numbers from documents in your Amazon S3 bucket.\n\nExample 2: PII Redaction - This Lambda function uses Amazon Comprehend, a\nnatural language processing (NLP) service using machine learning to find\ninsights and relationships in text. It automatically redacts personally\nidentifiable information (PII) such as names, addresses, dates, credit card\nnumbers, and social security numbers from documents in your Amazon S3 bucket.\n\nExample 3: Decompression - The Lambda function S3ObjectLambdaDecompression, is\nequipped to decompress objects stored in S3 in one of six compressed file\nformats including bzip2, gzip, snappy, zlib, zstandard and ZIP.\n\nFor information on how to view and use these functions, see [Using Amazon Web\nServices built Lambda\nfunctions](https://docs.aws.amazon.com/AmazonS3/latest/userguide/olap-examples.html)\nin the *Amazon S3 User Guide*.","ref":"AWS.S3.html#write_get_object_response/3","title":"AWS.S3.write_get_object_response/3","type":"function"},{"doc":"Amazon Web Services S3 Control provides access to Amazon S3 control plane\nactions.","ref":"AWS.S3Control.html","title":"AWS.S3Control","type":"module"},{"doc":"Associate your S3 Access Grants instance with an Amazon Web Services IAM\nIdentity Center instance.\n\nUse this action if you want to create access grants for users or groups from\nyour corporate identity directory. First, you must add your corporate identity\ndirectory to Amazon Web Services IAM Identity Center. Then, you can associate\nthis IAM Identity Center instance with your S3 Access Grants instance.","ref":"AWS.S3Control.html#associate_access_grants_identity_center/3","title":"AWS.S3Control.associate_access_grants_identity_center/3","type":"function"},{"doc":"#","ref":"AWS.S3Control.html#associate_access_grants_identity_center/3-definitions","title":"Definitions - AWS.S3Control.associate_access_grants_identity_center/3","type":"function"},{"doc":"You must have the `s3:AssociateAccessGrantsIdentityCenter` permission to use\nthis operation.\n\n#","ref":"AWS.S3Control.html#associate_access_grants_identity_center/3-permissions","title":"Permissions - AWS.S3Control.associate_access_grants_identity_center/3","type":"function"},{"doc":"You must also have the following permissions: `sso:CreateApplication`,\n`sso:PutApplicationGrant`, and `sso:PutApplicationAuthenticationMethod`.","ref":"AWS.S3Control.html#associate_access_grants_identity_center/3-additional-permissions","title":"Additional Permissions - AWS.S3Control.associate_access_grants_identity_center/3","type":"function"},{"doc":"Creates an access grant that gives a grantee access to your S3 data.\n\nThe grantee can be an IAM user or role or a directory user, or group. Before you\ncan create a grant, you must have an S3 Access Grants instance in the same\nRegion as the S3 data. You can create an S3 Access Grants instance using the\n[CreateAccessGrantsInstance](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_CreateAccessGrantsInstance.html). You must also have registered at least one S3 data location in your S3 Access\nGrants instance using\n[CreateAccessGrantsLocation](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_CreateAccessGrantsLocation.html).","ref":"AWS.S3Control.html#create_access_grant/3","title":"AWS.S3Control.create_access_grant/3","type":"function"},{"doc":"#","ref":"AWS.S3Control.html#create_access_grant/3-definitions","title":"Definitions - AWS.S3Control.create_access_grant/3","type":"function"},{"doc":"You must have the `s3:CreateAccessGrant` permission to use this operation.\n\n#","ref":"AWS.S3Control.html#create_access_grant/3-permissions","title":"Permissions - AWS.S3Control.create_access_grant/3","type":"function"},{"doc":"For any directory identity - `sso:DescribeInstance` and\n`sso:DescribeApplication`\n\nFor directory users - `identitystore:DescribeUser`\n\nFor directory groups - `identitystore:DescribeGroup`","ref":"AWS.S3Control.html#create_access_grant/3-additional-permissions","title":"Additional Permissions - AWS.S3Control.create_access_grant/3","type":"function"},{"doc":"Creates an S3 Access Grants instance, which serves as a logical grouping for\naccess grants.\n\nYou can create one S3 Access Grants instance per Region per account.","ref":"AWS.S3Control.html#create_access_grants_instance/3","title":"AWS.S3Control.create_access_grants_instance/3","type":"function"},{"doc":"#","ref":"AWS.S3Control.html#create_access_grants_instance/3-definitions","title":"Definitions - AWS.S3Control.create_access_grants_instance/3","type":"function"},{"doc":"You must have the `s3:CreateAccessGrantsInstance` permission to use this\noperation.\n\n#","ref":"AWS.S3Control.html#create_access_grants_instance/3-permissions","title":"Permissions - AWS.S3Control.create_access_grants_instance/3","type":"function"},{"doc":"To associate an IAM Identity Center instance with your S3 Access Grants\ninstance, you must also have the `sso:DescribeInstance`,\n`sso:CreateApplication`, `sso:PutApplicationGrant`, and\n`sso:PutApplicationAuthenticationMethod` permissions.","ref":"AWS.S3Control.html#create_access_grants_instance/3-additional-permissions","title":"Additional Permissions - AWS.S3Control.create_access_grants_instance/3","type":"function"},{"doc":"The S3 data location that you would like to register in your S3 Access Grants\ninstance.\n\nYour S3 data must be in the same Region as your S3 Access Grants instance. The\nlocation can be one of the following:\n\n  * The default S3 location `s3://`\n\n  * A bucket - `S3:// `\n\n  * A bucket and prefix - `S3:// / `\n\nWhen you register a location, you must include the IAM role that has permission\nto manage the S3 location that you are registering. Give S3 Access Grants\npermission to assume this role [using a policy](https://docs.aws.amazon.com/AmazonS3/latest/userguide/access-grants-location.html).\nS3 Access Grants assumes this role to manage access to the location and to vend\ntemporary credentials to grantees or client applications.","ref":"AWS.S3Control.html#create_access_grants_location/3","title":"AWS.S3Control.create_access_grants_location/3","type":"function"},{"doc":"#","ref":"AWS.S3Control.html#create_access_grants_location/3-definitions","title":"Definitions - AWS.S3Control.create_access_grants_location/3","type":"function"},{"doc":"You must have the `s3:CreateAccessGrantsLocation` permission to use this\noperation.\n\n#","ref":"AWS.S3Control.html#create_access_grants_location/3-permissions","title":"Permissions - AWS.S3Control.create_access_grants_location/3","type":"function"},{"doc":"You must also have the following permission for the specified IAM role:\n`iam:PassRole`","ref":"AWS.S3Control.html#create_access_grants_location/3-additional-permissions","title":"Additional Permissions - AWS.S3Control.create_access_grants_location/3","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nCreates an access point and associates it with the specified bucket. For more\ninformation, see [Managing Data Access with Amazon S3 Access Points](https://docs.aws.amazon.com/AmazonS3/latest/userguide/access-points.html)\nin the *Amazon S3 User Guide*.\n\nS3 on Outposts only supports VPC-style access points.\n\nFor more information, see [ Accessing Amazon S3 on Outposts using virtual private cloud (VPC) only access\npoints](https://docs.aws.amazon.com/AmazonS3/latest/userguide/S3onOutposts.html)\nin the *Amazon S3 User Guide*.\n\nAll Amazon S3 on Outposts REST API requests for this action require an\nadditional parameter of `x-amz-outpost-id` to be passed with the request. In\naddition, you must use an S3 on Outposts endpoint hostname prefix instead of\n`s3-control`. For an example of the request syntax for Amazon S3 on Outposts\nthat uses the S3 on Outposts endpoint hostname prefix and the `x-amz-outpost-id`\nderived by using the access point ARN, see the\n[Examples](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_CreateAccessPoint.html#API_control_CreateAccessPoint_Examples) section.\n\nThe following actions are related to `CreateAccessPoint`:\n\n  *\n[GetAccessPoint](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetAccessPoint.html)\n\n  *\n[DeleteAccessPoint](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteAccessPoint.html)     *\n[ListAccessPoints](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_ListAccessPoints.html)","ref":"AWS.S3Control.html#create_access_point/4","title":"AWS.S3Control.create_access_point/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nCreates an Object Lambda Access Point. For more information, see [Transforming objects with Object Lambda Access\nPoints](https://docs.aws.amazon.com/AmazonS3/latest/userguide/transforming-objects.html)\nin the *Amazon S3 User Guide*.\n\nThe following actions are related to `CreateAccessPointForObjectLambda`:\n\n  *\n[DeleteAccessPointForObjectLambda](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteAccessPointForObjectLambda.html)     *\n[GetAccessPointForObjectLambda](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetAccessPointForObjectLambda.html)\n\n  *\n[ListAccessPointsForObjectLambda](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_ListAccessPointsForObjectLambda.html)","ref":"AWS.S3Control.html#create_access_point_for_object_lambda/4","title":"AWS.S3Control.create_access_point_for_object_lambda/4","type":"function"},{"doc":"This action creates an Amazon S3 on Outposts bucket.\n\nTo create an S3 bucket, see [Create Bucket](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateBucket.html)\nin the *Amazon S3 API Reference*.\n\nCreates a new Outposts bucket. By creating the bucket, you become the bucket\nowner. To create an Outposts bucket, you must have S3 on Outposts. For more\ninformation, see [Using Amazon S3 on Outposts](https://docs.aws.amazon.com/AmazonS3/latest/userguide/S3onOutposts.html)\nin *Amazon S3 User Guide*.\n\nNot every string is an acceptable bucket name. For information on bucket naming\nrestrictions, see [Working with Amazon S3 Buckets](https://docs.aws.amazon.com/AmazonS3/latest/userguide/BucketRestrictions.html#bucketnamingrules).\n\nS3 on Outposts buckets support:\n\n  * Tags\n\n  * LifecycleConfigurations for deleting expired objects\n\nFor a complete list of restrictions and Amazon S3 feature limitations on S3 on\nOutposts, see [ Amazon S3 on Outposts Restrictions and Limitations](https://docs.aws.amazon.com/AmazonS3/latest/userguide/S3OnOutpostsRestrictionsLimitations.html).\n\nFor an example of the request syntax for Amazon S3 on Outposts that uses the S3\non Outposts endpoint hostname prefix and `x-amz-outpost-id` in your API request,\nsee the\n[Examples](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_CreateBucket.html#API_control_CreateBucket_Examples) section.\n\nThe following actions are related to `CreateBucket` for Amazon S3 on Outposts:\n\n  *\n[PutObject](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObject.html)\n\n  *\n[GetBucket](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetBucket.html)     *\n[DeleteBucket](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteBucket.html)\n\n  *\n[CreateAccessPoint](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_CreateAccessPoint.html)     *\n[PutAccessPointPolicy](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_PutAccessPointPolicy.html)","ref":"AWS.S3Control.html#create_bucket/4","title":"AWS.S3Control.create_bucket/4","type":"function"},{"doc":"This operation creates an S3 Batch Operations job.\n\nYou can use S3 Batch Operations to perform large-scale batch actions on Amazon\nS3 objects. Batch Operations can run a single action on lists of Amazon S3\nobjects that you specify. For more information, see [S3 Batch Operations](https://docs.aws.amazon.com/AmazonS3/latest/userguide/batch-ops.html)\nin the *Amazon S3 User Guide*.","ref":"AWS.S3Control.html#create_job/3","title":"AWS.S3Control.create_job/3","type":"function"},{"doc":"#","ref":"AWS.S3Control.html#create_job/3-definitions","title":"Definitions - AWS.S3Control.create_job/3","type":"function"},{"doc":"For information about permissions required to use the Batch Operations, see\n[Granting permissions for S3 Batch Operations](https://docs.aws.amazon.com/AmazonS3/latest/dev/mpuAndPermissions.html)\nin the *Amazon S3 User Guide*.\n\nRelated actions include:\n\n  *\n[DescribeJob](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DescribeJob.html)     *\n[ListJobs](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_ListJobs.html)\n\n  *\n[UpdateJobPriority](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_UpdateJobPriority.html)     *\n[UpdateJobStatus](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_UpdateJobStatus.html)\n\n  *\n[JobOperation](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_JobOperation.html)","ref":"AWS.S3Control.html#create_job/3-permissions","title":"Permissions - AWS.S3Control.create_job/3","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nCreates a Multi-Region Access Point and associates it with the specified\nbuckets. For more information about creating Multi-Region Access Points, see\n[Creating Multi-Region Access Points](https://docs.aws.amazon.com/AmazonS3/latest/userguide/CreatingMultiRegionAccessPoints.html)\nin the *Amazon S3 User Guide*.\n\nThis action will always be routed to the US West (Oregon) Region. For more\ninformation about the restrictions around managing Multi-Region Access Points,\nsee [Managing Multi-Region Access Points](https://docs.aws.amazon.com/AmazonS3/latest/userguide/ManagingMultiRegionAccessPoints.html)\nin the *Amazon S3 User Guide*.\n\nThis request is asynchronous, meaning that you might receive a response before\nthe command has completed. When this request provides a response, it provides a\ntoken that you can use to monitor the status of the request with\n`DescribeMultiRegionAccessPointOperation`.\n\nThe following actions are related to `CreateMultiRegionAccessPoint`:\n\n  *\n[DeleteMultiRegionAccessPoint](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteMultiRegionAccessPoint.html)     *\n[DescribeMultiRegionAccessPointOperation](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DescribeMultiRegionAccessPointOperation.html)\n\n  *\n[GetMultiRegionAccessPoint](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetMultiRegionAccessPoint.html)     *\n[ListMultiRegionAccessPoints](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_ListMultiRegionAccessPoints.html)","ref":"AWS.S3Control.html#create_multi_region_access_point/3","title":"AWS.S3Control.create_multi_region_access_point/3","type":"function"},{"doc":"Creates a new S3 Storage Lens group and associates it with the specified Amazon\nWeb Services account ID.\n\nAn S3 Storage Lens group is a custom grouping of objects based on prefix,\nsuffix, object tags, object size, object age, or a combination of these filters.\nFor each Storage Lens group that you’ve created, you can also optionally add\nAmazon Web Services resource tags. For more information about S3 Storage Lens\ngroups, see [Working with S3 Storage Lens groups](https://docs.aws.amazon.com/AmazonS3/latest/userguide/storage-lens-groups-overview.html).\n\nTo use this operation, you must have the permission to perform the\n`s3:CreateStorageLensGroup` action. If you’re trying to create a Storage Lens\ngroup with Amazon Web Services resource tags, you must also have permission to\nperform the `s3:TagResource` action. For more information about the required\nStorage Lens Groups permissions, see [Setting account permissions to use S3 Storage Lens\ngroups](https://docs.aws.amazon.com/AmazonS3/latest/userguide/storage_lens_iam_permissions.html#storage_lens_groups_permissions).\n\nFor information about Storage Lens groups errors, see [List of Amazon S3 Storage Lens error\ncodes](https://docs.aws.amazon.com/AmazonS3/latest/API/ErrorResponses.html#S3LensErrorCodeList).","ref":"AWS.S3Control.html#create_storage_lens_group/3","title":"AWS.S3Control.create_storage_lens_group/3","type":"function"},{"doc":"Deletes the access grant from the S3 Access Grants instance.\n\nYou cannot undo an access grant deletion and the grantee will no longer have\naccess to the S3 data.","ref":"AWS.S3Control.html#delete_access_grant/4","title":"AWS.S3Control.delete_access_grant/4","type":"function"},{"doc":"#","ref":"AWS.S3Control.html#delete_access_grant/4-definitions","title":"Definitions - AWS.S3Control.delete_access_grant/4","type":"function"},{"doc":"You must have the `s3:DeleteAccessGrant` permission to use this operation.","ref":"AWS.S3Control.html#delete_access_grant/4-permissions","title":"Permissions - AWS.S3Control.delete_access_grant/4","type":"function"},{"doc":"Deletes your S3 Access Grants instance.\n\nYou must first delete the access grants and locations before S3 Access Grants\ncan delete the instance. See\n[DeleteAccessGrant](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteAccessGrant.html) and\n[DeleteAccessGrantsLocation](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteAccessGrantsLocation.html).\nIf you have associated an IAM Identity Center instance with your S3 Access\nGrants instance, you must first dissassociate the Identity Center instance from\nthe S3 Access Grants instance before you can delete the S3 Access Grants\ninstance. See\n[AssociateAccessGrantsIdentityCenter](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_AssociateAccessGrantsIdentityCenter.html) and\n[DissociateAccessGrantsIdentityCenter](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DissociateAccessGrantsIdentityCenter.html).","ref":"AWS.S3Control.html#delete_access_grants_instance/3","title":"AWS.S3Control.delete_access_grants_instance/3","type":"function"},{"doc":"#","ref":"AWS.S3Control.html#delete_access_grants_instance/3-definitions","title":"Definitions - AWS.S3Control.delete_access_grants_instance/3","type":"function"},{"doc":"You must have the `s3:DeleteAccessGrantsInstance` permission to use this\noperation.","ref":"AWS.S3Control.html#delete_access_grants_instance/3-permissions","title":"Permissions - AWS.S3Control.delete_access_grants_instance/3","type":"function"},{"doc":"Deletes the resource policy of the S3 Access Grants instance.\n\nThe resource policy is used to manage cross-account access to your S3 Access\nGrants instance. By deleting the resource policy, you delete any cross-account\npermissions to your S3 Access Grants instance.","ref":"AWS.S3Control.html#delete_access_grants_instance_resource_policy/3","title":"AWS.S3Control.delete_access_grants_instance_resource_policy/3","type":"function"},{"doc":"#","ref":"AWS.S3Control.html#delete_access_grants_instance_resource_policy/3-definitions","title":"Definitions - AWS.S3Control.delete_access_grants_instance_resource_policy/3","type":"function"},{"doc":"You must have the `s3:DeleteAccessGrantsInstanceResourcePolicy` permission to\nuse this operation.","ref":"AWS.S3Control.html#delete_access_grants_instance_resource_policy/3-permissions","title":"Permissions - AWS.S3Control.delete_access_grants_instance_resource_policy/3","type":"function"},{"doc":"Deregisters a location from your S3 Access Grants instance.\n\nYou can only delete a location registration from an S3 Access Grants instance if\nthere are no grants associated with this location. See [Delete a grant](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteAccessGrant.html)\nfor information on how to delete grants. You need to have at least one\nregistered location in your S3 Access Grants instance in order to create access\ngrants.","ref":"AWS.S3Control.html#delete_access_grants_location/4","title":"AWS.S3Control.delete_access_grants_location/4","type":"function"},{"doc":"#","ref":"AWS.S3Control.html#delete_access_grants_location/4-definitions","title":"Definitions - AWS.S3Control.delete_access_grants_location/4","type":"function"},{"doc":"You must have the `s3:DeleteAccessGrantsLocation` permission to use this\noperation.","ref":"AWS.S3Control.html#delete_access_grants_location/4-permissions","title":"Permissions - AWS.S3Control.delete_access_grants_location/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nDeletes the specified access point.\n\nAll Amazon S3 on Outposts REST API requests for this action require an\nadditional parameter of `x-amz-outpost-id` to be passed with the request. In\naddition, you must use an S3 on Outposts endpoint hostname prefix instead of\n`s3-control`. For an example of the request syntax for Amazon S3 on Outposts\nthat uses the S3 on Outposts endpoint hostname prefix and the `x-amz-outpost-id`\nderived by using the access point ARN, see the\n[Examples](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteAccessPoint.html#API_control_DeleteAccessPoint_Examples) section.\n\nThe following actions are related to `DeleteAccessPoint`:\n\n  *\n[CreateAccessPoint](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_CreateAccessPoint.html)\n\n  *\n[GetAccessPoint](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetAccessPoint.html)     *\n[ListAccessPoints](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_ListAccessPoints.html)","ref":"AWS.S3Control.html#delete_access_point/4","title":"AWS.S3Control.delete_access_point/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nDeletes the specified Object Lambda Access Point.\n\nThe following actions are related to `DeleteAccessPointForObjectLambda`:\n\n  *\n[CreateAccessPointForObjectLambda](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_CreateAccessPointForObjectLambda.html)     *\n[GetAccessPointForObjectLambda](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetAccessPointForObjectLambda.html)\n\n  *\n[ListAccessPointsForObjectLambda](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_ListAccessPointsForObjectLambda.html)","ref":"AWS.S3Control.html#delete_access_point_for_object_lambda/4","title":"AWS.S3Control.delete_access_point_for_object_lambda/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nDeletes the access point policy for the specified access point.\n\nAll Amazon S3 on Outposts REST API requests for this action require an\nadditional parameter of `x-amz-outpost-id` to be passed with the request. In\naddition, you must use an S3 on Outposts endpoint hostname prefix instead of\n`s3-control`. For an example of the request syntax for Amazon S3 on Outposts\nthat uses the S3 on Outposts endpoint hostname prefix and the `x-amz-outpost-id`\nderived by using the access point ARN, see the\n[Examples](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteAccessPointPolicy.html#API_control_DeleteAccessPointPolicy_Examples) section.\n\nThe following actions are related to `DeleteAccessPointPolicy`:\n\n  *\n[PutAccessPointPolicy](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_PutAccessPointPolicy.html)\n\n  *\n[GetAccessPointPolicy](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetAccessPointPolicy.html)","ref":"AWS.S3Control.html#delete_access_point_policy/4","title":"AWS.S3Control.delete_access_point_policy/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nRemoves the resource policy for an Object Lambda Access Point.\n\nThe following actions are related to `DeleteAccessPointPolicyForObjectLambda`:\n\n  *\n[GetAccessPointPolicyForObjectLambda](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetAccessPointPolicyForObjectLambda.html)     *\n[PutAccessPointPolicyForObjectLambda](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_PutAccessPointPolicyForObjectLambda.html)","ref":"AWS.S3Control.html#delete_access_point_policy_for_object_lambda/4","title":"AWS.S3Control.delete_access_point_policy_for_object_lambda/4","type":"function"},{"doc":"This action deletes an Amazon S3 on Outposts bucket.\n\nTo delete an S3 bucket, see\n[DeleteBucket](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteBucket.html) in the *Amazon S3 API Reference*.\n\nDeletes the Amazon S3 on Outposts bucket. All objects (including all object\nversions and delete markers) in the bucket must be deleted before the bucket\nitself can be deleted. For more information, see [Using Amazon S3 on\nOutposts](https://docs.aws.amazon.com/AmazonS3/latest/userguide/S3onOutposts.html)\nin *Amazon S3 User Guide*.\n\nAll Amazon S3 on Outposts REST API requests for this action require an\nadditional parameter of `x-amz-outpost-id` to be passed with the request. In\naddition, you must use an S3 on Outposts endpoint hostname prefix instead of\n`s3-control`. For an example of the request syntax for Amazon S3 on Outposts\nthat uses the S3 on Outposts endpoint hostname prefix and the `x-amz-outpost-id`\nderived by using the access point ARN, see the\n[Examples](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteBucket.html#API_control_DeleteBucket_Examples) section.","ref":"AWS.S3Control.html#delete_bucket/4","title":"AWS.S3Control.delete_bucket/4","type":"function"},{"doc":"*\n[CreateBucket](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_CreateBucket.html)\n\n  *\n[GetBucket](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetBucket.html)     *\n[DeleteObject](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteObject.html)","ref":"AWS.S3Control.html#delete_bucket/4-related-resources","title":"Related Resources - AWS.S3Control.delete_bucket/4","type":"function"},{"doc":"This action deletes an Amazon S3 on Outposts bucket's lifecycle configuration.\n\nTo delete an S3 bucket's lifecycle configuration, see\n[DeleteBucketLifecycle](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteBucketLifecycle.html) in the *Amazon S3 API Reference*.\n\nDeletes the lifecycle configuration from the specified Outposts bucket. Amazon\nS3 on Outposts removes all the lifecycle configuration rules in the lifecycle\nsubresource associated with the bucket. Your objects never expire, and Amazon S3\non Outposts no longer automatically deletes any objects on the basis of rules\ncontained in the deleted lifecycle configuration. For more information, see\n[Using Amazon S3 on\nOutposts](https://docs.aws.amazon.com/AmazonS3/latest/userguide/S3onOutposts.html)\nin *Amazon S3 User Guide*.\n\nTo use this operation, you must have permission to perform the\n`s3-outposts:PutLifecycleConfiguration` action. By default, the bucket owner has\nthis permission and the Outposts bucket owner can grant this permission to\nothers.\n\nAll Amazon S3 on Outposts REST API requests for this action require an\nadditional parameter of `x-amz-outpost-id` to be passed with the request. In\naddition, you must use an S3 on Outposts endpoint hostname prefix instead of\n`s3-control`. For an example of the request syntax for Amazon S3 on Outposts\nthat uses the S3 on Outposts endpoint hostname prefix and the `x-amz-outpost-id`\nderived by using the access point ARN, see the\n[Examples](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteBucketLifecycleConfiguration.html#API_control_DeleteBucketLifecycleConfiguration_Examples) section.\n\nFor more information about object expiration, see [Elements to Describe\nLifecycle\nActions](https://docs.aws.amazon.com/AmazonS3/latest/dev/intro-lifecycle-rules.html#intro-lifecycle-rules-actions).\n\nRelated actions include:\n\n  *\n[PutBucketLifecycleConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_PutBucketLifecycleConfiguration.html)     *\n[GetBucketLifecycleConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetBucketLifecycleConfiguration.html)","ref":"AWS.S3Control.html#delete_bucket_lifecycle_configuration/4","title":"AWS.S3Control.delete_bucket_lifecycle_configuration/4","type":"function"},{"doc":"This action deletes an Amazon S3 on Outposts bucket policy.\n\nTo delete an S3 bucket policy, see\n[DeleteBucketPolicy](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteBucketPolicy.html) in the *Amazon S3 API Reference*.\n\nThis implementation of the DELETE action uses the policy subresource to delete\nthe policy of a specified Amazon S3 on Outposts bucket. If you are using an\nidentity other than the root user of the Amazon Web Services account that owns\nthe bucket, the calling identity must have the `s3-outposts:DeleteBucketPolicy`\npermissions on the specified Outposts bucket and belong to the bucket owner's\naccount to use this action. For more information, see [Using Amazon S3 on\nOutposts](https://docs.aws.amazon.com/AmazonS3/latest/userguide/S3onOutposts.html)\nin *Amazon S3 User Guide*.\n\nIf you don't have `DeleteBucketPolicy` permissions, Amazon S3 returns a `403\nAccess Denied` error. If you have the correct permissions, but you're not using\nan identity that belongs to the bucket owner's account, Amazon S3 returns a `405\nMethod Not Allowed` error.\n\nAs a security precaution, the root user of the Amazon Web Services account that\nowns a bucket can always use this action, even if the policy explicitly denies\nthe root user the ability to perform this action.\n\nFor more information about bucket policies, see [Using Bucket Policies and User Policies](https://docs.aws.amazon.com/AmazonS3/latest/dev/using-iam-policies.html).\n\nAll Amazon S3 on Outposts REST API requests for this action require an\nadditional parameter of `x-amz-outpost-id` to be passed with the request. In\naddition, you must use an S3 on Outposts endpoint hostname prefix instead of\n`s3-control`. For an example of the request syntax for Amazon S3 on Outposts\nthat uses the S3 on Outposts endpoint hostname prefix and the `x-amz-outpost-id`\nderived by using the access point ARN, see the\n[Examples](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteBucketPolicy.html#API_control_DeleteBucketPolicy_Examples) section.\n\nThe following actions are related to `DeleteBucketPolicy`:\n\n  *\n[GetBucketPolicy](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetBucketPolicy.html)\n\n  *\n[PutBucketPolicy](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_PutBucketPolicy.html)","ref":"AWS.S3Control.html#delete_bucket_policy/4","title":"AWS.S3Control.delete_bucket_policy/4","type":"function"},{"doc":"This operation deletes an Amazon S3 on Outposts bucket's replication\nconfiguration.\n\nTo delete an S3 bucket's replication configuration, see\n[DeleteBucketReplication](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteBucketReplication.html) in the *Amazon S3 API Reference*.\n\nDeletes the replication configuration from the specified S3 on Outposts bucket.\n\nTo use this operation, you must have permissions to perform the\n`s3-outposts:PutReplicationConfiguration` action. The Outposts bucket owner has\nthis permission by default and can grant it to others. For more information\nabout permissions, see [Setting up IAM with S3 on\nOutposts](https://docs.aws.amazon.com/AmazonS3/latest/userguide/S3OutpostsIAM.html)\nand [Managing access to S3 on Outposts buckets](https://docs.aws.amazon.com/AmazonS3/latest/userguide/S3OutpostsBucketPolicy.html)\nin the *Amazon S3 User Guide*.\n\nIt can take a while to propagate `PUT` or `DELETE` requests for a replication\nconfiguration to all S3 on Outposts systems. Therefore, the replication\nconfiguration that's returned by a `GET` request soon after a `PUT` or `DELETE`\nrequest might return a more recent result than what's on the Outpost. If an\nOutpost is offline, the delay in updating the replication configuration on that\nOutpost can be significant.\n\nAll Amazon S3 on Outposts REST API requests for this action require an\nadditional parameter of `x-amz-outpost-id` to be passed with the request. In\naddition, you must use an S3 on Outposts endpoint hostname prefix instead of\n`s3-control`. For an example of the request syntax for Amazon S3 on Outposts\nthat uses the S3 on Outposts endpoint hostname prefix and the `x-amz-outpost-id`\nderived by using the access point ARN, see the\n[Examples](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteBucketReplication.html#API_control_DeleteBucketReplication_Examples) section.\n\nFor information about S3 replication on Outposts configuration, see [Replicating\nobjects for S3 on\nOutposts](https://docs.aws.amazon.com/AmazonS3/latest/userguide/S3OutpostsReplication.html)\nin the *Amazon S3 User Guide*.\n\nThe following operations are related to `DeleteBucketReplication`:\n\n  *\n[PutBucketReplication](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_PutBucketReplication.html)     *\n[GetBucketReplication](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetBucketReplication.html)","ref":"AWS.S3Control.html#delete_bucket_replication/4","title":"AWS.S3Control.delete_bucket_replication/4","type":"function"},{"doc":"This action deletes an Amazon S3 on Outposts bucket's tags.\n\nTo delete an S3 bucket tags, see\n[DeleteBucketTagging](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteBucketTagging.html) in the *Amazon S3 API Reference*.\n\nDeletes the tags from the Outposts bucket. For more information, see [Using\nAmazon S3 on\nOutposts](https://docs.aws.amazon.com/AmazonS3/latest/userguide/S3onOutposts.html)\nin *Amazon S3 User Guide*.\n\nTo use this action, you must have permission to perform the `PutBucketTagging`\naction. By default, the bucket owner has this permission and can grant this\npermission to others.\n\nAll Amazon S3 on Outposts REST API requests for this action require an\nadditional parameter of `x-amz-outpost-id` to be passed with the request. In\naddition, you must use an S3 on Outposts endpoint hostname prefix instead of\n`s3-control`. For an example of the request syntax for Amazon S3 on Outposts\nthat uses the S3 on Outposts endpoint hostname prefix and the `x-amz-outpost-id`\nderived by using the access point ARN, see the\n[Examples](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteBucketTagging.html#API_control_DeleteBucketTagging_Examples) section.\n\nThe following actions are related to `DeleteBucketTagging`:\n\n  *\n[GetBucketTagging](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetBucketTagging.html)\n\n  *\n[PutBucketTagging](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_PutBucketTagging.html)","ref":"AWS.S3Control.html#delete_bucket_tagging/4","title":"AWS.S3Control.delete_bucket_tagging/4","type":"function"},{"doc":"Removes the entire tag set from the specified S3 Batch Operations job.","ref":"AWS.S3Control.html#delete_job_tagging/4","title":"AWS.S3Control.delete_job_tagging/4","type":"function"},{"doc":"#","ref":"AWS.S3Control.html#delete_job_tagging/4-definitions","title":"Definitions - AWS.S3Control.delete_job_tagging/4","type":"function"},{"doc":"To use the `DeleteJobTagging` operation, you must have permission to perform the\n`s3:DeleteJobTagging` action. For more information, see [Controlling access and labeling jobs using\ntags](https://docs.aws.amazon.com/AmazonS3/latest/dev/batch-ops-managing-jobs.html#batch-ops-job-tags)\nin the *Amazon S3 User Guide*.\n\nRelated actions include:\n\n  *\n[CreateJob](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_CreateJob.html)     *\n[GetJobTagging](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetJobTagging.html)\n\n  *\n[PutJobTagging](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_PutJobTagging.html)","ref":"AWS.S3Control.html#delete_job_tagging/4-permissions","title":"Permissions - AWS.S3Control.delete_job_tagging/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nDeletes a Multi-Region Access Point. This action does not delete the buckets\nassociated with the Multi-Region Access Point, only the Multi-Region Access\nPoint itself.\n\nThis action will always be routed to the US West (Oregon) Region. For more\ninformation about the restrictions around managing Multi-Region Access Points,\nsee [Managing Multi-Region Access Points](https://docs.aws.amazon.com/AmazonS3/latest/userguide/ManagingMultiRegionAccessPoints.html)\nin the *Amazon S3 User Guide*.\n\nThis request is asynchronous, meaning that you might receive a response before\nthe command has completed. When this request provides a response, it provides a\ntoken that you can use to monitor the status of the request with\n`DescribeMultiRegionAccessPointOperation`.\n\nThe following actions are related to `DeleteMultiRegionAccessPoint`:\n\n  *\n[CreateMultiRegionAccessPoint](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_CreateMultiRegionAccessPoint.html)     *\n[DescribeMultiRegionAccessPointOperation](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DescribeMultiRegionAccessPointOperation.html)\n\n  *\n[GetMultiRegionAccessPoint](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetMultiRegionAccessPoint.html)     *\n[ListMultiRegionAccessPoints](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_ListMultiRegionAccessPoints.html)","ref":"AWS.S3Control.html#delete_multi_region_access_point/3","title":"AWS.S3Control.delete_multi_region_access_point/3","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nRemoves the `PublicAccessBlock` configuration for an Amazon Web Services\naccount. For more information, see [ Using Amazon S3 block public access](https://docs.aws.amazon.com/AmazonS3/latest/dev/access-control-block-public-access.html).\n\nRelated actions include:\n\n  *\n[GetPublicAccessBlock](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetPublicAccessBlock.html)     *\n[PutPublicAccessBlock](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_PutPublicAccessBlock.html)","ref":"AWS.S3Control.html#delete_public_access_block/3","title":"AWS.S3Control.delete_public_access_block/3","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nDeletes the Amazon S3 Storage Lens configuration. For more information about S3\nStorage Lens, see [Assessing your storage activity and usage with Amazon S3 Storage Lens\n](https://docs.aws.amazon.com/AmazonS3/latest/dev/storage_lens.html) in the\n*Amazon S3 User Guide*.\n\nTo use this action, you must have permission to perform the\n`s3:DeleteStorageLensConfiguration` action. For more information, see [Setting permissions to use Amazon S3 Storage\nLens](https://docs.aws.amazon.com/AmazonS3/latest/dev/storage_lens_iam_permissions.html)\nin the *Amazon S3 User Guide*.","ref":"AWS.S3Control.html#delete_storage_lens_configuration/4","title":"AWS.S3Control.delete_storage_lens_configuration/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nDeletes the Amazon S3 Storage Lens configuration tags. For more information\nabout S3 Storage Lens, see [Assessing your storage activity and usage with Amazon S3 Storage Lens\n](https://docs.aws.amazon.com/AmazonS3/latest/dev/storage_lens.html) in the\n*Amazon S3 User Guide*.\n\nTo use this action, you must have permission to perform the\n`s3:DeleteStorageLensConfigurationTagging` action. For more information, see\n[Setting permissions to use Amazon S3 Storage Lens](https://docs.aws.amazon.com/AmazonS3/latest/dev/storage_lens_iam_permissions.html)\nin the *Amazon S3 User Guide*.","ref":"AWS.S3Control.html#delete_storage_lens_configuration_tagging/4","title":"AWS.S3Control.delete_storage_lens_configuration_tagging/4","type":"function"},{"doc":"Deletes an existing S3 Storage Lens group.\n\nTo use this operation, you must have the permission to perform the\n`s3:DeleteStorageLensGroup` action. For more information about the required\nStorage Lens Groups permissions, see [Setting account permissions to use S3 Storage Lens\ngroups](https://docs.aws.amazon.com/AmazonS3/latest/userguide/storage_lens_iam_permissions.html#storage_lens_groups_permissions).\n\nFor information about Storage Lens groups errors, see [List of Amazon S3 Storage Lens error\ncodes](https://docs.aws.amazon.com/AmazonS3/latest/API/ErrorResponses.html#S3LensErrorCodeList).","ref":"AWS.S3Control.html#delete_storage_lens_group/4","title":"AWS.S3Control.delete_storage_lens_group/4","type":"function"},{"doc":"Retrieves the configuration parameters and status for a Batch Operations job.\n\nFor more information, see [S3 Batch Operations](https://docs.aws.amazon.com/AmazonS3/latest/userguide/batch-ops.html)\nin the *Amazon S3 User Guide*.","ref":"AWS.S3Control.html#describe_job/4","title":"AWS.S3Control.describe_job/4","type":"function"},{"doc":"#","ref":"AWS.S3Control.html#describe_job/4-definitions","title":"Definitions - AWS.S3Control.describe_job/4","type":"function"},{"doc":"To use the `DescribeJob` operation, you must have permission to perform the\n`s3:DescribeJob` action.\n\nRelated actions include:\n\n  *\n[CreateJob](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_CreateJob.html)     *\n[ListJobs](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_ListJobs.html)\n\n  *\n[UpdateJobPriority](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_UpdateJobPriority.html)     *\n[UpdateJobStatus](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_UpdateJobStatus.html)","ref":"AWS.S3Control.html#describe_job/4-permissions","title":"Permissions - AWS.S3Control.describe_job/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nRetrieves the status of an asynchronous request to manage a Multi-Region Access\nPoint. For more information about managing Multi-Region Access Points and how\nasynchronous requests work, see [Managing Multi-Region Access Points](https://docs.aws.amazon.com/AmazonS3/latest/userguide/ManagingMultiRegionAccessPoints.html)\nin the *Amazon S3 User Guide*.\n\nThe following actions are related to `GetMultiRegionAccessPoint`:\n\n  *\n[CreateMultiRegionAccessPoint](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_CreateMultiRegionAccessPoint.html)     *\n[DeleteMultiRegionAccessPoint](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteMultiRegionAccessPoint.html)\n\n  *\n[GetMultiRegionAccessPoint](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetMultiRegionAccessPoint.html)     *\n[ListMultiRegionAccessPoints](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_ListMultiRegionAccessPoints.html)","ref":"AWS.S3Control.html#describe_multi_region_access_point_operation/4","title":"AWS.S3Control.describe_multi_region_access_point_operation/4","type":"function"},{"doc":"Dissociates the Amazon Web Services IAM Identity Center instance from the S3\nAccess Grants instance.","ref":"AWS.S3Control.html#dissociate_access_grants_identity_center/3","title":"AWS.S3Control.dissociate_access_grants_identity_center/3","type":"function"},{"doc":"#","ref":"AWS.S3Control.html#dissociate_access_grants_identity_center/3-definitions","title":"Definitions - AWS.S3Control.dissociate_access_grants_identity_center/3","type":"function"},{"doc":"You must have the `s3:DissociateAccessGrantsIdentityCenter` permission to use\nthis operation.\n\n#","ref":"AWS.S3Control.html#dissociate_access_grants_identity_center/3-permissions","title":"Permissions - AWS.S3Control.dissociate_access_grants_identity_center/3","type":"function"},{"doc":"You must have the `sso:DeleteApplication` permission to use this operation.","ref":"AWS.S3Control.html#dissociate_access_grants_identity_center/3-additional-permissions","title":"Additional Permissions - AWS.S3Control.dissociate_access_grants_identity_center/3","type":"function"},{"doc":"Get the details of an access grant from your S3 Access Grants instance.","ref":"AWS.S3Control.html#get_access_grant/4","title":"AWS.S3Control.get_access_grant/4","type":"function"},{"doc":"#","ref":"AWS.S3Control.html#get_access_grant/4-definitions","title":"Definitions - AWS.S3Control.get_access_grant/4","type":"function"},{"doc":"You must have the `s3:GetAccessGrant` permission to use this operation.","ref":"AWS.S3Control.html#get_access_grant/4-permissions","title":"Permissions - AWS.S3Control.get_access_grant/4","type":"function"},{"doc":"Retrieves the S3 Access Grants instance for a Region in your account.","ref":"AWS.S3Control.html#get_access_grants_instance/3","title":"AWS.S3Control.get_access_grants_instance/3","type":"function"},{"doc":"#","ref":"AWS.S3Control.html#get_access_grants_instance/3-definitions","title":"Definitions - AWS.S3Control.get_access_grants_instance/3","type":"function"},{"doc":"You must have the `s3:GetAccessGrantsInstance` permission to use this operation.","ref":"AWS.S3Control.html#get_access_grants_instance/3-permissions","title":"Permissions - AWS.S3Control.get_access_grants_instance/3","type":"function"},{"doc":"Retrieve the S3 Access Grants instance that contains a particular prefix.","ref":"AWS.S3Control.html#get_access_grants_instance_for_prefix/4","title":"AWS.S3Control.get_access_grants_instance_for_prefix/4","type":"function"},{"doc":"#","ref":"AWS.S3Control.html#get_access_grants_instance_for_prefix/4-definitions","title":"Definitions - AWS.S3Control.get_access_grants_instance_for_prefix/4","type":"function"},{"doc":"You must have the `s3:GetAccessGrantsInstanceForPrefix` permission for the\ncaller account to use this operation.\n\n#","ref":"AWS.S3Control.html#get_access_grants_instance_for_prefix/4-permissions","title":"Permissions - AWS.S3Control.get_access_grants_instance_for_prefix/4","type":"function"},{"doc":"The prefix owner account must grant you the following permissions to their S3\nAccess Grants instance: `s3:GetAccessGrantsInstanceForPrefix`.","ref":"AWS.S3Control.html#get_access_grants_instance_for_prefix/4-additional-permissions","title":"Additional Permissions - AWS.S3Control.get_access_grants_instance_for_prefix/4","type":"function"},{"doc":"Returns the resource policy of the S3 Access Grants instance.","ref":"AWS.S3Control.html#get_access_grants_instance_resource_policy/3","title":"AWS.S3Control.get_access_grants_instance_resource_policy/3","type":"function"},{"doc":"#","ref":"AWS.S3Control.html#get_access_grants_instance_resource_policy/3-definitions","title":"Definitions - AWS.S3Control.get_access_grants_instance_resource_policy/3","type":"function"},{"doc":"You must have the `s3:GetAccessGrantsInstanceResourcePolicy` permission to use\nthis operation.","ref":"AWS.S3Control.html#get_access_grants_instance_resource_policy/3-permissions","title":"Permissions - AWS.S3Control.get_access_grants_instance_resource_policy/3","type":"function"},{"doc":"Retrieves the details of a particular location registered in your S3 Access\nGrants instance.","ref":"AWS.S3Control.html#get_access_grants_location/4","title":"AWS.S3Control.get_access_grants_location/4","type":"function"},{"doc":"#","ref":"AWS.S3Control.html#get_access_grants_location/4-definitions","title":"Definitions - AWS.S3Control.get_access_grants_location/4","type":"function"},{"doc":"You must have the `s3:GetAccessGrantsLocation` permission to use this operation.","ref":"AWS.S3Control.html#get_access_grants_location/4-permissions","title":"Permissions - AWS.S3Control.get_access_grants_location/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nReturns configuration information about the specified access point.\n\nAll Amazon S3 on Outposts REST API requests for this action require an\nadditional parameter of `x-amz-outpost-id` to be passed with the request. In\naddition, you must use an S3 on Outposts endpoint hostname prefix instead of\n`s3-control`. For an example of the request syntax for Amazon S3 on Outposts\nthat uses the S3 on Outposts endpoint hostname prefix and the `x-amz-outpost-id`\nderived by using the access point ARN, see the\n[Examples](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetAccessPoint.html#API_control_GetAccessPoint_Examples) section.\n\nThe following actions are related to `GetAccessPoint`:\n\n  *\n[CreateAccessPoint](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_CreateAccessPoint.html)\n\n  *\n[DeleteAccessPoint](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteAccessPoint.html)     *\n[ListAccessPoints](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_ListAccessPoints.html)","ref":"AWS.S3Control.html#get_access_point/4","title":"AWS.S3Control.get_access_point/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nReturns configuration for an Object Lambda Access Point.\n\nThe following actions are related to\n`GetAccessPointConfigurationForObjectLambda`:\n\n  *\n[PutAccessPointConfigurationForObjectLambda](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_PutAccessPointConfigurationForObjectLambda.html)","ref":"AWS.S3Control.html#get_access_point_configuration_for_object_lambda/4","title":"AWS.S3Control.get_access_point_configuration_for_object_lambda/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nReturns configuration information about the specified Object Lambda Access Point\n\nThe following actions are related to `GetAccessPointForObjectLambda`:\n\n  *\n[CreateAccessPointForObjectLambda](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_CreateAccessPointForObjectLambda.html)     *\n[DeleteAccessPointForObjectLambda](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteAccessPointForObjectLambda.html)\n\n  *\n[ListAccessPointsForObjectLambda](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_ListAccessPointsForObjectLambda.html)","ref":"AWS.S3Control.html#get_access_point_for_object_lambda/4","title":"AWS.S3Control.get_access_point_for_object_lambda/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nReturns the access point policy associated with the specified access point.\n\nThe following actions are related to `GetAccessPointPolicy`:\n\n  *\n[PutAccessPointPolicy](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_PutAccessPointPolicy.html)     *\n[DeleteAccessPointPolicy](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteAccessPointPolicy.html)","ref":"AWS.S3Control.html#get_access_point_policy/4","title":"AWS.S3Control.get_access_point_policy/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nReturns the resource policy for an Object Lambda Access Point.\n\nThe following actions are related to `GetAccessPointPolicyForObjectLambda`:\n\n  *\n[DeleteAccessPointPolicyForObjectLambda](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteAccessPointPolicyForObjectLambda.html)     *\n[PutAccessPointPolicyForObjectLambda](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_PutAccessPointPolicyForObjectLambda.html)","ref":"AWS.S3Control.html#get_access_point_policy_for_object_lambda/4","title":"AWS.S3Control.get_access_point_policy_for_object_lambda/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nIndicates whether the specified access point currently has a policy that allows\npublic access. For more information about public access through access points,\nsee [Managing Data Access with Amazon S3 access points](https://docs.aws.amazon.com/AmazonS3/latest/userguide/access-points.html)\nin the *Amazon S3 User Guide*.","ref":"AWS.S3Control.html#get_access_point_policy_status/4","title":"AWS.S3Control.get_access_point_policy_status/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nReturns the status of the resource policy associated with an Object Lambda\nAccess Point.","ref":"AWS.S3Control.html#get_access_point_policy_status_for_object_lambda/4","title":"AWS.S3Control.get_access_point_policy_status_for_object_lambda/4","type":"function"},{"doc":"Gets an Amazon S3 on Outposts bucket.\n\nFor more information, see [ Using Amazon S3 on Outposts](https://docs.aws.amazon.com/AmazonS3/latest/userguide/S3onOutposts.html)\nin the *Amazon S3 User Guide*.\n\nIf you are using an identity other than the root user of the Amazon Web Services\naccount that owns the Outposts bucket, the calling identity must have the\n`s3-outposts:GetBucket` permissions on the specified Outposts bucket and belong\nto the Outposts bucket owner's account in order to use this action. Only users\nfrom Outposts bucket owner account with the right permissions can perform\nactions on an Outposts bucket.\n\nIf you don't have `s3-outposts:GetBucket` permissions or you're not using an\nidentity that belongs to the bucket owner's account, Amazon S3 returns a `403\nAccess Denied` error.\n\nThe following actions are related to `GetBucket` for Amazon S3 on Outposts:\n\nAll Amazon S3 on Outposts REST API requests for this action require an\nadditional parameter of `x-amz-outpost-id` to be passed with the request. In\naddition, you must use an S3 on Outposts endpoint hostname prefix instead of\n`s3-control`. For an example of the request syntax for Amazon S3 on Outposts\nthat uses the S3 on Outposts endpoint hostname prefix and the `x-amz-outpost-id`\nderived by using the access point ARN, see the\n[Examples](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetBucket.html#API_control_GetBucket_Examples) section.\n\n  *\n[PutObject](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObject.html)\n\n  *\n[CreateBucket](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_CreateBucket.html)     *\n[DeleteBucket](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteBucket.html)","ref":"AWS.S3Control.html#get_bucket/4","title":"AWS.S3Control.get_bucket/4","type":"function"},{"doc":"This action gets an Amazon S3 on Outposts bucket's lifecycle configuration.\n\nTo get an S3 bucket's lifecycle configuration, see\n[GetBucketLifecycleConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketLifecycleConfiguration.html) in the *Amazon S3 API Reference*.\n\nReturns the lifecycle configuration information set on the Outposts bucket. For\nmore information, see [Using Amazon S3 on\nOutposts](https://docs.aws.amazon.com/AmazonS3/latest/userguide/S3onOutposts.html)\nand for information about lifecycle configuration, see [ Object Lifecycle Management](https://docs.aws.amazon.com/AmazonS3/latest/dev/object-lifecycle-mgmt.html)\nin *Amazon S3 User Guide*.\n\nTo use this action, you must have permission to perform the\n`s3-outposts:GetLifecycleConfiguration` action. The Outposts bucket owner has\nthis permission, by default. The bucket owner can grant this permission to\nothers. For more information about permissions, see [Permissions Related to Bucket Subresource\nOperations](https://docs.aws.amazon.com/AmazonS3/latest/userguide/using-with-s3-actions.html#using-with-s3-actions-related-to-bucket-subresources)\nand [Managing Access Permissions to Your Amazon S3 Resources](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-access-control.html).\n\nAll Amazon S3 on Outposts REST API requests for this action require an\nadditional parameter of `x-amz-outpost-id` to be passed with the request. In\naddition, you must use an S3 on Outposts endpoint hostname prefix instead of\n`s3-control`. For an example of the request syntax for Amazon S3 on Outposts\nthat uses the S3 on Outposts endpoint hostname prefix and the `x-amz-outpost-id`\nderived by using the access point ARN, see the\n[Examples](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetBucketLifecycleConfiguration.html#API_control_GetBucketLifecycleConfiguration_Examples) section.\n\n`GetBucketLifecycleConfiguration` has the following special error:\n\n  * Error code: `NoSuchLifecycleConfiguration`\n\n    * Description: The lifecycle configuration does not\nexist.\n\n    * HTTP Status Code: 404 Not Found\n\n    * SOAP Fault Code Prefix: Client\n\nThe following actions are related to `GetBucketLifecycleConfiguration`:\n\n  *\n[PutBucketLifecycleConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_PutBucketLifecycleConfiguration.html)\n\n  *\n[DeleteBucketLifecycleConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteBucketLifecycleConfiguration.html)","ref":"AWS.S3Control.html#get_bucket_lifecycle_configuration/4","title":"AWS.S3Control.get_bucket_lifecycle_configuration/4","type":"function"},{"doc":"This action gets a bucket policy for an Amazon S3 on Outposts bucket.\n\nTo get a policy for an S3 bucket, see\n[GetBucketPolicy](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketPolicy.html) in the *Amazon S3 API Reference*.\n\nReturns the policy of a specified Outposts bucket. For more information, see\n[Using Amazon S3 on\nOutposts](https://docs.aws.amazon.com/AmazonS3/latest/userguide/S3onOutposts.html)\nin the *Amazon S3 User Guide*.\n\nIf you are using an identity other than the root user of the Amazon Web Services\naccount that owns the bucket, the calling identity must have the\n`GetBucketPolicy` permissions on the specified bucket and belong to the bucket\nowner's account in order to use this action.\n\nOnly users from Outposts bucket owner account with the right permissions can\nperform actions on an Outposts bucket. If you don't have\n`s3-outposts:GetBucketPolicy` permissions or you're not using an identity that\nbelongs to the bucket owner's account, Amazon S3 returns a `403 Access Denied`\nerror.\n\nAs a security precaution, the root user of the Amazon Web Services account that\nowns a bucket can always use this action, even if the policy explicitly denies\nthe root user the ability to perform this action.\n\nFor more information about bucket policies, see [Using Bucket Policies and User Policies](https://docs.aws.amazon.com/AmazonS3/latest/dev/using-iam-policies.html).\n\nAll Amazon S3 on Outposts REST API requests for this action require an\nadditional parameter of `x-amz-outpost-id` to be passed with the request. In\naddition, you must use an S3 on Outposts endpoint hostname prefix instead of\n`s3-control`. For an example of the request syntax for Amazon S3 on Outposts\nthat uses the S3 on Outposts endpoint hostname prefix and the `x-amz-outpost-id`\nderived by using the access point ARN, see the\n[Examples](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetBucketPolicy.html#API_control_GetBucketPolicy_Examples) section.\n\nThe following actions are related to `GetBucketPolicy`:\n\n  *\n[GetObject](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObject.html)\n\n  *\n[PutBucketPolicy](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_PutBucketPolicy.html)     *\n[DeleteBucketPolicy](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteBucketPolicy.html)","ref":"AWS.S3Control.html#get_bucket_policy/4","title":"AWS.S3Control.get_bucket_policy/4","type":"function"},{"doc":"This operation gets an Amazon S3 on Outposts bucket's replication configuration.\n\nTo get an S3 bucket's replication configuration, see\n[GetBucketReplication](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketReplication.html) in the *Amazon S3 API Reference*.\n\nReturns the replication configuration of an S3 on Outposts bucket. For more\ninformation about S3 on Outposts, see [Using Amazon S3 on\nOutposts](https://docs.aws.amazon.com/AmazonS3/latest/userguide/S3onOutposts.html)\nin the *Amazon S3 User Guide*. For information about S3 replication on Outposts\nconfiguration, see [Replicating objects for S3 on Outposts](https://docs.aws.amazon.com/AmazonS3/latest/userguide/S3OutpostsReplication.html)\nin the *Amazon S3 User Guide*.\n\nIt can take a while to propagate `PUT` or `DELETE` requests for a replication\nconfiguration to all S3 on Outposts systems. Therefore, the replication\nconfiguration that's returned by a `GET` request soon after a `PUT` or `DELETE`\nrequest might return a more recent result than what's on the Outpost. If an\nOutpost is offline, the delay in updating the replication configuration on that\nOutpost can be significant.\n\nThis action requires permissions for the\n`s3-outposts:GetReplicationConfiguration` action. The Outposts bucket owner has\nthis permission by default and can grant it to others. For more information\nabout permissions, see [Setting up IAM with S3 on Outposts](https://docs.aws.amazon.com/AmazonS3/latest/userguide/S3OutpostsIAM.html)\nand [Managing access to S3 on Outposts bucket](https://docs.aws.amazon.com/AmazonS3/latest/userguide/S3OutpostsBucketPolicy.html)\nin the *Amazon S3 User Guide*.\n\nAll Amazon S3 on Outposts REST API requests for this action require an\nadditional parameter of `x-amz-outpost-id` to be passed with the request. In\naddition, you must use an S3 on Outposts endpoint hostname prefix instead of\n`s3-control`. For an example of the request syntax for Amazon S3 on Outposts\nthat uses the S3 on Outposts endpoint hostname prefix and the `x-amz-outpost-id`\nderived by using the access point ARN, see the\n[Examples](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetBucketReplication.html#API_control_GetBucketReplication_Examples) section.\n\nIf you include the `Filter` element in a replication configuration, you must\nalso include the `DeleteMarkerReplication`, `Status`, and `Priority` elements.\nThe response also returns those elements.\n\nFor information about S3 on Outposts replication failure reasons, see\n[Replication failure\nreasons](https://docs.aws.amazon.com/AmazonS3/latest/userguide/outposts-replication-eventbridge.html#outposts-replication-failure-codes)\nin the *Amazon S3 User Guide*.\n\nThe following operations are related to `GetBucketReplication`:\n\n  *\n[PutBucketReplication](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_PutBucketReplication.html)     *\n[DeleteBucketReplication](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteBucketReplication.html)","ref":"AWS.S3Control.html#get_bucket_replication/4","title":"AWS.S3Control.get_bucket_replication/4","type":"function"},{"doc":"This action gets an Amazon S3 on Outposts bucket's tags.\n\nTo get an S3 bucket tags, see\n[GetBucketTagging](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketTagging.html) in the *Amazon S3 API Reference*.\n\nReturns the tag set associated with the Outposts bucket. For more information,\nsee [Using Amazon S3 on\nOutposts](https://docs.aws.amazon.com/AmazonS3/latest/userguide/S3onOutposts.html)\nin the *Amazon S3 User Guide*.\n\nTo use this action, you must have permission to perform the `GetBucketTagging`\naction. By default, the bucket owner has this permission and can grant this\npermission to others.\n\n`GetBucketTagging` has the following special error:\n\n  * Error code: `NoSuchTagSetError`\n\n    * Description: There is no tag set associated with the\nbucket.\n\nAll Amazon S3 on Outposts REST API requests for this action require an\nadditional parameter of `x-amz-outpost-id` to be passed with the request. In\naddition, you must use an S3 on Outposts endpoint hostname prefix instead of\n`s3-control`. For an example of the request syntax for Amazon S3 on Outposts\nthat uses the S3 on Outposts endpoint hostname prefix and the `x-amz-outpost-id`\nderived by using the access point ARN, see the\n[Examples](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetBucketTagging.html#API_control_GetBucketTagging_Examples) section.\n\nThe following actions are related to `GetBucketTagging`:\n\n  *\n[PutBucketTagging](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_PutBucketTagging.html)\n\n  *\n[DeleteBucketTagging](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteBucketTagging.html)","ref":"AWS.S3Control.html#get_bucket_tagging/4","title":"AWS.S3Control.get_bucket_tagging/4","type":"function"},{"doc":"This operation returns the versioning state for S3 on Outposts buckets only.\n\nTo return the versioning state for an S3 bucket, see\n[GetBucketVersioning](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketVersioning.html) in the *Amazon S3 API Reference*.\n\nReturns the versioning state for an S3 on Outposts bucket. With S3 Versioning,\nyou can save multiple distinct copies of your objects and recover from\nunintended user actions and application failures.\n\nIf you've never set versioning on your bucket, it has no versioning state. In\nthat case, the `GetBucketVersioning` request does not return a versioning state\nvalue.\n\nFor more information about versioning, see\n[Versioning](https://docs.aws.amazon.com/AmazonS3/latest/userguide/Versioning.html)\nin the *Amazon S3 User Guide*.\n\nAll Amazon S3 on Outposts REST API requests for this action require an\nadditional parameter of `x-amz-outpost-id` to be passed with the request. In\naddition, you must use an S3 on Outposts endpoint hostname prefix instead of\n`s3-control`. For an example of the request syntax for Amazon S3 on Outposts\nthat uses the S3 on Outposts endpoint hostname prefix and the `x-amz-outpost-id`\nderived by using the access point ARN, see the\n[Examples](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetBucketVersioning.html#API_control_GetBucketVersioning_Examples) section.\n\nThe following operations are related to `GetBucketVersioning` for S3 on\nOutposts.\n\n  *\n[PutBucketVersioning](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_PutBucketVersioning.html)\n\n  *\n[PutBucketLifecycleConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_PutBucketLifecycleConfiguration.html)     *\n[GetBucketLifecycleConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetBucketLifecycleConfiguration.html)","ref":"AWS.S3Control.html#get_bucket_versioning/4","title":"AWS.S3Control.get_bucket_versioning/4","type":"function"},{"doc":"Returns a temporary access credential from S3 Access Grants to the grantee or\nclient application.\n\nThe [temporary credential](https://docs.aws.amazon.com/STS/latest/APIReference/API_Credentials.html)\nis an Amazon Web Services STS token that grants them access to the S3 data.","ref":"AWS.S3Control.html#get_data_access/8","title":"AWS.S3Control.get_data_access/8","type":"function"},{"doc":"#","ref":"AWS.S3Control.html#get_data_access/8-definitions","title":"Definitions - AWS.S3Control.get_data_access/8","type":"function"},{"doc":"You must have the `s3:GetDataAccess` permission to use this operation.\n\n#","ref":"AWS.S3Control.html#get_data_access/8-permissions","title":"Permissions - AWS.S3Control.get_data_access/8","type":"function"},{"doc":"The IAM role that S3 Access Grants assumes must have the following permissions\nspecified in the trust policy when registering the location: `sts:AssumeRole`,\nfor directory users or groups `sts:SetContext`, and for IAM users or roles\n`sts:SourceIdentity`.","ref":"AWS.S3Control.html#get_data_access/8-additional-permissions","title":"Additional Permissions - AWS.S3Control.get_data_access/8","type":"function"},{"doc":"Returns the tags on an S3 Batch Operations job.","ref":"AWS.S3Control.html#get_job_tagging/4","title":"AWS.S3Control.get_job_tagging/4","type":"function"},{"doc":"#","ref":"AWS.S3Control.html#get_job_tagging/4-definitions","title":"Definitions - AWS.S3Control.get_job_tagging/4","type":"function"},{"doc":"To use the `GetJobTagging` operation, you must have permission to perform the\n`s3:GetJobTagging` action. For more information, see [Controlling access and labeling jobs using\ntags](https://docs.aws.amazon.com/AmazonS3/latest/dev/batch-ops-managing-jobs.html#batch-ops-job-tags)\nin the *Amazon S3 User Guide*.\n\nRelated actions include:\n\n  *\n[CreateJob](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_CreateJob.html)     *\n[PutJobTagging](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_PutJobTagging.html)\n\n  *\n[DeleteJobTagging](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteJobTagging.html)","ref":"AWS.S3Control.html#get_job_tagging/4-permissions","title":"Permissions - AWS.S3Control.get_job_tagging/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nReturns configuration information about the specified Multi-Region Access Point.\n\nThis action will always be routed to the US West (Oregon) Region. For more\ninformation about the restrictions around managing Multi-Region Access Points,\nsee [Managing Multi-Region Access Points](https://docs.aws.amazon.com/AmazonS3/latest/userguide/ManagingMultiRegionAccessPoints.html)\nin the *Amazon S3 User Guide*.\n\nThe following actions are related to `GetMultiRegionAccessPoint`:\n\n  *\n[CreateMultiRegionAccessPoint](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_CreateMultiRegionAccessPoint.html)     *\n[DeleteMultiRegionAccessPoint](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteMultiRegionAccessPoint.html)\n\n  *\n[DescribeMultiRegionAccessPointOperation](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DescribeMultiRegionAccessPointOperation.html)     *\n[ListMultiRegionAccessPoints](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_ListMultiRegionAccessPoints.html)","ref":"AWS.S3Control.html#get_multi_region_access_point/4","title":"AWS.S3Control.get_multi_region_access_point/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nReturns the access control policy of the specified Multi-Region Access Point.\n\nThis action will always be routed to the US West (Oregon) Region. For more\ninformation about the restrictions around managing Multi-Region Access Points,\nsee [Managing Multi-Region Access Points](https://docs.aws.amazon.com/AmazonS3/latest/userguide/ManagingMultiRegionAccessPoints.html)\nin the *Amazon S3 User Guide*.\n\nThe following actions are related to `GetMultiRegionAccessPointPolicy`:\n\n  *\n[GetMultiRegionAccessPointPolicyStatus](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetMultiRegionAccessPointPolicyStatus.html)     *\n[PutMultiRegionAccessPointPolicy](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_PutMultiRegionAccessPointPolicy.html)","ref":"AWS.S3Control.html#get_multi_region_access_point_policy/4","title":"AWS.S3Control.get_multi_region_access_point_policy/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nIndicates whether the specified Multi-Region Access Point has an access control\npolicy that allows public access.\n\nThis action will always be routed to the US West (Oregon) Region. For more\ninformation about the restrictions around managing Multi-Region Access Points,\nsee [Managing Multi-Region Access Points](https://docs.aws.amazon.com/AmazonS3/latest/userguide/ManagingMultiRegionAccessPoints.html)\nin the *Amazon S3 User Guide*.\n\nThe following actions are related to `GetMultiRegionAccessPointPolicyStatus`:\n\n  *\n[GetMultiRegionAccessPointPolicy](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetMultiRegionAccessPointPolicy.html)     *\n[PutMultiRegionAccessPointPolicy](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_PutMultiRegionAccessPointPolicy.html)","ref":"AWS.S3Control.html#get_multi_region_access_point_policy_status/4","title":"AWS.S3Control.get_multi_region_access_point_policy_status/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nReturns the routing configuration for a Multi-Region Access Point, indicating\nwhich Regions are active or passive.\n\nTo obtain routing control changes and failover requests, use the Amazon S3\nfailover control infrastructure endpoints in these five Amazon Web Services\nRegions:\n\n  * `us-east-1`\n\n  * `us-west-2`\n\n  * `ap-southeast-2`\n\n  * `ap-northeast-1`\n\n  * `eu-west-1`\n\nYour Amazon S3 bucket does not need to be in these five Regions.","ref":"AWS.S3Control.html#get_multi_region_access_point_routes/4","title":"AWS.S3Control.get_multi_region_access_point_routes/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nRetrieves the `PublicAccessBlock` configuration for an Amazon Web Services\naccount. For more information, see [ Using Amazon S3 block public access](https://docs.aws.amazon.com/AmazonS3/latest/dev/access-control-block-public-access.html).\n\nRelated actions include:\n\n  *\n[DeletePublicAccessBlock](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeletePublicAccessBlock.html)     *\n[PutPublicAccessBlock](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_PutPublicAccessBlock.html)","ref":"AWS.S3Control.html#get_public_access_block/3","title":"AWS.S3Control.get_public_access_block/3","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nGets the Amazon S3 Storage Lens configuration. For more information, see\n[Assessing your storage activity and usage with Amazon S3 Storage Lens\n](https://docs.aws.amazon.com/AmazonS3/latest/dev/storage_lens.html) in the\n*Amazon S3 User Guide*. For a complete list of S3 Storage Lens metrics, see [S3 Storage Lens metrics\nglossary](https://docs.aws.amazon.com/AmazonS3/latest/userguide/storage_lens_metrics_glossary.html)\nin the *Amazon S3 User Guide*.\n\nTo use this action, you must have permission to perform the\n`s3:GetStorageLensConfiguration` action. For more information, see [Setting permissions to use Amazon S3 Storage\nLens](https://docs.aws.amazon.com/AmazonS3/latest/dev/storage_lens_iam_permissions.html)\nin the *Amazon S3 User Guide*.","ref":"AWS.S3Control.html#get_storage_lens_configuration/4","title":"AWS.S3Control.get_storage_lens_configuration/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nGets the tags of Amazon S3 Storage Lens configuration. For more information\nabout S3 Storage Lens, see [Assessing your storage activity and usage with Amazon S3 Storage Lens\n](https://docs.aws.amazon.com/AmazonS3/latest/dev/storage_lens.html) in the\n*Amazon S3 User Guide*.\n\nTo use this action, you must have permission to perform the\n`s3:GetStorageLensConfigurationTagging` action. For more information, see\n[Setting permissions to use Amazon S3 Storage Lens](https://docs.aws.amazon.com/AmazonS3/latest/dev/storage_lens_iam_permissions.html)\nin the *Amazon S3 User Guide*.","ref":"AWS.S3Control.html#get_storage_lens_configuration_tagging/4","title":"AWS.S3Control.get_storage_lens_configuration_tagging/4","type":"function"},{"doc":"Retrieves the Storage Lens group configuration details.\n\nTo use this operation, you must have the permission to perform the\n`s3:GetStorageLensGroup` action. For more information about the required Storage\nLens Groups permissions, see [Setting account permissions to use S3 Storage Lens groups](https://docs.aws.amazon.com/AmazonS3/latest/userguide/storage_lens_iam_permissions.html#storage_lens_groups_permissions).\n\nFor information about Storage Lens groups errors, see [List of Amazon S3 Storage Lens error\ncodes](https://docs.aws.amazon.com/AmazonS3/latest/API/ErrorResponses.html#S3LensErrorCodeList).","ref":"AWS.S3Control.html#get_storage_lens_group/4","title":"AWS.S3Control.get_storage_lens_group/4","type":"function"},{"doc":"Returns the list of access grants in your S3 Access Grants instance.","ref":"AWS.S3Control.html#list_access_grants/10","title":"AWS.S3Control.list_access_grants/10","type":"function"},{"doc":"#","ref":"AWS.S3Control.html#list_access_grants/10-definitions","title":"Definitions - AWS.S3Control.list_access_grants/10","type":"function"},{"doc":"You must have the `s3:ListAccessGrants` permission to use this operation.","ref":"AWS.S3Control.html#list_access_grants/10-permissions","title":"Permissions - AWS.S3Control.list_access_grants/10","type":"function"},{"doc":"Returns a list of S3 Access Grants instances.\n\nAn S3 Access Grants instance serves as a logical grouping for your individual\naccess grants. You can only have one S3 Access Grants instance per Region per\naccount.","ref":"AWS.S3Control.html#list_access_grants_instances/5","title":"AWS.S3Control.list_access_grants_instances/5","type":"function"},{"doc":"#","ref":"AWS.S3Control.html#list_access_grants_instances/5-definitions","title":"Definitions - AWS.S3Control.list_access_grants_instances/5","type":"function"},{"doc":"You must have the `s3:ListAccessGrantsInstances` permission to use this\noperation.","ref":"AWS.S3Control.html#list_access_grants_instances/5-permissions","title":"Permissions - AWS.S3Control.list_access_grants_instances/5","type":"function"},{"doc":"Returns a list of the locations registered in your S3 Access Grants instance.","ref":"AWS.S3Control.html#list_access_grants_locations/6","title":"AWS.S3Control.list_access_grants_locations/6","type":"function"},{"doc":"#","ref":"AWS.S3Control.html#list_access_grants_locations/6-definitions","title":"Definitions - AWS.S3Control.list_access_grants_locations/6","type":"function"},{"doc":"You must have the `s3:ListAccessGrantsLocations` permission to use this\noperation.","ref":"AWS.S3Control.html#list_access_grants_locations/6-permissions","title":"Permissions - AWS.S3Control.list_access_grants_locations/6","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nReturns a list of the access points that are owned by the current account that's\nassociated with the specified bucket. You can retrieve up to 1000 access points\nper call. If the specified bucket has more than 1,000 access points (or the\nnumber specified in `maxResults`, whichever is less), the response will include\na continuation token that you can use to list the additional access points.\n\nAll Amazon S3 on Outposts REST API requests for this action require an\nadditional parameter of `x-amz-outpost-id` to be passed with the request. In\naddition, you must use an S3 on Outposts endpoint hostname prefix instead of\n`s3-control`. For an example of the request syntax for Amazon S3 on Outposts\nthat uses the S3 on Outposts endpoint hostname prefix and the `x-amz-outpost-id`\nderived by using the access point ARN, see the\n[Examples](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetAccessPoint.html#API_control_GetAccessPoint_Examples) section.\n\nThe following actions are related to `ListAccessPoints`:\n\n  *\n[CreateAccessPoint](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_CreateAccessPoint.html)\n\n  *\n[DeleteAccessPoint](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteAccessPoint.html)     *\n[GetAccessPoint](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetAccessPoint.html)","ref":"AWS.S3Control.html#list_access_points/6","title":"AWS.S3Control.list_access_points/6","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nReturns some or all (up to 1,000) access points associated with the Object\nLambda Access Point per call. If there are more access points than what can be\nreturned in one call, the response will include a continuation token that you\ncan use to list the additional access points.\n\nThe following actions are related to `ListAccessPointsForObjectLambda`:\n\n  *\n[CreateAccessPointForObjectLambda](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_CreateAccessPointForObjectLambda.html)     *\n[DeleteAccessPointForObjectLambda](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteAccessPointForObjectLambda.html)\n\n  *\n[GetAccessPointForObjectLambda](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetAccessPointForObjectLambda.html)","ref":"AWS.S3Control.html#list_access_points_for_object_lambda/5","title":"AWS.S3Control.list_access_points_for_object_lambda/5","type":"function"},{"doc":"Lists current S3 Batch Operations jobs as well as the jobs that have ended\nwithin the last 30 days for the Amazon Web Services account making the request.\n\nFor more information, see [S3 Batch Operations](https://docs.aws.amazon.com/AmazonS3/latest/userguide/batch-ops.html)\nin the *Amazon S3 User Guide*.","ref":"AWS.S3Control.html#list_jobs/6","title":"AWS.S3Control.list_jobs/6","type":"function"},{"doc":"#","ref":"AWS.S3Control.html#list_jobs/6-definitions","title":"Definitions - AWS.S3Control.list_jobs/6","type":"function"},{"doc":"To use the `ListJobs` operation, you must have permission to perform the\n`s3:ListJobs` action.\n\nRelated actions include:\n\n  *\n[CreateJob](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_CreateJob.html)     *\n[DescribeJob](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DescribeJob.html)\n\n  *\n[UpdateJobPriority](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_UpdateJobPriority.html)     *\n[UpdateJobStatus](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_UpdateJobStatus.html)","ref":"AWS.S3Control.html#list_jobs/6-permissions","title":"Permissions - AWS.S3Control.list_jobs/6","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nReturns a list of the Multi-Region Access Points currently associated with the\nspecified Amazon Web Services account. Each call can return up to 100\nMulti-Region Access Points, the maximum number of Multi-Region Access Points\nthat can be associated with a single account.\n\nThis action will always be routed to the US West (Oregon) Region. For more\ninformation about the restrictions around managing Multi-Region Access Points,\nsee [Managing Multi-Region Access Points](https://docs.aws.amazon.com/AmazonS3/latest/userguide/ManagingMultiRegionAccessPoints.html)\nin the *Amazon S3 User Guide*.\n\nThe following actions are related to `ListMultiRegionAccessPoint`:\n\n  *\n[CreateMultiRegionAccessPoint](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_CreateMultiRegionAccessPoint.html)     *\n[DeleteMultiRegionAccessPoint](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteMultiRegionAccessPoint.html)\n\n  *\n[DescribeMultiRegionAccessPointOperation](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DescribeMultiRegionAccessPointOperation.html)     *\n[GetMultiRegionAccessPoint](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetMultiRegionAccessPoint.html)","ref":"AWS.S3Control.html#list_multi_region_access_points/5","title":"AWS.S3Control.list_multi_region_access_points/5","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nReturns a list of all Outposts buckets in an Outpost that are owned by the\nauthenticated sender of the request. For more information, see [Using Amazon S3 on\nOutposts](https://docs.aws.amazon.com/AmazonS3/latest/userguide/S3onOutposts.html)\nin the *Amazon S3 User Guide*.\n\nFor an example of the request syntax for Amazon S3 on Outposts that uses the S3\non Outposts endpoint hostname prefix and `x-amz-outpost-id` in your request, see\nthe\n[Examples](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_ListRegionalBuckets.html#API_control_ListRegionalBuckets_Examples)\nsection.","ref":"AWS.S3Control.html#list_regional_buckets/6","title":"AWS.S3Control.list_regional_buckets/6","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nGets a list of Amazon S3 Storage Lens configurations. For more information about\nS3 Storage Lens, see [Assessing your storage activity and usage with Amazon S3 Storage Lens\n](https://docs.aws.amazon.com/AmazonS3/latest/dev/storage_lens.html) in the\n*Amazon S3 User Guide*.\n\nTo use this action, you must have permission to perform the\n`s3:ListStorageLensConfigurations` action. For more information, see [Setting permissions to use Amazon S3 Storage\nLens](https://docs.aws.amazon.com/AmazonS3/latest/dev/storage_lens_iam_permissions.html)\nin the *Amazon S3 User Guide*.","ref":"AWS.S3Control.html#list_storage_lens_configurations/4","title":"AWS.S3Control.list_storage_lens_configurations/4","type":"function"},{"doc":"Lists all the Storage Lens groups in the specified home Region.\n\nTo use this operation, you must have the permission to perform the\n`s3:ListStorageLensGroups` action. For more information about the required\nStorage Lens Groups permissions, see [Setting account permissions to use S3 Storage Lens\ngroups](https://docs.aws.amazon.com/AmazonS3/latest/userguide/storage_lens_iam_permissions.html#storage_lens_groups_permissions).\n\nFor information about Storage Lens groups errors, see [List of Amazon S3 Storage Lens error\ncodes](https://docs.aws.amazon.com/AmazonS3/latest/API/ErrorResponses.html#S3LensErrorCodeList).","ref":"AWS.S3Control.html#list_storage_lens_groups/4","title":"AWS.S3Control.list_storage_lens_groups/4","type":"function"},{"doc":"This operation allows you to list all the Amazon Web Services resource tags for\na specified resource.\n\nEach tag is a label consisting of a user-defined key and value. Tags can help\nyou manage, identify, organize, search for, and filter resources.","ref":"AWS.S3Control.html#list_tags_for_resource/4","title":"AWS.S3Control.list_tags_for_resource/4","type":"function"},{"doc":"#","ref":"AWS.S3Control.html#list_tags_for_resource/4-definitions","title":"Definitions - AWS.S3Control.list_tags_for_resource/4","type":"function"},{"doc":"You must have the `s3:ListTagsForResource` permission to use this operation.\n\nThis operation is only supported for [S3 Storage Lens groups](https://docs.aws.amazon.com/AmazonS3/latest/userguide/storage-lens-groups.html)\nand for [S3 Access Grants](https://docs.aws.amazon.com/AmazonS3/latest/userguide/access-grants-tagging.html).\nThe tagged resource can be an S3 Storage Lens group or S3 Access Grants\ninstance, registered location, or grant.\n\nFor more information about the required Storage Lens Groups permissions, see\n[Setting account permissions to use S3 Storage Lens groups](https://docs.aws.amazon.com/AmazonS3/latest/userguide/storage_lens_iam_permissions.html#storage_lens_groups_permissions).\n\nFor information about S3 Tagging errors, see [List of Amazon S3 Tagging error codes](https://docs.aws.amazon.com/AmazonS3/latest/API/ErrorResponses.html#S3TaggingErrorCodeList).","ref":"AWS.S3Control.html#list_tags_for_resource/4-permissions","title":"Permissions - AWS.S3Control.list_tags_for_resource/4","type":"function"},{"doc":"","ref":"AWS.S3Control.html#metadata/0","title":"AWS.S3Control.metadata/0","type":"function"},{"doc":"Updates the resource policy of the S3 Access Grants instance.","ref":"AWS.S3Control.html#put_access_grants_instance_resource_policy/3","title":"AWS.S3Control.put_access_grants_instance_resource_policy/3","type":"function"},{"doc":"#","ref":"AWS.S3Control.html#put_access_grants_instance_resource_policy/3-definitions","title":"Definitions - AWS.S3Control.put_access_grants_instance_resource_policy/3","type":"function"},{"doc":"You must have the `s3:PutAccessGrantsInstanceResourcePolicy` permission to use\nthis operation.","ref":"AWS.S3Control.html#put_access_grants_instance_resource_policy/3-permissions","title":"Permissions - AWS.S3Control.put_access_grants_instance_resource_policy/3","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nReplaces configuration for an Object Lambda Access Point.\n\nThe following actions are related to\n`PutAccessPointConfigurationForObjectLambda`:\n\n  *\n[GetAccessPointConfigurationForObjectLambda](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetAccessPointConfigurationForObjectLambda.html)","ref":"AWS.S3Control.html#put_access_point_configuration_for_object_lambda/4","title":"AWS.S3Control.put_access_point_configuration_for_object_lambda/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nAssociates an access policy with the specified access point. Each access point\ncan have only one policy, so a request made to this API replaces any existing\npolicy associated with the specified access point.\n\nAll Amazon S3 on Outposts REST API requests for this action require an\nadditional parameter of `x-amz-outpost-id` to be passed with the request. In\naddition, you must use an S3 on Outposts endpoint hostname prefix instead of\n`s3-control`. For an example of the request syntax for Amazon S3 on Outposts\nthat uses the S3 on Outposts endpoint hostname prefix and the `x-amz-outpost-id`\nderived by using the access point ARN, see the\n[Examples](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_PutAccessPointPolicy.html#API_control_PutAccessPointPolicy_Examples) section.\n\nThe following actions are related to `PutAccessPointPolicy`:\n\n  *\n[GetAccessPointPolicy](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetAccessPointPolicy.html)\n\n  *\n[DeleteAccessPointPolicy](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteAccessPointPolicy.html)","ref":"AWS.S3Control.html#put_access_point_policy/4","title":"AWS.S3Control.put_access_point_policy/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nCreates or replaces resource policy for an Object Lambda Access Point. For an\nexample policy, see [Creating Object Lambda Access Points](https://docs.aws.amazon.com/AmazonS3/latest/userguide/olap-create.html#olap-create-cli)\nin the *Amazon S3 User Guide*.\n\nThe following actions are related to `PutAccessPointPolicyForObjectLambda`:\n\n  *\n[DeleteAccessPointPolicyForObjectLambda](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteAccessPointPolicyForObjectLambda.html)     *\n[GetAccessPointPolicyForObjectLambda](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetAccessPointPolicyForObjectLambda.html)","ref":"AWS.S3Control.html#put_access_point_policy_for_object_lambda/4","title":"AWS.S3Control.put_access_point_policy_for_object_lambda/4","type":"function"},{"doc":"This action puts a lifecycle configuration to an Amazon S3 on Outposts bucket.\n\nTo put a lifecycle configuration to an S3 bucket, see\n[PutBucketLifecycleConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketLifecycleConfiguration.html) in the *Amazon S3 API Reference*.\n\nCreates a new lifecycle configuration for the S3 on Outposts bucket or replaces\nan existing lifecycle configuration. Outposts buckets only support lifecycle\nconfigurations that delete/expire objects after a certain period of time and\nabort incomplete multipart uploads.\n\nAll Amazon S3 on Outposts REST API requests for this action require an\nadditional parameter of `x-amz-outpost-id` to be passed with the request. In\naddition, you must use an S3 on Outposts endpoint hostname prefix instead of\n`s3-control`. For an example of the request syntax for Amazon S3 on Outposts\nthat uses the S3 on Outposts endpoint hostname prefix and the `x-amz-outpost-id`\nderived by using the access point ARN, see the\n[Examples](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_PutBucketLifecycleConfiguration.html#API_control_PutBucketLifecycleConfiguration_Examples)\nsection.\n\nThe following actions are related to `PutBucketLifecycleConfiguration`:\n\n  *\n[GetBucketLifecycleConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetBucketLifecycleConfiguration.html)     *\n[DeleteBucketLifecycleConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteBucketLifecycleConfiguration.html)","ref":"AWS.S3Control.html#put_bucket_lifecycle_configuration/4","title":"AWS.S3Control.put_bucket_lifecycle_configuration/4","type":"function"},{"doc":"This action puts a bucket policy to an Amazon S3 on Outposts bucket.\n\nTo put a policy on an S3 bucket, see\n[PutBucketPolicy](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketPolicy.html) in the *Amazon S3 API Reference*.\n\nApplies an Amazon S3 bucket policy to an Outposts bucket. For more information,\nsee [Using Amazon S3 on\nOutposts](https://docs.aws.amazon.com/AmazonS3/latest/userguide/S3onOutposts.html)\nin the *Amazon S3 User Guide*.\n\nIf you are using an identity other than the root user of the Amazon Web Services\naccount that owns the Outposts bucket, the calling identity must have the\n`PutBucketPolicy` permissions on the specified Outposts bucket and belong to the\nbucket owner's account in order to use this action.\n\nIf you don't have `PutBucketPolicy` permissions, Amazon S3 returns a `403 Access\nDenied` error. If you have the correct permissions, but you're not using an\nidentity that belongs to the bucket owner's account, Amazon S3 returns a `405\nMethod Not Allowed` error.\n\nAs a security precaution, the root user of the Amazon Web Services account that\nowns a bucket can always use this action, even if the policy explicitly denies\nthe root user the ability to perform this action.\n\nFor more information about bucket policies, see [Using Bucket Policies and User Policies](https://docs.aws.amazon.com/AmazonS3/latest/dev/using-iam-policies.html).\n\nAll Amazon S3 on Outposts REST API requests for this action require an\nadditional parameter of `x-amz-outpost-id` to be passed with the request. In\naddition, you must use an S3 on Outposts endpoint hostname prefix instead of\n`s3-control`. For an example of the request syntax for Amazon S3 on Outposts\nthat uses the S3 on Outposts endpoint hostname prefix and the `x-amz-outpost-id`\nderived by using the access point ARN, see the\n[Examples](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_PutBucketPolicy.html#API_control_PutBucketPolicy_Examples) section.\n\nThe following actions are related to `PutBucketPolicy`:\n\n  *\n[GetBucketPolicy](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetBucketPolicy.html)\n\n  *\n[DeleteBucketPolicy](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteBucketPolicy.html)","ref":"AWS.S3Control.html#put_bucket_policy/4","title":"AWS.S3Control.put_bucket_policy/4","type":"function"},{"doc":"This action creates an Amazon S3 on Outposts bucket's replication configuration.\n\nTo create an S3 bucket's replication configuration, see\n[PutBucketReplication](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketReplication.html) in the *Amazon S3 API Reference*.\n\nCreates a replication configuration or replaces an existing one. For information\nabout S3 replication on Outposts configuration, see [Replicating objects for S3\non\nOutposts](https://docs.aws.amazon.com/AmazonS3/latest/userguide/S3OutpostsReplication.html)\nin the *Amazon S3 User Guide*.\n\nIt can take a while to propagate `PUT` or `DELETE` requests for a replication\nconfiguration to all S3 on Outposts systems. Therefore, the replication\nconfiguration that's returned by a `GET` request soon after a `PUT` or `DELETE`\nrequest might return a more recent result than what's on the Outpost. If an\nOutpost is offline, the delay in updating the replication configuration on that\nOutpost can be significant.\n\nSpecify the replication configuration in the request body. In the replication\nconfiguration, you provide the following information:\n\n  * The name of the destination bucket or buckets where you want S3 on\nOutposts to replicate objects\n\n  * The Identity and Access Management (IAM) role that S3 on Outposts\ncan assume to replicate objects on your behalf\n\n  * Other relevant information, such as replication rules\n\nA replication configuration must include at least one rule and can contain a\nmaximum of 100. Each rule identifies a subset of objects to replicate by\nfiltering the objects in the source Outposts bucket. To choose additional\nsubsets of objects to replicate, add a rule for each subset.\n\nTo specify a subset of the objects in the source Outposts bucket to apply a\nreplication rule to, add the `Filter` element as a child of the `Rule` element.\nYou can filter objects based on an object key prefix, one or more object tags,\nor both. When you add the `Filter` element in the configuration, you must also\nadd the following elements: `DeleteMarkerReplication`, `Status`, and `Priority`.\n\nUsing `PutBucketReplication` on Outposts requires that both the source and\ndestination buckets must have versioning enabled. For information about enabling\nversioning on a bucket, see [Managing S3 Versioning for your S3 on Outposts bucket](https://docs.aws.amazon.com/AmazonS3/latest/userguide/S3OutpostsManagingVersioning.html).\n\nFor information about S3 on Outposts replication failure reasons, see\n[Replication failure reasons](https://docs.aws.amazon.com/AmazonS3/latest/userguide/outposts-replication-eventbridge.html#outposts-replication-failure-codes)\nin the *Amazon S3 User Guide*.","ref":"AWS.S3Control.html#put_bucket_replication/4","title":"AWS.S3Control.put_bucket_replication/4","type":"function"},{"doc":"Outposts buckets are encrypted at all times. All the objects in the source\nOutposts bucket are encrypted and can be replicated. Also, all the replicas in\nthe destination Outposts bucket are encrypted with the same encryption key as\nthe objects in the source Outposts bucket.","ref":"AWS.S3Control.html#put_bucket_replication/4-handling-replication-of-encrypted-objects","title":"Handling Replication of Encrypted Objects - AWS.S3Control.put_bucket_replication/4","type":"function"},{"doc":"To create a `PutBucketReplication` request, you must have\n`s3-outposts:PutReplicationConfiguration` permissions for the bucket. The\nOutposts bucket owner has this permission by default and can grant it to others.\nFor more information about permissions, see [Setting up IAM with S3 on Outposts](https://docs.aws.amazon.com/AmazonS3/latest/userguide/S3OutpostsIAM.html)\nand [Managing access to S3 on Outposts buckets](https://docs.aws.amazon.com/AmazonS3/latest/userguide/S3OutpostsBucketPolicy.html).\n\nTo perform this operation, the user or role must also have the `iam:CreateRole`\nand `iam:PassRole` permissions. For more information, see [Granting a user permissions to pass a role to an Amazon Web Services\nservice](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_use_passrole.html).\n\nAll Amazon S3 on Outposts REST API requests for this action require an\nadditional parameter of `x-amz-outpost-id` to be passed with the request. In\naddition, you must use an S3 on Outposts endpoint hostname prefix instead of\n`s3-control`. For an example of the request syntax for Amazon S3 on Outposts\nthat uses the S3 on Outposts endpoint hostname prefix and the `x-amz-outpost-id`\nderived by using the access point ARN, see the\n[Examples](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_PutBucketReplication.html#API_control_PutBucketReplication_Examples) section.\n\nThe following operations are related to `PutBucketReplication`:\n\n  *\n[GetBucketReplication](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetBucketReplication.html)\n\n  *\n[DeleteBucketReplication](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteBucketReplication.html)","ref":"AWS.S3Control.html#put_bucket_replication/4-permissions","title":"Permissions - AWS.S3Control.put_bucket_replication/4","type":"function"},{"doc":"This action puts tags on an Amazon S3 on Outposts bucket.\n\nTo put tags on an S3 bucket, see\n[PutBucketTagging](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketTagging.html) in the *Amazon S3 API Reference*.\n\nSets the tags for an S3 on Outposts bucket. For more information, see [Using\nAmazon S3 on\nOutposts](https://docs.aws.amazon.com/AmazonS3/latest/userguide/S3onOutposts.html)\nin the *Amazon S3 User Guide*.\n\nUse tags to organize your Amazon Web Services bill to reflect your own cost\nstructure. To do this, sign up to get your Amazon Web Services account bill with\ntag key values included. Then, to see the cost of combined resources, organize\nyour billing information according to resources with the same tag key values.\nFor example, you can tag several resources with a specific application name, and\nthen organize your billing information to see the total cost of that application\nacross several services. For more information, see [Cost allocation and tagging](https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/cost-alloc-tags.html).\n\nWithin a bucket, if you add a tag that has the same key as an existing tag, the\nnew value overwrites the old value. For more information, see [ Using cost allocation in Amazon S3 bucket\ntags](https://docs.aws.amazon.com/AmazonS3/latest/userguide/CostAllocTagging.html).\n\nTo use this action, you must have permissions to perform the\n`s3-outposts:PutBucketTagging` action. The Outposts bucket owner has this\npermission by default and can grant this permission to others. For more\ninformation about permissions, see [ Permissions Related to Bucket Subresource Operations](https://docs.aws.amazon.com/AmazonS3/latest/userguide/using-with-s3-actions.html#using-with-s3-actions-related-to-bucket-subresources)\nand [Managing access permissions to your Amazon S3 resources](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-access-control.html).\n\n`PutBucketTagging` has the following special errors:\n\n  * Error code: `InvalidTagError`\n\n    * Description: The tag provided was not a valid tag.\nThis error can occur if the tag did not pass input validation. For information\nabout tag restrictions, see [ User-Defined Tag Restrictions](https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/allocation-tag-restrictions.html)\nand [ Amazon Web Services-Generated Cost Allocation Tag Restrictions](https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/aws-tag-restrictions.html).\n\n  * Error code: `MalformedXMLError`\n\n    * Description: The XML provided does not match the\nschema.\n\n  * Error code: `OperationAbortedError `\n\n    * Description: A conflicting conditional action is\ncurrently in progress against this resource. Try again.\n\n  * Error code: `InternalError`\n\n    * Description: The service was unable to apply the\nprovided tag to the bucket.\n\nAll Amazon S3 on Outposts REST API requests for this action require an\nadditional parameter of `x-amz-outpost-id` to be passed with the request. In\naddition, you must use an S3 on Outposts endpoint hostname prefix instead of\n`s3-control`. For an example of the request syntax for Amazon S3 on Outposts\nthat uses the S3 on Outposts endpoint hostname prefix and the `x-amz-outpost-id`\nderived by using the access point ARN, see the\n[Examples](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_PutBucketTagging.html#API_control_PutBucketTagging_Examples) section.\n\nThe following actions are related to `PutBucketTagging`:\n\n  *\n[GetBucketTagging](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetBucketTagging.html)\n\n  *\n[DeleteBucketTagging](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteBucketTagging.html)","ref":"AWS.S3Control.html#put_bucket_tagging/4","title":"AWS.S3Control.put_bucket_tagging/4","type":"function"},{"doc":"This operation sets the versioning state for S3 on Outposts buckets only.\n\nTo set the versioning state for an S3 bucket, see\n[PutBucketVersioning](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketVersioning.html) in the *Amazon S3 API Reference*.\n\nSets the versioning state for an S3 on Outposts bucket. With S3 Versioning, you\ncan save multiple distinct copies of your objects and recover from unintended\nuser actions and application failures.\n\nYou can set the versioning state to one of the following:\n\n  * **Enabled** - Enables versioning for the objects in the bucket.\nAll objects added to the bucket receive a unique version ID.\n\n  * **Suspended** - Suspends versioning for the objects in the bucket.\nAll objects added to the bucket receive the version ID `null`.\n\nIf you've never set versioning on your bucket, it has no versioning state. In\nthat case, a [\nGetBucketVersioning](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetBucketVersioning.html)\nrequest does not return a versioning state value.\n\nWhen you enable S3 Versioning, for each object in your bucket, you have a\ncurrent version and zero or more noncurrent versions. You can configure your\nbucket S3 Lifecycle rules to expire noncurrent versions after a specified time\nperiod. For more information, see [ Creating and managing a lifecycle configuration for your S3 on Outposts\nbucket](https://docs.aws.amazon.com/AmazonS3/latest/userguide/S3OutpostsLifecycleManaging.html)\nin the *Amazon S3 User Guide*.\n\nIf you have an object expiration lifecycle configuration in your non-versioned\nbucket and you want to maintain the same permanent delete behavior when you\nenable versioning, you must add a noncurrent expiration policy. The noncurrent\nexpiration lifecycle configuration will manage the deletes of the noncurrent\nobject versions in the version-enabled bucket. For more information, see\n[Versioning](https://docs.aws.amazon.com/AmazonS3/latest/userguide/Versioning.html) in the *Amazon S3 User Guide*.\n\nAll Amazon S3 on Outposts REST API requests for this action require an\nadditional parameter of `x-amz-outpost-id` to be passed with the request. In\naddition, you must use an S3 on Outposts endpoint hostname prefix instead of\n`s3-control`. For an example of the request syntax for Amazon S3 on Outposts\nthat uses the S3 on Outposts endpoint hostname prefix and the `x-amz-outpost-id`\nderived by using the access point ARN, see the\n[Examples](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_PutBucketVersioning.html#API_control_PutBucketVersioning_Examples)\nsection.\n\nThe following operations are related to `PutBucketVersioning` for S3 on\nOutposts.\n\n  *\n[GetBucketVersioning](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetBucketVersioning.html)     *\n[PutBucketLifecycleConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_PutBucketLifecycleConfiguration.html)\n\n  *\n[GetBucketLifecycleConfiguration](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetBucketLifecycleConfiguration.html)","ref":"AWS.S3Control.html#put_bucket_versioning/4","title":"AWS.S3Control.put_bucket_versioning/4","type":"function"},{"doc":"Sets the supplied tag-set on an S3 Batch Operations job.\n\nA tag is a key-value pair. You can associate S3 Batch Operations tags with any\njob by sending a PUT request against the tagging subresource that is associated\nwith the job. To modify the existing tag set, you can either replace the\nexisting tag set entirely, or make changes within the existing tag set by\nretrieving the existing tag set using\n[GetJobTagging](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetJobTagging.html), modify that tag set, and use this operation to replace the tag set with the one\nyou modified. For more information, see [Controlling access and labeling jobs\nusing\ntags](https://docs.aws.amazon.com/AmazonS3/latest/dev/batch-ops-managing-jobs.html#batch-ops-job-tags)\nin the *Amazon S3 User Guide*.\n\n   If you send this request with an empty tag set, Amazon S3 deletes\nthe existing tag set on the Batch Operations job. If you use this method, you\nare charged for a Tier 1 Request (PUT). For more information, see [Amazon S3 pricing](http://aws.amazon.com/s3/pricing/).\n\n   For deleting existing tags for your Batch Operations job, a\n[DeleteJobTagging](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteJobTagging.html) request is preferred because it achieves the same result without incurring\ncharges.\n\n   A few things to consider about using tags:\n\n     Amazon S3 limits the maximum number of tags to 50 tags\nper job.\n\n     You can associate up to 50 tags with a job as long as\nthey have unique tag keys.\n\n     A tag key can be up to 128 Unicode characters in\nlength, and tag values can be up to 256 Unicode characters in length.\n\n     The key and values are case sensitive.\n\n     For tagging-related restrictions related to characters\nand encodings, see [User-Defined Tag\nRestrictions](https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/allocation-tag-restrictions.html)\nin the *Billing and Cost Management User Guide*.","ref":"AWS.S3Control.html#put_job_tagging/4","title":"AWS.S3Control.put_job_tagging/4","type":"function"},{"doc":"#","ref":"AWS.S3Control.html#put_job_tagging/4-definitions","title":"Definitions - AWS.S3Control.put_job_tagging/4","type":"function"},{"doc":"To use the `PutJobTagging` operation, you must have permission to perform the\n`s3:PutJobTagging` action.\n\nRelated actions include:\n\n  *\n[CreateJob](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_CreateJob.html)     *\n[GetJobTagging](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetJobTagging.html)\n\n  *\n[DeleteJobTagging](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteJobTagging.html)","ref":"AWS.S3Control.html#put_job_tagging/4-permissions","title":"Permissions - AWS.S3Control.put_job_tagging/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nAssociates an access control policy with the specified Multi-Region Access\nPoint. Each Multi-Region Access Point can have only one policy, so a request\nmade to this action replaces any existing policy that is associated with the\nspecified Multi-Region Access Point.\n\nThis action will always be routed to the US West (Oregon) Region. For more\ninformation about the restrictions around managing Multi-Region Access Points,\nsee [Managing Multi-Region Access Points](https://docs.aws.amazon.com/AmazonS3/latest/userguide/ManagingMultiRegionAccessPoints.html)\nin the *Amazon S3 User Guide*.\n\nThe following actions are related to `PutMultiRegionAccessPointPolicy`:\n\n  *\n[GetMultiRegionAccessPointPolicy](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetMultiRegionAccessPointPolicy.html)     *\n[GetMultiRegionAccessPointPolicyStatus](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetMultiRegionAccessPointPolicyStatus.html)","ref":"AWS.S3Control.html#put_multi_region_access_point_policy/3","title":"AWS.S3Control.put_multi_region_access_point_policy/3","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nCreates or modifies the `PublicAccessBlock` configuration for an Amazon Web\nServices account. For this operation, users must have the\n`s3:PutAccountPublicAccessBlock` permission. For more information, see [ Using Amazon S3 block public\naccess](https://docs.aws.amazon.com/AmazonS3/latest/dev/access-control-block-public-access.html).\n\nRelated actions include:\n\n  *\n[GetPublicAccessBlock](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetPublicAccessBlock.html)     *\n[DeletePublicAccessBlock](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeletePublicAccessBlock.html)","ref":"AWS.S3Control.html#put_public_access_block/3","title":"AWS.S3Control.put_public_access_block/3","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nPuts an Amazon S3 Storage Lens configuration. For more information about S3\nStorage Lens, see [Working with Amazon S3 Storage Lens](https://docs.aws.amazon.com/AmazonS3/latest/dev/storage_lens.html) in the\n*Amazon S3 User Guide*. For a complete list of S3 Storage Lens metrics, see [S3 Storage Lens metrics\nglossary](https://docs.aws.amazon.com/AmazonS3/latest/userguide/storage_lens_metrics_glossary.html)\nin the *Amazon S3 User Guide*.\n\nTo use this action, you must have permission to perform the\n`s3:PutStorageLensConfiguration` action. For more information, see [Setting permissions to use Amazon S3 Storage\nLens](https://docs.aws.amazon.com/AmazonS3/latest/dev/storage_lens_iam_permissions.html)\nin the *Amazon S3 User Guide*.","ref":"AWS.S3Control.html#put_storage_lens_configuration/4","title":"AWS.S3Control.put_storage_lens_configuration/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nPut or replace tags on an existing Amazon S3 Storage Lens configuration. For\nmore information about S3 Storage Lens, see [Assessing your storage activity and usage with Amazon S3 Storage Lens\n](https://docs.aws.amazon.com/AmazonS3/latest/dev/storage_lens.html) in the\n*Amazon S3 User Guide*.\n\nTo use this action, you must have permission to perform the\n`s3:PutStorageLensConfigurationTagging` action. For more information, see\n[Setting permissions to use Amazon S3 Storage Lens](https://docs.aws.amazon.com/AmazonS3/latest/dev/storage_lens_iam_permissions.html)\nin the *Amazon S3 User Guide*.","ref":"AWS.S3Control.html#put_storage_lens_configuration_tagging/4","title":"AWS.S3Control.put_storage_lens_configuration_tagging/4","type":"function"},{"doc":"This operation is not supported by directory buckets.\n\nSubmits an updated route configuration for a Multi-Region Access Point. This API\noperation updates the routing status for the specified Regions from active to\npassive, or from passive to active. A value of `0` indicates a passive status,\nwhich means that traffic won't be routed to the specified Region. A value of\n`100` indicates an active status, which means that traffic will be routed to the\nspecified Region. At least one Region must be active at all times.\n\nWhen the routing configuration is changed, any in-progress operations (uploads,\ncopies, deletes, and so on) to formerly active Regions will continue to run to\ntheir final completion state (success or failure). The routing configurations of\nany Regions that aren’t specified remain unchanged.\n\nUpdated routing configurations might not be immediately applied. It can take up\nto 2 minutes for your changes to take effect.\n\nTo submit routing control changes and failover requests, use the Amazon S3\nfailover control infrastructure endpoints in these five Amazon Web Services\nRegions:\n\n  * `us-east-1`\n\n  * `us-west-2`\n\n  * `ap-southeast-2`\n\n  * `ap-northeast-1`\n\n  * `eu-west-1`\n\nYour Amazon S3 bucket does not need to be in these five Regions.","ref":"AWS.S3Control.html#submit_multi_region_access_point_routes/4","title":"AWS.S3Control.submit_multi_region_access_point_routes/4","type":"function"},{"doc":"Creates a new Amazon Web Services resource tag or updates an existing resource\ntag.\n\nEach tag is a label consisting of a user-defined key and value. Tags can help\nyou manage, identify, organize, search for, and filter resources. You can add up\nto 50 Amazon Web Services resource tags for each S3 resource.\n\nThis operation is only supported for [S3 Storage Lens groups](https://docs.aws.amazon.com/AmazonS3/latest/userguide/storage-lens-groups.html)\nand for [S3 Access Grants](https://docs.aws.amazon.com/AmazonS3/latest/userguide/access-grants-tagging.html).\nThe tagged resource can be an S3 Storage Lens group or S3 Access Grants\ninstance, registered location, or grant.","ref":"AWS.S3Control.html#tag_resource/4","title":"AWS.S3Control.tag_resource/4","type":"function"},{"doc":"#","ref":"AWS.S3Control.html#tag_resource/4-definitions","title":"Definitions - AWS.S3Control.tag_resource/4","type":"function"},{"doc":"You must have the `s3:TagResource` permission to use this operation.\n\nFor more information about the required Storage Lens Groups permissions, see\n[Setting account permissions to use S3 Storage Lens groups](https://docs.aws.amazon.com/AmazonS3/latest/userguide/storage_lens_iam_permissions.html#storage_lens_groups_permissions).\n\nFor information about S3 Tagging errors, see [List of Amazon S3 Tagging error codes](https://docs.aws.amazon.com/AmazonS3/latest/API/ErrorResponses.html#S3TaggingErrorCodeList).","ref":"AWS.S3Control.html#tag_resource/4-permissions","title":"Permissions - AWS.S3Control.tag_resource/4","type":"function"},{"doc":"This operation removes the specified Amazon Web Services resource tags from an\nS3 resource.\n\nEach tag is a label consisting of a user-defined key and value. Tags can help\nyou manage, identify, organize, search for, and filter resources.\n\nThis operation is only supported for [S3 Storage Lens groups](https://docs.aws.amazon.com/AmazonS3/latest/userguide/storage-lens-groups.html)\nand for [S3 Access Grants](https://docs.aws.amazon.com/AmazonS3/latest/userguide/access-grants-tagging.html).\nThe tagged resource can be an S3 Storage Lens group or S3 Access Grants\ninstance, registered location, or grant.","ref":"AWS.S3Control.html#untag_resource/4","title":"AWS.S3Control.untag_resource/4","type":"function"},{"doc":"#","ref":"AWS.S3Control.html#untag_resource/4-definitions","title":"Definitions - AWS.S3Control.untag_resource/4","type":"function"},{"doc":"You must have the `s3:UntagResource` permission to use this operation.\n\nFor more information about the required Storage Lens Groups permissions, see\n[Setting account permissions to use S3 Storage Lens groups](https://docs.aws.amazon.com/AmazonS3/latest/userguide/storage_lens_iam_permissions.html#storage_lens_groups_permissions).\n\nFor information about S3 Tagging errors, see [List of Amazon S3 Tagging error codes](https://docs.aws.amazon.com/AmazonS3/latest/API/ErrorResponses.html#S3TaggingErrorCodeList).","ref":"AWS.S3Control.html#untag_resource/4-permissions","title":"Permissions - AWS.S3Control.untag_resource/4","type":"function"},{"doc":"Updates the IAM role of a registered location in your S3 Access Grants instance.","ref":"AWS.S3Control.html#update_access_grants_location/4","title":"AWS.S3Control.update_access_grants_location/4","type":"function"},{"doc":"#","ref":"AWS.S3Control.html#update_access_grants_location/4-definitions","title":"Definitions - AWS.S3Control.update_access_grants_location/4","type":"function"},{"doc":"You must have the `s3:UpdateAccessGrantsLocation` permission to use this\noperation.\n\n#","ref":"AWS.S3Control.html#update_access_grants_location/4-permissions","title":"Permissions - AWS.S3Control.update_access_grants_location/4","type":"function"},{"doc":"You must also have the following permission: `iam:PassRole`","ref":"AWS.S3Control.html#update_access_grants_location/4-additional-permissions","title":"Additional Permissions - AWS.S3Control.update_access_grants_location/4","type":"function"},{"doc":"Updates an existing S3 Batch Operations job's priority.\n\nFor more information, see [S3 Batch Operations](https://docs.aws.amazon.com/AmazonS3/latest/userguide/batch-ops.html)\nin the *Amazon S3 User Guide*.","ref":"AWS.S3Control.html#update_job_priority/4","title":"AWS.S3Control.update_job_priority/4","type":"function"},{"doc":"#","ref":"AWS.S3Control.html#update_job_priority/4-definitions","title":"Definitions - AWS.S3Control.update_job_priority/4","type":"function"},{"doc":"To use the `UpdateJobPriority` operation, you must have permission to perform\nthe `s3:UpdateJobPriority` action.\n\nRelated actions include:\n\n  *\n[CreateJob](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_CreateJob.html)     *\n[ListJobs](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_ListJobs.html)\n\n  *\n[DescribeJob](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DescribeJob.html)     *\n[UpdateJobStatus](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_UpdateJobStatus.html)","ref":"AWS.S3Control.html#update_job_priority/4-permissions","title":"Permissions - AWS.S3Control.update_job_priority/4","type":"function"},{"doc":"Updates the status for the specified job.\n\nUse this operation to confirm that you want to run a job or to cancel an\nexisting job. For more information, see [S3 Batch Operations](https://docs.aws.amazon.com/AmazonS3/latest/userguide/batch-ops.html)\nin the *Amazon S3 User Guide*.","ref":"AWS.S3Control.html#update_job_status/4","title":"AWS.S3Control.update_job_status/4","type":"function"},{"doc":"#","ref":"AWS.S3Control.html#update_job_status/4-definitions","title":"Definitions - AWS.S3Control.update_job_status/4","type":"function"},{"doc":"To use the `UpdateJobStatus` operation, you must have permission to perform the\n`s3:UpdateJobStatus` action.\n\nRelated actions include:\n\n  *\n[CreateJob](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_CreateJob.html)     *\n[ListJobs](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_ListJobs.html)\n\n  *\n[DescribeJob](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DescribeJob.html)     *\n[UpdateJobStatus](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_UpdateJobStatus.html)","ref":"AWS.S3Control.html#update_job_status/4-permissions","title":"Permissions - AWS.S3Control.update_job_status/4","type":"function"},{"doc":"Updates the existing Storage Lens group.\n\nTo use this operation, you must have the permission to perform the\n`s3:UpdateStorageLensGroup` action. For more information about the required\nStorage Lens Groups permissions, see [Setting account permissions to use S3 Storage Lens\ngroups](https://docs.aws.amazon.com/AmazonS3/latest/userguide/storage_lens_iam_permissions.html#storage_lens_groups_permissions).\n\nFor information about Storage Lens groups errors, see [List of Amazon S3 Storage Lens error\ncodes](https://docs.aws.amazon.com/AmazonS3/latest/API/ErrorResponses.html#S3LensErrorCodeList).","ref":"AWS.S3Control.html#update_storage_lens_group/4","title":"AWS.S3Control.update_storage_lens_group/4","type":"function"},{"doc":"Amazon S3 on Outposts provides access to S3 on Outposts operations.","ref":"AWS.S3Outposts.html","title":"AWS.S3Outposts","type":"module"},{"doc":"Creates an endpoint and associates it with the specified Outpost.\n\nIt can take up to 5 minutes for this action to finish.\n\nRelated actions include:\n\n  *\n[DeleteEndpoint](https://docs.aws.amazon.com/AmazonS3/latest/API/API_s3outposts_DeleteEndpoint.html)     *\n[ListEndpoints](https://docs.aws.amazon.com/AmazonS3/latest/API/API_s3outposts_ListEndpoints.html)","ref":"AWS.S3Outposts.html#create_endpoint/3","title":"AWS.S3Outposts.create_endpoint/3","type":"function"},{"doc":"Deletes an endpoint.\n\nIt can take up to 5 minutes for this action to finish.\n\nRelated actions include:\n\n  *\n[CreateEndpoint](https://docs.aws.amazon.com/AmazonS3/latest/API/API_s3outposts_CreateEndpoint.html)     *\n[ListEndpoints](https://docs.aws.amazon.com/AmazonS3/latest/API/API_s3outposts_ListEndpoints.html)","ref":"AWS.S3Outposts.html#delete_endpoint/3","title":"AWS.S3Outposts.delete_endpoint/3","type":"function"},{"doc":"Lists endpoints associated with the specified Outpost.\n\nRelated actions include:\n\n  *\n[CreateEndpoint](https://docs.aws.amazon.com/AmazonS3/latest/API/API_s3outposts_CreateEndpoint.html)     *\n[DeleteEndpoint](https://docs.aws.amazon.com/AmazonS3/latest/API/API_s3outposts_DeleteEndpoint.html)","ref":"AWS.S3Outposts.html#list_endpoints/4","title":"AWS.S3Outposts.list_endpoints/4","type":"function"},{"doc":"Lists the Outposts with S3 on Outposts capacity for your Amazon Web Services\naccount.\n\nIncludes S3 on Outposts that you have access to as the Outposts owner, or as a\nshared user from Resource Access Manager (RAM).","ref":"AWS.S3Outposts.html#list_outposts_with_s3/4","title":"AWS.S3Outposts.list_outposts_with_s3/4","type":"function"},{"doc":"Lists all endpoints associated with an Outpost that has been shared by Amazon\nWeb Services Resource Access Manager (RAM).\n\nRelated actions include:\n\n  *\n[CreateEndpoint](https://docs.aws.amazon.com/AmazonS3/latest/API/API_s3outposts_CreateEndpoint.html)     *\n[DeleteEndpoint](https://docs.aws.amazon.com/AmazonS3/latest/API/API_s3outposts_DeleteEndpoint.html)","ref":"AWS.S3Outposts.html#list_shared_endpoints/5","title":"AWS.S3Outposts.list_shared_endpoints/5","type":"function"},{"doc":"","ref":"AWS.S3Outposts.html#metadata/0","title":"AWS.S3Outposts.metadata/0","type":"function"},{"doc":"Amazon Simple Email Service\n\nThis document contains reference information for the [Amazon Simple Email Service](https://aws.amazon.com/ses/) (Amazon SES) API, version 2010-12-01.\n\nThis document is best used in conjunction with the [Amazon SES Developer Guide](https://docs.aws.amazon.com/ses/latest/DeveloperGuide/Welcome.html).\n\nFor a list of Amazon SES endpoints to use in service requests, see [Regions and Amazon SES](https://docs.aws.amazon.com/ses/latest/DeveloperGuide/regions.html)\nin the [Amazon SES Developer Guide](https://docs.aws.amazon.com/ses/latest/DeveloperGuide/Welcome.html).\n\nThis documentation contains reference information related to the following:\n\n  * [Amazon SES API Actions](https://docs.aws.amazon.com/ses/latest/APIReference/API_Operations.html)\n\n  * [Amazon SES API Data Types](https://docs.aws.amazon.com/ses/latest/APIReference/API_Types.html)\n\n  * [Common Parameters](https://docs.aws.amazon.com/ses/latest/APIReference/CommonParameters.html)\n\n  * [Common Errors](https://docs.aws.amazon.com/ses/latest/APIReference/CommonErrors.html)","ref":"AWS.SES.html","title":"AWS.SES","type":"module"},{"doc":"Creates a receipt rule set by cloning an existing one.\n\nAll receipt rules and configurations are copied to the new receipt rule set and\nare completely independent of the source rule set.\n\nFor information about setting up rule sets, see the [Amazon SES Developer Guide](https://docs.aws.amazon.com/ses/latest/dg/receiving-email-concepts.html#receiving-email-concepts-rules).\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#clone_receipt_rule_set/3","title":"AWS.SES.clone_receipt_rule_set/3","type":"function"},{"doc":"Creates a configuration set.\n\nConfiguration sets enable you to publish email sending events. For information\nabout using configuration sets, see the [Amazon SES Developer Guide](https://docs.aws.amazon.com/ses/latest/dg/monitor-sending-activity.html).\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#create_configuration_set/3","title":"AWS.SES.create_configuration_set/3","type":"function"},{"doc":"Creates a configuration set event destination.\n\nWhen you create or update an event destination, you must provide one, and only\none, destination. The destination can be CloudWatch, Amazon Kinesis Firehose, or\nAmazon Simple Notification Service (Amazon SNS).\n\nAn event destination is the Amazon Web Services service to which Amazon SES\npublishes the email sending events associated with a configuration set. For\ninformation about using configuration sets, see the [Amazon SES Developer Guide](https://docs.aws.amazon.com/ses/latest/dg/monitor-sending-activity.html).\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#create_configuration_set_event_destination/3","title":"AWS.SES.create_configuration_set_event_destination/3","type":"function"},{"doc":"Creates an association between a configuration set and a custom domain for open\nand click event tracking.\n\nBy default, images and links used for tracking open and click events are hosted\non domains operated by Amazon SES. You can configure a subdomain of your own to\nhandle these events. For information about using custom domains, see the [Amazon SES Developer\nGuide](https://docs.aws.amazon.com/ses/latest/dg/configure-custom-open-click-domains.html).","ref":"AWS.SES.html#create_configuration_set_tracking_options/3","title":"AWS.SES.create_configuration_set_tracking_options/3","type":"function"},{"doc":"Creates a new custom verification email template.\n\nFor more information about custom verification email templates, see [Using Custom Verification Email\nTemplates](https://docs.aws.amazon.com/ses/latest/dg/creating-identities.html#send-email-verify-address-custom)\nin the *Amazon SES Developer Guide*.\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#create_custom_verification_email_template/3","title":"AWS.SES.create_custom_verification_email_template/3","type":"function"},{"doc":"Creates a new IP address filter.\n\nFor information about setting up IP address filters, see the [Amazon SES Developer\nGuide](https://docs.aws.amazon.com/ses/latest/dg/receiving-email-ip-filtering-console-walkthrough.html).\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#create_receipt_filter/3","title":"AWS.SES.create_receipt_filter/3","type":"function"},{"doc":"Creates a receipt rule.\n\nFor information about setting up receipt rules, see the [Amazon SES Developer Guide](https://docs.aws.amazon.com/ses/latest/dg/receiving-email-receipt-rules-console-walkthrough.html).\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#create_receipt_rule/3","title":"AWS.SES.create_receipt_rule/3","type":"function"},{"doc":"Creates an empty receipt rule set.\n\nFor information about setting up receipt rule sets, see the [Amazon SES Developer\nGuide](https://docs.aws.amazon.com/ses/latest/dg/receiving-email-concepts.html#receiving-email-concepts-rules).\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#create_receipt_rule_set/3","title":"AWS.SES.create_receipt_rule_set/3","type":"function"},{"doc":"Creates an email template.\n\nEmail templates enable you to send personalized email to one or more\ndestinations in a single operation. For more information, see the [Amazon SES Developer\nGuide](https://docs.aws.amazon.com/ses/latest/dg/send-personalized-email-api.html).\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#create_template/3","title":"AWS.SES.create_template/3","type":"function"},{"doc":"Deletes a configuration set.\n\nConfiguration sets enable you to publish email sending events. For information\nabout using configuration sets, see the [Amazon SES Developer Guide](https://docs.aws.amazon.com/ses/latest/dg/monitor-sending-activity.html).\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#delete_configuration_set/3","title":"AWS.SES.delete_configuration_set/3","type":"function"},{"doc":"Deletes a configuration set event destination.\n\nConfiguration set event destinations are associated with configuration sets,\nwhich enable you to publish email sending events. For information about using\nconfiguration sets, see the [Amazon SES Developer Guide](https://docs.aws.amazon.com/ses/latest/dg/monitor-sending-activity.html).\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#delete_configuration_set_event_destination/3","title":"AWS.SES.delete_configuration_set_event_destination/3","type":"function"},{"doc":"Deletes an association between a configuration set and a custom domain for open\nand click event tracking.\n\nBy default, images and links used for tracking open and click events are hosted\non domains operated by Amazon SES. You can configure a subdomain of your own to\nhandle these events. For information about using custom domains, see the [Amazon SES Developer\nGuide](https://docs.aws.amazon.com/ses/latest/dg/configure-custom-open-click-domains.html).\n\nDeleting this kind of association results in emails sent using the specified\nconfiguration set to capture open and click events using the standard, Amazon\nSES-operated domains.","ref":"AWS.SES.html#delete_configuration_set_tracking_options/3","title":"AWS.SES.delete_configuration_set_tracking_options/3","type":"function"},{"doc":"Deletes an existing custom verification email template.\n\nFor more information about custom verification email templates, see [Using Custom Verification Email\nTemplates](https://docs.aws.amazon.com/ses/latest/dg/creating-identities.html#send-email-verify-address-custom)\nin the *Amazon SES Developer Guide*.\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#delete_custom_verification_email_template/3","title":"AWS.SES.delete_custom_verification_email_template/3","type":"function"},{"doc":"Deletes the specified identity (an email address or a domain) from the list of\nverified identities.\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#delete_identity/3","title":"AWS.SES.delete_identity/3","type":"function"},{"doc":"Deletes the specified sending authorization policy for the given identity (an\nemail address or a domain).\n\nThis operation returns successfully even if a policy with the specified name\ndoes not exist.\n\nThis operation is for the identity owner only. If you have not verified the\nidentity, it returns an error.\n\nSending authorization is a feature that enables an identity owner to authorize\nother senders to use its identities. For information about using sending\nauthorization, see the [Amazon SES Developer Guide](https://docs.aws.amazon.com/ses/latest/dg/sending-authorization.html).\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#delete_identity_policy/3","title":"AWS.SES.delete_identity_policy/3","type":"function"},{"doc":"Deletes the specified IP address filter.\n\nFor information about managing IP address filters, see the [Amazon SES Developer Guide](https://docs.aws.amazon.com/ses/latest/dg/receiving-email-ip-filtering-console-walkthrough.html).\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#delete_receipt_filter/3","title":"AWS.SES.delete_receipt_filter/3","type":"function"},{"doc":"Deletes the specified receipt rule.\n\nFor information about managing receipt rules, see the [Amazon SES Developer Guide](https://docs.aws.amazon.com/ses/latest/dg/receiving-email-receipt-rules-console-walkthrough.html).\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#delete_receipt_rule/3","title":"AWS.SES.delete_receipt_rule/3","type":"function"},{"doc":"Deletes the specified receipt rule set and all of the receipt rules it contains.\n\nThe currently active rule set cannot be deleted.\n\nFor information about managing receipt rule sets, see the [Amazon SES Developer Guide](https://docs.aws.amazon.com/ses/latest/dg/receiving-email-receipt-rules-console-walkthrough.html).\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#delete_receipt_rule_set/3","title":"AWS.SES.delete_receipt_rule_set/3","type":"function"},{"doc":"Deletes an email template.\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#delete_template/3","title":"AWS.SES.delete_template/3","type":"function"},{"doc":"Deprecated.\n\nUse the `DeleteIdentity` operation to delete email addresses and domains.","ref":"AWS.SES.html#delete_verified_email_address/3","title":"AWS.SES.delete_verified_email_address/3","type":"function"},{"doc":"Returns the metadata and receipt rules for the receipt rule set that is\ncurrently active.\n\nFor information about setting up receipt rule sets, see the [Amazon SES Developer\nGuide](https://docs.aws.amazon.com/ses/latest/dg/receiving-email-concepts.html#receiving-email-concepts-rules).\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#describe_active_receipt_rule_set/3","title":"AWS.SES.describe_active_receipt_rule_set/3","type":"function"},{"doc":"Returns the details of the specified configuration set.\n\nFor information about using configuration sets, see the [Amazon SES Developer Guide](https://docs.aws.amazon.com/ses/latest/dg/monitor-sending-activity.html).\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#describe_configuration_set/3","title":"AWS.SES.describe_configuration_set/3","type":"function"},{"doc":"Returns the details of the specified receipt rule.\n\nFor information about setting up receipt rules, see the [Amazon SES Developer Guide](https://docs.aws.amazon.com/ses/latest/dg/receiving-email-receipt-rules-console-walkthrough.html).\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#describe_receipt_rule/3","title":"AWS.SES.describe_receipt_rule/3","type":"function"},{"doc":"Returns the details of the specified receipt rule set.\n\nFor information about managing receipt rule sets, see the [Amazon SES Developer Guide](https://docs.aws.amazon.com/ses/latest/dg/receiving-email-receipt-rules-console-walkthrough.html).\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#describe_receipt_rule_set/3","title":"AWS.SES.describe_receipt_rule_set/3","type":"function"},{"doc":"Returns the email sending status of the Amazon SES account for the current\nRegion.\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#get_account_sending_enabled/3","title":"AWS.SES.get_account_sending_enabled/3","type":"function"},{"doc":"Returns the custom email verification template for the template name you\nspecify.\n\nFor more information about custom verification email templates, see [Using Custom Verification Email\nTemplates](https://docs.aws.amazon.com/ses/latest/dg/creating-identities.html#send-email-verify-address-custom)\nin the *Amazon SES Developer Guide*.\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#get_custom_verification_email_template/3","title":"AWS.SES.get_custom_verification_email_template/3","type":"function"},{"doc":"Returns the current status of Easy DKIM signing for an entity.\n\nFor domain name identities, this operation also returns the DKIM tokens that are\nrequired for Easy DKIM signing, and whether Amazon SES has successfully verified\nthat these tokens have been published.\n\nThis operation takes a list of identities as input and returns the following\ninformation for each:\n\n  * Whether Easy DKIM signing is enabled or disabled.\n\n  * A set of DKIM tokens that represent the identity. If the identity\nis an email address, the tokens represent the domain of that address.\n\n  * Whether Amazon SES has successfully verified the DKIM tokens\npublished in the domain's DNS. This information is only returned for domain name\nidentities, not for email addresses.\n\nThis operation is throttled at one request per second and can only get DKIM\nattributes for up to 100 identities at a time.\n\nFor more information about creating DNS records using DKIM tokens, go to the\n[Amazon SES Developer Guide](https://docs.aws.amazon.com/ses/latest/dg/send-email-authentication-dkim-easy-managing.html).","ref":"AWS.SES.html#get_identity_dkim_attributes/3","title":"AWS.SES.get_identity_dkim_attributes/3","type":"function"},{"doc":"Returns the custom MAIL FROM attributes for a list of identities (email\naddresses : domains).\n\nThis operation is throttled at one request per second and can only get custom\nMAIL FROM attributes for up to 100 identities at a time.","ref":"AWS.SES.html#get_identity_mail_from_domain_attributes/3","title":"AWS.SES.get_identity_mail_from_domain_attributes/3","type":"function"},{"doc":"Given a list of verified identities (email addresses and/or domains), returns a\nstructure describing identity notification attributes.\n\nThis operation is throttled at one request per second and can only get\nnotification attributes for up to 100 identities at a time.\n\nFor more information about using notifications with Amazon SES, see the [Amazon SES Developer\nGuide](https://docs.aws.amazon.com/ses/latest/dg/monitor-sending-activity-using-notifications.html).","ref":"AWS.SES.html#get_identity_notification_attributes/3","title":"AWS.SES.get_identity_notification_attributes/3","type":"function"},{"doc":"Returns the requested sending authorization policies for the given identity (an\nemail address or a domain).\n\nThe policies are returned as a map of policy names to policy contents. You can\nretrieve a maximum of 20 policies at a time.\n\nThis operation is for the identity owner only. If you have not verified the\nidentity, it returns an error.\n\nSending authorization is a feature that enables an identity owner to authorize\nother senders to use its identities. For information about using sending\nauthorization, see the [Amazon SES Developer Guide](https://docs.aws.amazon.com/ses/latest/dg/sending-authorization.html).\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#get_identity_policies/3","title":"AWS.SES.get_identity_policies/3","type":"function"},{"doc":"Given a list of identities (email addresses and/or domains), returns the\nverification status and (for domain identities) the verification token for each\nidentity.\n\nThe verification status of an email address is \"Pending\" until the email address\nowner clicks the link within the verification email that Amazon SES sent to that\naddress. If the email address owner clicks the link within 24 hours, the\nverification status of the email address changes to \"Success\". If the link is\nnot clicked within 24 hours, the verification status changes to \"Failed.\" In\nthat case, to verify the email address, you must restart the verification\nprocess from the beginning.\n\nFor domain identities, the domain's verification status is \"Pending\" as Amazon\nSES searches for the required TXT record in the DNS settings of the domain. When\nAmazon SES detects the record, the domain's verification status changes to\n\"Success\". If Amazon SES is unable to detect the record within 72 hours, the\ndomain's verification status changes to \"Failed.\" In that case, to verify the\ndomain, you must restart the verification process from the beginning.\n\nThis operation is throttled at one request per second and can only get\nverification attributes for up to 100 identities at a time.","ref":"AWS.SES.html#get_identity_verification_attributes/3","title":"AWS.SES.get_identity_verification_attributes/3","type":"function"},{"doc":"Provides the sending limits for the Amazon SES account.\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#get_send_quota/3","title":"AWS.SES.get_send_quota/3","type":"function"},{"doc":"Provides sending statistics for the current Amazon Web Services Region.\n\nThe result is a list of data points, representing the last two weeks of sending\nactivity. Each data point in the list contains statistics for a 15-minute period\nof time.\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#get_send_statistics/3","title":"AWS.SES.get_send_statistics/3","type":"function"},{"doc":"Displays the template object (which includes the Subject line, HTML part and\ntext part) for the template you specify.\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#get_template/3","title":"AWS.SES.get_template/3","type":"function"},{"doc":"Provides a list of the configuration sets associated with your Amazon SES\naccount in the current Amazon Web Services Region.\n\nFor information about using configuration sets, see [Monitoring Your Amazon SES Sending\nActivity](https://docs.aws.amazon.com/ses/latest/dg/monitor-sending-activity.html)\nin the *Amazon SES Developer Guide.*\n\nYou can execute this operation no more than once per second. This operation\nreturns up to 1,000 configuration sets each time it is run. If your Amazon SES\naccount has more than 1,000 configuration sets, this operation also returns\n`NextToken`. You can then execute the `ListConfigurationSets` operation again,\npassing the `NextToken` parameter and the value of the NextToken element to\nretrieve additional results.","ref":"AWS.SES.html#list_configuration_sets/3","title":"AWS.SES.list_configuration_sets/3","type":"function"},{"doc":"Lists the existing custom verification email templates for your account in the\ncurrent Amazon Web Services Region.\n\nFor more information about custom verification email templates, see [Using Custom Verification Email\nTemplates](https://docs.aws.amazon.com/ses/latest/dg/creating-identities.html#send-email-verify-address-custom)\nin the *Amazon SES Developer Guide*.\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#list_custom_verification_email_templates/3","title":"AWS.SES.list_custom_verification_email_templates/3","type":"function"},{"doc":"Returns a list containing all of the identities (email addresses and domains)\nfor your Amazon Web Services account in the current Amazon Web Services Region,\nregardless of verification status.\n\nYou can execute this operation no more than once per second.\n\nIt's recommended that for successive pagination calls of this API, you continue\nto the use the same parameter/value pairs as used in the original call, e.g., if\nyou used `IdentityType=Domain` in the the original call and received a\n`NextToken` in the response, you should continue providing the\n`IdentityType=Domain` parameter for further `NextToken` calls; however, if you\ndidn't provide the `IdentityType` parameter in the original call, then continue\nto not provide it for successive pagination calls. Using this protocol will\nensure consistent results.","ref":"AWS.SES.html#list_identities/3","title":"AWS.SES.list_identities/3","type":"function"},{"doc":"Returns a list of sending authorization policies that are attached to the given\nidentity (an email address or a domain).\n\nThis operation returns only a list. To get the actual policy content, use\n`GetIdentityPolicies`.\n\nThis operation is for the identity owner only. If you have not verified the\nidentity, it returns an error.\n\nSending authorization is a feature that enables an identity owner to authorize\nother senders to use its identities. For information about using sending\nauthorization, see the [Amazon SES Developer Guide](https://docs.aws.amazon.com/ses/latest/dg/sending-authorization.html).\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#list_identity_policies/3","title":"AWS.SES.list_identity_policies/3","type":"function"},{"doc":"Lists the IP address filters associated with your Amazon Web Services account in\nthe current Amazon Web Services Region.\n\nFor information about managing IP address filters, see the [Amazon SES Developer Guide](https://docs.aws.amazon.com/ses/latest/dg/receiving-email-ip-filtering-console-walkthrough.html).\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#list_receipt_filters/3","title":"AWS.SES.list_receipt_filters/3","type":"function"},{"doc":"Lists the receipt rule sets that exist under your Amazon Web Services account in\nthe current Amazon Web Services Region.\n\nIf there are additional receipt rule sets to be retrieved, you receive a\n`NextToken` that you can provide to the next call to `ListReceiptRuleSets` to\nretrieve the additional entries.\n\nFor information about managing receipt rule sets, see the [Amazon SES Developer Guide](https://docs.aws.amazon.com/ses/latest/dg/receiving-email-receipt-rules-console-walkthrough.html).\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#list_receipt_rule_sets/3","title":"AWS.SES.list_receipt_rule_sets/3","type":"function"},{"doc":"Lists the email templates present in your Amazon SES account in the current\nAmazon Web Services Region.\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#list_templates/3","title":"AWS.SES.list_templates/3","type":"function"},{"doc":"Deprecated.\n\nUse the `ListIdentities` operation to list the email addresses and domains\nassociated with your account.","ref":"AWS.SES.html#list_verified_email_addresses/3","title":"AWS.SES.list_verified_email_addresses/3","type":"function"},{"doc":"","ref":"AWS.SES.html#metadata/0","title":"AWS.SES.metadata/0","type":"function"},{"doc":"Adds or updates the delivery options for a configuration set.","ref":"AWS.SES.html#put_configuration_set_delivery_options/3","title":"AWS.SES.put_configuration_set_delivery_options/3","type":"function"},{"doc":"Adds or updates a sending authorization policy for the specified identity (an\nemail address or a domain).\n\nThis operation is for the identity owner only. If you have not verified the\nidentity, it returns an error.\n\nSending authorization is a feature that enables an identity owner to authorize\nother senders to use its identities. For information about using sending\nauthorization, see the [Amazon SES Developer Guide](https://docs.aws.amazon.com/ses/latest/dg/sending-authorization.html).\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#put_identity_policy/3","title":"AWS.SES.put_identity_policy/3","type":"function"},{"doc":"Reorders the receipt rules within a receipt rule set.\n\nAll of the rules in the rule set must be represented in this request. That is,\nit is error if the reorder request doesn't explicitly position all of the rules.\n\nFor information about managing receipt rule sets, see the [Amazon SES Developer Guide](https://docs.aws.amazon.com/ses/latest/dg/receiving-email-receipt-rules-console-walkthrough.html).\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#reorder_receipt_rule_set/3","title":"AWS.SES.reorder_receipt_rule_set/3","type":"function"},{"doc":"Generates and sends a bounce message to the sender of an email you received\nthrough Amazon SES.\n\nYou can only use this operation on an email up to 24 hours after you receive it.\n\nYou cannot use this operation to send generic bounces for mail that was not\nreceived by Amazon SES.\n\nFor information about receiving email through Amazon SES, see the [Amazon SES Developer\nGuide](https://docs.aws.amazon.com/ses/latest/dg/receiving-email.html).\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#send_bounce/3","title":"AWS.SES.send_bounce/3","type":"function"},{"doc":"Composes an email message to multiple destinations.\n\nThe message body is created using an email template.\n\nTo send email using this operation, your call must meet the following\nrequirements:\n\n  * The call must refer to an existing email template. You can create\nemail templates using `CreateTemplate`.\n\n  * The message must be sent from a verified email address or domain.\n\n  * If your account is still in the Amazon SES sandbox, you may send\nonly to verified addresses or domains, or to email addresses associated with the\nAmazon SES Mailbox Simulator. For more information, see [Verifying Email Addresses and\nDomains](https://docs.aws.amazon.com/ses/latest/dg/verify-addresses-and-domains.html)\nin the *Amazon SES Developer Guide.*\n\n  * The maximum message size is 10 MB.\n\n  * Each `Destination` parameter must include at least one recipient\nemail address. The recipient address can be a To: address, a CC: address, or a\nBCC: address. If a recipient email address is invalid (that is, it is not in the\nformat *UserName@[SubDomain.]Domain.TopLevelDomain*), the entire message is\nrejected, even if the message contains other recipients that are valid.\n\n  * The message may not include more than 50 recipients, across the\nTo:, CC: and BCC: fields. If you need to send an email message to a larger\naudience, you can divide your recipient list into groups of 50 or fewer, and\nthen call the `SendBulkTemplatedEmail` operation several times to send the\nmessage to each group.\n\n  * The number of destinations you can contact in a single call can be\nlimited by your account's maximum sending rate.","ref":"AWS.SES.html#send_bulk_templated_email/3","title":"AWS.SES.send_bulk_templated_email/3","type":"function"},{"doc":"Adds an email address to the list of identities for your Amazon SES account in\nthe current Amazon Web Services Region and attempts to verify it.\n\nAs a result of executing this operation, a customized verification email is sent\nto the specified address.\n\nTo use this operation, you must first create a custom verification email\ntemplate. For more information about creating and using custom verification\nemail templates, see [Using Custom Verification Email Templates](https://docs.aws.amazon.com/ses/latest/dg/creating-identities.html#send-email-verify-address-custom)\nin the *Amazon SES Developer Guide*.\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#send_custom_verification_email/3","title":"AWS.SES.send_custom_verification_email/3","type":"function"},{"doc":"Composes an email message and immediately queues it for sending.\n\nTo send email using this operation, your message must meet the following\nrequirements:\n\n  * The message must be sent from a verified email address or domain.\nIf you attempt to send email using a non-verified address or domain, the\noperation results in an \"Email address not verified\" error.\n\n  * If your account is still in the Amazon SES sandbox, you may only\nsend to verified addresses or domains, or to email addresses associated with the\nAmazon SES Mailbox Simulator. For more information, see [Verifying Email Addresses and\nDomains](https://docs.aws.amazon.com/ses/latest/dg/verify-addresses-and-domains.html)\nin the *Amazon SES Developer Guide.*\n\n  * The maximum message size is 10 MB.\n\n  * The message must include at least one recipient email address. The\nrecipient address can be a To: address, a CC: address, or a BCC: address. If a\nrecipient email address is invalid (that is, it is not in the format\n*UserName@[SubDomain.]Domain.TopLevelDomain*), the entire message is rejected, even if the message contains other recipients that are valid.\n\n  * The message may not include more than 50 recipients, across the\nTo:, CC: and BCC: fields. If you need to send an email message to a larger\naudience, you can divide your recipient list into groups of 50 or fewer, and\nthen call the `SendEmail` operation several times to send the message to each\ngroup.\n\nFor every message that you send, the total number of recipients (including each\nrecipient in the To:, CC: and BCC: fields) is counted against the maximum number\nof emails you can send in a 24-hour period (your *sending quota*). For more\ninformation about sending quotas in Amazon SES, see [Managing Your Amazon SES\nSending\nLimits](https://docs.aws.amazon.com/ses/latest/dg/manage-sending-quotas.html) in\nthe *Amazon SES Developer Guide.*","ref":"AWS.SES.html#send_email/3","title":"AWS.SES.send_email/3","type":"function"},{"doc":"Composes an email message and immediately queues it for sending.\n\nThis operation is more flexible than the `SendEmail` operation. When you use the\n`SendRawEmail` operation, you can specify the headers of the message as well as\nits content. This flexibility is useful, for example, when you need to send a\nmultipart MIME email (such a message that contains both a text and an HTML\nversion). You can also use this operation to send messages that include\nattachments.\n\nThe `SendRawEmail` operation has the following requirements:\n\n  * You can only send email from [verified email addresses or domains](https://docs.aws.amazon.com/ses/latest/dg/verify-addresses-and-domains.html).\nIf you try to send email from an address that isn't verified, the operation\nresults in an \"Email address not verified\" error.\n\n  * If your account is still in the [Amazon SES sandbox](https://docs.aws.amazon.com/ses/latest/dg/request-production-access.html),\nyou can only send email to other verified addresses in your account, or to\naddresses that are associated with the [Amazon SES mailbox simulator](https://docs.aws.amazon.com/ses/latest/dg/send-an-email-from-console.html).\n\n  * The maximum message size, including attachments, is 10 MB.\n\n  * Each message has to include at least one recipient address. A\nrecipient address includes any address on the To:, CC:, or BCC: lines.\n\n  * If you send a single message to more than one recipient address,\nand one of the recipient addresses isn't in a valid format (that is, it's not in\nthe format *UserName@[SubDomain.]Domain.TopLevelDomain*), Amazon SES rejects the entire message, even if the other addresses are valid.\n\n  * Each message can include up to 50 recipient addresses across the\nTo:, CC:, or BCC: lines. If you need to send a single message to more than 50\nrecipients, you have to split the list of recipient addresses into groups of\nless than 50 recipients, and send separate messages to each group.\n\n  * Amazon SES allows you to specify 8-bit Content-Transfer-Encoding\nfor MIME message parts. However, if Amazon SES has to modify the contents of\nyour message (for example, if you use open and click tracking), 8-bit content\nisn't preserved. For this reason, we highly recommend that you encode all\ncontent that isn't 7-bit ASCII. For more information, see [MIME\nEncoding](https://docs.aws.amazon.com/ses/latest/dg/send-email-raw.html#send-email-mime-encoding)\nin the *Amazon SES Developer Guide*.\n\nAdditionally, keep the following considerations in mind when using the\n`SendRawEmail` operation:\n\n  * Although you can customize the message headers when using the\n`SendRawEmail` operation, Amazon SES automatically applies its own `Message-ID`\nand `Date` headers; if you passed these headers when creating the message, they\nare overwritten by the values that Amazon SES provides.\n\n  * If you are using sending authorization to send on behalf of\nanother user, `SendRawEmail` enables you to specify the cross-account identity\nfor the email's Source, From, and Return-Path parameters in one of two ways: you\ncan pass optional parameters `SourceArn`, `FromArn`, and/or `ReturnPathArn`, or\nyou can include the following X-headers in the header of your raw email:\n\n    * `X-SES-SOURCE-ARN`\n\n    * `X-SES-FROM-ARN`\n\n    * `X-SES-RETURN-PATH-ARN`\n\nDon't include these X-headers in the DKIM signature. Amazon SES removes these\nbefore it sends the email.\n\nIf you only specify the `SourceIdentityArn` parameter, Amazon SES sets the From\nand Return-Path addresses to the same identity that you specified.\n\nFor more information about sending authorization, see the [Using Sending Authorization with Amazon\nSES](https://docs.aws.amazon.com/ses/latest/dg/sending-authorization.html) in\nthe *Amazon SES Developer Guide.*\n\n  * For every message that you send, the total number of recipients\n(including each recipient in the To:, CC: and BCC: fields) is counted against\nthe maximum number of emails you can send in a 24-hour period (your *sending\nquota*). For more information about sending quotas in Amazon SES, see [Managing Your Amazon SES Sending\nLimits](https://docs.aws.amazon.com/ses/latest/dg/manage-sending-quotas.html) in\nthe *Amazon SES Developer Guide.*","ref":"AWS.SES.html#send_raw_email/3","title":"AWS.SES.send_raw_email/3","type":"function"},{"doc":"Composes an email message using an email template and immediately queues it for\nsending.\n\nTo send email using this operation, your call must meet the following\nrequirements:\n\n  * The call must refer to an existing email template. You can create\nemail templates using the `CreateTemplate` operation.\n\n  * The message must be sent from a verified email address or domain.\n\n  * If your account is still in the Amazon SES sandbox, you may only\nsend to verified addresses or domains, or to email addresses associated with the\nAmazon SES Mailbox Simulator. For more information, see [Verifying Email Addresses and\nDomains](https://docs.aws.amazon.com/ses/latest/dg/verify-addresses-and-domains.html)\nin the *Amazon SES Developer Guide.*\n\n  * The maximum message size is 10 MB.\n\n  * Calls to the `SendTemplatedEmail` operation may only include one\n`Destination` parameter. A destination is a set of recipients that receives the\nsame version of the email. The `Destination` parameter can include up to 50\nrecipients, across the To:, CC: and BCC: fields.\n\n  * The `Destination` parameter must include at least one recipient\nemail address. The recipient address can be a To: address, a CC: address, or a\nBCC: address. If a recipient email address is invalid (that is, it is not in the\nformat *UserName@[SubDomain.]Domain.TopLevelDomain*), the entire message is rejected, even if the message contains other recipients that are valid.\n\nIf your call to the `SendTemplatedEmail` operation includes all of the required\nparameters, Amazon SES accepts it and returns a Message ID. However, if Amazon\nSES can't render the email because the template contains errors, it doesn't send\nthe email. Additionally, because it already accepted the message, Amazon SES\ndoesn't return a message stating that it was unable to send the email.\n\nFor these reasons, we highly recommend that you set up Amazon SES to send you\nnotifications when Rendering Failure events occur. For more information, see\n[Sending Personalized Email Using the Amazon SES\nAPI](https://docs.aws.amazon.com/ses/latest/dg/send-personalized-email-api.html)\nin the *Amazon Simple Email Service Developer Guide*.","ref":"AWS.SES.html#send_templated_email/3","title":"AWS.SES.send_templated_email/3","type":"function"},{"doc":"Sets the specified receipt rule set as the active receipt rule set.\n\nTo disable your email-receiving through Amazon SES completely, you can call this\noperation with `RuleSetName` set to null.\n\nFor information about managing receipt rule sets, see the [Amazon SES Developer Guide](https://docs.aws.amazon.com/ses/latest/dg/receiving-email-receipt-rules-console-walkthrough.html).\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#set_active_receipt_rule_set/3","title":"AWS.SES.set_active_receipt_rule_set/3","type":"function"},{"doc":"Enables or disables Easy DKIM signing of email sent from an identity.\n\nIf Easy DKIM signing is enabled for a domain, then Amazon SES uses DKIM to sign\nall email that it sends from addresses on that domain. If Easy DKIM signing is\nenabled for an email address, then Amazon SES uses DKIM to sign all email it\nsends from that address.\n\nFor email addresses (for example, `user@example.com`), you can only enable DKIM\nsigning if the corresponding domain (in this case, `example.com`) has been set\nup to use Easy DKIM.\n\nYou can enable DKIM signing for an identity at any time after you start the\nverification process for the identity, even if the verification process isn't\ncomplete.\n\nYou can execute this operation no more than once per second.\n\nFor more information about Easy DKIM signing, go to the [Amazon SES Developer Guide](https://docs.aws.amazon.com/ses/latest/dg/send-email-authentication-dkim-easy.html).","ref":"AWS.SES.html#set_identity_dkim_enabled/3","title":"AWS.SES.set_identity_dkim_enabled/3","type":"function"},{"doc":"Given an identity (an email address or a domain), enables or disables whether\nAmazon SES forwards bounce and complaint notifications as email.\n\nFeedback forwarding can only be disabled when Amazon Simple Notification Service\n(Amazon SNS) topics are specified for both bounces and complaints.\n\nFeedback forwarding does not apply to delivery notifications. Delivery\nnotifications are only available through Amazon SNS.\n\nYou can execute this operation no more than once per second.\n\nFor more information about using notifications with Amazon SES, see the [Amazon SES Developer\nGuide](https://docs.aws.amazon.com/ses/latest/dg/monitor-sending-activity-using-notifications.html).","ref":"AWS.SES.html#set_identity_feedback_forwarding_enabled/3","title":"AWS.SES.set_identity_feedback_forwarding_enabled/3","type":"function"},{"doc":"Given an identity (an email address or a domain), sets whether Amazon SES\nincludes the original email headers in the Amazon Simple Notification Service\n(Amazon SNS) notifications of a specified type.\n\nYou can execute this operation no more than once per second.\n\nFor more information about using notifications with Amazon SES, see the [Amazon SES Developer\nGuide](https://docs.aws.amazon.com/ses/latest/dg/monitor-sending-activity-using-notifications.html).","ref":"AWS.SES.html#set_identity_headers_in_notifications_enabled/3","title":"AWS.SES.set_identity_headers_in_notifications_enabled/3","type":"function"},{"doc":"Enables or disables the custom MAIL FROM domain setup for a verified identity\n(an email address or a domain).\n\nTo send emails using the specified MAIL FROM domain, you must add an MX record\nto your MAIL FROM domain's DNS settings. To ensure that your emails pass Sender\nPolicy Framework (SPF) checks, you must also add or update an SPF record. For\nmore information, see the [Amazon SES Developer Guide](https://docs.aws.amazon.com/ses/latest/dg/mail-from.html).\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#set_identity_mail_from_domain/3","title":"AWS.SES.set_identity_mail_from_domain/3","type":"function"},{"doc":"Sets an Amazon Simple Notification Service (Amazon SNS) topic to use when\ndelivering notifications.\n\nWhen you use this operation, you specify a verified identity, such as an email\naddress or domain. When you send an email that uses the chosen identity in the\nSource field, Amazon SES sends notifications to the topic you specified. You can\nsend bounce, complaint, or delivery notifications (or any combination of the\nthree) to the Amazon SNS topic that you specify.\n\nYou can execute this operation no more than once per second.\n\nFor more information about feedback notification, see the [Amazon SES Developer Guide](https://docs.aws.amazon.com/ses/latest/dg/monitor-sending-activity-using-notifications.html).","ref":"AWS.SES.html#set_identity_notification_topic/3","title":"AWS.SES.set_identity_notification_topic/3","type":"function"},{"doc":"Sets the position of the specified receipt rule in the receipt rule set.\n\nFor information about managing receipt rules, see the [Amazon SES Developer Guide](https://docs.aws.amazon.com/ses/latest/dg/receiving-email-receipt-rules-console-walkthrough.html).\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#set_receipt_rule_position/3","title":"AWS.SES.set_receipt_rule_position/3","type":"function"},{"doc":"Creates a preview of the MIME content of an email when provided with a template\nand a set of replacement data.\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#test_render_template/3","title":"AWS.SES.test_render_template/3","type":"function"},{"doc":"Enables or disables email sending across your entire Amazon SES account in the\ncurrent Amazon Web Services Region.\n\nYou can use this operation in conjunction with Amazon CloudWatch alarms to\ntemporarily pause email sending across your Amazon SES account in a given Amazon\nWeb Services Region when reputation metrics (such as your bounce or complaint\nrates) reach certain thresholds.\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#update_account_sending_enabled/3","title":"AWS.SES.update_account_sending_enabled/3","type":"function"},{"doc":"Updates the event destination of a configuration set.\n\nEvent destinations are associated with configuration sets, which enable you to\npublish email sending events to Amazon CloudWatch, Amazon Kinesis Firehose, or\nAmazon Simple Notification Service (Amazon SNS). For information about using\nconfiguration sets, see [Monitoring Your Amazon SES Sending Activity](https://docs.aws.amazon.com/ses/latest/dg/monitor-sending-activity.html)\nin the *Amazon SES Developer Guide.*\n\nWhen you create or update an event destination, you must provide one, and only\none, destination. The destination can be Amazon CloudWatch, Amazon Kinesis\nFirehose, or Amazon Simple Notification Service (Amazon SNS).\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#update_configuration_set_event_destination/3","title":"AWS.SES.update_configuration_set_event_destination/3","type":"function"},{"doc":"Enables or disables the publishing of reputation metrics for emails sent using a\nspecific configuration set in a given Amazon Web Services Region.\n\nReputation metrics include bounce and complaint rates. These metrics are\npublished to Amazon CloudWatch. By using CloudWatch, you can create alarms when\nbounce or complaint rates exceed certain thresholds.\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#update_configuration_set_reputation_metrics_enabled/3","title":"AWS.SES.update_configuration_set_reputation_metrics_enabled/3","type":"function"},{"doc":"Enables or disables email sending for messages sent using a specific\nconfiguration set in a given Amazon Web Services Region.\n\nYou can use this operation in conjunction with Amazon CloudWatch alarms to\ntemporarily pause email sending for a configuration set when the reputation\nmetrics for that configuration set (such as your bounce on complaint rate)\nexceed certain thresholds.\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#update_configuration_set_sending_enabled/3","title":"AWS.SES.update_configuration_set_sending_enabled/3","type":"function"},{"doc":"Modifies an association between a configuration set and a custom domain for open\nand click event tracking.\n\nBy default, images and links used for tracking open and click events are hosted\non domains operated by Amazon SES. You can configure a subdomain of your own to\nhandle these events. For information about using custom domains, see the [Amazon SES Developer\nGuide](https://docs.aws.amazon.com/ses/latest/dg/configure-custom-open-click-domains.html).","ref":"AWS.SES.html#update_configuration_set_tracking_options/3","title":"AWS.SES.update_configuration_set_tracking_options/3","type":"function"},{"doc":"Updates an existing custom verification email template.\n\nFor more information about custom verification email templates, see [Using Custom Verification Email\nTemplates](https://docs.aws.amazon.com/ses/latest/dg/creating-identities.html#send-email-verify-address-custom)\nin the *Amazon SES Developer Guide*.\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#update_custom_verification_email_template/3","title":"AWS.SES.update_custom_verification_email_template/3","type":"function"},{"doc":"Updates a receipt rule.\n\nFor information about managing receipt rules, see the [Amazon SES Developer Guide](https://docs.aws.amazon.com/ses/latest/dg/receiving-email-receipt-rules-console-walkthrough.html).\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#update_receipt_rule/3","title":"AWS.SES.update_receipt_rule/3","type":"function"},{"doc":"Updates an email template.\n\nEmail templates enable you to send personalized email to one or more\ndestinations in a single operation. For more information, see the [Amazon SES Developer\nGuide](https://docs.aws.amazon.com/ses/latest/dg/send-personalized-email-api.html).\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#update_template/3","title":"AWS.SES.update_template/3","type":"function"},{"doc":"Returns a set of DKIM tokens for a domain identity.\n\nWhen you execute the `VerifyDomainDkim` operation, the domain that you specify\nis added to the list of identities that are associated with your account. This\nis true even if you haven't already associated the domain with your account by\nusing the `VerifyDomainIdentity` operation. However, you can't send email from\nthe domain until you either successfully [verify it](https://docs.aws.amazon.com/ses/latest/dg/creating-identities.html#verify-domain-procedure)\nor you successfully [set up DKIM for it](https://docs.aws.amazon.com/ses/latest/dg/send-email-authentication-dkim-easy.html).\n\nYou use the tokens that are generated by this operation to create CNAME records.\nWhen Amazon SES detects that you've added these records to the DNS configuration\nfor a domain, you can start sending email from that domain. You can start\nsending email even if you haven't added the TXT record provided by the\nVerifyDomainIdentity operation to the DNS configuration for your domain. All\nemail that you send from the domain is authenticated using DKIM.\n\nTo create the CNAME records for DKIM authentication, use the following values:\n\n  * **Name**: *token*._domainkey.*example.com*\n\n  * **Type**: CNAME\n\n  * **Value**: *token*.dkim.amazonses.com\n\nIn the preceding example, replace *token* with one of the tokens that are\ngenerated when you execute this operation. Replace *example.com* with your\ndomain. Repeat this process for each token that's generated by this operation.\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#verify_domain_dkim/3","title":"AWS.SES.verify_domain_dkim/3","type":"function"},{"doc":"Adds a domain to the list of identities for your Amazon SES account in the\ncurrent Amazon Web Services Region and attempts to verify it.\n\nFor more information about verifying domains, see [Verifying Email Addresses and Domains](https://docs.aws.amazon.com/ses/latest/dg/verify-addresses-and-domains.html)\nin the *Amazon SES Developer Guide.*\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#verify_domain_identity/3","title":"AWS.SES.verify_domain_identity/3","type":"function"},{"doc":"Deprecated.\n\nUse the `VerifyEmailIdentity` operation to verify a new email address.","ref":"AWS.SES.html#verify_email_address/3","title":"AWS.SES.verify_email_address/3","type":"function"},{"doc":"Adds an email address to the list of identities for your Amazon SES account in\nthe current Amazon Web Services Region and attempts to verify it.\n\nAs a result of executing this operation, a verification email is sent to the\nspecified address.\n\nYou can execute this operation no more than once per second.","ref":"AWS.SES.html#verify_email_identity/3","title":"AWS.SES.verify_email_identity/3","type":"function"},{"doc":"Amazon SES API v2\n\n[Amazon SES](http://aws.amazon.com/ses) is an Amazon Web Services service that you can use to send email messages to your customers.\n\nIf you're new to Amazon SES API v2, you might find it helpful to review the\n[Amazon Simple Email Service Developer\nGuide](https://docs.aws.amazon.com/ses/latest/DeveloperGuide/). The *Amazon SES\nDeveloper Guide* provides information and code samples that demonstrate how to\nuse Amazon SES API v2 features programmatically.","ref":"AWS.SESv2.html","title":"AWS.SESv2","type":"module"},{"doc":"Retrieves batches of metric data collected based on your sending activity.\n\nYou can execute this operation no more than 16 times per second, and with at\nmost 160 queries from the batches per second (cumulative).","ref":"AWS.SESv2.html#batch_get_metric_data/3","title":"AWS.SESv2.batch_get_metric_data/3","type":"function"},{"doc":"Cancels an export job.","ref":"AWS.SESv2.html#cancel_export_job/4","title":"AWS.SESv2.cancel_export_job/4","type":"function"},{"doc":"Create a configuration set.\n\n*Configuration sets* are groups of rules that you can apply to the emails that\nyou send. You apply a configuration set to an email by specifying the name of\nthe configuration set when you call the Amazon SES API v2. When you apply a\nconfiguration set to an email, all of the rules in that configuration set are\napplied to the email.","ref":"AWS.SESv2.html#create_configuration_set/3","title":"AWS.SESv2.create_configuration_set/3","type":"function"},{"doc":"Create an event destination.\n\n*Events* include message sends, deliveries, opens, clicks, bounces, and\ncomplaints. *Event destinations* are places that you can send information about\nthese events to. For example, you can send event data to Amazon SNS to receive\nnotifications when you receive bounces or complaints, or you can use Amazon\nKinesis Data Firehose to stream data to Amazon S3 for long-term storage.\n\nA single configuration set can include more than one event destination.","ref":"AWS.SESv2.html#create_configuration_set_event_destination/4","title":"AWS.SESv2.create_configuration_set_event_destination/4","type":"function"},{"doc":"Creates a contact, which is an end-user who is receiving the email, and adds\nthem to a contact list.","ref":"AWS.SESv2.html#create_contact/4","title":"AWS.SESv2.create_contact/4","type":"function"},{"doc":"Creates a contact list.","ref":"AWS.SESv2.html#create_contact_list/3","title":"AWS.SESv2.create_contact_list/3","type":"function"},{"doc":"Creates a new custom verification email template.\n\nFor more information about custom verification email templates, see [Using custom verification email\ntemplates](https://docs.aws.amazon.com/ses/latest/dg/creating-identities.html#send-email-verify-address-custom)\nin the *Amazon SES Developer Guide*.\n\nYou can execute this operation no more than once per second.","ref":"AWS.SESv2.html#create_custom_verification_email_template/3","title":"AWS.SESv2.create_custom_verification_email_template/3","type":"function"},{"doc":"Create a new pool of dedicated IP addresses.\n\nA pool can include one or more dedicated IP addresses that are associated with\nyour Amazon Web Services account. You can associate a pool with a configuration\nset. When you send an email that uses that configuration set, the message is\nsent from one of the addresses in the associated pool.","ref":"AWS.SESv2.html#create_dedicated_ip_pool/3","title":"AWS.SESv2.create_dedicated_ip_pool/3","type":"function"},{"doc":"Create a new predictive inbox placement test.\n\nPredictive inbox placement tests can help you predict how your messages will be\nhandled by various email providers around the world. When you perform a\npredictive inbox placement test, you provide a sample message that contains the\ncontent that you plan to send to your customers. Amazon SES then sends that\nmessage to special email addresses spread across several major email providers.\nAfter about 24 hours, the test is complete, and you can use the\n`GetDeliverabilityTestReport` operation to view the results of the test.","ref":"AWS.SESv2.html#create_deliverability_test_report/3","title":"AWS.SESv2.create_deliverability_test_report/3","type":"function"},{"doc":"Starts the process of verifying an email identity.\n\nAn *identity* is an email address or domain that you use when you send email.\nBefore you can use an identity to send email, you first have to verify it. By\nverifying an identity, you demonstrate that you're the owner of the identity,\nand that you've given Amazon SES API v2 permission to send email from the\nidentity.\n\nWhen you verify an email address, Amazon SES sends an email to the address. Your\nemail address is verified as soon as you follow the link in the verification\nemail.\n\nWhen you verify a domain without specifying the `DkimSigningAttributes` object,\nthis operation provides a set of DKIM tokens. You can convert these tokens into\nCNAME records, which you then add to the DNS configuration for your domain. Your\ndomain is verified when Amazon SES detects these records in the DNS\nconfiguration for your domain. This verification method is known as [Easy DKIM](https://docs.aws.amazon.com/ses/latest/DeveloperGuide/easy-dkim.html).\n\nAlternatively, you can perform the verification process by providing your own\npublic-private key pair. This verification method is known as Bring Your Own\nDKIM (BYODKIM). To use BYODKIM, your call to the `CreateEmailIdentity` operation\nhas to include the `DkimSigningAttributes` object. When you specify this object,\nyou provide a selector (a component of the DNS record name that identifies the\npublic key to use for DKIM authentication) and a private key.\n\nWhen you verify a domain, this operation provides a set of DKIM tokens, which\nyou can convert into CNAME tokens. You add these CNAME tokens to the DNS\nconfiguration for your domain. Your domain is verified when Amazon SES detects\nthese records in the DNS configuration for your domain. For some DNS providers,\nit can take 72 hours or more to complete the domain verification process.\n\nAdditionally, you can associate an existing configuration set with the email\nidentity that you're verifying.","ref":"AWS.SESv2.html#create_email_identity/3","title":"AWS.SESv2.create_email_identity/3","type":"function"},{"doc":"Creates the specified sending authorization policy for the given identity (an\nemail address or a domain).\n\nThis API is for the identity owner only. If you have not verified the identity,\nthis API will return an error.\n\nSending authorization is a feature that enables an identity owner to authorize\nother senders to use its identities. For information about using sending\nauthorization, see the [Amazon SES Developer Guide](https://docs.aws.amazon.com/ses/latest/DeveloperGuide/sending-authorization.html).\n\nYou can execute this operation no more than once per second.","ref":"AWS.SESv2.html#create_email_identity_policy/5","title":"AWS.SESv2.create_email_identity_policy/5","type":"function"},{"doc":"Creates an email template.\n\nEmail templates enable you to send personalized email to one or more\ndestinations in a single API operation. For more information, see the [Amazon SES Developer\nGuide](https://docs.aws.amazon.com/ses/latest/DeveloperGuide/send-personalized-email-api.html).\n\nYou can execute this operation no more than once per second.","ref":"AWS.SESv2.html#create_email_template/3","title":"AWS.SESv2.create_email_template/3","type":"function"},{"doc":"Creates an export job for a data source and destination.\n\nYou can execute this operation no more than once per second.","ref":"AWS.SESv2.html#create_export_job/3","title":"AWS.SESv2.create_export_job/3","type":"function"},{"doc":"Creates an import job for a data destination.","ref":"AWS.SESv2.html#create_import_job/3","title":"AWS.SESv2.create_import_job/3","type":"function"},{"doc":"Delete an existing configuration set.\n\n*Configuration sets* are groups of rules that you can apply to the emails you\nsend. You apply a configuration set to an email by including a reference to the\nconfiguration set in the headers of the email. When you apply a configuration\nset to an email, all of the rules in that configuration set are applied to the\nemail.","ref":"AWS.SESv2.html#delete_configuration_set/4","title":"AWS.SESv2.delete_configuration_set/4","type":"function"},{"doc":"Delete an event destination.\n\n*Events* include message sends, deliveries, opens, clicks, bounces, and\ncomplaints. *Event destinations* are places that you can send information about\nthese events to. For example, you can send event data to Amazon SNS to receive\nnotifications when you receive bounces or complaints, or you can use Amazon\nKinesis Data Firehose to stream data to Amazon S3 for long-term storage.","ref":"AWS.SESv2.html#delete_configuration_set_event_destination/5","title":"AWS.SESv2.delete_configuration_set_event_destination/5","type":"function"},{"doc":"Removes a contact from a contact list.","ref":"AWS.SESv2.html#delete_contact/5","title":"AWS.SESv2.delete_contact/5","type":"function"},{"doc":"Deletes a contact list and all of the contacts on that list.","ref":"AWS.SESv2.html#delete_contact_list/4","title":"AWS.SESv2.delete_contact_list/4","type":"function"},{"doc":"Deletes an existing custom verification email template.\n\nFor more information about custom verification email templates, see [Using custom verification email\ntemplates](https://docs.aws.amazon.com/ses/latest/dg/creating-identities.html#send-email-verify-address-custom)\nin the *Amazon SES Developer Guide*.\n\nYou can execute this operation no more than once per second.","ref":"AWS.SESv2.html#delete_custom_verification_email_template/4","title":"AWS.SESv2.delete_custom_verification_email_template/4","type":"function"},{"doc":"Delete a dedicated IP pool.","ref":"AWS.SESv2.html#delete_dedicated_ip_pool/4","title":"AWS.SESv2.delete_dedicated_ip_pool/4","type":"function"},{"doc":"Deletes an email identity.\n\nAn identity can be either an email address or a domain name.","ref":"AWS.SESv2.html#delete_email_identity/4","title":"AWS.SESv2.delete_email_identity/4","type":"function"},{"doc":"Deletes the specified sending authorization policy for the given identity (an\nemail address or a domain).\n\nThis API returns successfully even if a policy with the specified name does not\nexist.\n\nThis API is for the identity owner only. If you have not verified the identity,\nthis API will return an error.\n\nSending authorization is a feature that enables an identity owner to authorize\nother senders to use its identities. For information about using sending\nauthorization, see the [Amazon SES Developer Guide](https://docs.aws.amazon.com/ses/latest/DeveloperGuide/sending-authorization.html).\n\nYou can execute this operation no more than once per second.","ref":"AWS.SESv2.html#delete_email_identity_policy/5","title":"AWS.SESv2.delete_email_identity_policy/5","type":"function"},{"doc":"Deletes an email template.\n\nYou can execute this operation no more than once per second.","ref":"AWS.SESv2.html#delete_email_template/4","title":"AWS.SESv2.delete_email_template/4","type":"function"},{"doc":"Removes an email address from the suppression list for your account.","ref":"AWS.SESv2.html#delete_suppressed_destination/4","title":"AWS.SESv2.delete_suppressed_destination/4","type":"function"},{"doc":"Obtain information about the email-sending status and capabilities of your\nAmazon SES account in the current Amazon Web Services Region.","ref":"AWS.SESv2.html#get_account/2","title":"AWS.SESv2.get_account/2","type":"function"},{"doc":"Retrieve a list of the blacklists that your dedicated IP addresses appear on.","ref":"AWS.SESv2.html#get_blacklist_reports/3","title":"AWS.SESv2.get_blacklist_reports/3","type":"function"},{"doc":"Get information about an existing configuration set, including the dedicated IP\npool that it's associated with, whether or not it's enabled for sending email,\nand more.\n\n*Configuration sets* are groups of rules that you can apply to the emails you\nsend. You apply a configuration set to an email by including a reference to the\nconfiguration set in the headers of the email. When you apply a configuration\nset to an email, all of the rules in that configuration set are applied to the\nemail.","ref":"AWS.SESv2.html#get_configuration_set/3","title":"AWS.SESv2.get_configuration_set/3","type":"function"},{"doc":"Retrieve a list of event destinations that are associated with a configuration\nset.\n\n*Events* include message sends, deliveries, opens, clicks, bounces, and\ncomplaints. *Event destinations* are places that you can send information about\nthese events to. For example, you can send event data to Amazon SNS to receive\nnotifications when you receive bounces or complaints, or you can use Amazon\nKinesis Data Firehose to stream data to Amazon S3 for long-term storage.","ref":"AWS.SESv2.html#get_configuration_set_event_destinations/3","title":"AWS.SESv2.get_configuration_set_event_destinations/3","type":"function"},{"doc":"Returns a contact from a contact list.","ref":"AWS.SESv2.html#get_contact/4","title":"AWS.SESv2.get_contact/4","type":"function"},{"doc":"Returns contact list metadata.\n\nIt does not return any information about the contacts present in the list.","ref":"AWS.SESv2.html#get_contact_list/3","title":"AWS.SESv2.get_contact_list/3","type":"function"},{"doc":"Returns the custom email verification template for the template name you\nspecify.\n\nFor more information about custom verification email templates, see [Using custom verification email\ntemplates](https://docs.aws.amazon.com/ses/latest/dg/creating-identities.html#send-email-verify-address-custom)\nin the *Amazon SES Developer Guide*.\n\nYou can execute this operation no more than once per second.","ref":"AWS.SESv2.html#get_custom_verification_email_template/3","title":"AWS.SESv2.get_custom_verification_email_template/3","type":"function"},{"doc":"Get information about a dedicated IP address, including the name of the\ndedicated IP pool that it's associated with, as well information about the\nautomatic warm-up process for the address.","ref":"AWS.SESv2.html#get_dedicated_ip/3","title":"AWS.SESv2.get_dedicated_ip/3","type":"function"},{"doc":"Retrieve information about the dedicated pool.","ref":"AWS.SESv2.html#get_dedicated_ip_pool/3","title":"AWS.SESv2.get_dedicated_ip_pool/3","type":"function"},{"doc":"List the dedicated IP addresses that are associated with your Amazon Web\nServices account.","ref":"AWS.SESv2.html#get_dedicated_ips/5","title":"AWS.SESv2.get_dedicated_ips/5","type":"function"},{"doc":"Retrieve information about the status of the Deliverability dashboard for your\naccount.\n\nWhen the Deliverability dashboard is enabled, you gain access to reputation,\ndeliverability, and other metrics for the domains that you use to send email.\nYou also gain the ability to perform predictive inbox placement tests.\n\nWhen you use the Deliverability dashboard, you pay a monthly subscription\ncharge, in addition to any other fees that you accrue by using Amazon SES and\nother Amazon Web Services services. For more information about the features and\ncost of a Deliverability dashboard subscription, see [Amazon SES Pricing](http://aws.amazon.com/ses/pricing/).","ref":"AWS.SESv2.html#get_deliverability_dashboard_options/2","title":"AWS.SESv2.get_deliverability_dashboard_options/2","type":"function"},{"doc":"Retrieve the results of a predictive inbox placement test.","ref":"AWS.SESv2.html#get_deliverability_test_report/3","title":"AWS.SESv2.get_deliverability_test_report/3","type":"function"},{"doc":"Retrieve all the deliverability data for a specific campaign.\n\nThis data is available for a campaign only if the campaign sent email by using a\ndomain that the Deliverability dashboard is enabled for.","ref":"AWS.SESv2.html#get_domain_deliverability_campaign/3","title":"AWS.SESv2.get_domain_deliverability_campaign/3","type":"function"},{"doc":"Retrieve inbox placement and engagement rates for the domains that you use to\nsend email.","ref":"AWS.SESv2.html#get_domain_statistics_report/5","title":"AWS.SESv2.get_domain_statistics_report/5","type":"function"},{"doc":"Provides information about a specific identity, including the identity's\nverification status, sending authorization policies, its DKIM authentication\nstatus, and its custom Mail-From settings.","ref":"AWS.SESv2.html#get_email_identity/3","title":"AWS.SESv2.get_email_identity/3","type":"function"},{"doc":"Returns the requested sending authorization policies for the given identity (an\nemail address or a domain).\n\nThe policies are returned as a map of policy names to policy contents. You can\nretrieve a maximum of 20 policies at a time.\n\nThis API is for the identity owner only. If you have not verified the identity,\nthis API will return an error.\n\nSending authorization is a feature that enables an identity owner to authorize\nother senders to use its identities. For information about using sending\nauthorization, see the [Amazon SES Developer Guide](https://docs.aws.amazon.com/ses/latest/DeveloperGuide/sending-authorization.html).\n\nYou can execute this operation no more than once per second.","ref":"AWS.SESv2.html#get_email_identity_policies/3","title":"AWS.SESv2.get_email_identity_policies/3","type":"function"},{"doc":"Displays the template object (which includes the subject line, HTML part and\ntext part) for the template you specify.\n\nYou can execute this operation no more than once per second.","ref":"AWS.SESv2.html#get_email_template/3","title":"AWS.SESv2.get_email_template/3","type":"function"},{"doc":"Provides information about an export job.","ref":"AWS.SESv2.html#get_export_job/3","title":"AWS.SESv2.get_export_job/3","type":"function"},{"doc":"Provides information about an import job.","ref":"AWS.SESv2.html#get_import_job/3","title":"AWS.SESv2.get_import_job/3","type":"function"},{"doc":"Provides information about a specific message, including the from address, the\nsubject, the recipient address, email tags, as well as events associated with\nthe message.\n\nYou can execute this operation no more than once per second.","ref":"AWS.SESv2.html#get_message_insights/3","title":"AWS.SESv2.get_message_insights/3","type":"function"},{"doc":"Retrieves information about a specific email address that's on the suppression\nlist for your account.","ref":"AWS.SESv2.html#get_suppressed_destination/3","title":"AWS.SESv2.get_suppressed_destination/3","type":"function"},{"doc":"List all of the configuration sets associated with your account in the current\nregion.\n\n*Configuration sets* are groups of rules that you can apply to the emails you\nsend. You apply a configuration set to an email by including a reference to the\nconfiguration set in the headers of the email. When you apply a configuration\nset to an email, all of the rules in that configuration set are applied to the\nemail.","ref":"AWS.SESv2.html#list_configuration_sets/4","title":"AWS.SESv2.list_configuration_sets/4","type":"function"},{"doc":"Lists all of the contact lists available.","ref":"AWS.SESv2.html#list_contact_lists/4","title":"AWS.SESv2.list_contact_lists/4","type":"function"},{"doc":"Lists the contacts present in a specific contact list.","ref":"AWS.SESv2.html#list_contacts/5","title":"AWS.SESv2.list_contacts/5","type":"function"},{"doc":"Lists the existing custom verification email templates for your account in the\ncurrent Amazon Web Services Region.\n\nFor more information about custom verification email templates, see [Using custom verification email\ntemplates](https://docs.aws.amazon.com/ses/latest/dg/creating-identities.html#send-email-verify-address-custom)\nin the *Amazon SES Developer Guide*.\n\nYou can execute this operation no more than once per second.","ref":"AWS.SESv2.html#list_custom_verification_email_templates/4","title":"AWS.SESv2.list_custom_verification_email_templates/4","type":"function"},{"doc":"List all of the dedicated IP pools that exist in your Amazon Web Services\naccount in the current Region.","ref":"AWS.SESv2.html#list_dedicated_ip_pools/4","title":"AWS.SESv2.list_dedicated_ip_pools/4","type":"function"},{"doc":"Show a list of the predictive inbox placement tests that you've performed,\nregardless of their statuses.\n\nFor predictive inbox placement tests that are complete, you can use the\n`GetDeliverabilityTestReport` operation to view the results.","ref":"AWS.SESv2.html#list_deliverability_test_reports/4","title":"AWS.SESv2.list_deliverability_test_reports/4","type":"function"},{"doc":"Retrieve deliverability data for all the campaigns that used a specific domain\nto send email during a specified time range.\n\nThis data is available for a domain only if you enabled the Deliverability\ndashboard for the domain.","ref":"AWS.SESv2.html#list_domain_deliverability_campaigns/7","title":"AWS.SESv2.list_domain_deliverability_campaigns/7","type":"function"},{"doc":"Returns a list of all of the email identities that are associated with your\nAmazon Web Services account.\n\nAn identity can be either an email address or a domain. This operation returns\nidentities that are verified as well as those that aren't. This operation\nreturns identities that are associated with Amazon SES and Amazon Pinpoint.","ref":"AWS.SESv2.html#list_email_identities/4","title":"AWS.SESv2.list_email_identities/4","type":"function"},{"doc":"Lists the email templates present in your Amazon SES account in the current\nAmazon Web Services Region.\n\nYou can execute this operation no more than once per second.","ref":"AWS.SESv2.html#list_email_templates/4","title":"AWS.SESv2.list_email_templates/4","type":"function"},{"doc":"Lists all of the export jobs.","ref":"AWS.SESv2.html#list_export_jobs/3","title":"AWS.SESv2.list_export_jobs/3","type":"function"},{"doc":"Lists all of the import jobs.","ref":"AWS.SESv2.html#list_import_jobs/4","title":"AWS.SESv2.list_import_jobs/4","type":"function"},{"doc":"Lists the recommendations present in your Amazon SES account in the current\nAmazon Web Services Region.\n\nYou can execute this operation no more than once per second.","ref":"AWS.SESv2.html#list_recommendations/3","title":"AWS.SESv2.list_recommendations/3","type":"function"},{"doc":"Retrieves a list of email addresses that are on the suppression list for your\naccount.","ref":"AWS.SESv2.html#list_suppressed_destinations/7","title":"AWS.SESv2.list_suppressed_destinations/7","type":"function"},{"doc":"Retrieve a list of the tags (keys and values) that are associated with a\nspecified resource.\n\nA *tag* is a label that you optionally define and associate with a resource.\nEach tag consists of a required *tag key* and an optional associated *tag\nvalue*. A tag key is a general label that acts as a category for more specific\ntag values. A tag value acts as a descriptor within a tag key.","ref":"AWS.SESv2.html#list_tags_for_resource/3","title":"AWS.SESv2.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.SESv2.html#metadata/0","title":"AWS.SESv2.metadata/0","type":"function"},{"doc":"Enable or disable the automatic warm-up feature for dedicated IP addresses.","ref":"AWS.SESv2.html#put_account_dedicated_ip_warmup_attributes/3","title":"AWS.SESv2.put_account_dedicated_ip_warmup_attributes/3","type":"function"},{"doc":"Update your Amazon SES account details.","ref":"AWS.SESv2.html#put_account_details/3","title":"AWS.SESv2.put_account_details/3","type":"function"},{"doc":"Enable or disable the ability of your account to send email.","ref":"AWS.SESv2.html#put_account_sending_attributes/3","title":"AWS.SESv2.put_account_sending_attributes/3","type":"function"},{"doc":"Change the settings for the account-level suppression list.","ref":"AWS.SESv2.html#put_account_suppression_attributes/3","title":"AWS.SESv2.put_account_suppression_attributes/3","type":"function"},{"doc":"Update your Amazon SES account VDM attributes.\n\nYou can execute this operation no more than once per second.","ref":"AWS.SESv2.html#put_account_vdm_attributes/3","title":"AWS.SESv2.put_account_vdm_attributes/3","type":"function"},{"doc":"Associate a configuration set with a dedicated IP pool.\n\nYou can use dedicated IP pools to create groups of dedicated IP addresses for\nsending specific types of email.","ref":"AWS.SESv2.html#put_configuration_set_delivery_options/4","title":"AWS.SESv2.put_configuration_set_delivery_options/4","type":"function"},{"doc":"Enable or disable collection of reputation metrics for emails that you send\nusing a particular configuration set in a specific Amazon Web Services Region.","ref":"AWS.SESv2.html#put_configuration_set_reputation_options/4","title":"AWS.SESv2.put_configuration_set_reputation_options/4","type":"function"},{"doc":"Enable or disable email sending for messages that use a particular configuration\nset in a specific Amazon Web Services Region.","ref":"AWS.SESv2.html#put_configuration_set_sending_options/4","title":"AWS.SESv2.put_configuration_set_sending_options/4","type":"function"},{"doc":"Specify the account suppression list preferences for a configuration set.","ref":"AWS.SESv2.html#put_configuration_set_suppression_options/4","title":"AWS.SESv2.put_configuration_set_suppression_options/4","type":"function"},{"doc":"Specify a custom domain to use for open and click tracking elements in email\nthat you send.","ref":"AWS.SESv2.html#put_configuration_set_tracking_options/4","title":"AWS.SESv2.put_configuration_set_tracking_options/4","type":"function"},{"doc":"Specify VDM preferences for email that you send using the configuration set.\n\nYou can execute this operation no more than once per second.","ref":"AWS.SESv2.html#put_configuration_set_vdm_options/4","title":"AWS.SESv2.put_configuration_set_vdm_options/4","type":"function"},{"doc":"Move a dedicated IP address to an existing dedicated IP pool.\n\nThe dedicated IP address that you specify must already exist, and must be\nassociated with your Amazon Web Services account.\n\nThe dedicated IP pool you specify must already exist. You can create a new pool\nby using the `CreateDedicatedIpPool` operation.","ref":"AWS.SESv2.html#put_dedicated_ip_in_pool/4","title":"AWS.SESv2.put_dedicated_ip_in_pool/4","type":"function"},{"doc":"Used to convert a dedicated IP pool to a different scaling mode.\n\n`MANAGED` pools cannot be converted to `STANDARD` scaling mode.","ref":"AWS.SESv2.html#put_dedicated_ip_pool_scaling_attributes/4","title":"AWS.SESv2.put_dedicated_ip_pool_scaling_attributes/4","type":"function"},{"doc":"","ref":"AWS.SESv2.html#put_dedicated_ip_warmup_attributes/4","title":"AWS.SESv2.put_dedicated_ip_warmup_attributes/4","type":"function"},{"doc":"Enable or disable the Deliverability dashboard.\n\nWhen you enable the Deliverability dashboard, you gain access to reputation,\ndeliverability, and other metrics for the domains that you use to send email.\nYou also gain the ability to perform predictive inbox placement tests.\n\nWhen you use the Deliverability dashboard, you pay a monthly subscription\ncharge, in addition to any other fees that you accrue by using Amazon SES and\nother Amazon Web Services services. For more information about the features and\ncost of a Deliverability dashboard subscription, see [Amazon SES Pricing](http://aws.amazon.com/ses/pricing/).","ref":"AWS.SESv2.html#put_deliverability_dashboard_option/3","title":"AWS.SESv2.put_deliverability_dashboard_option/3","type":"function"},{"doc":"Used to associate a configuration set with an email identity.","ref":"AWS.SESv2.html#put_email_identity_configuration_set_attributes/4","title":"AWS.SESv2.put_email_identity_configuration_set_attributes/4","type":"function"},{"doc":"Used to enable or disable DKIM authentication for an email identity.","ref":"AWS.SESv2.html#put_email_identity_dkim_attributes/4","title":"AWS.SESv2.put_email_identity_dkim_attributes/4","type":"function"},{"doc":"Used to configure or change the DKIM authentication settings for an email domain\nidentity.\n\nYou can use this operation to do any of the following:\n\n  * Update the signing attributes for an identity that uses Bring Your\nOwn DKIM (BYODKIM).\n\n  * Update the key length that should be used for Easy DKIM.\n\n  * Change from using no DKIM authentication to using Easy DKIM.\n\n  * Change from using no DKIM authentication to using BYODKIM.\n\n  * Change from using Easy DKIM to using BYODKIM.\n\n  * Change from using BYODKIM to using Easy DKIM.","ref":"AWS.SESv2.html#put_email_identity_dkim_signing_attributes/4","title":"AWS.SESv2.put_email_identity_dkim_signing_attributes/4","type":"function"},{"doc":"Used to enable or disable feedback forwarding for an identity.\n\nThis setting determines what happens when an identity is used to send an email\nthat results in a bounce or complaint event.\n\nIf the value is `true`, you receive email notifications when bounce or complaint\nevents occur. These notifications are sent to the address that you specified in\nthe `Return-Path` header of the original email.\n\nYou're required to have a method of tracking bounces and complaints. If you\nhaven't set up another mechanism for receiving bounce or complaint notifications\n(for example, by setting up an event destination), you receive an email\nnotification when these events occur (even if this setting is disabled).","ref":"AWS.SESv2.html#put_email_identity_feedback_attributes/4","title":"AWS.SESv2.put_email_identity_feedback_attributes/4","type":"function"},{"doc":"Used to enable or disable the custom Mail-From domain configuration for an email\nidentity.","ref":"AWS.SESv2.html#put_email_identity_mail_from_attributes/4","title":"AWS.SESv2.put_email_identity_mail_from_attributes/4","type":"function"},{"doc":"Adds an email address to the suppression list for your account.","ref":"AWS.SESv2.html#put_suppressed_destination/3","title":"AWS.SESv2.put_suppressed_destination/3","type":"function"},{"doc":"Composes an email message to multiple destinations.","ref":"AWS.SESv2.html#send_bulk_email/3","title":"AWS.SESv2.send_bulk_email/3","type":"function"},{"doc":"Adds an email address to the list of identities for your Amazon SES account in\nthe current Amazon Web Services Region and attempts to verify it.\n\nAs a result of executing this operation, a customized verification email is sent\nto the specified address.\n\nTo use this operation, you must first create a custom verification email\ntemplate. For more information about creating and using custom verification\nemail templates, see [Using custom verification email templates](https://docs.aws.amazon.com/ses/latest/dg/creating-identities.html#send-email-verify-address-custom)\nin the *Amazon SES Developer Guide*.\n\nYou can execute this operation no more than once per second.","ref":"AWS.SESv2.html#send_custom_verification_email/3","title":"AWS.SESv2.send_custom_verification_email/3","type":"function"},{"doc":"Sends an email message.\n\nYou can use the Amazon SES API v2 to send the following types of messages:\n\n  * **Simple** – A standard email message. When you create this type\nof message, you specify the sender, the recipient, and the message body, and\nAmazon SES assembles the message for you.\n\n  * **Raw** – A raw, MIME-formatted email message. When you send this\ntype of email, you have to specify all of the message headers, as well as the\nmessage body. You can use this message type to send messages that contain\nattachments. The message that you specify has to be a valid MIME message.\n\n  * **Templated** – A message that contains personalization tags. When\nyou send this type of email, Amazon SES API v2 automatically replaces the tags\nwith values that you specify.","ref":"AWS.SESv2.html#send_email/3","title":"AWS.SESv2.send_email/3","type":"function"},{"doc":"Add one or more tags (keys and values) to a specified resource.\n\nA *tag* is a label that you optionally define and associate with a resource.\nTags can help you categorize and manage resources in different ways, such as by\npurpose, owner, environment, or other criteria. A resource can have as many as\n50 tags.\n\nEach tag consists of a required *tag key* and an associated *tag value*, both of\nwhich you define. A tag key is a general label that acts as a category for more\nspecific tag values. A tag value acts as a descriptor within a tag key.","ref":"AWS.SESv2.html#tag_resource/3","title":"AWS.SESv2.tag_resource/3","type":"function"},{"doc":"Creates a preview of the MIME content of an email when provided with a template\nand a set of replacement data.\n\nYou can execute this operation no more than once per second.","ref":"AWS.SESv2.html#test_render_email_template/4","title":"AWS.SESv2.test_render_email_template/4","type":"function"},{"doc":"Remove one or more tags (keys and values) from a specified resource.","ref":"AWS.SESv2.html#untag_resource/3","title":"AWS.SESv2.untag_resource/3","type":"function"},{"doc":"Update the configuration of an event destination for a configuration set.\n\n*Events* include message sends, deliveries, opens, clicks, bounces, and\ncomplaints. *Event destinations* are places that you can send information about\nthese events to. For example, you can send event data to Amazon SNS to receive\nnotifications when you receive bounces or complaints, or you can use Amazon\nKinesis Data Firehose to stream data to Amazon S3 for long-term storage.","ref":"AWS.SESv2.html#update_configuration_set_event_destination/5","title":"AWS.SESv2.update_configuration_set_event_destination/5","type":"function"},{"doc":"Updates a contact's preferences for a list.\n\nIt is not necessary to specify all existing topic preferences in the\nTopicPreferences object, just the ones that need updating.","ref":"AWS.SESv2.html#update_contact/5","title":"AWS.SESv2.update_contact/5","type":"function"},{"doc":"Updates contact list metadata.\n\nThis operation does a complete replacement.","ref":"AWS.SESv2.html#update_contact_list/4","title":"AWS.SESv2.update_contact_list/4","type":"function"},{"doc":"Updates an existing custom verification email template.\n\nFor more information about custom verification email templates, see [Using custom verification email\ntemplates](https://docs.aws.amazon.com/ses/latest/dg/creating-identities.html#send-email-verify-address-custom)\nin the *Amazon SES Developer Guide*.\n\nYou can execute this operation no more than once per second.","ref":"AWS.SESv2.html#update_custom_verification_email_template/4","title":"AWS.SESv2.update_custom_verification_email_template/4","type":"function"},{"doc":"Updates the specified sending authorization policy for the given identity (an\nemail address or a domain).\n\nThis API returns successfully even if a policy with the specified name does not\nexist.\n\nThis API is for the identity owner only. If you have not verified the identity,\nthis API will return an error.\n\nSending authorization is a feature that enables an identity owner to authorize\nother senders to use its identities. For information about using sending\nauthorization, see the [Amazon SES Developer Guide](https://docs.aws.amazon.com/ses/latest/DeveloperGuide/sending-authorization.html).\n\nYou can execute this operation no more than once per second.","ref":"AWS.SESv2.html#update_email_identity_policy/5","title":"AWS.SESv2.update_email_identity_policy/5","type":"function"},{"doc":"Updates an email template.\n\nEmail templates enable you to send personalized email to one or more\ndestinations in a single API operation. For more information, see the [Amazon SES Developer\nGuide](https://docs.aws.amazon.com/ses/latest/DeveloperGuide/send-personalized-email-api.html).\n\nYou can execute this operation no more than once per second.","ref":"AWS.SESv2.html#update_email_template/4","title":"AWS.SESv2.update_email_template/4","type":"function"},{"doc":"Step Functions\n\nStep Functions is a service that lets you coordinate the components of\ndistributed applications and microservices using visual workflows.\n\nYou can use Step Functions to build applications from individual components,\neach of which performs a discrete function, or *task*, allowing you to scale and\nchange applications quickly. Step Functions provides a console that helps\nvisualize the components of your application as a series of steps. Step\nFunctions automatically triggers and tracks each step, and retries steps when\nthere are errors, so your application executes predictably and in the right\norder every time. Step Functions logs the state of each step, so you can quickly\ndiagnose and debug any issues.\n\nStep Functions manages operations and underlying infrastructure to ensure your\napplication is available at any scale. You can run tasks on Amazon Web Services,\nyour own servers, or any system that has access to Amazon Web Services. You can\naccess and use Step Functions using the console, the Amazon Web Services SDKs,\nor an HTTP API. For more information about Step Functions, see the * [Step Functions Developer\nGuide](https://docs.aws.amazon.com/step-functions/latest/dg/welcome.html) *.\n\nIf you use the Step Functions API actions using Amazon Web Services SDK\nintegrations, make sure the API actions are in camel case and parameter names\nare in Pascal case. For example, you could use Step Functions API action\n`startSyncExecution` and specify its parameter as `StateMachineArn`.","ref":"AWS.SFN.html","title":"AWS.SFN","type":"module"},{"doc":"Creates an activity.\n\nAn activity is a task that you write in any programming language and host on any\nmachine that has access to Step Functions. Activities must poll Step Functions\nusing the `GetActivityTask` API action and respond using `SendTask*` API\nactions. This function lets Step Functions know the existence of your activity\nand returns an identifier for use in a state machine and when polling from the\nactivity.\n\nThis operation is eventually consistent. The results are best effort and may not\nreflect very recent updates and changes.\n\n`CreateActivity` is an idempotent API. Subsequent requests won’t create a\nduplicate resource if it was already created. `CreateActivity`'s idempotency\ncheck is based on the activity `name`. If a following request has different\n`tags` values, Step Functions will ignore these differences and treat it as an\nidempotent request of the previous. In this case, `tags` will not be updated,\neven if they are different.","ref":"AWS.SFN.html#create_activity/3","title":"AWS.SFN.create_activity/3","type":"function"},{"doc":"Creates a state machine.\n\nA state machine consists of a collection of states that can do work (`Task`\nstates), determine to which states to transition next (`Choice` states), stop an\nexecution with an error (`Fail` states), and so on. State machines are specified\nusing a JSON-based, structured language. For more information, see [Amazon States\nLanguage](https://docs.aws.amazon.com/step-functions/latest/dg/concepts-amazon-states-language.html)\nin the Step Functions User Guide.\n\nIf you set the `publish` parameter of this API action to `true`, it publishes\nversion `1` as the first revision of the state machine.\n\nThis operation is eventually consistent. The results are best effort and may not\nreflect very recent updates and changes.\n\n`CreateStateMachine` is an idempotent API. Subsequent requests won’t create a\nduplicate resource if it was already created. `CreateStateMachine`'s idempotency\ncheck is based on the state machine `name`, `definition`, `type`,\n`LoggingConfiguration`, and `TracingConfiguration`. The check is also based on\nthe `publish` and `versionDescription` parameters. If a following request has a\ndifferent `roleArn` or `tags`, Step Functions will ignore these differences and\ntreat it as an idempotent request of the previous. In this case, `roleArn` and\n`tags` will not be updated, even if they are different.","ref":"AWS.SFN.html#create_state_machine/3","title":"AWS.SFN.create_state_machine/3","type":"function"},{"doc":"Creates an\n[alias](https://docs.aws.amazon.com/step-functions/latest/dg/concepts-state-machine-alias.html) for a state machine that points to one or two\n[versions](https://docs.aws.amazon.com/step-functions/latest/dg/concepts-state-machine-version.html)\nof the same state machine.\n\nYou can set your application to call `StartExecution` with an alias and update\nthe version the alias uses without changing the client's code.\n\nYou can also map an alias to split `StartExecution` requests between two\nversions of a state machine. To do this, add a second `RoutingConfig` object in\nthe `routingConfiguration` parameter. You must also specify the percentage of\nexecution run requests each version should receive in both `RoutingConfig`\nobjects. Step Functions randomly chooses which version runs a given execution\nbased on the percentage you specify.\n\nTo create an alias that points to a single version, specify a single\n`RoutingConfig` object with a `weight` set to 100.\n\nYou can create up to 100 aliases for each state machine. You must delete unused\naliases using the `DeleteStateMachineAlias` API action.\n\n`CreateStateMachineAlias` is an idempotent API. Step Functions bases the\nidempotency check on the `stateMachineArn`, `description`, `name`, and\n`routingConfiguration` parameters. Requests that contain the same values for\nthese parameters return a successful idempotent response without creating a\nduplicate resource.","ref":"AWS.SFN.html#create_state_machine_alias/3","title":"AWS.SFN.create_state_machine_alias/3","type":"function"},{"doc":"* `DescribeStateMachineAlias`\n\n  * `ListStateMachineAliases`\n\n  * `UpdateStateMachineAlias`\n\n  * `DeleteStateMachineAlias`","ref":"AWS.SFN.html#create_state_machine_alias/3-related-operations","title":"Related operations: - AWS.SFN.create_state_machine_alias/3","type":"function"},{"doc":"Deletes an activity.","ref":"AWS.SFN.html#delete_activity/3","title":"AWS.SFN.delete_activity/3","type":"function"},{"doc":"Deletes a state machine.\n\nThis is an asynchronous operation. It sets the state machine's status to\n`DELETING` and begins the deletion process. A state machine is deleted only when\nall its executions are completed. On the next state transition, the state\nmachine's executions are terminated.\n\nA qualified state machine ARN can either refer to a *Distributed Map state*\ndefined within a state machine, a version ARN, or an alias ARN.\n\nThe following are some examples of qualified and unqualified state machine ARNs:\n\n  * The following qualified state machine ARN refers to a *Distributed\nMap state* with a label `mapStateLabel` in a state machine named\n`myStateMachine`.\n\n`arn:partition:states:region:account-id:stateMachine:myStateMachine/mapStateLabel`\n\nIf you provide a qualified state machine ARN that refers to a *Distributed Map\nstate*, the request fails with `ValidationException`.\n\n  * The following unqualified state machine ARN refers to a state\nmachine named `myStateMachine`.\n\n`arn:partition:states:region:account-id:stateMachine:myStateMachine`\n\nThis API action also deletes all\n[versions](https://docs.aws.amazon.com/step-functions/latest/dg/concepts-state-machine-version.html) and\n[aliases](https://docs.aws.amazon.com/step-functions/latest/dg/concepts-state-machine-alias.html)\nassociated with a state machine.\n\nFor `EXPRESS` state machines, the deletion happens eventually (usually in less\nthan a minute). Running executions may emit logs after `DeleteStateMachine` API\nis called.","ref":"AWS.SFN.html#delete_state_machine/3","title":"AWS.SFN.delete_state_machine/3","type":"function"},{"doc":"Deletes a state machine\n[alias](https://docs.aws.amazon.com/step-functions/latest/dg/concepts-state-machine-alias.html).\n\nAfter you delete a state machine alias, you can't use it to start executions.\nWhen you delete a state machine alias, Step Functions doesn't delete the state\nmachine versions that alias references.","ref":"AWS.SFN.html#delete_state_machine_alias/3","title":"AWS.SFN.delete_state_machine_alias/3","type":"function"},{"doc":"* `CreateStateMachineAlias`\n\n  * `DescribeStateMachineAlias`\n\n  * `ListStateMachineAliases`\n\n  * `UpdateStateMachineAlias`","ref":"AWS.SFN.html#delete_state_machine_alias/3-related-operations","title":"Related operations: - AWS.SFN.delete_state_machine_alias/3","type":"function"},{"doc":"Deletes a state machine\n[version](https://docs.aws.amazon.com/step-functions/latest/dg/concepts-state-machine-version.html).  After you delete a version, you can't call `StartExecution` using that version's\nARN or use the version with a state machine\n[alias](https://docs.aws.amazon.com/step-functions/latest/dg/concepts-state-machine-alias.html).\n\nDeleting a state machine version won't terminate its in-progress executions.\n\nYou can't delete a state machine version currently referenced by one or more\naliases. Before you delete a version, you must either delete the aliases or\nupdate them to point to another state machine version.","ref":"AWS.SFN.html#delete_state_machine_version/3","title":"AWS.SFN.delete_state_machine_version/3","type":"function"},{"doc":"* `PublishStateMachineVersion`\n\n  * `ListStateMachineVersions`","ref":"AWS.SFN.html#delete_state_machine_version/3-related-operations","title":"Related operations: - AWS.SFN.delete_state_machine_version/3","type":"function"},{"doc":"Describes an activity.\n\nThis operation is eventually consistent. The results are best effort and may not\nreflect very recent updates and changes.","ref":"AWS.SFN.html#describe_activity/3","title":"AWS.SFN.describe_activity/3","type":"function"},{"doc":"Provides information about a state machine execution, such as the state machine\nassociated with the execution, the execution input and output, and relevant\nexecution metadata.\n\nIf you've\n[redriven](https://docs.aws.amazon.com/step-functions/latest/dg/redrive-executions.html)\nan execution, you can use this API action to return information about the\nredrives of that execution. In addition, you can use this API action to return\nthe Map Run Amazon Resource Name (ARN) if the execution was dispatched by a Map\nRun.\n\nIf you specify a version or alias ARN when you call the `StartExecution` API\naction, `DescribeExecution` returns that ARN.\n\nThis operation is eventually consistent. The results are best effort and may not\nreflect very recent updates and changes.\n\nExecutions of an `EXPRESS` state machine aren't supported by `DescribeExecution`\nunless a Map Run dispatched them.","ref":"AWS.SFN.html#describe_execution/3","title":"AWS.SFN.describe_execution/3","type":"function"},{"doc":"Provides information about a Map Run's configuration, progress, and results.\n\nIf you've\n[redriven](https://docs.aws.amazon.com/step-functions/latest/dg/redrive-map-run.html) a Map Run, this API action also returns information about the redrives of that\nMap Run. For more information, see [Examining Map\nRun](https://docs.aws.amazon.com/step-functions/latest/dg/concepts-examine-map-run.html)\nin the *Step Functions Developer Guide*.","ref":"AWS.SFN.html#describe_map_run/3","title":"AWS.SFN.describe_map_run/3","type":"function"},{"doc":"Provides information about a state machine's definition, its IAM role Amazon\nResource Name (ARN), and configuration.\n\nA qualified state machine ARN can either refer to a *Distributed Map state*\ndefined within a state machine, a version ARN, or an alias ARN.\n\nThe following are some examples of qualified and unqualified state machine ARNs:\n\n  * The following qualified state machine ARN refers to a *Distributed\nMap state* with a label `mapStateLabel` in a state machine named\n`myStateMachine`.\n\n`arn:partition:states:region:account-id:stateMachine:myStateMachine/mapStateLabel`\n\nIf you provide a qualified state machine ARN that refers to a *Distributed Map\nstate*, the request fails with `ValidationException`.\n\n  * The following qualified state machine ARN refers to an alias named\n`PROD`.\n\n`arn: :states: : :stateMachine: `\n\nIf you provide a qualified state machine ARN that refers to a version ARN or an\nalias ARN, the request starts execution for that version or alias.\n\n  * The following unqualified state machine ARN refers to a state\nmachine named `myStateMachine`.\n\n`arn: :states: : :stateMachine: `\n\nThis API action returns the details for a state machine version if the\n`stateMachineArn` you specify is a state machine version ARN.\n\nThis operation is eventually consistent. The results are best effort and may not\nreflect very recent updates and changes.","ref":"AWS.SFN.html#describe_state_machine/3","title":"AWS.SFN.describe_state_machine/3","type":"function"},{"doc":"Returns details about a state machine\n[alias](https://docs.aws.amazon.com/step-functions/latest/dg/concepts-state-machine-alias.html).","ref":"AWS.SFN.html#describe_state_machine_alias/3","title":"AWS.SFN.describe_state_machine_alias/3","type":"function"},{"doc":"* `CreateStateMachineAlias`\n\n  * `ListStateMachineAliases`\n\n  * `UpdateStateMachineAlias`\n\n  * `DeleteStateMachineAlias`","ref":"AWS.SFN.html#describe_state_machine_alias/3-related-operations","title":"Related operations: - AWS.SFN.describe_state_machine_alias/3","type":"function"},{"doc":"Provides information about a state machine's definition, its execution role ARN,\nand configuration.\n\nIf a Map Run dispatched the execution, this action returns the Map Run Amazon\nResource Name (ARN) in the response. The state machine returned is the state\nmachine associated with the Map Run.\n\nThis operation is eventually consistent. The results are best effort and may not\nreflect very recent updates and changes.\n\nThis API action is not supported by `EXPRESS` state machines.","ref":"AWS.SFN.html#describe_state_machine_for_execution/3","title":"AWS.SFN.describe_state_machine_for_execution/3","type":"function"},{"doc":"Used by workers to retrieve a task (with the specified activity ARN) which has\nbeen scheduled for execution by a running state machine.\n\nThis initiates a long poll, where the service holds the HTTP connection open and\nresponds as soon as a task becomes available (i.e. an execution of a task of\nthis type is needed.) The maximum time the service holds on to the request\nbefore responding is 60 seconds. If no task is available within 60 seconds, the\npoll returns a `taskToken` with a null string.\n\nThis API action isn't logged in CloudTrail.\n\nWorkers should set their client side socket timeout to at least 65 seconds (5\nseconds higher than the maximum time the service may hold the poll request).\n\nPolling with `GetActivityTask` can cause latency in some implementations. See\n[Avoid Latency When Polling for Activity Tasks](https://docs.aws.amazon.com/step-functions/latest/dg/bp-activity-pollers.html)\nin the Step Functions Developer Guide.","ref":"AWS.SFN.html#get_activity_task/3","title":"AWS.SFN.get_activity_task/3","type":"function"},{"doc":"Returns the history of the specified execution as a list of events.\n\nBy default, the results are returned in ascending order of the `timeStamp` of\nthe events. Use the `reverseOrder` parameter to get the latest events first.\n\nIf `nextToken` is returned, there are more results available. The value of\n`nextToken` is a unique pagination token for each page. Make the call again\nusing the returned token to retrieve the next page. Keep all other arguments\nunchanged. Each pagination token expires after 24 hours. Using an expired\npagination token will return an *HTTP 400 InvalidToken* error.\n\nThis API action is not supported by `EXPRESS` state machines.","ref":"AWS.SFN.html#get_execution_history/3","title":"AWS.SFN.get_execution_history/3","type":"function"},{"doc":"Lists the existing activities.\n\nIf `nextToken` is returned, there are more results available. The value of\n`nextToken` is a unique pagination token for each page. Make the call again\nusing the returned token to retrieve the next page. Keep all other arguments\nunchanged. Each pagination token expires after 24 hours. Using an expired\npagination token will return an *HTTP 400 InvalidToken* error.\n\nThis operation is eventually consistent. The results are best effort and may not\nreflect very recent updates and changes.","ref":"AWS.SFN.html#list_activities/3","title":"AWS.SFN.list_activities/3","type":"function"},{"doc":"Lists all executions of a state machine or a Map Run.\n\nYou can list all executions related to a state machine by specifying a state\nmachine Amazon Resource Name (ARN), or those related to a Map Run by specifying\na Map Run ARN. Using this API action, you can also list all\n[redriven](https://docs.aws.amazon.com/step-functions/latest/dg/redrive-executions.html) executions.\n\nYou can also provide a state machine\n[alias](https://docs.aws.amazon.com/step-functions/latest/dg/concepts-state-machine-alias.html)\nARN or\n[version](https://docs.aws.amazon.com/step-functions/latest/dg/concepts-state-machine-version.html)\nARN to list the executions associated with a specific alias or version.\n\nResults are sorted by time, with the most recent execution first.\n\nIf `nextToken` is returned, there are more results available. The value of\n`nextToken` is a unique pagination token for each page. Make the call again\nusing the returned token to retrieve the next page. Keep all other arguments\nunchanged. Each pagination token expires after 24 hours. Using an expired\npagination token will return an *HTTP 400 InvalidToken* error.\n\nThis operation is eventually consistent. The results are best effort and may not\nreflect very recent updates and changes.\n\nThis API action is not supported by `EXPRESS` state machines.","ref":"AWS.SFN.html#list_executions/3","title":"AWS.SFN.list_executions/3","type":"function"},{"doc":"Lists all Map Runs that were started by a given state machine execution.\n\nUse this API action to obtain Map Run ARNs, and then call `DescribeMapRun` to\nobtain more information, if needed.","ref":"AWS.SFN.html#list_map_runs/3","title":"AWS.SFN.list_map_runs/3","type":"function"},{"doc":"Lists\n[aliases](https://docs.aws.amazon.com/step-functions/latest/dg/concepts-state-machine-alias.html) for a specified state machine ARN.\n\nResults are sorted by time, with the most recently created aliases listed first.\n\nTo list aliases that reference a state machine\n[version](https://docs.aws.amazon.com/step-functions/latest/dg/concepts-state-machine-version.html),\nyou can specify the version ARN in the `stateMachineArn` parameter.\n\nIf `nextToken` is returned, there are more results available. The value of\n`nextToken` is a unique pagination token for each page. Make the call again\nusing the returned token to retrieve the next page. Keep all other arguments\nunchanged. Each pagination token expires after 24 hours. Using an expired\npagination token will return an *HTTP 400 InvalidToken* error.","ref":"AWS.SFN.html#list_state_machine_aliases/3","title":"AWS.SFN.list_state_machine_aliases/3","type":"function"},{"doc":"* `CreateStateMachineAlias`\n\n  * `DescribeStateMachineAlias`\n\n  * `UpdateStateMachineAlias`\n\n  * `DeleteStateMachineAlias`","ref":"AWS.SFN.html#list_state_machine_aliases/3-related-operations","title":"Related operations: - AWS.SFN.list_state_machine_aliases/3","type":"function"},{"doc":"Lists\n[versions](https://docs.aws.amazon.com/step-functions/latest/dg/concepts-state-machine-version.html)\nfor the specified state machine Amazon Resource Name (ARN).\n\nThe results are sorted in descending order of the version creation time.\n\nIf `nextToken` is returned, there are more results available. The value of\n`nextToken` is a unique pagination token for each page. Make the call again\nusing the returned token to retrieve the next page. Keep all other arguments\nunchanged. Each pagination token expires after 24 hours. Using an expired\npagination token will return an *HTTP 400 InvalidToken* error.","ref":"AWS.SFN.html#list_state_machine_versions/3","title":"AWS.SFN.list_state_machine_versions/3","type":"function"},{"doc":"* `PublishStateMachineVersion`\n\n  * `DeleteStateMachineVersion`","ref":"AWS.SFN.html#list_state_machine_versions/3-related-operations","title":"Related operations: - AWS.SFN.list_state_machine_versions/3","type":"function"},{"doc":"Lists the existing state machines.\n\nIf `nextToken` is returned, there are more results available. The value of\n`nextToken` is a unique pagination token for each page. Make the call again\nusing the returned token to retrieve the next page. Keep all other arguments\nunchanged. Each pagination token expires after 24 hours. Using an expired\npagination token will return an *HTTP 400 InvalidToken* error.\n\nThis operation is eventually consistent. The results are best effort and may not\nreflect very recent updates and changes.","ref":"AWS.SFN.html#list_state_machines/3","title":"AWS.SFN.list_state_machines/3","type":"function"},{"doc":"List tags for a given resource.\n\nTags may only contain Unicode letters, digits, white space, or these symbols: `_\n. : / = + - @`.","ref":"AWS.SFN.html#list_tags_for_resource/3","title":"AWS.SFN.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.SFN.html#metadata/0","title":"AWS.SFN.metadata/0","type":"function"},{"doc":"Creates a\n[version](https://docs.aws.amazon.com/step-functions/latest/dg/concepts-state-machine-version.html)\nfrom the current revision of a state machine.\n\nUse versions to create immutable snapshots of your state machine. You can start\nexecutions from versions either directly or with an alias. To create an alias,\nuse `CreateStateMachineAlias`.\n\nYou can publish up to 1000 versions for each state machine. You must manually\ndelete unused versions using the `DeleteStateMachineVersion` API action.\n\n`PublishStateMachineVersion` is an idempotent API. It doesn't create a duplicate\nstate machine version if it already exists for the current revision. Step\nFunctions bases `PublishStateMachineVersion`'s idempotency check on the\n`stateMachineArn`, `name`, and `revisionId` parameters. Requests with the same\nparameters return a successful idempotent response. If you don't specify a\n`revisionId`, Step Functions checks for a previously published version of the\nstate machine's current revision.","ref":"AWS.SFN.html#publish_state_machine_version/3","title":"AWS.SFN.publish_state_machine_version/3","type":"function"},{"doc":"* `DeleteStateMachineVersion`\n\n  * `ListStateMachineVersions`","ref":"AWS.SFN.html#publish_state_machine_version/3-related-operations","title":"Related operations: - AWS.SFN.publish_state_machine_version/3","type":"function"},{"doc":"Restarts unsuccessful executions of Standard workflows that didn't complete\nsuccessfully in the last 14 days.\n\nThese include failed, aborted, or timed out executions. When you\n[redrive](https://docs.aws.amazon.com/step-functions/latest/dg/redrive-executions.html) an execution, it continues the failed execution from the unsuccessful step and\nuses the same input. Step Functions preserves the results and execution history\nof the successful steps, and doesn't rerun these steps when you redrive an\nexecution. Redriven executions use the same state machine definition and\nexecution ARN as the original execution attempt.\n\nFor workflows that include an [Inline\nMap](https://docs.aws.amazon.com/step-functions/latest/dg/amazon-states-language-map-state.html)\nor\n[Parallel](https://docs.aws.amazon.com/step-functions/latest/dg/amazon-states-language-parallel-state.html) state, `RedriveExecution` API action reschedules and redrives only the\niterations and branches that failed or aborted.\n\nTo redrive a workflow that includes a Distributed Map state whose Map Run\nfailed, you must redrive the [parent\nworkflow](https://docs.aws.amazon.com/step-functions/latest/dg/use-dist-map-orchestrate-large-scale-parallel-workloads.html#dist-map-orchestrate-parallel-workloads-key-terms).\nThe parent workflow redrives all the unsuccessful states, including a failed Map\nRun. If a Map Run was not started in the original execution attempt, the\nredriven parent workflow starts the Map Run.\n\nThis API action is not supported by `EXPRESS` state machines.\n\nHowever, you can restart the unsuccessful executions of Express child workflows\nin a Distributed Map by redriving its Map Run. When you redrive a Map Run, the\nExpress child workflows are rerun using the `StartExecution` API action. For\nmore information, see [Redriving Map Runs](https://docs.aws.amazon.com/step-functions/latest/dg/redrive-map-run.html).\n\nYou can redrive executions if your original execution meets the following\nconditions:\n\n  * The execution status isn't `SUCCEEDED`.\n\n  * Your workflow execution has not exceeded the redrivable period of\n14 days. Redrivable period refers to the time during which you can redrive a\ngiven execution. This period starts from the day a state machine completes its\nexecution.\n\n  * The workflow execution has not exceeded the maximum open time of\none year. For more information about state machine quotas, see [Quotas related to state machine\nexecutions](https://docs.aws.amazon.com/step-functions/latest/dg/limits-overview.html#service-limits-state-machine-executions).\n\n  * The execution event history count is less than 24,999. Redriven\nexecutions append their event history to the existing event history. Make sure\nyour workflow execution contains less than 24,999 events to accommodate the\n`ExecutionRedriven` history event and at least one other history event.","ref":"AWS.SFN.html#redrive_execution/3","title":"AWS.SFN.redrive_execution/3","type":"function"},{"doc":"Used by activity workers, Task states using the\n[callback](https://docs.aws.amazon.com/step-functions/latest/dg/connect-to-resource.html#connect-wait-token) pattern, and optionally Task states using the [job\nrun](https://docs.aws.amazon.com/step-functions/latest/dg/connect-to-resource.html#connect-sync)\npattern to report that the task identified by the `taskToken` failed.","ref":"AWS.SFN.html#send_task_failure/3","title":"AWS.SFN.send_task_failure/3","type":"function"},{"doc":"Used by activity workers and Task states using the\n[callback](https://docs.aws.amazon.com/step-functions/latest/dg/connect-to-resource.html#connect-wait-token) pattern, and optionally Task states using the [job\nrun](https://docs.aws.amazon.com/step-functions/latest/dg/connect-to-resource.html#connect-sync)\npattern to report to Step Functions that the task represented by the specified\n`taskToken` is still making progress.\n\nThis action resets the `Heartbeat` clock. The `Heartbeat` threshold is specified\nin the state machine's Amazon States Language definition (`HeartbeatSeconds`).\nThis action does not in itself create an event in the execution history.\nHowever, if the task times out, the execution history contains an\n`ActivityTimedOut` entry for activities, or a `TaskTimedOut` entry for tasks\nusing the [job run](https://docs.aws.amazon.com/step-functions/latest/dg/connect-to-resource.html#connect-sync)\nor\n[callback](https://docs.aws.amazon.com/step-functions/latest/dg/connect-to-resource.html#connect-wait-token)\npattern.\n\nThe `Timeout` of a task, defined in the state machine's Amazon States Language\ndefinition, is its maximum allowed duration, regardless of the number of\n`SendTaskHeartbeat` requests received. Use `HeartbeatSeconds` to configure the\ntimeout interval for heartbeats.","ref":"AWS.SFN.html#send_task_heartbeat/3","title":"AWS.SFN.send_task_heartbeat/3","type":"function"},{"doc":"Used by activity workers, Task states using the\n[callback](https://docs.aws.amazon.com/step-functions/latest/dg/connect-to-resource.html#connect-wait-token) pattern, and optionally Task states using the [job\nrun](https://docs.aws.amazon.com/step-functions/latest/dg/connect-to-resource.html#connect-sync)\npattern to report that the task identified by the `taskToken` completed\nsuccessfully.","ref":"AWS.SFN.html#send_task_success/3","title":"AWS.SFN.send_task_success/3","type":"function"},{"doc":"Starts a state machine execution.\n\nA qualified state machine ARN can either refer to a *Distributed Map state*\ndefined within a state machine, a version ARN, or an alias ARN.\n\nThe following are some examples of qualified and unqualified state machine ARNs:\n\n  * The following qualified state machine ARN refers to a *Distributed\nMap state* with a label `mapStateLabel` in a state machine named\n`myStateMachine`.\n\n`arn:partition:states:region:account-id:stateMachine:myStateMachine/mapStateLabel`\n\nIf you provide a qualified state machine ARN that refers to a *Distributed Map\nstate*, the request fails with `ValidationException`.\n\n  * The following qualified state machine ARN refers to an alias named\n`PROD`.\n\n`arn: :states: : :stateMachine: `\n\nIf you provide a qualified state machine ARN that refers to a version ARN or an\nalias ARN, the request starts execution for that version or alias.\n\n  * The following unqualified state machine ARN refers to a state\nmachine named `myStateMachine`.\n\n`arn: :states: : :stateMachine: `\n\nIf you start an execution with an unqualified state machine ARN, Step Functions\nuses the latest revision of the state machine for the execution.\n\nTo start executions of a state machine\n[version](https://docs.aws.amazon.com/step-functions/latest/dg/concepts-state-machine-version.html), call `StartExecution` and provide the version ARN or the ARN of an\n[alias](https://docs.aws.amazon.com/step-functions/latest/dg/concepts-state-machine-alias.html)\nthat points to the version.\n\n`StartExecution` is idempotent for `STANDARD` workflows. For a `STANDARD`\nworkflow, if you call `StartExecution` with the same name and input as a running\nexecution, the call succeeds and return the same response as the original\nrequest. If the execution is closed or if the input is different, it returns a\n`400 ExecutionAlreadyExists` error. You can reuse names after 90 days.\n\n`StartExecution` isn't idempotent for `EXPRESS` workflows.","ref":"AWS.SFN.html#start_execution/3","title":"AWS.SFN.start_execution/3","type":"function"},{"doc":"Starts a Synchronous Express state machine execution.\n\n`StartSyncExecution` is not available for `STANDARD` workflows.\n\n`StartSyncExecution` will return a `200 OK` response, even if your execution\nfails, because the status code in the API response doesn't reflect function\nerrors. Error codes are reserved for errors that prevent your execution from\nrunning, such as permissions errors, limit errors, or issues with your state\nmachine code and configuration.\n\nThis API action isn't logged in CloudTrail.","ref":"AWS.SFN.html#start_sync_execution/3","title":"AWS.SFN.start_sync_execution/3","type":"function"},{"doc":"Stops an execution.\n\nThis API action is not supported by `EXPRESS` state machines.","ref":"AWS.SFN.html#stop_execution/3","title":"AWS.SFN.stop_execution/3","type":"function"},{"doc":"Add a tag to a Step Functions resource.\n\nAn array of key-value pairs. For more information, see [Using Cost Allocation Tags](https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/cost-alloc-tags.html)\nin the *Amazon Web Services Billing and Cost Management User Guide*, and\n[Controlling Access Using IAM Tags](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_iam-tags.html).\n\nTags may only contain Unicode letters, digits, white space, or these symbols: `_\n. : / = + - @`.","ref":"AWS.SFN.html#tag_resource/3","title":"AWS.SFN.tag_resource/3","type":"function"},{"doc":"Accepts the definition of a single state and executes it.\n\nYou can test a state without creating a state machine or updating an existing\nstate machine. Using this API, you can test the following:\n\n  * A state's [input and output processing](https://docs.aws.amazon.com/step-functions/latest/dg/test-state-isolation.html#test-state-input-output-dataflow)\ndata flow\n\n  * An [Amazon Web Services service integration](https://docs.aws.amazon.com/step-functions/latest/dg/connect-to-services.html)\nrequest and response\n\n  * An [HTTP Task](https://docs.aws.amazon.com/step-functions/latest/dg/connect-third-party-apis.html)\nrequest and response\n\nYou can call this API on only one state at a time. The states that you can test\ninclude the following:\n\n  * [All Task types](https://docs.aws.amazon.com/step-functions/latest/dg/amazon-states-language-task-state.html#task-types)\nexcept\n[Activity](https://docs.aws.amazon.com/step-functions/latest/dg/concepts-activities.html)     *\n[Pass](https://docs.aws.amazon.com/step-functions/latest/dg/amazon-states-language-pass-state.html)\n\n  *\n[Wait](https://docs.aws.amazon.com/step-functions/latest/dg/amazon-states-language-wait-state.html)     *\n[Choice](https://docs.aws.amazon.com/step-functions/latest/dg/amazon-states-language-choice-state.html)\n\n  *\n[Succeed](https://docs.aws.amazon.com/step-functions/latest/dg/amazon-states-language-succeed-state.html)     *\n[Fail](https://docs.aws.amazon.com/step-functions/latest/dg/amazon-states-language-fail-state.html)\n\nThe `TestState` API assumes an IAM role which must contain the required IAM\npermissions for the resources your state is accessing. For information about the\npermissions a state might need, see [IAM permissions to test a state](https://docs.aws.amazon.com/step-functions/latest/dg/test-state-isolation.html#test-state-permissions).\n\nThe `TestState` API can run for up to five minutes. If the execution of a state\nexceeds this duration, it fails with the `States.Timeout` error.\n\n`TestState` doesn't support [Activity tasks](https://docs.aws.amazon.com/step-functions/latest/dg/concepts-activities.html),\n`.sync` or `.waitForTaskToken` [service integration patterns](https://docs.aws.amazon.com/step-functions/latest/dg/connect-to-resource.html),\n[Parallel](https://docs.aws.amazon.com/step-functions/latest/dg/amazon-states-language-parallel-state.html), or\n[Map](https://docs.aws.amazon.com/step-functions/latest/dg/amazon-states-language-map-state.html)\nstates.","ref":"AWS.SFN.html#test_state/3","title":"AWS.SFN.test_state/3","type":"function"},{"doc":"Remove a tag from a Step Functions resource","ref":"AWS.SFN.html#untag_resource/3","title":"AWS.SFN.untag_resource/3","type":"function"},{"doc":"Updates an in-progress Map Run's configuration to include changes to the\nsettings that control maximum concurrency and Map Run failure.","ref":"AWS.SFN.html#update_map_run/3","title":"AWS.SFN.update_map_run/3","type":"function"},{"doc":"Updates an existing state machine by modifying its `definition`, `roleArn`, or\n`loggingConfiguration`.\n\nRunning executions will continue to use the previous `definition` and `roleArn`.\nYou must include at least one of `definition` or `roleArn` or you will receive a\n`MissingRequiredParameter` error.\n\nA qualified state machine ARN refers to a *Distributed Map state* defined within\na state machine. For example, the qualified state machine ARN\n`arn:partition:states:region:account-id:stateMachine:stateMachineName/mapStateLabel`\nrefers to a *Distributed Map state* with a label `mapStateLabel` in the state\nmachine named `stateMachineName`.\n\nA qualified state machine ARN can either refer to a *Distributed Map state*\ndefined within a state machine, a version ARN, or an alias ARN.\n\nThe following are some examples of qualified and unqualified state machine ARNs:\n\n  * The following qualified state machine ARN refers to a *Distributed\nMap state* with a label `mapStateLabel` in a state machine named\n`myStateMachine`.\n\n`arn:partition:states:region:account-id:stateMachine:myStateMachine/mapStateLabel`\n\nIf you provide a qualified state machine ARN that refers to a *Distributed Map\nstate*, the request fails with `ValidationException`.\n\n  * The following qualified state machine ARN refers to an alias named\n`PROD`.\n\n`arn: :states: : :stateMachine: `\n\nIf you provide a qualified state machine ARN that refers to a version ARN or an\nalias ARN, the request starts execution for that version or alias.\n\n  * The following unqualified state machine ARN refers to a state\nmachine named `myStateMachine`.\n\n`arn: :states: : :stateMachine: `\n\nAfter you update your state machine, you can set the `publish` parameter to\n`true` in the same action to publish a new\n[version](https://docs.aws.amazon.com/step-functions/latest/dg/concepts-state-machine-version.html).\nThis way, you can opt-in to strict versioning of your state machine.\n\nStep Functions assigns monotonically increasing integers for state machine\nversions, starting at version number 1.\n\nAll `StartExecution` calls within a few seconds use the updated `definition` and\n`roleArn`. Executions started immediately after you call `UpdateStateMachine`\nmay use the previous state machine `definition` and `roleArn`.","ref":"AWS.SFN.html#update_state_machine/3","title":"AWS.SFN.update_state_machine/3","type":"function"},{"doc":"Updates the configuration of an existing state machine\n[alias](https://docs.aws.amazon.com/step-functions/latest/dg/concepts-state-machine-alias.html)\nby modifying its `description` or `routingConfiguration`.\n\nYou must specify at least one of the `description` or `routingConfiguration`\nparameters to update a state machine alias.\n\n`UpdateStateMachineAlias` is an idempotent API. Step Functions bases the\nidempotency check on the `stateMachineAliasArn`, `description`, and\n`routingConfiguration` parameters. Requests with the same parameters return an\nidempotent response.\n\nThis operation is eventually consistent. All `StartExecution` requests made\nwithin a few seconds use the latest alias configuration. Executions started\nimmediately after calling `UpdateStateMachineAlias` may use the previous routing\nconfiguration.","ref":"AWS.SFN.html#update_state_machine_alias/3","title":"AWS.SFN.update_state_machine_alias/3","type":"function"},{"doc":"* `CreateStateMachineAlias`\n\n  * `DescribeStateMachineAlias`\n\n  * `ListStateMachineAliases`\n\n  * `DeleteStateMachineAlias`","ref":"AWS.SFN.html#update_state_machine_alias/3-related-operations","title":"Related operations: - AWS.SFN.update_state_machine_alias/3","type":"function"},{"doc":"","ref":"AWS.SMS.html","title":"AWS.SMS","type":"module"},{"doc":"We recommend [Amazon Web Services Application Migration Service](http://aws.amazon.com/application-migration-service) (Amazon Web\nServices MGN) as the primary migration service for lift-and-shift migrations.\n\nIf Amazon Web Services MGN is unavailable in a specific Amazon Web Services\nRegion, you can use the Server Migration Service APIs through March 2023.\n\nServer Migration Service (Server Migration Service) makes it easier and faster\nfor you to migrate your on-premises workloads to Amazon Web Services. To learn\nmore about Server Migration Service, see the following resources:\n\n  * [Server Migration Service product page](http://aws.amazon.com/server-migration-service/)\n\n  * [Server Migration Service User Guide](https://docs.aws.amazon.com/server-migration-service/latest/userguide/)","ref":"AWS.SMS.html#module-product-update","title":"Product update - AWS.SMS","type":"module"},{"doc":"Creates an application.\n\nAn application consists of one or more server groups. Each server group contain\none or more servers.","ref":"AWS.SMS.html#create_app/3","title":"AWS.SMS.create_app/3","type":"function"},{"doc":"Creates a replication job.\n\nThe replication job schedules periodic replication runs to replicate your server\nto Amazon Web Services. Each replication run creates an Amazon Machine Image\n(AMI).","ref":"AWS.SMS.html#create_replication_job/3","title":"AWS.SMS.create_replication_job/3","type":"function"},{"doc":"Deletes the specified application.\n\nOptionally deletes the launched stack associated with the application and all\nServer Migration Service replication jobs for servers in the application.","ref":"AWS.SMS.html#delete_app/3","title":"AWS.SMS.delete_app/3","type":"function"},{"doc":"Deletes the launch configuration for the specified application.","ref":"AWS.SMS.html#delete_app_launch_configuration/3","title":"AWS.SMS.delete_app_launch_configuration/3","type":"function"},{"doc":"Deletes the replication configuration for the specified application.","ref":"AWS.SMS.html#delete_app_replication_configuration/3","title":"AWS.SMS.delete_app_replication_configuration/3","type":"function"},{"doc":"Deletes the validation configuration for the specified application.","ref":"AWS.SMS.html#delete_app_validation_configuration/3","title":"AWS.SMS.delete_app_validation_configuration/3","type":"function"},{"doc":"Deletes the specified replication job.\n\nAfter you delete a replication job, there are no further replication runs.\nAmazon Web Services deletes the contents of the Amazon S3 bucket used to store\nServer Migration Service artifacts. The AMIs created by the replication runs are\nnot deleted.","ref":"AWS.SMS.html#delete_replication_job/3","title":"AWS.SMS.delete_replication_job/3","type":"function"},{"doc":"Deletes all servers from your server catalog.","ref":"AWS.SMS.html#delete_server_catalog/3","title":"AWS.SMS.delete_server_catalog/3","type":"function"},{"doc":"Disassociates the specified connector from Server Migration Service.\n\nAfter you disassociate a connector, it is no longer available to support\nreplication jobs.","ref":"AWS.SMS.html#disassociate_connector/3","title":"AWS.SMS.disassociate_connector/3","type":"function"},{"doc":"Generates a target change set for a currently launched stack and writes it to an\nAmazon S3 object in the customer’s Amazon S3 bucket.","ref":"AWS.SMS.html#generate_change_set/3","title":"AWS.SMS.generate_change_set/3","type":"function"},{"doc":"Generates an CloudFormation template based on the current launch configuration\nand writes it to an Amazon S3 object in the customer’s Amazon S3 bucket.","ref":"AWS.SMS.html#generate_template/3","title":"AWS.SMS.generate_template/3","type":"function"},{"doc":"Retrieve information about the specified application.","ref":"AWS.SMS.html#get_app/3","title":"AWS.SMS.get_app/3","type":"function"},{"doc":"Retrieves the application launch configuration associated with the specified\napplication.","ref":"AWS.SMS.html#get_app_launch_configuration/3","title":"AWS.SMS.get_app_launch_configuration/3","type":"function"},{"doc":"Retrieves the application replication configuration associated with the\nspecified application.","ref":"AWS.SMS.html#get_app_replication_configuration/3","title":"AWS.SMS.get_app_replication_configuration/3","type":"function"},{"doc":"Retrieves information about a configuration for validating an application.","ref":"AWS.SMS.html#get_app_validation_configuration/3","title":"AWS.SMS.get_app_validation_configuration/3","type":"function"},{"doc":"Retrieves output from validating an application.","ref":"AWS.SMS.html#get_app_validation_output/3","title":"AWS.SMS.get_app_validation_output/3","type":"function"},{"doc":"Describes the connectors registered with the Server Migration Service.","ref":"AWS.SMS.html#get_connectors/3","title":"AWS.SMS.get_connectors/3","type":"function"},{"doc":"Describes the specified replication job or all of your replication jobs.","ref":"AWS.SMS.html#get_replication_jobs/3","title":"AWS.SMS.get_replication_jobs/3","type":"function"},{"doc":"Describes the replication runs for the specified replication job.","ref":"AWS.SMS.html#get_replication_runs/3","title":"AWS.SMS.get_replication_runs/3","type":"function"},{"doc":"Describes the servers in your server catalog.\n\nBefore you can describe your servers, you must import them using\n`ImportServerCatalog`.","ref":"AWS.SMS.html#get_servers/3","title":"AWS.SMS.get_servers/3","type":"function"},{"doc":"Allows application import from Migration Hub.","ref":"AWS.SMS.html#import_app_catalog/3","title":"AWS.SMS.import_app_catalog/3","type":"function"},{"doc":"Gathers a complete list of on-premises servers.\n\nConnectors must be installed and monitoring all servers to import.\n\nThis call returns immediately, but might take additional time to retrieve all\nthe servers.","ref":"AWS.SMS.html#import_server_catalog/3","title":"AWS.SMS.import_server_catalog/3","type":"function"},{"doc":"Launches the specified application as a stack in CloudFormation.","ref":"AWS.SMS.html#launch_app/3","title":"AWS.SMS.launch_app/3","type":"function"},{"doc":"Retrieves summaries for all applications.","ref":"AWS.SMS.html#list_apps/3","title":"AWS.SMS.list_apps/3","type":"function"},{"doc":"","ref":"AWS.SMS.html#metadata/0","title":"AWS.SMS.metadata/0","type":"function"},{"doc":"Provides information to Server Migration Service about whether application\nvalidation is successful.","ref":"AWS.SMS.html#notify_app_validation_output/3","title":"AWS.SMS.notify_app_validation_output/3","type":"function"},{"doc":"Creates or updates the launch configuration for the specified application.","ref":"AWS.SMS.html#put_app_launch_configuration/3","title":"AWS.SMS.put_app_launch_configuration/3","type":"function"},{"doc":"Creates or updates the replication configuration for the specified application.","ref":"AWS.SMS.html#put_app_replication_configuration/3","title":"AWS.SMS.put_app_replication_configuration/3","type":"function"},{"doc":"Creates or updates a validation configuration for the specified application.","ref":"AWS.SMS.html#put_app_validation_configuration/3","title":"AWS.SMS.put_app_validation_configuration/3","type":"function"},{"doc":"Starts replicating the specified application by creating replication jobs for\neach server in the application.","ref":"AWS.SMS.html#start_app_replication/3","title":"AWS.SMS.start_app_replication/3","type":"function"},{"doc":"Starts an on-demand replication run for the specified application.","ref":"AWS.SMS.html#start_on_demand_app_replication/3","title":"AWS.SMS.start_on_demand_app_replication/3","type":"function"},{"doc":"Starts an on-demand replication run for the specified replication job.\n\nThis replication run starts immediately. This replication run is in addition to\nthe ones already scheduled.\n\nThere is a limit on the number of on-demand replications runs that you can\nrequest in a 24-hour period.","ref":"AWS.SMS.html#start_on_demand_replication_run/3","title":"AWS.SMS.start_on_demand_replication_run/3","type":"function"},{"doc":"Stops replicating the specified application by deleting the replication job for\neach server in the application.","ref":"AWS.SMS.html#stop_app_replication/3","title":"AWS.SMS.stop_app_replication/3","type":"function"},{"doc":"Terminates the stack for the specified application.","ref":"AWS.SMS.html#terminate_app/3","title":"AWS.SMS.terminate_app/3","type":"function"},{"doc":"Updates the specified application.","ref":"AWS.SMS.html#update_app/3","title":"AWS.SMS.update_app/3","type":"function"},{"doc":"Updates the specified settings for the specified replication job.","ref":"AWS.SMS.html#update_replication_job/3","title":"AWS.SMS.update_replication_job/3","type":"function"},{"doc":"Amazon Simple Notification Service\n\nAmazon Simple Notification Service (Amazon SNS) is a web service that enables\nyou to build distributed web-enabled applications.\n\nApplications can use Amazon SNS to easily push real-time notification messages\nto interested subscribers over multiple delivery protocols. For more information\nabout this product see the [Amazon SNS product page](http://aws.amazon.com/sns/). For detailed information about Amazon SNS\nfeatures and their associated API calls, see the [Amazon SNS Developer Guide](https://docs.aws.amazon.com/sns/latest/dg/).\n\nFor information on the permissions you need to use this API, see [Identity and access management in Amazon\nSNS](https://docs.aws.amazon.com/sns/latest/dg/sns-authentication-and-access-control.html)\nin the *Amazon SNS Developer Guide.*\n\nWe also provide SDKs that enable you to access Amazon SNS from your preferred\nprogramming language. The SDKs contain functionality that automatically takes\ncare of tasks such as: cryptographically signing your service requests, retrying\nrequests, and handling error responses. For a list of available SDKs, go to\n[Tools for Amazon Web Services](http://aws.amazon.com/tools/).","ref":"AWS.SNS.html","title":"AWS.SNS","type":"module"},{"doc":"Adds a statement to a topic's access control policy, granting access for the\nspecified Amazon Web Services accounts to the specified actions.\n\nTo remove the ability to change topic permissions, you must deny permissions to\nthe `AddPermission`, `RemovePermission`, and `SetTopicAttributes` actions in\nyour IAM policy.","ref":"AWS.SNS.html#add_permission/3","title":"AWS.SNS.add_permission/3","type":"function"},{"doc":"Accepts a phone number and indicates whether the phone holder has opted out of\nreceiving SMS messages from your Amazon Web Services account.\n\nYou cannot send SMS messages to a number that is opted out.\n\nTo resume sending messages, you can opt in the number by using the\n`OptInPhoneNumber` action.","ref":"AWS.SNS.html#check_if_phone_number_is_opted_out/3","title":"AWS.SNS.check_if_phone_number_is_opted_out/3","type":"function"},{"doc":"Verifies an endpoint owner's intent to receive messages by validating the token\nsent to the endpoint by an earlier `Subscribe` action.\n\nIf the token is valid, the action creates a new subscription and returns its\nAmazon Resource Name (ARN). This call requires an AWS signature only when the\n`AuthenticateOnUnsubscribe` flag is set to \"true\".","ref":"AWS.SNS.html#confirm_subscription/3","title":"AWS.SNS.confirm_subscription/3","type":"function"},{"doc":"Creates a platform application object for one of the supported push notification\nservices, such as APNS and GCM (Firebase Cloud Messaging), to which devices and\nmobile apps may register.\n\nYou must specify `PlatformPrincipal` and `PlatformCredential` attributes when\nusing the `CreatePlatformApplication` action.\n\n`PlatformPrincipal` and `PlatformCredential` are received from the notification\nservice.\n\n  * For `ADM`, `PlatformPrincipal` is `client id` and\n`PlatformCredential` is `client secret`.\n\n  * For `Baidu`, `PlatformPrincipal` is `API key` and\n`PlatformCredential` is `secret key`.\n\n  * For `APNS` and `APNS_SANDBOX` using certificate credentials,\n`PlatformPrincipal` is `SSL certificate` and `PlatformCredential` is `private\nkey`.\n\n  * For `APNS` and `APNS_SANDBOX` using token credentials,\n`PlatformPrincipal` is `signing key ID` and `PlatformCredential` is `signing\nkey`.\n\n  * For `GCM` (Firebase Cloud Messaging), there is no\n`PlatformPrincipal` and the `PlatformCredential` is `API key`.\n\n  * For `MPNS`, `PlatformPrincipal` is `TLS certificate` and\n`PlatformCredential` is `private key`.\n\n  * For `WNS`, `PlatformPrincipal` is `Package Security Identifier`\nand `PlatformCredential` is `secret key`.\n\nYou can use the returned `PlatformApplicationArn` as an attribute for the\n`CreatePlatformEndpoint` action.","ref":"AWS.SNS.html#create_platform_application/3","title":"AWS.SNS.create_platform_application/3","type":"function"},{"doc":"Creates an endpoint for a device and mobile app on one of the supported push\nnotification services, such as GCM (Firebase Cloud Messaging) and APNS.\n\n`CreatePlatformEndpoint` requires the `PlatformApplicationArn` that is returned\nfrom `CreatePlatformApplication`. You can use the returned `EndpointArn` to send\na message to a mobile app or by the `Subscribe` action for subscription to a\ntopic. The `CreatePlatformEndpoint` action is idempotent, so if the requester\nalready owns an endpoint with the same device token and attributes, that\nendpoint's ARN is returned without creating a new endpoint. For more\ninformation, see [Using Amazon SNS Mobile Push Notifications](https://docs.aws.amazon.com/sns/latest/dg/SNSMobilePush.html).\n\nWhen using `CreatePlatformEndpoint` with Baidu, two attributes must be provided:\nChannelId and UserId. The token field must also contain the ChannelId. For more\ninformation, see [Creating an Amazon SNS Endpoint for Baidu](https://docs.aws.amazon.com/sns/latest/dg/SNSMobilePushBaiduEndpoint.html).","ref":"AWS.SNS.html#create_platform_endpoint/3","title":"AWS.SNS.create_platform_endpoint/3","type":"function"},{"doc":"Adds a destination phone number to an Amazon Web Services account in the SMS\nsandbox and sends a one-time password (OTP) to that phone number.\n\nWhen you start using Amazon SNS to send SMS messages, your Amazon Web Services\naccount is in the *SMS sandbox*. The SMS sandbox provides a safe environment for\nyou to try Amazon SNS features without risking your reputation as an SMS sender.\nWhile your Amazon Web Services account is in the SMS sandbox, you can use all of\nthe features of Amazon SNS. However, you can send SMS messages only to verified\ndestination phone numbers. For more information, including how to move out of\nthe sandbox to send messages without restrictions, see [SMS sandbox](https://docs.aws.amazon.com/sns/latest/dg/sns-sms-sandbox.html) in the\n*Amazon SNS Developer Guide*.","ref":"AWS.SNS.html#create_sms_sandbox_phone_number/3","title":"AWS.SNS.create_sms_sandbox_phone_number/3","type":"function"},{"doc":"Creates a topic to which notifications can be published.\n\nUsers can create at most 100,000 standard topics (at most 1,000 FIFO topics).\nFor more information, see [Creating an Amazon SNS topic](https://docs.aws.amazon.com/sns/latest/dg/sns-create-topic.html) in the\n*Amazon SNS Developer Guide*. This action is idempotent, so if the requester\nalready owns a topic with the specified name, that topic's ARN is returned\nwithout creating a new topic.","ref":"AWS.SNS.html#create_topic/3","title":"AWS.SNS.create_topic/3","type":"function"},{"doc":"Deletes the endpoint for a device and mobile app from Amazon SNS.\n\nThis action is idempotent. For more information, see [Using Amazon SNS Mobile Push\nNotifications](https://docs.aws.amazon.com/sns/latest/dg/SNSMobilePush.html).\n\nWhen you delete an endpoint that is also subscribed to a topic, then you must\nalso unsubscribe the endpoint from the topic.","ref":"AWS.SNS.html#delete_endpoint/3","title":"AWS.SNS.delete_endpoint/3","type":"function"},{"doc":"Deletes a platform application object for one of the supported push notification\nservices, such as APNS and GCM (Firebase Cloud Messaging).\n\nFor more information, see [Using Amazon SNS Mobile Push Notifications](https://docs.aws.amazon.com/sns/latest/dg/SNSMobilePush.html).","ref":"AWS.SNS.html#delete_platform_application/3","title":"AWS.SNS.delete_platform_application/3","type":"function"},{"doc":"Deletes an Amazon Web Services account's verified or pending phone number from\nthe SMS sandbox.\n\nWhen you start using Amazon SNS to send SMS messages, your Amazon Web Services\naccount is in the *SMS sandbox*. The SMS sandbox provides a safe environment for\nyou to try Amazon SNS features without risking your reputation as an SMS sender.\nWhile your Amazon Web Services account is in the SMS sandbox, you can use all of\nthe features of Amazon SNS. However, you can send SMS messages only to verified\ndestination phone numbers. For more information, including how to move out of\nthe sandbox to send messages without restrictions, see [SMS sandbox](https://docs.aws.amazon.com/sns/latest/dg/sns-sms-sandbox.html) in the\n*Amazon SNS Developer Guide*.","ref":"AWS.SNS.html#delete_sms_sandbox_phone_number/3","title":"AWS.SNS.delete_sms_sandbox_phone_number/3","type":"function"},{"doc":"Deletes a topic and all its subscriptions.\n\nDeleting a topic might prevent some messages previously sent to the topic from\nbeing delivered to subscribers. This action is idempotent, so deleting a topic\nthat does not exist does not result in an error.","ref":"AWS.SNS.html#delete_topic/3","title":"AWS.SNS.delete_topic/3","type":"function"},{"doc":"Retrieves the specified inline `DataProtectionPolicy` document that is stored in\nthe specified Amazon SNS topic.","ref":"AWS.SNS.html#get_data_protection_policy/3","title":"AWS.SNS.get_data_protection_policy/3","type":"function"},{"doc":"Retrieves the endpoint attributes for a device on one of the supported push\nnotification services, such as GCM (Firebase Cloud Messaging) and APNS.\n\nFor more information, see [Using Amazon SNS Mobile Push Notifications](https://docs.aws.amazon.com/sns/latest/dg/SNSMobilePush.html).","ref":"AWS.SNS.html#get_endpoint_attributes/3","title":"AWS.SNS.get_endpoint_attributes/3","type":"function"},{"doc":"Retrieves the attributes of the platform application object for the supported\npush notification services, such as APNS and GCM (Firebase Cloud Messaging).\n\nFor more information, see [Using Amazon SNS Mobile Push Notifications](https://docs.aws.amazon.com/sns/latest/dg/SNSMobilePush.html).","ref":"AWS.SNS.html#get_platform_application_attributes/3","title":"AWS.SNS.get_platform_application_attributes/3","type":"function"},{"doc":"Returns the settings for sending SMS messages from your Amazon Web Services\naccount.\n\nThese settings are set with the `SetSMSAttributes` action.","ref":"AWS.SNS.html#get_sms_attributes/3","title":"AWS.SNS.get_sms_attributes/3","type":"function"},{"doc":"Retrieves the SMS sandbox status for the calling Amazon Web Services account in\nthe target Amazon Web Services Region.\n\nWhen you start using Amazon SNS to send SMS messages, your Amazon Web Services\naccount is in the *SMS sandbox*. The SMS sandbox provides a safe environment for\nyou to try Amazon SNS features without risking your reputation as an SMS sender.\nWhile your Amazon Web Services account is in the SMS sandbox, you can use all of\nthe features of Amazon SNS. However, you can send SMS messages only to verified\ndestination phone numbers. For more information, including how to move out of\nthe sandbox to send messages without restrictions, see [SMS sandbox](https://docs.aws.amazon.com/sns/latest/dg/sns-sms-sandbox.html) in the\n*Amazon SNS Developer Guide*.","ref":"AWS.SNS.html#get_sms_sandbox_account_status/3","title":"AWS.SNS.get_sms_sandbox_account_status/3","type":"function"},{"doc":"Returns all of the properties of a subscription.","ref":"AWS.SNS.html#get_subscription_attributes/3","title":"AWS.SNS.get_subscription_attributes/3","type":"function"},{"doc":"Returns all of the properties of a topic.\n\nTopic properties returned might differ based on the authorization of the user.","ref":"AWS.SNS.html#get_topic_attributes/3","title":"AWS.SNS.get_topic_attributes/3","type":"function"},{"doc":"Lists the endpoints and endpoint attributes for devices in a supported push\nnotification service, such as GCM (Firebase Cloud Messaging) and APNS.\n\nThe results for `ListEndpointsByPlatformApplication` are paginated and return a\nlimited list of endpoints, up to 100. If additional records are available after\nthe first page results, then a NextToken string will be returned. To receive the\nnext page, you call `ListEndpointsByPlatformApplication` again using the\nNextToken string received from the previous call. When there are no more records\nto return, NextToken will be null. For more information, see [Using Amazon SNS Mobile Push\nNotifications](https://docs.aws.amazon.com/sns/latest/dg/SNSMobilePush.html).\n\nThis action is throttled at 30 transactions per second (TPS).","ref":"AWS.SNS.html#list_endpoints_by_platform_application/3","title":"AWS.SNS.list_endpoints_by_platform_application/3","type":"function"},{"doc":"Lists the calling Amazon Web Services account's dedicated origination numbers\nand their metadata.\n\nFor more information about origination numbers, see [Origination numbers](https://docs.aws.amazon.com/sns/latest/dg/channels-sms-originating-identities-origination-numbers.html)\nin the *Amazon SNS Developer Guide*.","ref":"AWS.SNS.html#list_origination_numbers/3","title":"AWS.SNS.list_origination_numbers/3","type":"function"},{"doc":"Returns a list of phone numbers that are opted out, meaning you cannot send SMS\nmessages to them.\n\nThe results for `ListPhoneNumbersOptedOut` are paginated, and each page returns\nup to 100 phone numbers. If additional phone numbers are available after the\nfirst page of results, then a `NextToken` string will be returned. To receive\nthe next page, you call `ListPhoneNumbersOptedOut` again using the `NextToken`\nstring received from the previous call. When there are no more records to\nreturn, `NextToken` will be null.","ref":"AWS.SNS.html#list_phone_numbers_opted_out/3","title":"AWS.SNS.list_phone_numbers_opted_out/3","type":"function"},{"doc":"Lists the platform application objects for the supported push notification\nservices, such as APNS and GCM (Firebase Cloud Messaging).\n\nThe results for `ListPlatformApplications` are paginated and return a limited\nlist of applications, up to 100. If additional records are available after the\nfirst page results, then a NextToken string will be returned. To receive the\nnext page, you call `ListPlatformApplications` using the NextToken string\nreceived from the previous call. When there are no more records to return,\n`NextToken` will be null. For more information, see [Using Amazon SNS Mobile Push\nNotifications](https://docs.aws.amazon.com/sns/latest/dg/SNSMobilePush.html).\n\nThis action is throttled at 15 transactions per second (TPS).","ref":"AWS.SNS.html#list_platform_applications/3","title":"AWS.SNS.list_platform_applications/3","type":"function"},{"doc":"Lists the calling Amazon Web Services account's current verified and pending\ndestination phone numbers in the SMS sandbox.\n\nWhen you start using Amazon SNS to send SMS messages, your Amazon Web Services\naccount is in the *SMS sandbox*. The SMS sandbox provides a safe environment for\nyou to try Amazon SNS features without risking your reputation as an SMS sender.\nWhile your Amazon Web Services account is in the SMS sandbox, you can use all of\nthe features of Amazon SNS. However, you can send SMS messages only to verified\ndestination phone numbers. For more information, including how to move out of\nthe sandbox to send messages without restrictions, see [SMS sandbox](https://docs.aws.amazon.com/sns/latest/dg/sns-sms-sandbox.html) in the\n*Amazon SNS Developer Guide*.","ref":"AWS.SNS.html#list_sms_sandbox_phone_numbers/3","title":"AWS.SNS.list_sms_sandbox_phone_numbers/3","type":"function"},{"doc":"Returns a list of the requester's subscriptions.\n\nEach call returns a limited list of subscriptions, up to 100. If there are more\nsubscriptions, a `NextToken` is also returned. Use the `NextToken` parameter in\na new `ListSubscriptions` call to get further results.\n\nThis action is throttled at 30 transactions per second (TPS).","ref":"AWS.SNS.html#list_subscriptions/3","title":"AWS.SNS.list_subscriptions/3","type":"function"},{"doc":"Returns a list of the subscriptions to a specific topic.\n\nEach call returns a limited list of subscriptions, up to 100. If there are more\nsubscriptions, a `NextToken` is also returned. Use the `NextToken` parameter in\na new `ListSubscriptionsByTopic` call to get further results.\n\nThis action is throttled at 30 transactions per second (TPS).","ref":"AWS.SNS.html#list_subscriptions_by_topic/3","title":"AWS.SNS.list_subscriptions_by_topic/3","type":"function"},{"doc":"List all tags added to the specified Amazon SNS topic.\n\nFor an overview, see [Amazon SNS Tags](https://docs.aws.amazon.com/sns/latest/dg/sns-tags.html) in the *Amazon\nSimple Notification Service Developer Guide*.","ref":"AWS.SNS.html#list_tags_for_resource/3","title":"AWS.SNS.list_tags_for_resource/3","type":"function"},{"doc":"Returns a list of the requester's topics.\n\nEach call returns a limited list of topics, up to 100. If there are more topics,\na `NextToken` is also returned. Use the `NextToken` parameter in a new\n`ListTopics` call to get further results.\n\nThis action is throttled at 30 transactions per second (TPS).","ref":"AWS.SNS.html#list_topics/3","title":"AWS.SNS.list_topics/3","type":"function"},{"doc":"","ref":"AWS.SNS.html#metadata/0","title":"AWS.SNS.metadata/0","type":"function"},{"doc":"Use this request to opt in a phone number that is opted out, which enables you\nto resume sending SMS messages to the number.\n\nYou can opt in a phone number only once every 30 days.","ref":"AWS.SNS.html#opt_in_phone_number/3","title":"AWS.SNS.opt_in_phone_number/3","type":"function"},{"doc":"Sends a message to an Amazon SNS topic, a text message (SMS message) directly to\na phone number, or a message to a mobile platform endpoint (when you specify the\n`TargetArn`).\n\nIf you send a message to a topic, Amazon SNS delivers the message to each\nendpoint that is subscribed to the topic. The format of the message depends on\nthe notification protocol for each subscribed endpoint.\n\nWhen a `messageId` is returned, the message is saved and Amazon SNS immediately\ndelivers it to subscribers.\n\nTo use the `Publish` action for publishing a message to a mobile endpoint, such\nas an app on a Kindle device or mobile phone, you must specify the EndpointArn\nfor the TargetArn parameter. The EndpointArn is returned when making a call with\nthe `CreatePlatformEndpoint` action.\n\nFor more information about formatting messages, see [Send Custom Platform-Specific Payloads in Messages to Mobile\nDevices](https://docs.aws.amazon.com/sns/latest/dg/mobile-push-send-custommessage.html).\n\nYou can publish messages only to topics and endpoints in the same Amazon Web\nServices Region.","ref":"AWS.SNS.html#publish/3","title":"AWS.SNS.publish/3","type":"function"},{"doc":"Publishes up to ten messages to the specified topic.\n\nThis is a batch version of `Publish`. For FIFO topics, multiple messages within\na single batch are published in the order they are sent, and messages are\ndeduplicated within the batch and across batches for 5 minutes.\n\nThe result of publishing each message is reported individually in the response.\nBecause the batch request can result in a combination of successful and\nunsuccessful actions, you should check for batch errors even when the call\nreturns an HTTP status code of `200`.\n\nThe maximum allowed individual message size and the maximum total payload size\n(the sum of the individual lengths of all of the batched messages) are both 256\nKB (262,144 bytes).\n\nSome actions take lists of parameters. These lists are specified using the\n`param.n` notation. Values of `n` are integers starting from 1. For example, a\nparameter list with two elements looks like this:\n\n&AttributeName.1=first\n\n&AttributeName.2=second\n\nIf you send a batch message to a topic, Amazon SNS publishes the batch message\nto each endpoint that is subscribed to the topic. The format of the batch\nmessage depends on the notification protocol for each subscribed endpoint.\n\nWhen a `messageId` is returned, the batch message is saved and Amazon SNS\nimmediately delivers the message to subscribers.","ref":"AWS.SNS.html#publish_batch/3","title":"AWS.SNS.publish_batch/3","type":"function"},{"doc":"Adds or updates an inline policy document that is stored in the specified Amazon\nSNS topic.","ref":"AWS.SNS.html#put_data_protection_policy/3","title":"AWS.SNS.put_data_protection_policy/3","type":"function"},{"doc":"Removes a statement from a topic's access control policy.\n\nTo remove the ability to change topic permissions, you must deny permissions to\nthe `AddPermission`, `RemovePermission`, and `SetTopicAttributes` actions in\nyour IAM policy.","ref":"AWS.SNS.html#remove_permission/3","title":"AWS.SNS.remove_permission/3","type":"function"},{"doc":"Sets the attributes for an endpoint for a device on one of the supported push\nnotification services, such as GCM (Firebase Cloud Messaging) and APNS.\n\nFor more information, see [Using Amazon SNS Mobile Push Notifications](https://docs.aws.amazon.com/sns/latest/dg/SNSMobilePush.html).","ref":"AWS.SNS.html#set_endpoint_attributes/3","title":"AWS.SNS.set_endpoint_attributes/3","type":"function"},{"doc":"Sets the attributes of the platform application object for the supported push\nnotification services, such as APNS and GCM (Firebase Cloud Messaging).\n\nFor more information, see [Using Amazon SNS Mobile Push Notifications](https://docs.aws.amazon.com/sns/latest/dg/SNSMobilePush.html).\nFor information on configuring attributes for message delivery status, see\n[Using Amazon SNS Application Attributes for Message Delivery Status](https://docs.aws.amazon.com/sns/latest/dg/sns-msg-status.html).","ref":"AWS.SNS.html#set_platform_application_attributes/3","title":"AWS.SNS.set_platform_application_attributes/3","type":"function"},{"doc":"Use this request to set the default settings for sending SMS messages and\nreceiving daily SMS usage reports.\n\nYou can override some of these settings for a single message when you use the\n`Publish` action with the `MessageAttributes.entry.N` parameter. For more\ninformation, see [Publishing to a mobile phone](https://docs.aws.amazon.com/sns/latest/dg/sms_publish-to-phone.html) in\nthe *Amazon SNS Developer Guide*.\n\nTo use this operation, you must grant the Amazon SNS service principal\n(`sns.amazonaws.com`) permission to perform the `s3:ListBucket` action.","ref":"AWS.SNS.html#set_sms_attributes/3","title":"AWS.SNS.set_sms_attributes/3","type":"function"},{"doc":"Allows a subscription owner to set an attribute of the subscription to a new\nvalue.","ref":"AWS.SNS.html#set_subscription_attributes/3","title":"AWS.SNS.set_subscription_attributes/3","type":"function"},{"doc":"Allows a topic owner to set an attribute of the topic to a new value.\n\nTo remove the ability to change topic permissions, you must deny permissions to\nthe `AddPermission`, `RemovePermission`, and `SetTopicAttributes` actions in\nyour IAM policy.","ref":"AWS.SNS.html#set_topic_attributes/3","title":"AWS.SNS.set_topic_attributes/3","type":"function"},{"doc":"Subscribes an endpoint to an Amazon SNS topic.\n\nIf the endpoint type is HTTP/S or email, or if the endpoint and the topic are\nnot in the same Amazon Web Services account, the endpoint owner must run the\n`ConfirmSubscription` action to confirm the subscription.\n\nYou call the `ConfirmSubscription` action with the token from the subscription\nresponse. Confirmation tokens are valid for two days.\n\nThis action is throttled at 100 transactions per second (TPS).","ref":"AWS.SNS.html#subscribe/3","title":"AWS.SNS.subscribe/3","type":"function"},{"doc":"Add tags to the specified Amazon SNS topic.\n\nFor an overview, see [Amazon SNS Tags](https://docs.aws.amazon.com/sns/latest/dg/sns-tags.html) in the *Amazon\nSNS Developer Guide*.\n\nWhen you use topic tags, keep the following guidelines in mind:\n\n  * Adding more than 50 tags to a topic isn't recommended.\n\n  * Tags don't have any semantic meaning. Amazon SNS interprets tags\nas character strings.\n\n  * Tags are case-sensitive.\n\n  * A new tag with a key identical to that of an existing tag\noverwrites the existing tag.\n\n  * Tagging actions are limited to 10 TPS per Amazon Web Services\naccount, per Amazon Web Services Region. If your application requires a higher\nthroughput, file a [technical support request](https://console.aws.amazon.com/support/home#/case/create?issueType=technical).","ref":"AWS.SNS.html#tag_resource/3","title":"AWS.SNS.tag_resource/3","type":"function"},{"doc":"Deletes a subscription.\n\nIf the subscription requires authentication for deletion, only the owner of the\nsubscription or the topic's owner can unsubscribe, and an Amazon Web Services\nsignature is required. If the `Unsubscribe` call does not require authentication\nand the requester is not the subscription owner, a final cancellation message is\ndelivered to the endpoint, so that the endpoint owner can easily resubscribe to\nthe topic if the `Unsubscribe` request was unintended.\n\nAmazon SQS queue subscriptions require authentication for deletion. Only the\nowner of the subscription, or the owner of the topic can unsubscribe using the\nrequired Amazon Web Services signature.\n\nThis action is throttled at 100 transactions per second (TPS).","ref":"AWS.SNS.html#unsubscribe/3","title":"AWS.SNS.unsubscribe/3","type":"function"},{"doc":"Remove tags from the specified Amazon SNS topic.\n\nFor an overview, see [Amazon SNS Tags](https://docs.aws.amazon.com/sns/latest/dg/sns-tags.html) in the *Amazon\nSNS Developer Guide*.","ref":"AWS.SNS.html#untag_resource/3","title":"AWS.SNS.untag_resource/3","type":"function"},{"doc":"Verifies a destination phone number with a one-time password (OTP) for the\ncalling Amazon Web Services account.\n\nWhen you start using Amazon SNS to send SMS messages, your Amazon Web Services\naccount is in the *SMS sandbox*. The SMS sandbox provides a safe environment for\nyou to try Amazon SNS features without risking your reputation as an SMS sender.\nWhile your Amazon Web Services account is in the SMS sandbox, you can use all of\nthe features of Amazon SNS. However, you can send SMS messages only to verified\ndestination phone numbers. For more information, including how to move out of\nthe sandbox to send messages without restrictions, see [SMS sandbox](https://docs.aws.amazon.com/sns/latest/dg/sns-sms-sandbox.html) in the\n*Amazon SNS Developer Guide*.","ref":"AWS.SNS.html#verify_sms_sandbox_phone_number/3","title":"AWS.SNS.verify_sms_sandbox_phone_number/3","type":"function"},{"doc":"Welcome to the *Amazon SQS API Reference*.\n\nAmazon SQS is a reliable, highly-scalable hosted queue for storing messages as\nthey travel between applications or microservices. Amazon SQS moves data between\ndistributed application components and helps you decouple these components.\n\nFor information on the permissions you need to use this API, see [Identity and access\nmanagement](https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-authentication-and-access-control.html)\nin the *Amazon SQS Developer Guide.*\n\nYou can use [Amazon Web Services SDKs](http://aws.amazon.com/tools/#sdk) to access Amazon SQS using your favorite programming language. The SDKs perform\ntasks such as the following automatically:\n\n  * Cryptographically sign your service requests\n\n  * Retry requests\n\n  * Handle error responses","ref":"AWS.SQS.html","title":"AWS.SQS","type":"module"},{"doc":"* [Amazon SQS Product Page](http://aws.amazon.com/sqs/)\n\n  * *Amazon SQS Developer Guide*\n\n    * [Making API Requests](https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-making-api-requests.html)\n\n    * [Amazon SQS Message Attributes](https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-message-metadata.html#sqs-message-attributes)\n\n    * [Amazon SQS Dead-Letter Queues](https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-dead-letter-queues.html)\n\n  * [Amazon SQS in the *Command Line Interface*\n](http://docs.aws.amazon.com/cli/latest/reference/sqs/index.html)\n\n  * *Amazon Web Services General Reference*\n\n    * [Regions and Endpoints](https://docs.aws.amazon.com/general/latest/gr/rande.html#sqs_region)","ref":"AWS.SQS.html#module-additional-information","title":"Additional information - AWS.SQS","type":"module"},{"doc":"Adds a permission to a queue for a specific\n[principal](https://docs.aws.amazon.com/general/latest/gr/glos-chap.html#P).  This allows sharing access to the queue.\n\nWhen you create a queue, you have full control access rights for the queue. Only\nyou, the owner of the queue, can grant or deny permissions to the queue. For\nmore information about these permissions, see [Allow Developers to Write\nMessages to a Shared\nQueue](https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-writing-an-sqs-policy.html#write-messages-to-shared-queue)\nin the *Amazon SQS Developer Guide*.\n\n   `AddPermission` generates a policy for you. You can use `\n`SetQueueAttributes` ` to upload your policy. For more information, see [Using Custom Policies with the Amazon SQS Access Policy\nLanguage](https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-creating-custom-policies.html)\nin the *Amazon SQS Developer Guide*.\n\n   An Amazon SQS policy can have a maximum of seven actions per\nstatement.\n\n   To remove the ability to change queue permissions, you must deny\npermission to the `AddPermission`, `RemovePermission`, and `SetQueueAttributes`\nactions in your IAM policy.\n\n   Amazon SQS `AddPermission` does not support adding a non-account\nprincipal.\n\nCross-account permissions don't apply to this action. For more information, see\n[Grant cross-account permissions to a role and a username](https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-customer-managed-policy-examples.html#grant-cross-account-permissions-to-role-and-user-name)\nin the *Amazon SQS Developer Guide*.","ref":"AWS.SQS.html#add_permission/3","title":"AWS.SQS.add_permission/3","type":"function"},{"doc":"Cancels a specified message movement task.\n\nA message movement can only be cancelled when the current status is RUNNING.\nCancelling a message movement task does not revert the messages that have\nalready been moved. It can only stop the messages that have not been moved yet.\n\n   This action is currently limited to supporting message redrive from\n[dead-letter queues (DLQs)](https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-dead-letter-queues.html)\nonly. In this context, the source queue is the dead-letter queue (DLQ), while\nthe destination queue can be the original source queue (from which the messages\nwere driven to the dead-letter-queue), or a custom destination queue.\n\n   Currently, only standard queues are supported.\n\n   Only one active message movement task is supported per queue at any\ngiven time.","ref":"AWS.SQS.html#cancel_message_move_task/3","title":"AWS.SQS.cancel_message_move_task/3","type":"function"},{"doc":"Changes the visibility timeout of a specified message in a queue to a new value.\n\nThe default visibility timeout for a message is 30 seconds. The minimum is 0\nseconds. The maximum is 12 hours. For more information, see [Visibility Timeout](https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-visibility-timeout.html)\nin the *Amazon SQS Developer Guide*.\n\nFor example, if the default timeout for a queue is 60 seconds, 15 seconds have\nelapsed since you received the message, and you send a ChangeMessageVisibility\ncall with `VisibilityTimeout` set to 10 seconds, the 10 seconds begin to count\nfrom the time that you make the `ChangeMessageVisibility` call. Thus, any\nattempt to change the visibility timeout or to delete that message 10 seconds\nafter you initially change the visibility timeout (a total of 25 seconds) might\nresult in an error.\n\nAn Amazon SQS message has three basic states:\n\n  1. Sent to a queue by a producer.\n\n  2. Received from the queue by a consumer.\n\n  3. Deleted from the queue.\n\nA message is considered to be *stored* after it is sent to a queue by a\nproducer, but not yet received from the queue by a consumer (that is, between\nstates 1 and 2). There is no limit to the number of stored messages. A message\nis considered to be *in flight* after it is received from a queue by a consumer,\nbut not yet deleted from the queue (that is, between states 2 and 3). There is a\nlimit to the number of in flight messages.\n\nLimits that apply to in flight messages are unrelated to the *unlimited* number\nof stored messages.\n\nFor most standard queues (depending on queue traffic and message backlog), there\ncan be a maximum of approximately 120,000 in flight messages (received from a\nqueue by a consumer, but not yet deleted from the queue). If you reach this\nlimit, Amazon SQS returns the `OverLimit` error message. To avoid reaching the\nlimit, you should delete messages from the queue after they're processed. You\ncan also increase the number of queues you use to process your messages. To\nrequest a limit increase, [file a support request](https://console.aws.amazon.com/support/home#/case/create?issueType=service-limit-increase&limitType=service-code-sqs).\n\nFor FIFO queues, there can be a maximum of 20,000 in flight messages (received\nfrom a queue by a consumer, but not yet deleted from the queue). If you reach\nthis limit, Amazon SQS returns no error messages.\n\nIf you attempt to set the `VisibilityTimeout` to a value greater than the\nmaximum time left, Amazon SQS returns an error. Amazon SQS doesn't automatically\nrecalculate and increase the timeout to the maximum remaining time.\n\nUnlike with a queue, when you change the visibility timeout for a specific\nmessage the timeout value is applied immediately but isn't saved in memory for\nthat message. If you don't delete a message after it is received, the visibility\ntimeout for the message reverts to the original timeout value (not to the value\nyou set using the `ChangeMessageVisibility` action) the next time the message is\nreceived.","ref":"AWS.SQS.html#change_message_visibility/3","title":"AWS.SQS.change_message_visibility/3","type":"function"},{"doc":"Changes the visibility timeout of multiple messages.\n\nThis is a batch version of ` `ChangeMessageVisibility`.` The result of the\naction on each message is reported individually in the response. You can send up\nto 10 ` `ChangeMessageVisibility` ` requests with each\n`ChangeMessageVisibilityBatch` action.\n\nBecause the batch request can result in a combination of successful and\nunsuccessful actions, you should check for batch errors even when the call\nreturns an HTTP status code of `200`.","ref":"AWS.SQS.html#change_message_visibility_batch/3","title":"AWS.SQS.change_message_visibility_batch/3","type":"function"},{"doc":"Creates a new standard or FIFO queue.\n\nYou can pass one or more attributes in the request. Keep the following in mind:\n\n  * If you don't specify the `FifoQueue` attribute, Amazon SQS creates\na standard queue.\n\nYou can't change the queue type after you create it and you can't convert an\nexisting standard queue into a FIFO queue. You must either create a new FIFO\nqueue for your application or delete your existing standard queue and recreate\nit as a FIFO queue. For more information, see [Moving From a Standard Queue to a FIFO\nQueue](https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/FIFO-queues.html#FIFO-queues-moving)\nin the *Amazon SQS Developer Guide*.\n\n  * If you don't provide a value for an attribute, the queue is\ncreated with the default value for the attribute.\n\n  * If you delete a queue, you must wait at least 60 seconds before\ncreating a queue with the same name.\n\nTo successfully create a new queue, you must provide a queue name that adheres\nto the [limits related to queues](https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/limits-queues.html)\nand is unique within the scope of your queues.\n\nAfter you create a queue, you must wait at least one second after the queue is\ncreated to be able to use the queue.\n\nTo get the queue URL, use the ` `GetQueueUrl` ` action. ` `GetQueueUrl` `\nrequires only the `QueueName` parameter. be aware of existing queue names:\n\n  * If you provide the name of an existing queue along with the exact\nnames and values of all the queue's attributes, `CreateQueue` returns the queue\nURL for the existing queue.\n\n  * If the queue name, attribute names, or attribute values don't\nmatch an existing queue, `CreateQueue` returns an error.\n\nCross-account permissions don't apply to this action. For more information, see\n[Grant cross-account permissions to a role and a username](https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-customer-managed-policy-examples.html#grant-cross-account-permissions-to-role-and-user-name)\nin the *Amazon SQS Developer Guide*.","ref":"AWS.SQS.html#create_queue/3","title":"AWS.SQS.create_queue/3","type":"function"},{"doc":"Deletes the specified message from the specified queue.\n\nTo select the message to delete, use the `ReceiptHandle` of the message (*not*\nthe `MessageId` which you receive when you send the message). Amazon SQS can\ndelete a message from a queue even if a visibility timeout setting causes the\nmessage to be locked by another consumer. Amazon SQS automatically deletes\nmessages left in a queue longer than the retention period configured for the\nqueue.\n\nThe `ReceiptHandle` is associated with a *specific instance* of receiving a\nmessage. If you receive a message more than once, the `ReceiptHandle` is\ndifferent each time you receive a message. When you use the `DeleteMessage`\naction, you must provide the most recently received `ReceiptHandle` for the\nmessage (otherwise, the request succeeds, but the message will not be deleted).\n\nFor standard queues, it is possible to receive a message even after you delete\nit. This might happen on rare occasions if one of the servers which stores a\ncopy of the message is unavailable when you send the request to delete the\nmessage. The copy remains on the server and might be returned to you during a\nsubsequent receive request. You should ensure that your application is\nidempotent, so that receiving a message more than once does not cause issues.","ref":"AWS.SQS.html#delete_message/3","title":"AWS.SQS.delete_message/3","type":"function"},{"doc":"Deletes up to ten messages from the specified queue.\n\nThis is a batch version of ` `DeleteMessage`.` The result of the action on each\nmessage is reported individually in the response.\n\nBecause the batch request can result in a combination of successful and\nunsuccessful actions, you should check for batch errors even when the call\nreturns an HTTP status code of `200`.","ref":"AWS.SQS.html#delete_message_batch/3","title":"AWS.SQS.delete_message_batch/3","type":"function"},{"doc":"Deletes the queue specified by the `QueueUrl`, regardless of the queue's\ncontents.\n\nBe careful with the `DeleteQueue` action: When you delete a queue, any messages\nin the queue are no longer available.\n\nWhen you delete a queue, the deletion process takes up to 60 seconds. Requests\nyou send involving that queue during the 60 seconds might succeed. For example,\na ` `SendMessage` ` request might succeed, but after 60 seconds the queue and\nthe message you sent no longer exist.\n\nWhen you delete a queue, you must wait at least 60 seconds before creating a\nqueue with the same name.\n\nCross-account permissions don't apply to this action. For more information, see\n[Grant cross-account permissions to a role and a username](https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-customer-managed-policy-examples.html#grant-cross-account-permissions-to-role-and-user-name)\nin the *Amazon SQS Developer Guide*.\n\nThe delete operation uses the HTTP `GET` verb.","ref":"AWS.SQS.html#delete_queue/3","title":"AWS.SQS.delete_queue/3","type":"function"},{"doc":"Gets attributes for the specified queue.\n\nTo determine whether a queue is\n[FIFO](https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/FIFO-queues.html),\nyou can check whether `QueueName` ends with the `.fifo` suffix.","ref":"AWS.SQS.html#get_queue_attributes/3","title":"AWS.SQS.get_queue_attributes/3","type":"function"},{"doc":"Returns the URL of an existing Amazon SQS queue.\n\nTo access a queue that belongs to another AWS account, use the\n`QueueOwnerAWSAccountId` parameter to specify the account ID of the queue's\nowner. The queue's owner must grant you permission to access the queue. For more\ninformation about shared queue access, see ` `AddPermission` ` or see [Allow Developers to Write Messages to a Shared\nQueue](https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-writing-an-sqs-policy.html#write-messages-to-shared-queue)\nin the *Amazon SQS Developer Guide*.","ref":"AWS.SQS.html#get_queue_url/3","title":"AWS.SQS.get_queue_url/3","type":"function"},{"doc":"Returns a list of your queues that have the `RedrivePolicy` queue attribute\nconfigured with a dead-letter queue.\n\nThe `ListDeadLetterSourceQueues` methods supports pagination. Set parameter\n`MaxResults` in the request to specify the maximum number of results to be\nreturned in the response. If you do not set `MaxResults`, the response includes\na maximum of 1,000 results. If you set `MaxResults` and there are additional\nresults to display, the response includes a value for `NextToken`. Use\n`NextToken` as a parameter in your next request to `ListDeadLetterSourceQueues`\nto receive the next page of results.\n\nFor more information about using dead-letter queues, see [Using Amazon SQS Dead-Letter\nQueues](https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-dead-letter-queues.html)\nin the *Amazon SQS Developer Guide*.","ref":"AWS.SQS.html#list_dead_letter_source_queues/3","title":"AWS.SQS.list_dead_letter_source_queues/3","type":"function"},{"doc":"Gets the most recent message movement tasks (up to 10) under a specific source\nqueue.\n\n   This action is currently limited to supporting message redrive from\n[dead-letter queues (DLQs)](https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-dead-letter-queues.html)\nonly. In this context, the source queue is the dead-letter queue (DLQ), while\nthe destination queue can be the original source queue (from which the messages\nwere driven to the dead-letter-queue), or a custom destination queue.\n\n   Currently, only standard queues are supported.\n\n   Only one active message movement task is supported per queue at any\ngiven time.","ref":"AWS.SQS.html#list_message_move_tasks/3","title":"AWS.SQS.list_message_move_tasks/3","type":"function"},{"doc":"List all cost allocation tags added to the specified Amazon SQS queue.\n\nFor an overview, see [Tagging Your Amazon SQS Queues](https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-queue-tags.html)\nin the *Amazon SQS Developer Guide*.\n\nCross-account permissions don't apply to this action. For more information, see\n[Grant cross-account permissions to a role and a username](https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-customer-managed-policy-examples.html#grant-cross-account-permissions-to-role-and-user-name)\nin the *Amazon SQS Developer Guide*.","ref":"AWS.SQS.html#list_queue_tags/3","title":"AWS.SQS.list_queue_tags/3","type":"function"},{"doc":"Returns a list of your queues in the current region.\n\nThe response includes a maximum of 1,000 results. If you specify a value for the\noptional `QueueNamePrefix` parameter, only queues with a name that begins with\nthe specified value are returned.\n\nThe `listQueues` methods supports pagination. Set parameter `MaxResults` in the\nrequest to specify the maximum number of results to be returned in the response.\nIf you do not set `MaxResults`, the response includes a maximum of 1,000\nresults. If you set `MaxResults` and there are additional results to display,\nthe response includes a value for `NextToken`. Use `NextToken` as a parameter in\nyour next request to `listQueues` to receive the next page of results.\n\nCross-account permissions don't apply to this action. For more information, see\n[Grant cross-account permissions to a role and a username](https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-customer-managed-policy-examples.html#grant-cross-account-permissions-to-role-and-user-name)\nin the *Amazon SQS Developer Guide*.","ref":"AWS.SQS.html#list_queues/3","title":"AWS.SQS.list_queues/3","type":"function"},{"doc":"","ref":"AWS.SQS.html#metadata/0","title":"AWS.SQS.metadata/0","type":"function"},{"doc":"Deletes available messages in a queue (including in-flight messages) specified\nby the `QueueURL` parameter.\n\nWhen you use the `PurgeQueue` action, you can't retrieve any messages deleted\nfrom a queue.\n\nThe message deletion process takes up to 60 seconds. We recommend waiting for 60\nseconds regardless of your queue's size.\n\nMessages sent to the queue *before* you call `PurgeQueue` might be received but\nare deleted within the next minute.\n\nMessages sent to the queue *after* you call `PurgeQueue` might be deleted while\nthe queue is being purged.","ref":"AWS.SQS.html#purge_queue/3","title":"AWS.SQS.purge_queue/3","type":"function"},{"doc":"Retrieves one or more messages (up to 10), from the specified queue.\n\nUsing the `WaitTimeSeconds` parameter enables long-poll support. For more\ninformation, see [Amazon SQS Long Polling](https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-long-polling.html)\nin the *Amazon SQS Developer Guide*.\n\nShort poll is the default behavior where a weighted random set of machines is\nsampled on a `ReceiveMessage` call. Thus, only the messages on the sampled\nmachines are returned. If the number of messages in the queue is small (fewer\nthan 1,000), you most likely get fewer messages than you requested per\n`ReceiveMessage` call. If the number of messages in the queue is extremely\nsmall, you might not receive any messages in a particular `ReceiveMessage`\nresponse. If this happens, repeat the request.\n\nFor each message returned, the response includes the following:\n\n  * The message body.\n\n  * An MD5 digest of the message body. For information about MD5, see\n[RFC1321](https://www.ietf.org/rfc/rfc1321.txt).     * The `MessageId` you received when you sent the message to the\nqueue.\n\n  * The receipt handle.\n\n  * The message attributes.\n\n  * An MD5 digest of the message attributes.\n\nThe receipt handle is the identifier you must provide when deleting the message.\nFor more information, see [Queue and Message\nIdentifiers](https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-queue-message-identifiers.html)\nin the *Amazon SQS Developer Guide*.\n\nYou can provide the `VisibilityTimeout` parameter in your request. The parameter\nis applied to the messages that Amazon SQS returns in the response. If you don't\ninclude the parameter, the overall visibility timeout for the queue is used for\nthe returned messages. For more information, see [Visibility Timeout](https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-visibility-timeout.html)\nin the *Amazon SQS Developer Guide*.\n\nA message that isn't deleted or a message whose visibility isn't extended before\nthe visibility timeout expires counts as a failed receive. Depending on the\nconfiguration of the queue, the message might be sent to the dead-letter queue.\n\nIn the future, new attributes might be added. If you write code that calls this\naction, we recommend that you structure your code so that it can handle new\nattributes gracefully.","ref":"AWS.SQS.html#receive_message/3","title":"AWS.SQS.receive_message/3","type":"function"},{"doc":"Revokes any permissions in the queue policy that matches the specified `Label`\nparameter.\n\n   Only the owner of a queue can remove permissions from it.\n\n   Cross-account permissions don't apply to this action. For more\ninformation, see [Grant cross-account permissions to a role and a username](https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-customer-managed-policy-examples.html#grant-cross-account-permissions-to-role-and-user-name)\nin the *Amazon SQS Developer Guide*.\n\n   To remove the ability to change queue permissions, you must deny\npermission to the `AddPermission`, `RemovePermission`, and `SetQueueAttributes`\nactions in your IAM policy.","ref":"AWS.SQS.html#remove_permission/3","title":"AWS.SQS.remove_permission/3","type":"function"},{"doc":"Delivers a message to the specified queue.\n\nA message can include only XML, JSON, and unformatted text. The following\nUnicode characters are allowed:\n\n`#x9` | `#xA` | `#xD` | `#x20` to `#xD7FF` | `#xE000` to `#xFFFD` | `#x10000` to\n`#x10FFFF`\n\nAny characters not included in this list will be rejected. For more information,\nsee the [W3C specification for characters](http://www.w3.org/TR/REC-xml/#charsets).","ref":"AWS.SQS.html#send_message/3","title":"AWS.SQS.send_message/3","type":"function"},{"doc":"You can use `SendMessageBatch` to send up to 10 messages to the specified queue\nby assigning either identical or different values to each message (or by not\nassigning values at all).\n\nThis is a batch version of ` `SendMessage`.` For a FIFO queue, multiple messages\nwithin a single batch are enqueued in the order they are sent.\n\nThe result of sending each message is reported individually in the response.\nBecause the batch request can result in a combination of successful and\nunsuccessful actions, you should check for batch errors even when the call\nreturns an HTTP status code of `200`.\n\nThe maximum allowed individual message size and the maximum total payload size\n(the sum of the individual lengths of all of the batched messages) are both 256\nKiB (262,144 bytes).\n\nA message can include only XML, JSON, and unformatted text. The following\nUnicode characters are allowed:\n\n`#x9` | `#xA` | `#xD` | `#x20` to `#xD7FF` | `#xE000` to `#xFFFD` | `#x10000` to\n`#x10FFFF`\n\nAny characters not included in this list will be rejected. For more information,\nsee the [W3C specification for characters](http://www.w3.org/TR/REC-xml/#charsets).\n\nIf you don't specify the `DelaySeconds` parameter for an entry, Amazon SQS uses\nthe default value for the queue.","ref":"AWS.SQS.html#send_message_batch/3","title":"AWS.SQS.send_message_batch/3","type":"function"},{"doc":"Sets the value of one or more queue attributes.\n\nWhen you change a queue's attributes, the change can take up to 60 seconds for\nmost of the attributes to propagate throughout the Amazon SQS system. Changes\nmade to the `MessageRetentionPeriod` attribute can take up to 15 minutes and\nwill impact existing messages in the queue potentially causing them to be\nexpired and deleted if the `MessageRetentionPeriod` is reduced below the age of\nexisting messages.\n\n   In the future, new attributes might be added. If you write code\nthat calls this action, we recommend that you structure your code so that it can\nhandle new attributes gracefully.\n\n   Cross-account permissions don't apply to this action. For more\ninformation, see [Grant cross-account permissions to a role and a username](https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-customer-managed-policy-examples.html#grant-cross-account-permissions-to-role-and-user-name)\nin the *Amazon SQS Developer Guide*.\n\n   To remove the ability to change queue permissions, you must deny\npermission to the `AddPermission`, `RemovePermission`, and `SetQueueAttributes`\nactions in your IAM policy.","ref":"AWS.SQS.html#set_queue_attributes/3","title":"AWS.SQS.set_queue_attributes/3","type":"function"},{"doc":"Starts an asynchronous task to move messages from a specified source queue to a\nspecified destination queue.\n\n   This action is currently limited to supporting message redrive from\nqueues that are configured as [dead-letter queues (DLQs)](https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-dead-letter-queues.html)\nof other Amazon SQS queues only. Non-SQS queue sources of dead-letter queues,\nsuch as Lambda or Amazon SNS topics, are currently not supported.\n\n   In dead-letter queues redrive context, the `StartMessageMoveTask`\nthe source queue is the DLQ, while the destination queue can be the original\nsource queue (from which the messages were driven to the dead-letter-queue), or\na custom destination queue.\n\n   Currently, only standard queues support redrive. FIFO queues don't\nsupport redrive.\n\n   Only one active message movement task is supported per queue at any\ngiven time.","ref":"AWS.SQS.html#start_message_move_task/3","title":"AWS.SQS.start_message_move_task/3","type":"function"},{"doc":"Add cost allocation tags to the specified Amazon SQS queue.\n\nFor an overview, see [Tagging Your Amazon SQS Queues](https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-queue-tags.html)\nin the *Amazon SQS Developer Guide*.\n\nWhen you use queue tags, keep the following guidelines in mind:\n\n  * Adding more than 50 tags to a queue isn't recommended.\n\n  * Tags don't have any semantic meaning. Amazon SQS interprets tags\nas character strings.\n\n  * Tags are case-sensitive.\n\n  * A new tag with a key identical to that of an existing tag\noverwrites the existing tag.\n\nFor a full list of tag restrictions, see [Quotas related to queues](https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-limits.html#limits-queues)\nin the *Amazon SQS Developer Guide*.\n\nCross-account permissions don't apply to this action. For more information, see\n[Grant cross-account permissions to a role and a username](https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-customer-managed-policy-examples.html#grant-cross-account-permissions-to-role-and-user-name)\nin the *Amazon SQS Developer Guide*.","ref":"AWS.SQS.html#tag_queue/3","title":"AWS.SQS.tag_queue/3","type":"function"},{"doc":"Remove cost allocation tags from the specified Amazon SQS queue.\n\nFor an overview, see [Tagging Your Amazon SQS Queues](https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-queue-tags.html)\nin the *Amazon SQS Developer Guide*.\n\nCross-account permissions don't apply to this action. For more information, see\n[Grant cross-account permissions to a role and a username](https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-customer-managed-policy-examples.html#grant-cross-account-permissions-to-role-and-user-name)\nin the *Amazon SQS Developer Guide*.","ref":"AWS.SQS.html#untag_queue/3","title":"AWS.SQS.untag_queue/3","type":"function"},{"doc":"Amazon Web Services Systems Manager is the operations hub for your Amazon Web\nServices applications and resources and a secure end-to-end management solution\nfor hybrid cloud environments that enables safe and secure operations at scale.\n\nThis reference is intended to be used with the [Amazon Web Services Systems Manager User\nGuide](https://docs.aws.amazon.com/systems-manager/latest/userguide/). To get\nstarted, see [Setting up Amazon Web Services Systems Manager](https://docs.aws.amazon.com/systems-manager/latest/userguide/systems-manager-setting-up.html).","ref":"AWS.SSM.html","title":"AWS.SSM","type":"module"},{"doc":"* For information about each of the capabilities that comprise\nSystems Manager, see [Systems Manager capabilities](https://docs.aws.amazon.com/systems-manager/latest/userguide/what-is-systems-manager.html#systems-manager-capabilities)\nin the *Amazon Web Services Systems Manager User Guide*.\n\n  * For details about predefined runbooks for Automation, a capability\nof Amazon Web Services Systems Manager, see the * [Systems Manager Automation runbook\nreference](https://docs.aws.amazon.com/systems-manager-automation-runbooks/latest/userguide/automation-runbook-reference.html)\n*.\n\n  * For information about AppConfig, a capability of Systems Manager,\nsee the * [AppConfig User Guide](https://docs.aws.amazon.com/appconfig/latest/userguide/) * and the *\n[AppConfig API Reference](https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/) *.\n\n  * For information about Incident Manager, a capability of Systems\nManager, see the * [Systems Manager Incident Manager User Guide](https://docs.aws.amazon.com/incident-manager/latest/userguide/) * and the\n* [Systems Manager Incident Manager API Reference](https://docs.aws.amazon.com/incident-manager/latest/APIReference/) *.","ref":"AWS.SSM.html#module-related-resources","title":"Related resources - AWS.SSM","type":"module"},{"doc":"Adds or overwrites one or more tags for the specified resource.\n\n*Tags* are metadata that you can assign to your automations, documents, managed\nnodes, maintenance windows, Parameter Store parameters, and patch baselines.\nTags enable you to categorize your resources in different ways, for example, by\npurpose, owner, or environment. Each tag consists of a key and an optional\nvalue, both of which you define. For example, you could define a set of tags for\nyour account's managed nodes that helps you track each node's owner and stack\nlevel. For example:\n\n  * `Key=Owner,Value=DbAdmin`\n\n  * `Key=Owner,Value=SysAdmin`\n\n  * `Key=Owner,Value=Dev`\n\n  * `Key=Stack,Value=Production`\n\n  * `Key=Stack,Value=Pre-Production`\n\n  * `Key=Stack,Value=Test`\n\nMost resources can have a maximum of 50 tags. Automations can have a maximum of\n5 tags.\n\nWe recommend that you devise a set of tag keys that meets your needs for each\nresource type. Using a consistent set of tag keys makes it easier for you to\nmanage your resources. You can search and filter the resources based on the tags\nyou add. Tags don't have any semantic meaning to and are interpreted strictly as\na string of characters.\n\nFor more information about using tags with Amazon Elastic Compute Cloud (Amazon\nEC2) instances, see [Tagging your Amazon EC2 resources](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Using_Tags.html)\nin the *Amazon EC2 User Guide*.","ref":"AWS.SSM.html#add_tags_to_resource/3","title":"AWS.SSM.add_tags_to_resource/3","type":"function"},{"doc":"Associates a related item to a Systems Manager OpsCenter OpsItem.\n\nFor example, you can associate an Incident Manager incident or analysis with an\nOpsItem. Incident Manager and OpsCenter are capabilities of Amazon Web Services\nSystems Manager.","ref":"AWS.SSM.html#associate_ops_item_related_item/3","title":"AWS.SSM.associate_ops_item_related_item/3","type":"function"},{"doc":"Attempts to cancel the command specified by the Command ID.\n\nThere is no guarantee that the command will be terminated and the underlying\nprocess stopped.","ref":"AWS.SSM.html#cancel_command/3","title":"AWS.SSM.cancel_command/3","type":"function"},{"doc":"Stops a maintenance window execution that is already in progress and cancels any\ntasks in the window that haven't already starting running.\n\nTasks already in progress will continue to completion.","ref":"AWS.SSM.html#cancel_maintenance_window_execution/3","title":"AWS.SSM.cancel_maintenance_window_execution/3","type":"function"},{"doc":"Generates an activation code and activation ID you can use to register your\non-premises servers, edge devices, or virtual machine (VM) with Amazon Web\nServices Systems Manager.\n\nRegistering these machines with Systems Manager makes it possible to manage them\nusing Systems Manager capabilities. You use the activation code and ID when\ninstalling SSM Agent on machines in your hybrid environment. For more\ninformation about requirements for managing on-premises machines using Systems\nManager, see [Setting up Amazon Web Services Systems Manager for hybrid environments](https://docs.aws.amazon.com/systems-manager/latest/userguide/systems-manager-managedinstances.html)\nin the *Amazon Web Services Systems Manager User Guide*.\n\nAmazon Elastic Compute Cloud (Amazon EC2) instances, edge devices, and\non-premises servers and VMs that are configured for Systems Manager are all\ncalled *managed nodes*.","ref":"AWS.SSM.html#create_activation/3","title":"AWS.SSM.create_activation/3","type":"function"},{"doc":"A State Manager association defines the state that you want to maintain on your\nmanaged nodes.\n\nFor example, an association can specify that anti-virus software must be\ninstalled and running on your managed nodes, or that certain ports must be\nclosed. For static targets, the association specifies a schedule for when the\nconfiguration is reapplied. For dynamic targets, such as an Amazon Web Services\nresource group or an Amazon Web Services autoscaling group, State Manager, a\ncapability of Amazon Web Services Systems Manager applies the configuration when\nnew managed nodes are added to the group. The association also specifies actions\nto take when applying the configuration. For example, an association for\nanti-virus software might run once a day. If the software isn't installed, then\nState Manager installs it. If the software is installed, but the service isn't\nrunning, then the association might instruct State Manager to start the service.","ref":"AWS.SSM.html#create_association/3","title":"AWS.SSM.create_association/3","type":"function"},{"doc":"Associates the specified Amazon Web Services Systems Manager document (SSM\ndocument) with the specified managed nodes or targets.\n\nWhen you associate a document with one or more managed nodes using IDs or tags,\nAmazon Web Services Systems Manager Agent (SSM Agent) running on the managed\nnode processes the document and configures the node as specified.\n\nIf you associate a document with a managed node that already has an associated\ndocument, the system returns the AssociationAlreadyExists exception.","ref":"AWS.SSM.html#create_association_batch/3","title":"AWS.SSM.create_association_batch/3","type":"function"},{"doc":"Creates a Amazon Web Services Systems Manager (SSM document).\n\nAn SSM document defines the actions that Systems Manager performs on your\nmanaged nodes. For more information about SSM documents, including information\nabout supported schemas, features, and syntax, see [Amazon Web Services Systems Manager\nDocuments](https://docs.aws.amazon.com/systems-manager/latest/userguide/sysman-ssm-docs.html)\nin the *Amazon Web Services Systems Manager User Guide*.","ref":"AWS.SSM.html#create_document/3","title":"AWS.SSM.create_document/3","type":"function"},{"doc":"Creates a new maintenance window.\n\nThe value you specify for `Duration` determines the specific end time for the\nmaintenance window based on the time it begins. No maintenance window tasks are\npermitted to start after the resulting endtime minus the number of hours you\nspecify for `Cutoff`. For example, if the maintenance window starts at 3 PM, the\nduration is three hours, and the value you specify for `Cutoff` is one hour, no\nmaintenance window tasks can start after 5 PM.","ref":"AWS.SSM.html#create_maintenance_window/3","title":"AWS.SSM.create_maintenance_window/3","type":"function"},{"doc":"Creates a new OpsItem.\n\nYou must have permission in Identity and Access Management (IAM) to create a new\nOpsItem. For more information, see [Set up OpsCenter](https://docs.aws.amazon.com/systems-manager/latest/userguide/OpsCenter-setup.html)\nin the *Amazon Web Services Systems Manager User Guide*.\n\nOperations engineers and IT professionals use Amazon Web Services Systems\nManager OpsCenter to view, investigate, and remediate operational issues\nimpacting the performance and health of their Amazon Web Services resources. For\nmore information, see [Amazon Web Services Systems Manager OpsCenter](https://docs.aws.amazon.com/systems-manager/latest/userguide/OpsCenter.html)\nin the *Amazon Web Services Systems Manager User Guide*.","ref":"AWS.SSM.html#create_ops_item/3","title":"AWS.SSM.create_ops_item/3","type":"function"},{"doc":"If you create a new application in Application Manager, Amazon Web Services\nSystems Manager calls this API operation to specify information about the new\napplication, including the application type.","ref":"AWS.SSM.html#create_ops_metadata/3","title":"AWS.SSM.create_ops_metadata/3","type":"function"},{"doc":"Creates a patch baseline.\n\nFor information about valid key-value pairs in `PatchFilters` for each supported\noperating system type, see `PatchFilter`.","ref":"AWS.SSM.html#create_patch_baseline/3","title":"AWS.SSM.create_patch_baseline/3","type":"function"},{"doc":"A resource data sync helps you view data from multiple sources in a single\nlocation.\n\nAmazon Web Services Systems Manager offers two types of resource data sync:\n`SyncToDestination` and `SyncFromSource`.\n\nYou can configure Systems Manager Inventory to use the `SyncToDestination` type\nto synchronize Inventory data from multiple Amazon Web Services Regions to a\nsingle Amazon Simple Storage Service (Amazon S3) bucket. For more information,\nsee [Configuring resource data sync for Inventory](https://docs.aws.amazon.com/systems-manager/latest/userguide/sysman-inventory-datasync.html)\nin the *Amazon Web Services Systems Manager User Guide*.\n\nYou can configure Systems Manager Explorer to use the `SyncFromSource` type to\nsynchronize operational work items (OpsItems) and operational data (OpsData)\nfrom multiple Amazon Web Services Regions to a single Amazon S3 bucket. This\ntype can synchronize OpsItems and OpsData from multiple Amazon Web Services\naccounts and Amazon Web Services Regions or `EntireOrganization` by using\nOrganizations. For more information, see [Setting up Systems Manager Explorer to display data from multiple accounts and\nRegions](https://docs.aws.amazon.com/systems-manager/latest/userguide/Explorer-resource-data-sync.html)\nin the *Amazon Web Services Systems Manager User Guide*.\n\nA resource data sync is an asynchronous operation that returns immediately.\nAfter a successful initial sync is completed, the system continuously syncs\ndata. To check the status of a sync, use the `ListResourceDataSync`.\n\nBy default, data isn't encrypted in Amazon S3. We strongly recommend that you\nenable encryption in Amazon S3 to ensure secure data storage. We also recommend\nthat you secure access to the Amazon S3 bucket by creating a restrictive bucket\npolicy.","ref":"AWS.SSM.html#create_resource_data_sync/3","title":"AWS.SSM.create_resource_data_sync/3","type":"function"},{"doc":"Deletes an activation.\n\nYou aren't required to delete an activation. If you delete an activation, you\ncan no longer use it to register additional managed nodes. Deleting an\nactivation doesn't de-register managed nodes. You must manually de-register\nmanaged nodes.","ref":"AWS.SSM.html#delete_activation/3","title":"AWS.SSM.delete_activation/3","type":"function"},{"doc":"Disassociates the specified Amazon Web Services Systems Manager document (SSM\ndocument) from the specified managed node.\n\nIf you created the association by using the `Targets` parameter, then you must\ndelete the association by using the association ID.\n\nWhen you disassociate a document from a managed node, it doesn't change the\nconfiguration of the node. To change the configuration state of a managed node\nafter you disassociate a document, you must create a new document with the\ndesired configuration and associate it with the node.","ref":"AWS.SSM.html#delete_association/3","title":"AWS.SSM.delete_association/3","type":"function"},{"doc":"Deletes the Amazon Web Services Systems Manager document (SSM document) and all\nmanaged node associations to the document.\n\nBefore you delete the document, we recommend that you use `DeleteAssociation` to\ndisassociate all managed nodes that are associated with the document.","ref":"AWS.SSM.html#delete_document/3","title":"AWS.SSM.delete_document/3","type":"function"},{"doc":"Delete a custom inventory type or the data associated with a custom Inventory\ntype.\n\nDeleting a custom inventory type is also referred to as deleting a custom\ninventory schema.","ref":"AWS.SSM.html#delete_inventory/3","title":"AWS.SSM.delete_inventory/3","type":"function"},{"doc":"Deletes a maintenance window.","ref":"AWS.SSM.html#delete_maintenance_window/3","title":"AWS.SSM.delete_maintenance_window/3","type":"function"},{"doc":"Delete an OpsItem.\n\nYou must have permission in Identity and Access Management (IAM) to delete an\nOpsItem.\n\nNote the following important information about this operation.\n\n   Deleting an OpsItem is irreversible. You can't restore a deleted\nOpsItem.\n\n   This operation uses an *eventual consistency model*, which means\nthe system can take a few minutes to complete this operation. If you delete an\nOpsItem and immediately call, for example, `GetOpsItem`, the deleted OpsItem\nmight still appear in the response.\n\n   This operation is idempotent. The system doesn't throw an exception\nif you repeatedly call this operation for the same OpsItem. If the first call is\nsuccessful, all additional calls return the same successful response as the\nfirst call.\n\n   This operation doesn't support cross-account calls. A delegated\nadministrator or management account can't delete OpsItems in other accounts,\neven if OpsCenter has been set up for cross-account administration. For more\ninformation about cross-account administration, see [Setting up OpsCenter to centrally manage OpsItems across\naccounts](https://docs.aws.amazon.com/systems-manager/latest/userguide/OpsCenter-setting-up-cross-account.html)\nin the *Systems Manager User Guide*.","ref":"AWS.SSM.html#delete_ops_item/3","title":"AWS.SSM.delete_ops_item/3","type":"function"},{"doc":"Delete OpsMetadata related to an application.","ref":"AWS.SSM.html#delete_ops_metadata/3","title":"AWS.SSM.delete_ops_metadata/3","type":"function"},{"doc":"Delete a parameter from the system.\n\nAfter deleting a parameter, wait for at least 30 seconds to create a parameter\nwith the same name.","ref":"AWS.SSM.html#delete_parameter/3","title":"AWS.SSM.delete_parameter/3","type":"function"},{"doc":"Delete a list of parameters.\n\nAfter deleting a parameter, wait for at least 30 seconds to create a parameter\nwith the same name.","ref":"AWS.SSM.html#delete_parameters/3","title":"AWS.SSM.delete_parameters/3","type":"function"},{"doc":"Deletes a patch baseline.","ref":"AWS.SSM.html#delete_patch_baseline/3","title":"AWS.SSM.delete_patch_baseline/3","type":"function"},{"doc":"Deletes a resource data sync configuration.\n\nAfter the configuration is deleted, changes to data on managed nodes are no\nlonger synced to or from the target. Deleting a sync configuration doesn't\ndelete data.","ref":"AWS.SSM.html#delete_resource_data_sync/3","title":"AWS.SSM.delete_resource_data_sync/3","type":"function"},{"doc":"Deletes a Systems Manager resource policy.\n\nA resource policy helps you to define the IAM entity (for example, an Amazon Web\nServices account) that can manage your Systems Manager resources. Currently,\n`OpsItemGroup` is the only resource that supports Systems Manager resource\npolicies. The resource policy for `OpsItemGroup` enables Amazon Web Services\naccounts to view and interact with OpsCenter operational work items (OpsItems).","ref":"AWS.SSM.html#delete_resource_policy/3","title":"AWS.SSM.delete_resource_policy/3","type":"function"},{"doc":"Removes the server or virtual machine from the list of registered servers.\n\nYou can reregister the node again at any time. If you don't plan to use Run\nCommand on the server, we suggest uninstalling SSM Agent first.","ref":"AWS.SSM.html#deregister_managed_instance/3","title":"AWS.SSM.deregister_managed_instance/3","type":"function"},{"doc":"Removes a patch group from a patch baseline.","ref":"AWS.SSM.html#deregister_patch_baseline_for_patch_group/3","title":"AWS.SSM.deregister_patch_baseline_for_patch_group/3","type":"function"},{"doc":"Removes a target from a maintenance window.","ref":"AWS.SSM.html#deregister_target_from_maintenance_window/3","title":"AWS.SSM.deregister_target_from_maintenance_window/3","type":"function"},{"doc":"Removes a task from a maintenance window.","ref":"AWS.SSM.html#deregister_task_from_maintenance_window/3","title":"AWS.SSM.deregister_task_from_maintenance_window/3","type":"function"},{"doc":"Describes details about the activation, such as the date and time the activation\nwas created, its expiration date, the Identity and Access Management (IAM) role\nassigned to the managed nodes in the activation, and the number of nodes\nregistered by using this activation.","ref":"AWS.SSM.html#describe_activations/3","title":"AWS.SSM.describe_activations/3","type":"function"},{"doc":"Describes the association for the specified target or managed node.\n\nIf you created the association by using the `Targets` parameter, then you must\nretrieve the association by using the association ID.","ref":"AWS.SSM.html#describe_association/3","title":"AWS.SSM.describe_association/3","type":"function"},{"doc":"Views information about a specific execution of a specific association.","ref":"AWS.SSM.html#describe_association_execution_targets/3","title":"AWS.SSM.describe_association_execution_targets/3","type":"function"},{"doc":"Views all executions for a specific association ID.","ref":"AWS.SSM.html#describe_association_executions/3","title":"AWS.SSM.describe_association_executions/3","type":"function"},{"doc":"Provides details about all active and terminated Automation executions.","ref":"AWS.SSM.html#describe_automation_executions/3","title":"AWS.SSM.describe_automation_executions/3","type":"function"},{"doc":"Information about all active and terminated step executions in an Automation\nworkflow.","ref":"AWS.SSM.html#describe_automation_step_executions/3","title":"AWS.SSM.describe_automation_step_executions/3","type":"function"},{"doc":"Lists all patches eligible to be included in a patch baseline.\n\nCurrently, `DescribeAvailablePatches` supports only the Amazon Linux 1, Amazon\nLinux 2, and Windows Server operating systems.","ref":"AWS.SSM.html#describe_available_patches/3","title":"AWS.SSM.describe_available_patches/3","type":"function"},{"doc":"Describes the specified Amazon Web Services Systems Manager document (SSM\ndocument).","ref":"AWS.SSM.html#describe_document/3","title":"AWS.SSM.describe_document/3","type":"function"},{"doc":"Describes the permissions for a Amazon Web Services Systems Manager document\n(SSM document).\n\nIf you created the document, you are the owner. If a document is shared, it can\neither be shared privately (by specifying a user's Amazon Web Services account\nID) or publicly (*All*).","ref":"AWS.SSM.html#describe_document_permission/3","title":"AWS.SSM.describe_document_permission/3","type":"function"},{"doc":"All associations for the managed node(s).","ref":"AWS.SSM.html#describe_effective_instance_associations/3","title":"AWS.SSM.describe_effective_instance_associations/3","type":"function"},{"doc":"Retrieves the current effective patches (the patch and the approval state) for\nthe specified patch baseline.\n\nApplies to patch baselines for Windows only.","ref":"AWS.SSM.html#describe_effective_patches_for_patch_baseline/3","title":"AWS.SSM.describe_effective_patches_for_patch_baseline/3","type":"function"},{"doc":"The status of the associations for the managed node(s).","ref":"AWS.SSM.html#describe_instance_associations_status/3","title":"AWS.SSM.describe_instance_associations_status/3","type":"function"},{"doc":"Provides information about one or more of your managed nodes, including the\noperating system platform, SSM Agent version, association status, and IP\naddress.\n\nThis operation does not return information for nodes that are either Stopped or\nTerminated.\n\nIf you specify one or more node IDs, the operation returns information for those\nmanaged nodes. If you don't specify node IDs, it returns information for all\nyour managed nodes. If you specify a node ID that isn't valid or a node that you\ndon't own, you receive an error.\n\nThe `IamRole` field returned for this API operation is the Identity and Access\nManagement (IAM) role assigned to on-premises managed nodes. This operation does\nnot return the IAM role for EC2 instances.","ref":"AWS.SSM.html#describe_instance_information/3","title":"AWS.SSM.describe_instance_information/3","type":"function"},{"doc":"Retrieves the high-level patch state of one or more managed nodes.","ref":"AWS.SSM.html#describe_instance_patch_states/3","title":"AWS.SSM.describe_instance_patch_states/3","type":"function"},{"doc":"Retrieves the high-level patch state for the managed nodes in the specified\npatch group.","ref":"AWS.SSM.html#describe_instance_patch_states_for_patch_group/3","title":"AWS.SSM.describe_instance_patch_states_for_patch_group/3","type":"function"},{"doc":"Retrieves information about the patches on the specified managed node and their\nstate relative to the patch baseline being used for the node.","ref":"AWS.SSM.html#describe_instance_patches/3","title":"AWS.SSM.describe_instance_patches/3","type":"function"},{"doc":"Describes a specific delete inventory operation.","ref":"AWS.SSM.html#describe_inventory_deletions/3","title":"AWS.SSM.describe_inventory_deletions/3","type":"function"},{"doc":"Retrieves the individual task executions (one per target) for a particular task\nrun as part of a maintenance window execution.","ref":"AWS.SSM.html#describe_maintenance_window_execution_task_invocations/3","title":"AWS.SSM.describe_maintenance_window_execution_task_invocations/3","type":"function"},{"doc":"For a given maintenance window execution, lists the tasks that were run.","ref":"AWS.SSM.html#describe_maintenance_window_execution_tasks/3","title":"AWS.SSM.describe_maintenance_window_execution_tasks/3","type":"function"},{"doc":"Lists the executions of a maintenance window.\n\nThis includes information about when the maintenance window was scheduled to be\nactive, and information about tasks registered and run with the maintenance\nwindow.","ref":"AWS.SSM.html#describe_maintenance_window_executions/3","title":"AWS.SSM.describe_maintenance_window_executions/3","type":"function"},{"doc":"Retrieves information about upcoming executions of a maintenance window.","ref":"AWS.SSM.html#describe_maintenance_window_schedule/3","title":"AWS.SSM.describe_maintenance_window_schedule/3","type":"function"},{"doc":"Lists the targets registered with the maintenance window.","ref":"AWS.SSM.html#describe_maintenance_window_targets/3","title":"AWS.SSM.describe_maintenance_window_targets/3","type":"function"},{"doc":"Lists the tasks in a maintenance window.\n\nFor maintenance window tasks without a specified target, you can't supply values\nfor `--max-errors` and `--max-concurrency`. Instead, the system inserts a\nplaceholder value of `1`, which may be reported in the response to this command.\nThese values don't affect the running of your task and can be ignored.","ref":"AWS.SSM.html#describe_maintenance_window_tasks/3","title":"AWS.SSM.describe_maintenance_window_tasks/3","type":"function"},{"doc":"Retrieves the maintenance windows in an Amazon Web Services account.","ref":"AWS.SSM.html#describe_maintenance_windows/3","title":"AWS.SSM.describe_maintenance_windows/3","type":"function"},{"doc":"Retrieves information about the maintenance window targets or tasks that a\nmanaged node is associated with.","ref":"AWS.SSM.html#describe_maintenance_windows_for_target/3","title":"AWS.SSM.describe_maintenance_windows_for_target/3","type":"function"},{"doc":"Query a set of OpsItems.\n\nYou must have permission in Identity and Access Management (IAM) to query a list\nof OpsItems. For more information, see [Set up OpsCenter](https://docs.aws.amazon.com/systems-manager/latest/userguide/OpsCenter-setup.html)\nin the *Amazon Web Services Systems Manager User Guide*.\n\nOperations engineers and IT professionals use Amazon Web Services Systems\nManager OpsCenter to view, investigate, and remediate operational issues\nimpacting the performance and health of their Amazon Web Services resources. For\nmore information, see\n[OpsCenter](https://docs.aws.amazon.com/systems-manager/latest/userguide/OpsCenter.html)\nin the *Amazon Web Services Systems Manager User Guide*.","ref":"AWS.SSM.html#describe_ops_items/3","title":"AWS.SSM.describe_ops_items/3","type":"function"},{"doc":"Get information about a parameter.\n\nRequest results are returned on a best-effort basis. If you specify `MaxResults`\nin the request, the response includes information up to the limit specified. The\nnumber of items returned, however, can be between zero and the value of\n`MaxResults`. If the service reaches an internal limit while processing the\nresults, it stops the operation and returns the matching values up to that point\nand a `NextToken`. You can specify the `NextToken` in a subsequent call to get\nthe next set of results.\n\nIf you change the KMS key alias for the KMS key used to encrypt a parameter,\nthen you must also update the key alias the parameter uses to reference KMS.\nOtherwise, `DescribeParameters` retrieves whatever the original key alias was\nreferencing.","ref":"AWS.SSM.html#describe_parameters/3","title":"AWS.SSM.describe_parameters/3","type":"function"},{"doc":"Lists the patch baselines in your Amazon Web Services account.","ref":"AWS.SSM.html#describe_patch_baselines/3","title":"AWS.SSM.describe_patch_baselines/3","type":"function"},{"doc":"Returns high-level aggregated patch compliance state information for a patch\ngroup.","ref":"AWS.SSM.html#describe_patch_group_state/3","title":"AWS.SSM.describe_patch_group_state/3","type":"function"},{"doc":"Lists all patch groups that have been registered with patch baselines.","ref":"AWS.SSM.html#describe_patch_groups/3","title":"AWS.SSM.describe_patch_groups/3","type":"function"},{"doc":"Lists the properties of available patches organized by product, product family,\nclassification, severity, and other properties of available patches.\n\nYou can use the reported properties in the filters you specify in requests for\noperations such as `CreatePatchBaseline`, `UpdatePatchBaseline`,\n`DescribeAvailablePatches`, and `DescribePatchBaselines`.\n\nThe following section lists the properties that can be used in filters for each\nmajor operating system type:","ref":"AWS.SSM.html#describe_patch_properties/3","title":"AWS.SSM.describe_patch_properties/3","type":"function"},{"doc":"#","ref":"AWS.SSM.html#describe_patch_properties/3-definitions","title":"Definitions - AWS.SSM.describe_patch_properties/3","type":"function"},{"doc":"Valid properties: `PRODUCT` | `CLASSIFICATION` | `SEVERITY`\n\n#","ref":"AWS.SSM.html#describe_patch_properties/3-amazon_linux","title":"AMAZON_LINUX - AWS.SSM.describe_patch_properties/3","type":"function"},{"doc":"Valid properties: `PRODUCT` | `CLASSIFICATION` | `SEVERITY`\n\n#","ref":"AWS.SSM.html#describe_patch_properties/3-amazon_linux_2","title":"AMAZON_LINUX_2 - AWS.SSM.describe_patch_properties/3","type":"function"},{"doc":"Valid properties: `PRODUCT` | `CLASSIFICATION` | `SEVERITY`\n\n#","ref":"AWS.SSM.html#describe_patch_properties/3-centos","title":"CENTOS - AWS.SSM.describe_patch_properties/3","type":"function"},{"doc":"Valid properties: `PRODUCT` | `PRIORITY`\n\n#","ref":"AWS.SSM.html#describe_patch_properties/3-debian","title":"DEBIAN - AWS.SSM.describe_patch_properties/3","type":"function"},{"doc":"Valid properties: `PRODUCT` | `CLASSIFICATION`\n\n#","ref":"AWS.SSM.html#describe_patch_properties/3-macos","title":"MACOS - AWS.SSM.describe_patch_properties/3","type":"function"},{"doc":"Valid properties: `PRODUCT` | `CLASSIFICATION` | `SEVERITY`\n\n#","ref":"AWS.SSM.html#describe_patch_properties/3-oracle_linux","title":"ORACLE_LINUX - AWS.SSM.describe_patch_properties/3","type":"function"},{"doc":"Valid properties: `PRODUCT` | `CLASSIFICATION` | `SEVERITY`\n\n#","ref":"AWS.SSM.html#describe_patch_properties/3-redhat_enterprise_linux","title":"REDHAT_ENTERPRISE_LINUX - AWS.SSM.describe_patch_properties/3","type":"function"},{"doc":"Valid properties: `PRODUCT` | `CLASSIFICATION` | `SEVERITY`\n\n#","ref":"AWS.SSM.html#describe_patch_properties/3-suse","title":"SUSE - AWS.SSM.describe_patch_properties/3","type":"function"},{"doc":"Valid properties: `PRODUCT` | `PRIORITY`\n\n#","ref":"AWS.SSM.html#describe_patch_properties/3-ubuntu","title":"UBUNTU - AWS.SSM.describe_patch_properties/3","type":"function"},{"doc":"Valid properties: `PRODUCT` | `PRODUCT_FAMILY` | `CLASSIFICATION` |\n`MSRC_SEVERITY`","ref":"AWS.SSM.html#describe_patch_properties/3-windows","title":"WINDOWS - AWS.SSM.describe_patch_properties/3","type":"function"},{"doc":"Retrieves a list of all active sessions (both connected and disconnected) or\nterminated sessions from the past 30 days.","ref":"AWS.SSM.html#describe_sessions/3","title":"AWS.SSM.describe_sessions/3","type":"function"},{"doc":"Deletes the association between an OpsItem and a related item.\n\nFor example, this API operation can delete an Incident Manager incident from an\nOpsItem. Incident Manager is a capability of Amazon Web Services Systems\nManager.","ref":"AWS.SSM.html#disassociate_ops_item_related_item/3","title":"AWS.SSM.disassociate_ops_item_related_item/3","type":"function"},{"doc":"Get detailed information about a particular Automation execution.","ref":"AWS.SSM.html#get_automation_execution/3","title":"AWS.SSM.get_automation_execution/3","type":"function"},{"doc":"Gets the state of a Amazon Web Services Systems Manager change calendar at the\ncurrent time or a specified time.\n\nIf you specify a time, `GetCalendarState` returns the state of the calendar at\nthat specific time, and returns the next time that the change calendar state\nwill transition. If you don't specify a time, `GetCalendarState` uses the\ncurrent time. Change Calendar entries have two possible states: `OPEN` or\n`CLOSED`.\n\nIf you specify more than one calendar in a request, the command returns the\nstatus of `OPEN` only if all calendars in the request are open. If one or more\ncalendars in the request are closed, the status returned is `CLOSED`.\n\nFor more information about Change Calendar, a capability of Amazon Web Services\nSystems Manager, see [Amazon Web Services Systems Manager Change Calendar](https://docs.aws.amazon.com/systems-manager/latest/userguide/systems-manager-change-calendar.html)\nin the *Amazon Web Services Systems Manager User Guide*.","ref":"AWS.SSM.html#get_calendar_state/3","title":"AWS.SSM.get_calendar_state/3","type":"function"},{"doc":"Returns detailed information about command execution for an invocation or\nplugin.\n\n`GetCommandInvocation` only gives the execution status of a plugin in a\ndocument. To get the command execution status on a specific managed node, use\n`ListCommandInvocations`. To get the command execution status across managed\nnodes, use `ListCommands`.","ref":"AWS.SSM.html#get_command_invocation/3","title":"AWS.SSM.get_command_invocation/3","type":"function"},{"doc":"Retrieves the Session Manager connection status for a managed node to determine\nwhether it is running and ready to receive Session Manager connections.","ref":"AWS.SSM.html#get_connection_status/3","title":"AWS.SSM.get_connection_status/3","type":"function"},{"doc":"Retrieves the default patch baseline.\n\nAmazon Web Services Systems Manager supports creating multiple default patch\nbaselines. For example, you can create a default patch baseline for each\noperating system.\n\nIf you don't specify an operating system value, the default patch baseline for\nWindows is returned.","ref":"AWS.SSM.html#get_default_patch_baseline/3","title":"AWS.SSM.get_default_patch_baseline/3","type":"function"},{"doc":"Retrieves the current snapshot for the patch baseline the managed node uses.\n\nThis API is primarily used by the `AWS-RunPatchBaseline` Systems Manager\ndocument (SSM document).\n\nIf you run the command locally, such as with the Command Line Interface (CLI),\nthe system attempts to use your local Amazon Web Services credentials and the\noperation fails. To avoid this, you can run the command in the Amazon Web\nServices Systems Manager console. Use Run Command, a capability of Amazon Web\nServices Systems Manager, with an SSM document that enables you to target a\nmanaged node with a script or command. For example, run the command using the\n`AWS-RunShellScript` document or the `AWS-RunPowerShellScript` document.","ref":"AWS.SSM.html#get_deployable_patch_snapshot_for_instance/3","title":"AWS.SSM.get_deployable_patch_snapshot_for_instance/3","type":"function"},{"doc":"Gets the contents of the specified Amazon Web Services Systems Manager document\n(SSM document).","ref":"AWS.SSM.html#get_document/3","title":"AWS.SSM.get_document/3","type":"function"},{"doc":"Query inventory information.\n\nThis includes managed node status, such as `Stopped` or `Terminated`.","ref":"AWS.SSM.html#get_inventory/3","title":"AWS.SSM.get_inventory/3","type":"function"},{"doc":"Return a list of inventory type names for the account, or return a list of\nattribute names for a specific Inventory item type.","ref":"AWS.SSM.html#get_inventory_schema/3","title":"AWS.SSM.get_inventory_schema/3","type":"function"},{"doc":"Retrieves a maintenance window.","ref":"AWS.SSM.html#get_maintenance_window/3","title":"AWS.SSM.get_maintenance_window/3","type":"function"},{"doc":"Retrieves details about a specific a maintenance window execution.","ref":"AWS.SSM.html#get_maintenance_window_execution/3","title":"AWS.SSM.get_maintenance_window_execution/3","type":"function"},{"doc":"Retrieves the details about a specific task run as part of a maintenance window\nexecution.","ref":"AWS.SSM.html#get_maintenance_window_execution_task/3","title":"AWS.SSM.get_maintenance_window_execution_task/3","type":"function"},{"doc":"Retrieves information about a specific task running on a specific target.","ref":"AWS.SSM.html#get_maintenance_window_execution_task_invocation/3","title":"AWS.SSM.get_maintenance_window_execution_task_invocation/3","type":"function"},{"doc":"Retrieves the details of a maintenance window task.\n\nFor maintenance window tasks without a specified target, you can't supply values\nfor `--max-errors` and `--max-concurrency`. Instead, the system inserts a\nplaceholder value of `1`, which may be reported in the response to this command.\nThese values don't affect the running of your task and can be ignored.\n\nTo retrieve a list of tasks in a maintenance window, instead use the\n`DescribeMaintenanceWindowTasks` command.","ref":"AWS.SSM.html#get_maintenance_window_task/3","title":"AWS.SSM.get_maintenance_window_task/3","type":"function"},{"doc":"Get information about an OpsItem by using the ID.\n\nYou must have permission in Identity and Access Management (IAM) to view\ninformation about an OpsItem. For more information, see [Set up OpsCenter](https://docs.aws.amazon.com/systems-manager/latest/userguide/OpsCenter-setup.html)\nin the *Amazon Web Services Systems Manager User Guide*.\n\nOperations engineers and IT professionals use Amazon Web Services Systems\nManager OpsCenter to view, investigate, and remediate operational issues\nimpacting the performance and health of their Amazon Web Services resources. For\nmore information, see\n[OpsCenter](https://docs.aws.amazon.com/systems-manager/latest/userguide/OpsCenter.html)\nin the *Amazon Web Services Systems Manager User Guide*.","ref":"AWS.SSM.html#get_ops_item/3","title":"AWS.SSM.get_ops_item/3","type":"function"},{"doc":"View operational metadata related to an application in Application Manager.","ref":"AWS.SSM.html#get_ops_metadata/3","title":"AWS.SSM.get_ops_metadata/3","type":"function"},{"doc":"View a summary of operations metadata (OpsData) based on specified filters and\naggregators.\n\nOpsData can include information about Amazon Web Services Systems Manager\nOpsCenter operational workitems (OpsItems) as well as information about any\nAmazon Web Services resource or service configured to report OpsData to Amazon\nWeb Services Systems Manager Explorer.","ref":"AWS.SSM.html#get_ops_summary/3","title":"AWS.SSM.get_ops_summary/3","type":"function"},{"doc":"Get information about a single parameter by specifying the parameter name.\n\nTo get information about more than one parameter at a time, use the\n`GetParameters` operation.","ref":"AWS.SSM.html#get_parameter/3","title":"AWS.SSM.get_parameter/3","type":"function"},{"doc":"Retrieves the history of all changes to a parameter.\n\nIf you change the KMS key alias for the KMS key used to encrypt a parameter,\nthen you must also update the key alias the parameter uses to reference KMS.\nOtherwise, `GetParameterHistory` retrieves whatever the original key alias was\nreferencing.","ref":"AWS.SSM.html#get_parameter_history/3","title":"AWS.SSM.get_parameter_history/3","type":"function"},{"doc":"Get information about one or more parameters by specifying multiple parameter\nnames.\n\nTo get information about a single parameter, you can use the `GetParameter`\noperation instead.","ref":"AWS.SSM.html#get_parameters/3","title":"AWS.SSM.get_parameters/3","type":"function"},{"doc":"Retrieve information about one or more parameters in a specific hierarchy.\n\nRequest results are returned on a best-effort basis. If you specify `MaxResults`\nin the request, the response includes information up to the limit specified. The\nnumber of items returned, however, can be between zero and the value of\n`MaxResults`. If the service reaches an internal limit while processing the\nresults, it stops the operation and returns the matching values up to that point\nand a `NextToken`. You can specify the `NextToken` in a subsequent call to get\nthe next set of results.","ref":"AWS.SSM.html#get_parameters_by_path/3","title":"AWS.SSM.get_parameters_by_path/3","type":"function"},{"doc":"Retrieves information about a patch baseline.","ref":"AWS.SSM.html#get_patch_baseline/3","title":"AWS.SSM.get_patch_baseline/3","type":"function"},{"doc":"Retrieves the patch baseline that should be used for the specified patch group.","ref":"AWS.SSM.html#get_patch_baseline_for_patch_group/3","title":"AWS.SSM.get_patch_baseline_for_patch_group/3","type":"function"},{"doc":"Returns an array of the `Policy` object.","ref":"AWS.SSM.html#get_resource_policies/3","title":"AWS.SSM.get_resource_policies/3","type":"function"},{"doc":"`ServiceSetting` is an account-level setting for an Amazon Web Services service.\n\nThis setting defines how a user interacts with or uses a service or a feature of\na service. For example, if an Amazon Web Services service charges money to the\naccount based on feature or service usage, then the Amazon Web Services service\nteam might create a default setting of `false`. This means the user can't use\nthis feature unless they change the setting to `true` and intentionally opt in\nfor a paid feature.\n\nServices map a `SettingId` object to a setting value. Amazon Web Services\nservices teams define the default value for a `SettingId`. You can't create a\nnew `SettingId`, but you can overwrite the default value if you have the\n`ssm:UpdateServiceSetting` permission for the setting. Use the\n`UpdateServiceSetting` API operation to change the default setting. Or use the\n`ResetServiceSetting` to change the value back to the original value defined by\nthe Amazon Web Services service team.\n\nQuery the current service setting for the Amazon Web Services account.","ref":"AWS.SSM.html#get_service_setting/3","title":"AWS.SSM.get_service_setting/3","type":"function"},{"doc":"A parameter label is a user-defined alias to help you manage different versions\nof a parameter.\n\nWhen you modify a parameter, Amazon Web Services Systems Manager automatically\nsaves a new version and increments the version number by one. A label can help\nyou remember the purpose of a parameter when there are multiple versions.\n\nParameter labels have the following requirements and restrictions.\n\n  * A version of a parameter can have a maximum of 10 labels.\n\n  * You can't attach the same label to different versions of the same\nparameter. For example, if version 1 has the label Production, then you can't\nattach Production to version 2.\n\n  * You can move a label from one version of a parameter to another.\n\n  * You can't create a label when you create a new parameter. You must\nattach a label to a specific version of a parameter.\n\n  * If you no longer want to use a parameter label, then you can\neither delete it or move it to a different version of a parameter.\n\n  * A label can have a maximum of 100 characters.\n\n  * Labels can contain letters (case sensitive), numbers, periods (.),\nhyphens (-), or underscores (_).\n\n  * Labels can't begin with a number, \"`aws`\" or \"`ssm`\" (not case\nsensitive). If a label fails to meet these requirements, then the label isn't\nassociated with a parameter and the system displays it in the list of\nInvalidLabels.","ref":"AWS.SSM.html#label_parameter_version/3","title":"AWS.SSM.label_parameter_version/3","type":"function"},{"doc":"Retrieves all versions of an association for a specific association ID.","ref":"AWS.SSM.html#list_association_versions/3","title":"AWS.SSM.list_association_versions/3","type":"function"},{"doc":"Returns all State Manager associations in the current Amazon Web Services\naccount and Amazon Web Services Region.\n\nYou can limit the results to a specific State Manager association document or\nmanaged node by specifying a filter. State Manager is a capability of Amazon Web\nServices Systems Manager.","ref":"AWS.SSM.html#list_associations/3","title":"AWS.SSM.list_associations/3","type":"function"},{"doc":"An invocation is copy of a command sent to a specific managed node.\n\nA command can apply to one or more managed nodes. A command invocation applies\nto one managed node. For example, if a user runs `SendCommand` against three\nmanaged nodes, then a command invocation is created for each requested managed\nnode ID. `ListCommandInvocations` provide status about command execution.","ref":"AWS.SSM.html#list_command_invocations/3","title":"AWS.SSM.list_command_invocations/3","type":"function"},{"doc":"Lists the commands requested by users of the Amazon Web Services account.","ref":"AWS.SSM.html#list_commands/3","title":"AWS.SSM.list_commands/3","type":"function"},{"doc":"For a specified resource ID, this API operation returns a list of compliance\nstatuses for different resource types.\n\nCurrently, you can only specify one resource ID per call. List results depend on\nthe criteria specified in the filter.","ref":"AWS.SSM.html#list_compliance_items/3","title":"AWS.SSM.list_compliance_items/3","type":"function"},{"doc":"Returns a summary count of compliant and non-compliant resources for a\ncompliance type.\n\nFor example, this call can return State Manager associations, patches, or custom\ncompliance types according to the filter criteria that you specify.","ref":"AWS.SSM.html#list_compliance_summaries/3","title":"AWS.SSM.list_compliance_summaries/3","type":"function"},{"doc":"Information about approval reviews for a version of a change template in Change\nManager.","ref":"AWS.SSM.html#list_document_metadata_history/3","title":"AWS.SSM.list_document_metadata_history/3","type":"function"},{"doc":"List all versions for a document.","ref":"AWS.SSM.html#list_document_versions/3","title":"AWS.SSM.list_document_versions/3","type":"function"},{"doc":"Returns all Systems Manager (SSM) documents in the current Amazon Web Services\naccount and Amazon Web Services Region.\n\nYou can limit the results of this request by using a filter.","ref":"AWS.SSM.html#list_documents/3","title":"AWS.SSM.list_documents/3","type":"function"},{"doc":"A list of inventory items returned by the request.","ref":"AWS.SSM.html#list_inventory_entries/3","title":"AWS.SSM.list_inventory_entries/3","type":"function"},{"doc":"Returns a list of all OpsItem events in the current Amazon Web Services Region\nand Amazon Web Services account.\n\nYou can limit the results to events associated with specific OpsItems by\nspecifying a filter.","ref":"AWS.SSM.html#list_ops_item_events/3","title":"AWS.SSM.list_ops_item_events/3","type":"function"},{"doc":"Lists all related-item resources associated with a Systems Manager OpsCenter\nOpsItem.\n\nOpsCenter is a capability of Amazon Web Services Systems Manager.","ref":"AWS.SSM.html#list_ops_item_related_items/3","title":"AWS.SSM.list_ops_item_related_items/3","type":"function"},{"doc":"Amazon Web Services Systems Manager calls this API operation when displaying all\nApplication Manager OpsMetadata objects or blobs.","ref":"AWS.SSM.html#list_ops_metadata/3","title":"AWS.SSM.list_ops_metadata/3","type":"function"},{"doc":"Returns a resource-level summary count.\n\nThe summary includes information about compliant and non-compliant statuses and\ndetailed compliance-item severity counts, according to the filter criteria you\nspecify.","ref":"AWS.SSM.html#list_resource_compliance_summaries/3","title":"AWS.SSM.list_resource_compliance_summaries/3","type":"function"},{"doc":"Lists your resource data sync configurations.\n\nIncludes information about the last time a sync attempted to start, the last\nsync status, and the last time a sync successfully completed.\n\nThe number of sync configurations might be too large to return using a single\ncall to `ListResourceDataSync`. You can limit the number of sync configurations\nreturned by using the `MaxResults` parameter. To determine whether there are\nmore sync configurations to list, check the value of `NextToken` in the output.\nIf there are more sync configurations to list, you can request them by\nspecifying the `NextToken` returned in the call to the parameter of a subsequent\ncall.","ref":"AWS.SSM.html#list_resource_data_sync/3","title":"AWS.SSM.list_resource_data_sync/3","type":"function"},{"doc":"Returns a list of the tags assigned to the specified resource.\n\nFor information about the ID format for each supported resource type, see\n`AddTagsToResource`.","ref":"AWS.SSM.html#list_tags_for_resource/3","title":"AWS.SSM.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.SSM.html#metadata/0","title":"AWS.SSM.metadata/0","type":"function"},{"doc":"Shares a Amazon Web Services Systems Manager document (SSM document)publicly or\nprivately.\n\nIf you share a document privately, you must specify the Amazon Web Services user\nIDs for those people who can use the document. If you share a document publicly,\nyou must specify *All* as the account ID.","ref":"AWS.SSM.html#modify_document_permission/3","title":"AWS.SSM.modify_document_permission/3","type":"function"},{"doc":"Registers a compliance type and other compliance details on a designated\nresource.\n\nThis operation lets you register custom compliance details with a resource. This\ncall overwrites existing compliance information on the resource, so you must\nprovide a full list of compliance items each time that you send the request.\n\nComplianceType can be one of the following:\n\n  * ExecutionId: The execution ID when the patch, association, or\ncustom compliance item was applied.\n\n  * ExecutionType: Specify patch, association, or Custom:`string`.\n\n  * ExecutionTime. The time the patch, association, or custom\ncompliance item was applied to the managed node.\n\n  * Id: The patch, association, or custom compliance ID.\n\n  * Title: A title.\n\n  * Status: The status of the compliance item. For example, `approved`\nfor patches, or `Failed` for associations.\n\n  * Severity: A patch severity. For example, `Critical`.\n\n  * DocumentName: An SSM document name. For example,\n`AWS-RunPatchBaseline`.\n\n  * DocumentVersion: An SSM document version number. For example, 4.\n\n  * Classification: A patch classification. For example, `security\nupdates`.\n\n  * PatchBaselineId: A patch baseline ID.\n\n  * PatchSeverity: A patch severity. For example, `Critical`.\n\n  * PatchState: A patch state. For example,\n`InstancesWithFailedPatches`.\n\n  * PatchGroup: The name of a patch group.\n\n  * InstalledTime: The time the association, patch, or custom\ncompliance item was applied to the resource. Specify the time by using the\nfollowing format: yyyy-MM-dd'T'HH:mm:ss'Z'","ref":"AWS.SSM.html#put_compliance_items/3","title":"AWS.SSM.put_compliance_items/3","type":"function"},{"doc":"Bulk update custom inventory items on one or more managed nodes.\n\nThe request adds an inventory item, if it doesn't already exist, or updates an\ninventory item, if it does exist.","ref":"AWS.SSM.html#put_inventory/3","title":"AWS.SSM.put_inventory/3","type":"function"},{"doc":"Add a parameter to the system.","ref":"AWS.SSM.html#put_parameter/3","title":"AWS.SSM.put_parameter/3","type":"function"},{"doc":"Creates or updates a Systems Manager resource policy.\n\nA resource policy helps you to define the IAM entity (for example, an Amazon Web\nServices account) that can manage your Systems Manager resources. Currently,\n`OpsItemGroup` is the only resource that supports Systems Manager resource\npolicies. The resource policy for `OpsItemGroup` enables Amazon Web Services\naccounts to view and interact with OpsCenter operational work items (OpsItems).","ref":"AWS.SSM.html#put_resource_policy/3","title":"AWS.SSM.put_resource_policy/3","type":"function"},{"doc":"Defines the default patch baseline for the relevant operating system.\n\nTo reset the Amazon Web Services-predefined patch baseline as the default,\nspecify the full patch baseline Amazon Resource Name (ARN) as the baseline ID\nvalue. For example, for CentOS, specify\n`arn:aws:ssm:us-east-2:733109147000:patchbaseline/pb-0574b43a65ea646ed` instead\nof `pb-0574b43a65ea646ed`.","ref":"AWS.SSM.html#register_default_patch_baseline/3","title":"AWS.SSM.register_default_patch_baseline/3","type":"function"},{"doc":"Registers a patch baseline for a patch group.","ref":"AWS.SSM.html#register_patch_baseline_for_patch_group/3","title":"AWS.SSM.register_patch_baseline_for_patch_group/3","type":"function"},{"doc":"Registers a target with a maintenance window.","ref":"AWS.SSM.html#register_target_with_maintenance_window/3","title":"AWS.SSM.register_target_with_maintenance_window/3","type":"function"},{"doc":"Adds a new task to a maintenance window.","ref":"AWS.SSM.html#register_task_with_maintenance_window/3","title":"AWS.SSM.register_task_with_maintenance_window/3","type":"function"},{"doc":"Removes tag keys from the specified resource.","ref":"AWS.SSM.html#remove_tags_from_resource/3","title":"AWS.SSM.remove_tags_from_resource/3","type":"function"},{"doc":"`ServiceSetting` is an account-level setting for an Amazon Web Services service.\n\nThis setting defines how a user interacts with or uses a service or a feature of\na service. For example, if an Amazon Web Services service charges money to the\naccount based on feature or service usage, then the Amazon Web Services service\nteam might create a default setting of \"false\". This means the user can't use\nthis feature unless they change the setting to \"true\" and intentionally opt in\nfor a paid feature.\n\nServices map a `SettingId` object to a setting value. Amazon Web Services\nservices teams define the default value for a `SettingId`. You can't create a\nnew `SettingId`, but you can overwrite the default value if you have the\n`ssm:UpdateServiceSetting` permission for the setting. Use the\n`GetServiceSetting` API operation to view the current value. Use the\n`UpdateServiceSetting` API operation to change the default setting.\n\nReset the service setting for the account to the default value as provisioned by\nthe Amazon Web Services service team.","ref":"AWS.SSM.html#reset_service_setting/3","title":"AWS.SSM.reset_service_setting/3","type":"function"},{"doc":"Reconnects a session to a managed node after it has been disconnected.\n\nConnections can be resumed for disconnected sessions, but not terminated\nsessions.\n\nThis command is primarily for use by client machines to automatically reconnect\nduring intermittent network issues. It isn't intended for any other use.","ref":"AWS.SSM.html#resume_session/3","title":"AWS.SSM.resume_session/3","type":"function"},{"doc":"Sends a signal to an Automation execution to change the current behavior or\nstatus of the execution.","ref":"AWS.SSM.html#send_automation_signal/3","title":"AWS.SSM.send_automation_signal/3","type":"function"},{"doc":"Runs commands on one or more managed nodes.","ref":"AWS.SSM.html#send_command/3","title":"AWS.SSM.send_command/3","type":"function"},{"doc":"Runs an association immediately and only one time.\n\nThis operation can be helpful when troubleshooting associations.","ref":"AWS.SSM.html#start_associations_once/3","title":"AWS.SSM.start_associations_once/3","type":"function"},{"doc":"Initiates execution of an Automation runbook.","ref":"AWS.SSM.html#start_automation_execution/3","title":"AWS.SSM.start_automation_execution/3","type":"function"},{"doc":"Creates a change request for Change Manager.\n\nThe Automation runbooks specified in the change request run only after all\nrequired approvals for the change request have been received.","ref":"AWS.SSM.html#start_change_request_execution/3","title":"AWS.SSM.start_change_request_execution/3","type":"function"},{"doc":"Initiates a connection to a target (for example, a managed node) for a Session\nManager session.\n\nReturns a URL and token that can be used to open a WebSocket connection for\nsending input and receiving outputs.\n\nAmazon Web Services CLI usage: `start-session` is an interactive command that\nrequires the Session Manager plugin to be installed on the client machine making\nthe call. For information, see [Install the Session Manager plugin for the Amazon Web Services\nCLI](https://docs.aws.amazon.com/systems-manager/latest/userguide/session-manager-working-with-install-plugin.html)\nin the *Amazon Web Services Systems Manager User Guide*.\n\nAmazon Web Services Tools for PowerShell usage: Start-SSMSession isn't currently\nsupported by Amazon Web Services Tools for PowerShell on Windows local machines.","ref":"AWS.SSM.html#start_session/3","title":"AWS.SSM.start_session/3","type":"function"},{"doc":"Stop an Automation that is currently running.","ref":"AWS.SSM.html#stop_automation_execution/3","title":"AWS.SSM.stop_automation_execution/3","type":"function"},{"doc":"Permanently ends a session and closes the data connection between the Session\nManager client and SSM Agent on the managed node.\n\nA terminated session can't be resumed.","ref":"AWS.SSM.html#terminate_session/3","title":"AWS.SSM.terminate_session/3","type":"function"},{"doc":"Remove a label or labels from a parameter.","ref":"AWS.SSM.html#unlabel_parameter_version/3","title":"AWS.SSM.unlabel_parameter_version/3","type":"function"},{"doc":"Updates an association.\n\nYou can update the association name and version, the document version, schedule,\nparameters, and Amazon Simple Storage Service (Amazon S3) output. When you call\n`UpdateAssociation`, the system removes all optional parameters from the request\nand overwrites the association with null values for those parameters. This is by\ndesign. You must specify all optional parameters in the call, even if you are\nnot changing the parameters. This includes the `Name` parameter. Before calling\nthis API action, we recommend that you call the `DescribeAssociation` API\noperation and make a note of all optional parameters required for your\n`UpdateAssociation` call.\n\nIn order to call this API operation, a user, group, or role must be granted\npermission to call the `DescribeAssociation` API operation. If you don't have\npermission to call `DescribeAssociation`, then you receive the following error:\n`An error occurred (AccessDeniedException) when calling the UpdateAssociation\noperation: User:   isn't authorized to perform: ssm:DescribeAssociation\non resource:  `\n\nWhen you update an association, the association immediately runs against the\nspecified targets. You can add the `ApplyOnlyAtCronInterval` parameter to run\nthe association during the next schedule run.","ref":"AWS.SSM.html#update_association/3","title":"AWS.SSM.update_association/3","type":"function"},{"doc":"Updates the status of the Amazon Web Services Systems Manager document (SSM\ndocument) associated with the specified managed node.\n\n`UpdateAssociationStatus` is primarily used by the Amazon Web Services Systems\nManager Agent (SSM Agent) to report status updates about your associations and\nis only used for associations created with the `InstanceId` legacy parameter.","ref":"AWS.SSM.html#update_association_status/3","title":"AWS.SSM.update_association_status/3","type":"function"},{"doc":"Updates one or more values for an SSM document.","ref":"AWS.SSM.html#update_document/3","title":"AWS.SSM.update_document/3","type":"function"},{"doc":"Set the default version of a document.\n\nIf you change a document version for a State Manager association, Systems\nManager immediately runs the association unless you previously specifed the\n`apply-only-at-cron-interval` parameter.","ref":"AWS.SSM.html#update_document_default_version/3","title":"AWS.SSM.update_document_default_version/3","type":"function"},{"doc":"Updates information related to approval reviews for a specific version of a\nchange template in Change Manager.","ref":"AWS.SSM.html#update_document_metadata/3","title":"AWS.SSM.update_document_metadata/3","type":"function"},{"doc":"Updates an existing maintenance window.\n\nOnly specified parameters are modified.\n\nThe value you specify for `Duration` determines the specific end time for the\nmaintenance window based on the time it begins. No maintenance window tasks are\npermitted to start after the resulting endtime minus the number of hours you\nspecify for `Cutoff`. For example, if the maintenance window starts at 3 PM, the\nduration is three hours, and the value you specify for `Cutoff` is one hour, no\nmaintenance window tasks can start after 5 PM.","ref":"AWS.SSM.html#update_maintenance_window/3","title":"AWS.SSM.update_maintenance_window/3","type":"function"},{"doc":"Modifies the target of an existing maintenance window.\n\nYou can change the following:\n\n  * Name\n\n  * Description\n\n  * Owner\n\n  * IDs for an ID target\n\n  * Tags for a Tag target\n\n  * From any supported tag type to another. The three supported tag\ntypes are ID target, Tag target, and resource group. For more information, see\n`Target`.\n\nIf a parameter is null, then the corresponding field isn't modified.","ref":"AWS.SSM.html#update_maintenance_window_target/3","title":"AWS.SSM.update_maintenance_window_target/3","type":"function"},{"doc":"Modifies a task assigned to a maintenance window.\n\nYou can't change the task type, but you can change the following values:\n\n  * `TaskARN`. For example, you can change a `RUN_COMMAND` task from\n`AWS-RunPowerShellScript` to `AWS-RunShellScript`.\n\n  * `ServiceRoleArn`\n\n  * `TaskInvocationParameters`\n\n  * `Priority`\n\n  * `MaxConcurrency`\n\n  * `MaxErrors`\n\nOne or more targets must be specified for maintenance window Run Command-type\ntasks. Depending on the task, targets are optional for other maintenance window\ntask types (Automation, Lambda, and Step Functions). For more information about\nrunning tasks that don't specify targets, see [Registering maintenance window tasks without\ntargets](https://docs.aws.amazon.com/systems-manager/latest/userguide/maintenance-windows-targetless-tasks.html)\nin the *Amazon Web Services Systems Manager User Guide*.\n\nIf the value for a parameter in `UpdateMaintenanceWindowTask` is null, then the\ncorresponding field isn't modified. If you set `Replace` to true, then all\nfields required by the `RegisterTaskWithMaintenanceWindow` operation are\nrequired for this request. Optional fields that aren't specified are set to\nnull.\n\nWhen you update a maintenance window task that has options specified in\n`TaskInvocationParameters`, you must provide again all the\n`TaskInvocationParameters` values that you want to retain. The values you don't\nspecify again are removed. For example, suppose that when you registered a Run\nCommand task, you specified `TaskInvocationParameters` values for `Comment`,\n`NotificationConfig`, and `OutputS3BucketName`. If you update the maintenance\nwindow task and specify only a different `OutputS3BucketName` value, the values\nfor `Comment` and `NotificationConfig` are removed.","ref":"AWS.SSM.html#update_maintenance_window_task/3","title":"AWS.SSM.update_maintenance_window_task/3","type":"function"},{"doc":"Changes the Identity and Access Management (IAM) role that is assigned to the\non-premises server, edge device, or virtual machines (VM).\n\nIAM roles are first assigned to these hybrid nodes during the activation\nprocess. For more information, see `CreateActivation`.","ref":"AWS.SSM.html#update_managed_instance_role/3","title":"AWS.SSM.update_managed_instance_role/3","type":"function"},{"doc":"Edit or change an OpsItem.\n\nYou must have permission in Identity and Access Management (IAM) to update an\nOpsItem. For more information, see [Set up OpsCenter](https://docs.aws.amazon.com/systems-manager/latest/userguide/OpsCenter-setup.html)\nin the *Amazon Web Services Systems Manager User Guide*.\n\nOperations engineers and IT professionals use Amazon Web Services Systems\nManager OpsCenter to view, investigate, and remediate operational issues\nimpacting the performance and health of their Amazon Web Services resources. For\nmore information, see\n[OpsCenter](https://docs.aws.amazon.com/systems-manager/latest/userguide/OpsCenter.html)\nin the *Amazon Web Services Systems Manager User Guide*.","ref":"AWS.SSM.html#update_ops_item/3","title":"AWS.SSM.update_ops_item/3","type":"function"},{"doc":"Amazon Web Services Systems Manager calls this API operation when you edit\nOpsMetadata in Application Manager.","ref":"AWS.SSM.html#update_ops_metadata/3","title":"AWS.SSM.update_ops_metadata/3","type":"function"},{"doc":"Modifies an existing patch baseline.\n\nFields not specified in the request are left unchanged.\n\nFor information about valid key-value pairs in `PatchFilters` for each supported\noperating system type, see `PatchFilter`.","ref":"AWS.SSM.html#update_patch_baseline/3","title":"AWS.SSM.update_patch_baseline/3","type":"function"},{"doc":"Update a resource data sync.\n\nAfter you create a resource data sync for a Region, you can't change the account\noptions for that sync. For example, if you create a sync in the us-east-2 (Ohio)\nRegion and you choose the `Include only the current account` option, you can't\nedit that sync later and choose the `Include all accounts from my Organizations\nconfiguration` option. Instead, you must delete the first resource data sync,\nand create a new one.\n\nThis API operation only supports a resource data sync that was created with a\nSyncFromSource `SyncType`.","ref":"AWS.SSM.html#update_resource_data_sync/3","title":"AWS.SSM.update_resource_data_sync/3","type":"function"},{"doc":"`ServiceSetting` is an account-level setting for an Amazon Web Services service.\n\nThis setting defines how a user interacts with or uses a service or a feature of\na service. For example, if an Amazon Web Services service charges money to the\naccount based on feature or service usage, then the Amazon Web Services service\nteam might create a default setting of \"false\". This means the user can't use\nthis feature unless they change the setting to \"true\" and intentionally opt in\nfor a paid feature.\n\nServices map a `SettingId` object to a setting value. Amazon Web Services\nservices teams define the default value for a `SettingId`. You can't create a\nnew `SettingId`, but you can overwrite the default value if you have the\n`ssm:UpdateServiceSetting` permission for the setting. Use the\n`GetServiceSetting` API operation to view the current value. Or, use the\n`ResetServiceSetting` to change the value back to the original value defined by\nthe Amazon Web Services service team.\n\nUpdate the service setting for the account.","ref":"AWS.SSM.html#update_service_setting/3","title":"AWS.SSM.update_service_setting/3","type":"function"},{"doc":"Systems Manager Incident Manager is an incident management console designed to\nhelp users mitigate and recover from incidents affecting their Amazon Web\nServices-hosted applications.\n\nAn incident is any unplanned interruption or reduction in quality of services.\n\nIncident Manager increases incident resolution by notifying responders of\nimpact, highlighting relevant troubleshooting data, and providing collaboration\ntools to get services back up and running. To achieve the primary goal of\nreducing the time-to-resolution of critical incidents, Incident Manager\nautomates response plans and enables responder team escalation.","ref":"AWS.SSMContacts.html","title":"AWS.SSMContacts","type":"module"},{"doc":"Used to acknowledge an engagement to a contact channel during an incident.","ref":"AWS.SSMContacts.html#accept_page/3","title":"AWS.SSMContacts.accept_page/3","type":"function"},{"doc":"Activates a contact's contact channel.\n\nIncident Manager can't engage a contact until the contact channel has been\nactivated.","ref":"AWS.SSMContacts.html#activate_contact_channel/3","title":"AWS.SSMContacts.activate_contact_channel/3","type":"function"},{"doc":"Contacts are either the contacts that Incident Manager engages during an\nincident or the escalation plans that Incident Manager uses to engage contacts\nin phases during an incident.","ref":"AWS.SSMContacts.html#create_contact/3","title":"AWS.SSMContacts.create_contact/3","type":"function"},{"doc":"A contact channel is the method that Incident Manager uses to engage your\ncontact.","ref":"AWS.SSMContacts.html#create_contact_channel/3","title":"AWS.SSMContacts.create_contact_channel/3","type":"function"},{"doc":"Creates a rotation in an on-call schedule.","ref":"AWS.SSMContacts.html#create_rotation/3","title":"AWS.SSMContacts.create_rotation/3","type":"function"},{"doc":"Creates an override for a rotation in an on-call schedule.","ref":"AWS.SSMContacts.html#create_rotation_override/3","title":"AWS.SSMContacts.create_rotation_override/3","type":"function"},{"doc":"To no longer receive Incident Manager engagements to a contact channel, you can\ndeactivate the channel.","ref":"AWS.SSMContacts.html#deactivate_contact_channel/3","title":"AWS.SSMContacts.deactivate_contact_channel/3","type":"function"},{"doc":"To remove a contact from Incident Manager, you can delete the contact.\n\nDeleting a contact removes them from all escalation plans and related response\nplans. Deleting an escalation plan removes it from all related response plans.\nYou will have to recreate the contact and its contact channels before you can\nuse it again.","ref":"AWS.SSMContacts.html#delete_contact/3","title":"AWS.SSMContacts.delete_contact/3","type":"function"},{"doc":"To no longer receive engagements on a contact channel, you can delete the\nchannel from a contact.\n\nDeleting the contact channel removes it from the contact's engagement plan. If\nyou delete the only contact channel for a contact, you won't be able to engage\nthat contact during an incident.","ref":"AWS.SSMContacts.html#delete_contact_channel/3","title":"AWS.SSMContacts.delete_contact_channel/3","type":"function"},{"doc":"Deletes a rotation from the system.\n\nIf a rotation belongs to more than one on-call schedule, this operation deletes\nit from all of them.","ref":"AWS.SSMContacts.html#delete_rotation/3","title":"AWS.SSMContacts.delete_rotation/3","type":"function"},{"doc":"Deletes an existing override for an on-call rotation.","ref":"AWS.SSMContacts.html#delete_rotation_override/3","title":"AWS.SSMContacts.delete_rotation_override/3","type":"function"},{"doc":"Incident Manager uses engagements to engage contacts and escalation plans during\nan incident.\n\nUse this command to describe the engagement that occurred during an incident.","ref":"AWS.SSMContacts.html#describe_engagement/3","title":"AWS.SSMContacts.describe_engagement/3","type":"function"},{"doc":"Lists details of the engagement to a contact channel.","ref":"AWS.SSMContacts.html#describe_page/3","title":"AWS.SSMContacts.describe_page/3","type":"function"},{"doc":"Retrieves information about the specified contact or escalation plan.","ref":"AWS.SSMContacts.html#get_contact/3","title":"AWS.SSMContacts.get_contact/3","type":"function"},{"doc":"List details about a specific contact channel.","ref":"AWS.SSMContacts.html#get_contact_channel/3","title":"AWS.SSMContacts.get_contact_channel/3","type":"function"},{"doc":"Retrieves the resource policies attached to the specified contact or escalation\nplan.","ref":"AWS.SSMContacts.html#get_contact_policy/3","title":"AWS.SSMContacts.get_contact_policy/3","type":"function"},{"doc":"Retrieves information about an on-call rotation.","ref":"AWS.SSMContacts.html#get_rotation/3","title":"AWS.SSMContacts.get_rotation/3","type":"function"},{"doc":"Retrieves information about an override to an on-call rotation.","ref":"AWS.SSMContacts.html#get_rotation_override/3","title":"AWS.SSMContacts.get_rotation_override/3","type":"function"},{"doc":"Lists all contact channels for the specified contact.","ref":"AWS.SSMContacts.html#list_contact_channels/3","title":"AWS.SSMContacts.list_contact_channels/3","type":"function"},{"doc":"Lists all contacts and escalation plans in Incident Manager.","ref":"AWS.SSMContacts.html#list_contacts/3","title":"AWS.SSMContacts.list_contacts/3","type":"function"},{"doc":"Lists all engagements that have happened in an incident.","ref":"AWS.SSMContacts.html#list_engagements/3","title":"AWS.SSMContacts.list_engagements/3","type":"function"},{"doc":"Lists all of the engagements to contact channels that have been acknowledged.","ref":"AWS.SSMContacts.html#list_page_receipts/3","title":"AWS.SSMContacts.list_page_receipts/3","type":"function"},{"doc":"Returns the resolution path of an engagement.\n\nFor example, the escalation plan engaged in an incident might target an on-call\nschedule that includes several contacts in a rotation, but just one contact\non-call when the incident starts. The resolution path indicates the hierarchy of\n*escalation plan > on-call schedule > contact*.","ref":"AWS.SSMContacts.html#list_page_resolutions/3","title":"AWS.SSMContacts.list_page_resolutions/3","type":"function"},{"doc":"Lists the engagements to a contact's contact channels.","ref":"AWS.SSMContacts.html#list_pages_by_contact/3","title":"AWS.SSMContacts.list_pages_by_contact/3","type":"function"},{"doc":"Lists the engagements to contact channels that occurred by engaging a contact.","ref":"AWS.SSMContacts.html#list_pages_by_engagement/3","title":"AWS.SSMContacts.list_pages_by_engagement/3","type":"function"},{"doc":"Returns a list of shifts based on rotation configuration parameters.\n\nThe Incident Manager primarily uses this operation to populate the","ref":"AWS.SSMContacts.html#list_preview_rotation_shifts/3","title":"AWS.SSMContacts.list_preview_rotation_shifts/3","type":"function"},{"doc":"calendar. It is not typically run by end users.","ref":"AWS.SSMContacts.html#list_preview_rotation_shifts/3-preview","title":"Preview - AWS.SSMContacts.list_preview_rotation_shifts/3","type":"function"},{"doc":"Retrieves a list of overrides currently specified for an on-call rotation.","ref":"AWS.SSMContacts.html#list_rotation_overrides/3","title":"AWS.SSMContacts.list_rotation_overrides/3","type":"function"},{"doc":"Returns a list of shifts generated by an existing rotation in the system.","ref":"AWS.SSMContacts.html#list_rotation_shifts/3","title":"AWS.SSMContacts.list_rotation_shifts/3","type":"function"},{"doc":"Retrieves a list of on-call rotations.","ref":"AWS.SSMContacts.html#list_rotations/3","title":"AWS.SSMContacts.list_rotations/3","type":"function"},{"doc":"Lists the tags of an escalation plan or contact.","ref":"AWS.SSMContacts.html#list_tags_for_resource/3","title":"AWS.SSMContacts.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.SSMContacts.html#metadata/0","title":"AWS.SSMContacts.metadata/0","type":"function"},{"doc":"Adds a resource policy to the specified contact or escalation plan.\n\nThe resource policy is used to share the contact or escalation plan using\nResource Access Manager (RAM). For more information about cross-account sharing,\nsee [Setting up cross-account functionality](https://docs.aws.amazon.com/incident-manager/latest/userguide/xa.html).","ref":"AWS.SSMContacts.html#put_contact_policy/3","title":"AWS.SSMContacts.put_contact_policy/3","type":"function"},{"doc":"Sends an activation code to a contact channel.\n\nThe contact can use this code to activate the contact channel in the console or\nwith the `ActivateChannel` operation. Incident Manager can't engage a contact\nchannel until it has been activated.","ref":"AWS.SSMContacts.html#send_activation_code/3","title":"AWS.SSMContacts.send_activation_code/3","type":"function"},{"doc":"Starts an engagement to a contact or escalation plan.\n\nThe engagement engages each contact specified in the incident.","ref":"AWS.SSMContacts.html#start_engagement/3","title":"AWS.SSMContacts.start_engagement/3","type":"function"},{"doc":"Stops an engagement before it finishes the final stage of the escalation plan or\nengagement plan.\n\nFurther contacts aren't engaged.","ref":"AWS.SSMContacts.html#stop_engagement/3","title":"AWS.SSMContacts.stop_engagement/3","type":"function"},{"doc":"Tags a contact or escalation plan.\n\nYou can tag only contacts and escalation plans in the first region of your\nreplication set.","ref":"AWS.SSMContacts.html#tag_resource/3","title":"AWS.SSMContacts.tag_resource/3","type":"function"},{"doc":"Removes tags from the specified resource.","ref":"AWS.SSMContacts.html#untag_resource/3","title":"AWS.SSMContacts.untag_resource/3","type":"function"},{"doc":"Updates the contact or escalation plan specified.","ref":"AWS.SSMContacts.html#update_contact/3","title":"AWS.SSMContacts.update_contact/3","type":"function"},{"doc":"Updates a contact's contact channel.","ref":"AWS.SSMContacts.html#update_contact_channel/3","title":"AWS.SSMContacts.update_contact_channel/3","type":"function"},{"doc":"Updates the information specified for an on-call rotation.","ref":"AWS.SSMContacts.html#update_rotation/3","title":"AWS.SSMContacts.update_rotation/3","type":"function"},{"doc":"Systems Manager Incident Manager is an incident management console designed to\nhelp users mitigate and recover from incidents affecting their Amazon Web\nServices-hosted applications.\n\nAn incident is any unplanned interruption or reduction in quality of services.\n\nIncident Manager increases incident resolution by notifying responders of\nimpact, highlighting relevant troubleshooting data, and providing collaboration\ntools to get services back up and running. To achieve the primary goal of\nreducing the time-to-resolution of critical incidents, Incident Manager\nautomates response plans and enables responder team escalation.","ref":"AWS.SSMIncidents.html","title":"AWS.SSMIncidents","type":"module"},{"doc":"Retrieves details about all specified findings for an incident, including\ndescriptive details about each finding.\n\nA finding represents a recent application environment change made by an\nCodeDeploy deployment or an CloudFormation stack creation or update that can be\ninvestigated as a potential cause of the incident.","ref":"AWS.SSMIncidents.html#batch_get_incident_findings/3","title":"AWS.SSMIncidents.batch_get_incident_findings/3","type":"function"},{"doc":"A replication set replicates and encrypts your data to the provided Regions with\nthe provided KMS key.","ref":"AWS.SSMIncidents.html#create_replication_set/3","title":"AWS.SSMIncidents.create_replication_set/3","type":"function"},{"doc":"Creates a response plan that automates the initial response to incidents.\n\nA response plan engages contacts, starts chat channel collaboration, and\ninitiates runbooks at the beginning of an incident.","ref":"AWS.SSMIncidents.html#create_response_plan/3","title":"AWS.SSMIncidents.create_response_plan/3","type":"function"},{"doc":"Creates a custom timeline event on the incident details page of an incident\nrecord.\n\nIncident Manager automatically creates timeline events that mark key moments\nduring an incident. You can create custom timeline events to mark important\nevents that Incident Manager can detect automatically.","ref":"AWS.SSMIncidents.html#create_timeline_event/3","title":"AWS.SSMIncidents.create_timeline_event/3","type":"function"},{"doc":"Delete an incident record from Incident Manager.","ref":"AWS.SSMIncidents.html#delete_incident_record/3","title":"AWS.SSMIncidents.delete_incident_record/3","type":"function"},{"doc":"Deletes all Regions in your replication set.\n\nDeleting the replication set deletes all Incident Manager data.","ref":"AWS.SSMIncidents.html#delete_replication_set/3","title":"AWS.SSMIncidents.delete_replication_set/3","type":"function"},{"doc":"Deletes the resource policy that Resource Access Manager uses to share your\nIncident Manager resource.","ref":"AWS.SSMIncidents.html#delete_resource_policy/3","title":"AWS.SSMIncidents.delete_resource_policy/3","type":"function"},{"doc":"Deletes the specified response plan.\n\nDeleting a response plan stops all linked CloudWatch alarms and EventBridge\nevents from creating an incident with this response plan.","ref":"AWS.SSMIncidents.html#delete_response_plan/3","title":"AWS.SSMIncidents.delete_response_plan/3","type":"function"},{"doc":"Deletes a timeline event from an incident.","ref":"AWS.SSMIncidents.html#delete_timeline_event/3","title":"AWS.SSMIncidents.delete_timeline_event/3","type":"function"},{"doc":"Returns the details for the specified incident record.","ref":"AWS.SSMIncidents.html#get_incident_record/3","title":"AWS.SSMIncidents.get_incident_record/3","type":"function"},{"doc":"Retrieve your Incident Manager replication set.","ref":"AWS.SSMIncidents.html#get_replication_set/3","title":"AWS.SSMIncidents.get_replication_set/3","type":"function"},{"doc":"Retrieves the resource policies attached to the specified response plan.","ref":"AWS.SSMIncidents.html#get_resource_policies/3","title":"AWS.SSMIncidents.get_resource_policies/3","type":"function"},{"doc":"Retrieves the details of the specified response plan.","ref":"AWS.SSMIncidents.html#get_response_plan/3","title":"AWS.SSMIncidents.get_response_plan/3","type":"function"},{"doc":"Retrieves a timeline event based on its ID and incident record.","ref":"AWS.SSMIncidents.html#get_timeline_event/4","title":"AWS.SSMIncidents.get_timeline_event/4","type":"function"},{"doc":"Retrieves a list of the IDs of findings, plus their last modified times, that\nhave been identified for a specified incident.\n\nA finding represents a recent application environment change made by an\nCloudFormation stack creation or update or an CodeDeploy deployment that can be\ninvestigated as a potential cause of the incident.","ref":"AWS.SSMIncidents.html#list_incident_findings/3","title":"AWS.SSMIncidents.list_incident_findings/3","type":"function"},{"doc":"Lists all incident records in your account.\n\nUse this command to retrieve the Amazon Resource Name (ARN) of the incident\nrecord you want to update.","ref":"AWS.SSMIncidents.html#list_incident_records/3","title":"AWS.SSMIncidents.list_incident_records/3","type":"function"},{"doc":"List all related items for an incident record.","ref":"AWS.SSMIncidents.html#list_related_items/3","title":"AWS.SSMIncidents.list_related_items/3","type":"function"},{"doc":"Lists details about the replication set configured in your account.","ref":"AWS.SSMIncidents.html#list_replication_sets/3","title":"AWS.SSMIncidents.list_replication_sets/3","type":"function"},{"doc":"Lists all response plans in your account.","ref":"AWS.SSMIncidents.html#list_response_plans/3","title":"AWS.SSMIncidents.list_response_plans/3","type":"function"},{"doc":"Lists the tags that are attached to the specified response plan or incident.","ref":"AWS.SSMIncidents.html#list_tags_for_resource/3","title":"AWS.SSMIncidents.list_tags_for_resource/3","type":"function"},{"doc":"Lists timeline events for the specified incident record.","ref":"AWS.SSMIncidents.html#list_timeline_events/3","title":"AWS.SSMIncidents.list_timeline_events/3","type":"function"},{"doc":"","ref":"AWS.SSMIncidents.html#metadata/0","title":"AWS.SSMIncidents.metadata/0","type":"function"},{"doc":"Adds a resource policy to the specified response plan.\n\nThe resource policy is used to share the response plan using Resource Access\nManager (RAM). For more information about cross-account sharing, see\n[Cross-Region and cross-account incident management](https://docs.aws.amazon.com/incident-manager/latest/userguide/incident-manager-cross-account-cross-region.html).","ref":"AWS.SSMIncidents.html#put_resource_policy/3","title":"AWS.SSMIncidents.put_resource_policy/3","type":"function"},{"doc":"Used to start an incident from CloudWatch alarms, EventBridge events, or\nmanually.","ref":"AWS.SSMIncidents.html#start_incident/3","title":"AWS.SSMIncidents.start_incident/3","type":"function"},{"doc":"Adds a tag to a response plan.","ref":"AWS.SSMIncidents.html#tag_resource/4","title":"AWS.SSMIncidents.tag_resource/4","type":"function"},{"doc":"Removes a tag from a resource.","ref":"AWS.SSMIncidents.html#untag_resource/4","title":"AWS.SSMIncidents.untag_resource/4","type":"function"},{"doc":"Update deletion protection to either allow or deny deletion of the final Region\nin a replication set.","ref":"AWS.SSMIncidents.html#update_deletion_protection/3","title":"AWS.SSMIncidents.update_deletion_protection/3","type":"function"},{"doc":"Update the details of an incident record.\n\nYou can use this operation to update an incident record from the defined chat\nchannel. For more information about using actions in chat channels, see\n[Interacting through chat](https://docs.aws.amazon.com/incident-manager/latest/userguide/chat.html#chat-interact).","ref":"AWS.SSMIncidents.html#update_incident_record/3","title":"AWS.SSMIncidents.update_incident_record/3","type":"function"},{"doc":"Add or remove related items from the related items tab of an incident record.","ref":"AWS.SSMIncidents.html#update_related_items/3","title":"AWS.SSMIncidents.update_related_items/3","type":"function"},{"doc":"Add or delete Regions from your replication set.","ref":"AWS.SSMIncidents.html#update_replication_set/3","title":"AWS.SSMIncidents.update_replication_set/3","type":"function"},{"doc":"Updates the specified response plan.","ref":"AWS.SSMIncidents.html#update_response_plan/3","title":"AWS.SSMIncidents.update_response_plan/3","type":"function"},{"doc":"Updates a timeline event.\n\nYou can update events of type `Custom Event`.","ref":"AWS.SSMIncidents.html#update_timeline_event/3","title":"AWS.SSMIncidents.update_timeline_event/3","type":"function"},{"doc":"AWS IAM Identity Center (successor to AWS Single Sign-On) Portal is a web\nservice that makes it easy for you to assign user access to IAM Identity Center\nresources such as the AWS access portal.\n\nUsers can get AWS account applications and roles assigned to them and get\nfederated into the application.\n\nAlthough AWS Single Sign-On was renamed, the `sso` and `identitystore` API\nnamespaces will continue to retain their original name for backward\ncompatibility purposes. For more information, see [IAM Identity Center rename](https://docs.aws.amazon.com/singlesignon/latest/userguide/what-is.html#renamed).\n\nThis reference guide describes the IAM Identity Center Portal operations that\nyou can call programatically and includes detailed information on data types and\nerrors.\n\nAWS provides SDKs that consist of libraries and sample code for various\nprogramming languages and platforms, such as Java, Ruby, .Net, iOS, or Android.\nThe SDKs provide a convenient way to create programmatic access to IAM Identity\nCenter and other AWS services. For more information about the AWS SDKs,\nincluding how to download and install them, see [Tools for Amazon Web Services](http://aws.amazon.com/tools/).","ref":"AWS.SSO.html","title":"AWS.SSO","type":"module"},{"doc":"Returns the STS short-term credentials for a given role name that is assigned to\nthe user.","ref":"AWS.SSO.html#get_role_credentials/5","title":"AWS.SSO.get_role_credentials/5","type":"function"},{"doc":"Lists all roles that are assigned to the user for a given AWS account.","ref":"AWS.SSO.html#list_account_roles/6","title":"AWS.SSO.list_account_roles/6","type":"function"},{"doc":"Lists all AWS accounts assigned to the user.\n\nThese AWS accounts are assigned by the administrator of the account. For more\ninformation, see [Assign User Access](https://docs.aws.amazon.com/singlesignon/latest/userguide/useraccess.html#assignusers)\nin the *IAM Identity Center User Guide*. This operation returns a paginated\nresponse.","ref":"AWS.SSO.html#list_accounts/5","title":"AWS.SSO.list_accounts/5","type":"function"},{"doc":"Removes the locally stored SSO tokens from the client-side cache and sends an\nAPI call to the IAM Identity Center service to invalidate the corresponding\nserver-side IAM Identity Center sign in session.\n\nIf a user uses IAM Identity Center to access the AWS CLI, the user’s IAM\nIdentity Center sign in session is used to obtain an IAM session, as specified\nin the corresponding IAM Identity Center permission set. More specifically, IAM\nIdentity Center assumes an IAM role in the target account on behalf of the user,\nand the corresponding temporary AWS credentials are returned to the client.\n\nAfter user logout, any existing IAM role sessions that were created by using IAM\nIdentity Center permission sets continue based on the duration configured in the\npermission set. For more information, see [User authentications](https://docs.aws.amazon.com/singlesignon/latest/userguide/authconcept.html)\nin the *IAM Identity Center User Guide*.","ref":"AWS.SSO.html#logout/3","title":"AWS.SSO.logout/3","type":"function"},{"doc":"","ref":"AWS.SSO.html#metadata/0","title":"AWS.SSO.metadata/0","type":"function"},{"doc":"IAM Identity Center (successor to Single Sign-On) helps you securely create, or\nconnect, your workforce identities and manage their access centrally across\nAmazon Web Services accounts and applications.\n\nIAM Identity Center is the recommended approach for workforce authentication and\nauthorization in Amazon Web Services, for organizations of any size and type.\n\nIAM Identity Center uses the `sso` and `identitystore` API namespaces.\n\nThis reference guide provides information on single sign-on operations which\ncould be used for access management of Amazon Web Services accounts. For\ninformation about IAM Identity Center features, see the [IAM Identity Center User\nGuide](https://docs.aws.amazon.com/singlesignon/latest/userguide/what-is.html).\n\nMany operations in the IAM Identity Center APIs rely on identifiers for users\nand groups, known as principals. For more information about how to work with\nprincipals and principal IDs in IAM Identity Center, see the [Identity Store API Reference](https://docs.aws.amazon.com/singlesignon/latest/IdentityStoreAPIReference/welcome.html).\n\nAmazon Web Services provides SDKs that consist of libraries and sample code for\nvarious programming languages and platforms (Java, Ruby, .Net, iOS, Android, and\nmore). The SDKs provide a convenient way to create programmatic access to IAM\nIdentity Center and other Amazon Web Services services. For more information\nabout the Amazon Web Services SDKs, including how to download and install them,\nsee [Tools for Amazon Web Services](http://aws.amazon.com/tools/).","ref":"AWS.SSOAdmin.html","title":"AWS.SSOAdmin","type":"module"},{"doc":"Attaches the specified customer managed policy to the specified `PermissionSet`.","ref":"AWS.SSOAdmin.html#attach_customer_managed_policy_reference_to_permission_set/3","title":"AWS.SSOAdmin.attach_customer_managed_policy_reference_to_permission_set/3","type":"function"},{"doc":"Attaches an Amazon Web Services managed policy ARN to a permission set.\n\nIf the permission set is already referenced by one or more account assignments,\nyou will need to call ` `ProvisionPermissionSet` ` after this operation. Calling\n`ProvisionPermissionSet` applies the corresponding IAM policy updates to all\nassigned accounts.","ref":"AWS.SSOAdmin.html#attach_managed_policy_to_permission_set/3","title":"AWS.SSOAdmin.attach_managed_policy_to_permission_set/3","type":"function"},{"doc":"Assigns access to a principal for a specified Amazon Web Services account using\na specified permission set.\n\nThe term *principal* here refers to a user or group that is defined in IAM\nIdentity Center.\n\nAs part of a successful `CreateAccountAssignment` call, the specified permission\nset will automatically be provisioned to the account in the form of an IAM\npolicy. That policy is attached to the IAM role created in IAM Identity Center.\nIf the permission set is subsequently updated, the corresponding IAM policies\nattached to roles in your accounts will not be updated automatically. In this\ncase, you must call ` `ProvisionPermissionSet` ` to make these updates.\n\nAfter a successful response, call `DescribeAccountAssignmentCreationStatus` to\ndescribe the status of an assignment creation request.","ref":"AWS.SSOAdmin.html#create_account_assignment/3","title":"AWS.SSOAdmin.create_account_assignment/3","type":"function"},{"doc":"Creates an application in IAM Identity Center for the given application\nprovider.","ref":"AWS.SSOAdmin.html#create_application/3","title":"AWS.SSOAdmin.create_application/3","type":"function"},{"doc":"Grant application access to a user or group.","ref":"AWS.SSOAdmin.html#create_application_assignment/3","title":"AWS.SSOAdmin.create_application_assignment/3","type":"function"},{"doc":"Creates an instance of IAM Identity Center for a standalone Amazon Web Services\naccount that is not managed by Organizations or a member Amazon Web Services\naccount in an organization.\n\nYou can create only one instance per account and across all Amazon Web Services\nRegions.\n\nThe CreateInstance request is rejected if the following apply:\n\n  * The instance is created within the organization management\naccount.\n\n  * An instance already exists in the same account.","ref":"AWS.SSOAdmin.html#create_instance/3","title":"AWS.SSOAdmin.create_instance/3","type":"function"},{"doc":"Enables the attributes-based access control (ABAC) feature for the specified IAM\nIdentity Center instance.\n\nYou can also specify new attributes to add to your ABAC configuration during the\nenabling process. For more information about ABAC, see [Attribute-Based Access Control](/singlesignon/latest/userguide/abac.html) in the *IAM Identity Center\nUser Guide*.\n\nAfter a successful response, call\n`DescribeInstanceAccessControlAttributeConfiguration` to validate that\n`InstanceAccessControlAttributeConfiguration` was created.","ref":"AWS.SSOAdmin.html#create_instance_access_control_attribute_configuration/3","title":"AWS.SSOAdmin.create_instance_access_control_attribute_configuration/3","type":"function"},{"doc":"Creates a permission set within a specified IAM Identity Center instance.\n\nTo grant users and groups access to Amazon Web Services account resources, use `\n`CreateAccountAssignment` `.","ref":"AWS.SSOAdmin.html#create_permission_set/3","title":"AWS.SSOAdmin.create_permission_set/3","type":"function"},{"doc":"Creates a connection to a trusted token issuer in an instance of IAM Identity\nCenter.\n\nA trusted token issuer enables trusted identity propagation to be used with\napplications that authenticate outside of Amazon Web Services.\n\nThis trusted token issuer describes an external identity provider (IdP) that can\ngenerate claims or assertions in the form of access tokens for a user.\nApplications enabled for IAM Identity Center can use these tokens for\nauthentication.","ref":"AWS.SSOAdmin.html#create_trusted_token_issuer/3","title":"AWS.SSOAdmin.create_trusted_token_issuer/3","type":"function"},{"doc":"Deletes a principal's access from a specified Amazon Web Services account using\na specified permission set.\n\nAfter a successful response, call `DescribeAccountAssignmentDeletionStatus` to\ndescribe the status of an assignment deletion request.","ref":"AWS.SSOAdmin.html#delete_account_assignment/3","title":"AWS.SSOAdmin.delete_account_assignment/3","type":"function"},{"doc":"Deletes the association with the application.\n\nThe connected service resource still exists.","ref":"AWS.SSOAdmin.html#delete_application/3","title":"AWS.SSOAdmin.delete_application/3","type":"function"},{"doc":"Deletes an IAM Identity Center access scope from an application.","ref":"AWS.SSOAdmin.html#delete_application_access_scope/3","title":"AWS.SSOAdmin.delete_application_access_scope/3","type":"function"},{"doc":"Revoke application access to an application by deleting application assignments\nfor a user or group.","ref":"AWS.SSOAdmin.html#delete_application_assignment/3","title":"AWS.SSOAdmin.delete_application_assignment/3","type":"function"},{"doc":"Deletes an authentication method from an application.","ref":"AWS.SSOAdmin.html#delete_application_authentication_method/3","title":"AWS.SSOAdmin.delete_application_authentication_method/3","type":"function"},{"doc":"Deletes a grant from an application.","ref":"AWS.SSOAdmin.html#delete_application_grant/3","title":"AWS.SSOAdmin.delete_application_grant/3","type":"function"},{"doc":"Deletes the inline policy from a specified permission set.","ref":"AWS.SSOAdmin.html#delete_inline_policy_from_permission_set/3","title":"AWS.SSOAdmin.delete_inline_policy_from_permission_set/3","type":"function"},{"doc":"Deletes the instance of IAM Identity Center.\n\nOnly the account that owns the instance can call this API. Neither the delegated\nadministrator nor member account can delete the organization instance, but those\nroles can delete their own instance.","ref":"AWS.SSOAdmin.html#delete_instance/3","title":"AWS.SSOAdmin.delete_instance/3","type":"function"},{"doc":"Disables the attributes-based access control (ABAC) feature for the specified\nIAM Identity Center instance and deletes all of the attribute mappings that have\nbeen configured.\n\nOnce deleted, any attributes that are received from an identity source and any\ncustom attributes you have previously configured will not be passed. For more\ninformation about ABAC, see [Attribute-Based Access Control](/singlesignon/latest/userguide/abac.html) in the *IAM Identity Center\nUser Guide*.","ref":"AWS.SSOAdmin.html#delete_instance_access_control_attribute_configuration/3","title":"AWS.SSOAdmin.delete_instance_access_control_attribute_configuration/3","type":"function"},{"doc":"Deletes the specified permission set.","ref":"AWS.SSOAdmin.html#delete_permission_set/3","title":"AWS.SSOAdmin.delete_permission_set/3","type":"function"},{"doc":"Deletes the permissions boundary from a specified `PermissionSet`.","ref":"AWS.SSOAdmin.html#delete_permissions_boundary_from_permission_set/3","title":"AWS.SSOAdmin.delete_permissions_boundary_from_permission_set/3","type":"function"},{"doc":"Deletes a trusted token issuer configuration from an instance of IAM Identity\nCenter.\n\nDeleting this trusted token issuer configuration will cause users to lose access\nto any applications that are configured to use the trusted token issuer.","ref":"AWS.SSOAdmin.html#delete_trusted_token_issuer/3","title":"AWS.SSOAdmin.delete_trusted_token_issuer/3","type":"function"},{"doc":"Describes the status of the assignment creation request.","ref":"AWS.SSOAdmin.html#describe_account_assignment_creation_status/3","title":"AWS.SSOAdmin.describe_account_assignment_creation_status/3","type":"function"},{"doc":"Describes the status of the assignment deletion request.","ref":"AWS.SSOAdmin.html#describe_account_assignment_deletion_status/3","title":"AWS.SSOAdmin.describe_account_assignment_deletion_status/3","type":"function"},{"doc":"Retrieves the details of an application associated with an instance of IAM\nIdentity Center.","ref":"AWS.SSOAdmin.html#describe_application/3","title":"AWS.SSOAdmin.describe_application/3","type":"function"},{"doc":"Retrieves a direct assignment of a user or group to an application.\n\nIf the user doesn’t have a direct assignment to the application, the user may\nstill have access to the application through a group. Therefore, don’t use this\nAPI to test access to an application for a user. Instead use\n`ListApplicationAssignmentsForPrincipal`.","ref":"AWS.SSOAdmin.html#describe_application_assignment/3","title":"AWS.SSOAdmin.describe_application_assignment/3","type":"function"},{"doc":"Retrieves details about a provider that can be used to connect an Amazon Web\nServices managed application or customer managed application to IAM Identity\nCenter.","ref":"AWS.SSOAdmin.html#describe_application_provider/3","title":"AWS.SSOAdmin.describe_application_provider/3","type":"function"},{"doc":"Returns the details of an instance of IAM Identity Center.\n\nThe status can be one of the following:\n\n  * `CREATE_IN_PROGRESS` - The instance is in the process of being\ncreated. When the instance is ready for use, DescribeInstance returns the status\nof `ACTIVE`. While the instance is in the `CREATE_IN_PROGRESS` state, you can\ncall only DescribeInstance and DeleteInstance operations.\n\n  * `DELETE_IN_PROGRESS` - The instance is being deleted. Returns\n`AccessDeniedException` after the delete operation completes.\n\n  * `ACTIVE` - The instance is active.","ref":"AWS.SSOAdmin.html#describe_instance/3","title":"AWS.SSOAdmin.describe_instance/3","type":"function"},{"doc":"Returns the list of IAM Identity Center identity store attributes that have been\nconfigured to work with attributes-based access control (ABAC) for the specified\nIAM Identity Center instance.\n\nThis will not return attributes configured and sent by an external identity\nprovider. For more information about ABAC, see [Attribute-Based Access Control](/singlesignon/latest/userguide/abac.html) in the *IAM Identity Center\nUser Guide*.","ref":"AWS.SSOAdmin.html#describe_instance_access_control_attribute_configuration/3","title":"AWS.SSOAdmin.describe_instance_access_control_attribute_configuration/3","type":"function"},{"doc":"Gets the details of the permission set.","ref":"AWS.SSOAdmin.html#describe_permission_set/3","title":"AWS.SSOAdmin.describe_permission_set/3","type":"function"},{"doc":"Describes the status for the given permission set provisioning request.","ref":"AWS.SSOAdmin.html#describe_permission_set_provisioning_status/3","title":"AWS.SSOAdmin.describe_permission_set_provisioning_status/3","type":"function"},{"doc":"Retrieves details about a trusted token issuer configuration stored in an\ninstance of IAM Identity Center.\n\nDetails include the name of the trusted token issuer, the issuer URL, and the\npath of the source attribute and the destination attribute for a trusted token\nissuer configuration.","ref":"AWS.SSOAdmin.html#describe_trusted_token_issuer/3","title":"AWS.SSOAdmin.describe_trusted_token_issuer/3","type":"function"},{"doc":"Detaches the specified customer managed policy from the specified\n`PermissionSet`.","ref":"AWS.SSOAdmin.html#detach_customer_managed_policy_reference_from_permission_set/3","title":"AWS.SSOAdmin.detach_customer_managed_policy_reference_from_permission_set/3","type":"function"},{"doc":"Detaches the attached Amazon Web Services managed policy ARN from the specified\npermission set.","ref":"AWS.SSOAdmin.html#detach_managed_policy_from_permission_set/3","title":"AWS.SSOAdmin.detach_managed_policy_from_permission_set/3","type":"function"},{"doc":"Retrieves the authorized targets for an IAM Identity Center access scope for an\napplication.","ref":"AWS.SSOAdmin.html#get_application_access_scope/3","title":"AWS.SSOAdmin.get_application_access_scope/3","type":"function"},{"doc":"Retrieves the configuration of `PutApplicationAssignmentConfiguration`.","ref":"AWS.SSOAdmin.html#get_application_assignment_configuration/3","title":"AWS.SSOAdmin.get_application_assignment_configuration/3","type":"function"},{"doc":"Retrieves details about an authentication method used by an application.","ref":"AWS.SSOAdmin.html#get_application_authentication_method/3","title":"AWS.SSOAdmin.get_application_authentication_method/3","type":"function"},{"doc":"Retrieves details about an application grant.","ref":"AWS.SSOAdmin.html#get_application_grant/3","title":"AWS.SSOAdmin.get_application_grant/3","type":"function"},{"doc":"Obtains the inline policy assigned to the permission set.","ref":"AWS.SSOAdmin.html#get_inline_policy_for_permission_set/3","title":"AWS.SSOAdmin.get_inline_policy_for_permission_set/3","type":"function"},{"doc":"Obtains the permissions boundary for a specified `PermissionSet`.","ref":"AWS.SSOAdmin.html#get_permissions_boundary_for_permission_set/3","title":"AWS.SSOAdmin.get_permissions_boundary_for_permission_set/3","type":"function"},{"doc":"Lists the status of the Amazon Web Services account assignment creation requests\nfor a specified IAM Identity Center instance.","ref":"AWS.SSOAdmin.html#list_account_assignment_creation_status/3","title":"AWS.SSOAdmin.list_account_assignment_creation_status/3","type":"function"},{"doc":"Lists the status of the Amazon Web Services account assignment deletion requests\nfor a specified IAM Identity Center instance.","ref":"AWS.SSOAdmin.html#list_account_assignment_deletion_status/3","title":"AWS.SSOAdmin.list_account_assignment_deletion_status/3","type":"function"},{"doc":"Lists the assignee of the specified Amazon Web Services account with the\nspecified permission set.","ref":"AWS.SSOAdmin.html#list_account_assignments/3","title":"AWS.SSOAdmin.list_account_assignments/3","type":"function"},{"doc":"Retrieves a list of the IAM Identity Center associated Amazon Web Services\naccounts that the principal has access to.","ref":"AWS.SSOAdmin.html#list_account_assignments_for_principal/3","title":"AWS.SSOAdmin.list_account_assignments_for_principal/3","type":"function"},{"doc":"Lists all the Amazon Web Services accounts where the specified permission set is\nprovisioned.","ref":"AWS.SSOAdmin.html#list_accounts_for_provisioned_permission_set/3","title":"AWS.SSOAdmin.list_accounts_for_provisioned_permission_set/3","type":"function"},{"doc":"Lists the access scopes and authorized targets associated with an application.","ref":"AWS.SSOAdmin.html#list_application_access_scopes/3","title":"AWS.SSOAdmin.list_application_access_scopes/3","type":"function"},{"doc":"Lists Amazon Web Services account users that are assigned to an application.","ref":"AWS.SSOAdmin.html#list_application_assignments/3","title":"AWS.SSOAdmin.list_application_assignments/3","type":"function"},{"doc":"Lists the applications to which a specified principal is assigned.","ref":"AWS.SSOAdmin.html#list_application_assignments_for_principal/3","title":"AWS.SSOAdmin.list_application_assignments_for_principal/3","type":"function"},{"doc":"Lists all of the authentication methods supported by the specified application.","ref":"AWS.SSOAdmin.html#list_application_authentication_methods/3","title":"AWS.SSOAdmin.list_application_authentication_methods/3","type":"function"},{"doc":"List the grants associated with an application.","ref":"AWS.SSOAdmin.html#list_application_grants/3","title":"AWS.SSOAdmin.list_application_grants/3","type":"function"},{"doc":"Lists the application providers configured in the IAM Identity Center identity\nstore.","ref":"AWS.SSOAdmin.html#list_application_providers/3","title":"AWS.SSOAdmin.list_application_providers/3","type":"function"},{"doc":"Lists all applications associated with the instance of IAM Identity Center.\n\nWhen listing applications for an instance in the management account, member\naccounts must use the `applicationAccount` parameter to filter the list to only\napplications created from that account.","ref":"AWS.SSOAdmin.html#list_applications/3","title":"AWS.SSOAdmin.list_applications/3","type":"function"},{"doc":"Lists all customer managed policies attached to a specified `PermissionSet`.","ref":"AWS.SSOAdmin.html#list_customer_managed_policy_references_in_permission_set/3","title":"AWS.SSOAdmin.list_customer_managed_policy_references_in_permission_set/3","type":"function"},{"doc":"Lists the details of the organization and account instances of IAM Identity\nCenter that were created in or visible to the account calling this API.","ref":"AWS.SSOAdmin.html#list_instances/3","title":"AWS.SSOAdmin.list_instances/3","type":"function"},{"doc":"Lists the Amazon Web Services managed policy that is attached to a specified\npermission set.","ref":"AWS.SSOAdmin.html#list_managed_policies_in_permission_set/3","title":"AWS.SSOAdmin.list_managed_policies_in_permission_set/3","type":"function"},{"doc":"Lists the status of the permission set provisioning requests for a specified IAM\nIdentity Center instance.","ref":"AWS.SSOAdmin.html#list_permission_set_provisioning_status/3","title":"AWS.SSOAdmin.list_permission_set_provisioning_status/3","type":"function"},{"doc":"Lists the `PermissionSet`s in an IAM Identity Center instance.","ref":"AWS.SSOAdmin.html#list_permission_sets/3","title":"AWS.SSOAdmin.list_permission_sets/3","type":"function"},{"doc":"Lists all the permission sets that are provisioned to a specified Amazon Web\nServices account.","ref":"AWS.SSOAdmin.html#list_permission_sets_provisioned_to_account/3","title":"AWS.SSOAdmin.list_permission_sets_provisioned_to_account/3","type":"function"},{"doc":"Lists the tags that are attached to a specified resource.","ref":"AWS.SSOAdmin.html#list_tags_for_resource/3","title":"AWS.SSOAdmin.list_tags_for_resource/3","type":"function"},{"doc":"Lists all the trusted token issuers configured in an instance of IAM Identity\nCenter.","ref":"AWS.SSOAdmin.html#list_trusted_token_issuers/3","title":"AWS.SSOAdmin.list_trusted_token_issuers/3","type":"function"},{"doc":"","ref":"AWS.SSOAdmin.html#metadata/0","title":"AWS.SSOAdmin.metadata/0","type":"function"},{"doc":"The process by which a specified permission set is provisioned to the specified\ntarget.","ref":"AWS.SSOAdmin.html#provision_permission_set/3","title":"AWS.SSOAdmin.provision_permission_set/3","type":"function"},{"doc":"Adds or updates the list of authorized targets for an IAM Identity Center access\nscope for an application.","ref":"AWS.SSOAdmin.html#put_application_access_scope/3","title":"AWS.SSOAdmin.put_application_access_scope/3","type":"function"},{"doc":"Configure how users gain access to an application.\n\nIf `AssignmentsRequired` is `true` (default value), users don’t have access to\nthe application unless an assignment is created using the\n[CreateApplicationAssignment API](https://docs.aws.amazon.com/singlesignon/latest/APIReference/API_CreateApplicationAssignment.html).\nIf `false`, all users have access to the application. If an assignment is\ncreated using\n[CreateApplicationAssignment](https://docs.aws.amazon.com/singlesignon/latest/APIReference/API_CreateApplicationAssignment.html).,\nthe user retains access if `AssignmentsRequired` is set to `true`.","ref":"AWS.SSOAdmin.html#put_application_assignment_configuration/3","title":"AWS.SSOAdmin.put_application_assignment_configuration/3","type":"function"},{"doc":"Adds or updates an authentication method for an application.","ref":"AWS.SSOAdmin.html#put_application_authentication_method/3","title":"AWS.SSOAdmin.put_application_authentication_method/3","type":"function"},{"doc":"Adds a grant to an application.","ref":"AWS.SSOAdmin.html#put_application_grant/3","title":"AWS.SSOAdmin.put_application_grant/3","type":"function"},{"doc":"Attaches an inline policy to a permission set.\n\nIf the permission set is already referenced by one or more account assignments,\nyou will need to call ` `ProvisionPermissionSet` ` after this action to apply\nthe corresponding IAM policy updates to all assigned accounts.","ref":"AWS.SSOAdmin.html#put_inline_policy_to_permission_set/3","title":"AWS.SSOAdmin.put_inline_policy_to_permission_set/3","type":"function"},{"doc":"Attaches an Amazon Web Services managed or customer managed policy to the\nspecified `PermissionSet` as a permissions boundary.","ref":"AWS.SSOAdmin.html#put_permissions_boundary_to_permission_set/3","title":"AWS.SSOAdmin.put_permissions_boundary_to_permission_set/3","type":"function"},{"doc":"Associates a set of tags with a specified resource.","ref":"AWS.SSOAdmin.html#tag_resource/3","title":"AWS.SSOAdmin.tag_resource/3","type":"function"},{"doc":"Disassociates a set of tags from a specified resource.","ref":"AWS.SSOAdmin.html#untag_resource/3","title":"AWS.SSOAdmin.untag_resource/3","type":"function"},{"doc":"Updates application properties.","ref":"AWS.SSOAdmin.html#update_application/3","title":"AWS.SSOAdmin.update_application/3","type":"function"},{"doc":"Update the details for the instance of IAM Identity Center that is owned by the\nAmazon Web Services account.","ref":"AWS.SSOAdmin.html#update_instance/3","title":"AWS.SSOAdmin.update_instance/3","type":"function"},{"doc":"Updates the IAM Identity Center identity store attributes that you can use with\nthe IAM Identity Center instance for attributes-based access control (ABAC).\n\nWhen using an external identity provider as an identity source, you can pass\nattributes through the SAML assertion as an alternative to configuring\nattributes from the IAM Identity Center identity store. If a SAML assertion\npasses any of these attributes, IAM Identity Center replaces the attribute value\nwith the value from the IAM Identity Center identity store. For more information\nabout ABAC, see [Attribute-Based Access Control](/singlesignon/latest/userguide/abac.html) in the *IAM Identity Center\nUser Guide*.","ref":"AWS.SSOAdmin.html#update_instance_access_control_attribute_configuration/3","title":"AWS.SSOAdmin.update_instance_access_control_attribute_configuration/3","type":"function"},{"doc":"Updates an existing permission set.","ref":"AWS.SSOAdmin.html#update_permission_set/3","title":"AWS.SSOAdmin.update_permission_set/3","type":"function"},{"doc":"Updates the name of the trusted token issuer, or the path of a source attribute\nor destination attribute for a trusted token issuer configuration.\n\nUpdating this trusted token issuer configuration might cause users to lose\naccess to any applications that are configured to use the trusted token issuer.","ref":"AWS.SSOAdmin.html#update_trusted_token_issuer/3","title":"AWS.SSOAdmin.update_trusted_token_issuer/3","type":"function"},{"doc":"IAM Identity Center OpenID Connect (OIDC) is a web service that enables a client\n(such as CLI or a native application) to register with IAM Identity Center.\n\nThe service also enables the client to fetch the user’s access token upon\nsuccessful authentication and authorization with IAM Identity Center.\n\nIAM Identity Center uses the `sso` and `identitystore` API namespaces.","ref":"AWS.SSOOIDC.html","title":"AWS.SSOOIDC","type":"module"},{"doc":"Before you begin using this guide, we recommend that you first review the\nfollowing important information about how the IAM Identity Center OIDC service\nworks.\n\n  * The IAM Identity Center OIDC service currently implements only the\nportions of the OAuth 2.0 Device Authorization Grant standard\n([https://tools.ietf.org/html/rfc8628](https://tools.ietf.org/html/rfc8628)) that are necessary to enable single sign-on authentication with the CLI.\n\n  * With older versions of the CLI, the service only emits OIDC access\ntokens, so to obtain a new token, users must explicitly re-authenticate. To\naccess the OIDC flow that supports token refresh and doesn’t require\nre-authentication, update to the latest CLI version (1.27.10 for CLI V1 and\n2.9.0 for CLI V2) with support for OIDC token refresh and configurable IAM\nIdentity Center session durations. For more information, see [Configure Amazon\nWeb Services access portal session duration\n](https://docs.aws.amazon.com/singlesignon/latest/userguide/configure-user-session.html).\n\n  * The access tokens provided by this service grant access to all\nAmazon Web Services account entitlements assigned to an IAM Identity Center\nuser, not just a particular application.\n\n  * The documentation in this guide does not describe the mechanism to\nconvert the access token into Amazon Web Services Auth (“sigv4”) credentials for\nuse with IAM-protected Amazon Web Services service endpoints. For more\ninformation, see\n[GetRoleCredentials](https://docs.aws.amazon.com/singlesignon/latest/PortalAPIReference/API_GetRoleCredentials.html) in the *IAM Identity Center Portal API Reference Guide*.\n\nFor general information about IAM Identity Center, see [What is IAM Identity\nCenter?](https://docs.aws.amazon.com/singlesignon/latest/userguide/what-is.html)\nin the *IAM Identity Center User Guide*.","ref":"AWS.SSOOIDC.html#module-considerations-for-using-this-guide","title":"Considerations for Using This Guide - AWS.SSOOIDC","type":"module"},{"doc":"Creates and returns access and refresh tokens for clients that are authenticated\nusing client secrets.\n\nThe access token can be used to fetch short-term credentials for the assigned\nAWS accounts or to access application APIs using `bearer` authentication.","ref":"AWS.SSOOIDC.html#create_token/3","title":"AWS.SSOOIDC.create_token/3","type":"function"},{"doc":"Creates and returns access and refresh tokens for clients and applications that\nare authenticated using IAM entities.\n\nThe access token can be used to fetch short-term credentials for the assigned\nAWS accounts or to access application APIs using `bearer` authentication.","ref":"AWS.SSOOIDC.html#create_token_with_iam/3","title":"AWS.SSOOIDC.create_token_with_iam/3","type":"function"},{"doc":"","ref":"AWS.SSOOIDC.html#metadata/0","title":"AWS.SSOOIDC.metadata/0","type":"function"},{"doc":"Registers a client with IAM Identity Center.\n\nThis allows clients to initiate device authorization. The output should be\npersisted for reuse through many authentication requests.","ref":"AWS.SSOOIDC.html#register_client/3","title":"AWS.SSOOIDC.register_client/3","type":"function"},{"doc":"Initiates device authorization by requesting a pair of verification codes from\nthe authorization service.","ref":"AWS.SSOOIDC.html#start_device_authorization/3","title":"AWS.SSOOIDC.start_device_authorization/3","type":"function"},{"doc":"Security Token Service\n\nSecurity Token Service (STS) enables you to request temporary, limited-privilege\ncredentials for users.\n\nThis guide provides descriptions of the STS API. For more information about\nusing this service, see [Temporary Security Credentials](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp.html).","ref":"AWS.STS.html","title":"AWS.STS","type":"module"},{"doc":"Returns a set of temporary security credentials that you can use to access\nAmazon Web Services resources.\n\nThese temporary credentials consist of an access key ID, a secret access key,\nand a security token. Typically, you use `AssumeRole` within your account or for\ncross-account access. For a comparison of `AssumeRole` with other API operations\nthat produce temporary credentials, see [Requesting Temporary Security Credentials](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_request.html)\nand [Comparing the Amazon Web Services STS API operations](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_request.html#stsapi_comparison)\nin the *IAM User Guide*.","ref":"AWS.STS.html#assume_role/3","title":"AWS.STS.assume_role/3","type":"function"},{"doc":"The temporary security credentials created by `AssumeRole` can be used to make\nAPI calls to any Amazon Web Services service with the following exception: You\ncannot call the Amazon Web Services STS `GetFederationToken` or\n`GetSessionToken` API operations.\n\n(Optional) You can pass inline or managed [session policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies.html#policies_session)\nto this operation. You can pass a single JSON policy document to use as an\ninline session policy. You can also specify up to 10 managed policy Amazon\nResource Names (ARNs) to use as managed session policies. The plaintext that you\nuse for both inline and managed session policies can't exceed 2,048 characters.\nPassing policies to this operation returns new temporary credentials. The\nresulting session's permissions are the intersection of the role's\nidentity-based policy and the session policies. You can use the role's temporary\ncredentials in subsequent Amazon Web Services API calls to access resources in\nthe account that owns the role. You cannot use session policies to grant more\npermissions than those allowed by the identity-based policy of the role that is\nbeing assumed. For more information, see [Session Policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies.html#policies_session)\nin the *IAM User Guide*.\n\nWhen you create a role, you create two policies: a role trust policy that\nspecifies *who* can assume the role, and a permissions policy that specifies\n*what* can be done with the role. You specify the trusted principal that is\nallowed to assume the role in the role trust policy.\n\nTo assume a role from a different account, your Amazon Web Services account must\nbe trusted by the role. The trust relationship is defined in the role's trust\npolicy when the role is created. That trust policy states which accounts are\nallowed to delegate that access to users in the account.\n\nA user who wants to access a role in a different account must also have\npermissions that are delegated from the account administrator. The administrator\nmust attach a policy that allows the user to call `AssumeRole` for the ARN of\nthe role in the other account.\n\nTo allow a user to assume a role in the same account, you can do either of the\nfollowing:\n\n  * Attach a policy to the user that allows the user to call\n`AssumeRole` (as long as the role's trust policy trusts the account).\n\n  * Add the user as a principal directly in the role's trust policy.\n\nYou can do either because the role’s trust policy acts as an IAM resource-based\npolicy. When a resource-based policy grants access to a principal in the same\naccount, no additional identity-based policy is required. For more information\nabout trust policies and resource-based policies, see [IAM Policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies.html)\nin the *IAM User Guide*.","ref":"AWS.STS.html#assume_role/3-permissions","title":"Permissions - AWS.STS.assume_role/3","type":"function"},{"doc":"(Optional) You can pass tag key-value pairs to your session. These tags are\ncalled session tags. For more information about session tags, see [Passing Session Tags in\nSTS](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_session-tags.html) in\nthe *IAM User Guide*.\n\nAn administrator must grant you the permissions necessary to pass session tags.\nThe administrator can also create granular permissions to allow you to pass only\nspecific session tags. For more information, see [Tutorial: Using Tags for Attribute-Based Access\nControl](https://docs.aws.amazon.com/IAM/latest/UserGuide/tutorial_attribute-based-access-control.html)\nin the *IAM User Guide*.\n\nYou can set the session tags as transitive. Transitive tags persist during role\nchaining. For more information, see [Chaining Roles with Session Tags](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_session-tags.html#id_session-tags_role-chaining)\nin the *IAM User Guide*.","ref":"AWS.STS.html#assume_role/3-tags","title":"Tags - AWS.STS.assume_role/3","type":"function"},{"doc":"(Optional) You can include multi-factor authentication (MFA) information when\nyou call `AssumeRole`. This is useful for cross-account scenarios to ensure that\nthe user that assumes the role has been authenticated with an Amazon Web\nServices MFA device. In that scenario, the trust policy of the role being\nassumed includes a condition that tests for MFA authentication. If the caller\ndoes not include valid MFA information, the request to assume the role is\ndenied. The condition in a trust policy that tests for MFA authentication might\nlook like the following example.\n\n`\"Condition\": {\"Bool\": {\"aws:MultiFactorAuthPresent\": true}}`\n\nFor more information, see [Configuring MFA-Protected API Access](https://docs.aws.amazon.com/IAM/latest/UserGuide/MFAProtectedAPI.html)\nin the *IAM User Guide* guide.\n\nTo use MFA with `AssumeRole`, you pass values for the `SerialNumber` and\n`TokenCode` parameters. The `SerialNumber` value identifies the user's hardware\nor virtual MFA device. The `TokenCode` is the time-based one-time password\n(TOTP) that the MFA device produces.","ref":"AWS.STS.html#assume_role/3-using-mfa-with-assumerole","title":"Using MFA with AssumeRole - AWS.STS.assume_role/3","type":"function"},{"doc":"Returns a set of temporary security credentials for users who have been\nauthenticated via a SAML authentication response.\n\nThis operation provides a mechanism for tying an enterprise identity store or\ndirectory to role-based Amazon Web Services access without user-specific\ncredentials or configuration. For a comparison of `AssumeRoleWithSAML` with the\nother API operations that produce temporary credentials, see [Requesting Temporary Security\nCredentials](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_request.html)\nand [Comparing the Amazon Web Services STS API operations](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_request.html#stsapi_comparison)\nin the *IAM User Guide*.\n\nThe temporary security credentials returned by this operation consist of an\naccess key ID, a secret access key, and a security token. Applications can use\nthese temporary security credentials to sign calls to Amazon Web Services\nservices.","ref":"AWS.STS.html#assume_role_with_saml/3","title":"AWS.STS.assume_role_with_saml/3","type":"function"},{"doc":"By default, the temporary security credentials created by `AssumeRoleWithSAML`\nlast for one hour. However, you can use the optional `DurationSeconds` parameter\nto specify the duration of your session. Your role session lasts for the\nduration that you specify, or until the time specified in the SAML\nauthentication response's `SessionNotOnOrAfter` value, whichever is shorter. You\ncan provide a `DurationSeconds` value from 900 seconds (15 minutes) up to the\nmaximum session duration setting for the role. This setting can have a value\nfrom 1 hour to 12 hours. To learn how to view the maximum value for your role,\nsee [View the Maximum Session Duration Setting for a Role](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_use.html#id_roles_use_view-role-max-session)\nin the *IAM User Guide*. The maximum session duration limit applies when you use\nthe `AssumeRole*` API operations or the `assume-role*` CLI commands. However the\nlimit does not apply when you use those operations to create a console URL. For\nmore information, see [Using IAM Roles](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_use.html) in\nthe *IAM User Guide*.\n\n[Role chaining](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_terms-and-concepts.html#iam-term-role-chaining)\nlimits your CLI or Amazon Web Services API role session to a maximum of one\nhour. When you use the `AssumeRole` API operation to assume a role, you can\nspecify the duration of your role session with the `DurationSeconds` parameter.\nYou can specify a parameter value of up to 43200 seconds (12 hours), depending\non the maximum session duration setting for your role. However, if you assume a\nrole using role chaining and provide a `DurationSeconds` parameter value greater\nthan one hour, the operation fails.","ref":"AWS.STS.html#assume_role_with_saml/3-session-duration","title":"Session Duration - AWS.STS.assume_role_with_saml/3","type":"function"},{"doc":"The temporary security credentials created by `AssumeRoleWithSAML` can be used\nto make API calls to any Amazon Web Services service with the following\nexception: you cannot call the STS `GetFederationToken` or `GetSessionToken` API\noperations.\n\n(Optional) You can pass inline or managed [session policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies.html#policies_session)\nto this operation. You can pass a single JSON policy document to use as an\ninline session policy. You can also specify up to 10 managed policy Amazon\nResource Names (ARNs) to use as managed session policies. The plaintext that you\nuse for both inline and managed session policies can't exceed 2,048 characters.\nPassing policies to this operation returns new temporary credentials. The\nresulting session's permissions are the intersection of the role's\nidentity-based policy and the session policies. You can use the role's temporary\ncredentials in subsequent Amazon Web Services API calls to access resources in\nthe account that owns the role. You cannot use session policies to grant more\npermissions than those allowed by the identity-based policy of the role that is\nbeing assumed. For more information, see [Session Policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies.html#policies_session)\nin the *IAM User Guide*.\n\nCalling `AssumeRoleWithSAML` does not require the use of Amazon Web Services\nsecurity credentials. The identity of the caller is validated by using keys in\nthe metadata document that is uploaded for the SAML provider entity for your\nidentity provider.\n\nCalling `AssumeRoleWithSAML` can result in an entry in your CloudTrail logs. The\nentry includes the value in the `NameID` element of the SAML assertion. We\nrecommend that you use a `NameIDType` that is not associated with any personally\nidentifiable information (PII). For example, you could instead use the\npersistent identifier (`urn:oasis:names:tc:SAML:2.0:nameid-format:persistent`).","ref":"AWS.STS.html#assume_role_with_saml/3-permissions","title":"Permissions - AWS.STS.assume_role_with_saml/3","type":"function"},{"doc":"(Optional) You can configure your IdP to pass attributes into your SAML\nassertion as session tags. Each session tag consists of a key name and an\nassociated value. For more information about session tags, see [Passing Session Tags in\nSTS](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_session-tags.html) in\nthe *IAM User Guide*.\n\nYou can pass up to 50 session tags. The plaintext session tag keys can’t exceed\n128 characters and the values can’t exceed 256 characters. For these and\nadditional limits, see [IAM and STS Character Limits](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_iam-limits.html#reference_iam-limits-entity-length)\nin the *IAM User Guide*.\n\nAn Amazon Web Services conversion compresses the passed inline session policy,\nmanaged policy ARNs, and session tags into a packed binary format that has a\nseparate limit. Your request can fail for this limit even if your plaintext\nmeets the other requirements. The `PackedPolicySize` response element indicates\nby percentage how close the policies and tags for your request are to the upper\nsize limit.\n\nYou can pass a session tag with the same key as a tag that is attached to the\nrole. When you do, session tags override the role's tags with the same key.\n\nAn administrator must grant you the permissions necessary to pass session tags.\nThe administrator can also create granular permissions to allow you to pass only\nspecific session tags. For more information, see [Tutorial: Using Tags for Attribute-Based Access\nControl](https://docs.aws.amazon.com/IAM/latest/UserGuide/tutorial_attribute-based-access-control.html)\nin the *IAM User Guide*.\n\nYou can set the session tags as transitive. Transitive tags persist during role\nchaining. For more information, see [Chaining Roles with Session Tags](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_session-tags.html#id_session-tags_role-chaining)\nin the *IAM User Guide*.","ref":"AWS.STS.html#assume_role_with_saml/3-tags","title":"Tags - AWS.STS.assume_role_with_saml/3","type":"function"},{"doc":"Before your application can call `AssumeRoleWithSAML`, you must configure your\nSAML identity provider (IdP) to issue the claims required by Amazon Web\nServices. Additionally, you must use Identity and Access Management (IAM) to\ncreate a SAML provider entity in your Amazon Web Services account that\nrepresents your identity provider. You must also create an IAM role that\nspecifies this SAML provider in its trust policy.\n\nFor more information, see the following resources:\n\n  * [About SAML 2.0-based Federation](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_providers_saml.html)\nin the *IAM User Guide*.\n\n  * [Creating SAML Identity Providers](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_providers_create_saml.html)\nin the *IAM User Guide*.\n\n  * [Configuring a Relying Party and Claims](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_providers_create_saml_relying-party.html)\nin the *IAM User Guide*.\n\n  * [Creating a Role for SAML 2.0 Federation](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_create_for-idp_saml.html)\nin the *IAM User Guide*.","ref":"AWS.STS.html#assume_role_with_saml/3-saml-configuration","title":"SAML Configuration - AWS.STS.assume_role_with_saml/3","type":"function"},{"doc":"Returns a set of temporary security credentials for users who have been\nauthenticated in a mobile or web application with a web identity provider.\n\nExample providers include the OAuth 2.0 providers Login with Amazon and\nFacebook, or any OpenID Connect-compatible identity provider such as Google or\n[Amazon Cognito federated identities](https://docs.aws.amazon.com/cognito/latest/developerguide/cognito-identity.html).\n\nFor mobile applications, we recommend that you use Amazon Cognito. You can use\nAmazon Cognito with the [Amazon Web Services SDK for iOS Developer Guide](http://aws.amazon.com/sdkforios/) and the [Amazon Web Services SDK for Android Developer Guide](http://aws.amazon.com/sdkforandroid/) to uniquely\nidentify a user. You can also supply the user with a consistent identity\nthroughout the lifetime of an application.\n\nTo learn more about Amazon Cognito, see [Amazon Cognito identity pools](https://docs.aws.amazon.com/cognito/latest/developerguide/cognito-identity.html)\nin *Amazon Cognito Developer Guide*.\n\nCalling `AssumeRoleWithWebIdentity` does not require the use of Amazon Web\nServices security credentials. Therefore, you can distribute an application (for\nexample, on mobile devices) that requests temporary security credentials without\nincluding long-term Amazon Web Services credentials in the application. You also\ndon't need to deploy server-based proxy services that use long-term Amazon Web\nServices credentials. Instead, the identity of the caller is validated by using\na token from the web identity provider. For a comparison of\n`AssumeRoleWithWebIdentity` with the other API operations that produce temporary\ncredentials, see [Requesting Temporary Security Credentials](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_request.html)\nand [Comparing the Amazon Web Services STS API operations](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_request.html#stsapi_comparison)\nin the *IAM User Guide*.\n\nThe temporary security credentials returned by this API consist of an access key\nID, a secret access key, and a security token. Applications can use these\ntemporary security credentials to sign calls to Amazon Web Services service API\noperations.","ref":"AWS.STS.html#assume_role_with_web_identity/3","title":"AWS.STS.assume_role_with_web_identity/3","type":"function"},{"doc":"By default, the temporary security credentials created by\n`AssumeRoleWithWebIdentity` last for one hour. However, you can use the optional\n`DurationSeconds` parameter to specify the duration of your session. You can\nprovide a value from 900 seconds (15 minutes) up to the maximum session duration\nsetting for the role. This setting can have a value from 1 hour to 12 hours. To\nlearn how to view the maximum value for your role, see [View the Maximum Session Duration Setting for a\nRole](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_use.html#id_roles_use_view-role-max-session)\nin the *IAM User Guide*. The maximum session duration limit applies when you use\nthe `AssumeRole*` API operations or the `assume-role*` CLI commands. However the\nlimit does not apply when you use those operations to create a console URL. For\nmore information, see [Using IAM Roles](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_use.html) in\nthe *IAM User Guide*.","ref":"AWS.STS.html#assume_role_with_web_identity/3-session-duration","title":"Session Duration - AWS.STS.assume_role_with_web_identity/3","type":"function"},{"doc":"The temporary security credentials created by `AssumeRoleWithWebIdentity` can be\nused to make API calls to any Amazon Web Services service with the following\nexception: you cannot call the STS `GetFederationToken` or `GetSessionToken` API\noperations.\n\n(Optional) You can pass inline or managed [session policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies.html#policies_session)\nto this operation. You can pass a single JSON policy document to use as an\ninline session policy. You can also specify up to 10 managed policy Amazon\nResource Names (ARNs) to use as managed session policies. The plaintext that you\nuse for both inline and managed session policies can't exceed 2,048 characters.\nPassing policies to this operation returns new temporary credentials. The\nresulting session's permissions are the intersection of the role's\nidentity-based policy and the session policies. You can use the role's temporary\ncredentials in subsequent Amazon Web Services API calls to access resources in\nthe account that owns the role. You cannot use session policies to grant more\npermissions than those allowed by the identity-based policy of the role that is\nbeing assumed. For more information, see [Session Policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies.html#policies_session)\nin the *IAM User Guide*.","ref":"AWS.STS.html#assume_role_with_web_identity/3-permissions","title":"Permissions - AWS.STS.assume_role_with_web_identity/3","type":"function"},{"doc":"(Optional) You can configure your IdP to pass attributes into your web identity\ntoken as session tags. Each session tag consists of a key name and an associated\nvalue. For more information about session tags, see [Passing Session Tags in STS](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_session-tags.html) in\nthe *IAM User Guide*.\n\nYou can pass up to 50 session tags. The plaintext session tag keys can’t exceed\n128 characters and the values can’t exceed 256 characters. For these and\nadditional limits, see [IAM and STS Character Limits](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_iam-limits.html#reference_iam-limits-entity-length)\nin the *IAM User Guide*.\n\nAn Amazon Web Services conversion compresses the passed inline session policy,\nmanaged policy ARNs, and session tags into a packed binary format that has a\nseparate limit. Your request can fail for this limit even if your plaintext\nmeets the other requirements. The `PackedPolicySize` response element indicates\nby percentage how close the policies and tags for your request are to the upper\nsize limit.\n\nYou can pass a session tag with the same key as a tag that is attached to the\nrole. When you do, the session tag overrides the role tag with the same key.\n\nAn administrator must grant you the permissions necessary to pass session tags.\nThe administrator can also create granular permissions to allow you to pass only\nspecific session tags. For more information, see [Tutorial: Using Tags for Attribute-Based Access\nControl](https://docs.aws.amazon.com/IAM/latest/UserGuide/tutorial_attribute-based-access-control.html)\nin the *IAM User Guide*.\n\nYou can set the session tags as transitive. Transitive tags persist during role\nchaining. For more information, see [Chaining Roles with Session Tags](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_session-tags.html#id_session-tags_role-chaining)\nin the *IAM User Guide*.","ref":"AWS.STS.html#assume_role_with_web_identity/3-tags","title":"Tags - AWS.STS.assume_role_with_web_identity/3","type":"function"},{"doc":"Before your application can call `AssumeRoleWithWebIdentity`, you must have an\nidentity token from a supported identity provider and create a role that the\napplication can assume. The role that your application assumes must trust the\nidentity provider that is associated with the identity token. In other words,\nthe identity provider must be specified in the role's trust policy.\n\nCalling `AssumeRoleWithWebIdentity` can result in an entry in your CloudTrail\nlogs. The entry includes the\n[Subject](http://openid.net/specs/openid-connect-core-1_0.html#Claims) of the provided web identity token. We recommend that you avoid using any personally\nidentifiable information (PII) in this field. For example, you could instead use\na GUID or a pairwise identifier, as [suggested in the OIDC\nspecification](http://openid.net/specs/openid-connect-core-1_0.html#SubjectIDTypes).\n\nFor more information about how to use web identity federation and the\n`AssumeRoleWithWebIdentity` API, see the following resources:\n\n  * [Using Web Identity Federation API Operations for Mobile Apps](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_providers_oidc_manual.html)\nand [Federation Through a Web-based Identity Provider](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_request.html#api_assumerolewithwebidentity).\n\n  * [ Web Identity Federation Playground](https://aws.amazon.com/blogs/aws/the-aws-web-identity-federation-playground/).\nWalk through the process of authenticating through Login with Amazon, Facebook,\nor Google, getting temporary security credentials, and then using those\ncredentials to make a request to Amazon Web Services.\n\n  * [Amazon Web Services SDK for iOS Developer Guide](http://aws.amazon.com/sdkforios/) and [Amazon Web Services SDK for Android Developer Guide](http://aws.amazon.com/sdkforandroid/). These toolkits\ncontain sample apps that show how to invoke the identity providers. The toolkits\nthen show how to use the information from these providers to get and use\ntemporary security credentials.\n\n  * [Web Identity Federation with Mobile Applications](http://aws.amazon.com/articles/web-identity-federation-with-mobile-applications).\nThis article discusses web identity federation and shows an example of how to\nuse web identity federation to get access to content in Amazon S3.","ref":"AWS.STS.html#assume_role_with_web_identity/3-identities","title":"Identities - AWS.STS.assume_role_with_web_identity/3","type":"function"},{"doc":"Decodes additional information about the authorization status of a request from\nan encoded message returned in response to an Amazon Web Services request.\n\nFor example, if a user is not authorized to perform an operation that he or she\nhas requested, the request returns a `Client.UnauthorizedOperation` response (an\nHTTP 403 response). Some Amazon Web Services operations additionally return an\nencoded message that can provide details about this authorization failure.\n\nOnly certain Amazon Web Services operations return an encoded authorization\nmessage. The documentation for an individual operation indicates whether that\noperation returns an encoded message in addition to returning an HTTP code.\n\nThe message is encoded because the details of the authorization status can\ncontain privileged information that the user who requested the operation should\nnot see. To decode an authorization status message, a user must be granted\npermissions through an IAM\n[policy](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies.html) to request the `DecodeAuthorizationMessage` (`sts:DecodeAuthorizationMessage`)\naction.\n\nThe decoded message includes the following type of information:\n\n  * Whether the request was denied due to an explicit deny or due to\nthe absence of an explicit allow. For more information, see [Determining Whether\na Request is Allowed or\nDenied](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_evaluation-logic.html#policy-eval-denyallow)\nin the *IAM User Guide*.\n\n  * The principal who made the request.\n\n  * The requested action.\n\n  * The requested resource.\n\n  * The values of condition keys in the context of the user's request.","ref":"AWS.STS.html#decode_authorization_message/3","title":"AWS.STS.decode_authorization_message/3","type":"function"},{"doc":"Returns the account identifier for the specified access key ID.\n\nAccess keys consist of two parts: an access key ID (for example,\n`AKIAIOSFODNN7EXAMPLE`) and a secret access key (for example,\n`wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY`). For more information about access\nkeys, see [Managing Access Keys for IAM Users](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_access-keys.html)\nin the *IAM User Guide*.\n\nWhen you pass an access key ID to this operation, it returns the ID of the\nAmazon Web Services account to which the keys belong. Access key IDs beginning\nwith `AKIA` are long-term credentials for an IAM user or the Amazon Web Services\naccount root user. Access key IDs beginning with `ASIA` are temporary\ncredentials that are created using STS operations. If the account in the\nresponse belongs to you, you can sign in as the root user and review your root\nuser access keys. Then, you can pull a [credentials report](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_getting-report.html)\nto learn which IAM user owns the keys. To learn who requested the temporary\ncredentials for an `ASIA` access key, view the STS events in your [CloudTrail logs](https://docs.aws.amazon.com/IAM/latest/UserGuide/cloudtrail-integration.html)\nin the *IAM User Guide*.\n\nThis operation does not indicate the state of the access key. The key might be\nactive, inactive, or deleted. Active keys might not have permissions to perform\nan operation. Providing a deleted access key might return an error that the key\ndoesn't exist.","ref":"AWS.STS.html#get_access_key_info/3","title":"AWS.STS.get_access_key_info/3","type":"function"},{"doc":"Returns details about the IAM user or role whose credentials are used to call\nthe operation.\n\nNo permissions are required to perform this operation. If an administrator\nattaches a policy to your identity that explicitly denies access to the\n`sts:GetCallerIdentity` action, you can still perform this operation.\nPermissions are not required because the same information is returned when\naccess is denied. To view an example response, see [I Am Not Authorized to Perform:\niam:DeleteVirtualMFADevice](https://docs.aws.amazon.com/IAM/latest/UserGuide/troubleshoot_general.html#troubleshoot_general_access-denied-delete-mfa)\nin the *IAM User Guide*.","ref":"AWS.STS.html#get_caller_identity/3","title":"AWS.STS.get_caller_identity/3","type":"function"},{"doc":"Returns a set of temporary security credentials (consisting of an access key ID,\na secret access key, and a security token) for a user.\n\nA typical use is in a proxy application that gets temporary security credentials\non behalf of distributed applications inside a corporate network.\n\nYou must call the `GetFederationToken` operation using the long-term security\ncredentials of an IAM user. As a result, this call is appropriate in contexts\nwhere those credentials can be safeguarded, usually in a server-based\napplication. For a comparison of `GetFederationToken` with the other API\noperations that produce temporary credentials, see [Requesting Temporary Security\nCredentials](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_request.html)\nand [Comparing the Amazon Web Services STS API operations](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_request.html#stsapi_comparison)\nin the *IAM User Guide*.\n\nAlthough it is possible to call `GetFederationToken` using the security\ncredentials of an Amazon Web Services account root user rather than an IAM user\nthat you create for the purpose of a proxy application, we do not recommend it.\nFor more information, see [Safeguard your root user credentials and don't use them for everyday\ntasks](https://docs.aws.amazon.com/IAM/latest/UserGuide/best-practices.html#lock-away-credentials)\nin the *IAM User Guide*.\n\nYou can create a mobile-based or browser-based app that can authenticate users\nusing a web identity provider like Login with Amazon, Facebook, Google, or an\nOpenID Connect-compatible identity provider. In this case, we recommend that you\nuse [Amazon Cognito](http://aws.amazon.com/cognito/) or `AssumeRoleWithWebIdentity`. For more information, see [Federation Through a\nWeb-based Identity\nProvider](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_request.html#api_assumerolewithwebidentity)\nin the *IAM User Guide*.","ref":"AWS.STS.html#get_federation_token/3","title":"AWS.STS.get_federation_token/3","type":"function"},{"doc":"The temporary credentials are valid for the specified duration, from 900 seconds\n(15 minutes) up to a maximum of 129,600 seconds (36 hours). The default session\nduration is 43,200 seconds (12 hours). Temporary credentials obtained by using\nthe root user credentials have a maximum duration of 3,600 seconds (1 hour).","ref":"AWS.STS.html#get_federation_token/3-session-duration","title":"Session duration - AWS.STS.get_federation_token/3","type":"function"},{"doc":"You can use the temporary credentials created by `GetFederationToken` in any\nAmazon Web Services service with the following exceptions:\n\n  * You cannot call any IAM operations using the CLI or the Amazon Web\nServices API. This limitation does not apply to console sessions.\n\n  * You cannot call any STS operations except `GetCallerIdentity`.\n\nYou can use temporary credentials for single sign-on (SSO) to the console.\n\nYou must pass an inline or managed [session policy](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies.html#policies_session)\nto this operation. You can pass a single JSON policy document to use as an\ninline session policy. You can also specify up to 10 managed policy Amazon\nResource Names (ARNs) to use as managed session policies. The plaintext that you\nuse for both inline and managed session policies can't exceed 2,048 characters.\n\nThough the session policy parameters are optional, if you do not pass a policy,\nthen the resulting federated user session has no permissions. When you pass\nsession policies, the session permissions are the intersection of the IAM user\npolicies and the session policies that you pass. This gives you a way to further\nrestrict the permissions for a federated user. You cannot use session policies\nto grant more permissions than those that are defined in the permissions policy\nof the IAM user. For more information, see [Session Policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies.html#policies_session)\nin the *IAM User Guide*. For information about using `GetFederationToken` to\ncreate temporary security credentials, see [GetFederationToken—Federation Through a Custom Identity\nBroker](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_request.html#api_getfederationtoken).\n\nYou can use the credentials to access a resource that has a resource-based\npolicy. If that policy specifically references the federated user session in the\n`Principal` element of the policy, the session has the permissions allowed by\nthe policy. These permissions are granted in addition to the permissions granted\nby the session policies.","ref":"AWS.STS.html#get_federation_token/3-permissions","title":"Permissions - AWS.STS.get_federation_token/3","type":"function"},{"doc":"(Optional) You can pass tag key-value pairs to your session. These are called\nsession tags. For more information about session tags, see [Passing Session Tags in STS](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_session-tags.html)\nin the *IAM User Guide*.\n\nYou can create a mobile-based or browser-based app that can authenticate users\nusing a web identity provider like Login with Amazon, Facebook, Google, or an\nOpenID Connect-compatible identity provider. In this case, we recommend that you\nuse [Amazon Cognito](http://aws.amazon.com/cognito/) or `AssumeRoleWithWebIdentity`. For more information, see [Federation Through a\nWeb-based Identity\nProvider](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_request.html#api_assumerolewithwebidentity)\nin the *IAM User Guide*.\n\nAn administrator must grant you the permissions necessary to pass session tags.\nThe administrator can also create granular permissions to allow you to pass only\nspecific session tags. For more information, see [Tutorial: Using Tags for Attribute-Based Access\nControl](https://docs.aws.amazon.com/IAM/latest/UserGuide/tutorial_attribute-based-access-control.html)\nin the *IAM User Guide*.\n\nTag key–value pairs are not case sensitive, but case is preserved. This means\nthat you cannot have separate `Department` and `department` tag keys. Assume\nthat the user that you are federating has the `Department`=`Marketing` tag and\nyou pass the `department`=`engineering` session tag. `Department` and\n`department` are not saved as separate tags, and the session tag passed in the\nrequest takes precedence over the user tag.","ref":"AWS.STS.html#get_federation_token/3-tags","title":"Tags - AWS.STS.get_federation_token/3","type":"function"},{"doc":"Returns a set of temporary credentials for an Amazon Web Services account or IAM\nuser.\n\nThe credentials consist of an access key ID, a secret access key, and a security\ntoken. Typically, you use `GetSessionToken` if you want to use MFA to protect\nprogrammatic calls to specific Amazon Web Services API operations like Amazon\nEC2 `StopInstances`.\n\nMFA-enabled IAM users must call `GetSessionToken` and submit an MFA code that is\nassociated with their MFA device. Using the temporary security credentials that\nthe call returns, IAM users can then make programmatic calls to API operations\nthat require MFA authentication. An incorrect MFA code causes the API to return\nan access denied error. For a comparison of `GetSessionToken` with the other API\noperations that produce temporary credentials, see [Requesting Temporary Security\nCredentials](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_request.html)\nand [Comparing the Amazon Web Services STS API operations](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_request.html#stsapi_comparison)\nin the *IAM User Guide*.\n\nNo permissions are required for users to perform this operation. The purpose of\nthe `sts:GetSessionToken` operation is to authenticate the user using MFA. You\ncannot use policies to control authentication operations. For more information,\nsee [Permissions for GetSessionToken](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_control-access_getsessiontoken.html)\nin the *IAM User Guide*.","ref":"AWS.STS.html#get_session_token/3","title":"AWS.STS.get_session_token/3","type":"function"},{"doc":"The `GetSessionToken` operation must be called by using the long-term Amazon Web\nServices security credentials of an IAM user. Credentials that are created by\nIAM users are valid for the duration that you specify. This duration can range\nfrom 900 seconds (15 minutes) up to a maximum of 129,600 seconds (36 hours),\nwith a default of 43,200 seconds (12 hours). Credentials based on account\ncredentials can range from 900 seconds (15 minutes) up to 3,600 seconds (1\nhour), with a default of 1 hour.","ref":"AWS.STS.html#get_session_token/3-session-duration","title":"Session Duration - AWS.STS.get_session_token/3","type":"function"},{"doc":"The temporary security credentials created by `GetSessionToken` can be used to\nmake API calls to any Amazon Web Services service with the following exceptions:\n\n  * You cannot call any IAM API operations unless MFA authentication\ninformation is included in the request.\n\n  * You cannot call any STS API *except* `AssumeRole` or\n`GetCallerIdentity`.\n\nThe credentials that `GetSessionToken` returns are based on permissions\nassociated with the IAM user whose credentials were used to call the operation.\nThe temporary credentials have the same permissions as the IAM user.\n\nAlthough it is possible to call `GetSessionToken` using the security credentials\nof an Amazon Web Services account root user rather than an IAM user, we do not\nrecommend it. If `GetSessionToken` is called using root user credentials, the\ntemporary credentials have root user permissions. For more information, see\n[Safeguard your root user credentials and don't use them for everyday tasks](https://docs.aws.amazon.com/IAM/latest/UserGuide/best-practices.html#lock-away-credentials)\nin the *IAM User Guide*\n\nFor more information about using `GetSessionToken` to create temporary\ncredentials, see [Temporary Credentials for Users in Untrusted Environments](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_request.html#api_getsessiontoken)\nin the *IAM User Guide*.","ref":"AWS.STS.html#get_session_token/3-permissions","title":"Permissions - AWS.STS.get_session_token/3","type":"function"},{"doc":"","ref":"AWS.STS.html#metadata/0","title":"AWS.STS.metadata/0","type":"function"},{"doc":"Amazon Simple Workflow Service\n\nThe Amazon Simple Workflow Service (Amazon SWF) makes it easy to build\napplications that use Amazon's cloud to coordinate work across distributed\ncomponents.\n\nIn Amazon SWF, a *task* represents a logical unit of work that is performed by a\ncomponent of your workflow. Coordinating tasks in a workflow involves managing\nintertask dependencies, scheduling, and concurrency in accordance with the\nlogical flow of the application.\n\nAmazon SWF gives you full control over implementing tasks and coordinating them\nwithout worrying about underlying complexities such as tracking their progress\nand maintaining their state.\n\nThis documentation serves as reference only. For a broader overview of the\nAmazon SWF programming model, see the * [Amazon SWF Developer Guide](https://docs.aws.amazon.com/amazonswf/latest/developerguide/) *.","ref":"AWS.SWF.html","title":"AWS.SWF","type":"module"},{"doc":"Returns the number of closed workflow executions within the given domain that\nmeet the specified filtering criteria.\n\nThis operation is eventually consistent. The results are best effort and may not\nexactly reflect recent updates and changes.","ref":"AWS.SWF.html#count_closed_workflow_executions/3","title":"AWS.SWF.count_closed_workflow_executions/3","type":"function"},{"doc":"You can use IAM policies to control this action's access to Amazon SWF resources\nas follows:\n\n  * Use a `Resource` element with the domain name to limit the action\nto only specified domains.\n\n  * Use an `Action` element to allow or deny permission to call this\naction.\n\n  * Constrain the following parameters by using a `Condition` element\nwith the appropriate keys.\n\n    * `tagFilter.tag`: String constraint. The key is\n`swf:tagFilter.tag`.\n\n    * `typeFilter.name`: String constraint. The key is\n`swf:typeFilter.name`.\n\n    * `typeFilter.version`: String constraint. The key is\n`swf:typeFilter.version`.\n\nIf the caller doesn't have sufficient permissions to invoke the action, or the\nparameter values fall outside the specified constraints, the action fails. The\nassociated event attribute's `cause` parameter is set to\n`OPERATION_NOT_PERMITTED`. For details and example IAM policies, see [Using IAM to Manage Access to Amazon SWF\nWorkflows](https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html)\nin the *Amazon SWF Developer Guide*.","ref":"AWS.SWF.html#count_closed_workflow_executions/3-access-control","title":"Access Control - AWS.SWF.count_closed_workflow_executions/3","type":"function"},{"doc":"Returns the number of open workflow executions within the given domain that meet\nthe specified filtering criteria.\n\nThis operation is eventually consistent. The results are best effort and may not\nexactly reflect recent updates and changes.","ref":"AWS.SWF.html#count_open_workflow_executions/3","title":"AWS.SWF.count_open_workflow_executions/3","type":"function"},{"doc":"You can use IAM policies to control this action's access to Amazon SWF resources\nas follows:\n\n  * Use a `Resource` element with the domain name to limit the action\nto only specified domains.\n\n  * Use an `Action` element to allow or deny permission to call this\naction.\n\n  * Constrain the following parameters by using a `Condition` element\nwith the appropriate keys.\n\n    * `tagFilter.tag`: String constraint. The key is\n`swf:tagFilter.tag`.\n\n    * `typeFilter.name`: String constraint. The key is\n`swf:typeFilter.name`.\n\n    * `typeFilter.version`: String constraint. The key is\n`swf:typeFilter.version`.\n\nIf the caller doesn't have sufficient permissions to invoke the action, or the\nparameter values fall outside the specified constraints, the action fails. The\nassociated event attribute's `cause` parameter is set to\n`OPERATION_NOT_PERMITTED`. For details and example IAM policies, see [Using IAM to Manage Access to Amazon SWF\nWorkflows](https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html)\nin the *Amazon SWF Developer Guide*.","ref":"AWS.SWF.html#count_open_workflow_executions/3-access-control","title":"Access Control - AWS.SWF.count_open_workflow_executions/3","type":"function"},{"doc":"Returns the estimated number of activity tasks in the specified task list.\n\nThe count returned is an approximation and isn't guaranteed to be exact. If you\nspecify a task list that no activity task was ever scheduled in then `0` is\nreturned.","ref":"AWS.SWF.html#count_pending_activity_tasks/3","title":"AWS.SWF.count_pending_activity_tasks/3","type":"function"},{"doc":"You can use IAM policies to control this action's access to Amazon SWF resources\nas follows:\n\n  * Use a `Resource` element with the domain name to limit the action\nto only specified domains.\n\n  * Use an `Action` element to allow or deny permission to call this\naction.\n\n  * Constrain the `taskList.name` parameter by using a `Condition`\nelement with the `swf:taskList.name` key to allow the action to access only\ncertain task lists.\n\nIf the caller doesn't have sufficient permissions to invoke the action, or the\nparameter values fall outside the specified constraints, the action fails. The\nassociated event attribute's `cause` parameter is set to\n`OPERATION_NOT_PERMITTED`. For details and example IAM policies, see [Using IAM to Manage Access to Amazon SWF\nWorkflows](https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html)\nin the *Amazon SWF Developer Guide*.","ref":"AWS.SWF.html#count_pending_activity_tasks/3-access-control","title":"Access Control - AWS.SWF.count_pending_activity_tasks/3","type":"function"},{"doc":"Returns the estimated number of decision tasks in the specified task list.\n\nThe count returned is an approximation and isn't guaranteed to be exact. If you\nspecify a task list that no decision task was ever scheduled in then `0` is\nreturned.","ref":"AWS.SWF.html#count_pending_decision_tasks/3","title":"AWS.SWF.count_pending_decision_tasks/3","type":"function"},{"doc":"You can use IAM policies to control this action's access to Amazon SWF resources\nas follows:\n\n  * Use a `Resource` element with the domain name to limit the action\nto only specified domains.\n\n  * Use an `Action` element to allow or deny permission to call this\naction.\n\n  * Constrain the `taskList.name` parameter by using a `Condition`\nelement with the `swf:taskList.name` key to allow the action to access only\ncertain task lists.\n\nIf the caller doesn't have sufficient permissions to invoke the action, or the\nparameter values fall outside the specified constraints, the action fails. The\nassociated event attribute's `cause` parameter is set to\n`OPERATION_NOT_PERMITTED`. For details and example IAM policies, see [Using IAM to Manage Access to Amazon SWF\nWorkflows](https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html)\nin the *Amazon SWF Developer Guide*.","ref":"AWS.SWF.html#count_pending_decision_tasks/3-access-control","title":"Access Control - AWS.SWF.count_pending_decision_tasks/3","type":"function"},{"doc":"Deprecates the specified *activity type*.\n\nAfter an activity type has been deprecated, you cannot create new tasks of that\nactivity type. Tasks of this type that were scheduled before the type was\ndeprecated continue to run.\n\nThis operation is eventually consistent. The results are best effort and may not\nexactly reflect recent updates and changes.","ref":"AWS.SWF.html#deprecate_activity_type/3","title":"AWS.SWF.deprecate_activity_type/3","type":"function"},{"doc":"You can use IAM policies to control this action's access to Amazon SWF resources\nas follows:\n\n  * Use a `Resource` element with the domain name to limit the action\nto only specified domains.\n\n  * Use an `Action` element to allow or deny permission to call this\naction.\n\n  * Constrain the following parameters by using a `Condition` element\nwith the appropriate keys.\n\n    * `activityType.name`: String constraint. The key is\n`swf:activityType.name`.\n\n    * `activityType.version`: String constraint. The key is\n`swf:activityType.version`.\n\nIf the caller doesn't have sufficient permissions to invoke the action, or the\nparameter values fall outside the specified constraints, the action fails. The\nassociated event attribute's `cause` parameter is set to\n`OPERATION_NOT_PERMITTED`. For details and example IAM policies, see [Using IAM to Manage Access to Amazon SWF\nWorkflows](https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html)\nin the *Amazon SWF Developer Guide*.","ref":"AWS.SWF.html#deprecate_activity_type/3-access-control","title":"Access Control - AWS.SWF.deprecate_activity_type/3","type":"function"},{"doc":"Deprecates the specified domain.\n\nAfter a domain has been deprecated it cannot be used to create new workflow\nexecutions or register new types. However, you can still use visibility actions\non this domain. Deprecating a domain also deprecates all activity and workflow\ntypes registered in the domain. Executions that were started before the domain\nwas deprecated continues to run.\n\nThis operation is eventually consistent. The results are best effort and may not\nexactly reflect recent updates and changes.","ref":"AWS.SWF.html#deprecate_domain/3","title":"AWS.SWF.deprecate_domain/3","type":"function"},{"doc":"You can use IAM policies to control this action's access to Amazon SWF resources\nas follows:\n\n  * Use a `Resource` element with the domain name to limit the action\nto only specified domains.\n\n  * Use an `Action` element to allow or deny permission to call this\naction.\n\n  * You cannot use an IAM policy to constrain this action's\nparameters.\n\nIf the caller doesn't have sufficient permissions to invoke the action, or the\nparameter values fall outside the specified constraints, the action fails. The\nassociated event attribute's `cause` parameter is set to\n`OPERATION_NOT_PERMITTED`. For details and example IAM policies, see [Using IAM to Manage Access to Amazon SWF\nWorkflows](https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html)\nin the *Amazon SWF Developer Guide*.","ref":"AWS.SWF.html#deprecate_domain/3-access-control","title":"Access Control - AWS.SWF.deprecate_domain/3","type":"function"},{"doc":"Deprecates the specified *workflow type*.\n\nAfter a workflow type has been deprecated, you cannot create new executions of\nthat type. Executions that were started before the type was deprecated continues\nto run. A deprecated workflow type may still be used when calling visibility\nactions.\n\nThis operation is eventually consistent. The results are best effort and may not\nexactly reflect recent updates and changes.","ref":"AWS.SWF.html#deprecate_workflow_type/3","title":"AWS.SWF.deprecate_workflow_type/3","type":"function"},{"doc":"You can use IAM policies to control this action's access to Amazon SWF resources\nas follows:\n\n  * Use a `Resource` element with the domain name to limit the action\nto only specified domains.\n\n  * Use an `Action` element to allow or deny permission to call this\naction.\n\n  * Constrain the following parameters by using a `Condition` element\nwith the appropriate keys.\n\n    * `workflowType.name`: String constraint. The key is\n`swf:workflowType.name`.\n\n    * `workflowType.version`: String constraint. The key is\n`swf:workflowType.version`.\n\nIf the caller doesn't have sufficient permissions to invoke the action, or the\nparameter values fall outside the specified constraints, the action fails. The\nassociated event attribute's `cause` parameter is set to\n`OPERATION_NOT_PERMITTED`. For details and example IAM policies, see [Using IAM to Manage Access to Amazon SWF\nWorkflows](https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html)\nin the *Amazon SWF Developer Guide*.","ref":"AWS.SWF.html#deprecate_workflow_type/3-access-control","title":"Access Control - AWS.SWF.deprecate_workflow_type/3","type":"function"},{"doc":"Returns information about the specified activity type.\n\nThis includes configuration settings provided when the type was registered and\nother general information about the type.","ref":"AWS.SWF.html#describe_activity_type/3","title":"AWS.SWF.describe_activity_type/3","type":"function"},{"doc":"You can use IAM policies to control this action's access to Amazon SWF resources\nas follows:\n\n  * Use a `Resource` element with the domain name to limit the action\nto only specified domains.\n\n  * Use an `Action` element to allow or deny permission to call this\naction.\n\n  * Constrain the following parameters by using a `Condition` element\nwith the appropriate keys.\n\n    * `activityType.name`: String constraint. The key is\n`swf:activityType.name`.\n\n    * `activityType.version`: String constraint. The key is\n`swf:activityType.version`.\n\nIf the caller doesn't have sufficient permissions to invoke the action, or the\nparameter values fall outside the specified constraints, the action fails. The\nassociated event attribute's `cause` parameter is set to\n`OPERATION_NOT_PERMITTED`. For details and example IAM policies, see [Using IAM to Manage Access to Amazon SWF\nWorkflows](https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html)\nin the *Amazon SWF Developer Guide*.","ref":"AWS.SWF.html#describe_activity_type/3-access-control","title":"Access Control - AWS.SWF.describe_activity_type/3","type":"function"},{"doc":"Returns information about the specified domain, including description and\nstatus.","ref":"AWS.SWF.html#describe_domain/3","title":"AWS.SWF.describe_domain/3","type":"function"},{"doc":"You can use IAM policies to control this action's access to Amazon SWF resources\nas follows:\n\n  * Use a `Resource` element with the domain name to limit the action\nto only specified domains.\n\n  * Use an `Action` element to allow or deny permission to call this\naction.\n\n  * You cannot use an IAM policy to constrain this action's\nparameters.\n\nIf the caller doesn't have sufficient permissions to invoke the action, or the\nparameter values fall outside the specified constraints, the action fails. The\nassociated event attribute's `cause` parameter is set to\n`OPERATION_NOT_PERMITTED`. For details and example IAM policies, see [Using IAM to Manage Access to Amazon SWF\nWorkflows](https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html)\nin the *Amazon SWF Developer Guide*.","ref":"AWS.SWF.html#describe_domain/3-access-control","title":"Access Control - AWS.SWF.describe_domain/3","type":"function"},{"doc":"Returns information about the specified workflow execution including its type\nand some statistics.\n\nThis operation is eventually consistent. The results are best effort and may not\nexactly reflect recent updates and changes.","ref":"AWS.SWF.html#describe_workflow_execution/3","title":"AWS.SWF.describe_workflow_execution/3","type":"function"},{"doc":"You can use IAM policies to control this action's access to Amazon SWF resources\nas follows:\n\n  * Use a `Resource` element with the domain name to limit the action\nto only specified domains.\n\n  * Use an `Action` element to allow or deny permission to call this\naction.\n\n  * You cannot use an IAM policy to constrain this action's\nparameters.\n\nIf the caller doesn't have sufficient permissions to invoke the action, or the\nparameter values fall outside the specified constraints, the action fails. The\nassociated event attribute's `cause` parameter is set to\n`OPERATION_NOT_PERMITTED`. For details and example IAM policies, see [Using IAM to Manage Access to Amazon SWF\nWorkflows](https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html)\nin the *Amazon SWF Developer Guide*.","ref":"AWS.SWF.html#describe_workflow_execution/3-access-control","title":"Access Control - AWS.SWF.describe_workflow_execution/3","type":"function"},{"doc":"Returns information about the specified *workflow type*.\n\nThis includes configuration settings specified when the type was registered and\nother information such as creation date, current status, etc.","ref":"AWS.SWF.html#describe_workflow_type/3","title":"AWS.SWF.describe_workflow_type/3","type":"function"},{"doc":"You can use IAM policies to control this action's access to Amazon SWF resources\nas follows:\n\n  * Use a `Resource` element with the domain name to limit the action\nto only specified domains.\n\n  * Use an `Action` element to allow or deny permission to call this\naction.\n\n  * Constrain the following parameters by using a `Condition` element\nwith the appropriate keys.\n\n    * `workflowType.name`: String constraint. The key is\n`swf:workflowType.name`.\n\n    * `workflowType.version`: String constraint. The key is\n`swf:workflowType.version`.\n\nIf the caller doesn't have sufficient permissions to invoke the action, or the\nparameter values fall outside the specified constraints, the action fails. The\nassociated event attribute's `cause` parameter is set to\n`OPERATION_NOT_PERMITTED`. For details and example IAM policies, see [Using IAM to Manage Access to Amazon SWF\nWorkflows](https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html)\nin the *Amazon SWF Developer Guide*.","ref":"AWS.SWF.html#describe_workflow_type/3-access-control","title":"Access Control - AWS.SWF.describe_workflow_type/3","type":"function"},{"doc":"Returns the history of the specified workflow execution.\n\nThe results may be split into multiple pages. To retrieve subsequent pages, make\nthe call again using the `nextPageToken` returned by the initial call.\n\nThis operation is eventually consistent. The results are best effort and may not\nexactly reflect recent updates and changes.","ref":"AWS.SWF.html#get_workflow_execution_history/3","title":"AWS.SWF.get_workflow_execution_history/3","type":"function"},{"doc":"You can use IAM policies to control this action's access to Amazon SWF resources\nas follows:\n\n  * Use a `Resource` element with the domain name to limit the action\nto only specified domains.\n\n  * Use an `Action` element to allow or deny permission to call this\naction.\n\n  * You cannot use an IAM policy to constrain this action's\nparameters.\n\nIf the caller doesn't have sufficient permissions to invoke the action, or the\nparameter values fall outside the specified constraints, the action fails. The\nassociated event attribute's `cause` parameter is set to\n`OPERATION_NOT_PERMITTED`. For details and example IAM policies, see [Using IAM to Manage Access to Amazon SWF\nWorkflows](https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html)\nin the *Amazon SWF Developer Guide*.","ref":"AWS.SWF.html#get_workflow_execution_history/3-access-control","title":"Access Control - AWS.SWF.get_workflow_execution_history/3","type":"function"},{"doc":"Returns information about all activities registered in the specified domain that\nmatch the specified name and registration status.\n\nThe result includes information like creation date, current status of the\nactivity, etc. The results may be split into multiple pages. To retrieve\nsubsequent pages, make the call again using the `nextPageToken` returned by the\ninitial call.","ref":"AWS.SWF.html#list_activity_types/3","title":"AWS.SWF.list_activity_types/3","type":"function"},{"doc":"You can use IAM policies to control this action's access to Amazon SWF resources\nas follows:\n\n  * Use a `Resource` element with the domain name to limit the action\nto only specified domains.\n\n  * Use an `Action` element to allow or deny permission to call this\naction.\n\n  * You cannot use an IAM policy to constrain this action's\nparameters.\n\nIf the caller doesn't have sufficient permissions to invoke the action, or the\nparameter values fall outside the specified constraints, the action fails. The\nassociated event attribute's `cause` parameter is set to\n`OPERATION_NOT_PERMITTED`. For details and example IAM policies, see [Using IAM to Manage Access to Amazon SWF\nWorkflows](https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html)\nin the *Amazon SWF Developer Guide*.","ref":"AWS.SWF.html#list_activity_types/3-access-control","title":"Access Control - AWS.SWF.list_activity_types/3","type":"function"},{"doc":"Returns a list of closed workflow executions in the specified domain that meet\nthe filtering criteria.\n\nThe results may be split into multiple pages. To retrieve subsequent pages, make\nthe call again using the nextPageToken returned by the initial call.\n\nThis operation is eventually consistent. The results are best effort and may not\nexactly reflect recent updates and changes.","ref":"AWS.SWF.html#list_closed_workflow_executions/3","title":"AWS.SWF.list_closed_workflow_executions/3","type":"function"},{"doc":"You can use IAM policies to control this action's access to Amazon SWF resources\nas follows:\n\n  * Use a `Resource` element with the domain name to limit the action\nto only specified domains.\n\n  * Use an `Action` element to allow or deny permission to call this\naction.\n\n  * Constrain the following parameters by using a `Condition` element\nwith the appropriate keys.\n\n    * `tagFilter.tag`: String constraint. The key is\n`swf:tagFilter.tag`.\n\n    * `typeFilter.name`: String constraint. The key is\n`swf:typeFilter.name`.\n\n    * `typeFilter.version`: String constraint. The key is\n`swf:typeFilter.version`.\n\nIf the caller doesn't have sufficient permissions to invoke the action, or the\nparameter values fall outside the specified constraints, the action fails. The\nassociated event attribute's `cause` parameter is set to\n`OPERATION_NOT_PERMITTED`. For details and example IAM policies, see [Using IAM to Manage Access to Amazon SWF\nWorkflows](https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html)\nin the *Amazon SWF Developer Guide*.","ref":"AWS.SWF.html#list_closed_workflow_executions/3-access-control","title":"Access Control - AWS.SWF.list_closed_workflow_executions/3","type":"function"},{"doc":"Returns the list of domains registered in the account.\n\nThe results may be split into multiple pages. To retrieve subsequent pages, make\nthe call again using the nextPageToken returned by the initial call.\n\nThis operation is eventually consistent. The results are best effort and may not\nexactly reflect recent updates and changes.","ref":"AWS.SWF.html#list_domains/3","title":"AWS.SWF.list_domains/3","type":"function"},{"doc":"You can use IAM policies to control this action's access to Amazon SWF resources\nas follows:\n\n  * Use a `Resource` element with the domain name to limit the action\nto only specified domains. The element must be set to\n`arn:aws:swf::AccountID:domain/*`, where *AccountID* is the account ID, with no\ndashes.\n\n  * Use an `Action` element to allow or deny permission to call this\naction.\n\n  * You cannot use an IAM policy to constrain this action's\nparameters.\n\nIf the caller doesn't have sufficient permissions to invoke the action, or the\nparameter values fall outside the specified constraints, the action fails. The\nassociated event attribute's `cause` parameter is set to\n`OPERATION_NOT_PERMITTED`. For details and example IAM policies, see [Using IAM to Manage Access to Amazon SWF\nWorkflows](https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html)\nin the *Amazon SWF Developer Guide*.","ref":"AWS.SWF.html#list_domains/3-access-control","title":"Access Control - AWS.SWF.list_domains/3","type":"function"},{"doc":"Returns a list of open workflow executions in the specified domain that meet the\nfiltering criteria.\n\nThe results may be split into multiple pages. To retrieve subsequent pages, make\nthe call again using the nextPageToken returned by the initial call.\n\nThis operation is eventually consistent. The results are best effort and may not\nexactly reflect recent updates and changes.","ref":"AWS.SWF.html#list_open_workflow_executions/3","title":"AWS.SWF.list_open_workflow_executions/3","type":"function"},{"doc":"You can use IAM policies to control this action's access to Amazon SWF resources\nas follows:\n\n  * Use a `Resource` element with the domain name to limit the action\nto only specified domains.\n\n  * Use an `Action` element to allow or deny permission to call this\naction.\n\n  * Constrain the following parameters by using a `Condition` element\nwith the appropriate keys.\n\n    * `tagFilter.tag`: String constraint. The key is\n`swf:tagFilter.tag`.\n\n    * `typeFilter.name`: String constraint. The key is\n`swf:typeFilter.name`.\n\n    * `typeFilter.version`: String constraint. The key is\n`swf:typeFilter.version`.\n\nIf the caller doesn't have sufficient permissions to invoke the action, or the\nparameter values fall outside the specified constraints, the action fails. The\nassociated event attribute's `cause` parameter is set to\n`OPERATION_NOT_PERMITTED`. For details and example IAM policies, see [Using IAM to Manage Access to Amazon SWF\nWorkflows](https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html)\nin the *Amazon SWF Developer Guide*.","ref":"AWS.SWF.html#list_open_workflow_executions/3-access-control","title":"Access Control - AWS.SWF.list_open_workflow_executions/3","type":"function"},{"doc":"List tags for a given domain.","ref":"AWS.SWF.html#list_tags_for_resource/3","title":"AWS.SWF.list_tags_for_resource/3","type":"function"},{"doc":"Returns information about workflow types in the specified domain.\n\nThe results may be split into multiple pages that can be retrieved by making the\ncall repeatedly.","ref":"AWS.SWF.html#list_workflow_types/3","title":"AWS.SWF.list_workflow_types/3","type":"function"},{"doc":"You can use IAM policies to control this action's access to Amazon SWF resources\nas follows:\n\n  * Use a `Resource` element with the domain name to limit the action\nto only specified domains.\n\n  * Use an `Action` element to allow or deny permission to call this\naction.\n\n  * You cannot use an IAM policy to constrain this action's\nparameters.\n\nIf the caller doesn't have sufficient permissions to invoke the action, or the\nparameter values fall outside the specified constraints, the action fails. The\nassociated event attribute's `cause` parameter is set to\n`OPERATION_NOT_PERMITTED`. For details and example IAM policies, see [Using IAM to Manage Access to Amazon SWF\nWorkflows](https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html)\nin the *Amazon SWF Developer Guide*.","ref":"AWS.SWF.html#list_workflow_types/3-access-control","title":"Access Control - AWS.SWF.list_workflow_types/3","type":"function"},{"doc":"","ref":"AWS.SWF.html#metadata/0","title":"AWS.SWF.metadata/0","type":"function"},{"doc":"Used by workers to get an `ActivityTask` from the specified activity `taskList`.\n\nThis initiates a long poll, where the service holds the HTTP connection open and\nresponds as soon as a task becomes available. The maximum time the service holds\non to the request before responding is 60 seconds. If no task is available\nwithin 60 seconds, the poll returns an empty result. An empty result, in this\ncontext, means that an ActivityTask is returned, but that the value of taskToken\nis an empty string. If a task is returned, the worker should use its type to\nidentify and process it correctly.\n\nWorkers should set their client side socket timeout to at least 70 seconds (10\nseconds higher than the maximum time service may hold the poll request).","ref":"AWS.SWF.html#poll_for_activity_task/3","title":"AWS.SWF.poll_for_activity_task/3","type":"function"},{"doc":"You can use IAM policies to control this action's access to Amazon SWF resources\nas follows:\n\n  * Use a `Resource` element with the domain name to limit the action\nto only specified domains.\n\n  * Use an `Action` element to allow or deny permission to call this\naction.\n\n  * Constrain the `taskList.name` parameter by using a `Condition`\nelement with the `swf:taskList.name` key to allow the action to access only\ncertain task lists.\n\nIf the caller doesn't have sufficient permissions to invoke the action, or the\nparameter values fall outside the specified constraints, the action fails. The\nassociated event attribute's `cause` parameter is set to\n`OPERATION_NOT_PERMITTED`. For details and example IAM policies, see [Using IAM to Manage Access to Amazon SWF\nWorkflows](https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html)\nin the *Amazon SWF Developer Guide*.","ref":"AWS.SWF.html#poll_for_activity_task/3-access-control","title":"Access Control - AWS.SWF.poll_for_activity_task/3","type":"function"},{"doc":"Used by deciders to get a `DecisionTask` from the specified decision `taskList`.\n\nA decision task may be returned for any open workflow execution that is using\nthe specified task list. The task includes a paginated view of the history of\nthe workflow execution. The decider should use the workflow type and the history\nto determine how to properly handle the task.\n\nThis action initiates a long poll, where the service holds the HTTP connection\nopen and responds as soon a task becomes available. If no decision task is\navailable in the specified task list before the timeout of 60 seconds expires,\nan empty result is returned. An empty result, in this context, means that a\nDecisionTask is returned, but that the value of taskToken is an empty string.\n\nDeciders should set their client side socket timeout to at least 70 seconds (10\nseconds higher than the timeout).\n\nBecause the number of workflow history events for a single workflow execution\nmight be very large, the result returned might be split up across a number of\npages. To retrieve subsequent pages, make additional calls to\n`PollForDecisionTask` using the `nextPageToken` returned by the initial call.\nNote that you do *not* call `GetWorkflowExecutionHistory` with this\n`nextPageToken`. Instead, call `PollForDecisionTask` again.","ref":"AWS.SWF.html#poll_for_decision_task/3","title":"AWS.SWF.poll_for_decision_task/3","type":"function"},{"doc":"You can use IAM policies to control this action's access to Amazon SWF resources\nas follows:\n\n  * Use a `Resource` element with the domain name to limit the action\nto only specified domains.\n\n  * Use an `Action` element to allow or deny permission to call this\naction.\n\n  * Constrain the `taskList.name` parameter by using a `Condition`\nelement with the `swf:taskList.name` key to allow the action to access only\ncertain task lists.\n\nIf the caller doesn't have sufficient permissions to invoke the action, or the\nparameter values fall outside the specified constraints, the action fails. The\nassociated event attribute's `cause` parameter is set to\n`OPERATION_NOT_PERMITTED`. For details and example IAM policies, see [Using IAM to Manage Access to Amazon SWF\nWorkflows](https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html)\nin the *Amazon SWF Developer Guide*.","ref":"AWS.SWF.html#poll_for_decision_task/3-access-control","title":"Access Control - AWS.SWF.poll_for_decision_task/3","type":"function"},{"doc":"Used by activity workers to report to the service that the `ActivityTask`\nrepresented by the specified `taskToken` is still making progress.\n\nThe worker can also specify details of the progress, for example percent\ncomplete, using the `details` parameter. This action can also be used by the\nworker as a mechanism to check if cancellation is being requested for the\nactivity task. If a cancellation is being attempted for the specified task, then\nthe boolean `cancelRequested` flag returned by the service is set to `true`.\n\nThis action resets the `taskHeartbeatTimeout` clock. The `taskHeartbeatTimeout`\nis specified in `RegisterActivityType`.\n\nThis action doesn't in itself create an event in the workflow execution history.\nHowever, if the task times out, the workflow execution history contains a\n`ActivityTaskTimedOut` event that contains the information from the last\nheartbeat generated by the activity worker.\n\nThe `taskStartToCloseTimeout` of an activity type is the maximum duration of an\nactivity task, regardless of the number of `RecordActivityTaskHeartbeat`\nrequests received. The `taskStartToCloseTimeout` is also specified in\n`RegisterActivityType`.\n\nThis operation is only useful for long-lived activities to report liveliness of\nthe task and to determine if a cancellation is being attempted.\n\nIf the `cancelRequested` flag returns `true`, a cancellation is being attempted.\nIf the worker can cancel the activity, it should respond with\n`RespondActivityTaskCanceled`. Otherwise, it should ignore the cancellation\nrequest.","ref":"AWS.SWF.html#record_activity_task_heartbeat/3","title":"AWS.SWF.record_activity_task_heartbeat/3","type":"function"},{"doc":"You can use IAM policies to control this action's access to Amazon SWF resources\nas follows:\n\n  * Use a `Resource` element with the domain name to limit the action\nto only specified domains.\n\n  * Use an `Action` element to allow or deny permission to call this\naction.\n\n  * You cannot use an IAM policy to constrain this action's\nparameters.\n\nIf the caller doesn't have sufficient permissions to invoke the action, or the\nparameter values fall outside the specified constraints, the action fails. The\nassociated event attribute's `cause` parameter is set to\n`OPERATION_NOT_PERMITTED`. For details and example IAM policies, see [Using IAM to Manage Access to Amazon SWF\nWorkflows](https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html)\nin the *Amazon SWF Developer Guide*.","ref":"AWS.SWF.html#record_activity_task_heartbeat/3-access-control","title":"Access Control - AWS.SWF.record_activity_task_heartbeat/3","type":"function"},{"doc":"Registers a new *activity type* along with its configuration settings in the\nspecified domain.\n\nA `TypeAlreadyExists` fault is returned if the type already exists in the\ndomain. You cannot change any configuration settings of the type after its\nregistration, and it must be registered as a new version.","ref":"AWS.SWF.html#register_activity_type/3","title":"AWS.SWF.register_activity_type/3","type":"function"},{"doc":"You can use IAM policies to control this action's access to Amazon SWF resources\nas follows:\n\n  * Use a `Resource` element with the domain name to limit the action\nto only specified domains.\n\n  * Use an `Action` element to allow or deny permission to call this\naction.\n\n  * Constrain the following parameters by using a `Condition` element\nwith the appropriate keys.\n\n    * `defaultTaskList.name`: String constraint. The key is\n`swf:defaultTaskList.name`.\n\n    * `name`: String constraint. The key is `swf:name`.\n\n    * `version`: String constraint. The key is\n`swf:version`.\n\nIf the caller doesn't have sufficient permissions to invoke the action, or the\nparameter values fall outside the specified constraints, the action fails. The\nassociated event attribute's `cause` parameter is set to\n`OPERATION_NOT_PERMITTED`. For details and example IAM policies, see [Using IAM to Manage Access to Amazon SWF\nWorkflows](https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html)\nin the *Amazon SWF Developer Guide*.","ref":"AWS.SWF.html#register_activity_type/3-access-control","title":"Access Control - AWS.SWF.register_activity_type/3","type":"function"},{"doc":"Registers a new domain.","ref":"AWS.SWF.html#register_domain/3","title":"AWS.SWF.register_domain/3","type":"function"},{"doc":"You can use IAM policies to control this action's access to Amazon SWF resources\nas follows:\n\n  * You cannot use an IAM policy to control domain access for this\naction. The name of the domain being registered is available as the resource of\nthis action.\n\n  * Use an `Action` element to allow or deny permission to call this\naction.\n\n  * You cannot use an IAM policy to constrain this action's\nparameters.\n\nIf the caller doesn't have sufficient permissions to invoke the action, or the\nparameter values fall outside the specified constraints, the action fails. The\nassociated event attribute's `cause` parameter is set to\n`OPERATION_NOT_PERMITTED`. For details and example IAM policies, see [Using IAM to Manage Access to Amazon SWF\nWorkflows](https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html)\nin the *Amazon SWF Developer Guide*.","ref":"AWS.SWF.html#register_domain/3-access-control","title":"Access Control - AWS.SWF.register_domain/3","type":"function"},{"doc":"Registers a new *workflow type* and its configuration settings in the specified\ndomain.\n\nThe retention period for the workflow history is set by the `RegisterDomain`\naction.\n\nIf the type already exists, then a `TypeAlreadyExists` fault is returned. You\ncannot change the configuration settings of a workflow type once it is\nregistered and it must be registered as a new version.","ref":"AWS.SWF.html#register_workflow_type/3","title":"AWS.SWF.register_workflow_type/3","type":"function"},{"doc":"You can use IAM policies to control this action's access to Amazon SWF resources\nas follows:\n\n  * Use a `Resource` element with the domain name to limit the action\nto only specified domains.\n\n  * Use an `Action` element to allow or deny permission to call this\naction.\n\n  * Constrain the following parameters by using a `Condition` element\nwith the appropriate keys.\n\n    * `defaultTaskList.name`: String constraint. The key is\n`swf:defaultTaskList.name`.\n\n    * `name`: String constraint. The key is `swf:name`.\n\n    * `version`: String constraint. The key is\n`swf:version`.\n\nIf the caller doesn't have sufficient permissions to invoke the action, or the\nparameter values fall outside the specified constraints, the action fails. The\nassociated event attribute's `cause` parameter is set to\n`OPERATION_NOT_PERMITTED`. For details and example IAM policies, see [Using IAM to Manage Access to Amazon SWF\nWorkflows](https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html)\nin the *Amazon SWF Developer Guide*.","ref":"AWS.SWF.html#register_workflow_type/3-access-control","title":"Access Control - AWS.SWF.register_workflow_type/3","type":"function"},{"doc":"Records a `WorkflowExecutionCancelRequested` event in the currently running\nworkflow execution identified by the given domain, workflowId, and runId.\n\nThis logically requests the cancellation of the workflow execution as a whole.\nIt is up to the decider to take appropriate actions when it receives an\nexecution history with this event.\n\nIf the runId isn't specified, the `WorkflowExecutionCancelRequested` event is\nrecorded in the history of the current open workflow execution with the\nspecified workflowId in the domain.\n\nBecause this action allows the workflow to properly clean up and gracefully\nclose, it should be used instead of `TerminateWorkflowExecution` when possible.","ref":"AWS.SWF.html#request_cancel_workflow_execution/3","title":"AWS.SWF.request_cancel_workflow_execution/3","type":"function"},{"doc":"You can use IAM policies to control this action's access to Amazon SWF resources\nas follows:\n\n  * Use a `Resource` element with the domain name to limit the action\nto only specified domains.\n\n  * Use an `Action` element to allow or deny permission to call this\naction.\n\n  * You cannot use an IAM policy to constrain this action's\nparameters.\n\nIf the caller doesn't have sufficient permissions to invoke the action, or the\nparameter values fall outside the specified constraints, the action fails. The\nassociated event attribute's `cause` parameter is set to\n`OPERATION_NOT_PERMITTED`. For details and example IAM policies, see [Using IAM to Manage Access to Amazon SWF\nWorkflows](https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html)\nin the *Amazon SWF Developer Guide*.","ref":"AWS.SWF.html#request_cancel_workflow_execution/3-access-control","title":"Access Control - AWS.SWF.request_cancel_workflow_execution/3","type":"function"},{"doc":"Used by workers to tell the service that the `ActivityTask` identified by the\n`taskToken` was successfully canceled.\n\nAdditional `details` can be provided using the `details` argument.\n\nThese `details` (if provided) appear in the `ActivityTaskCanceled` event added\nto the workflow history.\n\nOnly use this operation if the `canceled` flag of a\n`RecordActivityTaskHeartbeat` request returns `true` and if the activity can be\nsafely undone or abandoned.\n\nA task is considered open from the time that it is scheduled until it is closed.\nTherefore a task is reported as open while a worker is processing it. A task is\nclosed after it has been specified in a call to `RespondActivityTaskCompleted`,\nRespondActivityTaskCanceled, `RespondActivityTaskFailed`, or the task has [timed out](https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dg-basic.html#swf-dev-timeout-types).","ref":"AWS.SWF.html#respond_activity_task_canceled/3","title":"AWS.SWF.respond_activity_task_canceled/3","type":"function"},{"doc":"You can use IAM policies to control this action's access to Amazon SWF resources\nas follows:\n\n  * Use a `Resource` element with the domain name to limit the action\nto only specified domains.\n\n  * Use an `Action` element to allow or deny permission to call this\naction.\n\n  * You cannot use an IAM policy to constrain this action's\nparameters.\n\nIf the caller doesn't have sufficient permissions to invoke the action, or the\nparameter values fall outside the specified constraints, the action fails. The\nassociated event attribute's `cause` parameter is set to\n`OPERATION_NOT_PERMITTED`. For details and example IAM policies, see [Using IAM to Manage Access to Amazon SWF\nWorkflows](https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html)\nin the *Amazon SWF Developer Guide*.","ref":"AWS.SWF.html#respond_activity_task_canceled/3-access-control","title":"Access Control - AWS.SWF.respond_activity_task_canceled/3","type":"function"},{"doc":"Used by workers to tell the service that the `ActivityTask` identified by the\n`taskToken` completed successfully with a `result` (if provided).\n\nThe `result` appears in the `ActivityTaskCompleted` event in the workflow\nhistory.\n\nIf the requested task doesn't complete successfully, use\n`RespondActivityTaskFailed` instead. If the worker finds that the task is\ncanceled through the `canceled` flag returned by `RecordActivityTaskHeartbeat`,\nit should cancel the task, clean up and then call `RespondActivityTaskCanceled`.\n\nA task is considered open from the time that it is scheduled until it is closed.\nTherefore a task is reported as open while a worker is processing it. A task is\nclosed after it has been specified in a call to RespondActivityTaskCompleted,\n`RespondActivityTaskCanceled`, `RespondActivityTaskFailed`, or the task has\n[timed out](https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dg-basic.html#swf-dev-timeout-types).","ref":"AWS.SWF.html#respond_activity_task_completed/3","title":"AWS.SWF.respond_activity_task_completed/3","type":"function"},{"doc":"You can use IAM policies to control this action's access to Amazon SWF resources\nas follows:\n\n  * Use a `Resource` element with the domain name to limit the action\nto only specified domains.\n\n  * Use an `Action` element to allow or deny permission to call this\naction.\n\n  * You cannot use an IAM policy to constrain this action's\nparameters.\n\nIf the caller doesn't have sufficient permissions to invoke the action, or the\nparameter values fall outside the specified constraints, the action fails. The\nassociated event attribute's `cause` parameter is set to\n`OPERATION_NOT_PERMITTED`. For details and example IAM policies, see [Using IAM to Manage Access to Amazon SWF\nWorkflows](https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html)\nin the *Amazon SWF Developer Guide*.","ref":"AWS.SWF.html#respond_activity_task_completed/3-access-control","title":"Access Control - AWS.SWF.respond_activity_task_completed/3","type":"function"},{"doc":"Used by workers to tell the service that the `ActivityTask` identified by the\n`taskToken` has failed with `reason` (if specified).\n\nThe `reason` and `details` appear in the `ActivityTaskFailed` event added to the\nworkflow history.\n\nA task is considered open from the time that it is scheduled until it is closed.\nTherefore a task is reported as open while a worker is processing it. A task is\nclosed after it has been specified in a call to `RespondActivityTaskCompleted`,\n`RespondActivityTaskCanceled`, RespondActivityTaskFailed, or the task has [timed out](https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dg-basic.html#swf-dev-timeout-types).","ref":"AWS.SWF.html#respond_activity_task_failed/3","title":"AWS.SWF.respond_activity_task_failed/3","type":"function"},{"doc":"You can use IAM policies to control this action's access to Amazon SWF resources\nas follows:\n\n  * Use a `Resource` element with the domain name to limit the action\nto only specified domains.\n\n  * Use an `Action` element to allow or deny permission to call this\naction.\n\n  * You cannot use an IAM policy to constrain this action's\nparameters.\n\nIf the caller doesn't have sufficient permissions to invoke the action, or the\nparameter values fall outside the specified constraints, the action fails. The\nassociated event attribute's `cause` parameter is set to\n`OPERATION_NOT_PERMITTED`. For details and example IAM policies, see [Using IAM to Manage Access to Amazon SWF\nWorkflows](https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html)\nin the *Amazon SWF Developer Guide*.","ref":"AWS.SWF.html#respond_activity_task_failed/3-access-control","title":"Access Control - AWS.SWF.respond_activity_task_failed/3","type":"function"},{"doc":"Used by deciders to tell the service that the `DecisionTask` identified by the\n`taskToken` has successfully completed.\n\nThe `decisions` argument specifies the list of decisions made while processing\nthe task.\n\nA `DecisionTaskCompleted` event is added to the workflow history. The\n`executionContext` specified is attached to the event in the workflow execution\nhistory.","ref":"AWS.SWF.html#respond_decision_task_completed/3","title":"AWS.SWF.respond_decision_task_completed/3","type":"function"},{"doc":"If an IAM policy grants permission to use `RespondDecisionTaskCompleted`, it can\nexpress permissions for the list of decisions in the `decisions` parameter. Each\nof the decisions has one or more parameters, much like a regular API call. To\nallow for policies to be as readable as possible, you can express permissions on\ndecisions as if they were actual API calls, including applying conditions to\nsome parameters. For more information, see [Using IAM to Manage Access to Amazon SWF\nWorkflows](https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html)\nin the *Amazon SWF Developer Guide*.","ref":"AWS.SWF.html#respond_decision_task_completed/3-access-control","title":"Access Control - AWS.SWF.respond_decision_task_completed/3","type":"function"},{"doc":"Records a `WorkflowExecutionSignaled` event in the workflow execution history\nand creates a decision task for the workflow execution identified by the given\ndomain, workflowId and runId.\n\nThe event is recorded with the specified user defined signalName and input (if\nprovided).\n\nIf a runId isn't specified, then the `WorkflowExecutionSignaled` event is\nrecorded in the history of the current open workflow with the matching\nworkflowId in the domain.\n\nIf the specified workflow execution isn't open, this method fails with\n`UnknownResource`.","ref":"AWS.SWF.html#signal_workflow_execution/3","title":"AWS.SWF.signal_workflow_execution/3","type":"function"},{"doc":"You can use IAM policies to control this action's access to Amazon SWF resources\nas follows:\n\n  * Use a `Resource` element with the domain name to limit the action\nto only specified domains.\n\n  * Use an `Action` element to allow or deny permission to call this\naction.\n\n  * You cannot use an IAM policy to constrain this action's\nparameters.\n\nIf the caller doesn't have sufficient permissions to invoke the action, or the\nparameter values fall outside the specified constraints, the action fails. The\nassociated event attribute's `cause` parameter is set to\n`OPERATION_NOT_PERMITTED`. For details and example IAM policies, see [Using IAM to Manage Access to Amazon SWF\nWorkflows](https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html)\nin the *Amazon SWF Developer Guide*.","ref":"AWS.SWF.html#signal_workflow_execution/3-access-control","title":"Access Control - AWS.SWF.signal_workflow_execution/3","type":"function"},{"doc":"Starts an execution of the workflow type in the specified domain using the\nprovided `workflowId` and input data.\n\nThis action returns the newly started workflow execution.","ref":"AWS.SWF.html#start_workflow_execution/3","title":"AWS.SWF.start_workflow_execution/3","type":"function"},{"doc":"You can use IAM policies to control this action's access to Amazon SWF resources\nas follows:\n\n  * Use a `Resource` element with the domain name to limit the action\nto only specified domains.\n\n  * Use an `Action` element to allow or deny permission to call this\naction.\n\n  * Constrain the following parameters by using a `Condition` element\nwith the appropriate keys.\n\n    * `tagList.member.0`: The key is `swf:tagList.member.0`.\n\n    * `tagList.member.1`: The key is `swf:tagList.member.1`.\n\n    * `tagList.member.2`: The key is `swf:tagList.member.2`.\n\n    * `tagList.member.3`: The key is `swf:tagList.member.3`.\n\n    * `tagList.member.4`: The key is `swf:tagList.member.4`.\n\n    * `taskList`: String constraint. The key is\n`swf:taskList.name`.\n\n    * `workflowType.name`: String constraint. The key is\n`swf:workflowType.name`.\n\n    * `workflowType.version`: String constraint. The key is\n`swf:workflowType.version`.\n\nIf the caller doesn't have sufficient permissions to invoke the action, or the\nparameter values fall outside the specified constraints, the action fails. The\nassociated event attribute's `cause` parameter is set to\n`OPERATION_NOT_PERMITTED`. For details and example IAM policies, see [Using IAM to Manage Access to Amazon SWF\nWorkflows](https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html)\nin the *Amazon SWF Developer Guide*.","ref":"AWS.SWF.html#start_workflow_execution/3-access-control","title":"Access Control - AWS.SWF.start_workflow_execution/3","type":"function"},{"doc":"Add a tag to a Amazon SWF domain.\n\nAmazon SWF supports a maximum of 50 tags per resource.","ref":"AWS.SWF.html#tag_resource/3","title":"AWS.SWF.tag_resource/3","type":"function"},{"doc":"Records a `WorkflowExecutionTerminated` event and forces closure of the workflow\nexecution identified by the given domain, runId, and workflowId.\n\nThe child policy, registered with the workflow type or specified when starting\nthis execution, is applied to any open child workflow executions of this\nworkflow execution.\n\nIf the identified workflow execution was in progress, it is terminated\nimmediately.\n\nIf a runId isn't specified, then the `WorkflowExecutionTerminated` event is\nrecorded in the history of the current open workflow with the matching\nworkflowId in the domain.\n\nYou should consider using `RequestCancelWorkflowExecution` action instead\nbecause it allows the workflow to gracefully close while\n`TerminateWorkflowExecution` doesn't.","ref":"AWS.SWF.html#terminate_workflow_execution/3","title":"AWS.SWF.terminate_workflow_execution/3","type":"function"},{"doc":"You can use IAM policies to control this action's access to Amazon SWF resources\nas follows:\n\n  * Use a `Resource` element with the domain name to limit the action\nto only specified domains.\n\n  * Use an `Action` element to allow or deny permission to call this\naction.\n\n  * You cannot use an IAM policy to constrain this action's\nparameters.\n\nIf the caller doesn't have sufficient permissions to invoke the action, or the\nparameter values fall outside the specified constraints, the action fails. The\nassociated event attribute's `cause` parameter is set to\n`OPERATION_NOT_PERMITTED`. For details and example IAM policies, see [Using IAM to Manage Access to Amazon SWF\nWorkflows](https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html)\nin the *Amazon SWF Developer Guide*.","ref":"AWS.SWF.html#terminate_workflow_execution/3-access-control","title":"Access Control - AWS.SWF.terminate_workflow_execution/3","type":"function"},{"doc":"Undeprecates a previously deprecated *activity type*.\n\nAfter an activity type has been undeprecated, you can create new tasks of that\nactivity type.\n\nThis operation is eventually consistent. The results are best effort and may not\nexactly reflect recent updates and changes.","ref":"AWS.SWF.html#undeprecate_activity_type/3","title":"AWS.SWF.undeprecate_activity_type/3","type":"function"},{"doc":"You can use IAM policies to control this action's access to Amazon SWF resources\nas follows:\n\n  * Use a `Resource` element with the domain name to limit the action\nto only specified domains.\n\n  * Use an `Action` element to allow or deny permission to call this\naction.\n\n  * Constrain the following parameters by using a `Condition` element\nwith the appropriate keys.\n\n    * `activityType.name`: String constraint. The key is\n`swf:activityType.name`.\n\n    * `activityType.version`: String constraint. The key is\n`swf:activityType.version`.\n\nIf the caller doesn't have sufficient permissions to invoke the action, or the\nparameter values fall outside the specified constraints, the action fails. The\nassociated event attribute's `cause` parameter is set to\n`OPERATION_NOT_PERMITTED`. For details and example IAM policies, see [Using IAM to Manage Access to Amazon SWF\nWorkflows](https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html)\nin the *Amazon SWF Developer Guide*.","ref":"AWS.SWF.html#undeprecate_activity_type/3-access-control","title":"Access Control - AWS.SWF.undeprecate_activity_type/3","type":"function"},{"doc":"Undeprecates a previously deprecated domain.\n\nAfter a domain has been undeprecated it can be used to create new workflow\nexecutions or register new types.\n\nThis operation is eventually consistent. The results are best effort and may not\nexactly reflect recent updates and changes.","ref":"AWS.SWF.html#undeprecate_domain/3","title":"AWS.SWF.undeprecate_domain/3","type":"function"},{"doc":"You can use IAM policies to control this action's access to Amazon SWF resources\nas follows:\n\n  * Use a `Resource` element with the domain name to limit the action\nto only specified domains.\n\n  * Use an `Action` element to allow or deny permission to call this\naction.\n\n  * You cannot use an IAM policy to constrain this action's\nparameters.\n\nIf the caller doesn't have sufficient permissions to invoke the action, or the\nparameter values fall outside the specified constraints, the action fails. The\nassociated event attribute's `cause` parameter is set to\n`OPERATION_NOT_PERMITTED`. For details and example IAM policies, see [Using IAM to Manage Access to Amazon SWF\nWorkflows](https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html)\nin the *Amazon SWF Developer Guide*.","ref":"AWS.SWF.html#undeprecate_domain/3-access-control","title":"Access Control - AWS.SWF.undeprecate_domain/3","type":"function"},{"doc":"Undeprecates a previously deprecated *workflow type*.\n\nAfter a workflow type has been undeprecated, you can create new executions of\nthat type.\n\nThis operation is eventually consistent. The results are best effort and may not\nexactly reflect recent updates and changes.","ref":"AWS.SWF.html#undeprecate_workflow_type/3","title":"AWS.SWF.undeprecate_workflow_type/3","type":"function"},{"doc":"You can use IAM policies to control this action's access to Amazon SWF resources\nas follows:\n\n  * Use a `Resource` element with the domain name to limit the action\nto only specified domains.\n\n  * Use an `Action` element to allow or deny permission to call this\naction.\n\n  * Constrain the following parameters by using a `Condition` element\nwith the appropriate keys.\n\n    * `workflowType.name`: String constraint. The key is\n`swf:workflowType.name`.\n\n    * `workflowType.version`: String constraint. The key is\n`swf:workflowType.version`.\n\nIf the caller doesn't have sufficient permissions to invoke the action, or the\nparameter values fall outside the specified constraints, the action fails. The\nassociated event attribute's `cause` parameter is set to\n`OPERATION_NOT_PERMITTED`. For details and example IAM policies, see [Using IAM to Manage Access to Amazon SWF\nWorkflows](https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html)\nin the *Amazon SWF Developer Guide*.","ref":"AWS.SWF.html#undeprecate_workflow_type/3-access-control","title":"Access Control - AWS.SWF.undeprecate_workflow_type/3","type":"function"},{"doc":"Remove a tag from a Amazon SWF domain.","ref":"AWS.SWF.html#untag_resource/3","title":"AWS.SWF.untag_resource/3","type":"function"},{"doc":"Provides APIs for creating and managing SageMaker resources.\n\nOther Resources:\n\n  * [SageMaker Developer Guide](https://docs.aws.amazon.com/sagemaker/latest/dg/whatis.html#first-time-user)\n\n  * [Amazon Augmented AI Runtime API Reference](https://docs.aws.amazon.com/augmented-ai/2019-11-07/APIReference/Welcome.html)","ref":"AWS.SageMaker.html","title":"AWS.SageMaker","type":"module"},{"doc":"Creates an *association* between the source and the destination.\n\nA source can be associated with multiple destinations, and a destination can be\nassociated with multiple sources. An association is a lineage tracking entity.\nFor more information, see [Amazon SageMaker ML Lineage Tracking](https://docs.aws.amazon.com/sagemaker/latest/dg/lineage-tracking.html).","ref":"AWS.SageMaker.html#add_association/3","title":"AWS.SageMaker.add_association/3","type":"function"},{"doc":"Adds or overwrites one or more tags for the specified SageMaker resource.\n\nYou can add tags to notebook instances, training jobs, hyperparameter tuning\njobs, batch transform jobs, models, labeling jobs, work teams, endpoint\nconfigurations, and endpoints.\n\nEach tag consists of a key and an optional value. Tag keys must be unique per\nresource. For more information about tags, see For more information, see [Amazon Web Services Tagging\nStrategies](https://aws.amazon.com/answers/account-management/aws-tagging-strategies/).\n\nTags that you add to a hyperparameter tuning job by calling this API are also\nadded to any training jobs that the hyperparameter tuning job launches after you\ncall this API, but not to training jobs that the hyperparameter tuning job\nlaunched before you called this API. To make sure that the tags associated with\na hyperparameter tuning job are also added to all training jobs that the\nhyperparameter tuning job launches, add the tags when you first create the\ntuning job by specifying them in the `Tags` parameter of\n[CreateHyperParameterTuningJob](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateHyperParameterTuningJob.html) \nTags that you add to a SageMaker Domain or User Profile by calling this API are\nalso added to any Apps that the Domain or User Profile launches after you call\nthis API, but not to Apps that the Domain or User Profile launched before you\ncalled this API. To make sure that the tags associated with a Domain or User\nProfile are also added to all Apps that the Domain or User Profile launches, add\nthe tags when you first create the Domain or User Profile by specifying them in\nthe `Tags` parameter of\n[CreateDomain](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateDomain.html)\nor\n[CreateUserProfile](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateUserProfile.html).","ref":"AWS.SageMaker.html#add_tags/3","title":"AWS.SageMaker.add_tags/3","type":"function"},{"doc":"Associates a trial component with a trial.\n\nA trial component can be associated with multiple trials. To disassociate a\ntrial component from a trial, call the\n[DisassociateTrialComponent](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DisassociateTrialComponent.html)\nAPI.","ref":"AWS.SageMaker.html#associate_trial_component/3","title":"AWS.SageMaker.associate_trial_component/3","type":"function"},{"doc":"This action batch describes a list of versioned model packages","ref":"AWS.SageMaker.html#batch_describe_model_package/3","title":"AWS.SageMaker.batch_describe_model_package/3","type":"function"},{"doc":"Creates an *action*.\n\nAn action is a lineage tracking entity that represents an action or activity.\nFor example, a model deployment or an HPO job. Generally, an action involves at\nleast one input or output artifact. For more information, see [Amazon SageMaker ML Lineage\nTracking](https://docs.aws.amazon.com/sagemaker/latest/dg/lineage-tracking.html).","ref":"AWS.SageMaker.html#create_action/3","title":"AWS.SageMaker.create_action/3","type":"function"},{"doc":"Create a machine learning algorithm that you can use in SageMaker and list in\nthe Amazon Web Services Marketplace.","ref":"AWS.SageMaker.html#create_algorithm/3","title":"AWS.SageMaker.create_algorithm/3","type":"function"},{"doc":"Creates a running app for the specified UserProfile.\n\nThis operation is automatically invoked by Amazon SageMaker upon access to the\nassociated Domain, and when new kernel configurations are selected by the user.\nA user may have multiple Apps active simultaneously.","ref":"AWS.SageMaker.html#create_app/3","title":"AWS.SageMaker.create_app/3","type":"function"},{"doc":"Creates a configuration for running a SageMaker image as a KernelGateway app.\n\nThe configuration specifies the Amazon Elastic File System storage volume on the\nimage, and a list of the kernels in the image.","ref":"AWS.SageMaker.html#create_app_image_config/3","title":"AWS.SageMaker.create_app_image_config/3","type":"function"},{"doc":"Creates an *artifact*.\n\nAn artifact is a lineage tracking entity that represents a URI addressable\nobject or data. Some examples are the S3 URI of a dataset and the ECR registry\npath of an image. For more information, see [Amazon SageMaker ML Lineage Tracking](https://docs.aws.amazon.com/sagemaker/latest/dg/lineage-tracking.html).","ref":"AWS.SageMaker.html#create_artifact/3","title":"AWS.SageMaker.create_artifact/3","type":"function"},{"doc":"Creates an Autopilot job also referred to as Autopilot experiment or AutoML job.\n\nWe recommend using the new versions\n[CreateAutoMLJobV2](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateAutoMLJobV2.html) and\n[DescribeAutoMLJobV2](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeAutoMLJobV2.html),\nwhich offer backward compatibility.\n\n`CreateAutoMLJobV2` can manage tabular problem types identical to those of its\nprevious version `CreateAutoMLJob`, as well as time-series forecasting,\nnon-tabular problem types such as image or text classification, and text\ngeneration (LLMs fine-tuning).\n\nFind guidelines about how to migrate a `CreateAutoMLJob` to `CreateAutoMLJobV2`\nin [Migrate a CreateAutoMLJob to CreateAutoMLJobV2](https://docs.aws.amazon.com/sagemaker/latest/dg/autopilot-automate-model-development-create-experiment.html#autopilot-create-experiment-api-migrate-v1-v2).\n\nYou can find the best-performing model after you run an AutoML job by calling\n[DescribeAutoMLJobV2](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeAutoMLJobV2.html) (recommended) or\n[DescribeAutoMLJob](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeAutoMLJob.html).","ref":"AWS.SageMaker.html#create_auto_ml_job/3","title":"AWS.SageMaker.create_auto_ml_job/3","type":"function"},{"doc":"Creates an Autopilot job also referred to as Autopilot experiment or AutoML job\nV2.\n\n[CreateAutoMLJobV2](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateAutoMLJobV2.html) and\n[DescribeAutoMLJobV2](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeAutoMLJobV2.html)\nare new versions of\n[CreateAutoMLJob](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateAutoMLJob.html) and\n[DescribeAutoMLJob](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeAutoMLJob.html)\nwhich offer backward compatibility.\n\n`CreateAutoMLJobV2` can manage tabular problem types identical to those of its\nprevious version `CreateAutoMLJob`, as well as time-series forecasting,\nnon-tabular problem types such as image or text classification, and text\ngeneration (LLMs fine-tuning).\n\nFind guidelines about how to migrate a `CreateAutoMLJob` to `CreateAutoMLJobV2`\nin [Migrate a CreateAutoMLJob to CreateAutoMLJobV2](https://docs.aws.amazon.com/sagemaker/latest/dg/autopilot-automate-model-development-create-experiment.html#autopilot-create-experiment-api-migrate-v1-v2).\n\nFor the list of available problem types supported by `CreateAutoMLJobV2`, see\n[AutoMLProblemTypeConfig](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_AutoMLProblemTypeConfig.html).  You can find the best-performing model after you run an AutoML job V2 by calling\n[DescribeAutoMLJobV2](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeAutoMLJobV2.html).","ref":"AWS.SageMaker.html#create_auto_ml_job_v2/3","title":"AWS.SageMaker.create_auto_ml_job_v2/3","type":"function"},{"doc":"Creates a SageMaker HyperPod cluster.\n\nSageMaker HyperPod is a capability of SageMaker for creating and managing\npersistent clusters for developing large machine learning models, such as large\nlanguage models (LLMs) and diffusion models. To learn more, see [Amazon SageMaker\nHyperPod](https://docs.aws.amazon.com/sagemaker/latest/dg/sagemaker-hyperpod.html)\nin the *Amazon SageMaker Developer Guide*.","ref":"AWS.SageMaker.html#create_cluster/3","title":"AWS.SageMaker.create_cluster/3","type":"function"},{"doc":"Creates a Git repository as a resource in your SageMaker account.\n\nYou can associate the repository with notebook instances so that you can use Git\nsource control for the notebooks you create. The Git repository is a resource in\nyour SageMaker account, so it can be associated with more than one notebook\ninstance, and it persists independently from the lifecycle of any notebook\ninstances it is associated with.\n\nThe repository can be hosted either in [Amazon Web Services CodeCommit](https://docs.aws.amazon.com/codecommit/latest/userguide/welcome.html)\nor in any other Git repository.","ref":"AWS.SageMaker.html#create_code_repository/3","title":"AWS.SageMaker.create_code_repository/3","type":"function"},{"doc":"Starts a model compilation job.\n\nAfter the model has been compiled, Amazon SageMaker saves the resulting model\nartifacts to an Amazon Simple Storage Service (Amazon S3) bucket that you\nspecify.\n\nIf you choose to host your model using Amazon SageMaker hosting services, you\ncan use the resulting model artifacts as part of the model. You can also use the\nartifacts with Amazon Web Services IoT Greengrass. In that case, deploy them as\nan ML resource.\n\nIn the request body, you provide the following:\n\n  * A name for the compilation job\n\n  * Information about the input model artifacts\n\n  * The output location for the compiled model and the device (target)\nthat the model runs on\n\n  * The Amazon Resource Name (ARN) of the IAM role that Amazon\nSageMaker assumes to perform the model compilation job.\n\nYou can also provide a `Tag` to track the model compilation job's resource use\nand costs. The response body contains the `CompilationJobArn` for the compiled\njob.\n\nTo stop a model compilation job, use\n[StopCompilationJob](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_StopCompilationJob.html). To get information about a particular model compilation job, use\n[DescribeCompilationJob](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeCompilationJob.html).\nTo get information about multiple model compilation jobs, use\n[ListCompilationJobs](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListCompilationJobs.html).","ref":"AWS.SageMaker.html#create_compilation_job/3","title":"AWS.SageMaker.create_compilation_job/3","type":"function"},{"doc":"Creates a *context*.\n\nA context is a lineage tracking entity that represents a logical grouping of\nother tracking or experiment entities. Some examples are an endpoint and a model\npackage. For more information, see [Amazon SageMaker ML Lineage Tracking](https://docs.aws.amazon.com/sagemaker/latest/dg/lineage-tracking.html).","ref":"AWS.SageMaker.html#create_context/3","title":"AWS.SageMaker.create_context/3","type":"function"},{"doc":"Creates a definition for a job that monitors data quality and drift.\n\nFor information about model monitor, see [Amazon SageMaker Model Monitor](https://docs.aws.amazon.com/sagemaker/latest/dg/model-monitor.html).","ref":"AWS.SageMaker.html#create_data_quality_job_definition/3","title":"AWS.SageMaker.create_data_quality_job_definition/3","type":"function"},{"doc":"Creates a device fleet.","ref":"AWS.SageMaker.html#create_device_fleet/3","title":"AWS.SageMaker.create_device_fleet/3","type":"function"},{"doc":"Creates a `Domain`.\n\nA domain consists of an associated Amazon Elastic File System volume, a list of\nauthorized users, and a variety of security, application, policy, and Amazon\nVirtual Private Cloud (VPC) configurations. Users within a domain can share\nnotebook files and other artifacts with each other.","ref":"AWS.SageMaker.html#create_domain/3","title":"AWS.SageMaker.create_domain/3","type":"function"},{"doc":"When a domain is created, an EFS volume is created for use by all of the users\nwithin the domain. Each user receives a private home directory within the EFS\nvolume for notebooks, Git repositories, and data files.\n\nSageMaker uses the Amazon Web Services Key Management Service (Amazon Web\nServices KMS) to encrypt the EFS volume attached to the domain with an Amazon\nWeb Services managed key by default. For more control, you can specify a\ncustomer managed key. For more information, see [Protect Data at Rest Using Encryption](https://docs.aws.amazon.com/sagemaker/latest/dg/encryption-at-rest.html).","ref":"AWS.SageMaker.html#create_domain/3-efs-storage","title":"EFS storage - AWS.SageMaker.create_domain/3","type":"function"},{"doc":"All traffic between the domain and the Amazon EFS volume is through the\nspecified VPC and subnets. For other traffic, you can specify the\n`AppNetworkAccessType` parameter. `AppNetworkAccessType` corresponds to the\nnetwork access type that you choose when you onboard to the domain. The\nfollowing options are available:\n\n  * `PublicInternetOnly` - Non-EFS traffic goes through a VPC managed\nby Amazon SageMaker, which allows internet access. This is the default value.\n\n  * `VpcOnly` - All traffic is through the specified VPC and subnets.\nInternet access is disabled by default. To allow internet access, you must\nspecify a NAT gateway.\n\nWhen internet access is disabled, you won't be able to run a Amazon SageMaker\nStudio notebook or to train or host models unless your VPC has an interface\nendpoint to the SageMaker API and runtime or a NAT gateway and your security\ngroups allow outbound connections.\n\nNFS traffic over TCP on port 2049 needs to be allowed in both inbound and\noutbound rules in order to launch a Amazon SageMaker Studio app successfully.\n\nFor more information, see [Connect Amazon SageMaker Studio Notebooks to Resources in a\nVPC](https://docs.aws.amazon.com/sagemaker/latest/dg/studio-notebooks-and-internet-access.html).","ref":"AWS.SageMaker.html#create_domain/3-vpc-configuration","title":"VPC configuration - AWS.SageMaker.create_domain/3","type":"function"},{"doc":"Creates an edge deployment plan, consisting of multiple stages.\n\nEach stage may have a different deployment configuration and devices.","ref":"AWS.SageMaker.html#create_edge_deployment_plan/3","title":"AWS.SageMaker.create_edge_deployment_plan/3","type":"function"},{"doc":"Creates a new stage in an existing edge deployment plan.","ref":"AWS.SageMaker.html#create_edge_deployment_stage/3","title":"AWS.SageMaker.create_edge_deployment_stage/3","type":"function"},{"doc":"Starts a SageMaker Edge Manager model packaging job.\n\nEdge Manager will use the model artifacts from the Amazon Simple Storage Service\nbucket that you specify. After the model has been packaged, Amazon SageMaker\nsaves the resulting artifacts to an S3 bucket that you specify.","ref":"AWS.SageMaker.html#create_edge_packaging_job/3","title":"AWS.SageMaker.create_edge_packaging_job/3","type":"function"},{"doc":"Creates an endpoint using the endpoint configuration specified in the request.\n\nSageMaker uses the endpoint to provision resources and deploy models. You create\nthe endpoint configuration with the\n[CreateEndpointConfig](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateEndpointConfig.html) API.\n\nUse this API to deploy models using SageMaker hosting services.\n\nYou must not delete an `EndpointConfig` that is in use by an endpoint that is\nlive or while the `UpdateEndpoint` or `CreateEndpoint` operations are being\nperformed on the endpoint. To update an endpoint, you must create a new\n`EndpointConfig`.\n\nThe endpoint name must be unique within an Amazon Web Services Region in your\nAmazon Web Services account.\n\nWhen it receives the request, SageMaker creates the endpoint, launches the\nresources (ML compute instances), and deploys the model(s) on them.\n\nWhen you call\n[CreateEndpoint](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateEndpoint.html),\na load call is made to DynamoDB to verify that your endpoint configuration\nexists. When you read data from a DynamoDB table supporting [ `Eventually Consistent Reads`\n](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/HowItWorks.ReadConsistency.html),\nthe response might not reflect the results of a recently completed write\noperation. The response might include some stale data. If the dependent entities\nare not yet in DynamoDB, this causes a validation error. If you repeat your read\nrequest after a short time, the response should return the latest data. So retry\nlogic is recommended to handle these possible issues. We also recommend that\ncustomers call\n[DescribeEndpointConfig](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeEndpointConfig.html) before calling\n[CreateEndpoint](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateEndpoint.html)\nto minimize the potential impact of a DynamoDB eventually consistent read.\n\nWhen SageMaker receives the request, it sets the endpoint status to `Creating`.\nAfter it creates the endpoint, it sets the status to `InService`. SageMaker can\nthen process incoming requests for inferences. To check the status of an\nendpoint, use the\n[DescribeEndpoint](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeEndpoint.html) API.\n\nIf any of the models hosted at this endpoint get model data from an Amazon S3\nlocation, SageMaker uses Amazon Web Services Security Token Service to download\nmodel artifacts from the S3 path you provided. Amazon Web Services STS is\nactivated in your Amazon Web Services account by default. If you previously\ndeactivated Amazon Web Services STS for a region, you need to reactivate Amazon\nWeb Services STS for that region. For more information, see [Activating and\nDeactivating Amazon Web Services STS in an Amazon Web Services\nRegion](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_enable-regions.html)\nin the *Amazon Web Services Identity and Access Management User Guide*.\n\nTo add the IAM role policies for using this API operation, go to the [IAM console](https://console.aws.amazon.com/iam/), and choose Roles in the left\nnavigation pane. Search the IAM role that you want to grant access to use the\n[CreateEndpoint](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateEndpoint.html) and\n[CreateEndpointConfig](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateEndpointConfig.html)\nAPI operations, add the following policies to the role.\n\n   Option 1: For a full SageMaker access, search and attach the\n`AmazonSageMakerFullAccess` policy.\n\n   Option 2: For granting a limited access to an IAM role, paste the\nfollowing Action elements manually into the JSON file of the IAM role:\n\n`\"Action\": [\"sagemaker:CreateEndpoint\", \"sagemaker:CreateEndpointConfig\"]`  `\"Resource\": [`\n\n`\"arn:aws:sagemaker:region:account-id:endpoint/endpointName\"`\n\n`\"arn:aws:sagemaker:region:account-id:endpoint-config/endpointConfigName\"`\n\n`]`\n\nFor more information, see [SageMaker API Permissions: Actions, Permissions, and Resources\nReference](https://docs.aws.amazon.com/sagemaker/latest/dg/api-permissions-reference.html).","ref":"AWS.SageMaker.html#create_endpoint/3","title":"AWS.SageMaker.create_endpoint/3","type":"function"},{"doc":"Creates an endpoint configuration that SageMaker hosting services uses to deploy\nmodels.\n\nIn the configuration, you identify one or more models, created using the\n`CreateModel` API, to deploy and the resources that you want SageMaker to\nprovision. Then you call the\n[CreateEndpoint](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateEndpoint.html) API.\n\nUse this API if you want to use SageMaker hosting services to deploy models into\nproduction.\n\nIn the request, you define a `ProductionVariant`, for each model that you want\nto deploy. Each `ProductionVariant` parameter also describes the resources that\nyou want SageMaker to provision. This includes the number and type of ML compute\ninstances to deploy.\n\nIf you are hosting multiple models, you also assign a `VariantWeight` to specify\nhow much traffic you want to allocate to each model. For example, suppose that\nyou want to host two models, A and B, and you assign traffic weight 2 for model\nA and 1 for model B. SageMaker distributes two-thirds of the traffic to Model A,\nand one-third to model B.\n\nWhen you call\n[CreateEndpoint](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateEndpoint.html),\na load call is made to DynamoDB to verify that your endpoint configuration\nexists. When you read data from a DynamoDB table supporting [ `Eventually Consistent Reads`\n](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/HowItWorks.ReadConsistency.html),\nthe response might not reflect the results of a recently completed write\noperation. The response might include some stale data. If the dependent entities\nare not yet in DynamoDB, this causes a validation error. If you repeat your read\nrequest after a short time, the response should return the latest data. So retry\nlogic is recommended to handle these possible issues. We also recommend that\ncustomers call\n[DescribeEndpointConfig](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeEndpointConfig.html) before calling\n[CreateEndpoint](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateEndpoint.html)\nto minimize the potential impact of a DynamoDB eventually consistent read.","ref":"AWS.SageMaker.html#create_endpoint_config/3","title":"AWS.SageMaker.create_endpoint_config/3","type":"function"},{"doc":"Creates a SageMaker *experiment*.\n\nAn experiment is a collection of *trials* that are observed, compared and\nevaluated as a group. A trial is a set of steps, called *trial components*, that\nproduce a machine learning model.\n\nIn the Studio UI, trials are referred to as *run groups* and trial components\nare referred to as *runs*.\n\nThe goal of an experiment is to determine the components that produce the best\nmodel. Multiple trials are performed, each one isolating and measuring the\nimpact of a change to one or more inputs, while keeping the remaining inputs\nconstant.\n\nWhen you use SageMaker Studio or the SageMaker Python SDK, all experiments,\ntrials, and trial components are automatically tracked, logged, and indexed.\nWhen you use the Amazon Web Services SDK for Python (Boto), you must use the\nlogging APIs provided by the SDK.\n\nYou can add tags to experiments, trials, trial components and then use the\n[Search](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_Search.html) API to search for the tags.\n\nTo add a description to an experiment, specify the optional `Description`\nparameter. To add a description later, or to change the description, call the\n[UpdateExperiment](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_UpdateExperiment.html)\nAPI.\n\nTo get a list of all your experiments, call the\n[ListExperiments](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListExperiments.html) API. To view an experiment's properties, call the\n[DescribeExperiment](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeExperiment.html)\nAPI. To get a list of all the trials associated with an experiment, call the\n[ListTrials](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListTrials.html) API. To create a trial call the\n[CreateTrial](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateTrial.html)\nAPI.","ref":"AWS.SageMaker.html#create_experiment/3","title":"AWS.SageMaker.create_experiment/3","type":"function"},{"doc":"Create a new `FeatureGroup`.\n\nA `FeatureGroup` is a group of `Features` defined in the `FeatureStore` to\ndescribe a `Record`.\n\nThe `FeatureGroup` defines the schema and features contained in the\n`FeatureGroup`. A `FeatureGroup` definition is composed of a list of `Features`,\na `RecordIdentifierFeatureName`, an `EventTimeFeatureName` and configurations\nfor its `OnlineStore` and `OfflineStore`. Check [Amazon Web Services service quotas](https://docs.aws.amazon.com/general/latest/gr/aws_service_limits.html)\nto see the `FeatureGroup`s quota for your Amazon Web Services account.\n\nNote that it can take approximately 10-15 minutes to provision an `OnlineStore`\n`FeatureGroup` with the `InMemory` `StorageType`.\n\nYou must include at least one of `OnlineStoreConfig` and `OfflineStoreConfig` to\ncreate a `FeatureGroup`.","ref":"AWS.SageMaker.html#create_feature_group/3","title":"AWS.SageMaker.create_feature_group/3","type":"function"},{"doc":"Creates a flow definition.","ref":"AWS.SageMaker.html#create_flow_definition/3","title":"AWS.SageMaker.create_flow_definition/3","type":"function"},{"doc":"Create a hub.\n\nHub APIs are only callable through SageMaker Studio.","ref":"AWS.SageMaker.html#create_hub/3","title":"AWS.SageMaker.create_hub/3","type":"function"},{"doc":"Defines the settings you will use for the human review workflow user interface.\n\nReviewers will see a three-panel interface with an instruction area, the item to\nreview, and an input area.","ref":"AWS.SageMaker.html#create_human_task_ui/3","title":"AWS.SageMaker.create_human_task_ui/3","type":"function"},{"doc":"Starts a hyperparameter tuning job.\n\nA hyperparameter tuning job finds the best version of a model by running many\ntraining jobs on your dataset using the algorithm you choose and values for\nhyperparameters within ranges that you specify. It then chooses the\nhyperparameter values that result in a model that performs the best, as measured\nby an objective metric that you choose.\n\nA hyperparameter tuning job automatically creates Amazon SageMaker experiments,\ntrials, and trial components for each training job that it runs. You can view\nthese entities in Amazon SageMaker Studio. For more information, see [View Experiments, Trials, and Trial\nComponents](https://docs.aws.amazon.com/sagemaker/latest/dg/experiments-view-compare.html#experiments-view).\n\nDo not include any security-sensitive information including account access IDs,\nsecrets or tokens in any hyperparameter field. If the use of security-sensitive\ncredentials are detected, SageMaker will reject your training job request and\nreturn an exception error.","ref":"AWS.SageMaker.html#create_hyper_parameter_tuning_job/3","title":"AWS.SageMaker.create_hyper_parameter_tuning_job/3","type":"function"},{"doc":"Creates a custom SageMaker image.\n\nA SageMaker image is a set of image versions. Each image version represents a\ncontainer image stored in Amazon ECR. For more information, see [Bring your own SageMaker\nimage](https://docs.aws.amazon.com/sagemaker/latest/dg/studio-byoi.html).","ref":"AWS.SageMaker.html#create_image/3","title":"AWS.SageMaker.create_image/3","type":"function"},{"doc":"Creates a version of the SageMaker image specified by `ImageName`.\n\nThe version represents the Amazon ECR container image specified by `BaseImage`.","ref":"AWS.SageMaker.html#create_image_version/3","title":"AWS.SageMaker.create_image_version/3","type":"function"},{"doc":"Creates an inference component, which is a SageMaker hosting object that you can\nuse to deploy a model to an endpoint.\n\nIn the inference component settings, you specify the model, the endpoint, and\nhow the model utilizes the resources that the endpoint hosts. You can optimize\nresource utilization by tailoring how the required CPU cores, accelerators, and\nmemory are allocated. You can deploy multiple inference components to an\nendpoint, where each inference component contains one model and the resource\nutilization needs for that individual model. After you deploy an inference\ncomponent, you can directly invoke the associated model when you use the\nInvokeEndpoint API action.","ref":"AWS.SageMaker.html#create_inference_component/3","title":"AWS.SageMaker.create_inference_component/3","type":"function"},{"doc":"Creates an inference experiment using the configurations specified in the\nrequest.\n\nUse this API to setup and schedule an experiment to compare model variants on a\nAmazon SageMaker inference endpoint. For more information about inference\nexperiments, see [Shadow tests](https://docs.aws.amazon.com/sagemaker/latest/dg/shadow-tests.html).\n\nAmazon SageMaker begins your experiment at the scheduled time and routes traffic\nto your endpoint's model variants based on your specified configuration.\n\nWhile the experiment is in progress or after it has concluded, you can view\nmetrics that compare your model variants. For more information, see [View, monitor, and edit shadow\ntests](https://docs.aws.amazon.com/sagemaker/latest/dg/shadow-tests-view-monitor-edit.html).","ref":"AWS.SageMaker.html#create_inference_experiment/3","title":"AWS.SageMaker.create_inference_experiment/3","type":"function"},{"doc":"Starts a recommendation job.\n\nYou can create either an instance recommendation or load test job.","ref":"AWS.SageMaker.html#create_inference_recommendations_job/3","title":"AWS.SageMaker.create_inference_recommendations_job/3","type":"function"},{"doc":"Creates a job that uses workers to label the data objects in your input dataset.\n\nYou can use the labeled data to train machine learning models.\n\nYou can select your workforce from one of three providers:\n\n  * A private workforce that you create. It can include employees,\ncontractors, and outside experts. Use a private workforce when want the data to\nstay within your organization or when a specific set of skills is required.\n\n  * One or more vendors that you select from the Amazon Web Services\nMarketplace. Vendors provide expertise in specific areas.\n\n  * The Amazon Mechanical Turk workforce. This is the largest\nworkforce, but it should only be used for public data or data that has been\nstripped of any personally identifiable information.\n\nYou can also use *automated data labeling* to reduce the number of data objects\nthat need to be labeled by a human. Automated data labeling uses *active\nlearning* to determine if a data object can be labeled by machine or if it needs\nto be sent to a human worker. For more information, see [Using Automated Data Labeling](https://docs.aws.amazon.com/sagemaker/latest/dg/sms-automated-labeling.html).\n\nThe data objects to be labeled are contained in an Amazon S3 bucket. You create\na *manifest file* that describes the location of each object. For more\ninformation, see [Using Input and Output Data](https://docs.aws.amazon.com/sagemaker/latest/dg/sms-data.html).\n\nThe output can be used as the manifest file for another labeling job or as\ntraining data for your machine learning models.\n\nYou can use this operation to create a static labeling job or a streaming\nlabeling job. A static labeling job stops if all data objects in the input\nmanifest file identified in `ManifestS3Uri` have been labeled. A streaming\nlabeling job runs perpetually until it is manually stopped, or remains idle for\n10 days. You can send new data objects to an active (`InProgress`) streaming\nlabeling job in real time. To learn how to create a static labeling job, see\n[Create a Labeling Job (API)\n](https://docs.aws.amazon.com/sagemaker/latest/dg/sms-create-labeling-job-api.html)\nin the Amazon SageMaker Developer Guide. To learn how to create a streaming\nlabeling job, see [Create a Streaming Labeling Job](https://docs.aws.amazon.com/sagemaker/latest/dg/sms-streaming-create-job.html).","ref":"AWS.SageMaker.html#create_labeling_job/3","title":"AWS.SageMaker.create_labeling_job/3","type":"function"},{"doc":"Creates a model in SageMaker.\n\nIn the request, you name the model and describe a primary container. For the\nprimary container, you specify the Docker image that contains inference code,\nartifacts (from prior training), and a custom environment map that the inference\ncode uses when you deploy the model for predictions.\n\nUse this API to create a model if you want to use SageMaker hosting services or\nrun a batch transform job.\n\nTo host your model, you create an endpoint configuration with the\n`CreateEndpointConfig` API, and then create an endpoint with the\n`CreateEndpoint` API. SageMaker then deploys all of the containers that you\ndefined for the model in the hosting environment.\n\nFor an example that calls this method when deploying a model to SageMaker\nhosting services, see [Create a Model (Amazon Web Services SDK for Python (Boto 3)).](https://docs.aws.amazon.com/sagemaker/latest/dg/realtime-endpoints-deployment.html#realtime-endpoints-deployment-create-model)\n\nTo run a batch transform using your model, you start a job with the\n`CreateTransformJob` API. SageMaker uses your model and your dataset to get\ninferences which are then saved to a specified S3 location.\n\nIn the request, you also provide an IAM role that SageMaker can assume to access\nmodel artifacts and docker image for deployment on ML compute hosting instances\nor for batch transform jobs. In addition, you also use the IAM role to manage\npermissions the inference code needs. For example, if the inference code access\nany other Amazon Web Services resources, you grant necessary permissions via\nthis role.","ref":"AWS.SageMaker.html#create_model/3","title":"AWS.SageMaker.create_model/3","type":"function"},{"doc":"Creates the definition for a model bias job.","ref":"AWS.SageMaker.html#create_model_bias_job_definition/3","title":"AWS.SageMaker.create_model_bias_job_definition/3","type":"function"},{"doc":"Creates an Amazon SageMaker Model Card.\n\nFor information about how to use model cards, see [Amazon SageMaker Model Card](https://docs.aws.amazon.com/sagemaker/latest/dg/model-cards.html).","ref":"AWS.SageMaker.html#create_model_card/3","title":"AWS.SageMaker.create_model_card/3","type":"function"},{"doc":"Creates an Amazon SageMaker Model Card export job.","ref":"AWS.SageMaker.html#create_model_card_export_job/3","title":"AWS.SageMaker.create_model_card_export_job/3","type":"function"},{"doc":"Creates the definition for a model explainability job.","ref":"AWS.SageMaker.html#create_model_explainability_job_definition/3","title":"AWS.SageMaker.create_model_explainability_job_definition/3","type":"function"},{"doc":"Creates a model package that you can use to create SageMaker models or list on\nAmazon Web Services Marketplace, or a versioned model that is part of a model\ngroup.\n\nBuyers can subscribe to model packages listed on Amazon Web Services Marketplace\nto create models in SageMaker.\n\nTo create a model package by specifying a Docker container that contains your\ninference code and the Amazon S3 location of your model artifacts, provide\nvalues for `InferenceSpecification`. To create a model from an algorithm\nresource that you created or subscribed to in Amazon Web Services Marketplace,\nprovide a value for `SourceAlgorithmSpecification`.\n\nThere are two types of model packages:\n\n   Versioned - a model that is part of a model group in the model\nregistry.\n\n   Unversioned - a model package that is not part of a model group.","ref":"AWS.SageMaker.html#create_model_package/3","title":"AWS.SageMaker.create_model_package/3","type":"function"},{"doc":"Creates a model group.\n\nA model group contains a group of model versions.","ref":"AWS.SageMaker.html#create_model_package_group/3","title":"AWS.SageMaker.create_model_package_group/3","type":"function"},{"doc":"Creates a definition for a job that monitors model quality and drift.\n\nFor information about model monitor, see [Amazon SageMaker Model Monitor](https://docs.aws.amazon.com/sagemaker/latest/dg/model-monitor.html).","ref":"AWS.SageMaker.html#create_model_quality_job_definition/3","title":"AWS.SageMaker.create_model_quality_job_definition/3","type":"function"},{"doc":"Creates a schedule that regularly starts Amazon SageMaker Processing Jobs to\nmonitor the data captured for an Amazon SageMaker Endpoint.","ref":"AWS.SageMaker.html#create_monitoring_schedule/3","title":"AWS.SageMaker.create_monitoring_schedule/3","type":"function"},{"doc":"Creates an SageMaker notebook instance.\n\nA notebook instance is a machine learning (ML) compute instance running on a\nJupyter notebook.\n\nIn a `CreateNotebookInstance` request, specify the type of ML compute instance\nthat you want to run. SageMaker launches the instance, installs common libraries\nthat you can use to explore datasets for model training, and attaches an ML\nstorage volume to the notebook instance.\n\nSageMaker also provides a set of example notebooks. Each notebook demonstrates\nhow to use SageMaker with a specific algorithm or with a machine learning\nframework.\n\nAfter receiving the request, SageMaker does the following:\n\n  1. Creates a network interface in the SageMaker VPC.\n\n  2. (Option) If you specified `SubnetId`, SageMaker creates a network\ninterface in your own VPC, which is inferred from the subnet ID that you provide\nin the input. When creating this network interface, SageMaker attaches the\nsecurity group that you specified in the request to the network interface that\nit creates in your VPC.\n\n  3. Launches an EC2 instance of the type specified in the request in\nthe SageMaker VPC. If you specified `SubnetId` of your VPC, SageMaker specifies\nboth network interfaces when launching this instance. This enables inbound\ntraffic from your own VPC to the notebook instance, assuming that the security\ngroups allow it.\n\nAfter creating the notebook instance, SageMaker returns its Amazon Resource Name\n(ARN). You can't change the name of a notebook instance after you create it.\n\nAfter SageMaker creates the notebook instance, you can connect to the Jupyter\nserver and work in Jupyter notebooks. For example, you can write code to explore\na dataset that you can use for model training, train a model, host models by\ncreating SageMaker endpoints, and validate hosted models.\n\nFor more information, see [How It Works](https://docs.aws.amazon.com/sagemaker/latest/dg/how-it-works.html).","ref":"AWS.SageMaker.html#create_notebook_instance/3","title":"AWS.SageMaker.create_notebook_instance/3","type":"function"},{"doc":"Creates a lifecycle configuration that you can associate with a notebook\ninstance.\n\nA *lifecycle configuration* is a collection of shell scripts that run when you\ncreate or start a notebook instance.\n\nEach lifecycle configuration script has a limit of 16384 characters.\n\nThe value of the `$PATH` environment variable that is available to both scripts\nis `/sbin:bin:/usr/sbin:/usr/bin`.\n\nView Amazon CloudWatch Logs for notebook instance lifecycle configurations in\nlog group `/aws/sagemaker/NotebookInstances` in log stream\n`[notebook-instance-name]/[LifecycleConfigHook]`.  Lifecycle configuration scripts cannot run for longer than 5 minutes. If a\nscript runs for longer than 5 minutes, it fails and the notebook instance is not\ncreated or started.\n\nFor information about notebook instance lifestyle configurations, see [Step 2.1:\n(Optional) Customize a Notebook\nInstance](https://docs.aws.amazon.com/sagemaker/latest/dg/notebook-lifecycle-config.html).","ref":"AWS.SageMaker.html#create_notebook_instance_lifecycle_config/3","title":"AWS.SageMaker.create_notebook_instance_lifecycle_config/3","type":"function"},{"doc":"Creates a pipeline using a JSON pipeline definition.","ref":"AWS.SageMaker.html#create_pipeline/3","title":"AWS.SageMaker.create_pipeline/3","type":"function"},{"doc":"Creates a URL for a specified UserProfile in a Domain.\n\nWhen accessed in a web browser, the user will be automatically signed in to the\ndomain, and granted access to all of the Apps and files associated with the\nDomain's Amazon Elastic File System volume. This operation can only be called\nwhen the authentication mode equals IAM.\n\nThe IAM role or user passed to this API defines the permissions to access the\napp. Once the presigned URL is created, no additional permission is required to\naccess this URL. IAM authorization policies for this API are also enforced for\nevery HTTP request and WebSocket frame that attempts to connect to the app.\n\nYou can restrict access to this API and to the URL that it returns to a list of\nIP addresses, Amazon VPCs or Amazon VPC Endpoints that you specify. For more\ninformation, see [Connect to Amazon SageMaker Studio Through an Interface VPC Endpoint](https://docs.aws.amazon.com/sagemaker/latest/dg/studio-interface-endpoint.html)\n.\n\nThe URL that you get from a call to `CreatePresignedDomainUrl` has a default\ntimeout of 5 minutes. You can configure this value using `ExpiresInSeconds`. If\nyou try to use the URL after the timeout limit expires, you are directed to the\nAmazon Web Services console sign-in page.","ref":"AWS.SageMaker.html#create_presigned_domain_url/3","title":"AWS.SageMaker.create_presigned_domain_url/3","type":"function"},{"doc":"Returns a URL that you can use to connect to the Jupyter server from a notebook\ninstance.\n\nIn the SageMaker console, when you choose `Open` next to a notebook instance,\nSageMaker opens a new tab showing the Jupyter server home page from the notebook\ninstance. The console uses this API to get the URL and show the page.\n\nThe IAM role or user used to call this API defines the permissions to access the\nnotebook instance. Once the presigned URL is created, no additional permission\nis required to access this URL. IAM authorization policies for this API are also\nenforced for every HTTP request and WebSocket frame that attempts to connect to\nthe notebook instance.\n\nYou can restrict access to this API and to the URL that it returns to a list of\nIP addresses that you specify. Use the `NotIpAddress` condition operator and the\n`aws:SourceIP` condition context key to specify the list of IP addresses that\nyou want to have access to the notebook instance. For more information, see\n[Limit Access to a Notebook Instance by IP Address](https://docs.aws.amazon.com/sagemaker/latest/dg/security_iam_id-based-policy-examples.html#nbi-ip-filter).\n\nThe URL that you get from a call to\n[CreatePresignedNotebookInstanceUrl](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreatePresignedNotebookInstanceUrl.html)\nis valid only for 5 minutes. If you try to use the URL after the 5-minute limit\nexpires, you are directed to the Amazon Web Services console sign-in page.","ref":"AWS.SageMaker.html#create_presigned_notebook_instance_url/3","title":"AWS.SageMaker.create_presigned_notebook_instance_url/3","type":"function"},{"doc":"Creates a processing job.","ref":"AWS.SageMaker.html#create_processing_job/3","title":"AWS.SageMaker.create_processing_job/3","type":"function"},{"doc":"Creates a machine learning (ML) project that can contain one or more templates\nthat set up an ML pipeline from training to deploying an approved model.","ref":"AWS.SageMaker.html#create_project/3","title":"AWS.SageMaker.create_project/3","type":"function"},{"doc":"Creates a space used for real time collaboration in a domain.","ref":"AWS.SageMaker.html#create_space/3","title":"AWS.SageMaker.create_space/3","type":"function"},{"doc":"Creates a new Amazon SageMaker Studio Lifecycle Configuration.","ref":"AWS.SageMaker.html#create_studio_lifecycle_config/3","title":"AWS.SageMaker.create_studio_lifecycle_config/3","type":"function"},{"doc":"Starts a model training job.\n\nAfter training completes, SageMaker saves the resulting model artifacts to an\nAmazon S3 location that you specify.\n\nIf you choose to host your model using SageMaker hosting services, you can use\nthe resulting model artifacts as part of the model. You can also use the\nartifacts in a machine learning service other than SageMaker, provided that you\nknow how to use them for inference.\n\nIn the request body, you provide the following:\n\n  * `AlgorithmSpecification` - Identifies the training algorithm to\nuse.\n\n  * `HyperParameters` - Specify these algorithm-specific parameters to\nenable the estimation of model parameters during training. Hyperparameters can\nbe tuned to optimize this learning process. For a list of hyperparameters for\neach training algorithm provided by SageMaker, see\n[Algorithms](https://docs.aws.amazon.com/sagemaker/latest/dg/algos.html).  Do not include any security-sensitive information including account access IDs,\nsecrets or tokens in any hyperparameter field. If the use of security-sensitive\ncredentials are detected, SageMaker will reject your training job request and\nreturn an exception error.\n\n  * `InputDataConfig` - Describes the input required by the training\njob and the Amazon S3, EFS, or FSx location where it is stored.\n\n  * `OutputDataConfig` - Identifies the Amazon S3 bucket where you\nwant SageMaker to save the results of model training.\n\n  * `ResourceConfig` - Identifies the resources, ML compute instances,\nand ML storage volumes to deploy for model training. In distributed training,\nyou specify more than one instance.\n\n  * `EnableManagedSpotTraining` - Optimize the cost of training\nmachine learning models by up to 80% by using Amazon EC2 Spot instances. For\nmore information, see [Managed Spot\nTraining](https://docs.aws.amazon.com/sagemaker/latest/dg/model-managed-spot-training.html).\n\n  * `RoleArn` - The Amazon Resource Name (ARN) that SageMaker assumes\nto perform tasks on your behalf during model training. You must grant this role\nthe necessary permissions so that SageMaker can successfully complete model\ntraining.\n\n  * `StoppingCondition` - To help cap training costs, use\n`MaxRuntimeInSeconds` to set a time limit for training. Use\n`MaxWaitTimeInSeconds` to specify how long a managed spot training job has to\ncomplete.\n\n  * `Environment` - The environment variables to set in the Docker\ncontainer.\n\n  * `RetryStrategy` - The number of times to retry the job when the\njob fails due to an `InternalServerError`.\n\nFor more information about SageMaker, see [How It Works](https://docs.aws.amazon.com/sagemaker/latest/dg/how-it-works.html).","ref":"AWS.SageMaker.html#create_training_job/3","title":"AWS.SageMaker.create_training_job/3","type":"function"},{"doc":"Starts a transform job.\n\nA transform job uses a trained model to get inferences on a dataset and saves\nthese results to an Amazon S3 location that you specify.\n\nTo perform batch transformations, you create a transform job and use the data\nthat you have readily available.\n\nIn the request body, you provide the following:\n\n  * `TransformJobName` - Identifies the transform job. The name must\nbe unique within an Amazon Web Services Region in an Amazon Web Services\naccount.\n\n  * `ModelName` - Identifies the model to use. `ModelName` must be the\nname of an existing Amazon SageMaker model in the same Amazon Web Services\nRegion and Amazon Web Services account. For information on creating a model, see\n[CreateModel](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateModel.html).     * `TransformInput` - Describes the dataset to be transformed and the\nAmazon S3 location where it is stored.\n\n  * `TransformOutput` - Identifies the Amazon S3 location where you\nwant Amazon SageMaker to save the results from the transform job.\n\n  * `TransformResources` - Identifies the ML compute instances for the\ntransform job.\n\nFor more information about how batch transformation works, see [Batch\nTransform](https://docs.aws.amazon.com/sagemaker/latest/dg/batch-transform.html).","ref":"AWS.SageMaker.html#create_transform_job/3","title":"AWS.SageMaker.create_transform_job/3","type":"function"},{"doc":"Creates an SageMaker *trial*.\n\nA trial is a set of steps called *trial components* that produce a machine\nlearning model. A trial is part of a single SageMaker *experiment*.\n\nWhen you use SageMaker Studio or the SageMaker Python SDK, all experiments,\ntrials, and trial components are automatically tracked, logged, and indexed.\nWhen you use the Amazon Web Services SDK for Python (Boto), you must use the\nlogging APIs provided by the SDK.\n\nYou can add tags to a trial and then use the\n[Search](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_Search.html) API to search for the tags.\n\nTo get a list of all your trials, call the\n[ListTrials](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListTrials.html)\nAPI. To view a trial's properties, call the\n[DescribeTrial](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeTrial.html) API. To create a trial component, call the\n[CreateTrialComponent](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateTrialComponent.html)\nAPI.","ref":"AWS.SageMaker.html#create_trial/3","title":"AWS.SageMaker.create_trial/3","type":"function"},{"doc":"Creates a *trial component*, which is a stage of a machine learning *trial*.\n\nA trial is composed of one or more trial components. A trial component can be\nused in multiple trials.\n\nTrial components include pre-processing jobs, training jobs, and batch transform\njobs.\n\nWhen you use SageMaker Studio or the SageMaker Python SDK, all experiments,\ntrials, and trial components are automatically tracked, logged, and indexed.\nWhen you use the Amazon Web Services SDK for Python (Boto), you must use the\nlogging APIs provided by the SDK.\n\nYou can add tags to a trial component and then use the\n[Search](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_Search.html)\nAPI to search for the tags.","ref":"AWS.SageMaker.html#create_trial_component/3","title":"AWS.SageMaker.create_trial_component/3","type":"function"},{"doc":"Creates a user profile.\n\nA user profile represents a single user within a domain, and is the main way to\nreference a \"person\" for the purposes of sharing, reporting, and other\nuser-oriented features. This entity is created when a user onboards to a domain.\nIf an administrator invites a person by email or imports them from IAM Identity\nCenter, a user profile is automatically created. A user profile is the primary\nholder of settings for an individual user and has a reference to the user's\nprivate Amazon Elastic File System home directory.","ref":"AWS.SageMaker.html#create_user_profile/3","title":"AWS.SageMaker.create_user_profile/3","type":"function"},{"doc":"Use this operation to create a workforce.\n\nThis operation will return an error if a workforce already exists in the Amazon\nWeb Services Region that you specify. You can only create one workforce in each\nAmazon Web Services Region per Amazon Web Services account.\n\nIf you want to create a new workforce in an Amazon Web Services Region where a\nworkforce already exists, use the\n[DeleteWorkforce](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteWorkforce.html) API operation to delete the existing workforce and then use `CreateWorkforce` to\ncreate a new workforce.\n\nTo create a private workforce using Amazon Cognito, you must specify a Cognito\nuser pool in `CognitoConfig`. You can also create an Amazon Cognito workforce\nusing the Amazon SageMaker console. For more information, see [ Create a Private\nWorkforce (Amazon\nCognito)](https://docs.aws.amazon.com/sagemaker/latest/dg/sms-workforce-create-private.html).\n\nTo create a private workforce using your own OIDC Identity Provider (IdP),\nspecify your IdP configuration in `OidcConfig`. Your OIDC IdP must support\n*groups* because groups are used by Ground Truth and Amazon A2I to create work\nteams. For more information, see [ Create a Private Workforce (OIDC IdP)](https://docs.aws.amazon.com/sagemaker/latest/dg/sms-workforce-create-private-oidc.html).","ref":"AWS.SageMaker.html#create_workforce/3","title":"AWS.SageMaker.create_workforce/3","type":"function"},{"doc":"Creates a new work team for labeling your data.\n\nA work team is defined by one or more Amazon Cognito user pools. You must first\ncreate the user pools before you can create a work team.\n\nYou cannot create more than 25 work teams in an account and region.","ref":"AWS.SageMaker.html#create_workteam/3","title":"AWS.SageMaker.create_workteam/3","type":"function"},{"doc":"Deletes an action.","ref":"AWS.SageMaker.html#delete_action/3","title":"AWS.SageMaker.delete_action/3","type":"function"},{"doc":"Removes the specified algorithm from your account.","ref":"AWS.SageMaker.html#delete_algorithm/3","title":"AWS.SageMaker.delete_algorithm/3","type":"function"},{"doc":"Used to stop and delete an app.","ref":"AWS.SageMaker.html#delete_app/3","title":"AWS.SageMaker.delete_app/3","type":"function"},{"doc":"Deletes an AppImageConfig.","ref":"AWS.SageMaker.html#delete_app_image_config/3","title":"AWS.SageMaker.delete_app_image_config/3","type":"function"},{"doc":"Deletes an artifact.\n\nEither `ArtifactArn` or `Source` must be specified.","ref":"AWS.SageMaker.html#delete_artifact/3","title":"AWS.SageMaker.delete_artifact/3","type":"function"},{"doc":"Deletes an association.","ref":"AWS.SageMaker.html#delete_association/3","title":"AWS.SageMaker.delete_association/3","type":"function"},{"doc":"Delete a SageMaker HyperPod cluster.","ref":"AWS.SageMaker.html#delete_cluster/3","title":"AWS.SageMaker.delete_cluster/3","type":"function"},{"doc":"Deletes the specified Git repository from your account.","ref":"AWS.SageMaker.html#delete_code_repository/3","title":"AWS.SageMaker.delete_code_repository/3","type":"function"},{"doc":"Deletes the specified compilation job.\n\nThis action deletes only the compilation job resource in Amazon SageMaker. It\ndoesn't delete other resources that are related to that job, such as the model\nartifacts that the job creates, the compilation logs in CloudWatch, the compiled\nmodel, or the IAM role.\n\nYou can delete a compilation job only if its current status is `COMPLETED`,\n`FAILED`, or `STOPPED`. If the job status is `STARTING` or `INPROGRESS`, stop\nthe job, and then delete it after its status becomes `STOPPED`.","ref":"AWS.SageMaker.html#delete_compilation_job/3","title":"AWS.SageMaker.delete_compilation_job/3","type":"function"},{"doc":"Deletes an context.","ref":"AWS.SageMaker.html#delete_context/3","title":"AWS.SageMaker.delete_context/3","type":"function"},{"doc":"Deletes a data quality monitoring job definition.","ref":"AWS.SageMaker.html#delete_data_quality_job_definition/3","title":"AWS.SageMaker.delete_data_quality_job_definition/3","type":"function"},{"doc":"Deletes a fleet.","ref":"AWS.SageMaker.html#delete_device_fleet/3","title":"AWS.SageMaker.delete_device_fleet/3","type":"function"},{"doc":"Used to delete a domain.\n\nIf you onboarded with IAM mode, you will need to delete your domain to onboard\nagain using IAM Identity Center. Use with caution. All of the members of the\ndomain will lose access to their EFS volume, including data, notebooks, and\nother artifacts.","ref":"AWS.SageMaker.html#delete_domain/3","title":"AWS.SageMaker.delete_domain/3","type":"function"},{"doc":"Deletes an edge deployment plan if (and only if) all the stages in the plan are\ninactive or there are no stages in the plan.","ref":"AWS.SageMaker.html#delete_edge_deployment_plan/3","title":"AWS.SageMaker.delete_edge_deployment_plan/3","type":"function"},{"doc":"Delete a stage in an edge deployment plan if (and only if) the stage is\ninactive.","ref":"AWS.SageMaker.html#delete_edge_deployment_stage/3","title":"AWS.SageMaker.delete_edge_deployment_stage/3","type":"function"},{"doc":"Deletes an endpoint.\n\nSageMaker frees up all of the resources that were deployed when the endpoint was\ncreated.\n\nSageMaker retires any custom KMS key grants associated with the endpoint,\nmeaning you don't need to use the\n[RevokeGrant](http://docs.aws.amazon.com/kms/latest/APIReference/API_RevokeGrant.html) API call.\n\nWhen you delete your endpoint, SageMaker asynchronously deletes associated\nendpoint resources such as KMS key grants. You might still see these resources\nin your account for a few minutes after deleting your endpoint. Do not delete or\nrevoke the permissions for your `\n[ExecutionRoleArn](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateModel.html#sagemaker-CreateModel-request-ExecutionRoleArn)\n`, otherwise SageMaker cannot delete these resources.","ref":"AWS.SageMaker.html#delete_endpoint/3","title":"AWS.SageMaker.delete_endpoint/3","type":"function"},{"doc":"Deletes an endpoint configuration.\n\nThe `DeleteEndpointConfig` API deletes only the specified configuration. It does\nnot delete endpoints created using the configuration.\n\nYou must not delete an `EndpointConfig` in use by an endpoint that is live or\nwhile the `UpdateEndpoint` or `CreateEndpoint` operations are being performed on\nthe endpoint. If you delete the `EndpointConfig` of an endpoint that is active\nor being created or updated you may lose visibility into the instance type the\nendpoint is using. The endpoint must be deleted in order to stop incurring\ncharges.","ref":"AWS.SageMaker.html#delete_endpoint_config/3","title":"AWS.SageMaker.delete_endpoint_config/3","type":"function"},{"doc":"Deletes an SageMaker experiment.\n\nAll trials associated with the experiment must be deleted first. Use the\n[ListTrials](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListTrials.html)\nAPI to get a list of the trials associated with the experiment.","ref":"AWS.SageMaker.html#delete_experiment/3","title":"AWS.SageMaker.delete_experiment/3","type":"function"},{"doc":"Delete the `FeatureGroup` and any data that was written to the `OnlineStore` of\nthe `FeatureGroup`.\n\nData cannot be accessed from the `OnlineStore` immediately after\n`DeleteFeatureGroup` is called.\n\nData written into the `OfflineStore` will not be deleted. The Amazon Web\nServices Glue database and tables that are automatically created for your\n`OfflineStore` are not deleted.\n\nNote that it can take approximately 10-15 minutes to delete an `OnlineStore`\n`FeatureGroup` with the `InMemory` `StorageType`.","ref":"AWS.SageMaker.html#delete_feature_group/3","title":"AWS.SageMaker.delete_feature_group/3","type":"function"},{"doc":"Deletes the specified flow definition.","ref":"AWS.SageMaker.html#delete_flow_definition/3","title":"AWS.SageMaker.delete_flow_definition/3","type":"function"},{"doc":"Delete a hub.\n\nHub APIs are only callable through SageMaker Studio.","ref":"AWS.SageMaker.html#delete_hub/3","title":"AWS.SageMaker.delete_hub/3","type":"function"},{"doc":"Delete the contents of a hub.\n\nHub APIs are only callable through SageMaker Studio.","ref":"AWS.SageMaker.html#delete_hub_content/3","title":"AWS.SageMaker.delete_hub_content/3","type":"function"},{"doc":"Use this operation to delete a human task user interface (worker task template).\n\nTo see a list of human task user interfaces (work task templates) in your\naccount, use\n[ListHumanTaskUis](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListHumanTaskUis.html).\nWhen you delete a worker task template, it no longer appears when you call\n`ListHumanTaskUis`.","ref":"AWS.SageMaker.html#delete_human_task_ui/3","title":"AWS.SageMaker.delete_human_task_ui/3","type":"function"},{"doc":"Deletes a hyperparameter tuning job.\n\nThe `DeleteHyperParameterTuningJob` API deletes only the tuning job entry that\nwas created in SageMaker when you called the `CreateHyperParameterTuningJob`\nAPI. It does not delete training jobs, artifacts, or the IAM role that you\nspecified when creating the model.","ref":"AWS.SageMaker.html#delete_hyper_parameter_tuning_job/3","title":"AWS.SageMaker.delete_hyper_parameter_tuning_job/3","type":"function"},{"doc":"Deletes a SageMaker image and all versions of the image.\n\nThe container images aren't deleted.","ref":"AWS.SageMaker.html#delete_image/3","title":"AWS.SageMaker.delete_image/3","type":"function"},{"doc":"Deletes a version of a SageMaker image.\n\nThe container image the version represents isn't deleted.","ref":"AWS.SageMaker.html#delete_image_version/3","title":"AWS.SageMaker.delete_image_version/3","type":"function"},{"doc":"Deletes an inference component.","ref":"AWS.SageMaker.html#delete_inference_component/3","title":"AWS.SageMaker.delete_inference_component/3","type":"function"},{"doc":"Deletes an inference experiment.\n\nThis operation does not delete your endpoint, variants, or any underlying\nresources. This operation only deletes the metadata of your experiment.","ref":"AWS.SageMaker.html#delete_inference_experiment/3","title":"AWS.SageMaker.delete_inference_experiment/3","type":"function"},{"doc":"Deletes a model.\n\nThe `DeleteModel` API deletes only the model entry that was created in SageMaker\nwhen you called the `CreateModel` API. It does not delete model artifacts,\ninference code, or the IAM role that you specified when creating the model.","ref":"AWS.SageMaker.html#delete_model/3","title":"AWS.SageMaker.delete_model/3","type":"function"},{"doc":"Deletes an Amazon SageMaker model bias job definition.","ref":"AWS.SageMaker.html#delete_model_bias_job_definition/3","title":"AWS.SageMaker.delete_model_bias_job_definition/3","type":"function"},{"doc":"Deletes an Amazon SageMaker Model Card.","ref":"AWS.SageMaker.html#delete_model_card/3","title":"AWS.SageMaker.delete_model_card/3","type":"function"},{"doc":"Deletes an Amazon SageMaker model explainability job definition.","ref":"AWS.SageMaker.html#delete_model_explainability_job_definition/3","title":"AWS.SageMaker.delete_model_explainability_job_definition/3","type":"function"},{"doc":"Deletes a model package.\n\nA model package is used to create SageMaker models or list on Amazon Web\nServices Marketplace. Buyers can subscribe to model packages listed on Amazon\nWeb Services Marketplace to create models in SageMaker.","ref":"AWS.SageMaker.html#delete_model_package/3","title":"AWS.SageMaker.delete_model_package/3","type":"function"},{"doc":"Deletes the specified model group.","ref":"AWS.SageMaker.html#delete_model_package_group/3","title":"AWS.SageMaker.delete_model_package_group/3","type":"function"},{"doc":"Deletes a model group resource policy.","ref":"AWS.SageMaker.html#delete_model_package_group_policy/3","title":"AWS.SageMaker.delete_model_package_group_policy/3","type":"function"},{"doc":"Deletes the secified model quality monitoring job definition.","ref":"AWS.SageMaker.html#delete_model_quality_job_definition/3","title":"AWS.SageMaker.delete_model_quality_job_definition/3","type":"function"},{"doc":"Deletes a monitoring schedule.\n\nAlso stops the schedule had not already been stopped. This does not delete the\njob execution history of the monitoring schedule.","ref":"AWS.SageMaker.html#delete_monitoring_schedule/3","title":"AWS.SageMaker.delete_monitoring_schedule/3","type":"function"},{"doc":"Deletes an SageMaker notebook instance.\n\nBefore you can delete a notebook instance, you must call the\n`StopNotebookInstance` API.\n\nWhen you delete a notebook instance, you lose all of your data. SageMaker\nremoves the ML compute instance, and deletes the ML storage volume and the\nnetwork interface associated with the notebook instance.","ref":"AWS.SageMaker.html#delete_notebook_instance/3","title":"AWS.SageMaker.delete_notebook_instance/3","type":"function"},{"doc":"Deletes a notebook instance lifecycle configuration.","ref":"AWS.SageMaker.html#delete_notebook_instance_lifecycle_config/3","title":"AWS.SageMaker.delete_notebook_instance_lifecycle_config/3","type":"function"},{"doc":"Deletes a pipeline if there are no running instances of the pipeline.\n\nTo delete a pipeline, you must stop all running instances of the pipeline using\nthe `StopPipelineExecution` API. When you delete a pipeline, all instances of\nthe pipeline are deleted.","ref":"AWS.SageMaker.html#delete_pipeline/3","title":"AWS.SageMaker.delete_pipeline/3","type":"function"},{"doc":"Delete the specified project.","ref":"AWS.SageMaker.html#delete_project/3","title":"AWS.SageMaker.delete_project/3","type":"function"},{"doc":"Used to delete a space.","ref":"AWS.SageMaker.html#delete_space/3","title":"AWS.SageMaker.delete_space/3","type":"function"},{"doc":"Deletes the Amazon SageMaker Studio Lifecycle Configuration.\n\nIn order to delete the Lifecycle Configuration, there must be no running apps\nusing the Lifecycle Configuration. You must also remove the Lifecycle\nConfiguration from UserSettings in all Domains and UserProfiles.","ref":"AWS.SageMaker.html#delete_studio_lifecycle_config/3","title":"AWS.SageMaker.delete_studio_lifecycle_config/3","type":"function"},{"doc":"Deletes the specified tags from an SageMaker resource.\n\nTo list a resource's tags, use the `ListTags` API.\n\nWhen you call this API to delete tags from a hyperparameter tuning job, the\ndeleted tags are not removed from training jobs that the hyperparameter tuning\njob launched before you called this API.\n\nWhen you call this API to delete tags from a SageMaker Domain or User Profile,\nthe deleted tags are not removed from Apps that the SageMaker Domain or User\nProfile launched before you called this API.","ref":"AWS.SageMaker.html#delete_tags/3","title":"AWS.SageMaker.delete_tags/3","type":"function"},{"doc":"Deletes the specified trial.\n\nAll trial components that make up the trial must be deleted first. Use the\n[DescribeTrialComponent](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeTrialComponent.html)\nAPI to get the list of trial components.","ref":"AWS.SageMaker.html#delete_trial/3","title":"AWS.SageMaker.delete_trial/3","type":"function"},{"doc":"Deletes the specified trial component.\n\nA trial component must be disassociated from all trials before the trial\ncomponent can be deleted. To disassociate a trial component from a trial, call\nthe\n[DisassociateTrialComponent](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DisassociateTrialComponent.html)\nAPI.","ref":"AWS.SageMaker.html#delete_trial_component/3","title":"AWS.SageMaker.delete_trial_component/3","type":"function"},{"doc":"Deletes a user profile.\n\nWhen a user profile is deleted, the user loses access to their EFS volume,\nincluding data, notebooks, and other artifacts.","ref":"AWS.SageMaker.html#delete_user_profile/3","title":"AWS.SageMaker.delete_user_profile/3","type":"function"},{"doc":"Use this operation to delete a workforce.\n\nIf you want to create a new workforce in an Amazon Web Services Region where a\nworkforce already exists, use this operation to delete the existing workforce\nand then use\n[CreateWorkforce](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateWorkforce.html) to create a new workforce.\n\nIf a private workforce contains one or more work teams, you must use the\n[DeleteWorkteam](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteWorkteam.html)\noperation to delete all work teams before you delete the workforce. If you try\nto delete a workforce that contains one or more work teams, you will recieve a\n`ResourceInUse` error.","ref":"AWS.SageMaker.html#delete_workforce/3","title":"AWS.SageMaker.delete_workforce/3","type":"function"},{"doc":"Deletes an existing work team.\n\nThis operation can't be undone.","ref":"AWS.SageMaker.html#delete_workteam/3","title":"AWS.SageMaker.delete_workteam/3","type":"function"},{"doc":"Deregisters the specified devices.\n\nAfter you deregister a device, you will need to re-register the devices.","ref":"AWS.SageMaker.html#deregister_devices/3","title":"AWS.SageMaker.deregister_devices/3","type":"function"},{"doc":"Describes an action.","ref":"AWS.SageMaker.html#describe_action/3","title":"AWS.SageMaker.describe_action/3","type":"function"},{"doc":"Returns a description of the specified algorithm that is in your account.","ref":"AWS.SageMaker.html#describe_algorithm/3","title":"AWS.SageMaker.describe_algorithm/3","type":"function"},{"doc":"Describes the app.","ref":"AWS.SageMaker.html#describe_app/3","title":"AWS.SageMaker.describe_app/3","type":"function"},{"doc":"Describes an AppImageConfig.","ref":"AWS.SageMaker.html#describe_app_image_config/3","title":"AWS.SageMaker.describe_app_image_config/3","type":"function"},{"doc":"Describes an artifact.","ref":"AWS.SageMaker.html#describe_artifact/3","title":"AWS.SageMaker.describe_artifact/3","type":"function"},{"doc":"Returns information about an AutoML job created by calling\n[CreateAutoMLJob](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateAutoMLJob.html).   AutoML jobs created by calling\n[CreateAutoMLJobV2](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateAutoMLJobV2.html)\ncannot be described by `DescribeAutoMLJob`.","ref":"AWS.SageMaker.html#describe_auto_ml_job/3","title":"AWS.SageMaker.describe_auto_ml_job/3","type":"function"},{"doc":"Returns information about an AutoML job created by calling\n[CreateAutoMLJobV2](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateAutoMLJobV2.html) or\n[CreateAutoMLJob](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateAutoMLJob.html).","ref":"AWS.SageMaker.html#describe_auto_ml_job_v2/3","title":"AWS.SageMaker.describe_auto_ml_job_v2/3","type":"function"},{"doc":"Retrieves information of a SageMaker HyperPod cluster.","ref":"AWS.SageMaker.html#describe_cluster/3","title":"AWS.SageMaker.describe_cluster/3","type":"function"},{"doc":"Retrieves information of an instance (also called a *node* interchangeably) of a\nSageMaker HyperPod cluster.","ref":"AWS.SageMaker.html#describe_cluster_node/3","title":"AWS.SageMaker.describe_cluster_node/3","type":"function"},{"doc":"Gets details about the specified Git repository.","ref":"AWS.SageMaker.html#describe_code_repository/3","title":"AWS.SageMaker.describe_code_repository/3","type":"function"},{"doc":"Returns information about a model compilation job.\n\nTo create a model compilation job, use\n[CreateCompilationJob](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateCompilationJob.html). To get information about multiple model compilation jobs, use\n[ListCompilationJobs](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListCompilationJobs.html).","ref":"AWS.SageMaker.html#describe_compilation_job/3","title":"AWS.SageMaker.describe_compilation_job/3","type":"function"},{"doc":"Describes a context.","ref":"AWS.SageMaker.html#describe_context/3","title":"AWS.SageMaker.describe_context/3","type":"function"},{"doc":"Gets the details of a data quality monitoring job definition.","ref":"AWS.SageMaker.html#describe_data_quality_job_definition/3","title":"AWS.SageMaker.describe_data_quality_job_definition/3","type":"function"},{"doc":"Describes the device.","ref":"AWS.SageMaker.html#describe_device/3","title":"AWS.SageMaker.describe_device/3","type":"function"},{"doc":"A description of the fleet the device belongs to.","ref":"AWS.SageMaker.html#describe_device_fleet/3","title":"AWS.SageMaker.describe_device_fleet/3","type":"function"},{"doc":"The description of the domain.","ref":"AWS.SageMaker.html#describe_domain/3","title":"AWS.SageMaker.describe_domain/3","type":"function"},{"doc":"Describes an edge deployment plan with deployment status per stage.","ref":"AWS.SageMaker.html#describe_edge_deployment_plan/3","title":"AWS.SageMaker.describe_edge_deployment_plan/3","type":"function"},{"doc":"A description of edge packaging jobs.","ref":"AWS.SageMaker.html#describe_edge_packaging_job/3","title":"AWS.SageMaker.describe_edge_packaging_job/3","type":"function"},{"doc":"Returns the description of an endpoint.","ref":"AWS.SageMaker.html#describe_endpoint/3","title":"AWS.SageMaker.describe_endpoint/3","type":"function"},{"doc":"Returns the description of an endpoint configuration created using the\n`CreateEndpointConfig` API.","ref":"AWS.SageMaker.html#describe_endpoint_config/3","title":"AWS.SageMaker.describe_endpoint_config/3","type":"function"},{"doc":"Provides a list of an experiment's properties.","ref":"AWS.SageMaker.html#describe_experiment/3","title":"AWS.SageMaker.describe_experiment/3","type":"function"},{"doc":"Use this operation to describe a `FeatureGroup`.\n\nThe response includes information on the creation time, `FeatureGroup` name, the\nunique identifier for each `FeatureGroup`, and more.","ref":"AWS.SageMaker.html#describe_feature_group/3","title":"AWS.SageMaker.describe_feature_group/3","type":"function"},{"doc":"Shows the metadata for a feature within a feature group.","ref":"AWS.SageMaker.html#describe_feature_metadata/3","title":"AWS.SageMaker.describe_feature_metadata/3","type":"function"},{"doc":"Returns information about the specified flow definition.","ref":"AWS.SageMaker.html#describe_flow_definition/3","title":"AWS.SageMaker.describe_flow_definition/3","type":"function"},{"doc":"Describe a hub.\n\nHub APIs are only callable through SageMaker Studio.","ref":"AWS.SageMaker.html#describe_hub/3","title":"AWS.SageMaker.describe_hub/3","type":"function"},{"doc":"Describe the content of a hub.\n\nHub APIs are only callable through SageMaker Studio.","ref":"AWS.SageMaker.html#describe_hub_content/3","title":"AWS.SageMaker.describe_hub_content/3","type":"function"},{"doc":"Returns information about the requested human task user interface (worker task\ntemplate).","ref":"AWS.SageMaker.html#describe_human_task_ui/3","title":"AWS.SageMaker.describe_human_task_ui/3","type":"function"},{"doc":"Returns a description of a hyperparameter tuning job, depending on the fields\nselected.\n\nThese fields can include the name, Amazon Resource Name (ARN), job status of\nyour tuning job and more.","ref":"AWS.SageMaker.html#describe_hyper_parameter_tuning_job/3","title":"AWS.SageMaker.describe_hyper_parameter_tuning_job/3","type":"function"},{"doc":"Describes a SageMaker image.","ref":"AWS.SageMaker.html#describe_image/3","title":"AWS.SageMaker.describe_image/3","type":"function"},{"doc":"Describes a version of a SageMaker image.","ref":"AWS.SageMaker.html#describe_image_version/3","title":"AWS.SageMaker.describe_image_version/3","type":"function"},{"doc":"Returns information about an inference component.","ref":"AWS.SageMaker.html#describe_inference_component/3","title":"AWS.SageMaker.describe_inference_component/3","type":"function"},{"doc":"Returns details about an inference experiment.","ref":"AWS.SageMaker.html#describe_inference_experiment/3","title":"AWS.SageMaker.describe_inference_experiment/3","type":"function"},{"doc":"Provides the results of the Inference Recommender job.\n\nOne or more recommendation jobs are returned.","ref":"AWS.SageMaker.html#describe_inference_recommendations_job/3","title":"AWS.SageMaker.describe_inference_recommendations_job/3","type":"function"},{"doc":"Gets information about a labeling job.","ref":"AWS.SageMaker.html#describe_labeling_job/3","title":"AWS.SageMaker.describe_labeling_job/3","type":"function"},{"doc":"Provides a list of properties for the requested lineage group.\n\nFor more information, see [ Cross-Account Lineage Tracking\n](https://docs.aws.amazon.com/sagemaker/latest/dg/xaccount-lineage-tracking.html)\nin the *Amazon SageMaker Developer Guide*.","ref":"AWS.SageMaker.html#describe_lineage_group/3","title":"AWS.SageMaker.describe_lineage_group/3","type":"function"},{"doc":"Describes a model that you created using the `CreateModel` API.","ref":"AWS.SageMaker.html#describe_model/3","title":"AWS.SageMaker.describe_model/3","type":"function"},{"doc":"Returns a description of a model bias job definition.","ref":"AWS.SageMaker.html#describe_model_bias_job_definition/3","title":"AWS.SageMaker.describe_model_bias_job_definition/3","type":"function"},{"doc":"Describes the content, creation time, and security configuration of an Amazon\nSageMaker Model Card.","ref":"AWS.SageMaker.html#describe_model_card/3","title":"AWS.SageMaker.describe_model_card/3","type":"function"},{"doc":"Describes an Amazon SageMaker Model Card export job.","ref":"AWS.SageMaker.html#describe_model_card_export_job/3","title":"AWS.SageMaker.describe_model_card_export_job/3","type":"function"},{"doc":"Returns a description of a model explainability job definition.","ref":"AWS.SageMaker.html#describe_model_explainability_job_definition/3","title":"AWS.SageMaker.describe_model_explainability_job_definition/3","type":"function"},{"doc":"Returns a description of the specified model package, which is used to create\nSageMaker models or list them on Amazon Web Services Marketplace.\n\nTo create models in SageMaker, buyers can subscribe to model packages listed on\nAmazon Web Services Marketplace.","ref":"AWS.SageMaker.html#describe_model_package/3","title":"AWS.SageMaker.describe_model_package/3","type":"function"},{"doc":"Gets a description for the specified model group.","ref":"AWS.SageMaker.html#describe_model_package_group/3","title":"AWS.SageMaker.describe_model_package_group/3","type":"function"},{"doc":"Returns a description of a model quality job definition.","ref":"AWS.SageMaker.html#describe_model_quality_job_definition/3","title":"AWS.SageMaker.describe_model_quality_job_definition/3","type":"function"},{"doc":"Describes the schedule for a monitoring job.","ref":"AWS.SageMaker.html#describe_monitoring_schedule/3","title":"AWS.SageMaker.describe_monitoring_schedule/3","type":"function"},{"doc":"Returns information about a notebook instance.","ref":"AWS.SageMaker.html#describe_notebook_instance/3","title":"AWS.SageMaker.describe_notebook_instance/3","type":"function"},{"doc":"Returns a description of a notebook instance lifecycle configuration.\n\nFor information about notebook instance lifestyle configurations, see [Step 2.1: (Optional) Customize a Notebook\nInstance](https://docs.aws.amazon.com/sagemaker/latest/dg/notebook-lifecycle-config.html).","ref":"AWS.SageMaker.html#describe_notebook_instance_lifecycle_config/3","title":"AWS.SageMaker.describe_notebook_instance_lifecycle_config/3","type":"function"},{"doc":"Describes the details of a pipeline.","ref":"AWS.SageMaker.html#describe_pipeline/3","title":"AWS.SageMaker.describe_pipeline/3","type":"function"},{"doc":"Describes the details of an execution's pipeline definition.","ref":"AWS.SageMaker.html#describe_pipeline_definition_for_execution/3","title":"AWS.SageMaker.describe_pipeline_definition_for_execution/3","type":"function"},{"doc":"Describes the details of a pipeline execution.","ref":"AWS.SageMaker.html#describe_pipeline_execution/3","title":"AWS.SageMaker.describe_pipeline_execution/3","type":"function"},{"doc":"Returns a description of a processing job.","ref":"AWS.SageMaker.html#describe_processing_job/3","title":"AWS.SageMaker.describe_processing_job/3","type":"function"},{"doc":"Describes the details of a project.","ref":"AWS.SageMaker.html#describe_project/3","title":"AWS.SageMaker.describe_project/3","type":"function"},{"doc":"Describes the space.","ref":"AWS.SageMaker.html#describe_space/3","title":"AWS.SageMaker.describe_space/3","type":"function"},{"doc":"Describes the Amazon SageMaker Studio Lifecycle Configuration.","ref":"AWS.SageMaker.html#describe_studio_lifecycle_config/3","title":"AWS.SageMaker.describe_studio_lifecycle_config/3","type":"function"},{"doc":"Gets information about a work team provided by a vendor.\n\nIt returns details about the subscription with a vendor in the Amazon Web\nServices Marketplace.","ref":"AWS.SageMaker.html#describe_subscribed_workteam/3","title":"AWS.SageMaker.describe_subscribed_workteam/3","type":"function"},{"doc":"Returns information about a training job.\n\nSome of the attributes below only appear if the training job successfully\nstarts. If the training job fails, `TrainingJobStatus` is `Failed` and,\ndepending on the `FailureReason`, attributes like `TrainingStartTime`,\n`TrainingTimeInSeconds`, `TrainingEndTime`, and `BillableTimeInSeconds` may not\nbe present in the response.","ref":"AWS.SageMaker.html#describe_training_job/3","title":"AWS.SageMaker.describe_training_job/3","type":"function"},{"doc":"Returns information about a transform job.","ref":"AWS.SageMaker.html#describe_transform_job/3","title":"AWS.SageMaker.describe_transform_job/3","type":"function"},{"doc":"Provides a list of a trial's properties.","ref":"AWS.SageMaker.html#describe_trial/3","title":"AWS.SageMaker.describe_trial/3","type":"function"},{"doc":"Provides a list of a trials component's properties.","ref":"AWS.SageMaker.html#describe_trial_component/3","title":"AWS.SageMaker.describe_trial_component/3","type":"function"},{"doc":"Describes a user profile.\n\nFor more information, see `CreateUserProfile`.","ref":"AWS.SageMaker.html#describe_user_profile/3","title":"AWS.SageMaker.describe_user_profile/3","type":"function"},{"doc":"Lists private workforce information, including workforce name, Amazon Resource\nName (ARN), and, if applicable, allowed IP address ranges\n([CIDRs](https://docs.aws.amazon.com/vpc/latest/userguide/VPC_Subnets.html)).\n\nAllowable IP address ranges are the IP addresses that workers can use to access\ntasks.\n\nThis operation applies only to private workforces.","ref":"AWS.SageMaker.html#describe_workforce/3","title":"AWS.SageMaker.describe_workforce/3","type":"function"},{"doc":"Gets information about a specific work team.\n\nYou can see information such as the create date, the last updated date,\nmembership information, and the work team's Amazon Resource Name (ARN).","ref":"AWS.SageMaker.html#describe_workteam/3","title":"AWS.SageMaker.describe_workteam/3","type":"function"},{"doc":"Disables using Service Catalog in SageMaker.\n\nService Catalog is used to create SageMaker projects.","ref":"AWS.SageMaker.html#disable_sagemaker_servicecatalog_portfolio/3","title":"AWS.SageMaker.disable_sagemaker_servicecatalog_portfolio/3","type":"function"},{"doc":"Disassociates a trial component from a trial.\n\nThis doesn't effect other trials the component is associated with. Before you\ncan delete a component, you must disassociate the component from all trials it\nis associated with. To associate a trial component with a trial, call the\n[AssociateTrialComponent](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_AssociateTrialComponent.html) API.\n\nTo get a list of the trials a component is associated with, use the\n[Search](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_Search.html)\nAPI. Specify `ExperimentTrialComponent` for the `Resource` parameter. The list\nappears in the response under `Results.TrialComponent.Parents`.","ref":"AWS.SageMaker.html#disassociate_trial_component/3","title":"AWS.SageMaker.disassociate_trial_component/3","type":"function"},{"doc":"Enables using Service Catalog in SageMaker.\n\nService Catalog is used to create SageMaker projects.","ref":"AWS.SageMaker.html#enable_sagemaker_servicecatalog_portfolio/3","title":"AWS.SageMaker.enable_sagemaker_servicecatalog_portfolio/3","type":"function"},{"doc":"Describes a fleet.","ref":"AWS.SageMaker.html#get_device_fleet_report/3","title":"AWS.SageMaker.get_device_fleet_report/3","type":"function"},{"doc":"The resource policy for the lineage group.","ref":"AWS.SageMaker.html#get_lineage_group_policy/3","title":"AWS.SageMaker.get_lineage_group_policy/3","type":"function"},{"doc":"Gets a resource policy that manages access for a model group.\n\nFor information about resource policies, see [Identity-based policies and resource-based\npolicies](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_identity-vs-resource.html)\nin the *Amazon Web Services Identity and Access Management User Guide.*.","ref":"AWS.SageMaker.html#get_model_package_group_policy/3","title":"AWS.SageMaker.get_model_package_group_policy/3","type":"function"},{"doc":"Gets the status of Service Catalog in SageMaker.\n\nService Catalog is used to create SageMaker projects.","ref":"AWS.SageMaker.html#get_sagemaker_servicecatalog_portfolio_status/3","title":"AWS.SageMaker.get_sagemaker_servicecatalog_portfolio_status/3","type":"function"},{"doc":"Starts an Amazon SageMaker Inference Recommender autoscaling recommendation job.\n\nReturns recommendations for autoscaling policies that you can apply to your\nSageMaker endpoint.","ref":"AWS.SageMaker.html#get_scaling_configuration_recommendation/3","title":"AWS.SageMaker.get_scaling_configuration_recommendation/3","type":"function"},{"doc":"An auto-complete API for the search functionality in the SageMaker console.\n\nIt returns suggestions of possible matches for the property name to use in\n`Search` queries. Provides suggestions for `HyperParameters`, `Tags`, and\n`Metrics`.","ref":"AWS.SageMaker.html#get_search_suggestions/3","title":"AWS.SageMaker.get_search_suggestions/3","type":"function"},{"doc":"Import hub content.\n\nHub APIs are only callable through SageMaker Studio.","ref":"AWS.SageMaker.html#import_hub_content/3","title":"AWS.SageMaker.import_hub_content/3","type":"function"},{"doc":"Lists the actions in your account and their properties.","ref":"AWS.SageMaker.html#list_actions/3","title":"AWS.SageMaker.list_actions/3","type":"function"},{"doc":"Lists the machine learning algorithms that have been created.","ref":"AWS.SageMaker.html#list_algorithms/3","title":"AWS.SageMaker.list_algorithms/3","type":"function"},{"doc":"Lists the aliases of a specified image or image version.","ref":"AWS.SageMaker.html#list_aliases/3","title":"AWS.SageMaker.list_aliases/3","type":"function"},{"doc":"Lists the AppImageConfigs in your account and their properties.\n\nThe list can be filtered by creation time or modified time, and whether the\nAppImageConfig name contains a specified string.","ref":"AWS.SageMaker.html#list_app_image_configs/3","title":"AWS.SageMaker.list_app_image_configs/3","type":"function"},{"doc":"Lists apps.","ref":"AWS.SageMaker.html#list_apps/3","title":"AWS.SageMaker.list_apps/3","type":"function"},{"doc":"Lists the artifacts in your account and their properties.","ref":"AWS.SageMaker.html#list_artifacts/3","title":"AWS.SageMaker.list_artifacts/3","type":"function"},{"doc":"Lists the associations in your account and their properties.","ref":"AWS.SageMaker.html#list_associations/3","title":"AWS.SageMaker.list_associations/3","type":"function"},{"doc":"Request a list of jobs.","ref":"AWS.SageMaker.html#list_auto_ml_jobs/3","title":"AWS.SageMaker.list_auto_ml_jobs/3","type":"function"},{"doc":"List the candidates created for the job.","ref":"AWS.SageMaker.html#list_candidates_for_auto_ml_job/3","title":"AWS.SageMaker.list_candidates_for_auto_ml_job/3","type":"function"},{"doc":"Retrieves the list of instances (also called *nodes* interchangeably) in a\nSageMaker HyperPod cluster.","ref":"AWS.SageMaker.html#list_cluster_nodes/3","title":"AWS.SageMaker.list_cluster_nodes/3","type":"function"},{"doc":"Retrieves the list of SageMaker HyperPod clusters.","ref":"AWS.SageMaker.html#list_clusters/3","title":"AWS.SageMaker.list_clusters/3","type":"function"},{"doc":"Gets a list of the Git repositories in your account.","ref":"AWS.SageMaker.html#list_code_repositories/3","title":"AWS.SageMaker.list_code_repositories/3","type":"function"},{"doc":"Lists model compilation jobs that satisfy various filters.\n\nTo create a model compilation job, use\n[CreateCompilationJob](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateCompilationJob.html). To get information about a particular model compilation job you have created,\nuse\n[DescribeCompilationJob](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeCompilationJob.html).","ref":"AWS.SageMaker.html#list_compilation_jobs/3","title":"AWS.SageMaker.list_compilation_jobs/3","type":"function"},{"doc":"Lists the contexts in your account and their properties.","ref":"AWS.SageMaker.html#list_contexts/3","title":"AWS.SageMaker.list_contexts/3","type":"function"},{"doc":"Lists the data quality job definitions in your account.","ref":"AWS.SageMaker.html#list_data_quality_job_definitions/3","title":"AWS.SageMaker.list_data_quality_job_definitions/3","type":"function"},{"doc":"Returns a list of devices in the fleet.","ref":"AWS.SageMaker.html#list_device_fleets/3","title":"AWS.SageMaker.list_device_fleets/3","type":"function"},{"doc":"A list of devices.","ref":"AWS.SageMaker.html#list_devices/3","title":"AWS.SageMaker.list_devices/3","type":"function"},{"doc":"Lists the domains.","ref":"AWS.SageMaker.html#list_domains/3","title":"AWS.SageMaker.list_domains/3","type":"function"},{"doc":"Lists all edge deployment plans.","ref":"AWS.SageMaker.html#list_edge_deployment_plans/3","title":"AWS.SageMaker.list_edge_deployment_plans/3","type":"function"},{"doc":"Returns a list of edge packaging jobs.","ref":"AWS.SageMaker.html#list_edge_packaging_jobs/3","title":"AWS.SageMaker.list_edge_packaging_jobs/3","type":"function"},{"doc":"Lists endpoint configurations.","ref":"AWS.SageMaker.html#list_endpoint_configs/3","title":"AWS.SageMaker.list_endpoint_configs/3","type":"function"},{"doc":"Lists endpoints.","ref":"AWS.SageMaker.html#list_endpoints/3","title":"AWS.SageMaker.list_endpoints/3","type":"function"},{"doc":"Lists all the experiments in your account.\n\nThe list can be filtered to show only experiments that were created in a\nspecific time range. The list can be sorted by experiment name or creation time.","ref":"AWS.SageMaker.html#list_experiments/3","title":"AWS.SageMaker.list_experiments/3","type":"function"},{"doc":"List `FeatureGroup`s based on given filter and order.","ref":"AWS.SageMaker.html#list_feature_groups/3","title":"AWS.SageMaker.list_feature_groups/3","type":"function"},{"doc":"Returns information about the flow definitions in your account.","ref":"AWS.SageMaker.html#list_flow_definitions/3","title":"AWS.SageMaker.list_flow_definitions/3","type":"function"},{"doc":"List hub content versions.\n\nHub APIs are only callable through SageMaker Studio.","ref":"AWS.SageMaker.html#list_hub_content_versions/3","title":"AWS.SageMaker.list_hub_content_versions/3","type":"function"},{"doc":"List the contents of a hub.\n\nHub APIs are only callable through SageMaker Studio.","ref":"AWS.SageMaker.html#list_hub_contents/3","title":"AWS.SageMaker.list_hub_contents/3","type":"function"},{"doc":"List all existing hubs.\n\nHub APIs are only callable through SageMaker Studio.","ref":"AWS.SageMaker.html#list_hubs/3","title":"AWS.SageMaker.list_hubs/3","type":"function"},{"doc":"Returns information about the human task user interfaces in your account.","ref":"AWS.SageMaker.html#list_human_task_uis/3","title":"AWS.SageMaker.list_human_task_uis/3","type":"function"},{"doc":"Gets a list of\n[HyperParameterTuningJobSummary](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_HyperParameterTuningJobSummary.html)\nobjects that describe the hyperparameter tuning jobs launched in your account.","ref":"AWS.SageMaker.html#list_hyper_parameter_tuning_jobs/3","title":"AWS.SageMaker.list_hyper_parameter_tuning_jobs/3","type":"function"},{"doc":"Lists the versions of a specified image and their properties.\n\nThe list can be filtered by creation time or modified time.","ref":"AWS.SageMaker.html#list_image_versions/3","title":"AWS.SageMaker.list_image_versions/3","type":"function"},{"doc":"Lists the images in your account and their properties.\n\nThe list can be filtered by creation time or modified time, and whether the\nimage name contains a specified string.","ref":"AWS.SageMaker.html#list_images/3","title":"AWS.SageMaker.list_images/3","type":"function"},{"doc":"Lists the inference components in your account and their properties.","ref":"AWS.SageMaker.html#list_inference_components/3","title":"AWS.SageMaker.list_inference_components/3","type":"function"},{"doc":"Returns the list of all inference experiments.","ref":"AWS.SageMaker.html#list_inference_experiments/3","title":"AWS.SageMaker.list_inference_experiments/3","type":"function"},{"doc":"Returns a list of the subtasks for an Inference Recommender job.\n\nThe supported subtasks are benchmarks, which evaluate the performance of your\nmodel on different instance types.","ref":"AWS.SageMaker.html#list_inference_recommendations_job_steps/3","title":"AWS.SageMaker.list_inference_recommendations_job_steps/3","type":"function"},{"doc":"Lists recommendation jobs that satisfy various filters.","ref":"AWS.SageMaker.html#list_inference_recommendations_jobs/3","title":"AWS.SageMaker.list_inference_recommendations_jobs/3","type":"function"},{"doc":"Gets a list of labeling jobs.","ref":"AWS.SageMaker.html#list_labeling_jobs/3","title":"AWS.SageMaker.list_labeling_jobs/3","type":"function"},{"doc":"Gets a list of labeling jobs assigned to a specified work team.","ref":"AWS.SageMaker.html#list_labeling_jobs_for_workteam/3","title":"AWS.SageMaker.list_labeling_jobs_for_workteam/3","type":"function"},{"doc":"A list of lineage groups shared with your Amazon Web Services account.\n\nFor more information, see [ Cross-Account Lineage Tracking\n](https://docs.aws.amazon.com/sagemaker/latest/dg/xaccount-lineage-tracking.html)\nin the *Amazon SageMaker Developer Guide*.","ref":"AWS.SageMaker.html#list_lineage_groups/3","title":"AWS.SageMaker.list_lineage_groups/3","type":"function"},{"doc":"Lists model bias jobs definitions that satisfy various filters.","ref":"AWS.SageMaker.html#list_model_bias_job_definitions/3","title":"AWS.SageMaker.list_model_bias_job_definitions/3","type":"function"},{"doc":"List the export jobs for the Amazon SageMaker Model Card.","ref":"AWS.SageMaker.html#list_model_card_export_jobs/3","title":"AWS.SageMaker.list_model_card_export_jobs/3","type":"function"},{"doc":"List existing versions of an Amazon SageMaker Model Card.","ref":"AWS.SageMaker.html#list_model_card_versions/3","title":"AWS.SageMaker.list_model_card_versions/3","type":"function"},{"doc":"List existing model cards.","ref":"AWS.SageMaker.html#list_model_cards/3","title":"AWS.SageMaker.list_model_cards/3","type":"function"},{"doc":"Lists model explainability job definitions that satisfy various filters.","ref":"AWS.SageMaker.html#list_model_explainability_job_definitions/3","title":"AWS.SageMaker.list_model_explainability_job_definitions/3","type":"function"},{"doc":"Lists the domain, framework, task, and model name of standard machine learning\nmodels found in common model zoos.","ref":"AWS.SageMaker.html#list_model_metadata/3","title":"AWS.SageMaker.list_model_metadata/3","type":"function"},{"doc":"Gets a list of the model groups in your Amazon Web Services account.","ref":"AWS.SageMaker.html#list_model_package_groups/3","title":"AWS.SageMaker.list_model_package_groups/3","type":"function"},{"doc":"Lists the model packages that have been created.","ref":"AWS.SageMaker.html#list_model_packages/3","title":"AWS.SageMaker.list_model_packages/3","type":"function"},{"doc":"Gets a list of model quality monitoring job definitions in your account.","ref":"AWS.SageMaker.html#list_model_quality_job_definitions/3","title":"AWS.SageMaker.list_model_quality_job_definitions/3","type":"function"},{"doc":"Lists models created with the `CreateModel` API.","ref":"AWS.SageMaker.html#list_models/3","title":"AWS.SageMaker.list_models/3","type":"function"},{"doc":"Gets a list of past alerts in a model monitoring schedule.","ref":"AWS.SageMaker.html#list_monitoring_alert_history/3","title":"AWS.SageMaker.list_monitoring_alert_history/3","type":"function"},{"doc":"Gets the alerts for a single monitoring schedule.","ref":"AWS.SageMaker.html#list_monitoring_alerts/3","title":"AWS.SageMaker.list_monitoring_alerts/3","type":"function"},{"doc":"Returns list of all monitoring job executions.","ref":"AWS.SageMaker.html#list_monitoring_executions/3","title":"AWS.SageMaker.list_monitoring_executions/3","type":"function"},{"doc":"Returns list of all monitoring schedules.","ref":"AWS.SageMaker.html#list_monitoring_schedules/3","title":"AWS.SageMaker.list_monitoring_schedules/3","type":"function"},{"doc":"Lists notebook instance lifestyle configurations created with the\n[CreateNotebookInstanceLifecycleConfig](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateNotebookInstanceLifecycleConfig.html)\nAPI.","ref":"AWS.SageMaker.html#list_notebook_instance_lifecycle_configs/3","title":"AWS.SageMaker.list_notebook_instance_lifecycle_configs/3","type":"function"},{"doc":"Returns a list of the SageMaker notebook instances in the requester's account in\nan Amazon Web Services Region.","ref":"AWS.SageMaker.html#list_notebook_instances/3","title":"AWS.SageMaker.list_notebook_instances/3","type":"function"},{"doc":"Gets a list of `PipeLineExecutionStep` objects.","ref":"AWS.SageMaker.html#list_pipeline_execution_steps/3","title":"AWS.SageMaker.list_pipeline_execution_steps/3","type":"function"},{"doc":"Gets a list of the pipeline executions.","ref":"AWS.SageMaker.html#list_pipeline_executions/3","title":"AWS.SageMaker.list_pipeline_executions/3","type":"function"},{"doc":"Gets a list of parameters for a pipeline execution.","ref":"AWS.SageMaker.html#list_pipeline_parameters_for_execution/3","title":"AWS.SageMaker.list_pipeline_parameters_for_execution/3","type":"function"},{"doc":"Gets a list of pipelines.","ref":"AWS.SageMaker.html#list_pipelines/3","title":"AWS.SageMaker.list_pipelines/3","type":"function"},{"doc":"Lists processing jobs that satisfy various filters.","ref":"AWS.SageMaker.html#list_processing_jobs/3","title":"AWS.SageMaker.list_processing_jobs/3","type":"function"},{"doc":"Gets a list of the projects in an Amazon Web Services account.","ref":"AWS.SageMaker.html#list_projects/3","title":"AWS.SageMaker.list_projects/3","type":"function"},{"doc":"Lists Amazon SageMaker Catalogs based on given filters and orders.\n\nThe maximum number of `ResourceCatalog`s viewable is 1000.","ref":"AWS.SageMaker.html#list_resource_catalogs/3","title":"AWS.SageMaker.list_resource_catalogs/3","type":"function"},{"doc":"Lists spaces.","ref":"AWS.SageMaker.html#list_spaces/3","title":"AWS.SageMaker.list_spaces/3","type":"function"},{"doc":"Lists devices allocated to the stage, containing detailed device information and\ndeployment status.","ref":"AWS.SageMaker.html#list_stage_devices/3","title":"AWS.SageMaker.list_stage_devices/3","type":"function"},{"doc":"Lists the Amazon SageMaker Studio Lifecycle Configurations in your Amazon Web\nServices Account.","ref":"AWS.SageMaker.html#list_studio_lifecycle_configs/3","title":"AWS.SageMaker.list_studio_lifecycle_configs/3","type":"function"},{"doc":"Gets a list of the work teams that you are subscribed to in the Amazon Web\nServices Marketplace.\n\nThe list may be empty if no work team satisfies the filter specified in the\n`NameContains` parameter.","ref":"AWS.SageMaker.html#list_subscribed_workteams/3","title":"AWS.SageMaker.list_subscribed_workteams/3","type":"function"},{"doc":"Returns the tags for the specified SageMaker resource.","ref":"AWS.SageMaker.html#list_tags/3","title":"AWS.SageMaker.list_tags/3","type":"function"},{"doc":"Lists training jobs.\n\nWhen `StatusEquals` and `MaxResults` are set at the same time, the `MaxResults`\nnumber of training jobs are first retrieved ignoring the `StatusEquals`\nparameter and then they are filtered by the `StatusEquals` parameter, which is\nreturned as a response.\n\nFor example, if `ListTrainingJobs` is invoked with the following parameters:\n\n`{ ... MaxResults: 100, StatusEquals: InProgress ... }`\n\nFirst, 100 trainings jobs with any status, including those other than\n`InProgress`, are selected (sorted according to the creation time, from the most\ncurrent to the oldest). Next, those with a status of `InProgress` are returned.\n\nYou can quickly test the API using the following Amazon Web Services CLI code.\n\n`aws sagemaker list-training-jobs --max-results 100 --status-equals InProgress`","ref":"AWS.SageMaker.html#list_training_jobs/3","title":"AWS.SageMaker.list_training_jobs/3","type":"function"},{"doc":"Gets a list of\n[TrainingJobSummary](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_TrainingJobSummary.html)\nobjects that describe the training jobs that a hyperparameter tuning job\nlaunched.","ref":"AWS.SageMaker.html#list_training_jobs_for_hyper_parameter_tuning_job/3","title":"AWS.SageMaker.list_training_jobs_for_hyper_parameter_tuning_job/3","type":"function"},{"doc":"Lists transform jobs.","ref":"AWS.SageMaker.html#list_transform_jobs/3","title":"AWS.SageMaker.list_transform_jobs/3","type":"function"},{"doc":"Lists the trial components in your account.\n\nYou can sort the list by trial component name or creation time. You can filter\nthe list to show only components that were created in a specific time range. You\ncan also filter on one of the following:\n\n  * `ExperimentName`\n\n  * `SourceArn`\n\n  * `TrialName`","ref":"AWS.SageMaker.html#list_trial_components/3","title":"AWS.SageMaker.list_trial_components/3","type":"function"},{"doc":"Lists the trials in your account.\n\nSpecify an experiment name to limit the list to the trials that are part of that\nexperiment. Specify a trial component name to limit the list to the trials that\nassociated with that trial component. The list can be filtered to show only\ntrials that were created in a specific time range. The list can be sorted by\ntrial name or creation time.","ref":"AWS.SageMaker.html#list_trials/3","title":"AWS.SageMaker.list_trials/3","type":"function"},{"doc":"Lists user profiles.","ref":"AWS.SageMaker.html#list_user_profiles/3","title":"AWS.SageMaker.list_user_profiles/3","type":"function"},{"doc":"Use this operation to list all private and vendor workforces in an Amazon Web\nServices Region.\n\nNote that you can only have one private workforce per Amazon Web Services\nRegion.","ref":"AWS.SageMaker.html#list_workforces/3","title":"AWS.SageMaker.list_workforces/3","type":"function"},{"doc":"Gets a list of private work teams that you have defined in a region.\n\nThe list may be empty if no work team satisfies the filter specified in the\n`NameContains` parameter.","ref":"AWS.SageMaker.html#list_workteams/3","title":"AWS.SageMaker.list_workteams/3","type":"function"},{"doc":"","ref":"AWS.SageMaker.html#metadata/0","title":"AWS.SageMaker.metadata/0","type":"function"},{"doc":"Adds a resouce policy to control access to a model group.\n\nFor information about resoure policies, see [Identity-based policies and resource-based\npolicies](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_identity-vs-resource.html)\nin the *Amazon Web Services Identity and Access Management User Guide.*.","ref":"AWS.SageMaker.html#put_model_package_group_policy/3","title":"AWS.SageMaker.put_model_package_group_policy/3","type":"function"},{"doc":"Use this action to inspect your lineage and discover relationships between\nentities.\n\nFor more information, see [ Querying Lineage Entities](https://docs.aws.amazon.com/sagemaker/latest/dg/querying-lineage-entities.html)\nin the *Amazon SageMaker Developer Guide*.","ref":"AWS.SageMaker.html#query_lineage/3","title":"AWS.SageMaker.query_lineage/3","type":"function"},{"doc":"Register devices.","ref":"AWS.SageMaker.html#register_devices/3","title":"AWS.SageMaker.register_devices/3","type":"function"},{"doc":"Renders the UI template so that you can preview the worker's experience.","ref":"AWS.SageMaker.html#render_ui_template/3","title":"AWS.SageMaker.render_ui_template/3","type":"function"},{"doc":"Retry the execution of the pipeline.","ref":"AWS.SageMaker.html#retry_pipeline_execution/3","title":"AWS.SageMaker.retry_pipeline_execution/3","type":"function"},{"doc":"Finds SageMaker resources that match a search query.\n\nMatching resources are returned as a list of `SearchRecord` objects in the\nresponse. You can sort the search results by any resource property in a\nascending or descending order.\n\nYou can query against the following value types: numeric, text, Boolean, and\ntimestamp.\n\nThe Search API may provide access to otherwise restricted data. See [Amazon SageMaker API Permissions: Actions, Permissions, and Resources\nReference](https://docs.aws.amazon.com/sagemaker/latest/dg/api-permissions-reference.html)\nfor more information.","ref":"AWS.SageMaker.html#search/3","title":"AWS.SageMaker.search/3","type":"function"},{"doc":"Notifies the pipeline that the execution of a callback step failed, along with a\nmessage describing why.\n\nWhen a callback step is run, the pipeline generates a callback token and\nincludes the token in a message sent to Amazon Simple Queue Service (Amazon\nSQS).","ref":"AWS.SageMaker.html#send_pipeline_execution_step_failure/3","title":"AWS.SageMaker.send_pipeline_execution_step_failure/3","type":"function"},{"doc":"Notifies the pipeline that the execution of a callback step succeeded and\nprovides a list of the step's output parameters.\n\nWhen a callback step is run, the pipeline generates a callback token and\nincludes the token in a message sent to Amazon Simple Queue Service (Amazon\nSQS).","ref":"AWS.SageMaker.html#send_pipeline_execution_step_success/3","title":"AWS.SageMaker.send_pipeline_execution_step_success/3","type":"function"},{"doc":"Starts a stage in an edge deployment plan.","ref":"AWS.SageMaker.html#start_edge_deployment_stage/3","title":"AWS.SageMaker.start_edge_deployment_stage/3","type":"function"},{"doc":"Starts an inference experiment.","ref":"AWS.SageMaker.html#start_inference_experiment/3","title":"AWS.SageMaker.start_inference_experiment/3","type":"function"},{"doc":"Starts a previously stopped monitoring schedule.\n\nBy default, when you successfully create a new schedule, the status of a\nmonitoring schedule is `scheduled`.","ref":"AWS.SageMaker.html#start_monitoring_schedule/3","title":"AWS.SageMaker.start_monitoring_schedule/3","type":"function"},{"doc":"Launches an ML compute instance with the latest version of the libraries and\nattaches your ML storage volume.\n\nAfter configuring the notebook instance, SageMaker sets the notebook instance\nstatus to `InService`. A notebook instance's status must be `InService` before\nyou can connect to your Jupyter notebook.","ref":"AWS.SageMaker.html#start_notebook_instance/3","title":"AWS.SageMaker.start_notebook_instance/3","type":"function"},{"doc":"Starts a pipeline execution.","ref":"AWS.SageMaker.html#start_pipeline_execution/3","title":"AWS.SageMaker.start_pipeline_execution/3","type":"function"},{"doc":"A method for forcing a running job to shut down.","ref":"AWS.SageMaker.html#stop_auto_ml_job/3","title":"AWS.SageMaker.stop_auto_ml_job/3","type":"function"},{"doc":"Stops a model compilation job.\n\nTo stop a job, Amazon SageMaker sends the algorithm the SIGTERM signal. This\ngracefully shuts the job down. If the job hasn't stopped, it sends the SIGKILL\nsignal.\n\nWhen it receives a `StopCompilationJob` request, Amazon SageMaker changes the\n`CompilationJobStatus` of the job to `Stopping`. After Amazon SageMaker stops\nthe job, it sets the `CompilationJobStatus` to `Stopped`.","ref":"AWS.SageMaker.html#stop_compilation_job/3","title":"AWS.SageMaker.stop_compilation_job/3","type":"function"},{"doc":"Stops a stage in an edge deployment plan.","ref":"AWS.SageMaker.html#stop_edge_deployment_stage/3","title":"AWS.SageMaker.stop_edge_deployment_stage/3","type":"function"},{"doc":"Request to stop an edge packaging job.","ref":"AWS.SageMaker.html#stop_edge_packaging_job/3","title":"AWS.SageMaker.stop_edge_packaging_job/3","type":"function"},{"doc":"Stops a running hyperparameter tuning job and all running training jobs that the\ntuning job launched.\n\nAll model artifacts output from the training jobs are stored in Amazon Simple\nStorage Service (Amazon S3). All data that the training jobs write to Amazon\nCloudWatch Logs are still available in CloudWatch. After the tuning job moves to\nthe `Stopped` state, it releases all reserved resources for the tuning job.","ref":"AWS.SageMaker.html#stop_hyper_parameter_tuning_job/3","title":"AWS.SageMaker.stop_hyper_parameter_tuning_job/3","type":"function"},{"doc":"Stops an inference experiment.","ref":"AWS.SageMaker.html#stop_inference_experiment/3","title":"AWS.SageMaker.stop_inference_experiment/3","type":"function"},{"doc":"Stops an Inference Recommender job.","ref":"AWS.SageMaker.html#stop_inference_recommendations_job/3","title":"AWS.SageMaker.stop_inference_recommendations_job/3","type":"function"},{"doc":"Stops a running labeling job.\n\nA job that is stopped cannot be restarted. Any results obtained before the job\nis stopped are placed in the Amazon S3 output bucket.","ref":"AWS.SageMaker.html#stop_labeling_job/3","title":"AWS.SageMaker.stop_labeling_job/3","type":"function"},{"doc":"Stops a previously started monitoring schedule.","ref":"AWS.SageMaker.html#stop_monitoring_schedule/3","title":"AWS.SageMaker.stop_monitoring_schedule/3","type":"function"},{"doc":"Terminates the ML compute instance.\n\nBefore terminating the instance, SageMaker disconnects the ML storage volume\nfrom it. SageMaker preserves the ML storage volume. SageMaker stops charging you\nfor the ML compute instance when you call `StopNotebookInstance`.\n\nTo access data on the ML storage volume for a notebook instance that has been\nterminated, call the `StartNotebookInstance` API. `StartNotebookInstance`\nlaunches another ML compute instance, configures it, and attaches the preserved\nML storage volume so you can continue your work.","ref":"AWS.SageMaker.html#stop_notebook_instance/3","title":"AWS.SageMaker.stop_notebook_instance/3","type":"function"},{"doc":"Stops a pipeline execution.","ref":"AWS.SageMaker.html#stop_pipeline_execution/3","title":"AWS.SageMaker.stop_pipeline_execution/3","type":"function"},{"doc":"A pipeline execution won't stop while a callback step is running. When you call\n`StopPipelineExecution` on a pipeline execution with a running callback step,\nSageMaker Pipelines sends an additional Amazon SQS message to the specified SQS\nqueue. The body of the SQS message contains a \"Status\" field which is set to\n\"Stopping\".\n\nYou should add logic to your Amazon SQS message consumer to take any needed\naction (for example, resource cleanup) upon receipt of the message followed by a\ncall to `SendPipelineExecutionStepSuccess` or\n`SendPipelineExecutionStepFailure`.\n\nOnly when SageMaker Pipelines receives one of these calls will it stop the\npipeline execution.","ref":"AWS.SageMaker.html#stop_pipeline_execution/3-callback-step","title":"Callback Step - AWS.SageMaker.stop_pipeline_execution/3","type":"function"},{"doc":"A pipeline execution can't be stopped while a lambda step is running because the\nLambda function invoked by the lambda step can't be stopped. If you attempt to\nstop the execution while the Lambda function is running, the pipeline waits for\nthe Lambda function to finish or until the timeout is hit, whichever occurs\nfirst, and then stops. If the Lambda function finishes, the pipeline execution\nstatus is `Stopped`. If the timeout is hit the pipeline execution status is\n`Failed`.","ref":"AWS.SageMaker.html#stop_pipeline_execution/3-lambda-step","title":"Lambda Step - AWS.SageMaker.stop_pipeline_execution/3","type":"function"},{"doc":"Stops a processing job.","ref":"AWS.SageMaker.html#stop_processing_job/3","title":"AWS.SageMaker.stop_processing_job/3","type":"function"},{"doc":"Stops a training job.\n\nTo stop a job, SageMaker sends the algorithm the `SIGTERM` signal, which delays\njob termination for 120 seconds. Algorithms might use this 120-second window to\nsave the model artifacts, so the results of the training is not lost.\n\nWhen it receives a `StopTrainingJob` request, SageMaker changes the status of\nthe job to `Stopping`. After SageMaker stops the job, it sets the status to\n`Stopped`.","ref":"AWS.SageMaker.html#stop_training_job/3","title":"AWS.SageMaker.stop_training_job/3","type":"function"},{"doc":"Stops a batch transform job.\n\nWhen Amazon SageMaker receives a `StopTransformJob` request, the status of the\njob changes to `Stopping`. After Amazon SageMaker stops the job, the status is\nset to `Stopped`. When you stop a batch transform job before it is completed,\nAmazon SageMaker doesn't store the job's output in Amazon S3.","ref":"AWS.SageMaker.html#stop_transform_job/3","title":"AWS.SageMaker.stop_transform_job/3","type":"function"},{"doc":"Updates an action.","ref":"AWS.SageMaker.html#update_action/3","title":"AWS.SageMaker.update_action/3","type":"function"},{"doc":"Updates the properties of an AppImageConfig.","ref":"AWS.SageMaker.html#update_app_image_config/3","title":"AWS.SageMaker.update_app_image_config/3","type":"function"},{"doc":"Updates an artifact.","ref":"AWS.SageMaker.html#update_artifact/3","title":"AWS.SageMaker.update_artifact/3","type":"function"},{"doc":"Update a SageMaker HyperPod cluster.","ref":"AWS.SageMaker.html#update_cluster/3","title":"AWS.SageMaker.update_cluster/3","type":"function"},{"doc":"Updates the specified Git repository with the specified values.","ref":"AWS.SageMaker.html#update_code_repository/3","title":"AWS.SageMaker.update_code_repository/3","type":"function"},{"doc":"Updates a context.","ref":"AWS.SageMaker.html#update_context/3","title":"AWS.SageMaker.update_context/3","type":"function"},{"doc":"Updates a fleet of devices.","ref":"AWS.SageMaker.html#update_device_fleet/3","title":"AWS.SageMaker.update_device_fleet/3","type":"function"},{"doc":"Updates one or more devices in a fleet.","ref":"AWS.SageMaker.html#update_devices/3","title":"AWS.SageMaker.update_devices/3","type":"function"},{"doc":"Updates the default settings for new user profiles in the domain.","ref":"AWS.SageMaker.html#update_domain/3","title":"AWS.SageMaker.update_domain/3","type":"function"},{"doc":"Deploys the `EndpointConfig` specified in the request to a new fleet of\ninstances.\n\nSageMaker shifts endpoint traffic to the new instances with the updated endpoint\nconfiguration and then deletes the old instances using the previous\n`EndpointConfig` (there is no availability loss). For more information about how\nto control the update and traffic shifting process, see [ Update models in production](https://docs.aws.amazon.com/sagemaker/latest/dg/deployment-guardrails.html).\n\nWhen SageMaker receives the request, it sets the endpoint status to `Updating`.\nAfter updating the endpoint, it sets the status to `InService`. To check the\nstatus of an endpoint, use the\n[DescribeEndpoint](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeEndpoint.html)\nAPI.\n\nYou must not delete an `EndpointConfig` in use by an endpoint that is live or\nwhile the `UpdateEndpoint` or `CreateEndpoint` operations are being performed on\nthe endpoint. To update an endpoint, you must create a new `EndpointConfig`.\n\nIf you delete the `EndpointConfig` of an endpoint that is active or being\ncreated or updated you may lose visibility into the instance type the endpoint\nis using. The endpoint must be deleted in order to stop incurring charges.","ref":"AWS.SageMaker.html#update_endpoint/3","title":"AWS.SageMaker.update_endpoint/3","type":"function"},{"doc":"Updates variant weight of one or more variants associated with an existing\nendpoint, or capacity of one variant associated with an existing endpoint.\n\nWhen it receives the request, SageMaker sets the endpoint status to `Updating`.\nAfter updating the endpoint, it sets the status to `InService`. To check the\nstatus of an endpoint, use the\n[DescribeEndpoint](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeEndpoint.html)\nAPI.","ref":"AWS.SageMaker.html#update_endpoint_weights_and_capacities/3","title":"AWS.SageMaker.update_endpoint_weights_and_capacities/3","type":"function"},{"doc":"Adds, updates, or removes the description of an experiment.\n\nUpdates the display name of an experiment.","ref":"AWS.SageMaker.html#update_experiment/3","title":"AWS.SageMaker.update_experiment/3","type":"function"},{"doc":"Updates the feature group by either adding features or updating the online store\nconfiguration.\n\nUse one of the following request parameters at a time while using the\n`UpdateFeatureGroup` API.\n\nYou can add features for your feature group using the `FeatureAdditions` request\nparameter. Features cannot be removed from a feature group.\n\nYou can update the online store configuration by using the `OnlineStoreConfig`\nrequest parameter. If a `TtlDuration` is specified, the default `TtlDuration`\napplies for all records added to the feature group *after the feature group is\nupdated*. If a record level `TtlDuration` exists from using the `PutRecord` API,\nthe record level `TtlDuration` applies to that record instead of the default\n`TtlDuration`.","ref":"AWS.SageMaker.html#update_feature_group/3","title":"AWS.SageMaker.update_feature_group/3","type":"function"},{"doc":"Updates the description and parameters of the feature group.","ref":"AWS.SageMaker.html#update_feature_metadata/3","title":"AWS.SageMaker.update_feature_metadata/3","type":"function"},{"doc":"Update a hub.\n\nHub APIs are only callable through SageMaker Studio.","ref":"AWS.SageMaker.html#update_hub/3","title":"AWS.SageMaker.update_hub/3","type":"function"},{"doc":"Updates the properties of a SageMaker image.\n\nTo change the image's tags, use the\n[AddTags](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_AddTags.html) and\n[DeleteTags](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteTags.html)\nAPIs.","ref":"AWS.SageMaker.html#update_image/3","title":"AWS.SageMaker.update_image/3","type":"function"},{"doc":"Updates the properties of a SageMaker image version.","ref":"AWS.SageMaker.html#update_image_version/3","title":"AWS.SageMaker.update_image_version/3","type":"function"},{"doc":"Updates an inference component.","ref":"AWS.SageMaker.html#update_inference_component/3","title":"AWS.SageMaker.update_inference_component/3","type":"function"},{"doc":"Runtime settings for a model that is deployed with an inference component.","ref":"AWS.SageMaker.html#update_inference_component_runtime_config/3","title":"AWS.SageMaker.update_inference_component_runtime_config/3","type":"function"},{"doc":"Updates an inference experiment that you created.\n\nThe status of the inference experiment has to be either `Created`, `Running`.\nFor more information on the status of an inference experiment, see\n[DescribeInferenceExperiment](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeInferenceExperiment.html).","ref":"AWS.SageMaker.html#update_inference_experiment/3","title":"AWS.SageMaker.update_inference_experiment/3","type":"function"},{"doc":"Update an Amazon SageMaker Model Card.\n\nYou cannot update both model card content and model card status in a single\ncall.","ref":"AWS.SageMaker.html#update_model_card/3","title":"AWS.SageMaker.update_model_card/3","type":"function"},{"doc":"Updates a versioned model.","ref":"AWS.SageMaker.html#update_model_package/3","title":"AWS.SageMaker.update_model_package/3","type":"function"},{"doc":"Update the parameters of a model monitor alert.","ref":"AWS.SageMaker.html#update_monitoring_alert/3","title":"AWS.SageMaker.update_monitoring_alert/3","type":"function"},{"doc":"Updates a previously created schedule.","ref":"AWS.SageMaker.html#update_monitoring_schedule/3","title":"AWS.SageMaker.update_monitoring_schedule/3","type":"function"},{"doc":"Updates a notebook instance.\n\nNotebookInstance updates include upgrading or downgrading the ML compute\ninstance used for your notebook instance to accommodate changes in your workload\nrequirements.","ref":"AWS.SageMaker.html#update_notebook_instance/3","title":"AWS.SageMaker.update_notebook_instance/3","type":"function"},{"doc":"Updates a notebook instance lifecycle configuration created with the\n[CreateNotebookInstanceLifecycleConfig](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateNotebookInstanceLifecycleConfig.html)\nAPI.","ref":"AWS.SageMaker.html#update_notebook_instance_lifecycle_config/3","title":"AWS.SageMaker.update_notebook_instance_lifecycle_config/3","type":"function"},{"doc":"Updates a pipeline.","ref":"AWS.SageMaker.html#update_pipeline/3","title":"AWS.SageMaker.update_pipeline/3","type":"function"},{"doc":"Updates a pipeline execution.","ref":"AWS.SageMaker.html#update_pipeline_execution/3","title":"AWS.SageMaker.update_pipeline_execution/3","type":"function"},{"doc":"Updates a machine learning (ML) project that is created from a template that\nsets up an ML pipeline from training to deploying an approved model.\n\nYou must not update a project that is in use. If you update the\n`ServiceCatalogProvisioningUpdateDetails` of a project that is active or being\ncreated, or updated, you may lose resources already created by the project.","ref":"AWS.SageMaker.html#update_project/3","title":"AWS.SageMaker.update_project/3","type":"function"},{"doc":"Updates the settings of a space.","ref":"AWS.SageMaker.html#update_space/3","title":"AWS.SageMaker.update_space/3","type":"function"},{"doc":"Update a model training job to request a new Debugger profiling configuration or\nto change warm pool retention length.","ref":"AWS.SageMaker.html#update_training_job/3","title":"AWS.SageMaker.update_training_job/3","type":"function"},{"doc":"Updates the display name of a trial.","ref":"AWS.SageMaker.html#update_trial/3","title":"AWS.SageMaker.update_trial/3","type":"function"},{"doc":"Updates one or more properties of a trial component.","ref":"AWS.SageMaker.html#update_trial_component/3","title":"AWS.SageMaker.update_trial_component/3","type":"function"},{"doc":"Updates a user profile.","ref":"AWS.SageMaker.html#update_user_profile/3","title":"AWS.SageMaker.update_user_profile/3","type":"function"},{"doc":"Use this operation to update your workforce.\n\nYou can use this operation to require that workers use specific IP addresses to\nwork on tasks and to update your OpenID Connect (OIDC) Identity Provider (IdP)\nworkforce configuration.\n\nThe worker portal is now supported in VPC and public internet.\n\nUse `SourceIpConfig` to restrict worker access to tasks to a specific range of\nIP addresses. You specify allowed IP addresses by creating a list of up to ten\n[CIDRs](https://docs.aws.amazon.com/vpc/latest/userguide/VPC_Subnets.html). By default, a workforce isn't restricted to specific IP addresses. If you specify a\nrange of IP addresses, workers who attempt to access tasks using any IP address\noutside the specified range are denied and get a `Not Found` error message on\nthe worker portal.\n\nTo restrict access to all the workers in public internet, add the\n`SourceIpConfig` CIDR value as \"10.0.0.0/16\".\n\nAmazon SageMaker does not support Source Ip restriction for worker portals in\nVPC.\n\nUse `OidcConfig` to update the configuration of a workforce created using your\nown OIDC IdP.\n\nYou can only update your OIDC IdP configuration when there are no work teams\nassociated with your workforce. You can delete work teams using the\n[DeleteWorkteam](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteWorkteam.html)\noperation.\n\nAfter restricting access to a range of IP addresses or updating your OIDC IdP\nconfiguration with this operation, you can view details about your update\nworkforce using the\n[DescribeWorkforce](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeWorkforce.html)\noperation.\n\nThis operation only applies to private workforces.","ref":"AWS.SageMaker.html#update_workforce/3","title":"AWS.SageMaker.update_workforce/3","type":"function"},{"doc":"Updates an existing work team with new member definitions or description.","ref":"AWS.SageMaker.html#update_workteam/3","title":"AWS.SageMaker.update_workteam/3","type":"function"},{"doc":"Amazon Augmented AI (Amazon A2I) adds the benefit of human judgment to any\nmachine learning application.\n\nWhen an AI application can't evaluate data with a high degree of confidence,\nhuman reviewers can take over. This human review is called a human review\nworkflow. To create and start a human review workflow, you need three resources:\na *worker task template*, a *flow definition*, and a *human loop*.\n\nFor information about these resources and prerequisites for using Amazon A2I,\nsee [Get Started with Amazon Augmented AI](https://docs.aws.amazon.com/sagemaker/latest/dg/a2i-getting-started.html) in\nthe Amazon SageMaker Developer Guide.\n\nThis API reference includes information about API actions and data types that\nyou can use to interact with Amazon A2I programmatically. Use this guide to:\n\n  * Start a human loop with the `StartHumanLoop` operation when using\nAmazon A2I with a *custom task type*. To learn more about the difference between\ncustom and built-in task types, see [Use Task Types\n](https://docs.aws.amazon.com/sagemaker/latest/dg/a2i-task-types-general.html).\nTo learn how to start a human loop using this API, see [Create and Start a Human Loop for a Custom Task Type\n](https://docs.aws.amazon.com/sagemaker/latest/dg/a2i-start-human-loop.html#a2i-instructions-starthumanloop)\nin the Amazon SageMaker Developer Guide.\n\n  * Manage your human loops. You can list all human loops that you\nhave created, describe individual human loops, and stop and delete human loops.\nTo learn more, see [Monitor and Manage Your Human Loop\n](https://docs.aws.amazon.com/sagemaker/latest/dg/a2i-monitor-humanloop-results.html)\nin the Amazon SageMaker Developer Guide.\n\nAmazon A2I integrates APIs from various AWS services to create and start human\nreview workflows for those services. To learn how Amazon A2I uses these APIs,\nsee [Use APIs in Amazon A2I](https://docs.aws.amazon.com/sagemaker/latest/dg/a2i-api-references.html) in\nthe Amazon SageMaker Developer Guide.","ref":"AWS.SageMakerA2IRuntime.html","title":"AWS.SageMakerA2IRuntime","type":"module"},{"doc":"Deletes the specified human loop for a flow definition.\n\nIf the human loop was deleted, this operation will return a\n`ResourceNotFoundException`.","ref":"AWS.SageMakerA2IRuntime.html#delete_human_loop/4","title":"AWS.SageMakerA2IRuntime.delete_human_loop/4","type":"function"},{"doc":"Returns information about the specified human loop.\n\nIf the human loop was deleted, this operation will return a\n`ResourceNotFoundException` error.","ref":"AWS.SageMakerA2IRuntime.html#describe_human_loop/3","title":"AWS.SageMakerA2IRuntime.describe_human_loop/3","type":"function"},{"doc":"Returns information about human loops, given the specified parameters.\n\nIf a human loop was deleted, it will not be included.","ref":"AWS.SageMakerA2IRuntime.html#list_human_loops/8","title":"AWS.SageMakerA2IRuntime.list_human_loops/8","type":"function"},{"doc":"","ref":"AWS.SageMakerA2IRuntime.html#metadata/0","title":"AWS.SageMakerA2IRuntime.metadata/0","type":"function"},{"doc":"Starts a human loop, provided that at least one activation condition is met.","ref":"AWS.SageMakerA2IRuntime.html#start_human_loop/3","title":"AWS.SageMakerA2IRuntime.start_human_loop/3","type":"function"},{"doc":"Stops the specified human loop.","ref":"AWS.SageMakerA2IRuntime.html#stop_human_loop/3","title":"AWS.SageMakerA2IRuntime.stop_human_loop/3","type":"function"},{"doc":"Contains all data plane API operations and data types for the Amazon SageMaker\nFeature Store.\n\nUse this API to put, delete, and retrieve (get) features from a feature store.\n\nUse the following operations to configure your `OnlineStore` and `OfflineStore`\nfeatures, and to create and manage feature groups:\n\n  *\n[CreateFeatureGroup](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateFeatureGroup.html)     *\n[DeleteFeatureGroup](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteFeatureGroup.html)\n\n  *\n[DescribeFeatureGroup](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeFeatureGroup.html)     *\n[ListFeatureGroups](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListFeatureGroups.html)","ref":"AWS.SageMakerFeatureStoreRuntime.html","title":"AWS.SageMakerFeatureStoreRuntime","type":"module"},{"doc":"Retrieves a batch of `Records` from a `FeatureGroup`.","ref":"AWS.SageMakerFeatureStoreRuntime.html#batch_get_record/3","title":"AWS.SageMakerFeatureStoreRuntime.batch_get_record/3","type":"function"},{"doc":"Deletes a `Record` from a `FeatureGroup` in the `OnlineStore`.\n\nFeature Store supports both `SoftDelete` and `HardDelete`. For `SoftDelete`\n(default), feature columns are set to `null` and the record is no longer\nretrievable by `GetRecord` or `BatchGetRecord`. For `HardDelete`, the complete\n`Record` is removed from the `OnlineStore`. In both cases, Feature Store appends\nthe deleted record marker to the `OfflineStore`. The deleted record marker is a\nrecord with the same `RecordIdentifer` as the original, but with `is_deleted`\nvalue set to `True`, `EventTime` set to the delete input `EventTime`, and other\nfeature values set to `null`.\n\nNote that the `EventTime` specified in `DeleteRecord` should be set later than\nthe `EventTime` of the existing record in the `OnlineStore` for that\n`RecordIdentifer`. If it is not, the deletion does not occur:\n\n  * For `SoftDelete`, the existing (not deleted) record remains in the\n`OnlineStore`, though the delete record marker is still written to the\n`OfflineStore`.\n\n  * `HardDelete` returns `EventTime`: `400 ValidationException` to\nindicate that the delete operation failed. No delete record marker is written to\nthe `OfflineStore`.\n\nWhen a record is deleted from the `OnlineStore`, the deleted record marker is\nappended to the `OfflineStore`. If you have the Iceberg table format enabled for\nyour `OfflineStore`, you can remove all history of a record from the\n`OfflineStore` using Amazon Athena or Apache Spark. For information on how to\nhard delete a record from the `OfflineStore` with the Iceberg table format\nenabled, see [Delete records from the offline store](https://docs.aws.amazon.com/sagemaker/latest/dg/feature-store-delete-records-offline-store.html#feature-store-delete-records-offline-store).","ref":"AWS.SageMakerFeatureStoreRuntime.html#delete_record/4","title":"AWS.SageMakerFeatureStoreRuntime.delete_record/4","type":"function"},{"doc":"Use for `OnlineStore` serving from a `FeatureStore`.\n\nOnly the latest records stored in the `OnlineStore` can be retrieved. If no\nRecord with `RecordIdentifierValue` is found, then an empty result is returned.","ref":"AWS.SageMakerFeatureStoreRuntime.html#get_record/6","title":"AWS.SageMakerFeatureStoreRuntime.get_record/6","type":"function"},{"doc":"","ref":"AWS.SageMakerFeatureStoreRuntime.html#metadata/0","title":"AWS.SageMakerFeatureStoreRuntime.metadata/0","type":"function"},{"doc":"The `PutRecord` API is used to ingest a list of `Records` into your feature\ngroup.\n\nIf a new record’s `EventTime` is greater, the new record is written to both the\n`OnlineStore` and `OfflineStore`. Otherwise, the record is a historic record and\nit is written only to the `OfflineStore`.\n\nYou can specify the ingestion to be applied to the `OnlineStore`,\n`OfflineStore`, or both by using the `TargetStores` request parameter.\n\nYou can set the ingested record to expire at a given time to live (TTL) duration\nafter the record’s event time, `ExpiresAt` = `EventTime` + `TtlDuration`, by\nspecifying the `TtlDuration` parameter. A record level `TtlDuration` is set when\nspecifying the `TtlDuration` parameter using the `PutRecord` API call. If the\ninput `TtlDuration` is `null` or unspecified, `TtlDuration` is set to the\ndefault feature group level `TtlDuration`. A record level `TtlDuration`\nsupersedes the group level `TtlDuration`.","ref":"AWS.SageMakerFeatureStoreRuntime.html#put_record/4","title":"AWS.SageMakerFeatureStoreRuntime.put_record/4","type":"function"},{"doc":"Provides APIs for creating and managing SageMaker geospatial resources.","ref":"AWS.SageMakerGeospatial.html","title":"AWS.SageMakerGeospatial","type":"module"},{"doc":"Use this operation to delete an Earth Observation job.","ref":"AWS.SageMakerGeospatial.html#delete_earth_observation_job/4","title":"AWS.SageMakerGeospatial.delete_earth_observation_job/4","type":"function"},{"doc":"Use this operation to delete a Vector Enrichment job.","ref":"AWS.SageMakerGeospatial.html#delete_vector_enrichment_job/4","title":"AWS.SageMakerGeospatial.delete_vector_enrichment_job/4","type":"function"},{"doc":"Use this operation to export results of an Earth Observation job and optionally\nsource images used as input to the EOJ to an Amazon S3 location.","ref":"AWS.SageMakerGeospatial.html#export_earth_observation_job/3","title":"AWS.SageMakerGeospatial.export_earth_observation_job/3","type":"function"},{"doc":"Use this operation to copy results of a Vector Enrichment job to an Amazon S3\nlocation.","ref":"AWS.SageMakerGeospatial.html#export_vector_enrichment_job/3","title":"AWS.SageMakerGeospatial.export_vector_enrichment_job/3","type":"function"},{"doc":"Get the details for a previously initiated Earth Observation job.","ref":"AWS.SageMakerGeospatial.html#get_earth_observation_job/3","title":"AWS.SageMakerGeospatial.get_earth_observation_job/3","type":"function"},{"doc":"Use this operation to get details of a specific raster data collection.","ref":"AWS.SageMakerGeospatial.html#get_raster_data_collection/3","title":"AWS.SageMakerGeospatial.get_raster_data_collection/3","type":"function"},{"doc":"Gets a web mercator tile for the given Earth Observation job.","ref":"AWS.SageMakerGeospatial.html#get_tile/14","title":"AWS.SageMakerGeospatial.get_tile/14","type":"function"},{"doc":"Retrieves details of a Vector Enrichment Job for a given job Amazon Resource\nName (ARN).","ref":"AWS.SageMakerGeospatial.html#get_vector_enrichment_job/3","title":"AWS.SageMakerGeospatial.get_vector_enrichment_job/3","type":"function"},{"doc":"Use this operation to get a list of the Earth Observation jobs associated with\nthe calling Amazon Web Services account.","ref":"AWS.SageMakerGeospatial.html#list_earth_observation_jobs/3","title":"AWS.SageMakerGeospatial.list_earth_observation_jobs/3","type":"function"},{"doc":"Use this operation to get raster data collections.","ref":"AWS.SageMakerGeospatial.html#list_raster_data_collections/4","title":"AWS.SageMakerGeospatial.list_raster_data_collections/4","type":"function"},{"doc":"Lists the tags attached to the resource.","ref":"AWS.SageMakerGeospatial.html#list_tags_for_resource/3","title":"AWS.SageMakerGeospatial.list_tags_for_resource/3","type":"function"},{"doc":"Retrieves a list of vector enrichment jobs.","ref":"AWS.SageMakerGeospatial.html#list_vector_enrichment_jobs/3","title":"AWS.SageMakerGeospatial.list_vector_enrichment_jobs/3","type":"function"},{"doc":"","ref":"AWS.SageMakerGeospatial.html#metadata/0","title":"AWS.SageMakerGeospatial.metadata/0","type":"function"},{"doc":"Allows you run image query on a specific raster data collection to get a list of\nthe satellite imagery matching the selected filters.","ref":"AWS.SageMakerGeospatial.html#search_raster_data_collection/3","title":"AWS.SageMakerGeospatial.search_raster_data_collection/3","type":"function"},{"doc":"Use this operation to create an Earth observation job.","ref":"AWS.SageMakerGeospatial.html#start_earth_observation_job/3","title":"AWS.SageMakerGeospatial.start_earth_observation_job/3","type":"function"},{"doc":"Creates a Vector Enrichment job for the supplied job type.\n\nCurrently, there are two supported job types: reverse geocoding and map\nmatching.","ref":"AWS.SageMakerGeospatial.html#start_vector_enrichment_job/3","title":"AWS.SageMakerGeospatial.start_vector_enrichment_job/3","type":"function"},{"doc":"Use this operation to stop an existing earth observation job.","ref":"AWS.SageMakerGeospatial.html#stop_earth_observation_job/3","title":"AWS.SageMakerGeospatial.stop_earth_observation_job/3","type":"function"},{"doc":"Stops the Vector Enrichment job for a given job ARN.","ref":"AWS.SageMakerGeospatial.html#stop_vector_enrichment_job/3","title":"AWS.SageMakerGeospatial.stop_vector_enrichment_job/3","type":"function"},{"doc":"The resource you want to tag.","ref":"AWS.SageMakerGeospatial.html#tag_resource/4","title":"AWS.SageMakerGeospatial.tag_resource/4","type":"function"},{"doc":"The resource you want to untag.","ref":"AWS.SageMakerGeospatial.html#untag_resource/4","title":"AWS.SageMakerGeospatial.untag_resource/4","type":"function"},{"doc":"Contains all data plane API operations and data types for Amazon SageMaker\nMetrics.\n\nUse these APIs to put and retrieve (get) features related to your training run.\n\n  *\n[BatchPutMetrics](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_metrics_BatchPutMetrics.html)","ref":"AWS.SageMakerMetrics.html","title":"AWS.SageMakerMetrics","type":"module"},{"doc":"Used to ingest training metrics into SageMaker.\n\nThese metrics can be visualized in SageMaker Studio and retrieved with the\n`GetMetrics` API.","ref":"AWS.SageMakerMetrics.html#batch_put_metrics/3","title":"AWS.SageMakerMetrics.batch_put_metrics/3","type":"function"},{"doc":"","ref":"AWS.SageMakerMetrics.html#metadata/0","title":"AWS.SageMakerMetrics.metadata/0","type":"function"},{"doc":"The Amazon SageMaker runtime API.","ref":"AWS.SageMakerRuntime.html","title":"AWS.SageMakerRuntime","type":"module"},{"doc":"After you deploy a model into production using Amazon SageMaker hosting\nservices, your client applications use this API to get inferences from the model\nhosted at the specified endpoint.\n\nFor an overview of Amazon SageMaker, see [How It Works](https://docs.aws.amazon.com/sagemaker/latest/dg/how-it-works.html).\n\nAmazon SageMaker strips all POST headers except those supported by the API.\nAmazon SageMaker might add additional headers. You should not rely on the\nbehavior of headers outside those enumerated in the request syntax.\n\nCalls to `InvokeEndpoint` are authenticated by using Amazon Web Services\nSignature Version 4. For information, see [Authenticating Requests (Amazon Web Services Signature Version\n4)](https://docs.aws.amazon.com/AmazonS3/latest/API/sig-v4-authenticating-requests.html)\nin the *Amazon S3 API Reference*.\n\nA customer's model containers must respond to requests within 60 seconds. The\nmodel itself can have a maximum processing time of 60 seconds before responding\nto invocations. If your model is going to take 50-60 seconds of processing time,\nthe SDK socket timeout should be set to be 70 seconds.\n\nEndpoints are scoped to an individual account, and are not public. The URL does\nnot contain the account ID, but Amazon SageMaker determines the account ID from\nthe authentication token that is supplied by the caller.","ref":"AWS.SageMakerRuntime.html#invoke_endpoint/4","title":"AWS.SageMakerRuntime.invoke_endpoint/4","type":"function"},{"doc":"After you deploy a model into production using Amazon SageMaker hosting\nservices, your client applications use this API to get inferences from the model\nhosted at the specified endpoint in an asynchronous manner.\n\nInference requests sent to this API are enqueued for asynchronous processing.\nThe processing of the inference request may or may not complete before you\nreceive a response from this API. The response from this API will not contain\nthe result of the inference request but contain information about where you can\nlocate it.\n\nAmazon SageMaker strips all POST headers except those supported by the API.\nAmazon SageMaker might add additional headers. You should not rely on the\nbehavior of headers outside those enumerated in the request syntax.\n\nCalls to `InvokeEndpointAsync` are authenticated by using Amazon Web Services\nSignature Version 4. For information, see [Authenticating Requests (Amazon Web Services Signature Version\n4)](https://docs.aws.amazon.com/AmazonS3/latest/API/sig-v4-authenticating-requests.html)\nin the *Amazon S3 API Reference*.","ref":"AWS.SageMakerRuntime.html#invoke_endpoint_async/4","title":"AWS.SageMakerRuntime.invoke_endpoint_async/4","type":"function"},{"doc":"Invokes a model at the specified endpoint to return the inference response as a\nstream.\n\nThe inference stream provides the response payload incrementally as a series of\nparts. Before you can get an inference stream, you must have access to a model\nthat's deployed using Amazon SageMaker hosting services, and the container for\nthat model must support inference streaming.\n\nFor more information that can help you use this API, see the following sections\nin the *Amazon SageMaker Developer Guide*:\n\n  * For information about how to add streaming support to a model, see\n[How Containers Serve Requests](https://docs.aws.amazon.com/sagemaker/latest/dg/your-algorithms-inference-code.html#your-algorithms-inference-code-how-containe-serves-requests).\n\n  * For information about how to process the streaming response, see\n[Invoke real-time endpoints](https://docs.aws.amazon.com/sagemaker/latest/dg/realtime-endpoints-test-endpoints.html).\n\nBefore you can use this operation, your IAM permissions must allow the\n`sagemaker:InvokeEndpoint` action. For more information about Amazon SageMaker\nactions for IAM policies, see [Actions, resources, and condition keys for Amazon SageMaker](https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonsagemaker.html)\nin the *IAM Service Authorization Reference*.\n\nAmazon SageMaker strips all POST headers except those supported by the API.\nAmazon SageMaker might add additional headers. You should not rely on the\nbehavior of headers outside those enumerated in the request syntax.\n\nCalls to `InvokeEndpointWithResponseStream` are authenticated by using Amazon\nWeb Services Signature Version 4. For information, see [Authenticating Requests (Amazon Web Services Signature Version\n4)](https://docs.aws.amazon.com/AmazonS3/latest/API/sig-v4-authenticating-requests.html)\nin the *Amazon S3 API Reference*.","ref":"AWS.SageMakerRuntime.html#invoke_endpoint_with_response_stream/4","title":"AWS.SageMakerRuntime.invoke_endpoint_with_response_stream/4","type":"function"},{"doc":"","ref":"AWS.SageMakerRuntime.html#metadata/0","title":"AWS.SageMakerRuntime.metadata/0","type":"function"},{"doc":"SageMaker Edge Manager dataplane service for communicating with active agents.","ref":"AWS.SagemakerEdge.html","title":"AWS.SagemakerEdge","type":"module"},{"doc":"Use to get the active deployments from a device.","ref":"AWS.SagemakerEdge.html#get_deployments/3","title":"AWS.SagemakerEdge.get_deployments/3","type":"function"},{"doc":"Use to check if a device is registered with SageMaker Edge Manager.","ref":"AWS.SagemakerEdge.html#get_device_registration/3","title":"AWS.SagemakerEdge.get_device_registration/3","type":"function"},{"doc":"","ref":"AWS.SagemakerEdge.html#metadata/0","title":"AWS.SagemakerEdge.metadata/0","type":"function"},{"doc":"Use to get the current status of devices registered on SageMaker Edge Manager.","ref":"AWS.SagemakerEdge.html#send_heartbeat/3","title":"AWS.SagemakerEdge.send_heartbeat/3","type":"function"},{"doc":"Savings Plans are a pricing model that offer significant savings on AWS usage\n(for example, on Amazon EC2 instances).\n\nYou commit to a consistent amount of usage, in USD per hour, for a term of 1 or\n3 years, and receive a lower price for that usage. For more information, see the\n[AWS Savings Plans User Guide](https://docs.aws.amazon.com/savingsplans/latest/userguide/).","ref":"AWS.Savingsplans.html","title":"AWS.Savingsplans","type":"module"},{"doc":"Creates a Savings Plan.","ref":"AWS.Savingsplans.html#create_savings_plan/3","title":"AWS.Savingsplans.create_savings_plan/3","type":"function"},{"doc":"Deletes the queued purchase for the specified Savings Plan.","ref":"AWS.Savingsplans.html#delete_queued_savings_plan/3","title":"AWS.Savingsplans.delete_queued_savings_plan/3","type":"function"},{"doc":"Describes the specified Savings Plans rates.","ref":"AWS.Savingsplans.html#describe_savings_plan_rates/3","title":"AWS.Savingsplans.describe_savings_plan_rates/3","type":"function"},{"doc":"Describes the specified Savings Plans.","ref":"AWS.Savingsplans.html#describe_savings_plans/3","title":"AWS.Savingsplans.describe_savings_plans/3","type":"function"},{"doc":"Describes the specified Savings Plans offering rates.","ref":"AWS.Savingsplans.html#describe_savings_plans_offering_rates/3","title":"AWS.Savingsplans.describe_savings_plans_offering_rates/3","type":"function"},{"doc":"Describes the specified Savings Plans offerings.","ref":"AWS.Savingsplans.html#describe_savings_plans_offerings/3","title":"AWS.Savingsplans.describe_savings_plans_offerings/3","type":"function"},{"doc":"Lists the tags for the specified resource.","ref":"AWS.Savingsplans.html#list_tags_for_resource/3","title":"AWS.Savingsplans.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.Savingsplans.html#metadata/0","title":"AWS.Savingsplans.metadata/0","type":"function"},{"doc":"Adds the specified tags to the specified resource.","ref":"AWS.Savingsplans.html#tag_resource/3","title":"AWS.Savingsplans.tag_resource/3","type":"function"},{"doc":"Removes the specified tags from the specified resource.","ref":"AWS.Savingsplans.html#untag_resource/3","title":"AWS.Savingsplans.untag_resource/3","type":"function"},{"doc":"Amazon EventBridge Scheduler is a serverless scheduler that allows you to\ncreate, run, and manage tasks from one central, managed service.\n\nEventBridge Scheduler delivers your tasks reliably, with built-in mechanisms\nthat adjust your schedules based on the availability of downstream targets. The\nfollowing reference lists the available API actions, and data types for\nEventBridge Scheduler.","ref":"AWS.Scheduler.html","title":"AWS.Scheduler","type":"module"},{"doc":"Creates the specified schedule.","ref":"AWS.Scheduler.html#create_schedule/4","title":"AWS.Scheduler.create_schedule/4","type":"function"},{"doc":"Creates the specified schedule group.","ref":"AWS.Scheduler.html#create_schedule_group/4","title":"AWS.Scheduler.create_schedule_group/4","type":"function"},{"doc":"Deletes the specified schedule.","ref":"AWS.Scheduler.html#delete_schedule/4","title":"AWS.Scheduler.delete_schedule/4","type":"function"},{"doc":"Deletes the specified schedule group.\n\nDeleting a schedule group results in EventBridge Scheduler deleting all\nschedules associated with the group. When you delete a group, it remains in a\n`DELETING` state until all of its associated schedules are deleted. Schedules\nassociated with the group that are set to run while the schedule group is in the\nprocess of being deleted might continue to invoke their targets until the\nschedule group and its associated schedules are deleted.\n\nThis operation is eventually consistent.","ref":"AWS.Scheduler.html#delete_schedule_group/4","title":"AWS.Scheduler.delete_schedule_group/4","type":"function"},{"doc":"Retrieves the specified schedule.","ref":"AWS.Scheduler.html#get_schedule/4","title":"AWS.Scheduler.get_schedule/4","type":"function"},{"doc":"Retrieves the specified schedule group.","ref":"AWS.Scheduler.html#get_schedule_group/3","title":"AWS.Scheduler.get_schedule_group/3","type":"function"},{"doc":"Returns a paginated list of your schedule groups.","ref":"AWS.Scheduler.html#list_schedule_groups/5","title":"AWS.Scheduler.list_schedule_groups/5","type":"function"},{"doc":"Returns a paginated list of your EventBridge Scheduler schedules.","ref":"AWS.Scheduler.html#list_schedules/7","title":"AWS.Scheduler.list_schedules/7","type":"function"},{"doc":"Lists the tags associated with the Scheduler resource.","ref":"AWS.Scheduler.html#list_tags_for_resource/3","title":"AWS.Scheduler.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.Scheduler.html#metadata/0","title":"AWS.Scheduler.metadata/0","type":"function"},{"doc":"Assigns one or more tags (key-value pairs) to the specified EventBridge\nScheduler resource.\n\nYou can only assign tags to schedule groups.","ref":"AWS.Scheduler.html#tag_resource/4","title":"AWS.Scheduler.tag_resource/4","type":"function"},{"doc":"Removes one or more tags from the specified EventBridge Scheduler schedule\ngroup.","ref":"AWS.Scheduler.html#untag_resource/4","title":"AWS.Scheduler.untag_resource/4","type":"function"},{"doc":"Updates the specified schedule.\n\nWhen you call `UpdateSchedule`, EventBridge Scheduler uses all values, including\nempty values, specified in the request and overrides the existing schedule. This\nis by design. This means that if you do not set an optional field in your\nrequest, that field will be set to its system-default value after the update.\n\nBefore calling this operation, we recommend that you call the `GetSchedule` API\noperation and make a note of all optional parameters for your `UpdateSchedule`\ncall.","ref":"AWS.Scheduler.html#update_schedule/4","title":"AWS.Scheduler.update_schedule/4","type":"function"},{"doc":"Amazon EventBridge Schema Registry","ref":"AWS.Schemas.html","title":"AWS.Schemas","type":"module"},{"doc":"Creates a discoverer.","ref":"AWS.Schemas.html#create_discoverer/3","title":"AWS.Schemas.create_discoverer/3","type":"function"},{"doc":"Creates a registry.","ref":"AWS.Schemas.html#create_registry/4","title":"AWS.Schemas.create_registry/4","type":"function"},{"doc":"Creates a schema definition.\n\nInactive schemas will be deleted after two years.","ref":"AWS.Schemas.html#create_schema/5","title":"AWS.Schemas.create_schema/5","type":"function"},{"doc":"Deletes a discoverer.","ref":"AWS.Schemas.html#delete_discoverer/4","title":"AWS.Schemas.delete_discoverer/4","type":"function"},{"doc":"Deletes a Registry.","ref":"AWS.Schemas.html#delete_registry/4","title":"AWS.Schemas.delete_registry/4","type":"function"},{"doc":"Delete the resource-based policy attached to the specified registry.","ref":"AWS.Schemas.html#delete_resource_policy/3","title":"AWS.Schemas.delete_resource_policy/3","type":"function"},{"doc":"Delete a schema definition.","ref":"AWS.Schemas.html#delete_schema/5","title":"AWS.Schemas.delete_schema/5","type":"function"},{"doc":"Delete the schema version definition","ref":"AWS.Schemas.html#delete_schema_version/6","title":"AWS.Schemas.delete_schema_version/6","type":"function"},{"doc":"Describe the code binding URI.","ref":"AWS.Schemas.html#describe_code_binding/6","title":"AWS.Schemas.describe_code_binding/6","type":"function"},{"doc":"Describes the discoverer.","ref":"AWS.Schemas.html#describe_discoverer/3","title":"AWS.Schemas.describe_discoverer/3","type":"function"},{"doc":"Describes the registry.","ref":"AWS.Schemas.html#describe_registry/3","title":"AWS.Schemas.describe_registry/3","type":"function"},{"doc":"Retrieve the schema definition.","ref":"AWS.Schemas.html#describe_schema/5","title":"AWS.Schemas.describe_schema/5","type":"function"},{"doc":"Exports a schema to a different specification.","ref":"AWS.Schemas.html#export_schema/6","title":"AWS.Schemas.export_schema/6","type":"function"},{"doc":"Get the code binding source URI.","ref":"AWS.Schemas.html#get_code_binding_source/6","title":"AWS.Schemas.get_code_binding_source/6","type":"function"},{"doc":"Get the discovered schema that was generated based on sampled events.","ref":"AWS.Schemas.html#get_discovered_schema/3","title":"AWS.Schemas.get_discovered_schema/3","type":"function"},{"doc":"Retrieves the resource-based policy attached to a given registry.","ref":"AWS.Schemas.html#get_resource_policy/3","title":"AWS.Schemas.get_resource_policy/3","type":"function"},{"doc":"List the discoverers.","ref":"AWS.Schemas.html#list_discoverers/6","title":"AWS.Schemas.list_discoverers/6","type":"function"},{"doc":"List the registries.","ref":"AWS.Schemas.html#list_registries/6","title":"AWS.Schemas.list_registries/6","type":"function"},{"doc":"Provides a list of the schema versions and related information.","ref":"AWS.Schemas.html#list_schema_versions/6","title":"AWS.Schemas.list_schema_versions/6","type":"function"},{"doc":"List the schemas.","ref":"AWS.Schemas.html#list_schemas/6","title":"AWS.Schemas.list_schemas/6","type":"function"},{"doc":"Get tags for resource.","ref":"AWS.Schemas.html#list_tags_for_resource/3","title":"AWS.Schemas.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.Schemas.html#metadata/0","title":"AWS.Schemas.metadata/0","type":"function"},{"doc":"Put code binding URI","ref":"AWS.Schemas.html#put_code_binding/6","title":"AWS.Schemas.put_code_binding/6","type":"function"},{"doc":"The name of the policy.","ref":"AWS.Schemas.html#put_resource_policy/3","title":"AWS.Schemas.put_resource_policy/3","type":"function"},{"doc":"Search the schemas","ref":"AWS.Schemas.html#search_schemas/6","title":"AWS.Schemas.search_schemas/6","type":"function"},{"doc":"Starts the discoverer","ref":"AWS.Schemas.html#start_discoverer/4","title":"AWS.Schemas.start_discoverer/4","type":"function"},{"doc":"Stops the discoverer","ref":"AWS.Schemas.html#stop_discoverer/4","title":"AWS.Schemas.stop_discoverer/4","type":"function"},{"doc":"Add tags to a resource.","ref":"AWS.Schemas.html#tag_resource/4","title":"AWS.Schemas.tag_resource/4","type":"function"},{"doc":"Removes tags from a resource.","ref":"AWS.Schemas.html#untag_resource/4","title":"AWS.Schemas.untag_resource/4","type":"function"},{"doc":"Updates the discoverer","ref":"AWS.Schemas.html#update_discoverer/4","title":"AWS.Schemas.update_discoverer/4","type":"function"},{"doc":"Updates a registry.","ref":"AWS.Schemas.html#update_registry/4","title":"AWS.Schemas.update_registry/4","type":"function"},{"doc":"Updates the schema definition\n\nInactive schemas will be deleted after two years.","ref":"AWS.Schemas.html#update_schema/5","title":"AWS.Schemas.update_schema/5","type":"function"},{"doc":"Amazon Web Services Secrets Manager\n\nAmazon Web Services Secrets Manager provides a service to enable you to store,\nmanage, and retrieve, secrets.\n\nThis guide provides descriptions of the Secrets Manager API. For more\ninformation about using this service, see the [Amazon Web Services Secrets Manager User\nGuide](https://docs.aws.amazon.com/secretsmanager/latest/userguide/introduction.html).","ref":"AWS.SecretsManager.html","title":"AWS.SecretsManager","type":"module"},{"doc":"This version of the Secrets Manager API Reference documents the Secrets Manager\nAPI version 2017-10-17.\n\nFor a list of endpoints, see [Amazon Web Services Secrets Manager endpoints](https://docs.aws.amazon.com/secretsmanager/latest/userguide/asm_access.html#endpoints).","ref":"AWS.SecretsManager.html#module-api-version","title":"API Version - AWS.SecretsManager","type":"module"},{"doc":"We welcome your feedback. Send your comments to\n[awssecretsmanager-feedback@amazon.com](mailto:awssecretsmanager-feedback@amazon.com), or post your feedback and questions in the [Amazon Web Services Secrets Manager\nDiscussion Forum](http://forums.aws.amazon.com/forum.jspa?forumID=296). For more\ninformation about the Amazon Web Services Discussion Forums, see [Forums Help](http://forums.aws.amazon.com/help.jspa).","ref":"AWS.SecretsManager.html#module-support-and-feedback-for-amazon-web-services-secrets-manager","title":"Support and Feedback for Amazon Web Services Secrets Manager - AWS.SecretsManager","type":"module"},{"doc":"Amazon Web Services Secrets Manager supports Amazon Web Services CloudTrail, a\nservice that records Amazon Web Services API calls for your Amazon Web Services\naccount and delivers log files to an Amazon S3 bucket. By using information\nthat's collected by Amazon Web Services CloudTrail, you can determine the\nrequests successfully made to Secrets Manager, who made the request, when it was\nmade, and so on. For more about Amazon Web Services Secrets Manager and support\nfor Amazon Web Services CloudTrail, see [Logging Amazon Web Services Secrets Manager Events with Amazon Web Services\nCloudTrail](https://docs.aws.amazon.com/secretsmanager/latest/userguide/monitoring.html#monitoring_cloudtrail)\nin the *Amazon Web Services Secrets Manager User Guide*. To learn more about\nCloudTrail, including enabling it and find your log files, see the [Amazon Web Services CloudTrail User\nGuide](https://docs.aws.amazon.com/awscloudtrail/latest/userguide/what_is_cloud_trail_top_level.html).","ref":"AWS.SecretsManager.html#module-logging-api-requests","title":"Logging API Requests - AWS.SecretsManager","type":"module"},{"doc":"Retrieves the contents of the encrypted fields `SecretString` or `SecretBinary`\nfor up to 20 secrets.\n\nTo retrieve a single secret, call `GetSecretValue`.\n\nTo choose which secrets to retrieve, you can specify a list of secrets by name\nor ARN, or you can use filters. If Secrets Manager encounters errors such as\n`AccessDeniedException` while attempting to retrieve any of the secrets, you can\nsee the errors in `Errors` in the response.\n\nSecrets Manager generates CloudTrail `GetSecretValue` log entries for each\nsecret you request when you call this action. Do not include sensitive\ninformation in request parameters because it might be logged. For more\ninformation, see [Logging Secrets Manager events with CloudTrail](https://docs.aws.amazon.com/secretsmanager/latest/userguide/retrieve-ct-entries.html).\n\n**Required permissions: ** `secretsmanager:BatchGetSecretValue`, and you must\nhave `secretsmanager:GetSecretValue` for each secret. If you use filters, you\nmust also have `secretsmanager:ListSecrets`. If the secrets are encrypted using\ncustomer-managed keys instead of the Amazon Web Services managed key\n`aws/secretsmanager`, then you also need `kms:Decrypt` permissions for the keys.\nFor more information, see [ IAM policy actions for Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#reference_iam-permissions_actions)\nand [Authentication and access control in Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/auth-and-access.html).","ref":"AWS.SecretsManager.html#batch_get_secret_value/3","title":"AWS.SecretsManager.batch_get_secret_value/3","type":"function"},{"doc":"Turns off automatic rotation, and if a rotation is currently in progress,\ncancels the rotation.\n\nIf you cancel a rotation in progress, it can leave the `VersionStage` labels in\nan unexpected state. You might need to remove the staging label `AWSPENDING`\nfrom the partially created version. You also need to determine whether to roll\nback to the previous version of the secret by moving the staging label\n`AWSCURRENT` to the version that has `AWSPENDING`. To determine which version\nhas a specific staging label, call `ListSecretVersionIds`. Then use\n`UpdateSecretVersionStage` to change staging labels. For more information, see\n[How rotation works](https://docs.aws.amazon.com/secretsmanager/latest/userguide/rotate-secrets_how.html).\n\nTo turn on automatic rotation again, call `RotateSecret`.\n\nSecrets Manager generates a CloudTrail log entry when you call this action. Do\nnot include sensitive information in request parameters because it might be\nlogged. For more information, see [Logging Secrets Manager events with CloudTrail](https://docs.aws.amazon.com/secretsmanager/latest/userguide/retrieve-ct-entries.html).\n\n**Required permissions: ** `secretsmanager:CancelRotateSecret`. For more\ninformation, see [ IAM policy actions for Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#reference_iam-permissions_actions)\nand [Authentication and access control in Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/auth-and-access.html).","ref":"AWS.SecretsManager.html#cancel_rotate_secret/3","title":"AWS.SecretsManager.cancel_rotate_secret/3","type":"function"},{"doc":"Creates a new secret.\n\nA *secret* can be a password, a set of credentials such as a user name and\npassword, an OAuth token, or other secret information that you store in an\nencrypted form in Secrets Manager. The secret also includes the connection\ninformation to access a database or other service, which Secrets Manager doesn't\nencrypt. A secret in Secrets Manager consists of both the protected secret data\nand the important information needed to manage the secret.\n\nFor secrets that use *managed rotation*, you need to create the secret through\nthe managing service. For more information, see [Secrets Manager secrets managed by other Amazon Web Services\nservices](https://docs.aws.amazon.com/secretsmanager/latest/userguide/service-linked-secrets.html).\n\nFor information about creating a secret in the console, see [Create a secret](https://docs.aws.amazon.com/secretsmanager/latest/userguide/manage_create-basic-secret.html).\n\nTo create a secret, you can provide the secret value to be encrypted in either\nthe `SecretString` parameter or the `SecretBinary` parameter, but not both. If\nyou include `SecretString` or `SecretBinary` then Secrets Manager creates an\ninitial secret version and automatically attaches the staging label `AWSCURRENT`\nto it.\n\nFor database credentials you want to rotate, for Secrets Manager to be able to\nrotate the secret, you must make sure the JSON you store in the `SecretString`\nmatches the [JSON structure of a database secret](https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_secret_json_structure.html).\n\nIf you don't specify an KMS encryption key, Secrets Manager uses the Amazon Web\nServices managed key `aws/secretsmanager`. If this key doesn't already exist in\nyour account, then Secrets Manager creates it for you automatically. All users\nand roles in the Amazon Web Services account automatically have access to use\n`aws/secretsmanager`. Creating `aws/secretsmanager` can result in a one-time\nsignificant delay in returning the result.\n\nIf the secret is in a different Amazon Web Services account from the credentials\ncalling the API, then you can't use `aws/secretsmanager` to encrypt the secret,\nand you must create and use a customer managed KMS key.\n\nSecrets Manager generates a CloudTrail log entry when you call this action. Do\nnot include sensitive information in request parameters except `SecretBinary` or\n`SecretString` because it might be logged. For more information, see [Logging Secrets Manager events with\nCloudTrail](https://docs.aws.amazon.com/secretsmanager/latest/userguide/retrieve-ct-entries.html).\n\n**Required permissions: ** `secretsmanager:CreateSecret`. If you include tags in\nthe secret, you also need `secretsmanager:TagResource`. For more information,\nsee [ IAM policy actions for Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#reference_iam-permissions_actions)\nand [Authentication and access control in Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/auth-and-access.html).\n\nTo encrypt the secret with a KMS key other than `aws/secretsmanager`, you need\n`kms:GenerateDataKey` and `kms:Decrypt` permission to the key.","ref":"AWS.SecretsManager.html#create_secret/3","title":"AWS.SecretsManager.create_secret/3","type":"function"},{"doc":"Deletes the resource-based permission policy attached to the secret.\n\nTo attach a policy to a secret, use `PutResourcePolicy`.\n\nSecrets Manager generates a CloudTrail log entry when you call this action. Do\nnot include sensitive information in request parameters because it might be\nlogged. For more information, see [Logging Secrets Manager events with CloudTrail](https://docs.aws.amazon.com/secretsmanager/latest/userguide/retrieve-ct-entries.html).\n\n**Required permissions: ** `secretsmanager:DeleteResourcePolicy`. For more\ninformation, see [ IAM policy actions for Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#reference_iam-permissions_actions)\nand [Authentication and access control in Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/auth-and-access.html).","ref":"AWS.SecretsManager.html#delete_resource_policy/3","title":"AWS.SecretsManager.delete_resource_policy/3","type":"function"},{"doc":"Deletes a secret and all of its versions.\n\nYou can specify a recovery window during which you can restore the secret. The\nminimum recovery window is 7 days. The default recovery window is 30 days.\nSecrets Manager attaches a `DeletionDate` stamp to the secret that specifies the\nend of the recovery window. At the end of the recovery window, Secrets Manager\ndeletes the secret permanently.\n\nYou can't delete a primary secret that is replicated to other Regions. You must\nfirst delete the replicas using `RemoveRegionsFromReplication`, and then delete\nthe primary secret. When you delete a replica, it is deleted immediately.\n\nYou can't directly delete a version of a secret. Instead, you remove all staging\nlabels from the version using `UpdateSecretVersionStage`. This marks the version\nas deprecated, and then Secrets Manager can automatically delete the version in\nthe background.\n\nTo determine whether an application still uses a secret, you can create an\nAmazon CloudWatch alarm to alert you to any attempts to access a secret during\nthe recovery window. For more information, see [ Monitor secrets scheduled for deletion](https://docs.aws.amazon.com/secretsmanager/latest/userguide/monitoring_cloudwatch_deleted-secrets.html).\n\nSecrets Manager performs the permanent secret deletion at the end of the waiting\nperiod as a background task with low priority. There is no guarantee of a\nspecific time after the recovery window for the permanent delete to occur.\n\nAt any time before recovery window ends, you can use `RestoreSecret` to remove\nthe `DeletionDate` and cancel the deletion of the secret.\n\nWhen a secret is scheduled for deletion, you cannot retrieve the secret value.\nYou must first cancel the deletion with `RestoreSecret` and then you can\nretrieve the secret.\n\nSecrets Manager generates a CloudTrail log entry when you call this action. Do\nnot include sensitive information in request parameters because it might be\nlogged. For more information, see [Logging Secrets Manager events with CloudTrail](https://docs.aws.amazon.com/secretsmanager/latest/userguide/retrieve-ct-entries.html).\n\n**Required permissions: ** `secretsmanager:DeleteSecret`. For more information,\nsee [ IAM policy actions for Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#reference_iam-permissions_actions)\nand [Authentication and access control in Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/auth-and-access.html).","ref":"AWS.SecretsManager.html#delete_secret/3","title":"AWS.SecretsManager.delete_secret/3","type":"function"},{"doc":"Retrieves the details of a secret.\n\nIt does not include the encrypted secret value. Secrets Manager only returns\nfields that have a value in the response.\n\nSecrets Manager generates a CloudTrail log entry when you call this action. Do\nnot include sensitive information in request parameters because it might be\nlogged. For more information, see [Logging Secrets Manager events with CloudTrail](https://docs.aws.amazon.com/secretsmanager/latest/userguide/retrieve-ct-entries.html).\n\n**Required permissions: ** `secretsmanager:DescribeSecret`. For more\ninformation, see [ IAM policy actions for Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#reference_iam-permissions_actions)\nand [Authentication and access control in Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/auth-and-access.html).","ref":"AWS.SecretsManager.html#describe_secret/3","title":"AWS.SecretsManager.describe_secret/3","type":"function"},{"doc":"Generates a random password.\n\nWe recommend that you specify the maximum length and include every character\ntype that the system you are generating a password for can support. By default,\nSecrets Manager uses uppercase and lowercase letters, numbers, and the following\ncharacters in passwords: `!\"#$%&'()*+,-./:;<=>?@[\\]^_`{|}~`  Secrets Manager generates a CloudTrail log entry when you call this action. Do\nnot include sensitive information in request parameters because it might be\nlogged. For more information, see [Logging Secrets Manager events with\nCloudTrail](https://docs.aws.amazon.com/secretsmanager/latest/userguide/retrieve-ct-entries.html).\n\n**Required permissions: ** `secretsmanager:GetRandomPassword`. For more\ninformation, see [ IAM policy actions for Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#reference_iam-permissions_actions)\nand [Authentication and access control in Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/auth-and-access.html).","ref":"AWS.SecretsManager.html#get_random_password/3","title":"AWS.SecretsManager.get_random_password/3","type":"function"},{"doc":"Retrieves the JSON text of the resource-based policy document attached to the\nsecret.\n\nFor more information about permissions policies attached to a secret, see\n[Permissions policies attached to a secret](https://docs.aws.amazon.com/secretsmanager/latest/userguide/auth-and-access_resource-policies.html).\n\nSecrets Manager generates a CloudTrail log entry when you call this action. Do\nnot include sensitive information in request parameters because it might be\nlogged. For more information, see [Logging Secrets Manager events with CloudTrail](https://docs.aws.amazon.com/secretsmanager/latest/userguide/retrieve-ct-entries.html).\n\n**Required permissions: ** `secretsmanager:GetResourcePolicy`. For more\ninformation, see [ IAM policy actions for Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#reference_iam-permissions_actions)\nand [Authentication and access control in Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/auth-and-access.html).","ref":"AWS.SecretsManager.html#get_resource_policy/3","title":"AWS.SecretsManager.get_resource_policy/3","type":"function"},{"doc":"Retrieves the contents of the encrypted fields `SecretString` or `SecretBinary`\nfrom the specified version of a secret, whichever contains content.\n\nTo retrieve the values for a group of secrets, call `BatchGetSecretValue`.\n\nWe recommend that you cache your secret values by using client-side caching.\nCaching secrets improves speed and reduces your costs. For more information, see\n[Cache secrets for your applications](https://docs.aws.amazon.com/secretsmanager/latest/userguide/retrieving-secrets.html).\n\nTo retrieve the previous version of a secret, use `VersionStage` and specify\nAWSPREVIOUS. To revert to the previous version of a secret, call\n[UpdateSecretVersionStage](https://docs.aws.amazon.com/cli/latest/reference/secretsmanager/update-secret-version-stage.html).  Secrets Manager generates a CloudTrail log entry when you call this action. Do\nnot include sensitive information in request parameters because it might be\nlogged. For more information, see [Logging Secrets Manager events with\nCloudTrail](https://docs.aws.amazon.com/secretsmanager/latest/userguide/retrieve-ct-entries.html).\n\n**Required permissions: ** `secretsmanager:GetSecretValue`. If the secret is\nencrypted using a customer-managed key instead of the Amazon Web Services\nmanaged key `aws/secretsmanager`, then you also need `kms:Decrypt` permissions\nfor that key. For more information, see [ IAM policy actions for Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#reference_iam-permissions_actions)\nand [Authentication and access control in Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/auth-and-access.html).","ref":"AWS.SecretsManager.html#get_secret_value/3","title":"AWS.SecretsManager.get_secret_value/3","type":"function"},{"doc":"Lists the versions of a secret.\n\nSecrets Manager uses staging labels to indicate the different versions of a\nsecret. For more information, see [ Secrets Manager concepts: Versions](https://docs.aws.amazon.com/secretsmanager/latest/userguide/getting-started.html#term_version).\n\nTo list the secrets in the account, use `ListSecrets`.\n\nSecrets Manager generates a CloudTrail log entry when you call this action. Do\nnot include sensitive information in request parameters because it might be\nlogged. For more information, see [Logging Secrets Manager events with CloudTrail](https://docs.aws.amazon.com/secretsmanager/latest/userguide/retrieve-ct-entries.html).\n\n**Required permissions: ** `secretsmanager:ListSecretVersionIds`. For more\ninformation, see [ IAM policy actions for Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#reference_iam-permissions_actions)\nand [Authentication and access control in Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/auth-and-access.html).","ref":"AWS.SecretsManager.html#list_secret_version_ids/3","title":"AWS.SecretsManager.list_secret_version_ids/3","type":"function"},{"doc":"Lists the secrets that are stored by Secrets Manager in the Amazon Web Services\naccount, not including secrets that are marked for deletion.\n\nTo see secrets marked for deletion, use the Secrets Manager console.\n\nListSecrets is eventually consistent, however it might not reflect changes from\nthe last five minutes. To get the latest information for a specific secret, use\n`DescribeSecret`.\n\nTo list the versions of a secret, use `ListSecretVersionIds`.\n\nTo retrieve the values for the secrets, call `BatchGetSecretValue` or\n`GetSecretValue`.\n\nFor information about finding secrets in the console, see [Find secrets in Secrets\nManager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/manage_search-secret.html).\n\nSecrets Manager generates a CloudTrail log entry when you call this action. Do\nnot include sensitive information in request parameters because it might be\nlogged. For more information, see [Logging Secrets Manager events with CloudTrail](https://docs.aws.amazon.com/secretsmanager/latest/userguide/retrieve-ct-entries.html).\n\n**Required permissions: ** `secretsmanager:ListSecrets`. For more information,\nsee [ IAM policy actions for Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#reference_iam-permissions_actions)\nand [Authentication and access control in Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/auth-and-access.html).","ref":"AWS.SecretsManager.html#list_secrets/3","title":"AWS.SecretsManager.list_secrets/3","type":"function"},{"doc":"","ref":"AWS.SecretsManager.html#metadata/0","title":"AWS.SecretsManager.metadata/0","type":"function"},{"doc":"Attaches a resource-based permission policy to a secret.\n\nA resource-based policy is optional. For more information, see [Authentication and access control for Secrets\nManager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/auth-and-access.html)\n\nFor information about attaching a policy in the console, see [Attach a permissions policy to a\nsecret](https://docs.aws.amazon.com/secretsmanager/latest/userguide/auth-and-access_resource-based-policies.html).\n\nSecrets Manager generates a CloudTrail log entry when you call this action. Do\nnot include sensitive information in request parameters because it might be\nlogged. For more information, see [Logging Secrets Manager events with CloudTrail](https://docs.aws.amazon.com/secretsmanager/latest/userguide/retrieve-ct-entries.html).\n\n**Required permissions: ** `secretsmanager:PutResourcePolicy`. For more\ninformation, see [ IAM policy actions for Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#reference_iam-permissions_actions)\nand [Authentication and access control in Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/auth-and-access.html).","ref":"AWS.SecretsManager.html#put_resource_policy/3","title":"AWS.SecretsManager.put_resource_policy/3","type":"function"},{"doc":"Creates a new version with a new encrypted secret value and attaches it to the\nsecret.\n\nThe version can contain a new `SecretString` value or a new `SecretBinary`\nvalue.\n\nWe recommend you avoid calling `PutSecretValue` at a sustained rate of more than\nonce every 10 minutes. When you update the secret value, Secrets Manager creates\na new version of the secret. Secrets Manager removes outdated versions when\nthere are more than 100, but it does not remove versions created less than 24\nhours ago. If you call `PutSecretValue` more than once every 10 minutes, you\ncreate more versions than Secrets Manager removes, and you will reach the quota\nfor secret versions.\n\nYou can specify the staging labels to attach to the new version in\n`VersionStages`. If you don't include `VersionStages`, then Secrets Manager\nautomatically moves the staging label `AWSCURRENT` to this version. If this\noperation creates the first version for the secret, then Secrets Manager\nautomatically attaches the staging label `AWSCURRENT` to it. If this operation\nmoves the staging label `AWSCURRENT` from another version to this version, then\nSecrets Manager also automatically moves the staging label `AWSPREVIOUS` to the\nversion that `AWSCURRENT` was removed from.\n\nThis operation is idempotent. If you call this operation with a\n`ClientRequestToken` that matches an existing version's VersionId, and you\nspecify the same secret data, the operation succeeds but does nothing. However,\nif the secret data is different, then the operation fails because you can't\nmodify an existing version; you can only create new ones.\n\nSecrets Manager generates a CloudTrail log entry when you call this action. Do\nnot include sensitive information in request parameters except `SecretBinary` or\n`SecretString` because it might be logged. For more information, see [Logging Secrets Manager events with\nCloudTrail](https://docs.aws.amazon.com/secretsmanager/latest/userguide/retrieve-ct-entries.html).\n\n**Required permissions: ** `secretsmanager:PutSecretValue`. For more\ninformation, see [ IAM policy actions for Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#reference_iam-permissions_actions)\nand [Authentication and access control in Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/auth-and-access.html).","ref":"AWS.SecretsManager.html#put_secret_value/3","title":"AWS.SecretsManager.put_secret_value/3","type":"function"},{"doc":"For a secret that is replicated to other Regions, deletes the secret replicas\nfrom the Regions you specify.\n\nSecrets Manager generates a CloudTrail log entry when you call this action. Do\nnot include sensitive information in request parameters because it might be\nlogged. For more information, see [Logging Secrets Manager events with CloudTrail](https://docs.aws.amazon.com/secretsmanager/latest/userguide/retrieve-ct-entries.html).\n\n**Required permissions: ** `secretsmanager:RemoveRegionsFromReplication`. For\nmore information, see [ IAM policy actions for Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#reference_iam-permissions_actions)\nand [Authentication and access control in Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/auth-and-access.html).","ref":"AWS.SecretsManager.html#remove_regions_from_replication/3","title":"AWS.SecretsManager.remove_regions_from_replication/3","type":"function"},{"doc":"Replicates the secret to a new Regions.\n\nSee [Multi-Region secrets](https://docs.aws.amazon.com/secretsmanager/latest/userguide/create-manage-multi-region-secrets.html).\n\nSecrets Manager generates a CloudTrail log entry when you call this action. Do\nnot include sensitive information in request parameters because it might be\nlogged. For more information, see [Logging Secrets Manager events with CloudTrail](https://docs.aws.amazon.com/secretsmanager/latest/userguide/retrieve-ct-entries.html).\n\n**Required permissions: ** `secretsmanager:ReplicateSecretToRegions`. If the\nprimary secret is encrypted with a KMS key other than `aws/secretsmanager`, you\nalso need `kms:Decrypt` permission to the key. To encrypt the replicated secret\nwith a KMS key other than `aws/secretsmanager`, you need `kms:GenerateDataKey`\nand `kms:Encrypt` to the key. For more information, see [ IAM policy actions for Secrets\nManager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#reference_iam-permissions_actions)\nand [Authentication and access control in Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/auth-and-access.html).","ref":"AWS.SecretsManager.html#replicate_secret_to_regions/3","title":"AWS.SecretsManager.replicate_secret_to_regions/3","type":"function"},{"doc":"Cancels the scheduled deletion of a secret by removing the `DeletedDate` time\nstamp.\n\nYou can access a secret again after it has been restored.\n\nSecrets Manager generates a CloudTrail log entry when you call this action. Do\nnot include sensitive information in request parameters because it might be\nlogged. For more information, see [Logging Secrets Manager events with CloudTrail](https://docs.aws.amazon.com/secretsmanager/latest/userguide/retrieve-ct-entries.html).\n\n**Required permissions: ** `secretsmanager:RestoreSecret`. For more information,\nsee [ IAM policy actions for Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#reference_iam-permissions_actions)\nand [Authentication and access control in Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/auth-and-access.html).","ref":"AWS.SecretsManager.html#restore_secret/3","title":"AWS.SecretsManager.restore_secret/3","type":"function"},{"doc":"Configures and starts the asynchronous process of rotating the secret.\n\nFor information about rotation, see [Rotate secrets](https://docs.aws.amazon.com/secretsmanager/latest/userguide/rotating-secrets.html)\nin the *Secrets Manager User Guide*. If you include the configuration\nparameters, the operation sets the values for the secret and then immediately\nstarts a rotation. If you don't include the configuration parameters, the\noperation starts a rotation with the values already stored in the secret.\n\nWhen rotation is successful, the `AWSPENDING` staging label might be attached to\nthe same version as the `AWSCURRENT` version, or it might not be attached to any\nversion. If the `AWSPENDING` staging label is present but not attached to the\nsame version as `AWSCURRENT`, then any later invocation of `RotateSecret`\nassumes that a previous rotation request is still in progress and returns an\nerror. When rotation is unsuccessful, the `AWSPENDING` staging label might be\nattached to an empty secret version. For more information, see [Troubleshoot rotation](https://docs.aws.amazon.com/secretsmanager/latest/userguide/troubleshoot_rotation.html)\nin the *Secrets Manager User Guide*.\n\nSecrets Manager generates a CloudTrail log entry when you call this action. Do\nnot include sensitive information in request parameters because it might be\nlogged. For more information, see [Logging Secrets Manager events with CloudTrail](https://docs.aws.amazon.com/secretsmanager/latest/userguide/retrieve-ct-entries.html).\n\n**Required permissions: ** `secretsmanager:RotateSecret`. For more information,\nsee [ IAM policy actions for Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#reference_iam-permissions_actions)\nand [Authentication and access control in Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/auth-and-access.html).\nYou also need `lambda:InvokeFunction` permissions on the rotation function. For\nmore information, see [ Permissions for rotation](https://docs.aws.amazon.com/secretsmanager/latest/userguide/rotating-secrets-required-permissions-function.html).","ref":"AWS.SecretsManager.html#rotate_secret/3","title":"AWS.SecretsManager.rotate_secret/3","type":"function"},{"doc":"Removes the link between the replica secret and the primary secret and promotes\nthe replica to a primary secret in the replica Region.\n\nYou must call this operation from the Region in which you want to promote the\nreplica to a primary secret.\n\nSecrets Manager generates a CloudTrail log entry when you call this action. Do\nnot include sensitive information in request parameters because it might be\nlogged. For more information, see [Logging Secrets Manager events with CloudTrail](https://docs.aws.amazon.com/secretsmanager/latest/userguide/retrieve-ct-entries.html).\n\n**Required permissions: ** `secretsmanager:StopReplicationToReplica`. For more\ninformation, see [ IAM policy actions for Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#reference_iam-permissions_actions)\nand [Authentication and access control in Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/auth-and-access.html).","ref":"AWS.SecretsManager.html#stop_replication_to_replica/3","title":"AWS.SecretsManager.stop_replication_to_replica/3","type":"function"},{"doc":"Attaches tags to a secret.\n\nTags consist of a key name and a value. Tags are part of the secret's metadata.\nThey are not associated with specific versions of the secret. This operation\nappends tags to the existing list of tags.\n\nFor tag quotas and naming restrictions, see [Service quotas for Tagging](https://docs.aws.amazon.com/general/latest/gr/arg.html#taged-reference-quotas)\nin the *Amazon Web Services General Reference guide*.\n\nIf you use tags as part of your security strategy, then adding or removing a tag\ncan change permissions. If successfully completing this operation would result\nin you losing your permissions for this secret, then the operation is blocked\nand returns an Access Denied error.\n\nSecrets Manager generates a CloudTrail log entry when you call this action. Do\nnot include sensitive information in request parameters because it might be\nlogged. For more information, see [Logging Secrets Manager events with CloudTrail](https://docs.aws.amazon.com/secretsmanager/latest/userguide/retrieve-ct-entries.html).\n\n**Required permissions: ** `secretsmanager:TagResource`. For more information,\nsee [ IAM policy actions for Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#reference_iam-permissions_actions)\nand [Authentication and access control in Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/auth-and-access.html).","ref":"AWS.SecretsManager.html#tag_resource/3","title":"AWS.SecretsManager.tag_resource/3","type":"function"},{"doc":"Removes specific tags from a secret.\n\nThis operation is idempotent. If a requested tag is not attached to the secret,\nno error is returned and the secret metadata is unchanged.\n\nIf you use tags as part of your security strategy, then removing a tag can\nchange permissions. If successfully completing this operation would result in\nyou losing your permissions for this secret, then the operation is blocked and\nreturns an Access Denied error.\n\nSecrets Manager generates a CloudTrail log entry when you call this action. Do\nnot include sensitive information in request parameters because it might be\nlogged. For more information, see [Logging Secrets Manager events with CloudTrail](https://docs.aws.amazon.com/secretsmanager/latest/userguide/retrieve-ct-entries.html).\n\n**Required permissions: ** `secretsmanager:UntagResource`. For more information,\nsee [ IAM policy actions for Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#reference_iam-permissions_actions)\nand [Authentication and access control in Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/auth-and-access.html).","ref":"AWS.SecretsManager.html#untag_resource/3","title":"AWS.SecretsManager.untag_resource/3","type":"function"},{"doc":"Modifies the details of a secret, including metadata and the secret value.\n\nTo change the secret value, you can also use `PutSecretValue`.\n\nTo change the rotation configuration of a secret, use `RotateSecret` instead.\n\nTo change a secret so that it is managed by another service, you need to\nrecreate the secret in that service. See [Secrets Manager secrets managed by other Amazon Web Services\nservices](https://docs.aws.amazon.com/secretsmanager/latest/userguide/service-linked-secrets.html).\n\nWe recommend you avoid calling `UpdateSecret` at a sustained rate of more than\nonce every 10 minutes. When you call `UpdateSecret` to update the secret value,\nSecrets Manager creates a new version of the secret. Secrets Manager removes\noutdated versions when there are more than 100, but it does not remove versions\ncreated less than 24 hours ago. If you update the secret value more than once\nevery 10 minutes, you create more versions than Secrets Manager removes, and you\nwill reach the quota for secret versions.\n\nIf you include `SecretString` or `SecretBinary` to create a new secret version,\nSecrets Manager automatically moves the staging label `AWSCURRENT` to the new\nversion. Then it attaches the label `AWSPREVIOUS` to the version that\n`AWSCURRENT` was removed from.\n\nIf you call this operation with a `ClientRequestToken` that matches an existing\nversion's `VersionId`, the operation results in an error. You can't modify an\nexisting version, you can only create a new version. To remove a version, remove\nall staging labels from it. See `UpdateSecretVersionStage`.\n\nSecrets Manager generates a CloudTrail log entry when you call this action. Do\nnot include sensitive information in request parameters except `SecretBinary` or\n`SecretString` because it might be logged. For more information, see [Logging Secrets Manager events with\nCloudTrail](https://docs.aws.amazon.com/secretsmanager/latest/userguide/retrieve-ct-entries.html).\n\n**Required permissions: ** `secretsmanager:UpdateSecret`. For more information,\nsee [ IAM policy actions for Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#reference_iam-permissions_actions)\nand [Authentication and access control in Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/auth-and-access.html).\nIf you use a customer managed key, you must also have `kms:GenerateDataKey`,\n`kms:Encrypt`, and `kms:Decrypt` permissions on the key. If you change the KMS\nkey and you don't have `kms:Encrypt` permission to the new key, Secrets Manager\ndoes not re-ecrypt existing secret versions with the new key. For more\ninformation, see [ Secret encryption and decryption](https://docs.aws.amazon.com/secretsmanager/latest/userguide/security-encryption.html).","ref":"AWS.SecretsManager.html#update_secret/3","title":"AWS.SecretsManager.update_secret/3","type":"function"},{"doc":"Modifies the staging labels attached to a version of a secret.\n\nSecrets Manager uses staging labels to track a version as it progresses through\nthe secret rotation process. Each staging label can be attached to only one\nversion at a time. To add a staging label to a version when it is already\nattached to another version, Secrets Manager first removes it from the other\nversion first and then attaches it to this one. For more information about\nversions and staging labels, see [Concepts: Version](https://docs.aws.amazon.com/secretsmanager/latest/userguide/getting-started.html#term_version).\n\nThe staging labels that you specify in the `VersionStage` parameter are added to\nthe existing list of staging labels for the version.\n\nYou can move the `AWSCURRENT` staging label to this version by including it in\nthis call.\n\nWhenever you move `AWSCURRENT`, Secrets Manager automatically moves the label\n`AWSPREVIOUS` to the version that `AWSCURRENT` was removed from.\n\nIf this action results in the last label being removed from a version, then the\nversion is considered to be 'deprecated' and can be deleted by Secrets Manager.\n\nSecrets Manager generates a CloudTrail log entry when you call this action. Do\nnot include sensitive information in request parameters because it might be\nlogged. For more information, see [Logging Secrets Manager events with CloudTrail](https://docs.aws.amazon.com/secretsmanager/latest/userguide/retrieve-ct-entries.html).\n\n**Required permissions: ** `secretsmanager:UpdateSecretVersionStage`. For more\ninformation, see [ IAM policy actions for Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#reference_iam-permissions_actions)\nand [Authentication and access control in Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/auth-and-access.html).","ref":"AWS.SecretsManager.html#update_secret_version_stage/3","title":"AWS.SecretsManager.update_secret_version_stage/3","type":"function"},{"doc":"Validates that a resource policy does not grant a wide range of principals\naccess to your secret.\n\nA resource-based policy is optional for secrets.\n\nThe API performs three checks when validating the policy:\n\n  * Sends a call to\n[Zelkova](https://aws.amazon.com/blogs/security/protect-sensitive-data-in-the-cloud-with-automated-reasoning-zelkova/), an automated reasoning engine, to ensure your resource policy does not allow\nbroad access to your secret, for example policies that use a wildcard for the\nprincipal.\n\n  * Checks for correct syntax in a policy.\n\n  * Verifies the policy does not lock out a caller.\n\nSecrets Manager generates a CloudTrail log entry when you call this action. Do\nnot include sensitive information in request parameters because it might be\nlogged. For more information, see [Logging Secrets Manager events with\nCloudTrail](https://docs.aws.amazon.com/secretsmanager/latest/userguide/retrieve-ct-entries.html).\n\n**Required permissions: ** `secretsmanager:ValidateResourcePolicy` and\n`secretsmanager:PutResourcePolicy`. For more information, see [ IAM policy actions for Secrets\nManager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#reference_iam-permissions_actions)\nand [Authentication and access control in Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/auth-and-access.html).","ref":"AWS.SecretsManager.html#validate_resource_policy/3","title":"AWS.SecretsManager.validate_resource_policy/3","type":"function"},{"doc":"Security Hub provides you with a comprehensive view of your security state in\nAmazon Web Services and helps you assess your Amazon Web Services environment\nagainst security industry standards and best practices.\n\nSecurity Hub collects security data across Amazon Web Services accounts, Amazon\nWeb Services, and supported third-party products and helps you analyze your\nsecurity trends and identify the highest priority security issues.\n\nTo help you manage the security state of your organization, Security Hub\nsupports multiple security standards. These include the Amazon Web Services\nFoundational Security Best Practices (FSBP) standard developed by Amazon Web\nServices, and external compliance frameworks such as the Center for Internet\nSecurity (CIS), the Payment Card Industry Data Security Standard (PCI DSS), and\nthe National Institute of Standards and Technology (NIST). Each standard\nincludes several security controls, each of which represents a security best\npractice. Security Hub runs checks against security controls and generates\ncontrol findings to help you assess your compliance against security best\npractices.\n\nIn addition to generating control findings, Security Hub also receives findings\nfrom other Amazon Web Services, such as Amazon GuardDuty and Amazon Inspector,\nand supported third-party products. This gives you a single pane of glass into a\nvariety of security-related issues. You can also send Security Hub findings to\nother Amazon Web Services and supported third-party products.\n\nSecurity Hub offers automation features that help you triage and remediate\nsecurity issues. For example, you can use automation rules to automatically\nupdate critical findings when a security check fails. You can also leverage the\nintegration with Amazon EventBridge to trigger automatic responses to specific\nfindings.\n\nThis guide, the *Security Hub API Reference*, provides information about the\nSecurity Hub API. This includes supported resources, HTTP methods, parameters,\nand schemas. If you're new to Security Hub, you might find it helpful to also\nreview the [ *Security Hub User Guide*\n](https://docs.aws.amazon.com/securityhub/latest/userguide/what-is-securityhub.html).\nThe user guide explains key concepts and provides procedures that demonstrate\nhow to use Security Hub features. It also provides information about topics such\nas integrating Security Hub with other Amazon Web Services.\n\nIn addition to interacting with Security Hub by making calls to the Security Hub\nAPI, you can use a current version of an Amazon Web Services command line tool\nor SDK. Amazon Web Services provides tools and SDKs that consist of libraries\nand sample code for various languages and platforms, such as PowerShell, Java,\nGo, Python, C++, and .NET. These tools and SDKs provide convenient, programmatic\naccess to Security Hub and other Amazon Web Services . They also handle tasks\nsuch as signing requests, managing errors, and retrying requests automatically.\nFor information about installing and using the Amazon Web Services tools and\nSDKs, see [Tools to Build on Amazon Web Services](http://aws.amazon.com/developer/tools/).\n\nWith the exception of operations that are related to central configuration,\nSecurity Hub API requests are executed only in the Amazon Web Services Region\nthat is currently active or in the specific Amazon Web Services Region that you\nspecify in your request. Any configuration or settings change that results from\nthe operation is applied only to that Region. To make the same change in other\nRegions, call the same API operation in each Region in which you want to apply\nthe change. When you use central configuration, API requests for enabling\nSecurity Hub, standards, and controls are executed in the home Region and all\nlinked Regions. For a list of central configuration operations, see the [Central configuration terms and\nconcepts](https://docs.aws.amazon.com/securityhub/latest/userguide/central-configuration-intro.html#central-configuration-concepts)\nsection of the *Security Hub User Guide*.\n\nThe following throttling limits apply to Security Hub API operations.\n\n  * `BatchEnableStandards` - `RateLimit` of 1 request per second.\n`BurstLimit` of 1 request per second.\n\n  * `GetFindings` - `RateLimit` of 3 requests per second. `BurstLimit`\nof 6 requests per second.\n\n  * `BatchImportFindings` - `RateLimit` of 10 requests per second.\n`BurstLimit` of 30 requests per second.\n\n  * `BatchUpdateFindings` - `RateLimit` of 10 requests per second.\n`BurstLimit` of 30 requests per second.\n\n  * `UpdateStandardsControl` - `RateLimit` of 1 request per second.\n`BurstLimit` of 5 requests per second.\n\n  * All other operations - `RateLimit` of 10 requests per second.\n`BurstLimit` of 30 requests per second.","ref":"AWS.SecurityHub.html","title":"AWS.SecurityHub","type":"module"},{"doc":"Accepts the invitation to be a member account and be monitored by the Security\nHub administrator account that the invitation was sent from.\n\nThis operation is only used by member accounts that are not added through\nOrganizations.\n\nWhen the member account accepts the invitation, permission is granted to the\nadministrator account to view findings generated in the member account.","ref":"AWS.SecurityHub.html#accept_administrator_invitation/3","title":"AWS.SecurityHub.accept_administrator_invitation/3","type":"function"},{"doc":"This method is deprecated.\n\nInstead, use `AcceptAdministratorInvitation`.\n\nThe Security Hub console continues to use `AcceptInvitation`. It will eventually\nchange to use `AcceptAdministratorInvitation`. Any IAM policies that\nspecifically control access to this function must continue to use\n`AcceptInvitation`. You should also add `AcceptAdministratorInvitation` to your\npolicies to ensure that the correct permissions are in place after the console\nbegins to use `AcceptAdministratorInvitation`.\n\nAccepts the invitation to be a member account and be monitored by the Security\nHub administrator account that the invitation was sent from.\n\nThis operation is only used by member accounts that are not added through\nOrganizations.\n\nWhen the member account accepts the invitation, permission is granted to the\nadministrator account to view findings generated in the member account.","ref":"AWS.SecurityHub.html#accept_invitation/3","title":"AWS.SecurityHub.accept_invitation/3","type":"function"},{"doc":"Deletes one or more automation rules.","ref":"AWS.SecurityHub.html#batch_delete_automation_rules/3","title":"AWS.SecurityHub.batch_delete_automation_rules/3","type":"function"},{"doc":"Disables the standards specified by the provided `StandardsSubscriptionArns`.\n\nFor more information, see [Security Standards](https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards.html)\nsection of the *Security Hub User Guide*.","ref":"AWS.SecurityHub.html#batch_disable_standards/3","title":"AWS.SecurityHub.batch_disable_standards/3","type":"function"},{"doc":"Enables the standards specified by the provided `StandardsArn`.\n\nTo obtain the ARN for a standard, use the `DescribeStandards` operation.\n\nFor more information, see the [Security Standards](https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards.html)\nsection of the *Security Hub User Guide*.","ref":"AWS.SecurityHub.html#batch_enable_standards/3","title":"AWS.SecurityHub.batch_enable_standards/3","type":"function"},{"doc":"Retrieves a list of details for automation rules based on rule Amazon Resource\nNames (ARNs).","ref":"AWS.SecurityHub.html#batch_get_automation_rules/3","title":"AWS.SecurityHub.batch_get_automation_rules/3","type":"function"},{"doc":"Returns associations between an Security Hub configuration and a batch of target\naccounts, organizational units, or the root.\n\nOnly the Security Hub delegated administrator can invoke this operation from the\nhome Region. A configuration can refer to a configuration policy or to a\nself-managed configuration.","ref":"AWS.SecurityHub.html#batch_get_configuration_policy_associations/3","title":"AWS.SecurityHub.batch_get_configuration_policy_associations/3","type":"function"},{"doc":"Provides details about a batch of security controls for the current Amazon Web\nServices account and Amazon Web Services Region.","ref":"AWS.SecurityHub.html#batch_get_security_controls/3","title":"AWS.SecurityHub.batch_get_security_controls/3","type":"function"},{"doc":"For a batch of security controls and standards, identifies whether each control\nis currently enabled or disabled in a standard.","ref":"AWS.SecurityHub.html#batch_get_standards_control_associations/3","title":"AWS.SecurityHub.batch_get_standards_control_associations/3","type":"function"},{"doc":"Imports security findings generated by a finding provider into Security Hub.\n\nThis action is requested by the finding provider to import its findings into\nSecurity Hub.\n\n`BatchImportFindings` must be called by one of the following:\n\n  * The Amazon Web Services account that is associated with a finding\nif you are using the [default product ARN](https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-custom-providers.html#securityhub-custom-providers-bfi-reqs)\nor are a partner sending findings from within a customer's Amazon Web Services\naccount. In these cases, the identifier of the account that you are calling\n`BatchImportFindings` from needs to be the same as the `AwsAccountId` attribute\nfor the finding.\n\n  * An Amazon Web Services account that Security Hub has allow-listed\nfor an official partner integration. In this case, you can call\n`BatchImportFindings` from the allow-listed account and send findings from\ndifferent customer accounts in the same batch.\n\nThe maximum allowed size for a finding is 240 Kb. An error is returned for any\nfinding larger than 240 Kb.\n\nAfter a finding is created, `BatchImportFindings` cannot be used to update the\nfollowing finding fields and objects, which Security Hub customers use to manage\ntheir investigation workflow.\n\n  * `Note`\n\n  * `UserDefinedFields`\n\n  * `VerificationState`\n\n  * `Workflow`\n\nFinding providers also should not use `BatchImportFindings` to update the\nfollowing attributes.\n\n  * `Confidence`\n\n  * `Criticality`\n\n  * `RelatedFindings`\n\n  * `Severity`\n\n  * `Types`\n\nInstead, finding providers use `FindingProviderFields` to provide values for\nthese attributes.","ref":"AWS.SecurityHub.html#batch_import_findings/3","title":"AWS.SecurityHub.batch_import_findings/3","type":"function"},{"doc":"Updates one or more automation rules based on rule Amazon Resource Names (ARNs)\nand input parameters.","ref":"AWS.SecurityHub.html#batch_update_automation_rules/3","title":"AWS.SecurityHub.batch_update_automation_rules/3","type":"function"},{"doc":"Used by Security Hub customers to update information about their investigation\ninto a finding.\n\nRequested by administrator accounts or member accounts. Administrator accounts\ncan update findings for their account and their member accounts. Member accounts\ncan update findings for their account.\n\nUpdates from `BatchUpdateFindings` do not affect the value of `UpdatedAt` for a\nfinding.\n\nAdministrator and member accounts can use `BatchUpdateFindings` to update the\nfollowing finding fields and objects.\n\n  * `Confidence`\n\n  * `Criticality`\n\n  * `Note`\n\n  * `RelatedFindings`\n\n  * `Severity`\n\n  * `Types`\n\n  * `UserDefinedFields`\n\n  * `VerificationState`\n\n  * `Workflow`\n\nYou can configure IAM policies to restrict access to fields and field values.\nFor example, you might not want member accounts to be able to suppress findings\nor change the finding severity. See [Configuring access to BatchUpdateFindings](https://docs.aws.amazon.com/securityhub/latest/userguide/finding-update-batchupdatefindings.html#batchupdatefindings-configure-access)\nin the *Security Hub User Guide*.","ref":"AWS.SecurityHub.html#batch_update_findings/3","title":"AWS.SecurityHub.batch_update_findings/3","type":"function"},{"doc":"For a batch of security controls and standards, this operation updates the\nenablement status of a control in a standard.","ref":"AWS.SecurityHub.html#batch_update_standards_control_associations/3","title":"AWS.SecurityHub.batch_update_standards_control_associations/3","type":"function"},{"doc":"Creates a custom action target in Security Hub.\n\nYou can use custom actions on findings and insights in Security Hub to trigger\ntarget actions in Amazon CloudWatch Events.","ref":"AWS.SecurityHub.html#create_action_target/3","title":"AWS.SecurityHub.create_action_target/3","type":"function"},{"doc":"Creates an automation rule based on input parameters.","ref":"AWS.SecurityHub.html#create_automation_rule/3","title":"AWS.SecurityHub.create_automation_rule/3","type":"function"},{"doc":"Creates a configuration policy with the defined configuration.\n\nOnly the Security Hub delegated administrator can invoke this operation from the\nhome Region.","ref":"AWS.SecurityHub.html#create_configuration_policy/3","title":"AWS.SecurityHub.create_configuration_policy/3","type":"function"},{"doc":"Used to enable finding aggregation.\n\nMust be called from the aggregation Region.\n\nFor more details about cross-Region replication, see [Configuring finding aggregation](https://docs.aws.amazon.com/securityhub/latest/userguide/finding-aggregation.html)\nin the *Security Hub User Guide*.","ref":"AWS.SecurityHub.html#create_finding_aggregator/3","title":"AWS.SecurityHub.create_finding_aggregator/3","type":"function"},{"doc":"Creates a custom insight in Security Hub.\n\nAn insight is a consolidation of findings that relate to a security issue that\nrequires attention or remediation.\n\nTo group the related findings in the insight, use the `GroupByAttribute`.","ref":"AWS.SecurityHub.html#create_insight/3","title":"AWS.SecurityHub.create_insight/3","type":"function"},{"doc":"Creates a member association in Security Hub between the specified accounts and\nthe account used to make the request, which is the administrator account.\n\nIf you are integrated with Organizations, then the administrator account is\ndesignated by the organization management account.\n\n`CreateMembers` is always used to add accounts that are not organization\nmembers.\n\nFor accounts that are managed using Organizations, `CreateMembers` is only used\nin the following cases:\n\n  * Security Hub is not configured to automatically add new\norganization accounts.\n\n  * The account was disassociated or deleted in Security Hub.\n\nThis action can only be used by an account that has Security Hub enabled. To\nenable Security Hub, you can use the `EnableSecurityHub` operation.\n\nFor accounts that are not organization members, you create the account\nassociation and then send an invitation to the member account. To send the\ninvitation, you use the `InviteMembers` operation. If the account owner accepts\nthe invitation, the account becomes a member account in Security Hub.\n\nAccounts that are managed using Organizations do not receive an invitation. They\nautomatically become a member account in Security Hub.\n\n  * If the organization account does not have Security Hub enabled,\nthen Security Hub and the default standards are automatically enabled. Note that\nSecurity Hub cannot be enabled automatically for the organization management\naccount. The organization management account must enable Security Hub before the\nadministrator account enables it as a member account.\n\n  * For organization accounts that already have Security Hub enabled,\nSecurity Hub does not make any other changes to those accounts. It does not\nchange their enabled standards or controls.\n\nA permissions policy is added that permits the administrator account to view the\nfindings generated in the member account.\n\nTo remove the association between the administrator and member accounts, use the\n`DisassociateFromMasterAccount` or `DisassociateMembers` operation.","ref":"AWS.SecurityHub.html#create_members/3","title":"AWS.SecurityHub.create_members/3","type":"function"},{"doc":"Declines invitations to become a member account.\n\nA prospective member account uses this operation to decline an invitation to\nbecome a member.\n\nThis operation is only called by member accounts that aren't part of an\norganization. Organization accounts don't receive invitations.","ref":"AWS.SecurityHub.html#decline_invitations/3","title":"AWS.SecurityHub.decline_invitations/3","type":"function"},{"doc":"Deletes a custom action target from Security Hub.\n\nDeleting a custom action target does not affect any findings or insights that\nwere already sent to Amazon CloudWatch Events using the custom action.","ref":"AWS.SecurityHub.html#delete_action_target/4","title":"AWS.SecurityHub.delete_action_target/4","type":"function"},{"doc":"Deletes a configuration policy.\n\nOnly the Security Hub delegated administrator can invoke this operation from the\nhome Region. For the deletion to succeed, you must first disassociate a\nconfiguration policy from target accounts, organizational units, or the root by\ninvoking the `StartConfigurationPolicyDisassociation` operation.","ref":"AWS.SecurityHub.html#delete_configuration_policy/4","title":"AWS.SecurityHub.delete_configuration_policy/4","type":"function"},{"doc":"Deletes a finding aggregator.\n\nWhen you delete the finding aggregator, you stop finding aggregation.\n\nWhen you stop finding aggregation, findings that were already aggregated to the\naggregation Region are still visible from the aggregation Region. New findings\nand finding updates are not aggregated.","ref":"AWS.SecurityHub.html#delete_finding_aggregator/4","title":"AWS.SecurityHub.delete_finding_aggregator/4","type":"function"},{"doc":"Deletes the insight specified by the `InsightArn`.","ref":"AWS.SecurityHub.html#delete_insight/4","title":"AWS.SecurityHub.delete_insight/4","type":"function"},{"doc":"Deletes invitations received by the Amazon Web Services account to become a\nmember account.\n\nA Security Hub administrator account can use this operation to delete\ninvitations sent to one or more member accounts.\n\nThis operation is only used to delete invitations that are sent to member\naccounts that aren't part of an organization. Organization accounts don't\nreceive invitations.","ref":"AWS.SecurityHub.html#delete_invitations/3","title":"AWS.SecurityHub.delete_invitations/3","type":"function"},{"doc":"Deletes the specified member accounts from Security Hub.\n\nYou can invoke this API only to delete accounts that became members through\ninvitation. You can't invoke this API to delete accounts that belong to an\nOrganizations organization.","ref":"AWS.SecurityHub.html#delete_members/3","title":"AWS.SecurityHub.delete_members/3","type":"function"},{"doc":"Returns a list of the custom action targets in Security Hub in your account.","ref":"AWS.SecurityHub.html#describe_action_targets/3","title":"AWS.SecurityHub.describe_action_targets/3","type":"function"},{"doc":"Returns details about the Hub resource in your account, including the `HubArn`\nand the time when you enabled Security Hub.","ref":"AWS.SecurityHub.html#describe_hub/3","title":"AWS.SecurityHub.describe_hub/3","type":"function"},{"doc":"Returns information about the way your organization is configured in Security\nHub.\n\nOnly the Security Hub administrator account can invoke this operation.","ref":"AWS.SecurityHub.html#describe_organization_configuration/2","title":"AWS.SecurityHub.describe_organization_configuration/2","type":"function"},{"doc":"Returns information about product integrations in Security Hub.\n\nYou can optionally provide an integration ARN. If you provide an integration\nARN, then the results only include that integration.\n\nIf you do not provide an integration ARN, then the results include all of the\navailable product integrations.","ref":"AWS.SecurityHub.html#describe_products/5","title":"AWS.SecurityHub.describe_products/5","type":"function"},{"doc":"Returns a list of the available standards in Security Hub.\n\nFor each standard, the results include the standard ARN, the name, and a\ndescription.","ref":"AWS.SecurityHub.html#describe_standards/4","title":"AWS.SecurityHub.describe_standards/4","type":"function"},{"doc":"Returns a list of security standards controls.\n\nFor each control, the results include information about whether it is currently\nenabled, the severity, and a link to remediation information.","ref":"AWS.SecurityHub.html#describe_standards_controls/5","title":"AWS.SecurityHub.describe_standards_controls/5","type":"function"},{"doc":"Disables the integration of the specified product with Security Hub.\n\nAfter the integration is disabled, findings from that product are no longer sent\nto Security Hub.","ref":"AWS.SecurityHub.html#disable_import_findings_for_product/4","title":"AWS.SecurityHub.disable_import_findings_for_product/4","type":"function"},{"doc":"Disables a Security Hub administrator account.\n\nCan only be called by the organization management account.","ref":"AWS.SecurityHub.html#disable_organization_admin_account/3","title":"AWS.SecurityHub.disable_organization_admin_account/3","type":"function"},{"doc":"Disables Security Hub in your account only in the current Amazon Web Services\nRegion.\n\nTo disable Security Hub in all Regions, you must submit one request per Region\nwhere you have enabled Security Hub.\n\nYou can't disable Security Hub in an account that is currently the Security Hub\nadministrator.\n\nWhen you disable Security Hub, your existing findings and insights and any\nSecurity Hub configuration settings are deleted after 90 days and cannot be\nrecovered. Any standards that were enabled are disabled, and your administrator\nand member account associations are removed.\n\nIf you want to save your existing findings, you must export them before you\ndisable Security Hub.","ref":"AWS.SecurityHub.html#disable_security_hub/3","title":"AWS.SecurityHub.disable_security_hub/3","type":"function"},{"doc":"Disassociates the current Security Hub member account from the associated\nadministrator account.\n\nThis operation is only used by accounts that are not part of an organization.\nFor organization accounts, only the administrator account can disassociate a\nmember account.","ref":"AWS.SecurityHub.html#disassociate_from_administrator_account/3","title":"AWS.SecurityHub.disassociate_from_administrator_account/3","type":"function"},{"doc":"This method is deprecated.\n\nInstead, use `DisassociateFromAdministratorAccount`.\n\nThe Security Hub console continues to use `DisassociateFromMasterAccount`. It\nwill eventually change to use `DisassociateFromAdministratorAccount`. Any IAM\npolicies that specifically control access to this function must continue to use\n`DisassociateFromMasterAccount`. You should also add\n`DisassociateFromAdministratorAccount` to your policies to ensure that the\ncorrect permissions are in place after the console begins to use\n`DisassociateFromAdministratorAccount`.\n\nDisassociates the current Security Hub member account from the associated\nadministrator account.\n\nThis operation is only used by accounts that are not part of an organization.\nFor organization accounts, only the administrator account can disassociate a\nmember account.","ref":"AWS.SecurityHub.html#disassociate_from_master_account/3","title":"AWS.SecurityHub.disassociate_from_master_account/3","type":"function"},{"doc":"Disassociates the specified member accounts from the associated administrator\naccount.\n\nCan be used to disassociate both accounts that are managed using Organizations\nand accounts that were invited manually.","ref":"AWS.SecurityHub.html#disassociate_members/3","title":"AWS.SecurityHub.disassociate_members/3","type":"function"},{"doc":"Enables the integration of a partner product with Security Hub.\n\nIntegrated products send findings to Security Hub.\n\nWhen you enable a product integration, a permissions policy that grants\npermission for the product to send findings to Security Hub is applied.","ref":"AWS.SecurityHub.html#enable_import_findings_for_product/3","title":"AWS.SecurityHub.enable_import_findings_for_product/3","type":"function"},{"doc":"Designates the Security Hub administrator account for an organization.\n\nCan only be called by the organization management account.","ref":"AWS.SecurityHub.html#enable_organization_admin_account/3","title":"AWS.SecurityHub.enable_organization_admin_account/3","type":"function"},{"doc":"Enables Security Hub for your account in the current Region or the Region you\nspecify in the request.\n\nWhen you enable Security Hub, you grant to Security Hub the permissions\nnecessary to gather findings from other services that are integrated with\nSecurity Hub.\n\nWhen you use the `EnableSecurityHub` operation to enable Security Hub, you also\nautomatically enable the following standards:\n\n  * Center for Internet Security (CIS) Amazon Web Services Foundations\nBenchmark v1.2.0\n\n  * Amazon Web Services Foundational Security Best Practices\n\nOther standards are not automatically enabled.\n\nTo opt out of automatically enabled standards, set `EnableDefaultStandards` to\n`false`.\n\nAfter you enable Security Hub, to enable a standard, use the\n`BatchEnableStandards` operation. To disable a standard, use the\n`BatchDisableStandards` operation.\n\nTo learn more, see the [setup information](https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-settingup.html)\nin the *Security Hub User Guide*.","ref":"AWS.SecurityHub.html#enable_security_hub/3","title":"AWS.SecurityHub.enable_security_hub/3","type":"function"},{"doc":"Provides the details for the Security Hub administrator account for the current\nmember account.\n\nCan be used by both member accounts that are managed using Organizations and\naccounts that were invited manually.","ref":"AWS.SecurityHub.html#get_administrator_account/2","title":"AWS.SecurityHub.get_administrator_account/2","type":"function"},{"doc":"Provides information about a configuration policy.\n\nOnly the Security Hub delegated administrator can invoke this operation from the\nhome Region.","ref":"AWS.SecurityHub.html#get_configuration_policy/3","title":"AWS.SecurityHub.get_configuration_policy/3","type":"function"},{"doc":"Returns the association between a configuration and a target account,\norganizational unit, or the root.\n\nThe configuration can be a configuration policy or self-managed behavior. Only\nthe Security Hub delegated administrator can invoke this operation from the home\nRegion.","ref":"AWS.SecurityHub.html#get_configuration_policy_association/3","title":"AWS.SecurityHub.get_configuration_policy_association/3","type":"function"},{"doc":"Returns a list of the standards that are currently enabled.","ref":"AWS.SecurityHub.html#get_enabled_standards/3","title":"AWS.SecurityHub.get_enabled_standards/3","type":"function"},{"doc":"Returns the current finding aggregation configuration.","ref":"AWS.SecurityHub.html#get_finding_aggregator/3","title":"AWS.SecurityHub.get_finding_aggregator/3","type":"function"},{"doc":"Returns history for a Security Hub finding in the last 90 days.\n\nThe history includes changes made to any fields in the Amazon Web Services\nSecurity Finding Format (ASFF).","ref":"AWS.SecurityHub.html#get_finding_history/3","title":"AWS.SecurityHub.get_finding_history/3","type":"function"},{"doc":"Returns a list of findings that match the specified criteria.\n\nIf finding aggregation is enabled, then when you call `GetFindings` from the\naggregation Region, the results include all of the matching findings from both\nthe aggregation Region and the linked Regions.","ref":"AWS.SecurityHub.html#get_findings/3","title":"AWS.SecurityHub.get_findings/3","type":"function"},{"doc":"Lists the results of the Security Hub insight specified by the insight ARN.","ref":"AWS.SecurityHub.html#get_insight_results/3","title":"AWS.SecurityHub.get_insight_results/3","type":"function"},{"doc":"Lists and describes insights for the specified insight ARNs.","ref":"AWS.SecurityHub.html#get_insights/3","title":"AWS.SecurityHub.get_insights/3","type":"function"},{"doc":"Returns the count of all Security Hub membership invitations that were sent to\nthe current member account, not including the currently accepted invitation.","ref":"AWS.SecurityHub.html#get_invitations_count/2","title":"AWS.SecurityHub.get_invitations_count/2","type":"function"},{"doc":"This method is deprecated.\n\nInstead, use `GetAdministratorAccount`.\n\nThe Security Hub console continues to use `GetMasterAccount`. It will eventually\nchange to use `GetAdministratorAccount`. Any IAM policies that specifically\ncontrol access to this function must continue to use `GetMasterAccount`. You\nshould also add `GetAdministratorAccount` to your policies to ensure that the\ncorrect permissions are in place after the console begins to use\n`GetAdministratorAccount`.\n\nProvides the details for the Security Hub administrator account for the current\nmember account.\n\nCan be used by both member accounts that are managed using Organizations and\naccounts that were invited manually.","ref":"AWS.SecurityHub.html#get_master_account/2","title":"AWS.SecurityHub.get_master_account/2","type":"function"},{"doc":"Returns the details for the Security Hub member accounts for the specified\naccount IDs.\n\nAn administrator account can be either the delegated Security Hub administrator\naccount for an organization or an administrator account that enabled Security\nHub manually.\n\nThe results include both member accounts that are managed using Organizations\nand accounts that were invited manually.","ref":"AWS.SecurityHub.html#get_members/3","title":"AWS.SecurityHub.get_members/3","type":"function"},{"doc":"Retrieves the definition of a security control.\n\nThe definition includes the control title, description, Region availability,\nparameter definitions, and other details.","ref":"AWS.SecurityHub.html#get_security_control_definition/3","title":"AWS.SecurityHub.get_security_control_definition/3","type":"function"},{"doc":"Invites other Amazon Web Services accounts to become member accounts for the\nSecurity Hub administrator account that the invitation is sent from.\n\nThis operation is only used to invite accounts that do not belong to an\norganization. Organization accounts do not receive invitations.\n\nBefore you can use this action to invite a member, you must first use the\n`CreateMembers` action to create the member account in Security Hub.\n\nWhen the account owner enables Security Hub and accepts the invitation to become\na member account, the administrator account can view the findings generated from\nthe member account.","ref":"AWS.SecurityHub.html#invite_members/3","title":"AWS.SecurityHub.invite_members/3","type":"function"},{"doc":"A list of automation rules and their metadata for the calling account.","ref":"AWS.SecurityHub.html#list_automation_rules/4","title":"AWS.SecurityHub.list_automation_rules/4","type":"function"},{"doc":"Lists the configuration policies that the Security Hub delegated administrator\nhas created for your organization.\n\nOnly the delegated administrator can invoke this operation from the home Region.","ref":"AWS.SecurityHub.html#list_configuration_policies/4","title":"AWS.SecurityHub.list_configuration_policies/4","type":"function"},{"doc":"Provides information about the associations for your configuration policies and\nself-managed behavior.\n\nOnly the Security Hub delegated administrator can invoke this operation from the\nhome Region.","ref":"AWS.SecurityHub.html#list_configuration_policy_associations/3","title":"AWS.SecurityHub.list_configuration_policy_associations/3","type":"function"},{"doc":"Lists all findings-generating solutions (products) that you are subscribed to\nreceive findings from in Security Hub.","ref":"AWS.SecurityHub.html#list_enabled_products_for_import/4","title":"AWS.SecurityHub.list_enabled_products_for_import/4","type":"function"},{"doc":"If finding aggregation is enabled, then `ListFindingAggregators` returns the ARN\nof the finding aggregator.\n\nYou can run this operation from any Region.","ref":"AWS.SecurityHub.html#list_finding_aggregators/4","title":"AWS.SecurityHub.list_finding_aggregators/4","type":"function"},{"doc":"Lists all Security Hub membership invitations that were sent to the current\nAmazon Web Services account.\n\nThis operation is only used by accounts that are managed by invitation. Accounts\nthat are managed using the integration with Organizations do not receive\ninvitations.","ref":"AWS.SecurityHub.html#list_invitations/4","title":"AWS.SecurityHub.list_invitations/4","type":"function"},{"doc":"Lists details about all member accounts for the current Security Hub\nadministrator account.\n\nThe results include both member accounts that belong to an organization and\nmember accounts that were invited manually.","ref":"AWS.SecurityHub.html#list_members/5","title":"AWS.SecurityHub.list_members/5","type":"function"},{"doc":"Lists the Security Hub administrator accounts.\n\nCan only be called by the organization management account.","ref":"AWS.SecurityHub.html#list_organization_admin_accounts/4","title":"AWS.SecurityHub.list_organization_admin_accounts/4","type":"function"},{"doc":"Lists all of the security controls that apply to a specified standard.","ref":"AWS.SecurityHub.html#list_security_control_definitions/5","title":"AWS.SecurityHub.list_security_control_definitions/5","type":"function"},{"doc":"Specifies whether a control is currently enabled or disabled in each enabled\nstandard in the calling account.","ref":"AWS.SecurityHub.html#list_standards_control_associations/5","title":"AWS.SecurityHub.list_standards_control_associations/5","type":"function"},{"doc":"Returns a list of tags associated with a resource.","ref":"AWS.SecurityHub.html#list_tags_for_resource/3","title":"AWS.SecurityHub.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.SecurityHub.html#metadata/0","title":"AWS.SecurityHub.metadata/0","type":"function"},{"doc":"Associates a target account, organizational unit, or the root with a specified\nconfiguration.\n\nThe target can be associated with a configuration policy or self-managed\nbehavior. Only the Security Hub delegated administrator can invoke this\noperation from the home Region.","ref":"AWS.SecurityHub.html#start_configuration_policy_association/3","title":"AWS.SecurityHub.start_configuration_policy_association/3","type":"function"},{"doc":"Disassociates a target account, organizational unit, or the root from a\nspecified configuration.\n\nWhen you disassociate a configuration from its target, the target inherits the\nconfiguration of the closest parent. If there’s no configuration to inherit, the\ntarget retains its settings but becomes a self-managed account. A target can be\ndisassociated from a configuration policy or self-managed behavior. Only the\nSecurity Hub delegated administrator can invoke this operation from the home\nRegion.","ref":"AWS.SecurityHub.html#start_configuration_policy_disassociation/3","title":"AWS.SecurityHub.start_configuration_policy_disassociation/3","type":"function"},{"doc":"Adds one or more tags to a resource.","ref":"AWS.SecurityHub.html#tag_resource/4","title":"AWS.SecurityHub.tag_resource/4","type":"function"},{"doc":"Removes one or more tags from a resource.","ref":"AWS.SecurityHub.html#untag_resource/4","title":"AWS.SecurityHub.untag_resource/4","type":"function"},{"doc":"Updates the name and description of a custom action target in Security Hub.","ref":"AWS.SecurityHub.html#update_action_target/4","title":"AWS.SecurityHub.update_action_target/4","type":"function"},{"doc":"Updates a configuration policy.\n\nOnly the Security Hub delegated administrator can invoke this operation from the\nhome Region.","ref":"AWS.SecurityHub.html#update_configuration_policy/4","title":"AWS.SecurityHub.update_configuration_policy/4","type":"function"},{"doc":"Updates the finding aggregation configuration.\n\nUsed to update the Region linking mode and the list of included or excluded\nRegions. You cannot use `UpdateFindingAggregator` to change the aggregation\nRegion.\n\nYou must run `UpdateFindingAggregator` from the current aggregation Region.","ref":"AWS.SecurityHub.html#update_finding_aggregator/3","title":"AWS.SecurityHub.update_finding_aggregator/3","type":"function"},{"doc":"`UpdateFindings` is deprecated.\n\nInstead of `UpdateFindings`, use `BatchUpdateFindings`.\n\nUpdates the `Note` and `RecordState` of the Security Hub-aggregated findings\nthat the filter attributes specify. Any member account that can view the finding\nalso sees the update to the finding.","ref":"AWS.SecurityHub.html#update_findings/3","title":"AWS.SecurityHub.update_findings/3","type":"function"},{"doc":"Updates the Security Hub insight identified by the specified insight ARN.","ref":"AWS.SecurityHub.html#update_insight/4","title":"AWS.SecurityHub.update_insight/4","type":"function"},{"doc":"Updates the configuration of your organization in Security Hub.\n\nOnly the Security Hub administrator account can invoke this operation.","ref":"AWS.SecurityHub.html#update_organization_configuration/3","title":"AWS.SecurityHub.update_organization_configuration/3","type":"function"},{"doc":"Updates the properties of a security control.","ref":"AWS.SecurityHub.html#update_security_control/3","title":"AWS.SecurityHub.update_security_control/3","type":"function"},{"doc":"Updates configuration options for Security Hub.","ref":"AWS.SecurityHub.html#update_security_hub_configuration/3","title":"AWS.SecurityHub.update_security_hub_configuration/3","type":"function"},{"doc":"Used to control whether an individual security standard control is enabled or\ndisabled.","ref":"AWS.SecurityHub.html#update_standards_control/4","title":"AWS.SecurityHub.update_standards_control/4","type":"function"},{"doc":"Amazon Security Lake is a fully managed security data lake service.\n\nYou can use Security Lake to automatically centralize security data from cloud,\non-premises, and custom sources into a data lake that's stored in your Amazon\nWeb Services account. Amazon Web Services Organizations is an account management\nservice that lets you consolidate multiple Amazon Web Services accounts into an\norganization that you create and centrally manage. With Organizations, you can\ncreate member accounts and invite existing accounts to join your organization.\nSecurity Lake helps you analyze security data for a more complete understanding\nof your security posture across the entire organization. It can also help you\nimprove the protection of your workloads, applications, and data.\n\nThe data lake is backed by Amazon Simple Storage Service (Amazon S3) buckets,\nand you retain ownership over your data.\n\nAmazon Security Lake integrates with CloudTrail, a service that provides a\nrecord of actions taken by a user, role, or an Amazon Web Services service. In\nSecurity Lake, CloudTrail captures API calls for Security Lake as events. The\ncalls captured include calls from the Security Lake console and code calls to\nthe Security Lake API operations. If you create a trail, you can enable\ncontinuous delivery of CloudTrail events to an Amazon S3 bucket, including\nevents for Security Lake. If you don't configure a trail, you can still view the\nmost recent events in the CloudTrail console in Event history. Using the\ninformation collected by CloudTrail you can determine the request that was made\nto Security Lake, the IP address from which the request was made, who made the\nrequest, when it was made, and additional details. To learn more about Security\nLake information in CloudTrail, see the [Amazon Security Lake User Guide](https://docs.aws.amazon.com/security-lake/latest/userguide/securitylake-cloudtrail.html).\n\nSecurity Lake automates the collection of security-related log and event data\nfrom integrated Amazon Web Services and third-party services. It also helps you\nmanage the lifecycle of data with customizable retention and replication\nsettings. Security Lake converts ingested data into Apache Parquet format and a\nstandard open-source schema called the Open Cybersecurity Schema Framework\n(OCSF).\n\nOther Amazon Web Services and third-party services can subscribe to the data\nthat's stored in Security Lake for incident response and security data\nanalytics.","ref":"AWS.SecurityLake.html","title":"AWS.SecurityLake","type":"module"},{"doc":"Adds a natively supported Amazon Web Service as an Amazon Security Lake source.\n\nEnables source types for member accounts in required Amazon Web Services\nRegions, based on the parameters you specify. You can choose any source type in\nany Region for either accounts that are part of a trusted organization or\nstandalone accounts. Once you add an Amazon Web Service as a source, Security\nLake starts collecting logs and events from it.\n\nYou can use this API only to enable natively supported Amazon Web Services as a\nsource. Use `CreateCustomLogSource` to enable data collection from a custom\nsource.","ref":"AWS.SecurityLake.html#create_aws_log_source/3","title":"AWS.SecurityLake.create_aws_log_source/3","type":"function"},{"doc":"Adds a third-party custom source in Amazon Security Lake, from the Amazon Web\nServices Region where you want to create a custom source.\n\nSecurity Lake can collect logs and events from third-party custom sources. After\ncreating the appropriate IAM role to invoke Glue crawler, use this API to add a\ncustom source name in Security Lake. This operation creates a partition in the\nAmazon S3 bucket for Security Lake as the target location for log files from the\ncustom source. In addition, this operation also creates an associated Glue table\nand an Glue crawler.","ref":"AWS.SecurityLake.html#create_custom_log_source/3","title":"AWS.SecurityLake.create_custom_log_source/3","type":"function"},{"doc":"Initializes an Amazon Security Lake instance with the provided (or default)\nconfiguration.\n\nYou can enable Security Lake in Amazon Web Services Regions with customized\nsettings before enabling log collection in Regions. To specify particular\nRegions, configure these Regions using the `configurations` parameter. If you\nhave already enabled Security Lake in a Region when you call this command, the\ncommand will update the Region if you provide new configuration parameters. If\nyou have not already enabled Security Lake in the Region when you call this API,\nit will set up the data lake in the Region with the specified configurations.\n\nWhen you enable Security Lake, it starts ingesting security data after the\n`CreateAwsLogSource` call. This includes ingesting security data from sources,\nstoring data, and making data accessible to subscribers. Security Lake also\nenables all the existing settings and resources that it stores or maintains for\nyour Amazon Web Services account in the current Region, including security log\nand event data. For more information, see the [Amazon Security Lake User Guide](https://docs.aws.amazon.com/security-lake/latest/userguide/what-is-security-lake.html).","ref":"AWS.SecurityLake.html#create_data_lake/3","title":"AWS.SecurityLake.create_data_lake/3","type":"function"},{"doc":"Creates the specified notification subscription in Amazon Security Lake for the\norganization you specify.","ref":"AWS.SecurityLake.html#create_data_lake_exception_subscription/3","title":"AWS.SecurityLake.create_data_lake_exception_subscription/3","type":"function"},{"doc":"Automatically enables Amazon Security Lake for new member accounts in your\norganization.\n\nSecurity Lake is not automatically enabled for any existing member accounts in\nyour organization.","ref":"AWS.SecurityLake.html#create_data_lake_organization_configuration/3","title":"AWS.SecurityLake.create_data_lake_organization_configuration/3","type":"function"},{"doc":"Creates a subscription permission for accounts that are already enabled in\nAmazon Security Lake.\n\nYou can create a subscriber with access to data in the current Amazon Web\nServices Region.","ref":"AWS.SecurityLake.html#create_subscriber/3","title":"AWS.SecurityLake.create_subscriber/3","type":"function"},{"doc":"Notifies the subscriber when new data is written to the data lake for the\nsources that the subscriber consumes in Security Lake.\n\nYou can create only one subscriber notification per subscriber.","ref":"AWS.SecurityLake.html#create_subscriber_notification/4","title":"AWS.SecurityLake.create_subscriber_notification/4","type":"function"},{"doc":"Removes a natively supported Amazon Web Service as an Amazon Security Lake\nsource.\n\nYou can remove a source for one or more Regions. When you remove the source,\nSecurity Lake stops collecting data from that source in the specified Regions\nand accounts, and subscribers can no longer consume new data from the source.\nHowever, subscribers can still consume data that Security Lake collected from\nthe source before removal.\n\nYou can choose any source type in any Amazon Web Services Region for either\naccounts that are part of a trusted organization or standalone accounts.","ref":"AWS.SecurityLake.html#delete_aws_log_source/3","title":"AWS.SecurityLake.delete_aws_log_source/3","type":"function"},{"doc":"Removes a custom log source from Amazon Security Lake, to stop sending data from\nthe custom source to Security Lake.","ref":"AWS.SecurityLake.html#delete_custom_log_source/4","title":"AWS.SecurityLake.delete_custom_log_source/4","type":"function"},{"doc":"When you disable Amazon Security Lake from your account, Security Lake is\ndisabled in all Amazon Web Services Regions and it stops collecting data from\nyour sources.\n\nAlso, this API automatically takes steps to remove the account from Security\nLake. However, Security Lake retains all of your existing settings and the\nresources that it created in your Amazon Web Services account in the current\nAmazon Web Services Region.\n\nThe `DeleteDataLake` operation does not delete the data that is stored in your\nAmazon S3 bucket, which is owned by your Amazon Web Services account. For more\ninformation, see the [Amazon Security Lake User Guide](https://docs.aws.amazon.com/security-lake/latest/userguide/disable-security-lake.html).","ref":"AWS.SecurityLake.html#delete_data_lake/3","title":"AWS.SecurityLake.delete_data_lake/3","type":"function"},{"doc":"Deletes the specified notification subscription in Amazon Security Lake for the\norganization you specify.","ref":"AWS.SecurityLake.html#delete_data_lake_exception_subscription/3","title":"AWS.SecurityLake.delete_data_lake_exception_subscription/3","type":"function"},{"doc":"Turns off automatic enablement of Amazon Security Lake for member accounts that\nare added to an organization in Organizations.\n\nOnly the delegated Security Lake administrator for an organization can perform\nthis operation. If the delegated Security Lake administrator performs this\noperation, new member accounts won't automatically contribute data to the data\nlake.","ref":"AWS.SecurityLake.html#delete_data_lake_organization_configuration/3","title":"AWS.SecurityLake.delete_data_lake_organization_configuration/3","type":"function"},{"doc":"Deletes the subscription permission and all notification settings for accounts\nthat are already enabled in Amazon Security Lake.\n\nWhen you run `DeleteSubscriber`, the subscriber will no longer consume data from\nSecurity Lake and the subscriber is removed. This operation deletes the\nsubscriber and removes access to data in the current Amazon Web Services Region.","ref":"AWS.SecurityLake.html#delete_subscriber/4","title":"AWS.SecurityLake.delete_subscriber/4","type":"function"},{"doc":"Deletes the specified notification subscription in Amazon Security Lake for the\norganization you specify.","ref":"AWS.SecurityLake.html#delete_subscriber_notification/4","title":"AWS.SecurityLake.delete_subscriber_notification/4","type":"function"},{"doc":"Deletes the Amazon Security Lake delegated administrator account for the\norganization.\n\nThis API can only be called by the organization management account. The\norganization management account cannot be the delegated administrator account.","ref":"AWS.SecurityLake.html#deregister_data_lake_delegated_administrator/3","title":"AWS.SecurityLake.deregister_data_lake_delegated_administrator/3","type":"function"},{"doc":"Retrieves the details of exception notifications for the account in Amazon\nSecurity Lake.","ref":"AWS.SecurityLake.html#get_data_lake_exception_subscription/2","title":"AWS.SecurityLake.get_data_lake_exception_subscription/2","type":"function"},{"doc":"Retrieves the configuration that will be automatically set up for accounts added\nto the organization after the organization has onboarded to Amazon Security\nLake.\n\nThis API does not take input parameters.","ref":"AWS.SecurityLake.html#get_data_lake_organization_configuration/2","title":"AWS.SecurityLake.get_data_lake_organization_configuration/2","type":"function"},{"doc":"Retrieves a snapshot of the current Region, including whether Amazon Security\nLake is enabled for those accounts and which sources Security Lake is collecting\ndata from.","ref":"AWS.SecurityLake.html#get_data_lake_sources/3","title":"AWS.SecurityLake.get_data_lake_sources/3","type":"function"},{"doc":"Retrieves the subscription information for the specified subscription ID.\n\nYou can get information about a specific subscriber.","ref":"AWS.SecurityLake.html#get_subscriber/3","title":"AWS.SecurityLake.get_subscriber/3","type":"function"},{"doc":"Lists the Amazon Security Lake exceptions that you can use to find the source of\nproblems and fix them.","ref":"AWS.SecurityLake.html#list_data_lake_exceptions/3","title":"AWS.SecurityLake.list_data_lake_exceptions/3","type":"function"},{"doc":"Retrieves the Amazon Security Lake configuration object for the specified Amazon\nWeb Services Regions.\n\nYou can use this operation to determine whether Security Lake is enabled for a\nRegion.","ref":"AWS.SecurityLake.html#list_data_lakes/3","title":"AWS.SecurityLake.list_data_lakes/3","type":"function"},{"doc":"Retrieves the log sources in the current Amazon Web Services Region.","ref":"AWS.SecurityLake.html#list_log_sources/3","title":"AWS.SecurityLake.list_log_sources/3","type":"function"},{"doc":"List all subscribers for the specific Amazon Security Lake account ID.\n\nYou can retrieve a list of subscriptions associated with a specific organization\nor Amazon Web Services account.","ref":"AWS.SecurityLake.html#list_subscribers/4","title":"AWS.SecurityLake.list_subscribers/4","type":"function"},{"doc":"Retrieves the tags (keys and values) that are associated with an Amazon Security\nLake resource: a subscriber, or the data lake configuration for your Amazon Web\nServices account in a particular Amazon Web Services Region.","ref":"AWS.SecurityLake.html#list_tags_for_resource/3","title":"AWS.SecurityLake.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.SecurityLake.html#metadata/0","title":"AWS.SecurityLake.metadata/0","type":"function"},{"doc":"Designates the Amazon Security Lake delegated administrator account for the\norganization.\n\nThis API can only be called by the organization management account. The\norganization management account cannot be the delegated administrator account.","ref":"AWS.SecurityLake.html#register_data_lake_delegated_administrator/3","title":"AWS.SecurityLake.register_data_lake_delegated_administrator/3","type":"function"},{"doc":"Adds or updates one or more tags that are associated with an Amazon Security\nLake resource: a subscriber, or the data lake configuration for your Amazon Web\nServices account in a particular Amazon Web Services Region.\n\nA *tag* is a label that you can define and associate with Amazon Web Services\nresources. Each tag consists of a required *tag key* and an associated *tag\nvalue*. A *tag key* is a general label that acts as a category for a more\nspecific tag value. A *tag value* acts as a descriptor for a tag key. Tags can\nhelp you identify, categorize, and manage resources in different ways, such as\nby owner, environment, or other criteria. For more information, see [Tagging Amazon Security Lake\nresources](https://docs.aws.amazon.com/security-lake/latest/userguide/tagging-resources.html)\nin the *Amazon Security Lake User Guide*.","ref":"AWS.SecurityLake.html#tag_resource/4","title":"AWS.SecurityLake.tag_resource/4","type":"function"},{"doc":"Removes one or more tags (keys and values) from an Amazon Security Lake\nresource: a subscriber, or the data lake configuration for your Amazon Web\nServices account in a particular Amazon Web Services Region.","ref":"AWS.SecurityLake.html#untag_resource/4","title":"AWS.SecurityLake.untag_resource/4","type":"function"},{"doc":"Specifies where to store your security data and for how long.\n\nYou can add a rollup Region to consolidate data from multiple Amazon Web\nServices Regions.","ref":"AWS.SecurityLake.html#update_data_lake/3","title":"AWS.SecurityLake.update_data_lake/3","type":"function"},{"doc":"Updates the specified notification subscription in Amazon Security Lake for the\norganization you specify.","ref":"AWS.SecurityLake.html#update_data_lake_exception_subscription/3","title":"AWS.SecurityLake.update_data_lake_exception_subscription/3","type":"function"},{"doc":"Updates an existing subscription for the given Amazon Security Lake account ID.\n\nYou can update a subscriber by changing the sources that the subscriber consumes\ndata from.","ref":"AWS.SecurityLake.html#update_subscriber/4","title":"AWS.SecurityLake.update_subscriber/4","type":"function"},{"doc":"Updates an existing notification method for the subscription (SQS or HTTPs\nendpoint) or switches the notification subscription endpoint for a subscriber.","ref":"AWS.SecurityLake.html#update_subscriber_notification/4","title":"AWS.SecurityLake.update_subscriber_notification/4","type":"function"},{"doc":"The AWS Serverless Application Repository makes it easy for developers and\nenterprises to quickly find\nand deploy serverless applications in the AWS Cloud.\n\nFor more information about serverless applications,\nsee Serverless Computing and Applications on the AWS website.\n\nThe AWS Serverless Application Repository is deeply integrated with the AWS\nLambda console, so that developers of\nall levels can get started with serverless computing without needing to learn\nanything new. You can use category\nkeywords to browse for applications such as web and mobile backends, data\nprocessing applications, or chatbots.\nYou can also search for applications by name, publisher, or event source. To use\nan application, you simply choose it,\nconfigure any required fields, and deploy it with a few clicks.\n\nYou can also easily publish applications, sharing them publicly with the\ncommunity at large, or privately\nwithin your team or across your organization. To publish a serverless\napplication (or app), you can use the\nAWS Management Console, AWS Command Line Interface (AWS CLI), or AWS SDKs to\nupload the code. Along with the\ncode, you upload a simple manifest file, also known as the AWS Serverless\nApplication Model (AWS SAM) template.\nFor more information about AWS SAM, see AWS Serverless Application Model (AWS\nSAM) on the AWS Labs\nGitHub repository.\n\nThe AWS Serverless Application Repository Developer Guide contains more\ninformation about the two developer\nexperiences available:\n\n  *\nConsuming Applications – Browse for applications and view information about\nthem, including\nsource code and readme files. Also install, configure, and deploy applications\nof your choosing.\n\nPublishing Applications – Configure and upload applications to make them\navailable to other\ndevelopers, and publish new versions of applications.","ref":"AWS.ServerlessApplicationRepository.html","title":"AWS.ServerlessApplicationRepository","type":"module"},{"doc":"Creates an application, optionally including an AWS SAM file to create the first\napplication version in the same call.","ref":"AWS.ServerlessApplicationRepository.html#create_application/3","title":"AWS.ServerlessApplicationRepository.create_application/3","type":"function"},{"doc":"Creates an application version.","ref":"AWS.ServerlessApplicationRepository.html#create_application_version/5","title":"AWS.ServerlessApplicationRepository.create_application_version/5","type":"function"},{"doc":"Creates an AWS CloudFormation change set for the given application.","ref":"AWS.ServerlessApplicationRepository.html#create_cloud_formation_change_set/4","title":"AWS.ServerlessApplicationRepository.create_cloud_formation_change_set/4","type":"function"},{"doc":"Creates an AWS CloudFormation template.","ref":"AWS.ServerlessApplicationRepository.html#create_cloud_formation_template/4","title":"AWS.ServerlessApplicationRepository.create_cloud_formation_template/4","type":"function"},{"doc":"Deletes the specified application.","ref":"AWS.ServerlessApplicationRepository.html#delete_application/4","title":"AWS.ServerlessApplicationRepository.delete_application/4","type":"function"},{"doc":"Gets the specified application.","ref":"AWS.ServerlessApplicationRepository.html#get_application/4","title":"AWS.ServerlessApplicationRepository.get_application/4","type":"function"},{"doc":"Retrieves the policy for the application.","ref":"AWS.ServerlessApplicationRepository.html#get_application_policy/3","title":"AWS.ServerlessApplicationRepository.get_application_policy/3","type":"function"},{"doc":"Gets the specified AWS CloudFormation template.","ref":"AWS.ServerlessApplicationRepository.html#get_cloud_formation_template/4","title":"AWS.ServerlessApplicationRepository.get_cloud_formation_template/4","type":"function"},{"doc":"Retrieves the list of applications nested in the containing application.","ref":"AWS.ServerlessApplicationRepository.html#list_application_dependencies/6","title":"AWS.ServerlessApplicationRepository.list_application_dependencies/6","type":"function"},{"doc":"Lists versions for the specified application.","ref":"AWS.ServerlessApplicationRepository.html#list_application_versions/5","title":"AWS.ServerlessApplicationRepository.list_application_versions/5","type":"function"},{"doc":"Lists applications owned by the requester.","ref":"AWS.ServerlessApplicationRepository.html#list_applications/4","title":"AWS.ServerlessApplicationRepository.list_applications/4","type":"function"},{"doc":"","ref":"AWS.ServerlessApplicationRepository.html#metadata/0","title":"AWS.ServerlessApplicationRepository.metadata/0","type":"function"},{"doc":"Sets the permission policy for an application.\n\nFor the list of actions supported for this operation, see\n[Application Permissions](https://docs.aws.amazon.com/serverlessrepo/latest/devguide/access-control-resource-based.html#application-permissions)\n\n.","ref":"AWS.ServerlessApplicationRepository.html#put_application_policy/4","title":"AWS.ServerlessApplicationRepository.put_application_policy/4","type":"function"},{"doc":"Unshares an application from an AWS Organization.\n\nThis operation can be called only from the organization's master account.","ref":"AWS.ServerlessApplicationRepository.html#unshare_application/4","title":"AWS.ServerlessApplicationRepository.unshare_application/4","type":"function"},{"doc":"Updates the specified application.","ref":"AWS.ServerlessApplicationRepository.html#update_application/4","title":"AWS.ServerlessApplicationRepository.update_application/4","type":"function"},{"doc":"Service Catalog\n\n[Service Catalog](http://aws.amazon.com/servicecatalog) enables organizations to create and manage catalogs of IT services that are approved for Amazon Web\nServices.\n\nTo get the most out of this documentation, you should be familiar with the\nterminology discussed in [Service Catalog\nConcepts](http://docs.aws.amazon.com/servicecatalog/latest/adminguide/what-is_concepts.html).","ref":"AWS.ServiceCatalog.html","title":"AWS.ServiceCatalog","type":"module"},{"doc":"Accepts an offer to share the specified portfolio.","ref":"AWS.ServiceCatalog.html#accept_portfolio_share/3","title":"AWS.ServiceCatalog.accept_portfolio_share/3","type":"function"},{"doc":"Associates the specified budget with the specified resource.","ref":"AWS.ServiceCatalog.html#associate_budget_with_resource/3","title":"AWS.ServiceCatalog.associate_budget_with_resource/3","type":"function"},{"doc":"Associates the specified principal ARN with the specified portfolio.\n\nIf you share the portfolio with principal name sharing enabled, the\n`PrincipalARN` association is included in the share.\n\nThe `PortfolioID`, `PrincipalARN`, and `PrincipalType` parameters are required.\n\nYou can associate a maximum of 10 Principals with a portfolio using\n`PrincipalType` as `IAM_PATTERN`.\n\nWhen you associate a principal with portfolio, a potential privilege escalation\npath may occur when that portfolio is then shared with other accounts. For a\nuser in a recipient account who is *not* an Service Catalog Admin, but still has\nthe ability to create Principals (Users/Groups/Roles), that user could create a\nrole that matches a principal name association for the portfolio. Although this\nuser may not know which principal names are associated through Service Catalog,\nthey may be able to guess the user. If this potential escalation path is a\nconcern, then Service Catalog recommends using `PrincipalType` as `IAM`. With\nthis configuration, the `PrincipalARN` must already exist in the recipient\naccount before it can be associated.","ref":"AWS.ServiceCatalog.html#associate_principal_with_portfolio/3","title":"AWS.ServiceCatalog.associate_principal_with_portfolio/3","type":"function"},{"doc":"Associates the specified product with the specified portfolio.\n\nA delegated admin is authorized to invoke this command.","ref":"AWS.ServiceCatalog.html#associate_product_with_portfolio/3","title":"AWS.ServiceCatalog.associate_product_with_portfolio/3","type":"function"},{"doc":"Associates a self-service action with a provisioning artifact.","ref":"AWS.ServiceCatalog.html#associate_service_action_with_provisioning_artifact/3","title":"AWS.ServiceCatalog.associate_service_action_with_provisioning_artifact/3","type":"function"},{"doc":"Associate the specified TagOption with the specified portfolio or product.","ref":"AWS.ServiceCatalog.html#associate_tag_option_with_resource/3","title":"AWS.ServiceCatalog.associate_tag_option_with_resource/3","type":"function"},{"doc":"Associates multiple self-service actions with provisioning artifacts.","ref":"AWS.ServiceCatalog.html#batch_associate_service_action_with_provisioning_artifact/3","title":"AWS.ServiceCatalog.batch_associate_service_action_with_provisioning_artifact/3","type":"function"},{"doc":"Disassociates a batch of self-service actions from the specified provisioning\nartifact.","ref":"AWS.ServiceCatalog.html#batch_disassociate_service_action_from_provisioning_artifact/3","title":"AWS.ServiceCatalog.batch_disassociate_service_action_from_provisioning_artifact/3","type":"function"},{"doc":"Copies the specified source product to the specified target product or a new\nproduct.\n\nYou can copy a product to the same account or another account. You can copy a\nproduct to the same Region or another Region. If you copy a product to another\naccount, you must first share the product in a portfolio using\n`CreatePortfolioShare`.\n\nThis operation is performed asynchronously. To track the progress of the\noperation, use `DescribeCopyProductStatus`.","ref":"AWS.ServiceCatalog.html#copy_product/3","title":"AWS.ServiceCatalog.copy_product/3","type":"function"},{"doc":"Creates a constraint.\n\nA delegated admin is authorized to invoke this command.","ref":"AWS.ServiceCatalog.html#create_constraint/3","title":"AWS.ServiceCatalog.create_constraint/3","type":"function"},{"doc":"Creates a portfolio.\n\nA delegated admin is authorized to invoke this command.","ref":"AWS.ServiceCatalog.html#create_portfolio/3","title":"AWS.ServiceCatalog.create_portfolio/3","type":"function"},{"doc":"Shares the specified portfolio with the specified account or organization node.\n\nShares to an organization node can only be created by the management account of\nan organization or by a delegated administrator. You can share portfolios to an\norganization, an organizational unit, or a specific account.\n\nNote that if a delegated admin is de-registered, they can no longer create\nportfolio shares.\n\n`AWSOrganizationsAccess` must be enabled in order to create a portfolio share to\nan organization node.\n\nYou can't share a shared resource, including portfolios that contain a shared\nproduct.\n\nIf the portfolio share with the specified account or organization node already\nexists, this action will have no effect and will not return an error. To update\nan existing share, you must use the ` UpdatePortfolioShare` API instead.\n\nWhen you associate a principal with portfolio, a potential privilege escalation\npath may occur when that portfolio is then shared with other accounts. For a\nuser in a recipient account who is *not* an Service Catalog Admin, but still has\nthe ability to create Principals (Users/Groups/Roles), that user could create a\nrole that matches a principal name association for the portfolio. Although this\nuser may not know which principal names are associated through Service Catalog,\nthey may be able to guess the user. If this potential escalation path is a\nconcern, then Service Catalog recommends using `PrincipalType` as `IAM`. With\nthis configuration, the `PrincipalARN` must already exist in the recipient\naccount before it can be associated.","ref":"AWS.ServiceCatalog.html#create_portfolio_share/3","title":"AWS.ServiceCatalog.create_portfolio_share/3","type":"function"},{"doc":"Creates a product.\n\nA delegated admin is authorized to invoke this command.\n\nThe user or role that performs this operation must have the\n`cloudformation:GetTemplate` IAM policy permission. This policy permission is\nrequired when using the `ImportFromPhysicalId` template source in the\ninformation data section.","ref":"AWS.ServiceCatalog.html#create_product/3","title":"AWS.ServiceCatalog.create_product/3","type":"function"},{"doc":"Creates a plan.\n\nA plan includes the list of resources to be created (when provisioning a new\nproduct) or modified (when updating a provisioned product) when the plan is\nexecuted.\n\nYou can create one plan for each provisioned product. To create a plan for an\nexisting provisioned product, the product status must be AVAILABLE or TAINTED.\n\nTo view the resource changes in the change set, use\n`DescribeProvisionedProductPlan`. To create or modify the provisioned product,\nuse `ExecuteProvisionedProductPlan`.","ref":"AWS.ServiceCatalog.html#create_provisioned_product_plan/3","title":"AWS.ServiceCatalog.create_provisioned_product_plan/3","type":"function"},{"doc":"Creates a provisioning artifact (also known as a version) for the specified\nproduct.\n\nYou cannot create a provisioning artifact for a product that was shared with\nyou.\n\nThe user or role that performs this operation must have the\n`cloudformation:GetTemplate` IAM policy permission. This policy permission is\nrequired when using the `ImportFromPhysicalId` template source in the\ninformation data section.","ref":"AWS.ServiceCatalog.html#create_provisioning_artifact/3","title":"AWS.ServiceCatalog.create_provisioning_artifact/3","type":"function"},{"doc":"Creates a self-service action.","ref":"AWS.ServiceCatalog.html#create_service_action/3","title":"AWS.ServiceCatalog.create_service_action/3","type":"function"},{"doc":"Creates a TagOption.","ref":"AWS.ServiceCatalog.html#create_tag_option/3","title":"AWS.ServiceCatalog.create_tag_option/3","type":"function"},{"doc":"Deletes the specified constraint.\n\nA delegated admin is authorized to invoke this command.","ref":"AWS.ServiceCatalog.html#delete_constraint/3","title":"AWS.ServiceCatalog.delete_constraint/3","type":"function"},{"doc":"Deletes the specified portfolio.\n\nYou cannot delete a portfolio if it was shared with you or if it has associated\nproducts, users, constraints, or shared accounts.\n\nA delegated admin is authorized to invoke this command.","ref":"AWS.ServiceCatalog.html#delete_portfolio/3","title":"AWS.ServiceCatalog.delete_portfolio/3","type":"function"},{"doc":"Stops sharing the specified portfolio with the specified account or organization\nnode.\n\nShares to an organization node can only be deleted by the management account of\nan organization or by a delegated administrator.\n\nNote that if a delegated admin is de-registered, portfolio shares created from\nthat account are removed.","ref":"AWS.ServiceCatalog.html#delete_portfolio_share/3","title":"AWS.ServiceCatalog.delete_portfolio_share/3","type":"function"},{"doc":"Deletes the specified product.\n\nYou cannot delete a product if it was shared with you or is associated with a\nportfolio.\n\nA delegated admin is authorized to invoke this command.","ref":"AWS.ServiceCatalog.html#delete_product/3","title":"AWS.ServiceCatalog.delete_product/3","type":"function"},{"doc":"Deletes the specified plan.","ref":"AWS.ServiceCatalog.html#delete_provisioned_product_plan/3","title":"AWS.ServiceCatalog.delete_provisioned_product_plan/3","type":"function"},{"doc":"Deletes the specified provisioning artifact (also known as a version) for the\nspecified product.\n\nYou cannot delete a provisioning artifact associated with a product that was\nshared with you. You cannot delete the last provisioning artifact for a product,\nbecause a product must have at least one provisioning artifact.","ref":"AWS.ServiceCatalog.html#delete_provisioning_artifact/3","title":"AWS.ServiceCatalog.delete_provisioning_artifact/3","type":"function"},{"doc":"Deletes a self-service action.","ref":"AWS.ServiceCatalog.html#delete_service_action/3","title":"AWS.ServiceCatalog.delete_service_action/3","type":"function"},{"doc":"Deletes the specified TagOption.\n\nYou cannot delete a TagOption if it is associated with a product or portfolio.","ref":"AWS.ServiceCatalog.html#delete_tag_option/3","title":"AWS.ServiceCatalog.delete_tag_option/3","type":"function"},{"doc":"Gets information about the specified constraint.","ref":"AWS.ServiceCatalog.html#describe_constraint/3","title":"AWS.ServiceCatalog.describe_constraint/3","type":"function"},{"doc":"Gets the status of the specified copy product operation.","ref":"AWS.ServiceCatalog.html#describe_copy_product_status/3","title":"AWS.ServiceCatalog.describe_copy_product_status/3","type":"function"},{"doc":"Gets information about the specified portfolio.\n\nA delegated admin is authorized to invoke this command.","ref":"AWS.ServiceCatalog.html#describe_portfolio/3","title":"AWS.ServiceCatalog.describe_portfolio/3","type":"function"},{"doc":"Gets the status of the specified portfolio share operation.\n\nThis API can only be called by the management account in the organization or by\na delegated admin.","ref":"AWS.ServiceCatalog.html#describe_portfolio_share_status/3","title":"AWS.ServiceCatalog.describe_portfolio_share_status/3","type":"function"},{"doc":"Returns a summary of each of the portfolio shares that were created for the\nspecified portfolio.\n\nYou can use this API to determine which accounts or organizational nodes this\nportfolio have been shared, whether the recipient entity has imported the share,\nand whether TagOptions are included with the share.\n\nThe `PortfolioId` and `Type` parameters are both required.","ref":"AWS.ServiceCatalog.html#describe_portfolio_shares/3","title":"AWS.ServiceCatalog.describe_portfolio_shares/3","type":"function"},{"doc":"Gets information about the specified product.\n\nRunning this operation with administrator access results in a failure.\n`DescribeProductAsAdmin` should be used instead.","ref":"AWS.ServiceCatalog.html#describe_product/3","title":"AWS.ServiceCatalog.describe_product/3","type":"function"},{"doc":"Gets information about the specified product.\n\nThis operation is run with administrator access.","ref":"AWS.ServiceCatalog.html#describe_product_as_admin/3","title":"AWS.ServiceCatalog.describe_product_as_admin/3","type":"function"},{"doc":"Gets information about the specified product.","ref":"AWS.ServiceCatalog.html#describe_product_view/3","title":"AWS.ServiceCatalog.describe_product_view/3","type":"function"},{"doc":"Gets information about the specified provisioned product.","ref":"AWS.ServiceCatalog.html#describe_provisioned_product/3","title":"AWS.ServiceCatalog.describe_provisioned_product/3","type":"function"},{"doc":"Gets information about the resource changes for the specified plan.","ref":"AWS.ServiceCatalog.html#describe_provisioned_product_plan/3","title":"AWS.ServiceCatalog.describe_provisioned_product_plan/3","type":"function"},{"doc":"Gets information about the specified provisioning artifact (also known as a\nversion) for the specified product.","ref":"AWS.ServiceCatalog.html#describe_provisioning_artifact/3","title":"AWS.ServiceCatalog.describe_provisioning_artifact/3","type":"function"},{"doc":"Gets information about the configuration required to provision the specified\nproduct using the specified provisioning artifact.\n\nIf the output contains a TagOption key with an empty list of values, there is a\nTagOption conflict for that key. The end user cannot take action to fix the\nconflict, and launch is not blocked. In subsequent calls to `ProvisionProduct`,\ndo not include conflicted TagOption keys as tags, or this causes the error\n\"Parameter validation failed: Missing required parameter in Tags[*N*]:*Value*\".\nTag the provisioned product with the value\n`sc-tagoption-conflict-portfolioId-productId`.","ref":"AWS.ServiceCatalog.html#describe_provisioning_parameters/3","title":"AWS.ServiceCatalog.describe_provisioning_parameters/3","type":"function"},{"doc":"Gets information about the specified request operation.\n\nUse this operation after calling a request operation (for example,\n`ProvisionProduct`, `TerminateProvisionedProduct`, or\n`UpdateProvisionedProduct`).\n\nIf a provisioned product was transferred to a new owner using\n`UpdateProvisionedProductProperties`, the new owner will be able to describe all\npast records for that product. The previous owner will no longer be able to\ndescribe the records, but will be able to use `ListRecordHistory` to see the\nproduct's history from when he was the owner.","ref":"AWS.ServiceCatalog.html#describe_record/3","title":"AWS.ServiceCatalog.describe_record/3","type":"function"},{"doc":"Describes a self-service action.","ref":"AWS.ServiceCatalog.html#describe_service_action/3","title":"AWS.ServiceCatalog.describe_service_action/3","type":"function"},{"doc":"Finds the default parameters for a specific self-service action on a specific\nprovisioned product and returns a map of the results to the user.","ref":"AWS.ServiceCatalog.html#describe_service_action_execution_parameters/3","title":"AWS.ServiceCatalog.describe_service_action_execution_parameters/3","type":"function"},{"doc":"Gets information about the specified TagOption.","ref":"AWS.ServiceCatalog.html#describe_tag_option/3","title":"AWS.ServiceCatalog.describe_tag_option/3","type":"function"},{"doc":"Disable portfolio sharing through the Organizations service.\n\nThis command will not delete your current shares, but prevents you from creating\nnew shares throughout your organization. Current shares are not kept in sync\nwith your organization structure if the structure changes after calling this\nAPI. Only the management account in the organization can call this API.\n\nYou cannot call this API if there are active delegated administrators in the\norganization.\n\nNote that a delegated administrator is not authorized to invoke\n`DisableAWSOrganizationsAccess`.\n\nIf you share an Service Catalog portfolio in an organization within\nOrganizations, and then disable Organizations access for Service Catalog, the\nportfolio access permissions will not sync with the latest changes to the\norganization structure. Specifically, accounts that you removed from the\norganization after disabling Service Catalog access will retain access to the\npreviously shared portfolio.","ref":"AWS.ServiceCatalog.html#disable_aws_organizations_access/3","title":"AWS.ServiceCatalog.disable_aws_organizations_access/3","type":"function"},{"doc":"Disassociates the specified budget from the specified resource.","ref":"AWS.ServiceCatalog.html#disassociate_budget_from_resource/3","title":"AWS.ServiceCatalog.disassociate_budget_from_resource/3","type":"function"},{"doc":"Disassociates a previously associated principal ARN from a specified portfolio.\n\nThe `PrincipalType` and `PrincipalARN` must match the\n`AssociatePrincipalWithPortfolio` call request details. For example, to\ndisassociate an association created with a `PrincipalARN` of `PrincipalType` IAM\nyou must use the `PrincipalType` IAM when calling\n`DisassociatePrincipalFromPortfolio`.\n\nFor portfolios that have been shared with principal name sharing enabled: after\ndisassociating a principal, share recipient accounts will no longer be able to\nprovision products in this portfolio using a role matching the name of the\nassociated principal.\n\nFor more information, review\n[associate-principal-with-portfolio](https://docs.aws.amazon.com/cli/latest/reference/servicecatalog/associate-principal-with-portfolio.html#options)\nin the Amazon Web Services CLI Command Reference.\n\nIf you disassociate a principal from a portfolio, with PrincipalType as `IAM`,\nthe same principal will still have access to the portfolio if it matches one of\nthe associated principals of type `IAM_PATTERN`. To fully remove access for a\nprincipal, verify all the associated Principals of type `IAM_PATTERN`, and then\nensure you disassociate any `IAM_PATTERN` principals that match the principal\nwhose access you are removing.","ref":"AWS.ServiceCatalog.html#disassociate_principal_from_portfolio/3","title":"AWS.ServiceCatalog.disassociate_principal_from_portfolio/3","type":"function"},{"doc":"Disassociates the specified product from the specified portfolio.\n\nA delegated admin is authorized to invoke this command.","ref":"AWS.ServiceCatalog.html#disassociate_product_from_portfolio/3","title":"AWS.ServiceCatalog.disassociate_product_from_portfolio/3","type":"function"},{"doc":"Disassociates the specified self-service action association from the specified\nprovisioning artifact.","ref":"AWS.ServiceCatalog.html#disassociate_service_action_from_provisioning_artifact/3","title":"AWS.ServiceCatalog.disassociate_service_action_from_provisioning_artifact/3","type":"function"},{"doc":"Disassociates the specified TagOption from the specified resource.","ref":"AWS.ServiceCatalog.html#disassociate_tag_option_from_resource/3","title":"AWS.ServiceCatalog.disassociate_tag_option_from_resource/3","type":"function"},{"doc":"Enable portfolio sharing feature through Organizations.\n\nThis API will allow Service Catalog to receive updates on your organization in\norder to sync your shares with the current structure. This API can only be\ncalled by the management account in the organization.\n\nWhen you call this API, Service Catalog calls\n`organizations:EnableAWSServiceAccess` on your behalf so that your shares stay\nin sync with any changes in your Organizations structure.\n\nNote that a delegated administrator is not authorized to invoke\n`EnableAWSOrganizationsAccess`.\n\nIf you have previously disabled Organizations access for Service Catalog, and\nthen enable access again, the portfolio access permissions might not sync with\nthe latest changes to the organization structure. Specifically, accounts that\nyou removed from the organization after disabling Service Catalog access, and\nbefore you enabled access again, can retain access to the previously shared\nportfolio. As a result, an account that has been removed from the organization\nmight still be able to create or manage Amazon Web Services resources when it is\nno longer authorized to do so. Amazon Web Services is working to resolve this\nissue.","ref":"AWS.ServiceCatalog.html#enable_aws_organizations_access/3","title":"AWS.ServiceCatalog.enable_aws_organizations_access/3","type":"function"},{"doc":"Provisions or modifies a product based on the resource changes for the specified\nplan.","ref":"AWS.ServiceCatalog.html#execute_provisioned_product_plan/3","title":"AWS.ServiceCatalog.execute_provisioned_product_plan/3","type":"function"},{"doc":"Executes a self-service action against a provisioned product.","ref":"AWS.ServiceCatalog.html#execute_provisioned_product_service_action/3","title":"AWS.ServiceCatalog.execute_provisioned_product_service_action/3","type":"function"},{"doc":"Get the Access Status for Organizations portfolio share feature.\n\nThis API can only be called by the management account in the organization or by\na delegated admin.","ref":"AWS.ServiceCatalog.html#get_aws_organizations_access_status/3","title":"AWS.ServiceCatalog.get_aws_organizations_access_status/3","type":"function"},{"doc":"This API takes either a `ProvisonedProductId` or a `ProvisionedProductName`,\nalong with a list of one or more output keys, and responds with the key/value\npairs of those outputs.","ref":"AWS.ServiceCatalog.html#get_provisioned_product_outputs/3","title":"AWS.ServiceCatalog.get_provisioned_product_outputs/3","type":"function"},{"doc":"Requests the import of a resource as an Service Catalog provisioned product that\nis associated to an Service Catalog product and provisioning artifact.\n\nOnce imported, all supported governance actions are supported on the provisioned\nproduct.\n\nResource import only supports CloudFormation stack ARNs. CloudFormation\nStackSets, and non-root nested stacks, are not supported.\n\nThe CloudFormation stack must have one of the following statuses to be imported:\n`CREATE_COMPLETE`, `UPDATE_COMPLETE`, `UPDATE_ROLLBACK_COMPLETE`,\n`IMPORT_COMPLETE`, and `IMPORT_ROLLBACK_COMPLETE`.\n\nImport of the resource requires that the CloudFormation stack template matches\nthe associated Service Catalog product provisioning artifact.\n\nWhen you import an existing CloudFormation stack into a portfolio, Service\nCatalog does not apply the product's associated constraints during the import\nprocess. Service Catalog applies the constraints after you call\n`UpdateProvisionedProduct` for the provisioned product.\n\nThe user or role that performs this operation must have the\n`cloudformation:GetTemplate` and `cloudformation:DescribeStacks` IAM policy\npermissions.\n\nYou can only import one provisioned product at a time. The product's\nCloudFormation stack must have the `IMPORT_COMPLETE` status before you import\nanother.","ref":"AWS.ServiceCatalog.html#import_as_provisioned_product/3","title":"AWS.ServiceCatalog.import_as_provisioned_product/3","type":"function"},{"doc":"Lists all imported portfolios for which account-to-account shares were accepted\nby this account.\n\nBy specifying the `PortfolioShareType`, you can list portfolios for which\norganizational shares were accepted by this account.","ref":"AWS.ServiceCatalog.html#list_accepted_portfolio_shares/3","title":"AWS.ServiceCatalog.list_accepted_portfolio_shares/3","type":"function"},{"doc":"Lists all the budgets associated to the specified resource.","ref":"AWS.ServiceCatalog.html#list_budgets_for_resource/3","title":"AWS.ServiceCatalog.list_budgets_for_resource/3","type":"function"},{"doc":"Lists the constraints for the specified portfolio and product.","ref":"AWS.ServiceCatalog.html#list_constraints_for_portfolio/3","title":"AWS.ServiceCatalog.list_constraints_for_portfolio/3","type":"function"},{"doc":"Lists the paths to the specified product.\n\nA path describes how the user gets access to a specified product and is\nnecessary when provisioning a product. A path also determines the constraints\nthat are put on a product. A path is dependent on a specific product, porfolio,\nand principal.\n\nWhen provisioning a product that's been added to a portfolio, you must grant\nyour user, group, or role access to the portfolio. For more information, see\n[Granting users access](https://docs.aws.amazon.com/servicecatalog/latest/adminguide/catalogs_portfolios_users.html)\nin the *Service Catalog User Guide*.","ref":"AWS.ServiceCatalog.html#list_launch_paths/3","title":"AWS.ServiceCatalog.list_launch_paths/3","type":"function"},{"doc":"Lists the organization nodes that have access to the specified portfolio.\n\nThis API can only be called by the management account in the organization or by\na delegated admin.\n\nIf a delegated admin is de-registered, they can no longer perform this\noperation.","ref":"AWS.ServiceCatalog.html#list_organization_portfolio_access/3","title":"AWS.ServiceCatalog.list_organization_portfolio_access/3","type":"function"},{"doc":"Lists the account IDs that have access to the specified portfolio.\n\nA delegated admin can list the accounts that have access to the shared\nportfolio. Note that if a delegated admin is de-registered, they can no longer\nperform this operation.","ref":"AWS.ServiceCatalog.html#list_portfolio_access/3","title":"AWS.ServiceCatalog.list_portfolio_access/3","type":"function"},{"doc":"Lists all portfolios in the catalog.","ref":"AWS.ServiceCatalog.html#list_portfolios/3","title":"AWS.ServiceCatalog.list_portfolios/3","type":"function"},{"doc":"Lists all portfolios that the specified product is associated with.","ref":"AWS.ServiceCatalog.html#list_portfolios_for_product/3","title":"AWS.ServiceCatalog.list_portfolios_for_product/3","type":"function"},{"doc":"Lists all `PrincipalARN`s and corresponding `PrincipalType`s associated with the\nspecified portfolio.","ref":"AWS.ServiceCatalog.html#list_principals_for_portfolio/3","title":"AWS.ServiceCatalog.list_principals_for_portfolio/3","type":"function"},{"doc":"Lists the plans for the specified provisioned product or all plans to which the\nuser has access.","ref":"AWS.ServiceCatalog.html#list_provisioned_product_plans/3","title":"AWS.ServiceCatalog.list_provisioned_product_plans/3","type":"function"},{"doc":"Lists all provisioning artifacts (also known as versions) for the specified\nproduct.","ref":"AWS.ServiceCatalog.html#list_provisioning_artifacts/3","title":"AWS.ServiceCatalog.list_provisioning_artifacts/3","type":"function"},{"doc":"Lists all provisioning artifacts (also known as versions) for the specified\nself-service action.","ref":"AWS.ServiceCatalog.html#list_provisioning_artifacts_for_service_action/3","title":"AWS.ServiceCatalog.list_provisioning_artifacts_for_service_action/3","type":"function"},{"doc":"Lists the specified requests or all performed requests.","ref":"AWS.ServiceCatalog.html#list_record_history/3","title":"AWS.ServiceCatalog.list_record_history/3","type":"function"},{"doc":"Lists the resources associated with the specified TagOption.","ref":"AWS.ServiceCatalog.html#list_resources_for_tag_option/3","title":"AWS.ServiceCatalog.list_resources_for_tag_option/3","type":"function"},{"doc":"Lists all self-service actions.","ref":"AWS.ServiceCatalog.html#list_service_actions/3","title":"AWS.ServiceCatalog.list_service_actions/3","type":"function"},{"doc":"Returns a paginated list of self-service actions associated with the specified\nProduct ID and Provisioning Artifact ID.","ref":"AWS.ServiceCatalog.html#list_service_actions_for_provisioning_artifact/3","title":"AWS.ServiceCatalog.list_service_actions_for_provisioning_artifact/3","type":"function"},{"doc":"Returns summary information about stack instances that are associated with the\nspecified `CFN_STACKSET` type provisioned product.\n\nYou can filter for stack instances that are associated with a specific Amazon\nWeb Services account name or Region.","ref":"AWS.ServiceCatalog.html#list_stack_instances_for_provisioned_product/3","title":"AWS.ServiceCatalog.list_stack_instances_for_provisioned_product/3","type":"function"},{"doc":"Lists the specified TagOptions or all TagOptions.","ref":"AWS.ServiceCatalog.html#list_tag_options/3","title":"AWS.ServiceCatalog.list_tag_options/3","type":"function"},{"doc":"","ref":"AWS.ServiceCatalog.html#metadata/0","title":"AWS.ServiceCatalog.metadata/0","type":"function"},{"doc":"Notifies the result of the provisioning engine execution.","ref":"AWS.ServiceCatalog.html#notify_provision_product_engine_workflow_result/3","title":"AWS.ServiceCatalog.notify_provision_product_engine_workflow_result/3","type":"function"},{"doc":"Notifies the result of the terminate engine execution.","ref":"AWS.ServiceCatalog.html#notify_terminate_provisioned_product_engine_workflow_result/3","title":"AWS.ServiceCatalog.notify_terminate_provisioned_product_engine_workflow_result/3","type":"function"},{"doc":"Notifies the result of the update engine execution.","ref":"AWS.ServiceCatalog.html#notify_update_provisioned_product_engine_workflow_result/3","title":"AWS.ServiceCatalog.notify_update_provisioned_product_engine_workflow_result/3","type":"function"},{"doc":"Provisions the specified product.\n\nA provisioned product is a resourced instance of a product. For example,\nprovisioning a product that's based on an CloudFormation template launches an\nCloudFormation stack and its underlying resources. You can check the status of\nthis request using `DescribeRecord`.\n\nIf the request contains a tag key with an empty list of values, there's a tag\nconflict for that key. Don't include conflicted keys as tags, or this will cause\nthe error \"Parameter validation failed: Missing required parameter in\nTags[*N*]:*Value*\".  When provisioning a product that's been added to a portfolio, you must grant\nyour user, group, or role access to the portfolio. For more information, see\n[Granting users\naccess](https://docs.aws.amazon.com/servicecatalog/latest/adminguide/catalogs_portfolios_users.html)\nin the *Service Catalog User Guide*.","ref":"AWS.ServiceCatalog.html#provision_product/3","title":"AWS.ServiceCatalog.provision_product/3","type":"function"},{"doc":"Rejects an offer to share the specified portfolio.","ref":"AWS.ServiceCatalog.html#reject_portfolio_share/3","title":"AWS.ServiceCatalog.reject_portfolio_share/3","type":"function"},{"doc":"Lists the provisioned products that are available (not terminated).\n\nTo use additional filtering, see `SearchProvisionedProducts`.","ref":"AWS.ServiceCatalog.html#scan_provisioned_products/3","title":"AWS.ServiceCatalog.scan_provisioned_products/3","type":"function"},{"doc":"Gets information about the products to which the caller has access.","ref":"AWS.ServiceCatalog.html#search_products/3","title":"AWS.ServiceCatalog.search_products/3","type":"function"},{"doc":"Gets information about the products for the specified portfolio or all products.","ref":"AWS.ServiceCatalog.html#search_products_as_admin/3","title":"AWS.ServiceCatalog.search_products_as_admin/3","type":"function"},{"doc":"Gets information about the provisioned products that meet the specified\ncriteria.","ref":"AWS.ServiceCatalog.html#search_provisioned_products/3","title":"AWS.ServiceCatalog.search_provisioned_products/3","type":"function"},{"doc":"Terminates the specified provisioned product.\n\nThis operation does not delete any records associated with the provisioned\nproduct.\n\nYou can check the status of this request using `DescribeRecord`.","ref":"AWS.ServiceCatalog.html#terminate_provisioned_product/3","title":"AWS.ServiceCatalog.terminate_provisioned_product/3","type":"function"},{"doc":"Updates the specified constraint.","ref":"AWS.ServiceCatalog.html#update_constraint/3","title":"AWS.ServiceCatalog.update_constraint/3","type":"function"},{"doc":"Updates the specified portfolio.\n\nYou cannot update a product that was shared with you.","ref":"AWS.ServiceCatalog.html#update_portfolio/3","title":"AWS.ServiceCatalog.update_portfolio/3","type":"function"},{"doc":"Updates the specified portfolio share.\n\nYou can use this API to enable or disable `TagOptions` sharing or Principal\nsharing for an existing portfolio share.\n\nThe portfolio share cannot be updated if the `CreatePortfolioShare` operation is\n`IN_PROGRESS`, as the share is not available to recipient entities. In this\ncase, you must wait for the portfolio share to be completed.\n\nYou must provide the `accountId` or organization node in the input, but not\nboth.\n\nIf the portfolio is shared to both an external account and an organization node,\nand both shares need to be updated, you must invoke `UpdatePortfolioShare`\nseparately for each share type.\n\nThis API cannot be used for removing the portfolio share. You must use\n`DeletePortfolioShare` API for that action.\n\nWhen you associate a principal with portfolio, a potential privilege escalation\npath may occur when that portfolio is then shared with other accounts. For a\nuser in a recipient account who is *not* an Service Catalog Admin, but still has\nthe ability to create Principals (Users/Groups/Roles), that user could create a\nrole that matches a principal name association for the portfolio. Although this\nuser may not know which principal names are associated through Service Catalog,\nthey may be able to guess the user. If this potential escalation path is a\nconcern, then Service Catalog recommends using `PrincipalType` as `IAM`. With\nthis configuration, the `PrincipalARN` must already exist in the recipient\naccount before it can be associated.","ref":"AWS.ServiceCatalog.html#update_portfolio_share/3","title":"AWS.ServiceCatalog.update_portfolio_share/3","type":"function"},{"doc":"Updates the specified product.","ref":"AWS.ServiceCatalog.html#update_product/3","title":"AWS.ServiceCatalog.update_product/3","type":"function"},{"doc":"Requests updates to the configuration of the specified provisioned product.\n\nIf there are tags associated with the object, they cannot be updated or added.\nDepending on the specific updates requested, this operation can update with no\ninterruption, with some interruption, or replace the provisioned product\nentirely.\n\nYou can check the status of this request using `DescribeRecord`.","ref":"AWS.ServiceCatalog.html#update_provisioned_product/3","title":"AWS.ServiceCatalog.update_provisioned_product/3","type":"function"},{"doc":"Requests updates to the properties of the specified provisioned product.","ref":"AWS.ServiceCatalog.html#update_provisioned_product_properties/3","title":"AWS.ServiceCatalog.update_provisioned_product_properties/3","type":"function"},{"doc":"Updates the specified provisioning artifact (also known as a version) for the\nspecified product.\n\nYou cannot update a provisioning artifact for a product that was shared with\nyou.","ref":"AWS.ServiceCatalog.html#update_provisioning_artifact/3","title":"AWS.ServiceCatalog.update_provisioning_artifact/3","type":"function"},{"doc":"Updates a self-service action.","ref":"AWS.ServiceCatalog.html#update_service_action/3","title":"AWS.ServiceCatalog.update_service_action/3","type":"function"},{"doc":"Updates the specified TagOption.","ref":"AWS.ServiceCatalog.html#update_tag_option/3","title":"AWS.ServiceCatalog.update_tag_option/3","type":"function"},{"doc":"Amazon Web Services Service Catalog AppRegistry enables organizations to\nunderstand the application context of their Amazon Web Services resources.\n\nAppRegistry provides a repository of your applications, their resources, and the\napplication metadata that you use within your enterprise.","ref":"AWS.ServiceCatalogAppRegistry.html","title":"AWS.ServiceCatalogAppRegistry","type":"module"},{"doc":"Associates an attribute group with an application to augment the application's\nmetadata with the group's attributes.\n\nThis feature enables applications to be described with user-defined details that\nare machine-readable, such as third-party integrations.","ref":"AWS.ServiceCatalogAppRegistry.html#associate_attribute_group/5","title":"AWS.ServiceCatalogAppRegistry.associate_attribute_group/5","type":"function"},{"doc":"Associates a resource with an application.\n\nThe resource can be specified by its ARN or name. The application can be\nspecified by ARN, ID, or name.","ref":"AWS.ServiceCatalogAppRegistry.html#associate_resource/6","title":"AWS.ServiceCatalogAppRegistry.associate_resource/6","type":"function"},{"doc":"You must have the following permissions to associate a resource using the\n`OPTIONS` parameter set to `APPLY_APPLICATION_TAG`.\n\n  * `tag:GetResources`\n\n  * `tag:TagResources`\n\nYou must also have these additional permissions if you don't use the\n`AWSServiceCatalogAppRegistryFullAccess` policy. For more information, see\n[AWSServiceCatalogAppRegistryFullAccess](https://docs.aws.amazon.com/servicecatalog/latest/arguide/full.html) in the AppRegistry Administrator Guide.\n\n  * `resource-groups:AssociateResource`\n\n  * `cloudformation:UpdateStack`\n\n  * `cloudformation:DescribeStacks`\n\nIn addition, you must have the tagging permission defined by the Amazon Web\nServices service that creates the resource. For more information, see\n[TagResources](https://docs.aws.amazon.com/resourcegroupstagging/latest/APIReference/API_TagResources.html)\nin the *Resource Groups Tagging API Reference*.","ref":"AWS.ServiceCatalogAppRegistry.html#associate_resource/6-minimum-permissions","title":"Minimum permissions - AWS.ServiceCatalogAppRegistry.associate_resource/6","type":"function"},{"doc":"Creates a new application that is the top-level node in a hierarchy of related\ncloud resource abstractions.","ref":"AWS.ServiceCatalogAppRegistry.html#create_application/3","title":"AWS.ServiceCatalogAppRegistry.create_application/3","type":"function"},{"doc":"Creates a new attribute group as a container for user-defined attributes.\n\nThis feature enables users to have full control over their cloud application's\nmetadata in a rich machine-readable format to facilitate integration with\nautomated workflows and third-party tools.","ref":"AWS.ServiceCatalogAppRegistry.html#create_attribute_group/3","title":"AWS.ServiceCatalogAppRegistry.create_attribute_group/3","type":"function"},{"doc":"Deletes an application that is specified either by its application ID, name, or\nARN.\n\nAll associated attribute groups and resources must be disassociated from it\nbefore deleting an application.","ref":"AWS.ServiceCatalogAppRegistry.html#delete_application/4","title":"AWS.ServiceCatalogAppRegistry.delete_application/4","type":"function"},{"doc":"Deletes an attribute group, specified either by its attribute group ID, name, or\nARN.","ref":"AWS.ServiceCatalogAppRegistry.html#delete_attribute_group/4","title":"AWS.ServiceCatalogAppRegistry.delete_attribute_group/4","type":"function"},{"doc":"Disassociates an attribute group from an application to remove the extra\nattributes contained in the attribute group from the application's metadata.\n\nThis operation reverts `AssociateAttributeGroup`.","ref":"AWS.ServiceCatalogAppRegistry.html#disassociate_attribute_group/5","title":"AWS.ServiceCatalogAppRegistry.disassociate_attribute_group/5","type":"function"},{"doc":"Disassociates a resource from application.\n\nBoth the resource and the application can be specified either by ID or name.","ref":"AWS.ServiceCatalogAppRegistry.html#disassociate_resource/6","title":"AWS.ServiceCatalogAppRegistry.disassociate_resource/6","type":"function"},{"doc":"You must have the following permissions to remove a resource that's been\nassociated with an application using the `APPLY_APPLICATION_TAG` option for\n[AssociateResource](https://docs.aws.amazon.com/servicecatalog/latest/dg/API_app-registry_AssociateResource.html).    * `tag:GetResources`\n\n  * `tag:UntagResources`\n\nYou must also have the following permissions if you don't use the\n`AWSServiceCatalogAppRegistryFullAccess` policy. For more information, see\n[AWSServiceCatalogAppRegistryFullAccess](https://docs.aws.amazon.com/servicecatalog/latest/arguide/full.html)\nin the AppRegistry Administrator Guide.\n\n  * `resource-groups:DisassociateResource`\n\n  * `cloudformation:UpdateStack`\n\n  * `cloudformation:DescribeStacks`\n\nIn addition, you must have the tagging permission defined by the Amazon Web\nServices service that creates the resource. For more information, see\n[UntagResources](https://docs.aws.amazon.com/resourcegroupstagging/latest/APIReference/API_UntTagResources.html)\nin the *Resource Groups Tagging API Reference*.","ref":"AWS.ServiceCatalogAppRegistry.html#disassociate_resource/6-minimum-permissions","title":"Minimum permissions - AWS.ServiceCatalogAppRegistry.disassociate_resource/6","type":"function"},{"doc":"Retrieves metadata information about one of your applications.\n\nThe application can be specified by its ARN, ID, or name (which is unique within\none account in one region at a given point in time). Specify by ARN or ID in\nautomated workflows if you want to make sure that the exact same application is\nreturned or a `ResourceNotFoundException` is thrown, avoiding the ABA addressing\nproblem.","ref":"AWS.ServiceCatalogAppRegistry.html#get_application/3","title":"AWS.ServiceCatalogAppRegistry.get_application/3","type":"function"},{"doc":"Gets the resource associated with the application.","ref":"AWS.ServiceCatalogAppRegistry.html#get_associated_resource/8","title":"AWS.ServiceCatalogAppRegistry.get_associated_resource/8","type":"function"},{"doc":"Retrieves an attribute group by its ARN, ID, or name.\n\nThe attribute group can be specified by its ARN, ID, or name.","ref":"AWS.ServiceCatalogAppRegistry.html#get_attribute_group/3","title":"AWS.ServiceCatalogAppRegistry.get_attribute_group/3","type":"function"},{"doc":"Retrieves a `TagKey` configuration from an account.","ref":"AWS.ServiceCatalogAppRegistry.html#get_configuration/2","title":"AWS.ServiceCatalogAppRegistry.get_configuration/2","type":"function"},{"doc":"Retrieves a list of all of your applications.\n\nResults are paginated.","ref":"AWS.ServiceCatalogAppRegistry.html#list_applications/4","title":"AWS.ServiceCatalogAppRegistry.list_applications/4","type":"function"},{"doc":"Lists all attribute groups that are associated with specified application.\n\nResults are paginated.","ref":"AWS.ServiceCatalogAppRegistry.html#list_associated_attribute_groups/5","title":"AWS.ServiceCatalogAppRegistry.list_associated_attribute_groups/5","type":"function"},{"doc":"Lists all of the resources that are associated with the specified application.\n\nResults are paginated.\n\nIf you share an application, and a consumer account associates a tag query to\nthe application, all of the users who can access the application can also view\nthe tag values in all accounts that are associated with it using this API.","ref":"AWS.ServiceCatalogAppRegistry.html#list_associated_resources/5","title":"AWS.ServiceCatalogAppRegistry.list_associated_resources/5","type":"function"},{"doc":"Lists all attribute groups which you have access to.\n\nResults are paginated.","ref":"AWS.ServiceCatalogAppRegistry.html#list_attribute_groups/4","title":"AWS.ServiceCatalogAppRegistry.list_attribute_groups/4","type":"function"},{"doc":"Lists the details of all attribute groups associated with a specific\napplication.\n\nThe results display in pages.","ref":"AWS.ServiceCatalogAppRegistry.html#list_attribute_groups_for_application/5","title":"AWS.ServiceCatalogAppRegistry.list_attribute_groups_for_application/5","type":"function"},{"doc":"Lists all of the tags on the resource.","ref":"AWS.ServiceCatalogAppRegistry.html#list_tags_for_resource/3","title":"AWS.ServiceCatalogAppRegistry.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.ServiceCatalogAppRegistry.html#metadata/0","title":"AWS.ServiceCatalogAppRegistry.metadata/0","type":"function"},{"doc":"Associates a `TagKey` configuration to an account.","ref":"AWS.ServiceCatalogAppRegistry.html#put_configuration/3","title":"AWS.ServiceCatalogAppRegistry.put_configuration/3","type":"function"},{"doc":"Syncs the resource with current AppRegistry records.\n\nSpecifically, the resource’s AppRegistry system tags sync with its associated\napplication. We remove the resource's AppRegistry system tags if it does not\nassociate with the application. The caller must have permissions to read and\nupdate the resource.","ref":"AWS.ServiceCatalogAppRegistry.html#sync_resource/5","title":"AWS.ServiceCatalogAppRegistry.sync_resource/5","type":"function"},{"doc":"Assigns one or more tags (key-value pairs) to the specified resource.\n\nEach tag consists of a key and an optional value. If a tag with the same key is\nalready associated with the resource, this action updates its value.\n\nThis operation returns an empty response if the call was successful.","ref":"AWS.ServiceCatalogAppRegistry.html#tag_resource/4","title":"AWS.ServiceCatalogAppRegistry.tag_resource/4","type":"function"},{"doc":"Removes tags from a resource.\n\nThis operation returns an empty response if the call was successful.","ref":"AWS.ServiceCatalogAppRegistry.html#untag_resource/4","title":"AWS.ServiceCatalogAppRegistry.untag_resource/4","type":"function"},{"doc":"Updates an existing application with new attributes.","ref":"AWS.ServiceCatalogAppRegistry.html#update_application/4","title":"AWS.ServiceCatalogAppRegistry.update_application/4","type":"function"},{"doc":"Updates an existing attribute group with new details.","ref":"AWS.ServiceCatalogAppRegistry.html#update_attribute_group/4","title":"AWS.ServiceCatalogAppRegistry.update_attribute_group/4","type":"function"},{"doc":"Cloud Map\n\nWith Cloud Map, you can configure public DNS, private DNS, or HTTP namespaces\nthat your microservice applications run in.\n\nWhen an instance becomes available, you can call the Cloud Map API to register\nthe instance with Cloud Map. For public or private DNS namespaces, Cloud Map\nautomatically creates DNS records and an optional health check. Clients that\nsubmit public or private DNS queries, or HTTP requests, for the service receive\nan answer that contains up to eight healthy records.","ref":"AWS.ServiceDiscovery.html","title":"AWS.ServiceDiscovery","type":"module"},{"doc":"Creates an HTTP namespace.\n\nService instances registered using an HTTP namespace can be discovered using a\n`DiscoverInstances` request but can't be discovered using DNS.\n\nFor the current quota on the number of namespaces that you can create using the\nsame Amazon Web Services account, see [Cloud Map quotas](https://docs.aws.amazon.com/cloud-map/latest/dg/cloud-map-limits.html)\nin the *Cloud Map Developer Guide*.","ref":"AWS.ServiceDiscovery.html#create_http_namespace/3","title":"AWS.ServiceDiscovery.create_http_namespace/3","type":"function"},{"doc":"Creates a private namespace based on DNS, which is visible only inside a\nspecified Amazon VPC.\n\nThe namespace defines your service naming scheme. For example, if you name your\nnamespace `example.com` and name your service `backend`, the resulting DNS name\nfor the service is `backend.example.com`. Service instances that are registered\nusing a private DNS namespace can be discovered using either a\n`DiscoverInstances` request or using DNS. For the current quota on the number of\nnamespaces that you can create using the same Amazon Web Services account, see\n[Cloud Map quotas](https://docs.aws.amazon.com/cloud-map/latest/dg/cloud-map-limits.html)\nin the *Cloud Map Developer Guide*.","ref":"AWS.ServiceDiscovery.html#create_private_dns_namespace/3","title":"AWS.ServiceDiscovery.create_private_dns_namespace/3","type":"function"},{"doc":"Creates a public namespace based on DNS, which is visible on the internet.\n\nThe namespace defines your service naming scheme. For example, if you name your\nnamespace `example.com` and name your service `backend`, the resulting DNS name\nfor the service is `backend.example.com`. You can discover instances that were\nregistered with a public DNS namespace by using either a `DiscoverInstances`\nrequest or using DNS. For the current quota on the number of namespaces that you\ncan create using the same Amazon Web Services account, see [Cloud Map quotas](https://docs.aws.amazon.com/cloud-map/latest/dg/cloud-map-limits.html)\nin the *Cloud Map Developer Guide*.\n\nThe `CreatePublicDnsNamespace` API operation is not supported in the Amazon Web\nServices GovCloud (US) Regions.","ref":"AWS.ServiceDiscovery.html#create_public_dns_namespace/3","title":"AWS.ServiceDiscovery.create_public_dns_namespace/3","type":"function"},{"doc":"Creates a service.\n\nThis action defines the configuration for the following entities:\n\n  * For public and private DNS namespaces, one of the following\ncombinations of DNS records in Amazon Route 53:\n\n    * `A`\n\n    * `AAAA`\n\n    * `A` and `AAAA`\n\n    * `SRV`\n\n    * `CNAME`\n\n  * Optionally, a health check\n\nAfter you create the service, you can submit a\n[RegisterInstance](https://docs.aws.amazon.com/cloud-map/latest/api/API_RegisterInstance.html) request, and Cloud Map uses the values in the configuration to create the\nspecified entities.\n\nFor the current quota on the number of instances that you can register using the\nsame namespace and using the same service, see [Cloud Map\nquotas](https://docs.aws.amazon.com/cloud-map/latest/dg/cloud-map-limits.html)\nin the *Cloud Map Developer Guide*.","ref":"AWS.ServiceDiscovery.html#create_service/3","title":"AWS.ServiceDiscovery.create_service/3","type":"function"},{"doc":"Deletes a namespace from the current account.\n\nIf the namespace still contains one or more services, the request fails.","ref":"AWS.ServiceDiscovery.html#delete_namespace/3","title":"AWS.ServiceDiscovery.delete_namespace/3","type":"function"},{"doc":"Deletes a specified service.\n\nIf the service still contains one or more registered instances, the request\nfails.","ref":"AWS.ServiceDiscovery.html#delete_service/3","title":"AWS.ServiceDiscovery.delete_service/3","type":"function"},{"doc":"Deletes the Amazon Route 53 DNS records and health check, if any, that Cloud Map\ncreated for the specified instance.","ref":"AWS.ServiceDiscovery.html#deregister_instance/3","title":"AWS.ServiceDiscovery.deregister_instance/3","type":"function"},{"doc":"Discovers registered instances for a specified namespace and service.\n\nYou can use `DiscoverInstances` to discover instances for any type of namespace.\n`DiscoverInstances` returns a randomized list of instances allowing customers to\ndistribute traffic evenly across instances. For public and private DNS\nnamespaces, you can also use DNS queries to discover instances.","ref":"AWS.ServiceDiscovery.html#discover_instances/3","title":"AWS.ServiceDiscovery.discover_instances/3","type":"function"},{"doc":"Discovers the increasing revision associated with an instance.","ref":"AWS.ServiceDiscovery.html#discover_instances_revision/3","title":"AWS.ServiceDiscovery.discover_instances_revision/3","type":"function"},{"doc":"Gets information about a specified instance.","ref":"AWS.ServiceDiscovery.html#get_instance/3","title":"AWS.ServiceDiscovery.get_instance/3","type":"function"},{"doc":"Gets the current health status (`Healthy`, `Unhealthy`, or `Unknown`) of one or\nmore instances that are associated with a specified service.\n\nThere's a brief delay between when you register an instance and when the health\nstatus for the instance is available.","ref":"AWS.ServiceDiscovery.html#get_instances_health_status/3","title":"AWS.ServiceDiscovery.get_instances_health_status/3","type":"function"},{"doc":"Gets information about a namespace.","ref":"AWS.ServiceDiscovery.html#get_namespace/3","title":"AWS.ServiceDiscovery.get_namespace/3","type":"function"},{"doc":"Gets information about any operation that returns an operation ID in the\nresponse, such as a `CreateHttpNamespace` request.\n\nTo get a list of operations that match specified criteria, see\n[ListOperations](https://docs.aws.amazon.com/cloud-map/latest/api/API_ListOperations.html).","ref":"AWS.ServiceDiscovery.html#get_operation/3","title":"AWS.ServiceDiscovery.get_operation/3","type":"function"},{"doc":"Gets the settings for a specified service.","ref":"AWS.ServiceDiscovery.html#get_service/3","title":"AWS.ServiceDiscovery.get_service/3","type":"function"},{"doc":"Lists summary information about the instances that you registered by using a\nspecified service.","ref":"AWS.ServiceDiscovery.html#list_instances/3","title":"AWS.ServiceDiscovery.list_instances/3","type":"function"},{"doc":"Lists summary information about the namespaces that were created by the current\nAmazon Web Services account.","ref":"AWS.ServiceDiscovery.html#list_namespaces/3","title":"AWS.ServiceDiscovery.list_namespaces/3","type":"function"},{"doc":"Lists operations that match the criteria that you specify.","ref":"AWS.ServiceDiscovery.html#list_operations/3","title":"AWS.ServiceDiscovery.list_operations/3","type":"function"},{"doc":"Lists summary information for all the services that are associated with one or\nmore specified namespaces.","ref":"AWS.ServiceDiscovery.html#list_services/3","title":"AWS.ServiceDiscovery.list_services/3","type":"function"},{"doc":"Lists tags for the specified resource.","ref":"AWS.ServiceDiscovery.html#list_tags_for_resource/3","title":"AWS.ServiceDiscovery.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.ServiceDiscovery.html#metadata/0","title":"AWS.ServiceDiscovery.metadata/0","type":"function"},{"doc":"Creates or updates one or more records and, optionally, creates a health check\nbased on the settings in a specified service.\n\nWhen you submit a `RegisterInstance` request, the following occurs:\n\n  * For each DNS record that you define in the service that's\nspecified by `ServiceId`, a record is created or updated in the hosted zone\nthat's associated with the corresponding namespace.\n\n  * If the service includes `HealthCheckConfig`, a health check is\ncreated based on the settings in the health check configuration.\n\n  * The health check, if any, is associated with each of the new or\nupdated records.\n\nOne `RegisterInstance` request must complete before you can submit another\nrequest and specify the same service ID and instance ID.\n\nFor more information, see\n[CreateService](https://docs.aws.amazon.com/cloud-map/latest/api/API_CreateService.html).  When Cloud Map receives a DNS query for the specified DNS name, it returns the\napplicable value:\n\n  * **If the health check is healthy**: returns all the records\n\n  * **If the health check is unhealthy**: returns the applicable value\nfor the last healthy instance\n\n  * **If you didn't specify a health check configuration**: returns\nall the records\n\nFor the current quota on the number of instances that you can register using the\nsame namespace and using the same service, see [Cloud Map\nquotas](https://docs.aws.amazon.com/cloud-map/latest/dg/cloud-map-limits.html)\nin the *Cloud Map Developer Guide*.","ref":"AWS.ServiceDiscovery.html#register_instance/3","title":"AWS.ServiceDiscovery.register_instance/3","type":"function"},{"doc":"Adds one or more tags to the specified resource.","ref":"AWS.ServiceDiscovery.html#tag_resource/3","title":"AWS.ServiceDiscovery.tag_resource/3","type":"function"},{"doc":"Removes one or more tags from the specified resource.","ref":"AWS.ServiceDiscovery.html#untag_resource/3","title":"AWS.ServiceDiscovery.untag_resource/3","type":"function"},{"doc":"Updates an HTTP namespace.","ref":"AWS.ServiceDiscovery.html#update_http_namespace/3","title":"AWS.ServiceDiscovery.update_http_namespace/3","type":"function"},{"doc":"Submits a request to change the health status of a custom health check to\nhealthy or unhealthy.\n\nYou can use `UpdateInstanceCustomHealthStatus` to change the status only for\ncustom health checks, which you define using `HealthCheckCustomConfig` when you\ncreate a service. You can't use it to change the status for Route 53 health\nchecks, which you define using `HealthCheckConfig`.\n\nFor more information, see\n[HealthCheckCustomConfig](https://docs.aws.amazon.com/cloud-map/latest/api/API_HealthCheckCustomConfig.html).","ref":"AWS.ServiceDiscovery.html#update_instance_custom_health_status/3","title":"AWS.ServiceDiscovery.update_instance_custom_health_status/3","type":"function"},{"doc":"Updates a private DNS namespace.","ref":"AWS.ServiceDiscovery.html#update_private_dns_namespace/3","title":"AWS.ServiceDiscovery.update_private_dns_namespace/3","type":"function"},{"doc":"Updates a public DNS namespace.","ref":"AWS.ServiceDiscovery.html#update_public_dns_namespace/3","title":"AWS.ServiceDiscovery.update_public_dns_namespace/3","type":"function"},{"doc":"Submits a request to perform the following operations:\n\n  * Update the TTL setting for existing `DnsRecords` configurations\n\n  * Add, update, or delete `HealthCheckConfig` for a specified service\n\nYou can't add, update, or delete a `HealthCheckCustomConfig` configuration.\n\nFor public and private DNS namespaces, note the following:\n\n  * If you omit any existing `DnsRecords` or `HealthCheckConfig`\nconfigurations from an `UpdateService` request, the configurations are deleted\nfrom the service.\n\n  * If you omit an existing `HealthCheckCustomConfig` configuration\nfrom an `UpdateService` request, the configuration isn't deleted from the\nservice.\n\nWhen you update settings for a service, Cloud Map also updates the corresponding\nsettings in all the records and health checks that were created by using the\nspecified service.","ref":"AWS.ServiceDiscovery.html#update_service/3","title":"AWS.ServiceDiscovery.update_service/3","type":"function"},{"doc":"With Service Quotas, you can view and manage your quotas easily as your Amazon\nWeb Services workloads grow.\n\nQuotas, also referred to as limits, are the maximum number of resources that you\ncan create in your Amazon Web Services account. For more information, see the\n[Service Quotas User Guide](https://docs.aws.amazon.com/servicequotas/latest/userguide/).","ref":"AWS.ServiceQuotas.html","title":"AWS.ServiceQuotas","type":"module"},{"doc":"Associates your quota request template with your organization.\n\nWhen a new Amazon Web Services account is created in your organization, the\nquota increase requests in the template are automatically applied to the\naccount. You can add a quota increase request for any adjustable quota to your\ntemplate.","ref":"AWS.ServiceQuotas.html#associate_service_quota_template/3","title":"AWS.ServiceQuotas.associate_service_quota_template/3","type":"function"},{"doc":"Deletes the quota increase request for the specified quota from your quota\nrequest template.","ref":"AWS.ServiceQuotas.html#delete_service_quota_increase_request_from_template/3","title":"AWS.ServiceQuotas.delete_service_quota_increase_request_from_template/3","type":"function"},{"doc":"Disables your quota request template.\n\nAfter a template is disabled, the quota increase requests in the template are\nnot applied to new Amazon Web Services accounts in your organization. Disabling\na quota request template does not apply its quota increase requests.","ref":"AWS.ServiceQuotas.html#disassociate_service_quota_template/3","title":"AWS.ServiceQuotas.disassociate_service_quota_template/3","type":"function"},{"doc":"Retrieves the status of the association for the quota request template.","ref":"AWS.ServiceQuotas.html#get_association_for_service_quota_template/3","title":"AWS.ServiceQuotas.get_association_for_service_quota_template/3","type":"function"},{"doc":"Retrieves the default value for the specified quota.\n\nThe default value does not reflect any quota increases.","ref":"AWS.ServiceQuotas.html#get_aws_default_service_quota/3","title":"AWS.ServiceQuotas.get_aws_default_service_quota/3","type":"function"},{"doc":"Retrieves information about the specified quota increase request.","ref":"AWS.ServiceQuotas.html#get_requested_service_quota_change/3","title":"AWS.ServiceQuotas.get_requested_service_quota_change/3","type":"function"},{"doc":"Retrieves the applied quota value for the specified quota.\n\nFor some quotas, only the default values are available. If the applied quota\nvalue is not available for a quota, the quota is not retrieved.","ref":"AWS.ServiceQuotas.html#get_service_quota/3","title":"AWS.ServiceQuotas.get_service_quota/3","type":"function"},{"doc":"Retrieves information about the specified quota increase request in your quota\nrequest template.","ref":"AWS.ServiceQuotas.html#get_service_quota_increase_request_from_template/3","title":"AWS.ServiceQuotas.get_service_quota_increase_request_from_template/3","type":"function"},{"doc":"Lists the default values for the quotas for the specified Amazon Web Service.\n\nA default value does not reflect any quota increases.","ref":"AWS.ServiceQuotas.html#list_aws_default_service_quotas/3","title":"AWS.ServiceQuotas.list_aws_default_service_quotas/3","type":"function"},{"doc":"Retrieves the quota increase requests for the specified Amazon Web Service.","ref":"AWS.ServiceQuotas.html#list_requested_service_quota_change_history/3","title":"AWS.ServiceQuotas.list_requested_service_quota_change_history/3","type":"function"},{"doc":"Retrieves the quota increase requests for the specified quota.","ref":"AWS.ServiceQuotas.html#list_requested_service_quota_change_history_by_quota/3","title":"AWS.ServiceQuotas.list_requested_service_quota_change_history_by_quota/3","type":"function"},{"doc":"Lists the quota increase requests in the specified quota request template.","ref":"AWS.ServiceQuotas.html#list_service_quota_increase_requests_in_template/3","title":"AWS.ServiceQuotas.list_service_quota_increase_requests_in_template/3","type":"function"},{"doc":"Lists the applied quota values for the specified Amazon Web Service.\n\nFor some quotas, only the default values are available. If the applied quota\nvalue is not available for a quota, the quota is not retrieved.","ref":"AWS.ServiceQuotas.html#list_service_quotas/3","title":"AWS.ServiceQuotas.list_service_quotas/3","type":"function"},{"doc":"Lists the names and codes for the Amazon Web Services integrated with Service\nQuotas.","ref":"AWS.ServiceQuotas.html#list_services/3","title":"AWS.ServiceQuotas.list_services/3","type":"function"},{"doc":"Returns a list of the tags assigned to the specified applied quota.","ref":"AWS.ServiceQuotas.html#list_tags_for_resource/3","title":"AWS.ServiceQuotas.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.ServiceQuotas.html#metadata/0","title":"AWS.ServiceQuotas.metadata/0","type":"function"},{"doc":"Adds a quota increase request to your quota request template.","ref":"AWS.ServiceQuotas.html#put_service_quota_increase_request_into_template/3","title":"AWS.ServiceQuotas.put_service_quota_increase_request_into_template/3","type":"function"},{"doc":"Submits a quota increase request for the specified quota.","ref":"AWS.ServiceQuotas.html#request_service_quota_increase/3","title":"AWS.ServiceQuotas.request_service_quota_increase/3","type":"function"},{"doc":"Adds tags to the specified applied quota.\n\nYou can include one or more tags to add to the quota.","ref":"AWS.ServiceQuotas.html#tag_resource/3","title":"AWS.ServiceQuotas.tag_resource/3","type":"function"},{"doc":"Removes tags from the specified applied quota.\n\nYou can specify one or more tags to remove.","ref":"AWS.ServiceQuotas.html#untag_resource/3","title":"AWS.ServiceQuotas.untag_resource/3","type":"function"},{"doc":"Shield Advanced\n\nThis is the *Shield Advanced API Reference*.\n\nThis guide is for developers who need detailed information about the Shield\nAdvanced API actions, data types, and errors. For detailed information about WAF\nand Shield Advanced features and an overview of how to use the WAF and Shield\nAdvanced APIs, see the [WAF and Shield Developer Guide](https://docs.aws.amazon.com/waf/latest/developerguide/).","ref":"AWS.Shield.html","title":"AWS.Shield","type":"module"},{"doc":"Authorizes the Shield Response Team (SRT) to access the specified Amazon S3\nbucket containing log data such as Application Load Balancer access logs,\nCloudFront logs, or logs from third party sources.\n\nYou can associate up to 10 Amazon S3 buckets with your subscription.\n\nTo use the services of the SRT and make an `AssociateDRTLogBucket` request, you\nmust be subscribed to the [Business Support plan](http://aws.amazon.com/premiumsupport/business-support/) or the [Enterprise Support plan](http://aws.amazon.com/premiumsupport/enterprise-support/).","ref":"AWS.Shield.html#associate_drt_log_bucket/3","title":"AWS.Shield.associate_drt_log_bucket/3","type":"function"},{"doc":"Authorizes the Shield Response Team (SRT) using the specified role, to access\nyour Amazon Web Services account to assist with DDoS attack mitigation during\npotential attacks.\n\nThis enables the SRT to inspect your WAF configuration and create or update WAF\nrules and web ACLs.\n\nYou can associate only one `RoleArn` with your subscription. If you submit an\n`AssociateDRTRole` request for an account that already has an associated role,\nthe new `RoleArn` will replace the existing `RoleArn`.\n\nPrior to making the `AssociateDRTRole` request, you must attach the\n`AWSShieldDRTAccessPolicy` managed policy to the role that you'll specify in the\nrequest. You can access this policy in the IAM console at\n[AWSShieldDRTAccessPolicy](https://console.aws.amazon.com/iam/home?#/policies/arn:aws:iam::aws:policy/service-role/AWSShieldDRTAccessPolicy). For more information see [Adding and removing IAM identity\npermissions](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_manage-attach-detach.html).\nThe role must also trust the service principal `drt.shield.amazonaws.com`. For\nmore information, see [IAM JSON policy elements: Principal](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_principal.html).\n\nThe SRT will have access only to your WAF and Shield resources. By submitting\nthis request, you authorize the SRT to inspect your WAF and Shield configuration\nand create and update WAF rules and web ACLs on your behalf. The SRT takes these\nactions only if explicitly authorized by you.\n\nYou must have the `iam:PassRole` permission to make an `AssociateDRTRole`\nrequest. For more information, see [Granting a user permissions to pass a role to an Amazon Web Services\nservice](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_use_passrole.html).\n\nTo use the services of the SRT and make an `AssociateDRTRole` request, you must\nbe subscribed to the [Business Support plan](http://aws.amazon.com/premiumsupport/business-support/) or the [Enterprise Support plan](http://aws.amazon.com/premiumsupport/enterprise-support/).","ref":"AWS.Shield.html#associate_drt_role/3","title":"AWS.Shield.associate_drt_role/3","type":"function"},{"doc":"Adds health-based detection to the Shield Advanced protection for a resource.\n\nShield Advanced health-based detection uses the health of your Amazon Web\nServices resource to improve responsiveness and accuracy in attack detection and\nresponse.\n\nYou define the health check in Route 53 and then associate it with your Shield\nAdvanced protection. For more information, see [Shield Advanced Health-Based Detection](https://docs.aws.amazon.com/waf/latest/developerguide/ddos-overview.html#ddos-advanced-health-check-option)\nin the *WAF Developer Guide*.","ref":"AWS.Shield.html#associate_health_check/3","title":"AWS.Shield.associate_health_check/3","type":"function"},{"doc":"Initializes proactive engagement and sets the list of contacts for the Shield\nResponse Team (SRT) to use.\n\nYou must provide at least one phone number in the emergency contact list.\n\nAfter you have initialized proactive engagement using this call, to disable or\nenable proactive engagement, use the calls `DisableProactiveEngagement` and\n`EnableProactiveEngagement`.\n\nThis call defines the list of email addresses and phone numbers that the SRT can\nuse to contact you for escalations to the SRT and to initiate proactive customer\nsupport.\n\nThe contacts that you provide in the request replace any contacts that were\nalready defined. If you already have contacts defined and want to use them,\nretrieve the list using `DescribeEmergencyContactSettings` and then provide it\nto this call.","ref":"AWS.Shield.html#associate_proactive_engagement_details/3","title":"AWS.Shield.associate_proactive_engagement_details/3","type":"function"},{"doc":"Enables Shield Advanced for a specific Amazon Web Services resource.\n\nThe resource can be an Amazon CloudFront distribution, Amazon Route 53 hosted\nzone, Global Accelerator standard accelerator, Elastic IP Address, Application\nLoad Balancer, or a Classic Load Balancer. You can protect Amazon EC2 instances\nand Network Load Balancers by association with protected Amazon EC2 Elastic IP\naddresses.\n\nYou can add protection to only a single resource with each `CreateProtection`\nrequest. You can add protection to multiple resources at once through the Shield\nAdvanced console at\n[https://console.aws.amazon.com/wafv2/shieldv2#/](https://console.aws.amazon.com/wafv2/shieldv2#/). For more information see [Getting Started with Shield\nAdvanced](https://docs.aws.amazon.com/waf/latest/developerguide/getting-started-ddos.html)\nand [Adding Shield Advanced protection to Amazon Web Services resources](https://docs.aws.amazon.com/waf/latest/developerguide/configure-new-protection.html).","ref":"AWS.Shield.html#create_protection/3","title":"AWS.Shield.create_protection/3","type":"function"},{"doc":"Creates a grouping of protected resources so they can be handled as a\ncollective.\n\nThis resource grouping improves the accuracy of detection and reduces false\npositives.","ref":"AWS.Shield.html#create_protection_group/3","title":"AWS.Shield.create_protection_group/3","type":"function"},{"doc":"Activates Shield Advanced for an account.\n\nFor accounts that are members of an Organizations organization, Shield Advanced\nsubscriptions are billed against the organization's payer account, regardless of\nwhether the payer account itself is subscribed.\n\nWhen you initially create a subscription, your subscription is set to be\nautomatically renewed at the end of the existing subscription period. You can\nchange this by submitting an `UpdateSubscription` request.","ref":"AWS.Shield.html#create_subscription/3","title":"AWS.Shield.create_subscription/3","type":"function"},{"doc":"Deletes an Shield Advanced `Protection`.","ref":"AWS.Shield.html#delete_protection/3","title":"AWS.Shield.delete_protection/3","type":"function"},{"doc":"Removes the specified protection group.","ref":"AWS.Shield.html#delete_protection_group/3","title":"AWS.Shield.delete_protection_group/3","type":"function"},{"doc":"Removes Shield Advanced from an account.\n\nShield Advanced requires a 1-year subscription commitment. You cannot delete a\nsubscription prior to the completion of that commitment.","ref":"AWS.Shield.html#delete_subscription/3","title":"AWS.Shield.delete_subscription/3","type":"function"},{"doc":"Describes the details of a DDoS attack.","ref":"AWS.Shield.html#describe_attack/3","title":"AWS.Shield.describe_attack/3","type":"function"},{"doc":"Provides information about the number and type of attacks Shield has detected in\nthe last year for all resources that belong to your account, regardless of\nwhether you've defined Shield protections for them.\n\nThis operation is available to Shield customers as well as to Shield Advanced\ncustomers.\n\nThe operation returns data for the time range of midnight UTC, one year ago, to\nmidnight UTC, today. For example, if the current time is `2020-10-26 15:39:32\nPDT`, equal to `2020-10-26 22:39:32 UTC`, then the time range for the attack\ndata returned is from `2019-10-26 00:00:00 UTC` to `2020-10-26 00:00:00 UTC`.\n\nThe time range indicates the period covered by the attack statistics data items.","ref":"AWS.Shield.html#describe_attack_statistics/3","title":"AWS.Shield.describe_attack_statistics/3","type":"function"},{"doc":"Returns the current role and list of Amazon S3 log buckets used by the Shield\nResponse Team (SRT) to access your Amazon Web Services account while assisting\nwith attack mitigation.","ref":"AWS.Shield.html#describe_drt_access/3","title":"AWS.Shield.describe_drt_access/3","type":"function"},{"doc":"A list of email addresses and phone numbers that the Shield Response Team (SRT)\ncan use to contact you if you have proactive engagement enabled, for escalations\nto the SRT and to initiate proactive customer support.","ref":"AWS.Shield.html#describe_emergency_contact_settings/3","title":"AWS.Shield.describe_emergency_contact_settings/3","type":"function"},{"doc":"Lists the details of a `Protection` object.","ref":"AWS.Shield.html#describe_protection/3","title":"AWS.Shield.describe_protection/3","type":"function"},{"doc":"Returns the specification for the specified protection group.","ref":"AWS.Shield.html#describe_protection_group/3","title":"AWS.Shield.describe_protection_group/3","type":"function"},{"doc":"Provides details about the Shield Advanced subscription for an account.","ref":"AWS.Shield.html#describe_subscription/3","title":"AWS.Shield.describe_subscription/3","type":"function"},{"doc":"Disable the Shield Advanced automatic application layer DDoS mitigation feature\nfor the protected resource.\n\nThis stops Shield Advanced from creating, verifying, and applying WAF rules for\nattacks that it detects for the resource.","ref":"AWS.Shield.html#disable_application_layer_automatic_response/3","title":"AWS.Shield.disable_application_layer_automatic_response/3","type":"function"},{"doc":"Removes authorization from the Shield Response Team (SRT) to notify contacts\nabout escalations to the SRT and to initiate proactive customer support.","ref":"AWS.Shield.html#disable_proactive_engagement/3","title":"AWS.Shield.disable_proactive_engagement/3","type":"function"},{"doc":"Removes the Shield Response Team's (SRT) access to the specified Amazon S3\nbucket containing the logs that you shared previously.","ref":"AWS.Shield.html#disassociate_drt_log_bucket/3","title":"AWS.Shield.disassociate_drt_log_bucket/3","type":"function"},{"doc":"Removes the Shield Response Team's (SRT) access to your Amazon Web Services\naccount.","ref":"AWS.Shield.html#disassociate_drt_role/3","title":"AWS.Shield.disassociate_drt_role/3","type":"function"},{"doc":"Removes health-based detection from the Shield Advanced protection for a\nresource.\n\nShield Advanced health-based detection uses the health of your Amazon Web\nServices resource to improve responsiveness and accuracy in attack detection and\nresponse.\n\nYou define the health check in Route 53 and then associate or disassociate it\nwith your Shield Advanced protection. For more information, see [Shield Advanced Health-Based\nDetection](https://docs.aws.amazon.com/waf/latest/developerguide/ddos-overview.html#ddos-advanced-health-check-option)\nin the *WAF Developer Guide*.","ref":"AWS.Shield.html#disassociate_health_check/3","title":"AWS.Shield.disassociate_health_check/3","type":"function"},{"doc":"Enable the Shield Advanced automatic application layer DDoS mitigation for the\nprotected resource.\n\nThis feature is available for Amazon CloudFront distributions and Application\nLoad Balancers only.\n\nThis causes Shield Advanced to create, verify, and apply WAF rules for DDoS\nattacks that it detects for the resource. Shield Advanced applies the rules in a\nShield rule group inside the web ACL that you've associated with the resource.\nFor information about how automatic mitigation works and the requirements for\nusing it, see [Shield Advanced automatic application layer DDoS mitigation](https://docs.aws.amazon.com/waf/latest/developerguide/ddos-advanced-automatic-app-layer-response.html).\n\nDon't use this action to make changes to automatic mitigation settings when it's\nalready enabled for a resource. Instead, use\n`UpdateApplicationLayerAutomaticResponse`.\n\nTo use this feature, you must associate a web ACL with the protected resource.\nThe web ACL must be created using the latest version of WAF (v2). You can\nassociate the web ACL through the Shield Advanced console at\n[https://console.aws.amazon.com/wafv2/shieldv2#/](https://console.aws.amazon.com/wafv2/shieldv2#/). For more information, see [Getting Started with Shield\nAdvanced](https://docs.aws.amazon.com/waf/latest/developerguide/getting-started-ddos.html).\nYou can also associate the web ACL to the resource through the WAF console or\nthe WAF API, but you must manage Shield Advanced automatic mitigation through\nShield Advanced. For information about WAF, see [WAF Developer Guide](https://docs.aws.amazon.com/waf/latest/developerguide/).","ref":"AWS.Shield.html#enable_application_layer_automatic_response/3","title":"AWS.Shield.enable_application_layer_automatic_response/3","type":"function"},{"doc":"Authorizes the Shield Response Team (SRT) to use email and phone to notify\ncontacts about escalations to the SRT and to initiate proactive customer\nsupport.","ref":"AWS.Shield.html#enable_proactive_engagement/3","title":"AWS.Shield.enable_proactive_engagement/3","type":"function"},{"doc":"Returns the `SubscriptionState`, either `Active` or `Inactive`.","ref":"AWS.Shield.html#get_subscription_state/3","title":"AWS.Shield.get_subscription_state/3","type":"function"},{"doc":"Returns all ongoing DDoS attacks or all DDoS attacks during a specified time\nperiod.","ref":"AWS.Shield.html#list_attacks/3","title":"AWS.Shield.list_attacks/3","type":"function"},{"doc":"Retrieves `ProtectionGroup` objects for the account.\n\nYou can retrieve all protection groups or you can provide filtering criteria and\nretrieve just the subset of protection groups that match the criteria.","ref":"AWS.Shield.html#list_protection_groups/3","title":"AWS.Shield.list_protection_groups/3","type":"function"},{"doc":"Retrieves `Protection` objects for the account.\n\nYou can retrieve all protections or you can provide filtering criteria and\nretrieve just the subset of protections that match the criteria.","ref":"AWS.Shield.html#list_protections/3","title":"AWS.Shield.list_protections/3","type":"function"},{"doc":"Retrieves the resources that are included in the protection group.","ref":"AWS.Shield.html#list_resources_in_protection_group/3","title":"AWS.Shield.list_resources_in_protection_group/3","type":"function"},{"doc":"Gets information about Amazon Web Services tags for a specified Amazon Resource\nName (ARN) in Shield.","ref":"AWS.Shield.html#list_tags_for_resource/3","title":"AWS.Shield.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.Shield.html#metadata/0","title":"AWS.Shield.metadata/0","type":"function"},{"doc":"Adds or updates tags for a resource in Shield.","ref":"AWS.Shield.html#tag_resource/3","title":"AWS.Shield.tag_resource/3","type":"function"},{"doc":"Removes tags from a resource in Shield.","ref":"AWS.Shield.html#untag_resource/3","title":"AWS.Shield.untag_resource/3","type":"function"},{"doc":"Updates an existing Shield Advanced automatic application layer DDoS mitigation\nconfiguration for the specified resource.","ref":"AWS.Shield.html#update_application_layer_automatic_response/3","title":"AWS.Shield.update_application_layer_automatic_response/3","type":"function"},{"doc":"Updates the details of the list of email addresses and phone numbers that the\nShield Response Team (SRT) can use to contact you if you have proactive\nengagement enabled, for escalations to the SRT and to initiate proactive\ncustomer support.","ref":"AWS.Shield.html#update_emergency_contact_settings/3","title":"AWS.Shield.update_emergency_contact_settings/3","type":"function"},{"doc":"Updates an existing protection group.\n\nA protection group is a grouping of protected resources so they can be handled\nas a collective. This resource grouping improves the accuracy of detection and\nreduces false positives.","ref":"AWS.Shield.html#update_protection_group/3","title":"AWS.Shield.update_protection_group/3","type":"function"},{"doc":"Updates the details of an existing subscription.\n\nOnly enter values for parameters you want to change. Empty parameters are not\nupdated.\n\nFor accounts that are members of an Organizations organization, Shield Advanced\nsubscriptions are billed against the organization's payer account, regardless of\nwhether the payer account itself is subscribed.","ref":"AWS.Shield.html#update_subscription/3","title":"AWS.Shield.update_subscription/3","type":"function"},{"doc":"AWS Signer is a fully managed code-signing service to help you ensure the trust\nand integrity of your code.\n\nSigner supports the following applications:\n\nWith code signing for AWS Lambda, you can sign [AWS Lambda](http://docs.aws.amazon.com/lambda/latest/dg/) deployment packages.\nIntegrated support is provided for [Amazon S3](http://docs.aws.amazon.com/AmazonS3/latest/gsg/), [Amazon CloudWatch](http://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/), and\n[AWS CloudTrail](http://docs.aws.amazon.com/awscloudtrail/latest/userguide/). In order to sign code, you create a signing profile and then use Signer to sign\nLambda zip files in S3.\n\nWith code signing for IoT, you can sign code for any IoT device that is\nsupported by AWS. IoT code signing is available for [Amazon\nFreeRTOS](http://docs.aws.amazon.com/freertos/latest/userguide/) and [AWS IoT Device Management](http://docs.aws.amazon.com/iot/latest/developerguide/), and\nis integrated with [AWS Certificate Manager (ACM)](http://docs.aws.amazon.com/acm/latest/userguide/). In order to sign code,\nyou import a third-party code-signing certificate using ACM, and use that to\nsign updates in Amazon FreeRTOS and AWS IoT Device Management.\n\nWith Signer and the Notation CLI from the [Notary Project](https://notaryproject.dev/), you can sign container images stored in a\ncontainer registry such as Amazon Elastic Container Registry (ECR). The\nsignatures are stored in the registry alongside the images, where they are\navailable for verifying image authenticity and integrity.\n\nFor more information about Signer, see the [AWS Signer Developer Guide](https://docs.aws.amazon.com/signer/latest/developerguide/Welcome.html).","ref":"AWS.Signer.html","title":"AWS.Signer","type":"module"},{"doc":"Adds cross-account permissions to a signing profile.","ref":"AWS.Signer.html#add_profile_permission/4","title":"AWS.Signer.add_profile_permission/4","type":"function"},{"doc":"Changes the state of an `ACTIVE` signing profile to `CANCELED`.\n\nA canceled profile is still viewable with the `ListSigningProfiles` operation,\nbut it cannot perform new signing jobs, and is deleted two years after\ncancelation.","ref":"AWS.Signer.html#cancel_signing_profile/4","title":"AWS.Signer.cancel_signing_profile/4","type":"function"},{"doc":"Returns information about a specific code signing job.\n\nYou specify the job by using the `jobId` value that is returned by the\n`StartSigningJob` operation.","ref":"AWS.Signer.html#describe_signing_job/3","title":"AWS.Signer.describe_signing_job/3","type":"function"},{"doc":"Retrieves the revocation status of one or more of the signing profile, signing\njob, and signing certificate.","ref":"AWS.Signer.html#get_revocation_status/7","title":"AWS.Signer.get_revocation_status/7","type":"function"},{"doc":"Returns information on a specific signing platform.","ref":"AWS.Signer.html#get_signing_platform/3","title":"AWS.Signer.get_signing_platform/3","type":"function"},{"doc":"Returns information on a specific signing profile.","ref":"AWS.Signer.html#get_signing_profile/4","title":"AWS.Signer.get_signing_profile/4","type":"function"},{"doc":"Lists the cross-account permissions associated with a signing profile.","ref":"AWS.Signer.html#list_profile_permissions/4","title":"AWS.Signer.list_profile_permissions/4","type":"function"},{"doc":"Lists all your signing jobs.\n\nYou can use the `maxResults` parameter to limit the number of signing jobs that\nare returned in the response. If additional jobs remain to be listed, AWS Signer\nreturns a `nextToken` value. Use this value in subsequent calls to\n`ListSigningJobs` to fetch the remaining values. You can continue calling\n`ListSigningJobs` with your `maxResults` parameter and with new values that\nSigner returns in the `nextToken` parameter until all of your signing jobs have\nbeen returned.","ref":"AWS.Signer.html#list_signing_jobs/11","title":"AWS.Signer.list_signing_jobs/11","type":"function"},{"doc":"Lists all signing platforms available in AWS Signer that match the request\nparameters.\n\nIf additional jobs remain to be listed, Signer returns a `nextToken` value. Use\nthis value in subsequent calls to `ListSigningJobs` to fetch the remaining\nvalues. You can continue calling `ListSigningJobs` with your `maxResults`\nparameter and with new values that Signer returns in the `nextToken` parameter\nuntil all of your signing jobs have been returned.","ref":"AWS.Signer.html#list_signing_platforms/7","title":"AWS.Signer.list_signing_platforms/7","type":"function"},{"doc":"Lists all available signing profiles in your AWS account.\n\nReturns only profiles with an `ACTIVE` status unless the `includeCanceled`\nrequest field is set to `true`. If additional jobs remain to be listed, AWS\nSigner returns a `nextToken` value. Use this value in subsequent calls to\n`ListSigningJobs` to fetch the remaining values. You can continue calling\n`ListSigningJobs` with your `maxResults` parameter and with new values that\nSigner returns in the `nextToken` parameter until all of your signing jobs have\nbeen returned.","ref":"AWS.Signer.html#list_signing_profiles/7","title":"AWS.Signer.list_signing_profiles/7","type":"function"},{"doc":"Returns a list of the tags associated with a signing profile resource.","ref":"AWS.Signer.html#list_tags_for_resource/3","title":"AWS.Signer.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.Signer.html#metadata/0","title":"AWS.Signer.metadata/0","type":"function"},{"doc":"Creates a signing profile.\n\nA signing profile is a code-signing template that can be used to carry out a\npre-defined signing job.","ref":"AWS.Signer.html#put_signing_profile/4","title":"AWS.Signer.put_signing_profile/4","type":"function"},{"doc":"Removes cross-account permissions from a signing profile.","ref":"AWS.Signer.html#remove_profile_permission/5","title":"AWS.Signer.remove_profile_permission/5","type":"function"},{"doc":"Changes the state of a signing job to REVOKED.\n\nThis indicates that the signature is no longer valid.","ref":"AWS.Signer.html#revoke_signature/4","title":"AWS.Signer.revoke_signature/4","type":"function"},{"doc":"Changes the state of a signing profile to REVOKED.\n\nThis indicates that signatures generated using the signing profile after an\neffective start date are no longer valid.","ref":"AWS.Signer.html#revoke_signing_profile/4","title":"AWS.Signer.revoke_signing_profile/4","type":"function"},{"doc":"Signs a binary payload and returns a signature envelope.","ref":"AWS.Signer.html#sign_payload/3","title":"AWS.Signer.sign_payload/3","type":"function"},{"doc":"Initiates a signing job to be performed on the code provided.\n\nSigning jobs are viewable by the `ListSigningJobs` operation for two years after\nthey are performed. Note the following requirements:\n\n  * You must create an Amazon S3 source bucket. For more information,\nsee [Creating a Bucket](http://docs.aws.amazon.com/AmazonS3/latest/gsg/CreatingABucket.html) in\nthe *Amazon S3 Getting Started Guide*.\n\n  * Your S3 source bucket must be version enabled.\n\n  * You must create an S3 destination bucket. AWS Signer uses your S3\ndestination bucket to write your signed code.\n\n  * You specify the name of the source and destination buckets when\ncalling the `StartSigningJob` operation.\n\n  * You must also specify a request token that identifies your request\nto Signer.\n\nYou can call the `DescribeSigningJob` and the `ListSigningJobs` actions after\nyou call `StartSigningJob`.\n\nFor a Java example that shows how to use this action, see\n[StartSigningJob](https://docs.aws.amazon.com/signer/latest/developerguide/api-startsigningjob.html).","ref":"AWS.Signer.html#start_signing_job/3","title":"AWS.Signer.start_signing_job/3","type":"function"},{"doc":"Adds one or more tags to a signing profile.\n\nTags are labels that you can use to identify and organize your AWS resources.\nEach tag consists of a key and an optional value. To specify the signing\nprofile, use its Amazon Resource Name (ARN). To specify the tag, use a key-value\npair.","ref":"AWS.Signer.html#tag_resource/4","title":"AWS.Signer.tag_resource/4","type":"function"},{"doc":"Removes one or more tags from a signing profile.\n\nTo remove the tags, specify a list of tag keys.","ref":"AWS.Signer.html#untag_resource/4","title":"AWS.Signer.untag_resource/4","type":"function"},{"doc":"SimSpace Weaver (SimSpace Weaver) is a service that you can use to build and run\nlarge-scale spatial simulations in the Amazon Web Services Cloud.\n\nFor example, you can create crowd simulations, large real-world environments,\nand immersive and interactive experiences. For more information about SimSpace\nWeaver, see the * [SimSpace Weaver User Guide](https://docs.aws.amazon.com/simspaceweaver/latest/userguide/) *.\n\nThis API reference describes the API operations and data types that you can use\nto communicate directly with SimSpace Weaver.\n\nSimSpace Weaver also provides the SimSpace Weaver app SDK, which you use for app\ndevelopment. The SimSpace Weaver app SDK API reference is included in the\nSimSpace Weaver app SDK documentation. This documentation is part of the\nSimSpace Weaver app SDK distributable package.","ref":"AWS.SimSpaceWeaver.html","title":"AWS.SimSpaceWeaver","type":"module"},{"doc":"Creates a snapshot of the specified simulation.\n\nA snapshot is a file that contains simulation state data at a specific time. The\nstate data saved in a snapshot includes entity data from the State Fabric, the\nsimulation configuration specified in the schema, and the clock tick number. You\ncan use the snapshot to initialize a new simulation. For more information about\nsnapshots, see\n[Snapshots](https://docs.aws.amazon.com/simspaceweaver/latest/userguide/working-with_snapshots.html)\nin the *SimSpace Weaver User Guide*.\n\nYou specify a `Destination` when you create a snapshot. The `Destination` is the\nname of an Amazon S3 bucket and an optional `ObjectKeyPrefix`. The\n`ObjectKeyPrefix` is usually the name of a folder in the bucket. SimSpace Weaver\ncreates a `snapshot` folder inside the `Destination` and places the snapshot\nfile there.\n\nThe snapshot file is an Amazon S3 object. It has an object key with the form: `\n*object-key-prefix*/snapshot/*simulation-name*-*YYMMdd*-*HHmm*-*ss*.zip`, where:\n\n  * ` *YY* ` is the 2-digit year\n\n  * ` *MM* ` is the 2-digit month\n\n  * ` *dd* ` is the 2-digit day of the month\n\n  * ` *HH* ` is the 2-digit hour (24-hour clock)\n\n  * ` *mm* ` is the 2-digit minutes\n\n  * ` *ss* ` is the 2-digit seconds","ref":"AWS.SimSpaceWeaver.html#create_snapshot/3","title":"AWS.SimSpaceWeaver.create_snapshot/3","type":"function"},{"doc":"Deletes the instance of the given custom app.","ref":"AWS.SimSpaceWeaver.html#delete_app/3","title":"AWS.SimSpaceWeaver.delete_app/3","type":"function"},{"doc":"Deletes all SimSpace Weaver resources assigned to the given simulation.\n\nYour simulation uses resources in other Amazon Web Services. This API operation\ndoesn't delete resources in other Amazon Web Services.","ref":"AWS.SimSpaceWeaver.html#delete_simulation/3","title":"AWS.SimSpaceWeaver.delete_simulation/3","type":"function"},{"doc":"Returns the state of the given custom app.","ref":"AWS.SimSpaceWeaver.html#describe_app/5","title":"AWS.SimSpaceWeaver.describe_app/5","type":"function"},{"doc":"Returns the current state of the given simulation.","ref":"AWS.SimSpaceWeaver.html#describe_simulation/3","title":"AWS.SimSpaceWeaver.describe_simulation/3","type":"function"},{"doc":"Lists all custom apps or service apps for the given simulation and domain.","ref":"AWS.SimSpaceWeaver.html#list_apps/6","title":"AWS.SimSpaceWeaver.list_apps/6","type":"function"},{"doc":"Lists the SimSpace Weaver simulations in the Amazon Web Services account used to\nmake the API call.","ref":"AWS.SimSpaceWeaver.html#list_simulations/4","title":"AWS.SimSpaceWeaver.list_simulations/4","type":"function"},{"doc":"Lists all tags on a SimSpace Weaver resource.","ref":"AWS.SimSpaceWeaver.html#list_tags_for_resource/3","title":"AWS.SimSpaceWeaver.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.SimSpaceWeaver.html#metadata/0","title":"AWS.SimSpaceWeaver.metadata/0","type":"function"},{"doc":"Starts a custom app with the configuration specified in the simulation schema.","ref":"AWS.SimSpaceWeaver.html#start_app/3","title":"AWS.SimSpaceWeaver.start_app/3","type":"function"},{"doc":"Starts the simulation clock.","ref":"AWS.SimSpaceWeaver.html#start_clock/3","title":"AWS.SimSpaceWeaver.start_clock/3","type":"function"},{"doc":"Starts a simulation with the given name.\n\nYou must choose to start your simulation from a schema or from a snapshot. For\nmore information about the schema, see the [schema reference](https://docs.aws.amazon.com/simspaceweaver/latest/userguide/schema-reference.html)\nin the *SimSpace Weaver User Guide*. For more information about snapshots, see\n[Snapshots](https://docs.aws.amazon.com/simspaceweaver/latest/userguide/working-with_snapshots.html)\nin the *SimSpace Weaver User Guide*.","ref":"AWS.SimSpaceWeaver.html#start_simulation/3","title":"AWS.SimSpaceWeaver.start_simulation/3","type":"function"},{"doc":"Stops the given custom app and shuts down all of its allocated compute\nresources.","ref":"AWS.SimSpaceWeaver.html#stop_app/3","title":"AWS.SimSpaceWeaver.stop_app/3","type":"function"},{"doc":"Stops the simulation clock.","ref":"AWS.SimSpaceWeaver.html#stop_clock/3","title":"AWS.SimSpaceWeaver.stop_clock/3","type":"function"},{"doc":"Stops the given simulation.\n\nYou can't restart a simulation after you stop it. If you want to restart a\nsimulation, then you must stop it, delete it, and start a new instance of it.","ref":"AWS.SimSpaceWeaver.html#stop_simulation/3","title":"AWS.SimSpaceWeaver.stop_simulation/3","type":"function"},{"doc":"Adds tags to a SimSpace Weaver resource.\n\nFor more information about tags, see [Tagging Amazon Web Services resources](https://docs.aws.amazon.com/general/latest/gr/aws_tagging.html) in\nthe *Amazon Web Services General Reference*.","ref":"AWS.SimSpaceWeaver.html#tag_resource/4","title":"AWS.SimSpaceWeaver.tag_resource/4","type":"function"},{"doc":"Removes tags from a SimSpace Weaver resource.\n\nFor more information about tags, see [Tagging Amazon Web Services resources](https://docs.aws.amazon.com/general/latest/gr/aws_tagging.html) in\nthe *Amazon Web Services General Reference*.","ref":"AWS.SimSpaceWeaver.html#untag_resource/4","title":"AWS.SimSpaceWeaver.untag_resource/4","type":"function"},{"doc":"Amazon SimpleDB is a web service providing the core database functions of data\nindexing and querying in the cloud.\n\nBy offloading the time and effort associated with building and operating a\nweb-scale database, SimpleDB provides developers the freedom to focus on\napplication development. A traditional, clustered relational database requires a\nsizable upfront capital outlay, is complex to design, and often requires\nextensive and repetitive database administration. Amazon SimpleDB is\ndramatically simpler, requiring no schema, automatically indexing your data and\nproviding a simple API for storage and access. This approach eliminates the\nadministrative burden of data modeling, index maintenance, and performance\ntuning. Developers gain access to this functionality within Amazon's proven\ncomputing environment, are able to scale instantly, and pay only for what they\nuse.\n\nVisit [http://aws.amazon.com/simpledb/](http://aws.amazon.com/simpledb/) for\nmore information.","ref":"AWS.SimpleDB.html","title":"AWS.SimpleDB","type":"module"},{"doc":"Performs multiple DeleteAttributes operations in a single call, which reduces\nround trips and latencies.\n\nThis enables Amazon SimpleDB to optimize requests, which generally yields better\nthroughput.\n\nIf you specify BatchDeleteAttributes without attributes or values, all the\nattributes for the item are deleted.\n\nBatchDeleteAttributes is an idempotent operation; running it multiple times on\nthe same item or attribute doesn't result in an error.\n\nThe BatchDeleteAttributes operation succeeds or fails in its entirety. There are\nno partial deletes. You can execute multiple BatchDeleteAttributes operations\nand other operations in parallel. However, large numbers of concurrent\nBatchDeleteAttributes calls can result in Service Unavailable (503) responses.\n\nThis operation is vulnerable to exceeding the maximum URL size when making a\nREST request using the HTTP GET method.\n\nThis operation does not support conditions using Expected.X.Name,\nExpected.X.Value, or Expected.X.Exists.\n\nThe following limitations are enforced for this operation:\n\n  * 1 MB request size\n  * 25 item limit per BatchDeleteAttributes operation","ref":"AWS.SimpleDB.html#batch_delete_attributes/3","title":"AWS.SimpleDB.batch_delete_attributes/3","type":"function"},{"doc":"The `BatchPutAttributes` operation creates or replaces attributes within one or\nmore items.\n\nBy using this operation, the client can perform multiple `PutAttribute`\noperation with a single call. This helps yield savings in round trips and\nlatencies, enabling Amazon SimpleDB to optimize requests and generally produce\nbetter throughput.\n\nThe client may specify the item name with the `Item.X.ItemName` parameter. The\nclient may specify new attributes using a combination of the\n`Item.X.Attribute.Y.Name` and `Item.X.Attribute.Y.Value` parameters. The client\nmay specify the first attribute for the first item using the parameters\n`Item.0.Attribute.0.Name` and `Item.0.Attribute.0.Value`, and for the second\nattribute for the first item by the parameters `Item.0.Attribute.1.Name` and\n`Item.0.Attribute.1.Value`, and so on.\n\nAttributes are uniquely identified within an item by their name/value\ncombination. For example, a single item can have the attributes `{ \"first_name\",\n\"first_value\" }` and `{ \"first_name\", \"second_value\" }`. However, it cannot have\ntwo attribute instances where both the `Item.X.Attribute.Y.Name` and\n`Item.X.Attribute.Y.Value` are the same.\n\nOptionally, the requester can supply the `Replace` parameter for each individual\nvalue. Setting this value to `true` will cause the new attribute values to\nreplace the existing attribute values. For example, if an item `I` has the\nattributes `{ 'a', '1' }, { 'b', '2'}` and `{ 'b', '3' }` and the requester does\na BatchPutAttributes of `{'I', 'b', '4' }` with the Replace parameter set to\ntrue, the final attributes of the item will be `{ 'a', '1' }` and `{ 'b', '4'\n}`, replacing the previous values of the 'b' attribute with the new value.\n\nYou cannot specify an empty string as an item or as an attribute name. The\n`BatchPutAttributes` operation succeeds or fails in its entirety. There are no\npartial puts.\n\nThis operation is vulnerable to exceeding the maximum URL size when making a\nREST request using the HTTP GET method. This operation does not support\nconditions using `Expected.X.Name`, `Expected.X.Value`, or `Expected.X.Exists`.\n\nYou can execute multiple `BatchPutAttributes` operations and other operations in\nparallel. However, large numbers of concurrent `BatchPutAttributes` calls can\nresult in Service Unavailable (503) responses.\n\nThe following limitations are enforced for this operation:\n\n  * 256 attribute name-value pairs per item\n  * 1 MB request size\n  * 1 billion attributes per domain\n  * 10 GB of total user data storage per domain\n  * 25 item limit per `BatchPutAttributes` operation","ref":"AWS.SimpleDB.html#batch_put_attributes/3","title":"AWS.SimpleDB.batch_put_attributes/3","type":"function"},{"doc":"The `CreateDomain` operation creates a new domain.\n\nThe domain name should be unique among the domains associated with the Access\nKey ID provided in the request. The `CreateDomain` operation may take 10 or more\nseconds to complete.\n\nCreateDomain is an idempotent operation; running it multiple times using the\nsame domain name will not result in an error response.\n\nThe client can create up to 100 domains per account.\n\nIf the client requires additional domains, go to [\nhttp://aws.amazon.com/contact-us/simpledb-limit-request/](http://aws.amazon.com/contact-us/simpledb-limit-request/).","ref":"AWS.SimpleDB.html#create_domain/3","title":"AWS.SimpleDB.create_domain/3","type":"function"},{"doc":"Deletes one or more attributes associated with an item.\n\nIf all attributes of the item are deleted, the item is deleted.\n\nIf `DeleteAttributes` is called without being passed any attributes or values\nspecified, all the attributes for the item are deleted.\n\n`DeleteAttributes` is an idempotent operation; running it multiple times on the\nsame item or attribute does not result in an error response.\n\nBecause Amazon SimpleDB makes multiple copies of item data and uses an eventual\nconsistency update model, performing a `GetAttributes` or `Select` operation\n(read) immediately after a `DeleteAttributes` or `PutAttributes` operation\n(write) might not return updated item data.","ref":"AWS.SimpleDB.html#delete_attributes/3","title":"AWS.SimpleDB.delete_attributes/3","type":"function"},{"doc":"The `DeleteDomain` operation deletes a domain.\n\nAny items (and their attributes) in the domain are deleted as well. The\n`DeleteDomain` operation might take 10 or more seconds to complete.\n\nRunning `DeleteDomain` on a domain that does not exist or running the function\nmultiple times using the same domain name will not result in an error response.","ref":"AWS.SimpleDB.html#delete_domain/3","title":"AWS.SimpleDB.delete_domain/3","type":"function"},{"doc":"Returns information about the domain, including when the domain was created, the\nnumber of items and attributes in the domain, and the size of the attribute\nnames and values.","ref":"AWS.SimpleDB.html#domain_metadata/3","title":"AWS.SimpleDB.domain_metadata/3","type":"function"},{"doc":"Returns all of the attributes associated with the specified item.\n\nOptionally, the attributes returned can be limited to one or more attributes by\nspecifying an attribute name parameter.\n\nIf the item does not exist on the replica that was accessed for this operation,\nan empty set is returned. The system does not return an error as it cannot\nguarantee the item does not exist on other replicas.\n\nIf GetAttributes is called without being passed any attribute names, all the\nattributes for the item are returned.","ref":"AWS.SimpleDB.html#get_attributes/3","title":"AWS.SimpleDB.get_attributes/3","type":"function"},{"doc":"The `ListDomains` operation lists all domains associated with the Access Key ID.\n\nIt returns domain names up to the limit set by\n[MaxNumberOfDomains](#MaxNumberOfDomains). A [NextToken](#NextToken) is returned\nif there are more than `MaxNumberOfDomains` domains. Calling `ListDomains`\nsuccessive times with the `NextToken` provided by the operation returns up to\n`MaxNumberOfDomains` more domain names with each successive operation call.","ref":"AWS.SimpleDB.html#list_domains/3","title":"AWS.SimpleDB.list_domains/3","type":"function"},{"doc":"","ref":"AWS.SimpleDB.html#metadata/0","title":"AWS.SimpleDB.metadata/0","type":"function"},{"doc":"The PutAttributes operation creates or replaces attributes in an item.\n\nThe client may specify new attributes using a combination of the\n`Attribute.X.Name` and `Attribute.X.Value` parameters. The client specifies the\nfirst attribute by the parameters `Attribute.0.Name` and `Attribute.0.Value`,\nthe second attribute by the parameters `Attribute.1.Name` and\n`Attribute.1.Value`, and so on.\n\nAttributes are uniquely identified in an item by their name/value combination.\nFor example, a single item can have the attributes `{ \"first_name\",\n\"first_value\" }` and `{ \"first_name\", second_value\" }`. However, it cannot have\ntwo attribute instances where both the `Attribute.X.Name` and\n`Attribute.X.Value` are the same.\n\nOptionally, the requestor can supply the `Replace` parameter for each individual\nattribute. Setting this value to `true` causes the new attribute value to\nreplace the existing attribute value(s). For example, if an item has the\nattributes `{ 'a', '1' }`, `{ 'b', '2'}` and `{ 'b', '3' }` and the requestor\ncalls `PutAttributes` using the attributes `{ 'b', '4' }` with the `Replace`\nparameter set to true, the final attributes of the item are changed to `{ 'a',\n'1' }` and `{ 'b', '4' }`, which replaces the previous values of the 'b'\nattribute with the new value.\n\nUsing `PutAttributes` to replace attribute values that do not exist will not\nresult in an error response.\n\nYou cannot specify an empty string as an attribute name.\n\nBecause Amazon SimpleDB makes multiple copies of client data and uses an\neventual consistency update model, an immediate `GetAttributes` or `Select`\noperation (read) immediately after a `PutAttributes` or `DeleteAttributes`\noperation (write) might not return the updated data.\n\nThe following limitations are enforced for this operation:\n\n  * 256 total attribute name-value pairs per item\n  * One billion attributes per domain\n  * 10 GB of total user data storage per domain","ref":"AWS.SimpleDB.html#put_attributes/3","title":"AWS.SimpleDB.put_attributes/3","type":"function"},{"doc":"The `Select` operation returns a set of attributes for `ItemNames` that match\nthe select expression.\n\n`Select` is similar to the standard SQL SELECT statement.\n\nThe total size of the response cannot exceed 1 MB in total size. Amazon SimpleDB\nautomatically adjusts the number of items returned per page to enforce this\nlimit. For example, if the client asks to retrieve 2500 items, but each\nindividual item is 10 kB in size, the system returns 100 items and an\nappropriate `NextToken` so the client can access the next page of results.\n\nFor information on how to construct select expressions, see Using Select to\nCreate Amazon SimpleDB Queries in the Developer Guide.","ref":"AWS.SimpleDB.html#select/3","title":"AWS.SimpleDB.select/3","type":"function"},{"doc":"Amazon Web Services Snow Device Management documentation.","ref":"AWS.SnowDeviceManagement.html","title":"AWS.SnowDeviceManagement","type":"module"},{"doc":"Sends a cancel request for a specified task.\n\nYou can cancel a task only if it's still in a `QUEUED` state. Tasks that are\nalready running can't be cancelled.\n\nA task might still run if it's processed from the queue before the `CancelTask`\noperation changes the task's state.","ref":"AWS.SnowDeviceManagement.html#cancel_task/4","title":"AWS.SnowDeviceManagement.cancel_task/4","type":"function"},{"doc":"Instructs one or more devices to start a task, such as unlocking or rebooting.","ref":"AWS.SnowDeviceManagement.html#create_task/3","title":"AWS.SnowDeviceManagement.create_task/3","type":"function"},{"doc":"Checks device-specific information, such as the device type, software version,\nIP addresses, and lock status.","ref":"AWS.SnowDeviceManagement.html#describe_device/4","title":"AWS.SnowDeviceManagement.describe_device/4","type":"function"},{"doc":"Checks the current state of the Amazon EC2 instances.\n\nThe output is similar to `describeDevice`, but the results are sourced from the\ndevice cache in the Amazon Web Services Cloud and include a subset of the\navailable fields.","ref":"AWS.SnowDeviceManagement.html#describe_device_ec2_instances/4","title":"AWS.SnowDeviceManagement.describe_device_ec2_instances/4","type":"function"},{"doc":"Checks the status of a remote task running on one or more target devices.","ref":"AWS.SnowDeviceManagement.html#describe_execution/5","title":"AWS.SnowDeviceManagement.describe_execution/5","type":"function"},{"doc":"Checks the metadata for a given task on a device.","ref":"AWS.SnowDeviceManagement.html#describe_task/4","title":"AWS.SnowDeviceManagement.describe_task/4","type":"function"},{"doc":"Returns a list of the Amazon Web Services resources available for a device.\n\nCurrently, Amazon EC2 instances are the only supported resource type.","ref":"AWS.SnowDeviceManagement.html#list_device_resources/6","title":"AWS.SnowDeviceManagement.list_device_resources/6","type":"function"},{"doc":"Returns a list of all devices on your Amazon Web Services account that have\nAmazon Web Services Snow Device Management enabled in the Amazon Web Services\nRegion where the command is run.","ref":"AWS.SnowDeviceManagement.html#list_devices/5","title":"AWS.SnowDeviceManagement.list_devices/5","type":"function"},{"doc":"Returns the status of tasks for one or more target devices.","ref":"AWS.SnowDeviceManagement.html#list_executions/6","title":"AWS.SnowDeviceManagement.list_executions/6","type":"function"},{"doc":"Returns a list of tags for a managed device or task.","ref":"AWS.SnowDeviceManagement.html#list_tags_for_resource/3","title":"AWS.SnowDeviceManagement.list_tags_for_resource/3","type":"function"},{"doc":"Returns a list of tasks that can be filtered by state.","ref":"AWS.SnowDeviceManagement.html#list_tasks/5","title":"AWS.SnowDeviceManagement.list_tasks/5","type":"function"},{"doc":"","ref":"AWS.SnowDeviceManagement.html#metadata/0","title":"AWS.SnowDeviceManagement.metadata/0","type":"function"},{"doc":"Adds or replaces tags on a device or task.","ref":"AWS.SnowDeviceManagement.html#tag_resource/4","title":"AWS.SnowDeviceManagement.tag_resource/4","type":"function"},{"doc":"Removes a tag from a device or task.","ref":"AWS.SnowDeviceManagement.html#untag_resource/4","title":"AWS.SnowDeviceManagement.untag_resource/4","type":"function"},{"doc":"The Amazon Web Services Snow Family provides a petabyte-scale data transport\nsolution that uses secure devices to transfer large amounts of data between your\non-premises data centers and Amazon Simple Storage Service (Amazon S3).\n\nThe Snow Family commands described here provide access to the same functionality\nthat is available in the Amazon Web Services Snow Family Management Console,\nwhich enables you to create and manage jobs for a Snow Family device. To\ntransfer data locally with a Snow Family device, you'll need to use the Snowball\nEdge client or the Amazon S3 API Interface for Snowball or OpsHub for Snow\nFamily. For more information, see the [User Guide](https://docs.aws.amazon.com/AWSImportExport/latest/ug/api-reference.html).","ref":"AWS.Snowball.html","title":"AWS.Snowball","type":"module"},{"doc":"Cancels a cluster job.\n\nYou can only cancel a cluster job while it's in the `AwaitingQuorum` status.\nYou'll have at least an hour after creating a cluster job to cancel it.","ref":"AWS.Snowball.html#cancel_cluster/3","title":"AWS.Snowball.cancel_cluster/3","type":"function"},{"doc":"Cancels the specified job.\n\nYou can only cancel a job before its `JobState` value changes to\n`PreparingAppliance`. Requesting the `ListJobs` or `DescribeJob` action returns\na job's `JobState` as part of the response element data returned.","ref":"AWS.Snowball.html#cancel_job/3","title":"AWS.Snowball.cancel_job/3","type":"function"},{"doc":"Creates an address for a Snow device to be shipped to.\n\nIn most regions, addresses are validated at the time of creation. The address\nyou provide must be located within the serviceable area of your region. If the\naddress is invalid or unsupported, then an exception is thrown. If providing an\naddress as a JSON file through the `cli-input-json` option, include the full\nfile path. For example, `--cli-input-json file://create-address.json`.","ref":"AWS.Snowball.html#create_address/3","title":"AWS.Snowball.create_address/3","type":"function"},{"doc":"Creates an empty cluster.\n\nEach cluster supports five nodes. You use the `CreateJob` action separately to\ncreate the jobs for each of these nodes. The cluster does not ship until these\nfive node jobs have been created.","ref":"AWS.Snowball.html#create_cluster/3","title":"AWS.Snowball.create_cluster/3","type":"function"},{"doc":"Creates a job to import or export data between Amazon S3 and your on-premises\ndata center.\n\nYour Amazon Web Services account must have the right trust policies and\npermissions in place to create a job for a Snow device. If you're creating a job\nfor a node in a cluster, you only need to provide the `clusterId` value; the\nother job attributes are inherited from the cluster.\n\nOnly the Snowball; Edge device type is supported when ordering clustered jobs.\n\nThe device capacity is optional.\n\nAvailability of device types differ by Amazon Web Services Region. For more\ninformation about Region availability, see [Amazon Web Services Regional Services](https://aws.amazon.com/about-aws/global-infrastructure/regional-product-services/?p=ngi&loc=4).","ref":"AWS.Snowball.html#create_job/3","title":"AWS.Snowball.create_job/3","type":"function"},{"doc":"* Device type:","ref":"AWS.Snowball.html#create_job/3-snow-family-devices-and-their-capacities","title":"Snow Family devices and their capacities. - AWS.Snowball.create_job/3","type":"function"},{"doc":"* Capacity: T14\n\n    * Description: Snowcone\n\n  * Device type:","ref":"AWS.Snowball.html#create_job/3-snc1_ssd","title":"SNC1_SSD - AWS.Snowball.create_job/3","type":"function"},{"doc":"* Capacity: T8\n\n    * Description: Snowcone\n\n  * Device type:","ref":"AWS.Snowball.html#create_job/3-snc1_hdd","title":"SNC1_HDD - AWS.Snowball.create_job/3","type":"function"},{"doc":"* Capacity: T98\n\n    * Description: Snowball Edge Storage Optimized for data\ntransfer only\n\n  * Device type:","ref":"AWS.Snowball.html#create_job/3-edge_s","title":"EDGE_S - AWS.Snowball.create_job/3","type":"function"},{"doc":"* Capacity: T42\n\n    * Description: Snowball Edge Compute Optimized with GPU\n\n  * Device type:","ref":"AWS.Snowball.html#create_job/3-edge_cg","title":"EDGE_CG - AWS.Snowball.create_job/3","type":"function"},{"doc":"* Capacity: T42\n\n    * Description: Snowball Edge Compute Optimized without\nGPU\n\n  * Device type:","ref":"AWS.Snowball.html#create_job/3-edge_c","title":"EDGE_C - AWS.Snowball.create_job/3","type":"function"},{"doc":"* Capacity: T100\n\n    * Description: Snowball Edge Storage Optimized with EC2\nCompute\n\nThis device is replaced with T98.\n\n  * Device type:","ref":"AWS.Snowball.html#create_job/3-edge","title":"EDGE - AWS.Snowball.create_job/3","type":"function"},{"doc":"* Capacity: T50\n\n    * Description: Original Snowball device\n\nThis device is only available in the Ningxia, Beijing, and Singapore Amazon Web\nServices Region\n\n  * Device type:","ref":"AWS.Snowball.html#create_job/3-standard","title":"STANDARD - AWS.Snowball.create_job/3","type":"function"},{"doc":"* Capacity: T80\n\n    * Description: Original Snowball device\n\nThis device is only available in the Ningxia, Beijing, and Singapore Amazon Web\nServices Region.\n\n  * Snow Family device type:","ref":"AWS.Snowball.html#create_job/3-standard","title":"STANDARD - AWS.Snowball.create_job/3","type":"function"},{"doc":"* Capacity: T13\n\n    * Description: Snowblade.\n\n  * Device type:","ref":"AWS.Snowball.html#create_job/3-rack_5u_c","title":"RACK_5U_C - AWS.Snowball.create_job/3","type":"function"},{"doc":"* Capacity: T240\n\n    * Description: Snowball Edge Storage Optimized 210TB","ref":"AWS.Snowball.html#create_job/3-v3_5s","title":"V3_5S - AWS.Snowball.create_job/3","type":"function"},{"doc":"Creates a job with the long-term usage option for a device.\n\nThe long-term usage is a 1-year or 3-year long-term pricing type for the device.\nYou are billed upfront, and Amazon Web Services provides discounts for long-term\npricing.","ref":"AWS.Snowball.html#create_long_term_pricing/3","title":"AWS.Snowball.create_long_term_pricing/3","type":"function"},{"doc":"Creates a shipping label that will be used to return the Snow device to Amazon\nWeb Services.","ref":"AWS.Snowball.html#create_return_shipping_label/3","title":"AWS.Snowball.create_return_shipping_label/3","type":"function"},{"doc":"Takes an `AddressId` and returns specific details about that address in the form\nof an `Address` object.","ref":"AWS.Snowball.html#describe_address/3","title":"AWS.Snowball.describe_address/3","type":"function"},{"doc":"Returns a specified number of `ADDRESS` objects.\n\nCalling this API in one of the US regions will return addresses from the list of\nall addresses associated with this account in all US regions.","ref":"AWS.Snowball.html#describe_addresses/3","title":"AWS.Snowball.describe_addresses/3","type":"function"},{"doc":"Returns information about a specific cluster including shipping information,\ncluster status, and other important metadata.","ref":"AWS.Snowball.html#describe_cluster/3","title":"AWS.Snowball.describe_cluster/3","type":"function"},{"doc":"Returns information about a specific job including shipping information, job\nstatus, and other important metadata.","ref":"AWS.Snowball.html#describe_job/3","title":"AWS.Snowball.describe_job/3","type":"function"},{"doc":"Information on the shipping label of a Snow device that is being returned to\nAmazon Web Services.","ref":"AWS.Snowball.html#describe_return_shipping_label/3","title":"AWS.Snowball.describe_return_shipping_label/3","type":"function"},{"doc":"Returns a link to an Amazon S3 presigned URL for the manifest file associated\nwith the specified `JobId` value.\n\nYou can access the manifest file for up to 60 minutes after this request has\nbeen made. To access the manifest file after 60 minutes have passed, you'll have\nto make another call to the `GetJobManifest` action.\n\nThe manifest is an encrypted file that you can download after your job enters\nthe `WithCustomer` status. This is the only valid status for calling this API as\nthe manifest and `UnlockCode` code value are used for securing your device and\nshould only be used when you have the device. The manifest is decrypted by using\nthe `UnlockCode` code value, when you pass both values to the Snow device\nthrough the Snowball client when the client is started for the first time.\n\nAs a best practice, we recommend that you don't save a copy of an `UnlockCode`\nvalue in the same location as the manifest file for that job. Saving these\nseparately helps prevent unauthorized parties from gaining access to the Snow\ndevice associated with that job.\n\nThe credentials of a given job, including its manifest file and unlock code,\nexpire 360 days after the job is created.","ref":"AWS.Snowball.html#get_job_manifest/3","title":"AWS.Snowball.get_job_manifest/3","type":"function"},{"doc":"Returns the `UnlockCode` code value for the specified job.\n\nA particular `UnlockCode` value can be accessed for up to 360 days after the\nassociated job has been created.\n\nThe `UnlockCode` value is a 29-character code with 25 alphanumeric characters\nand 4 hyphens. This code is used to decrypt the manifest file when it is passed\nalong with the manifest to the Snow device through the Snowball client when the\nclient is started for the first time. The only valid status for calling this API\nis `WithCustomer` as the manifest and `Unlock` code values are used for securing\nyour device and should only be used when you have the device.\n\nAs a best practice, we recommend that you don't save a copy of the `UnlockCode`\nin the same location as the manifest file for that job. Saving these separately\nhelps prevent unauthorized parties from gaining access to the Snow device\nassociated with that job.","ref":"AWS.Snowball.html#get_job_unlock_code/3","title":"AWS.Snowball.get_job_unlock_code/3","type":"function"},{"doc":"Returns information about the Snow Family service limit for your account, and\nalso the number of Snow devices your account has in use.\n\nThe default service limit for the number of Snow devices that you can have at\none time is 1. If you want to increase your service limit, contact Amazon Web\nServices Support.","ref":"AWS.Snowball.html#get_snowball_usage/3","title":"AWS.Snowball.get_snowball_usage/3","type":"function"},{"doc":"Returns an Amazon S3 presigned URL for an update file associated with a\nspecified `JobId`.","ref":"AWS.Snowball.html#get_software_updates/3","title":"AWS.Snowball.get_software_updates/3","type":"function"},{"doc":"Returns an array of `JobListEntry` objects of the specified length.\n\nEach `JobListEntry` object is for a job in the specified cluster and contains a\njob's state, a job's ID, and other information.","ref":"AWS.Snowball.html#list_cluster_jobs/3","title":"AWS.Snowball.list_cluster_jobs/3","type":"function"},{"doc":"Returns an array of `ClusterListEntry` objects of the specified length.\n\nEach `ClusterListEntry` object contains a cluster's state, a cluster's ID, and\nother important status information.","ref":"AWS.Snowball.html#list_clusters/3","title":"AWS.Snowball.list_clusters/3","type":"function"},{"doc":"This action returns a list of the different Amazon EC2-compatible Amazon Machine\nImages (AMIs) that are owned by your Amazon Web Services accountthat would be\nsupported for use on a Snow device.\n\nCurrently, supported AMIs are based on the Amazon Linux-2, Ubuntu 20.04 LTS -\nFocal, or Ubuntu 22.04 LTS - Jammy images, available on the Amazon Web Services\nMarketplace. Ubuntu 16.04 LTS - Xenial (HVM) images are no longer supported in\nthe Market, but still supported for use on devices through Amazon EC2 VM\nImport/Export and running locally in AMIs.","ref":"AWS.Snowball.html#list_compatible_images/3","title":"AWS.Snowball.list_compatible_images/3","type":"function"},{"doc":"Returns an array of `JobListEntry` objects of the specified length.\n\nEach `JobListEntry` object contains a job's state, a job's ID, and a value that\nindicates whether the job is a job part, in the case of export jobs. Calling\nthis API action in one of the US regions will return jobs from the list of all\njobs associated with this account in all US regions.","ref":"AWS.Snowball.html#list_jobs/3","title":"AWS.Snowball.list_jobs/3","type":"function"},{"doc":"Lists all long-term pricing types.","ref":"AWS.Snowball.html#list_long_term_pricing/3","title":"AWS.Snowball.list_long_term_pricing/3","type":"function"},{"doc":"A list of locations from which the customer can choose to pickup a device.","ref":"AWS.Snowball.html#list_pickup_locations/3","title":"AWS.Snowball.list_pickup_locations/3","type":"function"},{"doc":"Lists all supported versions for Snow on-device services.\n\nReturns an array of `ServiceVersion` object containing the supported versions\nfor a particular service.","ref":"AWS.Snowball.html#list_service_versions/3","title":"AWS.Snowball.list_service_versions/3","type":"function"},{"doc":"","ref":"AWS.Snowball.html#metadata/0","title":"AWS.Snowball.metadata/0","type":"function"},{"doc":"While a cluster's `ClusterState` value is in the `AwaitingQuorum` state, you can\nupdate some of the information associated with a cluster.\n\nOnce the cluster changes to a different job state, usually 60 minutes after the\ncluster being created, this action is no longer available.","ref":"AWS.Snowball.html#update_cluster/3","title":"AWS.Snowball.update_cluster/3","type":"function"},{"doc":"While a job's `JobState` value is `New`, you can update some of the information\nassociated with a job.\n\nOnce the job changes to a different job state, usually within 60 minutes of the\njob being created, this action is no longer available.","ref":"AWS.Snowball.html#update_job/3","title":"AWS.Snowball.update_job/3","type":"function"},{"doc":"Updates the state when a shipment state changes to a different state.","ref":"AWS.Snowball.html#update_job_shipment_state/3","title":"AWS.Snowball.update_job_shipment_state/3","type":"function"},{"doc":"Updates the long-term pricing type.","ref":"AWS.Snowball.html#update_long_term_pricing/3","title":"AWS.Snowball.update_long_term_pricing/3","type":"function"},{"doc":"This API reference provides descriptions, syntax, and other details about each\nof the actions and data types for AWS Systems Manager for SAP.\n\nThe topic for each action shows the API request parameters and responses.","ref":"AWS.SsmSap.html","title":"AWS.SsmSap","type":"module"},{"doc":"Removes permissions associated with the target database.","ref":"AWS.SsmSap.html#delete_resource_permission/3","title":"AWS.SsmSap.delete_resource_permission/3","type":"function"},{"doc":"Deregister an SAP application with AWS Systems Manager for SAP.\n\nThis action does not aﬀect the existing setup of your SAP workloads on Amazon\nEC2.","ref":"AWS.SsmSap.html#deregister_application/3","title":"AWS.SsmSap.deregister_application/3","type":"function"},{"doc":"Gets an application registered with AWS Systems Manager for SAP.\n\nIt also returns the components of the application.","ref":"AWS.SsmSap.html#get_application/3","title":"AWS.SsmSap.get_application/3","type":"function"},{"doc":"Gets the component of an application registered with AWS Systems Manager for\nSAP.","ref":"AWS.SsmSap.html#get_component/3","title":"AWS.SsmSap.get_component/3","type":"function"},{"doc":"Gets the SAP HANA database of an application registered with AWS Systems Manager\nfor SAP.","ref":"AWS.SsmSap.html#get_database/3","title":"AWS.SsmSap.get_database/3","type":"function"},{"doc":"Gets the details of an operation by specifying the operation ID.","ref":"AWS.SsmSap.html#get_operation/3","title":"AWS.SsmSap.get_operation/3","type":"function"},{"doc":"Gets permissions associated with the target database.","ref":"AWS.SsmSap.html#get_resource_permission/3","title":"AWS.SsmSap.get_resource_permission/3","type":"function"},{"doc":"Lists all the applications registered with AWS Systems Manager for SAP.","ref":"AWS.SsmSap.html#list_applications/3","title":"AWS.SsmSap.list_applications/3","type":"function"},{"doc":"Lists all the components registered with AWS Systems Manager for SAP.","ref":"AWS.SsmSap.html#list_components/3","title":"AWS.SsmSap.list_components/3","type":"function"},{"doc":"Lists the SAP HANA databases of an application registered with AWS Systems\nManager for SAP.","ref":"AWS.SsmSap.html#list_databases/3","title":"AWS.SsmSap.list_databases/3","type":"function"},{"doc":"Lists the operations performed by AWS Systems Manager for SAP.","ref":"AWS.SsmSap.html#list_operations/3","title":"AWS.SsmSap.list_operations/3","type":"function"},{"doc":"Lists all tags on an SAP HANA application and/or database registered with AWS\nSystems Manager for SAP.","ref":"AWS.SsmSap.html#list_tags_for_resource/3","title":"AWS.SsmSap.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.SsmSap.html#metadata/0","title":"AWS.SsmSap.metadata/0","type":"function"},{"doc":"Adds permissions to the target database.","ref":"AWS.SsmSap.html#put_resource_permission/3","title":"AWS.SsmSap.put_resource_permission/3","type":"function"},{"doc":"Register an SAP application with AWS Systems Manager for SAP.\n\nYou must meet the following requirements before registering.\n\nThe SAP application you want to register with AWS Systems Manager for SAP is\nrunning on Amazon EC2.\n\nAWS Systems Manager Agent must be setup on an Amazon EC2 instance along with the\nrequired IAM permissions.\n\nAmazon EC2 instance(s) must have access to the secrets created in AWS Secrets\nManager to manage SAP applications and components.","ref":"AWS.SsmSap.html#register_application/3","title":"AWS.SsmSap.register_application/3","type":"function"},{"doc":"Refreshes a registered application.","ref":"AWS.SsmSap.html#start_application_refresh/3","title":"AWS.SsmSap.start_application_refresh/3","type":"function"},{"doc":"Creates tag for a resource by specifying the ARN.","ref":"AWS.SsmSap.html#tag_resource/4","title":"AWS.SsmSap.tag_resource/4","type":"function"},{"doc":"Delete the tags for a resource.","ref":"AWS.SsmSap.html#untag_resource/4","title":"AWS.SsmSap.untag_resource/4","type":"function"},{"doc":"Updates the settings of an application registered with AWS Systems Manager for\nSAP.","ref":"AWS.SsmSap.html#update_application_settings/3","title":"AWS.SsmSap.update_application_settings/3","type":"function"},{"doc":"Storage Gateway Service\n\nStorage Gateway is the service that connects an on-premises software appliance\nwith cloud-based storage to provide seamless and secure integration between an\norganization's on-premises IT environment and the Amazon Web Services storage\ninfrastructure.\n\nThe service enables you to securely upload data to the Amazon Web Services Cloud\nfor cost effective backup and rapid disaster recovery.\n\nUse the following links to get started using the *Storage Gateway Service API\nReference*:\n\n  * [Storage Gateway required request headers](https://docs.aws.amazon.com/storagegateway/latest/userguide/AWSStorageGatewayAPI.html#AWSStorageGatewayHTTPRequestsHeaders):\nDescribes the required headers that you must send with every POST request to\nStorage Gateway.\n\n  * [Signing requests](https://docs.aws.amazon.com/storagegateway/latest/userguide/AWSStorageGatewayAPI.html#AWSStorageGatewaySigningRequests):\nStorage Gateway requires that you authenticate every request you send; this\ntopic describes how sign such a request.\n\n  * [Error responses](https://docs.aws.amazon.com/storagegateway/latest/userguide/AWSStorageGatewayAPI.html#APIErrorResponses):\nProvides reference information about Storage Gateway errors.\n\n  * [Operations in Storage Gateway](https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_Operations.html):\nContains detailed descriptions of all Storage Gateway operations, their request\nparameters, response elements, possible errors, and examples of requests and\nresponses.\n\n  * [Storage Gateway endpoints and quotas](https://docs.aws.amazon.com/general/latest/gr/sg.html): Provides a list\nof each Amazon Web Services Region and the endpoints available for use with\nStorage Gateway.\n\nStorage Gateway resource IDs are in uppercase. When you use these resource IDs\nwith the Amazon EC2 API, EC2 expects resource IDs in lowercase. You must change\nyour resource ID to lowercase to use it with the EC2 API. For example, in\nStorage Gateway the ID for a volume might be `vol-AA22BB012345DAF670`. When you\nuse this ID with the EC2 API, you must change it to `vol-aa22bb012345daf670`.\nOtherwise, the EC2 API might not behave as expected.\n\nIDs for Storage Gateway volumes and Amazon EBS snapshots created from gateway\nvolumes are changing to a longer format. Starting in December 2016, all new\nvolumes and snapshots will be created with a 17-character string. Starting in\nApril 2016, you will be able to use these longer IDs so you can test your\nsystems with the new format. For more information, see [Longer EC2 and EBS resource IDs](http://aws.amazon.com/ec2/faqs/#longer-ids).\n\nFor example, a volume Amazon Resource Name (ARN) with the longer volume ID\nformat looks like the following:\n\n`arn:aws:storagegateway:us-west-2:111122223333:gateway/sgw-12A3456B/volume/vol-1122AABBCCDDEEFFG`.\n\nA snapshot ID with the longer ID format looks like the following:\n`snap-78e226633445566ee`.\n\nFor more information, see [Announcement: Heads-up – Longer Storage Gateway volume and snapshot IDs coming in\n2016](http://forums.aws.amazon.com/ann.jspa?annID=3557).","ref":"AWS.StorageGateway.html","title":"AWS.StorageGateway","type":"module"},{"doc":"Activates the gateway you previously deployed on your host.\n\nIn the activation process, you specify information such as the Amazon Web\nServices Region that you want to use for storing snapshots or tapes, the time\nzone for scheduled snapshots the gateway snapshot schedule window, an activation\nkey, and a name for your gateway. The activation process also associates your\ngateway with your account. For more information, see `UpdateGatewayInformation`.\n\nYou must turn on the gateway VM before you can activate your gateway.","ref":"AWS.StorageGateway.html#activate_gateway/3","title":"AWS.StorageGateway.activate_gateway/3","type":"function"},{"doc":"Configures one or more gateway local disks as cache for a gateway.\n\nThis operation is only supported in the cached volume, tape, and file gateway\ntype (see [How Storage Gateway works (architecture)](https://docs.aws.amazon.com/storagegateway/latest/userguide/StorageGatewayConcepts.html).\n\nIn the request, you specify the gateway Amazon Resource Name (ARN) to which you\nwant to add cache, and one or more disk IDs that you want to configure as cache.","ref":"AWS.StorageGateway.html#add_cache/3","title":"AWS.StorageGateway.add_cache/3","type":"function"},{"doc":"Adds one or more tags to the specified resource.\n\nYou use tags to add metadata to resources, which you can use to categorize these\nresources. For example, you can categorize resources by purpose, owner,\nenvironment, or team. Each tag consists of a key and a value, which you define.\nYou can add tags to the following Storage Gateway resources:\n\n  * Storage gateways of all types\n\n  * Storage volumes\n\n  * Virtual tapes\n\n  * NFS and SMB file shares\n\n  * File System associations\n\nYou can create a maximum of 50 tags for each resource. Virtual tapes and storage\nvolumes that are recovered to a new gateway maintain their tags.","ref":"AWS.StorageGateway.html#add_tags_to_resource/3","title":"AWS.StorageGateway.add_tags_to_resource/3","type":"function"},{"doc":"Configures one or more gateway local disks as upload buffer for a specified\ngateway.\n\nThis operation is supported for the stored volume, cached volume, and tape\ngateway types.\n\nIn the request, you specify the gateway Amazon Resource Name (ARN) to which you\nwant to add upload buffer, and one or more disk IDs that you want to configure\nas upload buffer.","ref":"AWS.StorageGateway.html#add_upload_buffer/3","title":"AWS.StorageGateway.add_upload_buffer/3","type":"function"},{"doc":"Configures one or more gateway local disks as working storage for a gateway.\n\nThis operation is only supported in the stored volume gateway type. This\noperation is deprecated in cached volume API version 20120630. Use\n`AddUploadBuffer` instead.\n\nWorking storage is also referred to as upload buffer. You can also use the\n`AddUploadBuffer` operation to add upload buffer to a stored volume gateway.\n\nIn the request, you specify the gateway Amazon Resource Name (ARN) to which you\nwant to add working storage, and one or more disk IDs that you want to configure\nas working storage.","ref":"AWS.StorageGateway.html#add_working_storage/3","title":"AWS.StorageGateway.add_working_storage/3","type":"function"},{"doc":"Assigns a tape to a tape pool for archiving.\n\nThe tape assigned to a pool is archived in the S3 storage class that is\nassociated with the pool. When you use your backup application to eject the\ntape, the tape is archived directly into the S3 storage class (S3 Glacier or S3\nGlacier Deep Archive) that corresponds to the pool.","ref":"AWS.StorageGateway.html#assign_tape_pool/3","title":"AWS.StorageGateway.assign_tape_pool/3","type":"function"},{"doc":"Associate an Amazon FSx file system with the FSx File Gateway.\n\nAfter the association process is complete, the file shares on the Amazon FSx\nfile system are available for access through the gateway. This operation only\nsupports the FSx File Gateway type.","ref":"AWS.StorageGateway.html#associate_file_system/3","title":"AWS.StorageGateway.associate_file_system/3","type":"function"},{"doc":"Connects a volume to an iSCSI connection and then attaches the volume to the\nspecified gateway.\n\nDetaching and attaching a volume enables you to recover your data from one\ngateway to a different gateway without creating a snapshot. It also makes it\neasier to move your volumes from an on-premises gateway to a gateway hosted on\nan Amazon EC2 instance.","ref":"AWS.StorageGateway.html#attach_volume/3","title":"AWS.StorageGateway.attach_volume/3","type":"function"},{"doc":"Cancels archiving of a virtual tape to the virtual tape shelf (VTS) after the\narchiving process is initiated.\n\nThis operation is only supported in the tape gateway type.","ref":"AWS.StorageGateway.html#cancel_archival/3","title":"AWS.StorageGateway.cancel_archival/3","type":"function"},{"doc":"Cancels retrieval of a virtual tape from the virtual tape shelf (VTS) to a\ngateway after the retrieval process is initiated.\n\nThe virtual tape is returned to the VTS. This operation is only supported in the\ntape gateway type.","ref":"AWS.StorageGateway.html#cancel_retrieval/3","title":"AWS.StorageGateway.cancel_retrieval/3","type":"function"},{"doc":"Creates a cached volume on a specified cached volume gateway.\n\nThis operation is only supported in the cached volume gateway type.\n\nCache storage must be allocated to the gateway before you can create a cached\nvolume. Use the `AddCache` operation to add cache storage to a gateway.\n\nIn the request, you must specify the gateway, size of the volume in bytes, the\niSCSI target name, an IP address on which to expose the target, and a unique\nclient token. In response, the gateway creates the volume and returns\ninformation about it. This information includes the volume Amazon Resource Name\n(ARN), its size, and the iSCSI target ARN that initiators can use to connect to\nthe volume target.\n\nOptionally, you can provide the ARN for an existing volume as the\n`SourceVolumeARN` for this cached volume, which creates an exact copy of the\nexisting volume’s latest recovery point. The `VolumeSizeInBytes` value must be\nequal to or larger than the size of the copied volume, in bytes.","ref":"AWS.StorageGateway.html#create_cached_iscsi_volume/3","title":"AWS.StorageGateway.create_cached_iscsi_volume/3","type":"function"},{"doc":"Creates a Network File System (NFS) file share on an existing S3 File Gateway.\n\nIn Storage Gateway, a file share is a file system mount point backed by Amazon\nS3 cloud storage. Storage Gateway exposes file shares using an NFS interface.\nThis operation is only supported for S3 File Gateways.\n\nS3 File gateway requires Security Token Service (Amazon Web Services STS) to be\nactivated to enable you to create a file share. Make sure Amazon Web Services\nSTS is activated in the Amazon Web Services Region you are creating your S3 File\nGateway in. If Amazon Web Services STS is not activated in the Amazon Web\nServices Region, activate it. For information about how to activate Amazon Web\nServices STS, see [Activating and deactivating Amazon Web Services STS in an Amazon Web Services\nRegion](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_enable-regions.html)\nin the *Identity and Access Management User Guide*.\n\nS3 File Gateways do not support creating hard or symbolic links on a file share.","ref":"AWS.StorageGateway.html#create_nfs_file_share/3","title":"AWS.StorageGateway.create_nfs_file_share/3","type":"function"},{"doc":"Creates a Server Message Block (SMB) file share on an existing S3 File Gateway.\n\nIn Storage Gateway, a file share is a file system mount point backed by Amazon\nS3 cloud storage. Storage Gateway exposes file shares using an SMB interface.\nThis operation is only supported for S3 File Gateways.\n\nS3 File Gateways require Security Token Service (Amazon Web Services STS) to be\nactivated to enable you to create a file share. Make sure that Amazon Web\nServices STS is activated in the Amazon Web Services Region you are creating\nyour S3 File Gateway in. If Amazon Web Services STS is not activated in this\nAmazon Web Services Region, activate it. For information about how to activate\nAmazon Web Services STS, see [Activating and deactivating Amazon Web Services STS in an Amazon Web Services\nRegion](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_enable-regions.html)\nin the *Identity and Access Management User Guide*.\n\nFile gateways don't support creating hard or symbolic links on a file share.","ref":"AWS.StorageGateway.html#create_smb_file_share/3","title":"AWS.StorageGateway.create_smb_file_share/3","type":"function"},{"doc":"Initiates a snapshot of a volume.\n\nStorage Gateway provides the ability to back up point-in-time snapshots of your\ndata to Amazon Simple Storage (Amazon S3) for durable off-site recovery, and\nalso import the data to an Amazon Elastic Block Store (EBS) volume in Amazon\nElastic Compute Cloud (EC2). You can take snapshots of your gateway volume on a\nscheduled or ad hoc basis. This API enables you to take an ad hoc snapshot. For\nmore information, see [Editing a snapshot schedule](https://docs.aws.amazon.com/storagegateway/latest/userguide/managing-volumes.html#SchedulingSnapshot).\n\nIn the `CreateSnapshot` request, you identify the volume by providing its Amazon\nResource Name (ARN). You must also provide description for the snapshot. When\nStorage Gateway takes the snapshot of specified volume, the snapshot and\ndescription appears in the Storage Gateway console. In response, Storage Gateway\nreturns you a snapshot ID. You can use this snapshot ID to check the snapshot\nprogress or later use it when you want to create a volume from a snapshot. This\noperation is only supported in stored and cached volume gateway type.\n\nTo list or delete a snapshot, you must use the Amazon EC2 API. For more\ninformation, see\n[DescribeSnapshots](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeSnapshots.html) or\n[DeleteSnapshot](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteSnapshot.html)\nin the *Amazon Elastic Compute Cloud API Reference*.\n\nVolume and snapshot IDs are changing to a longer length ID format. For more\ninformation, see the important note on the\n[Welcome](https://docs.aws.amazon.com/storagegateway/latest/APIReference/Welcome.html)\npage.","ref":"AWS.StorageGateway.html#create_snapshot/3","title":"AWS.StorageGateway.create_snapshot/3","type":"function"},{"doc":"Initiates a snapshot of a gateway from a volume recovery point.\n\nThis operation is only supported in the cached volume gateway type.\n\nA volume recovery point is a point in time at which all data of the volume is\nconsistent and from which you can create a snapshot. To get a list of volume\nrecovery point for cached volume gateway, use `ListVolumeRecoveryPoints`.\n\nIn the `CreateSnapshotFromVolumeRecoveryPoint` request, you identify the volume\nby providing its Amazon Resource Name (ARN). You must also provide a description\nfor the snapshot. When the gateway takes a snapshot of the specified volume, the\nsnapshot and its description appear in the Storage Gateway console. In response,\nthe gateway returns you a snapshot ID. You can use this snapshot ID to check the\nsnapshot progress or later use it when you want to create a volume from a\nsnapshot.\n\nTo list or delete a snapshot, you must use the Amazon EC2 API. For more\ninformation, see\n[DescribeSnapshots](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeSnapshots.html) or\n[DeleteSnapshot](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteSnapshot.html)\nin the *Amazon Elastic Compute Cloud API Reference*.","ref":"AWS.StorageGateway.html#create_snapshot_from_volume_recovery_point/3","title":"AWS.StorageGateway.create_snapshot_from_volume_recovery_point/3","type":"function"},{"doc":"Creates a volume on a specified gateway.\n\nThis operation is only supported in the stored volume gateway type.\n\nThe size of the volume to create is inferred from the disk size. You can choose\nto preserve existing data on the disk, create volume from an existing snapshot,\nor create an empty volume. If you choose to create an empty gateway volume, then\nany existing data on the disk is erased.\n\nIn the request, you must specify the gateway and the disk information on which\nyou are creating the volume. In response, the gateway creates the volume and\nreturns volume information such as the volume Amazon Resource Name (ARN), its\nsize, and the iSCSI target ARN that initiators can use to connect to the volume\ntarget.","ref":"AWS.StorageGateway.html#create_stored_iscsi_volume/3","title":"AWS.StorageGateway.create_stored_iscsi_volume/3","type":"function"},{"doc":"Creates a new custom tape pool.\n\nYou can use custom tape pool to enable tape retention lock on tapes that are\narchived in the custom pool.","ref":"AWS.StorageGateway.html#create_tape_pool/3","title":"AWS.StorageGateway.create_tape_pool/3","type":"function"},{"doc":"Creates a virtual tape by using your own barcode.\n\nYou write data to the virtual tape and then archive the tape. A barcode is\nunique and cannot be reused if it has already been used on a tape. This applies\nto barcodes used on deleted tapes. This operation is only supported in the tape\ngateway type.\n\nCache storage must be allocated to the gateway before you can create a virtual\ntape. Use the `AddCache` operation to add cache storage to a gateway.","ref":"AWS.StorageGateway.html#create_tape_with_barcode/3","title":"AWS.StorageGateway.create_tape_with_barcode/3","type":"function"},{"doc":"Creates one or more virtual tapes.\n\nYou write data to the virtual tapes and then archive the tapes. This operation\nis only supported in the tape gateway type.\n\nCache storage must be allocated to the gateway before you can create virtual\ntapes. Use the `AddCache` operation to add cache storage to a gateway.","ref":"AWS.StorageGateway.html#create_tapes/3","title":"AWS.StorageGateway.create_tapes/3","type":"function"},{"doc":"Deletes the automatic tape creation policy of a gateway.\n\nIf you delete this policy, new virtual tapes must be created manually. Use the\nAmazon Resource Name (ARN) of the gateway in your request to remove the policy.","ref":"AWS.StorageGateway.html#delete_automatic_tape_creation_policy/3","title":"AWS.StorageGateway.delete_automatic_tape_creation_policy/3","type":"function"},{"doc":"Deletes the bandwidth rate limits of a gateway.\n\nYou can delete either the upload and download bandwidth rate limit, or you can\ndelete both. If you delete only one of the limits, the other limit remains\nunchanged. To specify which gateway to work with, use the Amazon Resource Name\n(ARN) of the gateway in your request. This operation is supported only for the\nstored volume, cached volume, and tape gateway types.","ref":"AWS.StorageGateway.html#delete_bandwidth_rate_limit/3","title":"AWS.StorageGateway.delete_bandwidth_rate_limit/3","type":"function"},{"doc":"Deletes Challenge-Handshake Authentication Protocol (CHAP) credentials for a\nspecified iSCSI target and initiator pair.\n\nThis operation is supported in volume and tape gateway types.","ref":"AWS.StorageGateway.html#delete_chap_credentials/3","title":"AWS.StorageGateway.delete_chap_credentials/3","type":"function"},{"doc":"Deletes a file share from an S3 File Gateway.\n\nThis operation is only supported for S3 File Gateways.","ref":"AWS.StorageGateway.html#delete_file_share/3","title":"AWS.StorageGateway.delete_file_share/3","type":"function"},{"doc":"Deletes a gateway.\n\nTo specify which gateway to delete, use the Amazon Resource Name (ARN) of the\ngateway in your request. The operation deletes the gateway; however, it does not\ndelete the gateway virtual machine (VM) from your host computer.\n\nAfter you delete a gateway, you cannot reactivate it. Completed snapshots of the\ngateway volumes are not deleted upon deleting the gateway, however, pending\nsnapshots will not complete. After you delete a gateway, your next step is to\nremove it from your environment.\n\nYou no longer pay software charges after the gateway is deleted; however, your\nexisting Amazon EBS snapshots persist and you will continue to be billed for\nthese snapshots. You can choose to remove all remaining Amazon EBS snapshots by\ncanceling your Amazon EC2 subscription.  If you prefer not to cancel your Amazon\nEC2 subscription, you can delete your snapshots using the Amazon EC2 console.\nFor more information, see the [Storage Gateway detail page](http://aws.amazon.com/storagegateway).","ref":"AWS.StorageGateway.html#delete_gateway/3","title":"AWS.StorageGateway.delete_gateway/3","type":"function"},{"doc":"Deletes a snapshot of a volume.\n\nYou can take snapshots of your gateway volumes on a scheduled or ad hoc basis.\nThis API action enables you to delete a snapshot schedule for a volume. For more\ninformation, see [Backing up your volumes](https://docs.aws.amazon.com/storagegateway/latest/userguide/backing-up-volumes.html).\nIn the `DeleteSnapshotSchedule` request, you identify the volume by providing\nits Amazon Resource Name (ARN). This operation is only supported for cached\nvolume gateway types.\n\nTo list or delete a snapshot, you must use the Amazon EC2 API. For more\ninformation, go to\n[DescribeSnapshots](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeSnapshots.html)\nin the *Amazon Elastic Compute Cloud API Reference*.","ref":"AWS.StorageGateway.html#delete_snapshot_schedule/3","title":"AWS.StorageGateway.delete_snapshot_schedule/3","type":"function"},{"doc":"Deletes the specified virtual tape.\n\nThis operation is only supported in the tape gateway type.","ref":"AWS.StorageGateway.html#delete_tape/3","title":"AWS.StorageGateway.delete_tape/3","type":"function"},{"doc":"Deletes the specified virtual tape from the virtual tape shelf (VTS).\n\nThis operation is only supported in the tape gateway type.","ref":"AWS.StorageGateway.html#delete_tape_archive/3","title":"AWS.StorageGateway.delete_tape_archive/3","type":"function"},{"doc":"Delete a custom tape pool.\n\nA custom tape pool can only be deleted if there are no tapes in the pool and if\nthere are no automatic tape creation policies that reference the custom tape\npool.","ref":"AWS.StorageGateway.html#delete_tape_pool/3","title":"AWS.StorageGateway.delete_tape_pool/3","type":"function"},{"doc":"Deletes the specified storage volume that you previously created using the\n`CreateCachediSCSIVolume` or `CreateStorediSCSIVolume` API.\n\nThis operation is only supported in the cached volume and stored volume types.\nFor stored volume gateways, the local disk that was configured as the storage\nvolume is not deleted. You can reuse the local disk to create another storage\nvolume.\n\nBefore you delete a volume, make sure there are no iSCSI connections to the\nvolume you are deleting. You should also make sure there is no snapshot in\nprogress. You can use the Amazon Elastic Compute Cloud (Amazon EC2) API to query\nsnapshots on the volume you are deleting and check the snapshot status. For more\ninformation, go to\n[DescribeSnapshots](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/ApiReference-query-DescribeSnapshots.html)\nin the *Amazon Elastic Compute Cloud API Reference*.\n\nIn the request, you must provide the Amazon Resource Name (ARN) of the storage\nvolume you want to delete.","ref":"AWS.StorageGateway.html#delete_volume/3","title":"AWS.StorageGateway.delete_volume/3","type":"function"},{"doc":"Returns information about the most recent high availability monitoring test that\nwas performed on the host in a cluster.\n\nIf a test isn't performed, the status and start time in the response would be\nnull.","ref":"AWS.StorageGateway.html#describe_availability_monitor_test/3","title":"AWS.StorageGateway.describe_availability_monitor_test/3","type":"function"},{"doc":"Returns the bandwidth rate limits of a gateway.\n\nBy default, these limits are not set, which means no bandwidth rate limiting is\nin effect. This operation is supported only for the stored volume, cached\nvolume, and tape gateway types. To describe bandwidth rate limits for S3 file\ngateways, use `DescribeBandwidthRateLimitSchedule`.\n\nThis operation returns a value for a bandwidth rate limit only if the limit is\nset. If no limits are set for the gateway, then this operation returns only the\ngateway ARN in the response body. To specify which gateway to describe, use the\nAmazon Resource Name (ARN) of the gateway in your request.","ref":"AWS.StorageGateway.html#describe_bandwidth_rate_limit/3","title":"AWS.StorageGateway.describe_bandwidth_rate_limit/3","type":"function"},{"doc":"Returns information about the bandwidth rate limit schedule of a gateway.\n\nBy default, gateways do not have bandwidth rate limit schedules, which means no\nbandwidth rate limiting is in effect. This operation is supported only for\nvolume, tape and S3 file gateways. FSx file gateways do not support bandwidth\nrate limits.\n\nThis operation returns information about a gateway's bandwidth rate limit\nschedule. A bandwidth rate limit schedule consists of one or more bandwidth rate\nlimit intervals. A bandwidth rate limit interval defines a period of time on one\nor more days of the week, during which bandwidth rate limits are specified for\nuploading, downloading, or both.\n\nA bandwidth rate limit interval consists of one or more days of the week, a\nstart hour and minute, an ending hour and minute, and bandwidth rate limits for\nuploading and downloading\n\nIf no bandwidth rate limit schedule intervals are set for the gateway, this\noperation returns an empty response. To specify which gateway to describe, use\nthe Amazon Resource Name (ARN) of the gateway in your request.","ref":"AWS.StorageGateway.html#describe_bandwidth_rate_limit_schedule/3","title":"AWS.StorageGateway.describe_bandwidth_rate_limit_schedule/3","type":"function"},{"doc":"Returns information about the cache of a gateway.\n\nThis operation is only supported in the cached volume, tape, and file gateway\ntypes.\n\nThe response includes disk IDs that are configured as cache, and it includes the\namount of cache allocated and used.","ref":"AWS.StorageGateway.html#describe_cache/3","title":"AWS.StorageGateway.describe_cache/3","type":"function"},{"doc":"Returns a description of the gateway volumes specified in the request.\n\nThis operation is only supported in the cached volume gateway types.\n\nThe list of gateway volumes in the request must be from one gateway. In the\nresponse, Storage Gateway returns volume information sorted by volume Amazon\nResource Name (ARN).","ref":"AWS.StorageGateway.html#describe_cached_iscsi_volumes/3","title":"AWS.StorageGateway.describe_cached_iscsi_volumes/3","type":"function"},{"doc":"Returns an array of Challenge-Handshake Authentication Protocol (CHAP)\ncredentials information for a specified iSCSI target, one for each\ntarget-initiator pair.\n\nThis operation is supported in the volume and tape gateway types.","ref":"AWS.StorageGateway.html#describe_chap_credentials/3","title":"AWS.StorageGateway.describe_chap_credentials/3","type":"function"},{"doc":"Gets the file system association information.\n\nThis operation is only supported for FSx File Gateways.","ref":"AWS.StorageGateway.html#describe_file_system_associations/3","title":"AWS.StorageGateway.describe_file_system_associations/3","type":"function"},{"doc":"Returns metadata about a gateway such as its name, network interfaces, time\nzone, status, and software version.\n\nTo specify which gateway to describe, use the Amazon Resource Name (ARN) of the\ngateway in your request.","ref":"AWS.StorageGateway.html#describe_gateway_information/3","title":"AWS.StorageGateway.describe_gateway_information/3","type":"function"},{"doc":"Returns your gateway's weekly maintenance start time including the day and time\nof the week.\n\nNote that values are in terms of the gateway's time zone.","ref":"AWS.StorageGateway.html#describe_maintenance_start_time/3","title":"AWS.StorageGateway.describe_maintenance_start_time/3","type":"function"},{"doc":"Gets a description for one or more Network File System (NFS) file shares from an\nS3 File Gateway.\n\nThis operation is only supported for S3 File Gateways.","ref":"AWS.StorageGateway.html#describe_nfs_file_shares/3","title":"AWS.StorageGateway.describe_nfs_file_shares/3","type":"function"},{"doc":"Gets a description for one or more Server Message Block (SMB) file shares from a\nS3 File Gateway.\n\nThis operation is only supported for S3 File Gateways.","ref":"AWS.StorageGateway.html#describe_smb_file_shares/3","title":"AWS.StorageGateway.describe_smb_file_shares/3","type":"function"},{"doc":"Gets a description of a Server Message Block (SMB) file share settings from a\nfile gateway.\n\nThis operation is only supported for file gateways.","ref":"AWS.StorageGateway.html#describe_smb_settings/3","title":"AWS.StorageGateway.describe_smb_settings/3","type":"function"},{"doc":"Describes the snapshot schedule for the specified gateway volume.\n\nThe snapshot schedule information includes intervals at which snapshots are\nautomatically initiated on the volume. This operation is only supported in the\ncached volume and stored volume types.","ref":"AWS.StorageGateway.html#describe_snapshot_schedule/3","title":"AWS.StorageGateway.describe_snapshot_schedule/3","type":"function"},{"doc":"Returns the description of the gateway volumes specified in the request.\n\nThe list of gateway volumes in the request must be from one gateway. In the\nresponse, Storage Gateway returns volume information sorted by volume ARNs. This\noperation is only supported in stored volume gateway type.","ref":"AWS.StorageGateway.html#describe_stored_iscsi_volumes/3","title":"AWS.StorageGateway.describe_stored_iscsi_volumes/3","type":"function"},{"doc":"Returns a description of specified virtual tapes in the virtual tape shelf\n(VTS).\n\nThis operation is only supported in the tape gateway type.\n\nIf a specific `TapeARN` is not specified, Storage Gateway returns a description\nof all virtual tapes found in the VTS associated with your account.","ref":"AWS.StorageGateway.html#describe_tape_archives/3","title":"AWS.StorageGateway.describe_tape_archives/3","type":"function"},{"doc":"Returns a list of virtual tape recovery points that are available for the\nspecified tape gateway.\n\nA recovery point is a point-in-time view of a virtual tape at which all the data\non the virtual tape is consistent. If your gateway crashes, virtual tapes that\nhave recovery points can be recovered to a new gateway. This operation is only\nsupported in the tape gateway type.","ref":"AWS.StorageGateway.html#describe_tape_recovery_points/3","title":"AWS.StorageGateway.describe_tape_recovery_points/3","type":"function"},{"doc":"Returns a description of virtual tapes that correspond to the specified Amazon\nResource Names (ARNs).\n\nIf `TapeARN` is not specified, returns a description of the virtual tapes\nassociated with the specified gateway. This operation is only supported for the\ntape gateway type.\n\nThe operation supports pagination. By default, the operation returns a maximum\nof up to 100 tapes. You can optionally specify the `Limit` field in the body to\nlimit the number of tapes in the response. If the number of tapes returned in\nthe response is truncated, the response includes a `Marker` field. You can use\nthis `Marker` value in your subsequent request to retrieve the next set of\ntapes.","ref":"AWS.StorageGateway.html#describe_tapes/3","title":"AWS.StorageGateway.describe_tapes/3","type":"function"},{"doc":"Returns information about the upload buffer of a gateway.\n\nThis operation is supported for the stored volume, cached volume, and tape\ngateway types.\n\nThe response includes disk IDs that are configured as upload buffer space, and\nit includes the amount of upload buffer space allocated and used.","ref":"AWS.StorageGateway.html#describe_upload_buffer/3","title":"AWS.StorageGateway.describe_upload_buffer/3","type":"function"},{"doc":"Returns a description of virtual tape library (VTL) devices for the specified\ntape gateway.\n\nIn the response, Storage Gateway returns VTL device information.\n\nThis operation is only supported in the tape gateway type.","ref":"AWS.StorageGateway.html#describe_vtl_devices/3","title":"AWS.StorageGateway.describe_vtl_devices/3","type":"function"},{"doc":"Returns information about the working storage of a gateway.\n\nThis operation is only supported in the stored volumes gateway type. This\noperation is deprecated in cached volumes API version (20120630). Use\nDescribeUploadBuffer instead.\n\nWorking storage is also referred to as upload buffer. You can also use the\nDescribeUploadBuffer operation to add upload buffer to a stored volume gateway.\n\nThe response includes disk IDs that are configured as working storage, and it\nincludes the amount of working storage allocated and used.","ref":"AWS.StorageGateway.html#describe_working_storage/3","title":"AWS.StorageGateway.describe_working_storage/3","type":"function"},{"doc":"Disconnects a volume from an iSCSI connection and then detaches the volume from\nthe specified gateway.\n\nDetaching and attaching a volume enables you to recover your data from one\ngateway to a different gateway without creating a snapshot. It also makes it\neasier to move your volumes from an on-premises gateway to a gateway hosted on\nan Amazon EC2 instance. This operation is only supported in the volume gateway\ntype.","ref":"AWS.StorageGateway.html#detach_volume/3","title":"AWS.StorageGateway.detach_volume/3","type":"function"},{"doc":"Disables a tape gateway when the gateway is no longer functioning.\n\nFor example, if your gateway VM is damaged, you can disable the gateway so you\ncan recover virtual tapes.\n\nUse this operation for a tape gateway that is not reachable or not functioning.\nThis operation is only supported in the tape gateway type.\n\nAfter a gateway is disabled, it cannot be enabled.","ref":"AWS.StorageGateway.html#disable_gateway/3","title":"AWS.StorageGateway.disable_gateway/3","type":"function"},{"doc":"Disassociates an Amazon FSx file system from the specified gateway.\n\nAfter the disassociation process finishes, the gateway can no longer access the\nAmazon FSx file system. This operation is only supported in the FSx File Gateway\ntype.","ref":"AWS.StorageGateway.html#disassociate_file_system/3","title":"AWS.StorageGateway.disassociate_file_system/3","type":"function"},{"doc":"Adds a file gateway to an Active Directory domain.\n\nThis operation is only supported for file gateways that support the SMB file\nprotocol.\n\nJoining a domain creates an Active Directory computer account in the default\norganizational unit, using the gateway's **Gateway ID** as the account name (for\nexample, SGW-1234ADE). If your Active Directory environment requires that you\npre-stage accounts to facilitate the join domain process, you will need to\ncreate this account ahead of time.\n\nTo create the gateway's computer account in an organizational unit other than\nthe default, you must specify the organizational unit when joining the domain.","ref":"AWS.StorageGateway.html#join_domain/3","title":"AWS.StorageGateway.join_domain/3","type":"function"},{"doc":"Lists the automatic tape creation policies for a gateway.\n\nIf there are no automatic tape creation policies for the gateway, it returns an\nempty list.\n\nThis operation is only supported for tape gateways.","ref":"AWS.StorageGateway.html#list_automatic_tape_creation_policies/3","title":"AWS.StorageGateway.list_automatic_tape_creation_policies/3","type":"function"},{"doc":"Gets a list of the file shares for a specific S3 File Gateway, or the list of\nfile shares that belong to the calling Amazon Web Services account.\n\nThis operation is only supported for S3 File Gateways.","ref":"AWS.StorageGateway.html#list_file_shares/3","title":"AWS.StorageGateway.list_file_shares/3","type":"function"},{"doc":"Gets a list of `FileSystemAssociationSummary` objects.\n\nEach object contains a summary of a file system association. This operation is\nonly supported for FSx File Gateways.","ref":"AWS.StorageGateway.html#list_file_system_associations/3","title":"AWS.StorageGateway.list_file_system_associations/3","type":"function"},{"doc":"Lists gateways owned by an Amazon Web Services account in an Amazon Web Services\nRegion specified in the request.\n\nThe returned list is ordered by gateway Amazon Resource Name (ARN).\n\nBy default, the operation returns a maximum of 100 gateways. This operation\nsupports pagination that allows you to optionally reduce the number of gateways\nreturned in a response.\n\nIf you have more gateways than are returned in a response (that is, the response\nreturns only a truncated list of your gateways), the response contains a marker\nthat you can specify in your next request to fetch the next page of gateways.","ref":"AWS.StorageGateway.html#list_gateways/3","title":"AWS.StorageGateway.list_gateways/3","type":"function"},{"doc":"Returns a list of the gateway's local disks.\n\nTo specify which gateway to describe, you use the Amazon Resource Name (ARN) of\nthe gateway in the body of the request.\n\nThe request returns a list of all disks, specifying which are configured as\nworking storage, cache storage, or stored volume or not configured at all. The\nresponse includes a `DiskStatus` field. This field can have a value of present\n(the disk is available to use), missing (the disk is no longer connected to the\ngateway), or mismatch (the disk node is occupied by a disk that has incorrect\nmetadata or the disk content is corrupted).","ref":"AWS.StorageGateway.html#list_local_disks/3","title":"AWS.StorageGateway.list_local_disks/3","type":"function"},{"doc":"Lists the tags that have been added to the specified resource.\n\nThis operation is supported in storage gateways of all types.","ref":"AWS.StorageGateway.html#list_tags_for_resource/3","title":"AWS.StorageGateway.list_tags_for_resource/3","type":"function"},{"doc":"Lists custom tape pools.\n\nYou specify custom tape pools to list by specifying one or more custom tape pool\nAmazon Resource Names (ARNs). If you don't specify a custom tape pool ARN, the\noperation lists all custom tape pools.\n\nThis operation supports pagination. You can optionally specify the `Limit`\nparameter in the body to limit the number of tape pools in the response. If the\nnumber of tape pools returned in the response is truncated, the response\nincludes a `Marker` element that you can use in your subsequent request to\nretrieve the next set of tape pools.","ref":"AWS.StorageGateway.html#list_tape_pools/3","title":"AWS.StorageGateway.list_tape_pools/3","type":"function"},{"doc":"Lists virtual tapes in your virtual tape library (VTL) and your virtual tape\nshelf (VTS).\n\nYou specify the tapes to list by specifying one or more tape Amazon Resource\nNames (ARNs). If you don't specify a tape ARN, the operation lists all virtual\ntapes in both your VTL and VTS.\n\nThis operation supports pagination. By default, the operation returns a maximum\nof up to 100 tapes. You can optionally specify the `Limit` parameter in the body\nto limit the number of tapes in the response. If the number of tapes returned in\nthe response is truncated, the response includes a `Marker` element that you can\nuse in your subsequent request to retrieve the next set of tapes. This operation\nis only supported in the tape gateway type.","ref":"AWS.StorageGateway.html#list_tapes/3","title":"AWS.StorageGateway.list_tapes/3","type":"function"},{"doc":"Lists iSCSI initiators that are connected to a volume.\n\nYou can use this operation to determine whether a volume is being used or not.\nThis operation is only supported in the cached volume and stored volume gateway\ntypes.","ref":"AWS.StorageGateway.html#list_volume_initiators/3","title":"AWS.StorageGateway.list_volume_initiators/3","type":"function"},{"doc":"Lists the recovery points for a specified gateway.\n\nThis operation is only supported in the cached volume gateway type.\n\nEach cache volume has one recovery point. A volume recovery point is a point in\ntime at which all data of the volume is consistent and from which you can create\na snapshot or clone a new cached volume from a source volume. To create a\nsnapshot from a volume recovery point use the\n`CreateSnapshotFromVolumeRecoveryPoint` operation.","ref":"AWS.StorageGateway.html#list_volume_recovery_points/3","title":"AWS.StorageGateway.list_volume_recovery_points/3","type":"function"},{"doc":"Lists the iSCSI stored volumes of a gateway.\n\nResults are sorted by volume ARN. The response includes only the volume ARNs. If\nyou want additional volume information, use the `DescribeStorediSCSIVolumes` or\nthe `DescribeCachediSCSIVolumes` API.\n\nThe operation supports pagination. By default, the operation returns a maximum\nof up to 100 volumes. You can optionally specify the `Limit` field in the body\nto limit the number of volumes in the response. If the number of volumes\nreturned in the response is truncated, the response includes a Marker field. You\ncan use this Marker value in your subsequent request to retrieve the next set of\nvolumes. This operation is only supported in the cached volume and stored volume\ngateway types.","ref":"AWS.StorageGateway.html#list_volumes/3","title":"AWS.StorageGateway.list_volumes/3","type":"function"},{"doc":"","ref":"AWS.StorageGateway.html#metadata/0","title":"AWS.StorageGateway.metadata/0","type":"function"},{"doc":"Sends you notification through CloudWatch Events when all files written to your\nfile share have been uploaded to Amazon S3.\n\nStorage Gateway can send a notification through Amazon CloudWatch Events when\nall files written to your file share up to that point in time have been uploaded\nto Amazon S3. These files include files written to the file share up to the time\nthat you make a request for notification. When the upload is done, Storage\nGateway sends you notification through an Amazon CloudWatch Event. You can\nconfigure CloudWatch Events to send the notification through event targets such\nas Amazon SNS or Lambda function. This operation is only supported for S3 File\nGateways.\n\nFor more information, see [Getting file upload notification](https://docs.aws.amazon.com/filegateway/latest/files3/monitoring-file-gateway.html#get-notification)\nin the *Amazon S3 File Gateway User Guide*.","ref":"AWS.StorageGateway.html#notify_when_uploaded/3","title":"AWS.StorageGateway.notify_when_uploaded/3","type":"function"},{"doc":"Refreshes the cached inventory of objects for the specified file share.\n\nThis operation finds objects in the Amazon S3 bucket that were added, removed,\nor replaced since the gateway last listed the bucket's contents and cached the\nresults. This operation does not import files into the S3 File Gateway cache\nstorage. It only updates the cached inventory to reflect changes in the\ninventory of the objects in the S3 bucket. This operation is only supported in\nthe S3 File Gateway types.\n\nYou can subscribe to be notified through an Amazon CloudWatch event when your\n`RefreshCache` operation completes. For more information, see [Getting notified about file\noperations](https://docs.aws.amazon.com/filegateway/latest/files3/monitoring-file-gateway.html#get-notification)\nin the *Amazon S3 File Gateway User Guide*. This operation is Only supported for\nS3 File Gateways.\n\nWhen this API is called, it only initiates the refresh operation. When the API\ncall completes and returns a success code, it doesn't necessarily mean that the\nfile refresh has completed. You should use the refresh-complete notification to\ndetermine that the operation has completed before you check for new files on the\ngateway file share. You can subscribe to be notified through a CloudWatch event\nwhen your `RefreshCache` operation completes.\n\nThrottle limit: This API is asynchronous, so the gateway will accept no more\nthan two refreshes at any time. We recommend using the refresh-complete\nCloudWatch event notification before issuing additional requests. For more\ninformation, see [Getting notified about file operations](https://docs.aws.amazon.com/filegateway/latest/files3/monitoring-file-gateway.html#get-notification)\nin the *Amazon S3 File Gateway User Guide*.\n\n   Wait at least 60 seconds between consecutive RefreshCache API\nrequests.\n\n   If you invoke the RefreshCache API when two requests are already\nbeing processed, any new request will cause an `InvalidGatewayRequestException`\nerror because too many requests were sent to the server.\n\nThe S3 bucket name does not need to be included when entering the list of\nfolders in the FolderList parameter.\n\nFor more information, see [Getting notified about file operations](https://docs.aws.amazon.com/filegateway/latest/files3/monitoring-file-gateway.html#get-notification)\nin the *Amazon S3 File Gateway User Guide*.","ref":"AWS.StorageGateway.html#refresh_cache/3","title":"AWS.StorageGateway.refresh_cache/3","type":"function"},{"doc":"Removes one or more tags from the specified resource.\n\nThis operation is supported in storage gateways of all types.","ref":"AWS.StorageGateway.html#remove_tags_from_resource/3","title":"AWS.StorageGateway.remove_tags_from_resource/3","type":"function"},{"doc":"Resets all cache disks that have encountered an error and makes the disks\navailable for reconfiguration as cache storage.\n\nIf your cache disk encounters an error, the gateway prevents read and write\noperations on virtual tapes in the gateway. For example, an error can occur when\na disk is corrupted or removed from the gateway. When a cache is reset, the\ngateway loses its cache storage. At this point, you can reconfigure the disks as\ncache disks. This operation is only supported in the cached volume and tape\ntypes.\n\nIf the cache disk you are resetting contains data that has not been uploaded to\nAmazon S3 yet, that data can be lost. After you reset cache disks, there will be\nno configured cache disks left in the gateway, so you must configure at least\none new cache disk for your gateway to function properly.","ref":"AWS.StorageGateway.html#reset_cache/3","title":"AWS.StorageGateway.reset_cache/3","type":"function"},{"doc":"Retrieves an archived virtual tape from the virtual tape shelf (VTS) to a tape\ngateway.\n\nVirtual tapes archived in the VTS are not associated with any gateway. However\nafter a tape is retrieved, it is associated with a gateway, even though it is\nalso listed in the VTS, that is, archive. This operation is only supported in\nthe tape gateway type.\n\nOnce a tape is successfully retrieved to a gateway, it cannot be retrieved again\nto another gateway. You must archive the tape again before you can retrieve it\nto another gateway. This operation is only supported in the tape gateway type.","ref":"AWS.StorageGateway.html#retrieve_tape_archive/3","title":"AWS.StorageGateway.retrieve_tape_archive/3","type":"function"},{"doc":"Retrieves the recovery point for the specified virtual tape.\n\nThis operation is only supported in the tape gateway type.\n\nA recovery point is a point in time view of a virtual tape at which all the data\non the tape is consistent. If your gateway crashes, virtual tapes that have\nrecovery points can be recovered to a new gateway.\n\nThe virtual tape can be retrieved to only one gateway. The retrieved tape is\nread-only. The virtual tape can be retrieved to only a tape gateway. There is no\ncharge for retrieving recovery points.","ref":"AWS.StorageGateway.html#retrieve_tape_recovery_point/3","title":"AWS.StorageGateway.retrieve_tape_recovery_point/3","type":"function"},{"doc":"Sets the password for your VM local console.\n\nWhen you log in to the local console for the first time, you log in to the VM\nwith the default credentials. We recommend that you set a new password. You\ndon't need to know the default password to set a new password.","ref":"AWS.StorageGateway.html#set_local_console_password/3","title":"AWS.StorageGateway.set_local_console_password/3","type":"function"},{"doc":"Sets the password for the guest user `smbguest`.\n\nThe `smbguest` user is the user when the authentication method for the file\nshare is set to `GuestAccess`. This operation only supported for S3 File\nGateways","ref":"AWS.StorageGateway.html#set_smb_guest_password/3","title":"AWS.StorageGateway.set_smb_guest_password/3","type":"function"},{"doc":"Shuts down a Tape Gateway or Volume Gateway.\n\nTo specify which gateway to shut down, use the Amazon Resource Name (ARN) of the\ngateway in the body of your request.\n\nThis API action cannot be used to shut down S3 File Gateway or FSx File Gateway.\n\nThe operation shuts down the gateway service component running in the gateway's\nvirtual machine (VM) and not the host VM.\n\nIf you want to shut down the VM, it is recommended that you first shut down the\ngateway component in the VM to avoid unpredictable conditions.\n\nAfter the gateway is shutdown, you cannot call any other API except\n`StartGateway`, `DescribeGatewayInformation`, and `ListGateways`. For more\ninformation, see `ActivateGateway`. Your applications cannot read from or write\nto the gateway's storage volumes, and there are no snapshots taken.\n\nWhen you make a shutdown request, you will get a `200 OK` success response\nimmediately. However, it might take some time for the gateway to shut down. You\ncan call the `DescribeGatewayInformation` API to check the status. For more\ninformation, see `ActivateGateway`.\n\nIf do not intend to use the gateway again, you must delete the gateway (using\n`DeleteGateway`) to no longer pay software charges associated with the gateway.","ref":"AWS.StorageGateway.html#shutdown_gateway/3","title":"AWS.StorageGateway.shutdown_gateway/3","type":"function"},{"doc":"Start a test that verifies that the specified gateway is configured for High\nAvailability monitoring in your host environment.\n\nThis request only initiates the test and that a successful response only\nindicates that the test was started. It doesn't indicate that the test passed.\nFor the status of the test, invoke the `DescribeAvailabilityMonitorTest` API.\n\nStarting this test will cause your gateway to go offline for a brief period.","ref":"AWS.StorageGateway.html#start_availability_monitor_test/3","title":"AWS.StorageGateway.start_availability_monitor_test/3","type":"function"},{"doc":"Starts a gateway that you previously shut down (see `ShutdownGateway`).\n\nAfter the gateway starts, you can then make other API calls, your applications\ncan read from or write to the gateway's storage volumes and you will be able to\ntake snapshot backups.\n\nWhen you make a request, you will get a 200 OK success response immediately.\nHowever, it might take some time for the gateway to be ready. You should call\n`DescribeGatewayInformation` and check the status before making any additional\nAPI calls. For more information, see `ActivateGateway`.\n\nTo specify which gateway to start, use the Amazon Resource Name (ARN) of the\ngateway in your request.","ref":"AWS.StorageGateway.html#start_gateway/3","title":"AWS.StorageGateway.start_gateway/3","type":"function"},{"doc":"Updates the automatic tape creation policy of a gateway.\n\nUse this to update the policy with a new set of automatic tape creation rules.\nThis is only supported for tape gateways.\n\nBy default, there is no automatic tape creation policy.\n\nA gateway can have only one automatic tape creation policy.","ref":"AWS.StorageGateway.html#update_automatic_tape_creation_policy/3","title":"AWS.StorageGateway.update_automatic_tape_creation_policy/3","type":"function"},{"doc":"Updates the bandwidth rate limits of a gateway.\n\nYou can update both the upload and download bandwidth rate limit or specify only\none of the two. If you don't set a bandwidth rate limit, the existing rate limit\nremains. This operation is supported only for the stored volume, cached volume,\nand tape gateway types. To update bandwidth rate limits for S3 file gateways,\nuse `UpdateBandwidthRateLimitSchedule`.\n\nBy default, a gateway's bandwidth rate limits are not set. If you don't set any\nlimit, the gateway does not have any limitations on its bandwidth usage and\ncould potentially use the maximum available bandwidth.\n\nTo specify which gateway to update, use the Amazon Resource Name (ARN) of the\ngateway in your request.","ref":"AWS.StorageGateway.html#update_bandwidth_rate_limit/3","title":"AWS.StorageGateway.update_bandwidth_rate_limit/3","type":"function"},{"doc":"Updates the bandwidth rate limit schedule for a specified gateway.\n\nBy default, gateways do not have bandwidth rate limit schedules, which means no\nbandwidth rate limiting is in effect. Use this to initiate or update a gateway's\nbandwidth rate limit schedule. This operation is supported for volume, tape, and\nS3 file gateways. S3 file gateways support bandwidth rate limits for upload\nonly. FSx file gateways do not support bandwidth rate limits.","ref":"AWS.StorageGateway.html#update_bandwidth_rate_limit_schedule/3","title":"AWS.StorageGateway.update_bandwidth_rate_limit_schedule/3","type":"function"},{"doc":"Updates the Challenge-Handshake Authentication Protocol (CHAP) credentials for a\nspecified iSCSI target.\n\nBy default, a gateway does not have CHAP enabled; however, for added security,\nyou might use it. This operation is supported in the volume and tape gateway\ntypes.\n\nWhen you update CHAP credentials, all existing connections on the target are\nclosed and initiators must reconnect with the new credentials.","ref":"AWS.StorageGateway.html#update_chap_credentials/3","title":"AWS.StorageGateway.update_chap_credentials/3","type":"function"},{"doc":"Updates a file system association.\n\nThis operation is only supported in the FSx File Gateways.","ref":"AWS.StorageGateway.html#update_file_system_association/3","title":"AWS.StorageGateway.update_file_system_association/3","type":"function"},{"doc":"Updates a gateway's metadata, which includes the gateway's name and time zone.\n\nTo specify which gateway to update, use the Amazon Resource Name (ARN) of the\ngateway in your request.\n\nFor gateways activated after September 2, 2015, the gateway's ARN contains the\ngateway ID rather than the gateway name. However, changing the name of the\ngateway has no effect on the gateway's ARN.","ref":"AWS.StorageGateway.html#update_gateway_information/3","title":"AWS.StorageGateway.update_gateway_information/3","type":"function"},{"doc":"Updates the gateway virtual machine (VM) software.\n\nThe request immediately triggers the software update.\n\nWhen you make this request, you get a `200 OK` success response immediately.\nHowever, it might take some time for the update to complete. You can call\n`DescribeGatewayInformation` to verify the gateway is in the `STATE_RUNNING`\nstate.\n\nA software update forces a system restart of your gateway. You can minimize the\nchance of any disruption to your applications by increasing your iSCSI\nInitiators' timeouts. For more information about increasing iSCSI Initiator\ntimeouts for Windows and Linux, see [Customizing your Windows iSCSI settings](https://docs.aws.amazon.com/storagegateway/latest/userguide/ConfiguringiSCSIClientInitiatorWindowsClient.html#CustomizeWindowsiSCSISettings)\nand [Customizing your Linux iSCSI settings](https://docs.aws.amazon.com/storagegateway/latest/userguide/ConfiguringiSCSIClientInitiatorRedHatClient.html#CustomizeLinuxiSCSISettings),\nrespectively.","ref":"AWS.StorageGateway.html#update_gateway_software_now/3","title":"AWS.StorageGateway.update_gateway_software_now/3","type":"function"},{"doc":"Updates a gateway's weekly maintenance start time information, including day and\ntime of the week.\n\nThe maintenance time is the time in your gateway's time zone.","ref":"AWS.StorageGateway.html#update_maintenance_start_time/3","title":"AWS.StorageGateway.update_maintenance_start_time/3","type":"function"},{"doc":"Updates a Network File System (NFS) file share.\n\nThis operation is only supported in S3 File Gateways.\n\nTo leave a file share field unchanged, set the corresponding input field to\nnull.\n\nUpdates the following file share settings:\n\n  * Default storage class for your S3 bucket\n\n  * Metadata defaults for your S3 bucket\n\n  * Allowed NFS clients for your file share\n\n  * Squash settings\n\n  * Write status of your file share","ref":"AWS.StorageGateway.html#update_nfs_file_share/3","title":"AWS.StorageGateway.update_nfs_file_share/3","type":"function"},{"doc":"Updates a Server Message Block (SMB) file share.\n\nThis operation is only supported for S3 File Gateways.\n\nTo leave a file share field unchanged, set the corresponding input field to\nnull.\n\nFile gateways require Security Token Service (Amazon Web Services STS) to be\nactivated to enable you to create a file share. Make sure that Amazon Web\nServices STS is activated in the Amazon Web Services Region you are creating\nyour file gateway in. If Amazon Web Services STS is not activated in this Amazon\nWeb Services Region, activate it. For information about how to activate Amazon\nWeb Services STS, see [Activating and deactivating Amazon Web Services STS in an Amazon Web Services\nRegion](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_enable-regions.html)\nin the *Identity and Access Management User Guide*.\n\nFile gateways don't support creating hard or symbolic links on a file share.","ref":"AWS.StorageGateway.html#update_smb_file_share/3","title":"AWS.StorageGateway.update_smb_file_share/3","type":"function"},{"doc":"Controls whether the shares on an S3 File Gateway are visible in a net view or\nbrowse list.\n\nThe operation is only supported for S3 File Gateways.","ref":"AWS.StorageGateway.html#update_smb_file_share_visibility/3","title":"AWS.StorageGateway.update_smb_file_share_visibility/3","type":"function"},{"doc":"Updates the list of Active Directory users and groups that have special\npermissions for SMB file shares on the gateway.","ref":"AWS.StorageGateway.html#update_smb_local_groups/3","title":"AWS.StorageGateway.update_smb_local_groups/3","type":"function"},{"doc":"Updates the SMB security strategy on a file gateway.\n\nThis action is only supported in file gateways.\n\nThis API is called Security level in the User Guide.\n\nA higher security level can affect performance of the gateway.","ref":"AWS.StorageGateway.html#update_smb_security_strategy/3","title":"AWS.StorageGateway.update_smb_security_strategy/3","type":"function"},{"doc":"Updates a snapshot schedule configured for a gateway volume.\n\nThis operation is only supported in the cached volume and stored volume gateway\ntypes.\n\nThe default snapshot schedule for volume is once every 24 hours, starting at the\ncreation time of the volume. You can use this API to change the snapshot\nschedule configured for the volume.\n\nIn the request you must identify the gateway volume whose snapshot schedule you\nwant to update, and the schedule information, including when you want the\nsnapshot to begin on a day and the frequency (in hours) of snapshots.","ref":"AWS.StorageGateway.html#update_snapshot_schedule/3","title":"AWS.StorageGateway.update_snapshot_schedule/3","type":"function"},{"doc":"Updates the type of medium changer in a tape gateway.\n\nWhen you activate a tape gateway, you select a medium changer type for the tape\ngateway. This operation enables you to select a different type of medium changer\nafter a tape gateway is activated. This operation is only supported in the tape\ngateway type.","ref":"AWS.StorageGateway.html#update_vtl_device_type/3","title":"AWS.StorageGateway.update_vtl_device_type/3","type":"function"},{"doc":"AWS Supply Chain is a cloud-based application that works with your enterprise\nresource planning (ERP) and supply chain management systems.\n\nUsing AWS Supply Chain, you can connect and extract your inventory, supply, and\ndemand related data from existing ERP or supply chain systems into a single data\nmodel.\n\nThe AWS Supply Chain API supports configuration data import for Supply Planning.\n\nAll AWS Supply chain API operations are Amazon-authenticated and\ncertificate-signed. They not only require the use of the AWS SDK, but also allow\nfor the exclusive use of AWS Identity and Access Management users and roles to\nhelp facilitate access, trust, and permission policies.","ref":"AWS.SupplyChain.html","title":"AWS.SupplyChain","type":"module"},{"doc":"CreateBillOfMaterialsImportJob creates an import job for the Product Bill Of\nMaterials (BOM) entity.\n\nFor information on the product_bom entity, see the AWS Supply Chain User Guide.\n\nThe CSV file must be located in an Amazon S3 location accessible to AWS Supply\nChain. It is recommended to use the same Amazon S3 bucket created during your\nAWS Supply Chain instance creation.","ref":"AWS.SupplyChain.html#create_bill_of_materials_import_job/4","title":"AWS.SupplyChain.create_bill_of_materials_import_job/4","type":"function"},{"doc":"Get status and details of a BillOfMaterialsImportJob.","ref":"AWS.SupplyChain.html#get_bill_of_materials_import_job/4","title":"AWS.SupplyChain.get_bill_of_materials_import_job/4","type":"function"},{"doc":"","ref":"AWS.SupplyChain.html#metadata/0","title":"AWS.SupplyChain.metadata/0","type":"function"},{"doc":"Amazon Web Services Support\n\nThe *Amazon Web Services Support API Reference* is intended for programmers who\nneed detailed information about the Amazon Web Services Support operations and\ndata types.\n\nYou can use the API to manage your support cases programmatically. The Amazon\nWeb Services Support API uses HTTP methods that return results in JSON format.\n\n   You must have a Business, Enterprise On-Ramp, or Enterprise Support\nplan to use the Amazon Web Services Support API.\n\n   If you call the Amazon Web Services Support API from an account\nthat doesn't have a Business, Enterprise On-Ramp, or Enterprise Support plan,\nthe `SubscriptionRequiredException` error message appears. For information about\nchanging your support plan, see [Amazon Web Services Support](http://aws.amazon.com/premiumsupport/).\n\nYou can also use the Amazon Web Services Support API to access features for\n[Trusted Advisor](http://aws.amazon.com/premiumsupport/trustedadvisor/). You can return a list of checks and their descriptions, get check results, specify\nchecks to refresh, and get the refresh status of checks.\n\nYou can manage your support cases with the following Amazon Web Services Support\nAPI operations:\n\n  * The `CreateCase`, `DescribeCases`, `DescribeAttachment`, and\n`ResolveCase` operations create Amazon Web Services Support cases, retrieve\ninformation about cases, and resolve cases.\n\n  * The `DescribeCommunications`, `AddCommunicationToCase`, and\n`AddAttachmentsToSet` operations retrieve and add communications and attachments\nto Amazon Web Services Support cases.\n\n  * The `DescribeServices` and `DescribeSeverityLevels` operations\nreturn Amazon Web Service names, service codes, service categories, and problem\nseverity levels. You use these values when you call the `CreateCase` operation.\n\nYou can also use the Amazon Web Services Support API to call the Trusted Advisor\noperations. For more information, see [Trusted\nAdvisor](https://docs.aws.amazon.com/) in the *Amazon Web Services Support User\nGuide*.\n\nFor authentication of requests, Amazon Web Services Support uses [Signature Version 4 Signing\nProcess](https://docs.aws.amazon.com/general/latest/gr/signature-version-4.html).\n\nFor more information about this service and the endpoints to use, see [About the Amazon Web Services Support\nAPI](https://docs.aws.amazon.com/awssupport/latest/user/about-support-api.html)\nin the *Amazon Web Services Support User Guide*.","ref":"AWS.Support.html","title":"AWS.Support","type":"module"},{"doc":"Adds one or more attachments to an attachment set.\n\nAn attachment set is a temporary container for attachments that you add to a\ncase or case communication. The set is available for 1 hour after it's created.\nThe `expiryTime` returned in the response is when the set expires.\n\n   You must have a Business, Enterprise On-Ramp, or Enterprise Support\nplan to use the Amazon Web Services Support API.\n\n   If you call the Amazon Web Services Support API from an account\nthat doesn't have a Business, Enterprise On-Ramp, or Enterprise Support plan,\nthe `SubscriptionRequiredException` error message appears. For information about\nchanging your support plan, see [Amazon Web Services Support](http://aws.amazon.com/premiumsupport/).","ref":"AWS.Support.html#add_attachments_to_set/3","title":"AWS.Support.add_attachments_to_set/3","type":"function"},{"doc":"Adds additional customer communication to an Amazon Web Services Support case.\n\nUse the `caseId` parameter to identify the case to which to add communication.\nYou can list a set of email addresses to copy on the communication by using the\n`ccEmailAddresses` parameter. The `communicationBody` value contains the text of\nthe communication.\n\n   You must have a Business, Enterprise On-Ramp, or Enterprise Support\nplan to use the Amazon Web Services Support API.\n\n   If you call the Amazon Web Services Support API from an account\nthat doesn't have a Business, Enterprise On-Ramp, or Enterprise Support plan,\nthe `SubscriptionRequiredException` error message appears. For information about\nchanging your support plan, see [Amazon Web Services Support](http://aws.amazon.com/premiumsupport/).","ref":"AWS.Support.html#add_communication_to_case/3","title":"AWS.Support.add_communication_to_case/3","type":"function"},{"doc":"Creates a case in the Amazon Web Services Support Center.\n\nThis operation is similar to how you create a case in the Amazon Web Services\nSupport Center [Create Case](https://console.aws.amazon.com/support/home#/case/create) page.\n\nThe Amazon Web Services Support API doesn't support requesting service limit\nincreases. You can submit a service limit increase in the following ways:\n\n  * Submit a request from the Amazon Web Services Support Center\n[Create Case](https://console.aws.amazon.com/support/home#/case/create) page.     * Use the Service Quotas\n[RequestServiceQuotaIncrease](https://docs.aws.amazon.com/servicequotas/2019-06-24/apireference/API_RequestServiceQuotaIncrease.html)\noperation.\n\nA successful `CreateCase` request returns an Amazon Web Services Support case\nnumber. You can use the `DescribeCases` operation and specify the case number to\nget existing Amazon Web Services Support cases. After you create a case, use the\n`AddCommunicationToCase` operation to add additional communication or\nattachments to an existing case.\n\nThe `caseId` is separate from the `displayId` that appears in the [Amazon Web Services Support Center](https://console.aws.amazon.com/support). Use the\n`DescribeCases` operation to get the `displayId`.\n\n   You must have a Business, Enterprise On-Ramp, or Enterprise Support\nplan to use the Amazon Web Services Support API.\n\n   If you call the Amazon Web Services Support API from an account\nthat doesn't have a Business, Enterprise On-Ramp, or Enterprise Support plan,\nthe `SubscriptionRequiredException` error message appears. For information about\nchanging your support plan, see [Amazon Web Services Support](http://aws.amazon.com/premiumsupport/).","ref":"AWS.Support.html#create_case/3","title":"AWS.Support.create_case/3","type":"function"},{"doc":"Returns the attachment that has the specified ID.\n\nAttachments can include screenshots, error logs, or other files that describe\nyour issue. Attachment IDs are generated by the case management system when you\nadd an attachment to a case or case communication. Attachment IDs are returned\nin the `AttachmentDetails` objects that are returned by the\n`DescribeCommunications` operation.\n\n   You must have a Business, Enterprise On-Ramp, or Enterprise Support\nplan to use the Amazon Web Services Support API.\n\n   If you call the Amazon Web Services Support API from an account\nthat doesn't have a Business, Enterprise On-Ramp, or Enterprise Support plan,\nthe `SubscriptionRequiredException` error message appears. For information about\nchanging your support plan, see [Amazon Web Services Support](http://aws.amazon.com/premiumsupport/).","ref":"AWS.Support.html#describe_attachment/3","title":"AWS.Support.describe_attachment/3","type":"function"},{"doc":"Returns a list of cases that you specify by passing one or more case IDs.\n\nYou can use the `afterTime` and `beforeTime` parameters to filter the cases by\ndate. You can set values for the `includeResolvedCases` and\n`includeCommunications` parameters to specify how much information to return.\n\nThe response returns the following in JSON format:\n\n  * One or more\n[CaseDetails](https://docs.aws.amazon.com/awssupport/latest/APIReference/API_CaseDetails.html) data types.\n\n  * One or more `nextToken` values, which specify where to paginate\nthe returned records represented by the `CaseDetails` objects.\n\nCase data is available for 12 months after creation. If a case was created more\nthan 12 months ago, a request might return an error.\n\n   You must have a Business, Enterprise On-Ramp, or Enterprise Support\nplan to use the Amazon Web Services Support API.\n\n   If you call the Amazon Web Services Support API from an account\nthat doesn't have a Business, Enterprise On-Ramp, or Enterprise Support plan,\nthe `SubscriptionRequiredException` error message appears. For information about\nchanging your support plan, see [Amazon Web Services\nSupport](http://aws.amazon.com/premiumsupport/).","ref":"AWS.Support.html#describe_cases/3","title":"AWS.Support.describe_cases/3","type":"function"},{"doc":"Returns communications and attachments for one or more support cases.\n\nUse the `afterTime` and `beforeTime` parameters to filter by date. You can use\nthe `caseId` parameter to restrict the results to a specific case.\n\nCase data is available for 12 months after creation. If a case was created more\nthan 12 months ago, a request for data might cause an error.\n\nYou can use the `maxResults` and `nextToken` parameters to control the\npagination of the results. Set `maxResults` to the number of cases that you want\nto display on each page, and use `nextToken` to specify the resumption of\npagination.\n\n   You must have a Business, Enterprise On-Ramp, or Enterprise Support\nplan to use the Amazon Web Services Support API.\n\n   If you call the Amazon Web Services Support API from an account\nthat doesn't have a Business, Enterprise On-Ramp, or Enterprise Support plan,\nthe `SubscriptionRequiredException` error message appears. For information about\nchanging your support plan, see [Amazon Web Services Support](http://aws.amazon.com/premiumsupport/).","ref":"AWS.Support.html#describe_communications/3","title":"AWS.Support.describe_communications/3","type":"function"},{"doc":"Returns a list of CreateCaseOption types along with the corresponding supported\nhours and language availability.\n\nYou can specify the `language` `categoryCode`, `issueType` and `serviceCode`\nused to retrieve the CreateCaseOptions.\n\n   You must have a Business, Enterprise On-Ramp, or Enterprise Support\nplan to use the Amazon Web Services Support API.\n\n   If you call the Amazon Web Services Support API from an account\nthat doesn't have a Business, Enterprise On-Ramp, or Enterprise Support plan,\nthe `SubscriptionRequiredException` error message appears. For information about\nchanging your support plan, see [Amazon Web Services Support](http://aws.amazon.com/premiumsupport/).","ref":"AWS.Support.html#describe_create_case_options/3","title":"AWS.Support.describe_create_case_options/3","type":"function"},{"doc":"Returns the current list of Amazon Web Services services and a list of service\ncategories for each service.\n\nYou then use service names and categories in your `CreateCase` requests. Each\nAmazon Web Services service has its own set of categories.\n\nThe service codes and category codes correspond to the values that appear in the\n**Service** and **Category** lists on the Amazon Web Services Support Center\n[Create Case](https://console.aws.amazon.com/support/home#/case/create) page. The values in those fields don't necessarily match the service codes and\ncategories returned by the `DescribeServices` operation. Always use the service\ncodes and categories that the `DescribeServices` operation returns, so that you\nhave the most recent set of service and category codes.\n\n   You must have a Business, Enterprise On-Ramp, or Enterprise Support\nplan to use the Amazon Web Services Support API.\n\n   If you call the Amazon Web Services Support API from an account\nthat doesn't have a Business, Enterprise On-Ramp, or Enterprise Support plan,\nthe `SubscriptionRequiredException` error message appears. For information about\nchanging your support plan, see [Amazon Web Services\nSupport](http://aws.amazon.com/premiumsupport/).","ref":"AWS.Support.html#describe_services/3","title":"AWS.Support.describe_services/3","type":"function"},{"doc":"Returns the list of severity levels that you can assign to a support case.\n\nThe severity level for a case is also a field in the `CaseDetails` data type\nthat you include for a `CreateCase` request.\n\n   You must have a Business, Enterprise On-Ramp, or Enterprise Support\nplan to use the Amazon Web Services Support API.\n\n   If you call the Amazon Web Services Support API from an account\nthat doesn't have a Business, Enterprise On-Ramp, or Enterprise Support plan,\nthe `SubscriptionRequiredException` error message appears. For information about\nchanging your support plan, see [Amazon Web Services Support](http://aws.amazon.com/premiumsupport/).","ref":"AWS.Support.html#describe_severity_levels/3","title":"AWS.Support.describe_severity_levels/3","type":"function"},{"doc":"Returns a list of supported languages for a specified `categoryCode`,\n`issueType` and `serviceCode`.\n\nThe returned supported languages will include a ISO 639-1 code for the\n`language`, and the language display name.\n\n   You must have a Business, Enterprise On-Ramp, or Enterprise Support\nplan to use the Amazon Web Services Support API.\n\n   If you call the Amazon Web Services Support API from an account\nthat doesn't have a Business, Enterprise On-Ramp, or Enterprise Support plan,\nthe `SubscriptionRequiredException` error message appears. For information about\nchanging your support plan, see [Amazon Web Services Support](http://aws.amazon.com/premiumsupport/).","ref":"AWS.Support.html#describe_supported_languages/3","title":"AWS.Support.describe_supported_languages/3","type":"function"},{"doc":"Returns the refresh status of the Trusted Advisor checks that have the specified\ncheck IDs.\n\nYou can get the check IDs by calling the `DescribeTrustedAdvisorChecks`\noperation.\n\nSome checks are refreshed automatically, and you can't return their refresh\nstatuses by using the `DescribeTrustedAdvisorCheckRefreshStatuses` operation. If\nyou call this operation for these checks, you might see an\n`InvalidParameterValue` error.\n\n   You must have a Business, Enterprise On-Ramp, or Enterprise Support\nplan to use the Amazon Web Services Support API.\n\n   If you call the Amazon Web Services Support API from an account\nthat doesn't have a Business, Enterprise On-Ramp, or Enterprise Support plan,\nthe `SubscriptionRequiredException` error message appears. For information about\nchanging your support plan, see [Amazon Web Services Support](http://aws.amazon.com/premiumsupport/).\n\nTo call the Trusted Advisor operations in the Amazon Web Services Support API,\nyou must use the US East (N. Virginia) endpoint. Currently, the US West (Oregon)\nand Europe (Ireland) endpoints don't support the Trusted Advisor operations. For\nmore information, see [About the Amazon Web Services Support API](https://docs.aws.amazon.com/awssupport/latest/user/about-support-api.html#endpoint)\nin the *Amazon Web Services Support User Guide*.","ref":"AWS.Support.html#describe_trusted_advisor_check_refresh_statuses/3","title":"AWS.Support.describe_trusted_advisor_check_refresh_statuses/3","type":"function"},{"doc":"Returns the results of the Trusted Advisor check that has the specified check\nID.\n\nYou can get the check IDs by calling the `DescribeTrustedAdvisorChecks`\noperation.\n\nThe response contains a `TrustedAdvisorCheckResult` object, which contains these\nthree objects:\n\n  * `TrustedAdvisorCategorySpecificSummary`\n\n  * `TrustedAdvisorResourceDetail`\n\n  * `TrustedAdvisorResourcesSummary`\n\nIn addition, the response contains these fields:\n\n  * **status** - The alert status of the check can be `ok` (green),\n`warning` (yellow), `error` (red), or `not_available`.\n\n  * **timestamp** - The time of the last refresh of the check.\n\n  * **checkId** - The unique identifier for the check.\n\n   You must have a Business, Enterprise On-Ramp, or Enterprise Support\nplan to use the Amazon Web Services Support API.\n\n   If you call the Amazon Web Services Support API from an account\nthat doesn't have a Business, Enterprise On-Ramp, or Enterprise Support plan,\nthe `SubscriptionRequiredException` error message appears. For information about\nchanging your support plan, see [Amazon Web Services Support](http://aws.amazon.com/premiumsupport/).\n\nTo call the Trusted Advisor operations in the Amazon Web Services Support API,\nyou must use the US East (N. Virginia) endpoint. Currently, the US West (Oregon)\nand Europe (Ireland) endpoints don't support the Trusted Advisor operations. For\nmore information, see [About the Amazon Web Services Support API](https://docs.aws.amazon.com/awssupport/latest/user/about-support-api.html#endpoint)\nin the *Amazon Web Services Support User Guide*.","ref":"AWS.Support.html#describe_trusted_advisor_check_result/3","title":"AWS.Support.describe_trusted_advisor_check_result/3","type":"function"},{"doc":"Returns the results for the Trusted Advisor check summaries for the check IDs\nthat you specified.\n\nYou can get the check IDs by calling the `DescribeTrustedAdvisorChecks`\noperation.\n\nThe response contains an array of `TrustedAdvisorCheckSummary` objects.\n\n   You must have a Business, Enterprise On-Ramp, or Enterprise Support\nplan to use the Amazon Web Services Support API.\n\n   If you call the Amazon Web Services Support API from an account\nthat doesn't have a Business, Enterprise On-Ramp, or Enterprise Support plan,\nthe `SubscriptionRequiredException` error message appears. For information about\nchanging your support plan, see [Amazon Web Services Support](http://aws.amazon.com/premiumsupport/).\n\nTo call the Trusted Advisor operations in the Amazon Web Services Support API,\nyou must use the US East (N. Virginia) endpoint. Currently, the US West (Oregon)\nand Europe (Ireland) endpoints don't support the Trusted Advisor operations. For\nmore information, see [About the Amazon Web Services Support API](https://docs.aws.amazon.com/awssupport/latest/user/about-support-api.html#endpoint)\nin the *Amazon Web Services Support User Guide*.","ref":"AWS.Support.html#describe_trusted_advisor_check_summaries/3","title":"AWS.Support.describe_trusted_advisor_check_summaries/3","type":"function"},{"doc":"Returns information about all available Trusted Advisor checks, including the\nname, ID, category, description, and metadata.\n\nYou must specify a language code.\n\nThe response contains a `TrustedAdvisorCheckDescription` object for each check.\nYou must set the Amazon Web Services Region to us-east-1.\n\n   You must have a Business, Enterprise On-Ramp, or Enterprise Support\nplan to use the Amazon Web Services Support API.\n\n   If you call the Amazon Web Services Support API from an account\nthat doesn't have a Business, Enterprise On-Ramp, or Enterprise Support plan,\nthe `SubscriptionRequiredException` error message appears. For information about\nchanging your support plan, see [Amazon Web Services Support](http://aws.amazon.com/premiumsupport/).\n\n   The names and descriptions for Trusted Advisor checks are subject\nto change. We recommend that you specify the check ID in your code to uniquely\nidentify a check.\n\nTo call the Trusted Advisor operations in the Amazon Web Services Support API,\nyou must use the US East (N. Virginia) endpoint. Currently, the US West (Oregon)\nand Europe (Ireland) endpoints don't support the Trusted Advisor operations. For\nmore information, see [About the Amazon Web Services Support API](https://docs.aws.amazon.com/awssupport/latest/user/about-support-api.html#endpoint)\nin the *Amazon Web Services Support User Guide*.","ref":"AWS.Support.html#describe_trusted_advisor_checks/3","title":"AWS.Support.describe_trusted_advisor_checks/3","type":"function"},{"doc":"","ref":"AWS.Support.html#metadata/0","title":"AWS.Support.metadata/0","type":"function"},{"doc":"Refreshes the Trusted Advisor check that you specify using the check ID.\n\nYou can get the check IDs by calling the `DescribeTrustedAdvisorChecks`\noperation.\n\nSome checks are refreshed automatically. If you call the\n`RefreshTrustedAdvisorCheck` operation to refresh them, you might see the\n`InvalidParameterValue` error.\n\nThe response contains a `TrustedAdvisorCheckRefreshStatus` object.\n\n   You must have a Business, Enterprise On-Ramp, or Enterprise Support\nplan to use the Amazon Web Services Support API.\n\n   If you call the Amazon Web Services Support API from an account\nthat doesn't have a Business, Enterprise On-Ramp, or Enterprise Support plan,\nthe `SubscriptionRequiredException` error message appears. For information about\nchanging your support plan, see [Amazon Web Services Support](http://aws.amazon.com/premiumsupport/).\n\nTo call the Trusted Advisor operations in the Amazon Web Services Support API,\nyou must use the US East (N. Virginia) endpoint. Currently, the US West (Oregon)\nand Europe (Ireland) endpoints don't support the Trusted Advisor operations. For\nmore information, see [About the Amazon Web Services Support API](https://docs.aws.amazon.com/awssupport/latest/user/about-support-api.html#endpoint)\nin the *Amazon Web Services Support User Guide*.","ref":"AWS.Support.html#refresh_trusted_advisor_check/3","title":"AWS.Support.refresh_trusted_advisor_check/3","type":"function"},{"doc":"Resolves a support case.\n\nThis operation takes a `caseId` and returns the initial and final state of the\ncase.\n\n   You must have a Business, Enterprise On-Ramp, or Enterprise Support\nplan to use the Amazon Web Services Support API.\n\n   If you call the Amazon Web Services Support API from an account\nthat doesn't have a Business, Enterprise On-Ramp, or Enterprise Support plan,\nthe `SubscriptionRequiredException` error message appears. For information about\nchanging your support plan, see [Amazon Web Services Support](http://aws.amazon.com/premiumsupport/).","ref":"AWS.Support.html#resolve_case/3","title":"AWS.Support.resolve_case/3","type":"function"},{"doc":"Amazon Web Services Support App in Slack\n\nYou can use the Amazon Web Services Support App in Slack API to manage your\nsupport cases in Slack for your Amazon Web Services account.\n\nAfter you configure your Slack workspace and channel with the Amazon Web\nServices Support App, you can perform the following tasks directly in your Slack\nchannel:\n\n  * Create, search, update, and resolve your support cases\n\n  * Request service quota increases for your account\n\n  * Invite Amazon Web Services Support agents to your channel so that\nyou can chat directly about your support cases\n\nFor more information about how to perform these actions in Slack, see the\nfollowing documentation in the *Amazon Web Services Support User Guide*:\n\n  * [Amazon Web Services Support App in Slack](https://docs.aws.amazon.com/awssupport/latest/user/aws-support-app-for-slack.html)\n\n  * [Joining a live chat session with Amazon Web Services Support](https://docs.aws.amazon.com/awssupport/latest/user/joining-a-live-chat-session.html)\n\n  * [Requesting service quota increases](https://docs.aws.amazon.com/awssupport/latest/user/service-quota-increase.html)\n\n  * [Amazon Web Services Support App commands in Slack](https://docs.aws.amazon.com/awssupport/latest/user/support-app-commands.html)\n\nYou can also use the Amazon Web Services Management Console instead of the\nAmazon Web Services Support App API to manage your Slack configurations. For\nmore information, see [Authorize a Slack workspace to enable the Amazon Web Services Support\nApp](https://docs.aws.amazon.com/awssupport/latest/user/authorize-slack-workspace.html).\n\n   You must have a Business or Enterprise Support plan to use the\nAmazon Web Services Support App API.\n\n   For more information about the Amazon Web Services Support App\nendpoints, see the [Amazon Web Services Support App in Slack endpoints](https://docs.aws.amazon.com/general/latest/gr/awssupport.html#awssupport_app_region)\nin the *Amazon Web Services General Reference*.","ref":"AWS.SupportApp.html","title":"AWS.SupportApp","type":"module"},{"doc":"Creates a Slack channel configuration for your Amazon Web Services account.\n\n   You can add up to 5 Slack workspaces for your account.\n\n   You can add up to 20 Slack channels for your account.\n\nA Slack channel can have up to 100 Amazon Web Services accounts. This means that\nonly 100 accounts can add the same Slack channel to the Amazon Web Services\nSupport App. We recommend that you only add the accounts that you need to manage\nsupport cases for your organization. This can reduce the notifications about\ncase updates that you receive in the Slack channel.\n\nWe recommend that you choose a private Slack channel so that only members in\nthat channel have read and write access to your support cases. Anyone in your\nSlack channel can create, update, or resolve support cases for your account.\nUsers require an invitation to join private channels.","ref":"AWS.SupportApp.html#create_slack_channel_configuration/3","title":"AWS.SupportApp.create_slack_channel_configuration/3","type":"function"},{"doc":"Deletes an alias for an Amazon Web Services account ID.\n\nThe alias appears in the Amazon Web Services Support App page of the Amazon Web\nServices Support Center. The alias also appears in Slack messages from the\nAmazon Web Services Support App.","ref":"AWS.SupportApp.html#delete_account_alias/3","title":"AWS.SupportApp.delete_account_alias/3","type":"function"},{"doc":"Deletes a Slack channel configuration from your Amazon Web Services account.\n\nThis operation doesn't delete your Slack channel.","ref":"AWS.SupportApp.html#delete_slack_channel_configuration/3","title":"AWS.SupportApp.delete_slack_channel_configuration/3","type":"function"},{"doc":"Deletes a Slack workspace configuration from your Amazon Web Services account.\n\nThis operation doesn't delete your Slack workspace.","ref":"AWS.SupportApp.html#delete_slack_workspace_configuration/3","title":"AWS.SupportApp.delete_slack_workspace_configuration/3","type":"function"},{"doc":"Retrieves the alias from an Amazon Web Services account ID.\n\nThe alias appears in the Amazon Web Services Support App page of the Amazon Web\nServices Support Center. The alias also appears in Slack messages from the\nAmazon Web Services Support App.","ref":"AWS.SupportApp.html#get_account_alias/3","title":"AWS.SupportApp.get_account_alias/3","type":"function"},{"doc":"Lists the Slack channel configurations for an Amazon Web Services account.","ref":"AWS.SupportApp.html#list_slack_channel_configurations/3","title":"AWS.SupportApp.list_slack_channel_configurations/3","type":"function"},{"doc":"Lists the Slack workspace configurations for an Amazon Web Services account.","ref":"AWS.SupportApp.html#list_slack_workspace_configurations/3","title":"AWS.SupportApp.list_slack_workspace_configurations/3","type":"function"},{"doc":"","ref":"AWS.SupportApp.html#metadata/0","title":"AWS.SupportApp.metadata/0","type":"function"},{"doc":"Creates or updates an individual alias for each Amazon Web Services account ID.\n\nThe alias appears in the Amazon Web Services Support App page of the Amazon Web\nServices Support Center. The alias also appears in Slack messages from the\nAmazon Web Services Support App.","ref":"AWS.SupportApp.html#put_account_alias/3","title":"AWS.SupportApp.put_account_alias/3","type":"function"},{"doc":"Registers a Slack workspace for your Amazon Web Services account.\n\nTo call this API, your account must be part of an organization in Organizations.\n\nIf you're the *management account* and you want to register Slack workspaces for\nyour organization, you must complete the following tasks:\n\n  1. Sign in to the [Amazon Web Services Support Center](https://console.aws.amazon.com/support/app) and authorize the Slack\nworkspaces where you want your organization to have access to. See [Authorize a Slack\nworkspace](https://docs.aws.amazon.com/awssupport/latest/user/authorize-slack-workspace.html)\nin the *Amazon Web Services Support User Guide*.\n\n  2. Call the `RegisterSlackWorkspaceForOrganization` API to authorize\neach Slack workspace for the organization.\n\nAfter the management account authorizes the Slack workspace, member accounts can\ncall this API to authorize the same Slack workspace for their individual\naccounts. Member accounts don't need to authorize the Slack workspace manually\nthrough the [Amazon Web Services Support Center](https://console.aws.amazon.com/support/app).\n\nTo use the Amazon Web Services Support App, each account must then complete the\nfollowing tasks:\n\n  * Create an Identity and Access Management (IAM) role with the\nrequired permission. For more information, see [Managing access to the Amazon Web Services Support\nApp](https://docs.aws.amazon.com/awssupport/latest/user/support-app-permissions.html).\n\n  * Configure a Slack channel to use the Amazon Web Services Support\nApp for support cases for that account. For more information, see [Configuring a Slack\nchannel](https://docs.aws.amazon.com/awssupport/latest/user/add-your-slack-channel.html).","ref":"AWS.SupportApp.html#register_slack_workspace_for_organization/3","title":"AWS.SupportApp.register_slack_workspace_for_organization/3","type":"function"},{"doc":"Updates the configuration for a Slack channel, such as case update\nnotifications.","ref":"AWS.SupportApp.html#update_slack_channel_configuration/3","title":"AWS.SupportApp.update_slack_channel_configuration/3","type":"function"},{"doc":"Amazon CloudWatch Synthetics\n\nYou can use Amazon CloudWatch Synthetics to continually monitor your services.\n\nYou can create and manage *canaries*, which are modular, lightweight scripts\nthat monitor your endpoints and APIs from the outside-in. You can set up your\ncanaries to run 24 hours a day, once per minute. The canaries help you check the\navailability and latency of your web services and troubleshoot anomalies by\ninvestigating load time data, screenshots of the UI, logs, and metrics. The\ncanaries seamlessly integrate with CloudWatch ServiceLens to help you trace the\ncauses of impacted nodes in your applications. For more information, see [Using ServiceLens to Monitor the Health of Your\nApplications](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/ServiceLens.html)\nin the *Amazon CloudWatch User Guide*.\n\nBefore you create and manage canaries, be aware of the security considerations.\nFor more information, see [Security Considerations for Synthetics Canaries](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/servicelens_canaries_security.html).","ref":"AWS.Synthetics.html","title":"AWS.Synthetics","type":"module"},{"doc":"Associates a canary with a group.\n\nUsing groups can help you with managing and automating your canaries, and you\ncan also view aggregated run results and statistics for all canaries in a group.\n\nYou must run this operation in the Region where the canary exists.","ref":"AWS.Synthetics.html#associate_resource/4","title":"AWS.Synthetics.associate_resource/4","type":"function"},{"doc":"Creates a canary.\n\nCanaries are scripts that monitor your endpoints and APIs from the outside-in.\nCanaries help you check the availability and latency of your web services and\ntroubleshoot anomalies by investigating load time data, screenshots of the UI,\nlogs, and metrics. You can set up a canary to run continuously or just once.\n\nDo not use `CreateCanary` to modify an existing canary. Use\n[UpdateCanary](https://docs.aws.amazon.com/AmazonSynthetics/latest/APIReference/API_UpdateCanary.html) instead.\n\nTo create canaries, you must have the `CloudWatchSyntheticsFullAccess` policy.\nIf you are creating a new IAM role for the canary, you also need the\n`iam:CreateRole`, `iam:CreatePolicy` and `iam:AttachRolePolicy` permissions. For\nmore information, see [Necessary Roles and\nPermissions](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch_Synthetics_Canaries_Roles).\n\nDo not include secrets or proprietary information in your canary names. The\ncanary name makes up part of the Amazon Resource Name (ARN) for the canary, and\nthe ARN is included in outbound calls over the internet. For more information,\nsee [Security Considerations for Synthetics Canaries](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/servicelens_canaries_security.html).","ref":"AWS.Synthetics.html#create_canary/3","title":"AWS.Synthetics.create_canary/3","type":"function"},{"doc":"Creates a group which you can use to associate canaries with each other,\nincluding cross-Region canaries.\n\nUsing groups can help you with managing and automating your canaries, and you\ncan also view aggregated run results and statistics for all canaries in a group.\n\nGroups are global resources. When you create a group, it is replicated across\nAmazon Web Services Regions, and you can view it and add canaries to it from any\nRegion. Although the group ARN format reflects the Region name where it was\ncreated, a group is not constrained to any Region. This means that you can put\ncanaries from multiple Regions into the same group, and then use that group to\nview and manage all of those canaries in a single view.\n\nGroups are supported in all Regions except the Regions that are disabled by\ndefault. For more information about these Regions, see [Enabling a Region](https://docs.aws.amazon.com/general/latest/gr/rande-manage.html#rande-manage-enable).\n\nEach group can contain as many as 10 canaries. You can have as many as 20 groups\nin your account. Any single canary can be a member of up to 10 groups.","ref":"AWS.Synthetics.html#create_group/3","title":"AWS.Synthetics.create_group/3","type":"function"},{"doc":"Permanently deletes the specified canary.\n\nIf you specify `DeleteLambda` to `true`, CloudWatch Synthetics also deletes the\nLambda functions and layers that are used by the canary.\n\nOther resources used and created by the canary are not automatically deleted.\nAfter you delete a canary that you do not intend to use again, you should also\ndelete the following:\n\n  * The CloudWatch alarms created for this canary. These alarms have a\nname of `Synthetics-SharpDrop-Alarm-*MyCanaryName* `.\n\n  * Amazon S3 objects and buckets, such as the canary's artifact\nlocation.\n\n  * IAM roles created for the canary. If they were created in the\nconsole, these roles have the name `\nrole/service-role/CloudWatchSyntheticsRole-*MyCanaryName* `.\n\n  * CloudWatch Logs log groups created for the canary. These logs\ngroups have the name `/aws/lambda/cwsyn-*MyCanaryName* `.\n\nBefore you delete a canary, you might want to use `GetCanary` to display the\ninformation about this canary. Make note of the information returned by this\noperation so that you can delete these resources after you delete the canary.","ref":"AWS.Synthetics.html#delete_canary/4","title":"AWS.Synthetics.delete_canary/4","type":"function"},{"doc":"Deletes a group.\n\nThe group doesn't need to be empty to be deleted. If there are canaries in the\ngroup, they are not deleted when you delete the group.\n\nGroups are a global resource that appear in all Regions, but the request to\ndelete a group must be made from its home Region. You can find the home Region\nof a group within its ARN.","ref":"AWS.Synthetics.html#delete_group/4","title":"AWS.Synthetics.delete_group/4","type":"function"},{"doc":"This operation returns a list of the canaries in your account, along with full\ndetails about each canary.\n\nThis operation supports resource-level authorization using an IAM policy and the\n`Names` parameter. If you specify the `Names` parameter, the operation is\nsuccessful only if you have authorization to view all the canaries that you\nspecify in your request. If you do not have permission to view any of the\ncanaries, the request fails with a 403 response.\n\nYou are required to use the `Names` parameter if you are logged on to a user or\nrole that has an IAM policy that restricts which canaries that you are allowed\nto view. For more information, see [ Limiting a user to viewing specific canaries](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch_Synthetics_Canaries_Restricted.html).","ref":"AWS.Synthetics.html#describe_canaries/3","title":"AWS.Synthetics.describe_canaries/3","type":"function"},{"doc":"Use this operation to see information from the most recent run of each canary\nthat you have created.\n\nThis operation supports resource-level authorization using an IAM policy and the\n`Names` parameter. If you specify the `Names` parameter, the operation is\nsuccessful only if you have authorization to view all the canaries that you\nspecify in your request. If you do not have permission to view any of the\ncanaries, the request fails with a 403 response.\n\nYou are required to use the `Names` parameter if you are logged on to a user or\nrole that has an IAM policy that restricts which canaries that you are allowed\nto view. For more information, see [ Limiting a user to viewing specific canaries](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch_Synthetics_Canaries_Restricted.html).","ref":"AWS.Synthetics.html#describe_canaries_last_run/3","title":"AWS.Synthetics.describe_canaries_last_run/3","type":"function"},{"doc":"Returns a list of Synthetics canary runtime versions.\n\nFor more information, see [ Canary Runtime Versions](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch_Synthetics_Canaries_Library.html).","ref":"AWS.Synthetics.html#describe_runtime_versions/3","title":"AWS.Synthetics.describe_runtime_versions/3","type":"function"},{"doc":"Removes a canary from a group.\n\nYou must run this operation in the Region where the canary exists.","ref":"AWS.Synthetics.html#disassociate_resource/4","title":"AWS.Synthetics.disassociate_resource/4","type":"function"},{"doc":"Retrieves complete information about one canary.\n\nYou must specify the name of the canary that you want. To get a list of canaries\nand their names, use\n[DescribeCanaries](https://docs.aws.amazon.com/AmazonSynthetics/latest/APIReference/API_DescribeCanaries.html).","ref":"AWS.Synthetics.html#get_canary/3","title":"AWS.Synthetics.get_canary/3","type":"function"},{"doc":"Retrieves a list of runs for a specified canary.","ref":"AWS.Synthetics.html#get_canary_runs/4","title":"AWS.Synthetics.get_canary_runs/4","type":"function"},{"doc":"Returns information about one group.\n\nGroups are a global resource, so you can use this operation from any Region.","ref":"AWS.Synthetics.html#get_group/3","title":"AWS.Synthetics.get_group/3","type":"function"},{"doc":"Returns a list of the groups that the specified canary is associated with.\n\nThe canary that you specify must be in the current Region.","ref":"AWS.Synthetics.html#list_associated_groups/4","title":"AWS.Synthetics.list_associated_groups/4","type":"function"},{"doc":"This operation returns a list of the ARNs of the canaries that are associated\nwith the specified group.","ref":"AWS.Synthetics.html#list_group_resources/4","title":"AWS.Synthetics.list_group_resources/4","type":"function"},{"doc":"Returns a list of all groups in the account, displaying their names, unique IDs,\nand ARNs.\n\nThe groups from all Regions are returned.","ref":"AWS.Synthetics.html#list_groups/3","title":"AWS.Synthetics.list_groups/3","type":"function"},{"doc":"Displays the tags associated with a canary or group.","ref":"AWS.Synthetics.html#list_tags_for_resource/3","title":"AWS.Synthetics.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.Synthetics.html#metadata/0","title":"AWS.Synthetics.metadata/0","type":"function"},{"doc":"Use this operation to run a canary that has already been created.\n\nThe frequency of the canary runs is determined by the value of the canary's\n`Schedule`. To see a canary's schedule, use\n[GetCanary](https://docs.aws.amazon.com/AmazonSynthetics/latest/APIReference/API_GetCanary.html).","ref":"AWS.Synthetics.html#start_canary/4","title":"AWS.Synthetics.start_canary/4","type":"function"},{"doc":"Stops the canary to prevent all future runs.\n\nIf the canary is currently running,the run that is in progress completes on its\nown, publishes metrics, and uploads artifacts, but it is not recorded in\nSynthetics as a completed run.\n\nYou can use `StartCanary` to start it running again with the canary’s current\nschedule at any point in the future.","ref":"AWS.Synthetics.html#stop_canary/4","title":"AWS.Synthetics.stop_canary/4","type":"function"},{"doc":"Assigns one or more tags (key-value pairs) to the specified canary or group.\n\nTags can help you organize and categorize your resources. You can also use them\nto scope user permissions, by granting a user permission to access or change\nonly resources with certain tag values.\n\nTags don't have any semantic meaning to Amazon Web Services and are interpreted\nstrictly as strings of characters.\n\nYou can use the `TagResource` action with a resource that already has tags. If\nyou specify a new tag key for the resource, this tag is appended to the list of\ntags associated with the resource. If you specify a tag key that is already\nassociated with the resource, the new tag value that you specify replaces the\nprevious value for that tag.\n\nYou can associate as many as 50 tags with a canary or group.","ref":"AWS.Synthetics.html#tag_resource/4","title":"AWS.Synthetics.tag_resource/4","type":"function"},{"doc":"Removes one or more tags from the specified resource.","ref":"AWS.Synthetics.html#untag_resource/4","title":"AWS.Synthetics.untag_resource/4","type":"function"},{"doc":"Updates the configuration of a canary that has already been created.\n\nYou can't use this operation to update the tags of an existing canary. To change\nthe tags of an existing canary, use\n[TagResource](https://docs.aws.amazon.com/AmazonSynthetics/latest/APIReference/API_TagResource.html).","ref":"AWS.Synthetics.html#update_canary/4","title":"AWS.Synthetics.update_canary/4","type":"function"},{"doc":"Amazon Textract detects and analyzes text in documents and converts it into\nmachine-readable text.\n\nThis is the API reference documentation for Amazon Textract.","ref":"AWS.Textract.html","title":"AWS.Textract","type":"module"},{"doc":"Analyzes an input document for relationships between detected items.\n\nThe types of information returned are as follows:\n\n  * Form data (key-value pairs). The related information is returned\nin two `Block` objects, each of type `KEY_VALUE_SET`: a KEY `Block` object and a\nVALUE `Block` object. For example, *Name: Ana Silva Carolina* contains a key and\nvalue. *Name:* is the key. *Ana Silva Carolina* is the value.\n\n  * Table and table cell data. A TABLE `Block` object contains\ninformation about a detected table. A CELL `Block` object is returned for each\ncell in a table.\n\n  * Lines and words of text. A LINE `Block` object contains one or\nmore WORD `Block` objects. All lines and words that are detected in the document\nare returned (including text that doesn't have a relationship with the value of\n`FeatureTypes`).\n\n  * Signatures. A SIGNATURE `Block` object contains the location\ninformation of a signature in a document. If used in conjunction with forms or\ntables, a signature can be given a Key-Value pairing or be detected in the cell\nof a table.\n\n  * Query. A QUERY Block object contains the query text, alias and\nlink to the associated Query results block object.\n\n  * Query Result. A QUERY_RESULT Block object contains the answer to\nthe query and an ID that connects it to the query asked. This Block also\ncontains a confidence score.\n\nSelection elements such as check boxes and option buttons (radio buttons) can be\ndetected in form data and in tables. A SELECTION_ELEMENT `Block` object contains\ninformation about a selection element, including the selection status.\n\nYou can choose which type of analysis to perform by specifying the\n`FeatureTypes` list.\n\nThe output is returned in a list of `Block` objects.\n\n`AnalyzeDocument` is a synchronous operation. To analyze documents\nasynchronously, use `StartDocumentAnalysis`.\n\nFor more information, see [Document Text Analysis](https://docs.aws.amazon.com/textract/latest/dg/how-it-works-analyzing.html).","ref":"AWS.Textract.html#analyze_document/3","title":"AWS.Textract.analyze_document/3","type":"function"},{"doc":"`AnalyzeExpense` synchronously analyzes an input document for financially\nrelated relationships between text.\n\nInformation is returned as `ExpenseDocuments` and seperated as follows:\n\n  * `LineItemGroups`- A data set containing `LineItems` which store\ninformation about the lines of text, such as an item purchased and its price on\na receipt.\n\n  * `SummaryFields`- Contains all other information a receipt, such as\nheader information or the vendors name.","ref":"AWS.Textract.html#analyze_expense/3","title":"AWS.Textract.analyze_expense/3","type":"function"},{"doc":"Analyzes identity documents for relevant information.\n\nThis information is extracted and returned as `IdentityDocumentFields`, which\nrecords both the normalized field and value of the extracted text. Unlike other\nAmazon Textract operations, `AnalyzeID` doesn't return any Geometry data.","ref":"AWS.Textract.html#analyze_id/3","title":"AWS.Textract.analyze_id/3","type":"function"},{"doc":"Creates an adapter, which can be fine-tuned for enhanced performance on user\nprovided documents.\n\nTakes an AdapterName and FeatureType. Currently the only supported feature type\nis `QUERIES`. You can also provide a Description, Tags, and a\nClientRequestToken. You can choose whether or not the adapter should be\nAutoUpdated with the AutoUpdate argument. By default, AutoUpdate is set to\nDISABLED.","ref":"AWS.Textract.html#create_adapter/3","title":"AWS.Textract.create_adapter/3","type":"function"},{"doc":"Creates a new version of an adapter.\n\nOperates on a provided AdapterId and a specified dataset provided via the\nDatasetConfig argument. Requires that you specify an Amazon S3 bucket with the\nOutputConfig argument. You can provide an optional KMSKeyId, an optional\nClientRequestToken, and optional tags.","ref":"AWS.Textract.html#create_adapter_version/3","title":"AWS.Textract.create_adapter_version/3","type":"function"},{"doc":"Deletes an Amazon Textract adapter.\n\nTakes an AdapterId and deletes the adapter specified by the ID.","ref":"AWS.Textract.html#delete_adapter/3","title":"AWS.Textract.delete_adapter/3","type":"function"},{"doc":"Deletes an Amazon Textract adapter version.\n\nRequires that you specify both an AdapterId and a AdapterVersion. Deletes the\nadapter version specified by the AdapterId and the AdapterVersion.","ref":"AWS.Textract.html#delete_adapter_version/3","title":"AWS.Textract.delete_adapter_version/3","type":"function"},{"doc":"Detects text in the input document.\n\nAmazon Textract can detect lines of text and the words that make up a line of\ntext. The input document must be in one of the following image formats: JPEG,\nPNG, PDF, or TIFF. `DetectDocumentText` returns the detected text in an array of\n`Block` objects.\n\nEach document page has as an associated `Block` of type PAGE. Each PAGE `Block`\nobject is the parent of LINE `Block` objects that represent the lines of\ndetected text on a page. A LINE `Block` object is a parent for each word that\nmakes up the line. Words are represented by `Block` objects of type WORD.\n\n`DetectDocumentText` is a synchronous operation. To analyze documents\nasynchronously, use `StartDocumentTextDetection`.\n\nFor more information, see [Document Text Detection](https://docs.aws.amazon.com/textract/latest/dg/how-it-works-detecting.html).","ref":"AWS.Textract.html#detect_document_text/3","title":"AWS.Textract.detect_document_text/3","type":"function"},{"doc":"Gets configuration information for an adapter specified by an AdapterId,\nreturning information on AdapterName, Description, CreationTime, AutoUpdate\nstatus, and FeatureTypes.","ref":"AWS.Textract.html#get_adapter/3","title":"AWS.Textract.get_adapter/3","type":"function"},{"doc":"Gets configuration information for the specified adapter version, including:\nAdapterId, AdapterVersion, FeatureTypes, Status, StatusMessage, DatasetConfig,\nKMSKeyId, OutputConfig, Tags and EvaluationMetrics.","ref":"AWS.Textract.html#get_adapter_version/3","title":"AWS.Textract.get_adapter_version/3","type":"function"},{"doc":"Gets the results for an Amazon Textract asynchronous operation that analyzes\ntext in a document.\n\nYou start asynchronous text analysis by calling `StartDocumentAnalysis`, which\nreturns a job identifier (`JobId`). When the text analysis operation finishes,\nAmazon Textract publishes a completion status to the Amazon Simple Notification\nService (Amazon SNS) topic that's registered in the initial call to\n`StartDocumentAnalysis`. To get the results of the text-detection operation,\nfirst check that the status value published to the Amazon SNS topic is\n`SUCCEEDED`. If so, call `GetDocumentAnalysis`, and pass the job identifier\n(`JobId`) from the initial call to `StartDocumentAnalysis`.\n\n`GetDocumentAnalysis` returns an array of `Block` objects. The following types\nof information are returned:\n\n  * Form data (key-value pairs). The related information is returned\nin two `Block` objects, each of type `KEY_VALUE_SET`: a KEY `Block` object and a\nVALUE `Block` object. For example, *Name: Ana Silva Carolina* contains a key and\nvalue. *Name:* is the key. *Ana Silva Carolina* is the value.\n\n  * Table and table cell data. A TABLE `Block` object contains\ninformation about a detected table. A CELL `Block` object is returned for each\ncell in a table.\n\n  * Lines and words of text. A LINE `Block` object contains one or\nmore WORD `Block` objects. All lines and words that are detected in the document\nare returned (including text that doesn't have a relationship with the value of\nthe `StartDocumentAnalysis` `FeatureTypes` input parameter).\n\n  * Query. A QUERY Block object contains the query text, alias and\nlink to the associated Query results block object.\n\n  * Query Results. A QUERY_RESULT Block object contains the answer to\nthe query and an ID that connects it to the query asked. This Block also\ncontains a confidence score.\n\nWhile processing a document with queries, look out for\n`INVALID_REQUEST_PARAMETERS` output. This indicates that either the per page\nquery limit has been exceeded or that the operation is trying to query a page in\nthe document which doesn’t exist.\n\nSelection elements such as check boxes and option buttons (radio buttons) can be\ndetected in form data and in tables. A SELECTION_ELEMENT `Block` object contains\ninformation about a selection element, including the selection status.\n\nUse the `MaxResults` parameter to limit the number of blocks that are returned.\nIf there are more results than specified in `MaxResults`, the value of\n`NextToken` in the operation response contains a pagination token for getting\nthe next set of results. To get the next page of results, call\n`GetDocumentAnalysis`, and populate the `NextToken` request parameter with the\ntoken value that's returned from the previous call to `GetDocumentAnalysis`.\n\nFor more information, see [Document Text Analysis](https://docs.aws.amazon.com/textract/latest/dg/how-it-works-analyzing.html).","ref":"AWS.Textract.html#get_document_analysis/3","title":"AWS.Textract.get_document_analysis/3","type":"function"},{"doc":"Gets the results for an Amazon Textract asynchronous operation that detects text\nin a document.\n\nAmazon Textract can detect lines of text and the words that make up a line of\ntext.\n\nYou start asynchronous text detection by calling `StartDocumentTextDetection`,\nwhich returns a job identifier (`JobId`). When the text detection operation\nfinishes, Amazon Textract publishes a completion status to the Amazon Simple\nNotification Service (Amazon SNS) topic that's registered in the initial call to\n`StartDocumentTextDetection`. To get the results of the text-detection\noperation, first check that the status value published to the Amazon SNS topic\nis `SUCCEEDED`. If so, call `GetDocumentTextDetection`, and pass the job\nidentifier (`JobId`) from the initial call to `StartDocumentTextDetection`.\n\n`GetDocumentTextDetection` returns an array of `Block` objects.\n\nEach document page has as an associated `Block` of type PAGE. Each PAGE `Block`\nobject is the parent of LINE `Block` objects that represent the lines of\ndetected text on a page. A LINE `Block` object is a parent for each word that\nmakes up the line. Words are represented by `Block` objects of type WORD.\n\nUse the MaxResults parameter to limit the number of blocks that are returned. If\nthere are more results than specified in `MaxResults`, the value of `NextToken`\nin the operation response contains a pagination token for getting the next set\nof results. To get the next page of results, call `GetDocumentTextDetection`,\nand populate the `NextToken` request parameter with the token value that's\nreturned from the previous call to `GetDocumentTextDetection`.\n\nFor more information, see [Document Text Detection](https://docs.aws.amazon.com/textract/latest/dg/how-it-works-detecting.html).","ref":"AWS.Textract.html#get_document_text_detection/3","title":"AWS.Textract.get_document_text_detection/3","type":"function"},{"doc":"Gets the results for an Amazon Textract asynchronous operation that analyzes\ninvoices and receipts.\n\nAmazon Textract finds contact information, items purchased, and vendor name,\nfrom input invoices and receipts.\n\nYou start asynchronous invoice/receipt analysis by calling\n`StartExpenseAnalysis`, which returns a job identifier (`JobId`). Upon\ncompletion of the invoice/receipt analysis, Amazon Textract publishes the\ncompletion status to the Amazon Simple Notification Service (Amazon SNS) topic.\nThis topic must be registered in the initial call to `StartExpenseAnalysis`. To\nget the results of the invoice/receipt analysis operation, first ensure that the\nstatus value published to the Amazon SNS topic is `SUCCEEDED`. If so, call\n`GetExpenseAnalysis`, and pass the job identifier (`JobId`) from the initial\ncall to `StartExpenseAnalysis`.\n\nUse the MaxResults parameter to limit the number of blocks that are returned. If\nthere are more results than specified in `MaxResults`, the value of `NextToken`\nin the operation response contains a pagination token for getting the next set\nof results. To get the next page of results, call `GetExpenseAnalysis`, and\npopulate the `NextToken` request parameter with the token value that's returned\nfrom the previous call to `GetExpenseAnalysis`.\n\nFor more information, see [Analyzing Invoices and Receipts](https://docs.aws.amazon.com/textract/latest/dg/invoices-receipts.html).","ref":"AWS.Textract.html#get_expense_analysis/3","title":"AWS.Textract.get_expense_analysis/3","type":"function"},{"doc":"Gets the results for an Amazon Textract asynchronous operation that analyzes\ntext in a lending document.\n\nYou start asynchronous text analysis by calling `StartLendingAnalysis`, which\nreturns a job identifier (`JobId`). When the text analysis operation finishes,\nAmazon Textract publishes a completion status to the Amazon Simple Notification\nService (Amazon SNS) topic that's registered in the initial call to\n`StartLendingAnalysis`.\n\nTo get the results of the text analysis operation, first check that the status\nvalue published to the Amazon SNS topic is SUCCEEDED. If so, call\nGetLendingAnalysis, and pass the job identifier (`JobId`) from the initial call\nto `StartLendingAnalysis`.","ref":"AWS.Textract.html#get_lending_analysis/3","title":"AWS.Textract.get_lending_analysis/3","type":"function"},{"doc":"Gets summarized results for the `StartLendingAnalysis` operation, which analyzes\ntext in a lending document.\n\nThe returned summary consists of information about documents grouped together by\na common document type. Information like detected signatures, page numbers, and\nsplit documents is returned with respect to the type of grouped document.\n\nYou start asynchronous text analysis by calling `StartLendingAnalysis`, which\nreturns a job identifier (`JobId`). When the text analysis operation finishes,\nAmazon Textract publishes a completion status to the Amazon Simple Notification\nService (Amazon SNS) topic that's registered in the initial call to\n`StartLendingAnalysis`.\n\nTo get the results of the text analysis operation, first check that the status\nvalue published to the Amazon SNS topic is SUCCEEDED. If so, call\n`GetLendingAnalysisSummary`, and pass the job identifier (`JobId`) from the\ninitial call to `StartLendingAnalysis`.","ref":"AWS.Textract.html#get_lending_analysis_summary/3","title":"AWS.Textract.get_lending_analysis_summary/3","type":"function"},{"doc":"List all version of an adapter that meet the specified filtration criteria.","ref":"AWS.Textract.html#list_adapter_versions/3","title":"AWS.Textract.list_adapter_versions/3","type":"function"},{"doc":"Lists all adapters that match the specified filtration criteria.","ref":"AWS.Textract.html#list_adapters/3","title":"AWS.Textract.list_adapters/3","type":"function"},{"doc":"Lists all tags for an Amazon Textract resource.","ref":"AWS.Textract.html#list_tags_for_resource/3","title":"AWS.Textract.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.Textract.html#metadata/0","title":"AWS.Textract.metadata/0","type":"function"},{"doc":"Starts the asynchronous analysis of an input document for relationships between\ndetected items such as key-value pairs, tables, and selection elements.\n\n`StartDocumentAnalysis` can analyze text in documents that are in JPEG, PNG,\nTIFF, and PDF format. The documents are stored in an Amazon S3 bucket. Use\n`DocumentLocation` to specify the bucket name and file name of the document.\n\n`StartDocumentAnalysis` returns a job identifier (`JobId`) that you use to get\nthe results of the operation. When text analysis is finished, Amazon Textract\npublishes a completion status to the Amazon Simple Notification Service (Amazon\nSNS) topic that you specify in `NotificationChannel`. To get the results of the\ntext analysis operation, first check that the status value published to the\nAmazon SNS topic is `SUCCEEDED`. If so, call `GetDocumentAnalysis`, and pass the\njob identifier (`JobId`) from the initial call to `StartDocumentAnalysis`.\n\nFor more information, see [Document Text Analysis](https://docs.aws.amazon.com/textract/latest/dg/how-it-works-analyzing.html).","ref":"AWS.Textract.html#start_document_analysis/3","title":"AWS.Textract.start_document_analysis/3","type":"function"},{"doc":"Starts the asynchronous detection of text in a document.\n\nAmazon Textract can detect lines of text and the words that make up a line of\ntext.\n\n`StartDocumentTextDetection` can analyze text in documents that are in JPEG,\nPNG, TIFF, and PDF format. The documents are stored in an Amazon S3 bucket. Use\n`DocumentLocation` to specify the bucket name and file name of the document.\n\n`StartTextDetection` returns a job identifier (`JobId`) that you use to get the\nresults of the operation. When text detection is finished, Amazon Textract\npublishes a completion status to the Amazon Simple Notification Service (Amazon\nSNS) topic that you specify in `NotificationChannel`. To get the results of the\ntext detection operation, first check that the status value published to the\nAmazon SNS topic is `SUCCEEDED`. If so, call `GetDocumentTextDetection`, and\npass the job identifier (`JobId`) from the initial call to\n`StartDocumentTextDetection`.\n\nFor more information, see [Document Text Detection](https://docs.aws.amazon.com/textract/latest/dg/how-it-works-detecting.html).","ref":"AWS.Textract.html#start_document_text_detection/3","title":"AWS.Textract.start_document_text_detection/3","type":"function"},{"doc":"Starts the asynchronous analysis of invoices or receipts for data like contact\ninformation, items purchased, and vendor names.\n\n`StartExpenseAnalysis` can analyze text in documents that are in JPEG, PNG, and\nPDF format. The documents must be stored in an Amazon S3 bucket. Use the\n`DocumentLocation` parameter to specify the name of your S3 bucket and the name\nof the document in that bucket.\n\n`StartExpenseAnalysis` returns a job identifier (`JobId`) that you will provide\nto `GetExpenseAnalysis` to retrieve the results of the operation. When the\nanalysis of the input invoices/receipts is finished, Amazon Textract publishes a\ncompletion status to the Amazon Simple Notification Service (Amazon SNS) topic\nthat you provide to the `NotificationChannel`. To obtain the results of the\ninvoice and receipt analysis operation, ensure that the status value published\nto the Amazon SNS topic is `SUCCEEDED`. If so, call `GetExpenseAnalysis`, and\npass the job identifier (`JobId`) that was returned by your call to\n`StartExpenseAnalysis`.\n\nFor more information, see [Analyzing Invoices and Receipts](https://docs.aws.amazon.com/textract/latest/dg/invoice-receipts.html).","ref":"AWS.Textract.html#start_expense_analysis/3","title":"AWS.Textract.start_expense_analysis/3","type":"function"},{"doc":"Starts the classification and analysis of an input document.\n\n`StartLendingAnalysis` initiates the classification and analysis of a packet of\nlending documents. `StartLendingAnalysis` operates on a document file located in\nan Amazon S3 bucket.\n\n`StartLendingAnalysis` can analyze text in documents that are in one of the\nfollowing formats: JPEG, PNG, TIFF, PDF. Use `DocumentLocation` to specify the\nbucket name and the file name of the document.\n\n`StartLendingAnalysis` returns a job identifier (`JobId`) that you use to get\nthe results of the operation. When the text analysis is finished, Amazon\nTextract publishes a completion status to the Amazon Simple Notification Service\n(Amazon SNS) topic that you specify in `NotificationChannel`. To get the results\nof the text analysis operation, first check that the status value published to\nthe Amazon SNS topic is SUCCEEDED. If the status is SUCCEEDED you can call\neither `GetLendingAnalysis` or `GetLendingAnalysisSummary` and provide the\n`JobId` to obtain the results of the analysis.\n\nIf using `OutputConfig` to specify an Amazon S3 bucket, the output will be\ncontained within the specified prefix in a directory labeled with the job-id. In\nthe directory there are 3 sub-directories:\n\n  * detailedResponse (contains the GetLendingAnalysis response)\n\n  * summaryResponse (for the GetLendingAnalysisSummary response)\n\n  * splitDocuments (documents split across logical boundaries)","ref":"AWS.Textract.html#start_lending_analysis/3","title":"AWS.Textract.start_lending_analysis/3","type":"function"},{"doc":"Adds one or more tags to the specified resource.","ref":"AWS.Textract.html#tag_resource/3","title":"AWS.Textract.tag_resource/3","type":"function"},{"doc":"Removes any tags with the specified keys from the specified resource.","ref":"AWS.Textract.html#untag_resource/3","title":"AWS.Textract.untag_resource/3","type":"function"},{"doc":"Update the configuration for an adapter.\n\nFeatureTypes configurations cannot be updated. At least one new parameter must\nbe specified as an argument.","ref":"AWS.Textract.html#update_adapter/3","title":"AWS.Textract.update_adapter/3","type":"function"},{"doc":"Amazon Timestream Query","ref":"AWS.TimestreamQuery.html","title":"AWS.TimestreamQuery","type":"module"},{"doc":"Cancels a query that has been issued.\n\nCancellation is provided only if the query has not completed running before the\ncancellation request was issued. Because cancellation is an idempotent\noperation, subsequent cancellation requests will return a `CancellationMessage`,\nindicating that the query has already been canceled. See [code sample](https://docs.aws.amazon.com/timestream/latest/developerguide/code-samples.cancel-query.html)\nfor details.","ref":"AWS.TimestreamQuery.html#cancel_query/3","title":"AWS.TimestreamQuery.cancel_query/3","type":"function"},{"doc":"Create a scheduled query that will be run on your behalf at the configured\nschedule.\n\nTimestream assumes the execution role provided as part of the\n`ScheduledQueryExecutionRoleArn` parameter to run the query. You can use the\n`NotificationConfiguration` parameter to configure notification for your\nscheduled query operations.","ref":"AWS.TimestreamQuery.html#create_scheduled_query/3","title":"AWS.TimestreamQuery.create_scheduled_query/3","type":"function"},{"doc":"Deletes a given scheduled query.\n\nThis is an irreversible operation.","ref":"AWS.TimestreamQuery.html#delete_scheduled_query/3","title":"AWS.TimestreamQuery.delete_scheduled_query/3","type":"function"},{"doc":"DescribeEndpoints returns a list of available endpoints to make Timestream API\ncalls against.\n\nThis API is available through both Write and Query.\n\nBecause the Timestream SDKs are designed to transparently work with the\nservice’s architecture, including the management and mapping of the service\nendpoints, *it is not recommended that you use this API unless*:\n\n  * You are using [VPC endpoints (Amazon Web Services PrivateLink) with Timestream\n](https://docs.aws.amazon.com/timestream/latest/developerguide/VPCEndpoints)\n\n  * Your application uses a programming language that does not yet\nhave SDK support\n\n  * You require better control over the client-side implementation\n\nFor detailed information on how and when to use and implement DescribeEndpoints,\nsee [The Endpoint Discovery Pattern](https://docs.aws.amazon.com/timestream/latest/developerguide/Using.API.html#Using-API.endpoint-discovery).","ref":"AWS.TimestreamQuery.html#describe_endpoints/3","title":"AWS.TimestreamQuery.describe_endpoints/3","type":"function"},{"doc":"Provides detailed information about a scheduled query.","ref":"AWS.TimestreamQuery.html#describe_scheduled_query/3","title":"AWS.TimestreamQuery.describe_scheduled_query/3","type":"function"},{"doc":"You can use this API to run a scheduled query manually.","ref":"AWS.TimestreamQuery.html#execute_scheduled_query/3","title":"AWS.TimestreamQuery.execute_scheduled_query/3","type":"function"},{"doc":"Gets a list of all scheduled queries in the caller's Amazon account and Region.\n\n`ListScheduledQueries` is eventually consistent.","ref":"AWS.TimestreamQuery.html#list_scheduled_queries/3","title":"AWS.TimestreamQuery.list_scheduled_queries/3","type":"function"},{"doc":"List all tags on a Timestream query resource.","ref":"AWS.TimestreamQuery.html#list_tags_for_resource/3","title":"AWS.TimestreamQuery.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.TimestreamQuery.html#metadata/0","title":"AWS.TimestreamQuery.metadata/0","type":"function"},{"doc":"A synchronous operation that allows you to submit a query with parameters to be\nstored by Timestream for later running.\n\nTimestream only supports using this operation with the\n`PrepareQueryRequest$ValidateOnly` set to `true`.","ref":"AWS.TimestreamQuery.html#prepare_query/3","title":"AWS.TimestreamQuery.prepare_query/3","type":"function"},{"doc":"`Query` is a synchronous operation that enables you to run a query against your\nAmazon Timestream data.\n\n`Query` will time out after 60 seconds. You must update the default timeout in\nthe SDK to support a timeout of 60 seconds. See the [code sample](https://docs.aws.amazon.com/timestream/latest/developerguide/code-samples.run-query.html)\nfor details.\n\nYour query request will fail in the following cases:\n\n  * If you submit a `Query` request with the same client token outside\nof the 5-minute idempotency window.\n\n  * If you submit a `Query` request with the same client token, but\nchange other parameters, within the 5-minute idempotency window.\n\n  * If the size of the row (including the query metadata) exceeds 1\nMB, then the query will fail with the following error message:\n\n`Query aborted as max page response size has been exceeded by the output result\nrow`\n\n  * If the IAM principal of the query initiator and the result reader\nare not the same and/or the query initiator and the result reader do not have\nthe same query string in the query requests, the query will fail with an\n`Invalid pagination token` error.","ref":"AWS.TimestreamQuery.html#query/3","title":"AWS.TimestreamQuery.query/3","type":"function"},{"doc":"Associate a set of tags with a Timestream resource.\n\nYou can then activate these user-defined tags so that they appear on the Billing\nand Cost Management console for cost allocation tracking.","ref":"AWS.TimestreamQuery.html#tag_resource/3","title":"AWS.TimestreamQuery.tag_resource/3","type":"function"},{"doc":"Removes the association of tags from a Timestream query resource.","ref":"AWS.TimestreamQuery.html#untag_resource/3","title":"AWS.TimestreamQuery.untag_resource/3","type":"function"},{"doc":"Update a scheduled query.","ref":"AWS.TimestreamQuery.html#update_scheduled_query/3","title":"AWS.TimestreamQuery.update_scheduled_query/3","type":"function"},{"doc":"Amazon Timestream Write\n\nAmazon Timestream is a fast, scalable, fully managed time-series database\nservice that makes it easy to store and analyze trillions of time-series data\npoints per day.\n\nWith Timestream, you can easily store and analyze IoT sensor data to derive\ninsights from your IoT applications. You can analyze industrial telemetry to\nstreamline equipment management and maintenance. You can also store and analyze\nlog data and metrics to improve the performance and availability of your\napplications.\n\nTimestream is built from the ground up to effectively ingest, process, and store\ntime-series data. It organizes data to optimize query processing. It\nautomatically scales based on the volume of data ingested and on the query\nvolume to ensure you receive optimal performance while inserting and querying\ndata. As your data grows over time, Timestream’s adaptive query processing\nengine spans across storage tiers to provide fast analysis while reducing costs.","ref":"AWS.TimestreamWrite.html","title":"AWS.TimestreamWrite","type":"module"},{"doc":"Creates a new Timestream batch load task.\n\nA batch load task processes data from a CSV source in an S3 location and writes\nto a Timestream table. A mapping from source to target is defined in a batch\nload task. Errors and events are written to a report at an S3 location. For the\nreport, if the KMS key is not specified, the report will be encrypted with an S3\nmanaged key when `SSE_S3` is the option. Otherwise an error is thrown. For more\ninformation, see [Amazon Web Services managed keys](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#aws-managed-cmk).\n[Service quotas apply](https://docs.aws.amazon.com/timestream/latest/developerguide/ts-limits.html).\nFor details, see [code sample](https://docs.aws.amazon.com/timestream/latest/developerguide/code-samples.create-batch-load.html).","ref":"AWS.TimestreamWrite.html#create_batch_load_task/3","title":"AWS.TimestreamWrite.create_batch_load_task/3","type":"function"},{"doc":"Creates a new Timestream database.\n\nIf the KMS key is not specified, the database will be encrypted with a\nTimestream managed KMS key located in your account. For more information, see\n[Amazon Web Services managed keys](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#aws-managed-cmk).\n[Service quotas apply](https://docs.aws.amazon.com/timestream/latest/developerguide/ts-limits.html).\nFor details, see [code sample](https://docs.aws.amazon.com/timestream/latest/developerguide/code-samples.create-db.html).","ref":"AWS.TimestreamWrite.html#create_database/3","title":"AWS.TimestreamWrite.create_database/3","type":"function"},{"doc":"Adds a new table to an existing database in your account.\n\nIn an Amazon Web Services account, table names must be at least unique within\neach Region if they are in the same database. You might have identical table\nnames in the same Region if the tables are in separate databases. While creating\nthe table, you must specify the table name, database name, and the retention\nproperties. [Service quotas apply](https://docs.aws.amazon.com/timestream/latest/developerguide/ts-limits.html).\nSee [code sample](https://docs.aws.amazon.com/timestream/latest/developerguide/code-samples.create-table.html)\nfor details.","ref":"AWS.TimestreamWrite.html#create_table/3","title":"AWS.TimestreamWrite.create_table/3","type":"function"},{"doc":"Deletes a given Timestream database.\n\n*This is an irreversible operation. After a database is deleted, the time-series\ndata from its tables cannot be recovered.*\n\nAll tables in the database must be deleted first, or a ValidationException error\nwill be thrown.\n\nDue to the nature of distributed retries, the operation can return either\nsuccess or a ResourceNotFoundException. Clients should consider them equivalent.\n\nSee [code sample](https://docs.aws.amazon.com/timestream/latest/developerguide/code-samples.delete-db.html)\nfor details.","ref":"AWS.TimestreamWrite.html#delete_database/3","title":"AWS.TimestreamWrite.delete_database/3","type":"function"},{"doc":"Deletes a given Timestream table.\n\nThis is an irreversible operation. After a Timestream database table is deleted,\nthe time-series data stored in the table cannot be recovered.\n\nDue to the nature of distributed retries, the operation can return either\nsuccess or a ResourceNotFoundException. Clients should consider them equivalent.\n\nSee [code sample](https://docs.aws.amazon.com/timestream/latest/developerguide/code-samples.delete-table.html)\nfor details.","ref":"AWS.TimestreamWrite.html#delete_table/3","title":"AWS.TimestreamWrite.delete_table/3","type":"function"},{"doc":"Returns information about the batch load task, including configurations,\nmappings, progress, and other details.\n\n[Service quotas apply](https://docs.aws.amazon.com/timestream/latest/developerguide/ts-limits.html).\nSee [code sample](https://docs.aws.amazon.com/timestream/latest/developerguide/code-samples.describe-batch-load.html)\nfor details.","ref":"AWS.TimestreamWrite.html#describe_batch_load_task/3","title":"AWS.TimestreamWrite.describe_batch_load_task/3","type":"function"},{"doc":"Returns information about the database, including the database name, time that\nthe database was created, and the total number of tables found within the\ndatabase.\n\n[Service quotas apply](https://docs.aws.amazon.com/timestream/latest/developerguide/ts-limits.html).\nSee [code sample](https://docs.aws.amazon.com/timestream/latest/developerguide/code-samples.describe-db.html)\nfor details.","ref":"AWS.TimestreamWrite.html#describe_database/3","title":"AWS.TimestreamWrite.describe_database/3","type":"function"},{"doc":"Returns a list of available endpoints to make Timestream API calls against.\n\nThis API operation is available through both the Write and Query APIs.\n\nBecause the Timestream SDKs are designed to transparently work with the\nservice’s architecture, including the management and mapping of the service\nendpoints, *we don't recommend that you use this API operation unless*:\n\n  * You are using [VPC endpoints (Amazon Web Services PrivateLink) with\nTimestream](https://docs.aws.amazon.com/timestream/latest/developerguide/VPCEndpoints)\n\n  * Your application uses a programming language that does not yet\nhave SDK support\n\n  * You require better control over the client-side implementation\n\nFor detailed information on how and when to use and implement DescribeEndpoints,\nsee [The Endpoint Discovery Pattern](https://docs.aws.amazon.com/timestream/latest/developerguide/Using.API.html#Using-API.endpoint-discovery).","ref":"AWS.TimestreamWrite.html#describe_endpoints/3","title":"AWS.TimestreamWrite.describe_endpoints/3","type":"function"},{"doc":"Returns information about the table, including the table name, database name,\nretention duration of the memory store and the magnetic store.\n\n[Service quotas apply](https://docs.aws.amazon.com/timestream/latest/developerguide/ts-limits.html).\nSee [code sample](https://docs.aws.amazon.com/timestream/latest/developerguide/code-samples.describe-table.html)\nfor details.","ref":"AWS.TimestreamWrite.html#describe_table/3","title":"AWS.TimestreamWrite.describe_table/3","type":"function"},{"doc":"Provides a list of batch load tasks, along with the name, status, when the task\nis resumable until, and other details.\n\nSee [code sample](https://docs.aws.amazon.com/timestream/latest/developerguide/code-samples.list-batch-load-tasks.html)\nfor details.","ref":"AWS.TimestreamWrite.html#list_batch_load_tasks/3","title":"AWS.TimestreamWrite.list_batch_load_tasks/3","type":"function"},{"doc":"Returns a list of your Timestream databases.\n\n[Service quotas apply](https://docs.aws.amazon.com/timestream/latest/developerguide/ts-limits.html).\nSee [code sample](https://docs.aws.amazon.com/timestream/latest/developerguide/code-samples.list-db.html)\nfor details.","ref":"AWS.TimestreamWrite.html#list_databases/3","title":"AWS.TimestreamWrite.list_databases/3","type":"function"},{"doc":"Provides a list of tables, along with the name, status, and retention properties\nof each table.\n\nSee [code sample](https://docs.aws.amazon.com/timestream/latest/developerguide/code-samples.list-table.html)\nfor details.","ref":"AWS.TimestreamWrite.html#list_tables/3","title":"AWS.TimestreamWrite.list_tables/3","type":"function"},{"doc":"Lists all tags on a Timestream resource.","ref":"AWS.TimestreamWrite.html#list_tags_for_resource/3","title":"AWS.TimestreamWrite.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.TimestreamWrite.html#metadata/0","title":"AWS.TimestreamWrite.metadata/0","type":"function"},{"doc":"","ref":"AWS.TimestreamWrite.html#resume_batch_load_task/3","title":"AWS.TimestreamWrite.resume_batch_load_task/3","type":"function"},{"doc":"Associates a set of tags with a Timestream resource.\n\nYou can then activate these user-defined tags so that they appear on the Billing\nand Cost Management console for cost allocation tracking.","ref":"AWS.TimestreamWrite.html#tag_resource/3","title":"AWS.TimestreamWrite.tag_resource/3","type":"function"},{"doc":"Removes the association of tags from a Timestream resource.","ref":"AWS.TimestreamWrite.html#untag_resource/3","title":"AWS.TimestreamWrite.untag_resource/3","type":"function"},{"doc":"Modifies the KMS key for an existing database.\n\nWhile updating the database, you must specify the database name and the\nidentifier of the new KMS key to be used (`KmsKeyId`). If there are any\nconcurrent `UpdateDatabase` requests, first writer wins.\n\nSee [code sample](https://docs.aws.amazon.com/timestream/latest/developerguide/code-samples.update-db.html)\nfor details.","ref":"AWS.TimestreamWrite.html#update_database/3","title":"AWS.TimestreamWrite.update_database/3","type":"function"},{"doc":"Modifies the retention duration of the memory store and magnetic store for your\nTimestream table.\n\nNote that the change in retention duration takes effect immediately. For\nexample, if the retention period of the memory store was initially set to 2\nhours and then changed to 24 hours, the memory store will be capable of holding\n24 hours of data, but will be populated with 24 hours of data 22 hours after\nthis change was made. Timestream does not retrieve data from the magnetic store\nto populate the memory store.\n\nSee [code sample](https://docs.aws.amazon.com/timestream/latest/developerguide/code-samples.update-table.html)\nfor details.","ref":"AWS.TimestreamWrite.html#update_table/3","title":"AWS.TimestreamWrite.update_table/3","type":"function"},{"doc":"Enables you to write your time-series data into Timestream.\n\nYou can specify a single data point or a batch of data points to be inserted\ninto the system. Timestream offers you a flexible schema that auto detects the\ncolumn names and data types for your Timestream tables based on the dimension\nnames and data types of the data points you specify when invoking writes into\nthe database.\n\nTimestream supports eventual consistency read semantics. This means that when\nyou query data immediately after writing a batch of data into Timestream, the\nquery results might not reflect the results of a recently completed write\noperation. The results may also include some stale data. If you repeat the query\nrequest after a short time, the results should return the latest data. [Service quotas\napply](https://docs.aws.amazon.com/timestream/latest/developerguide/ts-limits.html).\n\nSee [code sample](https://docs.aws.amazon.com/timestream/latest/developerguide/code-samples.write.html)\nfor details.","ref":"AWS.TimestreamWrite.html#write_records/3","title":"AWS.TimestreamWrite.write_records/3","type":"function"},{"doc":"You can use the `Version` parameter in a `WriteRecords` request to update data\npoints. Timestream tracks a version number with each record. `Version` defaults\nto `1` when it's not specified for the record in the request. Timestream updates\nan existing record’s measure value along with its `Version` when it receives a\nwrite request with a higher `Version` number for that record. When it receives\nan update request where the measure value is the same as that of the existing\nrecord, Timestream still updates `Version`, if it is greater than the existing\nvalue of `Version`. You can update a data point as many times as desired, as\nlong as the value of `Version` continuously increases.\n\nFor example, suppose you write a new record without indicating `Version` in the\nrequest. Timestream stores this record, and set `Version` to `1`. Now, suppose\nyou try to update this record with a `WriteRecords` request of the same record\nwith a different measure value but, like before, do not provide `Version`. In\nthis case, Timestream will reject this update with a `RejectedRecordsException`\nsince the updated record’s version is not greater than the existing value of\nVersion.\n\nHowever, if you were to resend the update request with `Version` set to `2`,\nTimestream would then succeed in updating the record’s value, and the `Version`\nwould be set to `2`. Next, suppose you sent a `WriteRecords` request with this\nsame record and an identical measure value, but with `Version` set to `3`. In\nthis case, Timestream would only update `Version` to `3`. Any further updates\nwould need to send a version number greater than `3`, or the update requests\nwould receive a `RejectedRecordsException`.","ref":"AWS.TimestreamWrite.html#write_records/3-upserts","title":"Upserts - AWS.TimestreamWrite.write_records/3","type":"function"},{"doc":"Amazon Web Services Telco Network Builder (TNB) is a network automation service\nthat helps you deploy and manage telecom networks.\n\nAWS TNB helps you with the lifecycle management of your telecommunication\nnetwork functions throughout planning, deployment, and post-deployment\nactivities.","ref":"AWS.Tnb.html","title":"AWS.Tnb","type":"module"},{"doc":"Cancels a network operation.\n\nA network operation is any operation that is done to your network, such as\nnetwork instance instantiation or termination.","ref":"AWS.Tnb.html#cancel_sol_network_operation/4","title":"AWS.Tnb.cancel_sol_network_operation/4","type":"function"},{"doc":"Creates a function package.\n\nA function package is a .zip file in CSAR (Cloud Service Archive) format that\ncontains a network function (an ETSI standard telecommunication application) and\nfunction package descriptor that uses the TOSCA standard to describe how the\nnetwork functions should run on your network. For more information, see\n[Function packages](https://docs.aws.amazon.com/tnb/latest/ug/function-packages.html) in\nthe *Amazon Web Services Telco Network Builder User Guide*.\n\nCreating a function package is the first step for creating a network in AWS TNB.\nThis request creates an empty container with an ID. The next step is to upload\nthe actual CSAR zip file into that empty container. To upload function package\ncontent, see\n[PutSolFunctionPackageContent](https://docs.aws.amazon.com/tnb/latest/APIReference/API_PutSolFunctionPackageContent.html).","ref":"AWS.Tnb.html#create_sol_function_package/3","title":"AWS.Tnb.create_sol_function_package/3","type":"function"},{"doc":"Creates a network instance.\n\nA network instance is a single network created in Amazon Web Services TNB that\ncan be deployed and on which life-cycle operations (like terminate, update, and\ndelete) can be performed. Creating a network instance is the third step after\ncreating a network package. For more information about network instances,\n[Network instances](https://docs.aws.amazon.com/tnb/latest/ug/network-instances.html) in\nthe *Amazon Web Services Telco Network Builder User Guide*.\n\nOnce you create a network instance, you can instantiate it. To instantiate a\nnetwork, see\n[InstantiateSolNetworkInstance](https://docs.aws.amazon.com/tnb/latest/APIReference/API_InstantiateSolNetworkInstance.html).","ref":"AWS.Tnb.html#create_sol_network_instance/3","title":"AWS.Tnb.create_sol_network_instance/3","type":"function"},{"doc":"Creates a network package.\n\nA network package is a .zip file in CSAR (Cloud Service Archive) format defines\nthe function packages you want to deploy and the Amazon Web Services\ninfrastructure you want to deploy them on. For more information, see [Network instances](https://docs.aws.amazon.com/tnb/latest/ug/network-instances.html) in\nthe *Amazon Web Services Telco Network Builder User Guide*.\n\nA network package consists of a network service descriptor (NSD) file (required)\nand any additional files (optional), such as scripts specific to your needs. For\nexample, if you have multiple function packages in your network package, you can\nuse the NSD to define which network functions should run in certain VPCs,\nsubnets, or EKS clusters.\n\nThis request creates an empty network package container with an ID. Once you\ncreate a network package, you can upload the network package content using\n[PutSolNetworkPackageContent](https://docs.aws.amazon.com/tnb/latest/APIReference/API_PutSolNetworkPackageContent.html).","ref":"AWS.Tnb.html#create_sol_network_package/3","title":"AWS.Tnb.create_sol_network_package/3","type":"function"},{"doc":"Deletes a function package.\n\nA function package is a .zip file in CSAR (Cloud Service Archive) format that\ncontains a network function (an ETSI standard telecommunication application) and\nfunction package descriptor that uses the TOSCA standard to describe how the\nnetwork functions should run on your network.\n\nTo delete a function package, the package must be in a disabled state. To\ndisable a function package, see\n[UpdateSolFunctionPackage](https://docs.aws.amazon.com/tnb/latest/APIReference/API_UpdateSolFunctionPackage.html).","ref":"AWS.Tnb.html#delete_sol_function_package/4","title":"AWS.Tnb.delete_sol_function_package/4","type":"function"},{"doc":"Deletes a network instance.\n\nA network instance is a single network created in Amazon Web Services TNB that\ncan be deployed and on which life-cycle operations (like terminate, update, and\ndelete) can be performed.\n\nTo delete a network instance, the instance must be in a stopped or terminated\nstate. To terminate a network instance, see\n[TerminateSolNetworkInstance](https://docs.aws.amazon.com/tnb/latest/APIReference/API_TerminateSolNetworkInstance.html).","ref":"AWS.Tnb.html#delete_sol_network_instance/4","title":"AWS.Tnb.delete_sol_network_instance/4","type":"function"},{"doc":"Deletes network package.\n\nA network package is a .zip file in CSAR (Cloud Service Archive) format defines\nthe function packages you want to deploy and the Amazon Web Services\ninfrastructure you want to deploy them on.\n\nTo delete a network package, the package must be in a disable state. To disable\na network package, see\n[UpdateSolNetworkPackage](https://docs.aws.amazon.com/tnb/latest/APIReference/API_UpdateSolNetworkPackage.html).","ref":"AWS.Tnb.html#delete_sol_network_package/4","title":"AWS.Tnb.delete_sol_network_package/4","type":"function"},{"doc":"Gets the details of a network function instance, including the instantation\nstate and metadata from the function package descriptor in the network function\npackage.\n\nA network function instance is a function in a function package .","ref":"AWS.Tnb.html#get_sol_function_instance/3","title":"AWS.Tnb.get_sol_function_instance/3","type":"function"},{"doc":"Gets the details of an individual function package, such as the operational\nstate and whether the package is in use.\n\nA function package is a .zip file in CSAR (Cloud Service Archive) format that\ncontains a network function (an ETSI standard telecommunication application) and\nfunction package descriptor that uses the TOSCA standard to describe how the\nnetwork functions should run on your network..","ref":"AWS.Tnb.html#get_sol_function_package/3","title":"AWS.Tnb.get_sol_function_package/3","type":"function"},{"doc":"Gets the contents of a function package.\n\nA function package is a .zip file in CSAR (Cloud Service Archive) format that\ncontains a network function (an ETSI standard telecommunication application) and\nfunction package descriptor that uses the TOSCA standard to describe how the\nnetwork functions should run on your network.","ref":"AWS.Tnb.html#get_sol_function_package_content/4","title":"AWS.Tnb.get_sol_function_package_content/4","type":"function"},{"doc":"Gets a function package descriptor in a function package.\n\nA function package descriptor is a .yaml file in a function package that uses\nthe TOSCA standard to describe how the network function in the function package\nshould run on your network.\n\nA function package is a .zip file in CSAR (Cloud Service Archive) format that\ncontains a network function (an ETSI standard telecommunication application) and\nfunction package descriptor that uses the TOSCA standard to describe how the\nnetwork functions should run on your network.","ref":"AWS.Tnb.html#get_sol_function_package_descriptor/4","title":"AWS.Tnb.get_sol_function_package_descriptor/4","type":"function"},{"doc":"Gets the details of the network instance.\n\nA network instance is a single network created in Amazon Web Services TNB that\ncan be deployed and on which life-cycle operations (like terminate, update, and\ndelete) can be performed.","ref":"AWS.Tnb.html#get_sol_network_instance/3","title":"AWS.Tnb.get_sol_network_instance/3","type":"function"},{"doc":"Gets the details of a network operation, including the tasks involved in the\nnetwork operation and the status of the tasks.\n\nA network operation is any operation that is done to your network, such as\nnetwork instance instantiation or termination.","ref":"AWS.Tnb.html#get_sol_network_operation/3","title":"AWS.Tnb.get_sol_network_operation/3","type":"function"},{"doc":"Gets the details of a network package.\n\nA network package is a .zip file in CSAR (Cloud Service Archive) format defines\nthe function packages you want to deploy and the Amazon Web Services\ninfrastructure you want to deploy them on.","ref":"AWS.Tnb.html#get_sol_network_package/3","title":"AWS.Tnb.get_sol_network_package/3","type":"function"},{"doc":"Gets the contents of a network package.\n\nA network package is a .zip file in CSAR (Cloud Service Archive) format defines\nthe function packages you want to deploy and the Amazon Web Services\ninfrastructure you want to deploy them on.","ref":"AWS.Tnb.html#get_sol_network_package_content/4","title":"AWS.Tnb.get_sol_network_package_content/4","type":"function"},{"doc":"Gets the content of the network service descriptor.\n\nA network service descriptor is a .yaml file in a network package that uses the\nTOSCA standard to describe the network functions you want to deploy and the\nAmazon Web Services infrastructure you want to deploy the network functions on.","ref":"AWS.Tnb.html#get_sol_network_package_descriptor/3","title":"AWS.Tnb.get_sol_network_package_descriptor/3","type":"function"},{"doc":"Instantiates a network instance.\n\nA network instance is a single network created in Amazon Web Services TNB that\ncan be deployed and on which life-cycle operations (like terminate, update, and\ndelete) can be performed.\n\nBefore you can instantiate a network instance, you have to create a network\ninstance. For more information, see\n[CreateSolNetworkInstance](https://docs.aws.amazon.com/tnb/latest/APIReference/API_CreateSolNetworkInstance.html).","ref":"AWS.Tnb.html#instantiate_sol_network_instance/4","title":"AWS.Tnb.instantiate_sol_network_instance/4","type":"function"},{"doc":"Lists network function instances.\n\nA network function instance is a function in a function package .","ref":"AWS.Tnb.html#list_sol_function_instances/4","title":"AWS.Tnb.list_sol_function_instances/4","type":"function"},{"doc":"Lists information about function packages.\n\nA function package is a .zip file in CSAR (Cloud Service Archive) format that\ncontains a network function (an ETSI standard telecommunication application) and\nfunction package descriptor that uses the TOSCA standard to describe how the\nnetwork functions should run on your network.","ref":"AWS.Tnb.html#list_sol_function_packages/4","title":"AWS.Tnb.list_sol_function_packages/4","type":"function"},{"doc":"Lists your network instances.\n\nA network instance is a single network created in Amazon Web Services TNB that\ncan be deployed and on which life-cycle operations (like terminate, update, and\ndelete) can be performed.","ref":"AWS.Tnb.html#list_sol_network_instances/4","title":"AWS.Tnb.list_sol_network_instances/4","type":"function"},{"doc":"Lists details for a network operation, including when the operation started and\nthe status of the operation.\n\nA network operation is any operation that is done to your network, such as\nnetwork instance instantiation or termination.","ref":"AWS.Tnb.html#list_sol_network_operations/4","title":"AWS.Tnb.list_sol_network_operations/4","type":"function"},{"doc":"Lists network packages.\n\nA network package is a .zip file in CSAR (Cloud Service Archive) format defines\nthe function packages you want to deploy and the Amazon Web Services\ninfrastructure you want to deploy them on.","ref":"AWS.Tnb.html#list_sol_network_packages/4","title":"AWS.Tnb.list_sol_network_packages/4","type":"function"},{"doc":"Lists tags for AWS TNB resources.","ref":"AWS.Tnb.html#list_tags_for_resource/3","title":"AWS.Tnb.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.Tnb.html#metadata/0","title":"AWS.Tnb.metadata/0","type":"function"},{"doc":"Uploads the contents of a function package.\n\nA function package is a .zip file in CSAR (Cloud Service Archive) format that\ncontains a network function (an ETSI standard telecommunication application) and\nfunction package descriptor that uses the TOSCA standard to describe how the\nnetwork functions should run on your network.","ref":"AWS.Tnb.html#put_sol_function_package_content/4","title":"AWS.Tnb.put_sol_function_package_content/4","type":"function"},{"doc":"Uploads the contents of a network package.\n\nA network package is a .zip file in CSAR (Cloud Service Archive) format defines\nthe function packages you want to deploy and the Amazon Web Services\ninfrastructure you want to deploy them on.","ref":"AWS.Tnb.html#put_sol_network_package_content/4","title":"AWS.Tnb.put_sol_network_package_content/4","type":"function"},{"doc":"Tags an AWS TNB resource.\n\nA tag is a label that you assign to an Amazon Web Services resource. Each tag\nconsists of a key and an optional value. You can use tags to search and filter\nyour resources or track your Amazon Web Services costs.","ref":"AWS.Tnb.html#tag_resource/4","title":"AWS.Tnb.tag_resource/4","type":"function"},{"doc":"Terminates a network instance.\n\nA network instance is a single network created in Amazon Web Services TNB that\ncan be deployed and on which life-cycle operations (like terminate, update, and\ndelete) can be performed.\n\nYou must terminate a network instance before you can delete it.","ref":"AWS.Tnb.html#terminate_sol_network_instance/4","title":"AWS.Tnb.terminate_sol_network_instance/4","type":"function"},{"doc":"Untags an AWS TNB resource.\n\nA tag is a label that you assign to an Amazon Web Services resource. Each tag\nconsists of a key and an optional value. You can use tags to search and filter\nyour resources or track your Amazon Web Services costs.","ref":"AWS.Tnb.html#untag_resource/4","title":"AWS.Tnb.untag_resource/4","type":"function"},{"doc":"Updates the operational state of function package.\n\nA function package is a .zip file in CSAR (Cloud Service Archive) format that\ncontains a network function (an ETSI standard telecommunication application) and\nfunction package descriptor that uses the TOSCA standard to describe how the\nnetwork functions should run on your network.","ref":"AWS.Tnb.html#update_sol_function_package/4","title":"AWS.Tnb.update_sol_function_package/4","type":"function"},{"doc":"Update a network instance.\n\nA network instance is a single network created in Amazon Web Services TNB that\ncan be deployed and on which life-cycle operations (like terminate, update, and\ndelete) can be performed.","ref":"AWS.Tnb.html#update_sol_network_instance/4","title":"AWS.Tnb.update_sol_network_instance/4","type":"function"},{"doc":"Updates the operational state of a network package.\n\nA network package is a .zip file in CSAR (Cloud Service Archive) format defines\nthe function packages you want to deploy and the Amazon Web Services\ninfrastructure you want to deploy them on.\n\nA network service descriptor is a .yaml file in a network package that uses the\nTOSCA standard to describe the network functions you want to deploy and the\nAmazon Web Services infrastructure you want to deploy the network functions on.","ref":"AWS.Tnb.html#update_sol_network_package/4","title":"AWS.Tnb.update_sol_network_package/4","type":"function"},{"doc":"Validates function package content.\n\nThis can be used as a dry run before uploading function package content with\n[PutSolFunctionPackageContent](https://docs.aws.amazon.com/tnb/latest/APIReference/API_PutSolFunctionPackageContent.html).\n\nA function package is a .zip file in CSAR (Cloud Service Archive) format that\ncontains a network function (an ETSI standard telecommunication application) and\nfunction package descriptor that uses the TOSCA standard to describe how the\nnetwork functions should run on your network.","ref":"AWS.Tnb.html#validate_sol_function_package_content/4","title":"AWS.Tnb.validate_sol_function_package_content/4","type":"function"},{"doc":"Validates network package content.\n\nThis can be used as a dry run before uploading network package content with\n[PutSolNetworkPackageContent](https://docs.aws.amazon.com/tnb/latest/APIReference/API_PutSolNetworkPackageContent.html).\n\nA network package is a .zip file in CSAR (Cloud Service Archive) format defines\nthe function packages you want to deploy and the Amazon Web Services\ninfrastructure you want to deploy them on.","ref":"AWS.Tnb.html#validate_sol_network_package_content/4","title":"AWS.Tnb.validate_sol_network_package_content/4","type":"function"},{"doc":"Amazon Transcribe offers three main types of batch transcription: **Standard**,\n**Medical**, and **Call Analytics**.\n\n  * **Standard transcriptions** are the most common option. Refer to\nfor details.\n\n  * **Medical transcriptions** are tailored to medical professionals\nand incorporate medical terms. A common use case for this service is\ntranscribing doctor-patient dialogue into after-visit notes. Refer to for\ndetails.\n\n  * **Call Analytics transcriptions** are designed for use with call\ncenter audio on two different channels; if you're looking for insight into\ncustomer service calls, use this option. Refer to for details.","ref":"AWS.Transcribe.html","title":"AWS.Transcribe","type":"module"},{"doc":"Creates a new Call Analytics category.\n\nAll categories are automatically applied to your Call Analytics transcriptions.\nNote that in order to apply categories to your transcriptions, you must create\nthem before submitting your transcription request, as categories cannot be\napplied retroactively.\n\nWhen creating a new category, you can use the `InputType` parameter to label the\ncategory as a `POST_CALL` or a `REAL_TIME` category. `POST_CALL` categories can\nonly be applied to post-call transcriptions and `REAL_TIME` categories can only\nbe applied to real-time transcriptions. If you do not include `InputType`, your\ncategory is created as a `POST_CALL` category by default.\n\nCall Analytics categories are composed of rules. For each category, you must\ncreate between 1 and 20 rules. Rules can include these parameters: , , , and .\n\nTo update an existing category, see .\n\nTo learn more about Call Analytics categories, see [Creating categories for post-call\ntranscriptions](https://docs.aws.amazon.com/transcribe/latest/dg/tca-categories-batch.html)\nand [Creating categories for real-time transcriptions](https://docs.aws.amazon.com/transcribe/latest/dg/tca-categories-stream.html).","ref":"AWS.Transcribe.html#create_call_analytics_category/3","title":"AWS.Transcribe.create_call_analytics_category/3","type":"function"},{"doc":"Creates a new custom language model.\n\nWhen creating a new custom language model, you must specify:\n\n  * If you want a Wideband (audio sample rates over 16,000 Hz) or\nNarrowband (audio sample rates under 16,000 Hz) base model\n\n  * The location of your training and tuning files (this must be an\nAmazon S3 URI)\n\n  * The language of your model\n\n  * A unique name for your model","ref":"AWS.Transcribe.html#create_language_model/3","title":"AWS.Transcribe.create_language_model/3","type":"function"},{"doc":"Creates a new custom medical vocabulary.\n\nBefore creating a new custom medical vocabulary, you must first upload a text\nfile that contains your vocabulary table into an Amazon S3 bucket. Note that\nthis differs from , where you can include a list of terms within your request\nusing the `Phrases` flag; `CreateMedicalVocabulary` does not support the\n`Phrases` flag and only accepts vocabularies in table format.\n\nEach language has a character set that contains all allowed characters for that\nspecific language. If you use unsupported characters, your custom vocabulary\nrequest fails. Refer to [Character Sets for Custom Vocabularies](https://docs.aws.amazon.com/transcribe/latest/dg/charsets.html) to\nget the character set for your language.\n\nFor more information, see [Custom vocabularies](https://docs.aws.amazon.com/transcribe/latest/dg/custom-vocabulary.html).","ref":"AWS.Transcribe.html#create_medical_vocabulary/3","title":"AWS.Transcribe.create_medical_vocabulary/3","type":"function"},{"doc":"Creates a new custom vocabulary.\n\nWhen creating a new custom vocabulary, you can either upload a text file that\ncontains your new entries, phrases, and terms into an Amazon S3 bucket and\ninclude the URI in your request. Or you can include a list of terms directly in\nyour request using the `Phrases` flag.\n\nEach language has a character set that contains all allowed characters for that\nspecific language. If you use unsupported characters, your custom vocabulary\nrequest fails. Refer to [Character Sets for Custom Vocabularies](https://docs.aws.amazon.com/transcribe/latest/dg/charsets.html) to\nget the character set for your language.\n\nFor more information, see [Custom vocabularies](https://docs.aws.amazon.com/transcribe/latest/dg/custom-vocabulary.html).","ref":"AWS.Transcribe.html#create_vocabulary/3","title":"AWS.Transcribe.create_vocabulary/3","type":"function"},{"doc":"Creates a new custom vocabulary filter.\n\nYou can use custom vocabulary filters to mask, delete, or flag specific words\nfrom your transcript. Custom vocabulary filters are commonly used to mask\nprofanity in transcripts.\n\nEach language has a character set that contains all allowed characters for that\nspecific language. If you use unsupported characters, your custom vocabulary\nfilter request fails. Refer to [Character Sets for Custom Vocabularies](https://docs.aws.amazon.com/transcribe/latest/dg/charsets.html) to\nget the character set for your language.\n\nFor more information, see [Vocabulary filtering](https://docs.aws.amazon.com/transcribe/latest/dg/vocabulary-filtering.html).","ref":"AWS.Transcribe.html#create_vocabulary_filter/3","title":"AWS.Transcribe.create_vocabulary_filter/3","type":"function"},{"doc":"Deletes a Call Analytics category.\n\nTo use this operation, specify the name of the category you want to delete using\n`CategoryName`. Category names are case sensitive.","ref":"AWS.Transcribe.html#delete_call_analytics_category/3","title":"AWS.Transcribe.delete_call_analytics_category/3","type":"function"},{"doc":"Deletes a Call Analytics job.\n\nTo use this operation, specify the name of the job you want to delete using\n`CallAnalyticsJobName`. Job names are case sensitive.","ref":"AWS.Transcribe.html#delete_call_analytics_job/3","title":"AWS.Transcribe.delete_call_analytics_job/3","type":"function"},{"doc":"Deletes a custom language model.\n\nTo use this operation, specify the name of the language model you want to delete\nusing `ModelName`. custom language model names are case sensitive.","ref":"AWS.Transcribe.html#delete_language_model/3","title":"AWS.Transcribe.delete_language_model/3","type":"function"},{"doc":"Deletes a Medical Scribe job.\n\nTo use this operation, specify the name of the job you want to delete using\n`MedicalScribeJobName`. Job names are case sensitive.","ref":"AWS.Transcribe.html#delete_medical_scribe_job/3","title":"AWS.Transcribe.delete_medical_scribe_job/3","type":"function"},{"doc":"Deletes a medical transcription job.\n\nTo use this operation, specify the name of the job you want to delete using\n`MedicalTranscriptionJobName`. Job names are case sensitive.","ref":"AWS.Transcribe.html#delete_medical_transcription_job/3","title":"AWS.Transcribe.delete_medical_transcription_job/3","type":"function"},{"doc":"Deletes a custom medical vocabulary.\n\nTo use this operation, specify the name of the custom vocabulary you want to\ndelete using `VocabularyName`. Custom vocabulary names are case sensitive.","ref":"AWS.Transcribe.html#delete_medical_vocabulary/3","title":"AWS.Transcribe.delete_medical_vocabulary/3","type":"function"},{"doc":"Deletes a transcription job.\n\nTo use this operation, specify the name of the job you want to delete using\n`TranscriptionJobName`. Job names are case sensitive.","ref":"AWS.Transcribe.html#delete_transcription_job/3","title":"AWS.Transcribe.delete_transcription_job/3","type":"function"},{"doc":"Deletes a custom vocabulary.\n\nTo use this operation, specify the name of the custom vocabulary you want to\ndelete using `VocabularyName`. Custom vocabulary names are case sensitive.","ref":"AWS.Transcribe.html#delete_vocabulary/3","title":"AWS.Transcribe.delete_vocabulary/3","type":"function"},{"doc":"Deletes a custom vocabulary filter.\n\nTo use this operation, specify the name of the custom vocabulary filter you want\nto delete using `VocabularyFilterName`. Custom vocabulary filter names are case\nsensitive.","ref":"AWS.Transcribe.html#delete_vocabulary_filter/3","title":"AWS.Transcribe.delete_vocabulary_filter/3","type":"function"},{"doc":"Provides information about the specified custom language model.\n\nThis operation also shows if the base language model that you used to create\nyour custom language model has been updated. If Amazon Transcribe has updated\nthe base model, you can create a new custom language model using the updated\nbase model.\n\nIf you tried to create a new custom language model and the request wasn't\nsuccessful, you can use `DescribeLanguageModel` to help identify the reason for\nthis failure.","ref":"AWS.Transcribe.html#describe_language_model/3","title":"AWS.Transcribe.describe_language_model/3","type":"function"},{"doc":"Provides information about the specified Call Analytics category.\n\nTo get a list of your Call Analytics categories, use the operation.","ref":"AWS.Transcribe.html#get_call_analytics_category/3","title":"AWS.Transcribe.get_call_analytics_category/3","type":"function"},{"doc":"Provides information about the specified Call Analytics job.\n\nTo view the job's status, refer to `CallAnalyticsJobStatus`. If the status is\n`COMPLETED`, the job is finished. You can find your completed transcript at the\nURI specified in `TranscriptFileUri`. If the status is `FAILED`, `FailureReason`\nprovides details on why your transcription job failed.\n\nIf you enabled personally identifiable information (PII) redaction, the redacted\ntranscript appears at the location specified in `RedactedTranscriptFileUri`.\n\nIf you chose to redact the audio in your media file, you can find your redacted\nmedia file at the location specified in `RedactedMediaFileUri`.\n\nTo get a list of your Call Analytics jobs, use the operation.","ref":"AWS.Transcribe.html#get_call_analytics_job/3","title":"AWS.Transcribe.get_call_analytics_job/3","type":"function"},{"doc":"Provides information about the specified Medical Scribe job.\n\nTo view the status of the specified medical transcription job, check the\n`MedicalScribeJobStatus` field. If the status is `COMPLETED`, the job is\nfinished. You can find the results at the location specified in\n`MedicalScribeOutput`. If the status is `FAILED`, `FailureReason` provides\ndetails on why your Medical Scribe job failed.\n\nTo get a list of your Medical Scribe jobs, use the operation.","ref":"AWS.Transcribe.html#get_medical_scribe_job/3","title":"AWS.Transcribe.get_medical_scribe_job/3","type":"function"},{"doc":"Provides information about the specified medical transcription job.\n\nTo view the status of the specified medical transcription job, check the\n`TranscriptionJobStatus` field. If the status is `COMPLETED`, the job is\nfinished. You can find the results at the location specified in\n`TranscriptFileUri`. If the status is `FAILED`, `FailureReason` provides details\non why your transcription job failed.\n\nTo get a list of your medical transcription jobs, use the operation.","ref":"AWS.Transcribe.html#get_medical_transcription_job/3","title":"AWS.Transcribe.get_medical_transcription_job/3","type":"function"},{"doc":"Provides information about the specified custom medical vocabulary.\n\nTo view the status of the specified custom medical vocabulary, check the\n`VocabularyState` field. If the status is `READY`, your custom vocabulary is\navailable to use. If the status is `FAILED`, `FailureReason` provides details on\nwhy your vocabulary failed.\n\nTo get a list of your custom medical vocabularies, use the operation.","ref":"AWS.Transcribe.html#get_medical_vocabulary/3","title":"AWS.Transcribe.get_medical_vocabulary/3","type":"function"},{"doc":"Provides information about the specified transcription job.\n\nTo view the status of the specified transcription job, check the\n`TranscriptionJobStatus` field. If the status is `COMPLETED`, the job is\nfinished. You can find the results at the location specified in\n`TranscriptFileUri`. If the status is `FAILED`, `FailureReason` provides details\non why your transcription job failed.\n\nIf you enabled content redaction, the redacted transcript can be found at the\nlocation specified in `RedactedTranscriptFileUri`.\n\nTo get a list of your transcription jobs, use the operation.","ref":"AWS.Transcribe.html#get_transcription_job/3","title":"AWS.Transcribe.get_transcription_job/3","type":"function"},{"doc":"Provides information about the specified custom vocabulary.\n\nTo view the status of the specified custom vocabulary, check the\n`VocabularyState` field. If the status is `READY`, your custom vocabulary is\navailable to use. If the status is `FAILED`, `FailureReason` provides details on\nwhy your custom vocabulary failed.\n\nTo get a list of your custom vocabularies, use the operation.","ref":"AWS.Transcribe.html#get_vocabulary/3","title":"AWS.Transcribe.get_vocabulary/3","type":"function"},{"doc":"Provides information about the specified custom vocabulary filter.\n\nTo get a list of your custom vocabulary filters, use the operation.","ref":"AWS.Transcribe.html#get_vocabulary_filter/3","title":"AWS.Transcribe.get_vocabulary_filter/3","type":"function"},{"doc":"Provides a list of Call Analytics categories, including all rules that make up\neach category.\n\nTo get detailed information about a specific Call Analytics category, use the\noperation.","ref":"AWS.Transcribe.html#list_call_analytics_categories/3","title":"AWS.Transcribe.list_call_analytics_categories/3","type":"function"},{"doc":"Provides a list of Call Analytics jobs that match the specified criteria.\n\nIf no criteria are specified, all Call Analytics jobs are returned.\n\nTo get detailed information about a specific Call Analytics job, use the\noperation.","ref":"AWS.Transcribe.html#list_call_analytics_jobs/3","title":"AWS.Transcribe.list_call_analytics_jobs/3","type":"function"},{"doc":"Provides a list of custom language models that match the specified criteria.\n\nIf no criteria are specified, all custom language models are returned.\n\nTo get detailed information about a specific custom language model, use the\noperation.","ref":"AWS.Transcribe.html#list_language_models/3","title":"AWS.Transcribe.list_language_models/3","type":"function"},{"doc":"Provides a list of Medical Scribe jobs that match the specified criteria.\n\nIf no criteria are specified, all Medical Scribe jobs are returned.\n\nTo get detailed information about a specific Medical Scribe job, use the\noperation.","ref":"AWS.Transcribe.html#list_medical_scribe_jobs/3","title":"AWS.Transcribe.list_medical_scribe_jobs/3","type":"function"},{"doc":"Provides a list of medical transcription jobs that match the specified criteria.\n\nIf no criteria are specified, all medical transcription jobs are returned.\n\nTo get detailed information about a specific medical transcription job, use the\noperation.","ref":"AWS.Transcribe.html#list_medical_transcription_jobs/3","title":"AWS.Transcribe.list_medical_transcription_jobs/3","type":"function"},{"doc":"Provides a list of custom medical vocabularies that match the specified\ncriteria.\n\nIf no criteria are specified, all custom medical vocabularies are returned.\n\nTo get detailed information about a specific custom medical vocabulary, use the\noperation.","ref":"AWS.Transcribe.html#list_medical_vocabularies/3","title":"AWS.Transcribe.list_medical_vocabularies/3","type":"function"},{"doc":"Lists all tags associated with the specified transcription job, vocabulary,\nmodel, or resource.\n\nTo learn more about using tags with Amazon Transcribe, refer to [Tagging resources](https://docs.aws.amazon.com/transcribe/latest/dg/tagging.html).","ref":"AWS.Transcribe.html#list_tags_for_resource/3","title":"AWS.Transcribe.list_tags_for_resource/3","type":"function"},{"doc":"Provides a list of transcription jobs that match the specified criteria.\n\nIf no criteria are specified, all transcription jobs are returned.\n\nTo get detailed information about a specific transcription job, use the\noperation.","ref":"AWS.Transcribe.html#list_transcription_jobs/3","title":"AWS.Transcribe.list_transcription_jobs/3","type":"function"},{"doc":"Provides a list of custom vocabularies that match the specified criteria.\n\nIf no criteria are specified, all custom vocabularies are returned.\n\nTo get detailed information about a specific custom vocabulary, use the\noperation.","ref":"AWS.Transcribe.html#list_vocabularies/3","title":"AWS.Transcribe.list_vocabularies/3","type":"function"},{"doc":"Provides a list of custom vocabulary filters that match the specified criteria.\n\nIf no criteria are specified, all custom vocabularies are returned.\n\nTo get detailed information about a specific custom vocabulary filter, use the\noperation.","ref":"AWS.Transcribe.html#list_vocabulary_filters/3","title":"AWS.Transcribe.list_vocabulary_filters/3","type":"function"},{"doc":"","ref":"AWS.Transcribe.html#metadata/0","title":"AWS.Transcribe.metadata/0","type":"function"},{"doc":"Transcribes the audio from a customer service call and applies any additional\nRequest Parameters you choose to include in your request.\n\nIn addition to many standard transcription features, Call Analytics provides you\nwith call characteristics, call summarization, speaker sentiment, and optional\nredaction of your text transcript and your audio file. You can also apply custom\ncategories to flag specified conditions. To learn more about these features and\ninsights, refer to [Analyzing call center audio with Call Analytics](https://docs.aws.amazon.com/transcribe/latest/dg/call-analytics.html).\n\nIf you want to apply categories to your Call Analytics job, you must create them\nbefore submitting your job request. Categories cannot be retroactively applied\nto a job. To create a new category, use the operation. To learn more about Call\nAnalytics categories, see [Creating categories for post-call transcriptions](https://docs.aws.amazon.com/transcribe/latest/dg/tca-categories-batch.html)\nand [Creating categories for real-time transcriptions](https://docs.aws.amazon.com/transcribe/latest/dg/tca-categories-stream.html).\n\nTo make a `StartCallAnalyticsJob` request, you must first upload your media file\ninto an Amazon S3 bucket; you can then specify the Amazon S3 location of the\nfile using the `Media` parameter.\n\nNote that job queuing is enabled by default for Call Analytics jobs.\n\nYou must include the following parameters in your `StartCallAnalyticsJob`\nrequest:\n\n  * `region`: The Amazon Web Services Region where you are making your\nrequest. For a list of Amazon Web Services Regions supported with Amazon\nTranscribe, refer to [Amazon Transcribe endpoints and quotas](https://docs.aws.amazon.com/general/latest/gr/transcribe.html).\n\n  * `CallAnalyticsJobName`: A custom name that you create for your\ntranscription job that's unique within your Amazon Web Services account.\n\n  * `DataAccessRoleArn`: The Amazon Resource Name (ARN) of an IAM role\nthat has permissions to access the Amazon S3 bucket that contains your input\nfiles.\n\n  * `Media` (`MediaFileUri` or `RedactedMediaFileUri`): The Amazon S3\nlocation of your media file.\n\nWith Call Analytics, you can redact the audio contained in your media file by\nincluding `RedactedMediaFileUri`, instead of `MediaFileUri`, to specify the\nlocation of your input audio. If you choose to redact your audio, you can find\nyour redacted media at the location specified in the `RedactedMediaFileUri`\nfield of your response.","ref":"AWS.Transcribe.html#start_call_analytics_job/3","title":"AWS.Transcribe.start_call_analytics_job/3","type":"function"},{"doc":"Transcribes patient-clinician conversations and generates clinical notes.\n\nAmazon Web Services HealthScribe automatically provides rich conversation\ntranscripts, identifies speaker roles, classifies dialogues, extracts medical\nterms, and generates preliminary clinical notes. To learn more about these\nfeatures, refer to [Amazon Web Services HealthScribe](https://docs.aws.amazon.com/transcribe/latest/dg/health-scribe.html).\n\nTo make a `StartMedicalScribeJob` request, you must first upload your media file\ninto an Amazon S3 bucket; you can then specify the Amazon S3 location of the\nfile using the `Media` parameter.\n\nYou must include the following parameters in your `StartMedicalTranscriptionJob`\nrequest:\n\n  * `DataAccessRoleArn`: The ARN of an IAM role with the these minimum\npermissions: read permission on input file Amazon S3 bucket specified in\n`Media`, write permission on the Amazon S3 bucket specified in\n`OutputBucketName`, and full permissions on the KMS key specified in\n`OutputEncryptionKMSKeyId` (if set). The role should also allow\n`transcribe.amazonaws.com` to assume it.\n\n  * `Media` (`MediaFileUri`): The Amazon S3 location of your media\nfile.\n\n  * `MedicalScribeJobName`: A custom name you create for your\nMedicalScribe job that is unique within your Amazon Web Services account.\n\n  * `OutputBucketName`: The Amazon S3 bucket where you want your\noutput files stored.\n\n  * `Settings`: A `MedicalScribeSettings` obect that must set exactly\none of `ShowSpeakerLabels` or `ChannelIdentification` to true. If\n`ShowSpeakerLabels` is true, `MaxSpeakerLabels` must also be set.\n\n  * `ChannelDefinitions`: A `MedicalScribeChannelDefinitions` array\nshould be set if and only if the `ChannelIdentification` value of `Settings` is\nset to true.","ref":"AWS.Transcribe.html#start_medical_scribe_job/3","title":"AWS.Transcribe.start_medical_scribe_job/3","type":"function"},{"doc":"Transcribes the audio from a medical dictation or conversation and applies any\nadditional Request Parameters you choose to include in your request.\n\nIn addition to many standard transcription features, Amazon Transcribe Medical\nprovides you with a robust medical vocabulary and, optionally, content\nidentification, which adds flags to personal health information (PHI). To learn\nmore about these features, refer to [How Amazon Transcribe Medical works](https://docs.aws.amazon.com/transcribe/latest/dg/how-it-works-med.html).\n\nTo make a `StartMedicalTranscriptionJob` request, you must first upload your\nmedia file into an Amazon S3 bucket; you can then specify the Amazon S3 location\nof the file using the `Media` parameter.\n\nYou must include the following parameters in your `StartMedicalTranscriptionJob`\nrequest:\n\n  * `region`: The Amazon Web Services Region where you are making your\nrequest. For a list of Amazon Web Services Regions supported with Amazon\nTranscribe, refer to [Amazon Transcribe endpoints and quotas](https://docs.aws.amazon.com/general/latest/gr/transcribe.html).\n\n  * `MedicalTranscriptionJobName`: A custom name you create for your\ntranscription job that is unique within your Amazon Web Services account.\n\n  * `Media` (`MediaFileUri`): The Amazon S3 location of your media\nfile.\n\n  * `LanguageCode`: This must be `en-US`.\n\n  * `OutputBucketName`: The Amazon S3 bucket where you want your\ntranscript stored. If you want your output stored in a sub-folder of this\nbucket, you must also include `OutputKey`.\n\n  * `Specialty`: This must be `PRIMARYCARE`.\n\n  * `Type`: Choose whether your audio is a conversation or a\ndictation.","ref":"AWS.Transcribe.html#start_medical_transcription_job/3","title":"AWS.Transcribe.start_medical_transcription_job/3","type":"function"},{"doc":"Transcribes the audio from a media file and applies any additional Request\nParameters you choose to include in your request.\n\nTo make a `StartTranscriptionJob` request, you must first upload your media file\ninto an Amazon S3 bucket; you can then specify the Amazon S3 location of the\nfile using the `Media` parameter.\n\nYou must include the following parameters in your `StartTranscriptionJob`\nrequest:\n\n  * `region`: The Amazon Web Services Region where you are making your\nrequest. For a list of Amazon Web Services Regions supported with Amazon\nTranscribe, refer to [Amazon Transcribe endpoints and quotas](https://docs.aws.amazon.com/general/latest/gr/transcribe.html).\n\n  * `TranscriptionJobName`: A custom name you create for your\ntranscription job that is unique within your Amazon Web Services account.\n\n  * `Media` (`MediaFileUri`): The Amazon S3 location of your media\nfile.\n\n  * One of `LanguageCode`, `IdentifyLanguage`, or\n`IdentifyMultipleLanguages`: If you know the language of your media file,\nspecify it using the `LanguageCode` parameter; you can find all valid language\ncodes in the [Supported languages](https://docs.aws.amazon.com/transcribe/latest/dg/supported-languages.html)\ntable. If you do not know the languages spoken in your media, use either\n`IdentifyLanguage` or `IdentifyMultipleLanguages` and let Amazon Transcribe\nidentify the languages for you.","ref":"AWS.Transcribe.html#start_transcription_job/3","title":"AWS.Transcribe.start_transcription_job/3","type":"function"},{"doc":"Adds one or more custom tags, each in the form of a key:value pair, to the\nspecified resource.\n\nTo learn more about using tags with Amazon Transcribe, refer to [Tagging resources](https://docs.aws.amazon.com/transcribe/latest/dg/tagging.html).","ref":"AWS.Transcribe.html#tag_resource/3","title":"AWS.Transcribe.tag_resource/3","type":"function"},{"doc":"Removes the specified tags from the specified Amazon Transcribe resource.\n\nIf you include `UntagResource` in your request, you must also include\n`ResourceArn` and `TagKeys`.","ref":"AWS.Transcribe.html#untag_resource/3","title":"AWS.Transcribe.untag_resource/3","type":"function"},{"doc":"Updates the specified Call Analytics category with new rules.\n\nNote that the `UpdateCallAnalyticsCategory` operation overwrites all existing\nrules contained in the specified category. You cannot append additional rules\nonto an existing category.\n\nTo create a new category, see .","ref":"AWS.Transcribe.html#update_call_analytics_category/3","title":"AWS.Transcribe.update_call_analytics_category/3","type":"function"},{"doc":"Updates an existing custom medical vocabulary with new values.\n\nThis operation overwrites all existing information with your new values; you\ncannot append new terms onto an existing custom vocabulary.","ref":"AWS.Transcribe.html#update_medical_vocabulary/3","title":"AWS.Transcribe.update_medical_vocabulary/3","type":"function"},{"doc":"Updates an existing custom vocabulary with new values.\n\nThis operation overwrites all existing information with your new values; you\ncannot append new terms onto an existing custom vocabulary.","ref":"AWS.Transcribe.html#update_vocabulary/3","title":"AWS.Transcribe.update_vocabulary/3","type":"function"},{"doc":"Updates an existing custom vocabulary filter with a new list of words.\n\nThe new list you provide overwrites all previous entries; you cannot append new\nterms onto an existing custom vocabulary filter.","ref":"AWS.Transcribe.html#update_vocabulary_filter/3","title":"AWS.Transcribe.update_vocabulary_filter/3","type":"function"},{"doc":"Amazon Transcribe streaming offers three main types of real-time transcription:\n**Standard**, **Medical**, and **Call Analytics**.\n\n  * **Standard transcriptions** are the most common option. Refer to\nfor details.\n\n  * **Medical transcriptions** are tailored to medical professionals\nand incorporate medical terms. A common use case for this service is\ntranscribing doctor-patient dialogue in real time, so doctors can focus on their\npatient instead of taking notes. Refer to for details.\n\n  * **Call Analytics transcriptions** are designed for use with call\ncenter audio on two different channels; if you're looking for insight into\ncustomer service calls, use this option. Refer to for details.","ref":"AWS.TranscribeStreaming.html","title":"AWS.TranscribeStreaming","type":"module"},{"doc":"","ref":"AWS.TranscribeStreaming.html#metadata/0","title":"AWS.TranscribeStreaming.metadata/0","type":"function"},{"doc":"Starts a bidirectional HTTP/2 or WebSocket stream where audio is streamed to\nAmazon Transcribe and the transcription results are streamed to your\napplication.\n\nUse this operation for [Call Analytics](https://docs.aws.amazon.com/transcribe/latest/dg/call-analytics.html)\ntranscriptions.\n\nThe following parameters are required:\n\n  * `language-code`\n\n  * `media-encoding`\n\n  * `sample-rate`\n\nFor more information on streaming with Amazon Transcribe, see [Transcribing streaming\naudio](https://docs.aws.amazon.com/transcribe/latest/dg/streaming.html).","ref":"AWS.TranscribeStreaming.html#start_call_analytics_stream_transcription/3","title":"AWS.TranscribeStreaming.start_call_analytics_stream_transcription/3","type":"function"},{"doc":"Starts a bidirectional HTTP/2 or WebSocket stream where audio is streamed to\nAmazon Transcribe Medical and the transcription results are streamed to your\napplication.\n\nThe following parameters are required:\n\n  * `language-code`\n\n  * `media-encoding`\n\n  * `sample-rate`\n\nFor more information on streaming with Amazon Transcribe Medical, see\n[Transcribing streaming audio](https://docs.aws.amazon.com/transcribe/latest/dg/streaming.html).","ref":"AWS.TranscribeStreaming.html#start_medical_stream_transcription/3","title":"AWS.TranscribeStreaming.start_medical_stream_transcription/3","type":"function"},{"doc":"Starts a bidirectional HTTP/2 or WebSocket stream where audio is streamed to\nAmazon Transcribe and the transcription results are streamed to your\napplication.\n\nThe following parameters are required:\n\n  * `language-code` or `identify-language` or\n`identify-multiple-language`\n\n  * `media-encoding`\n\n  * `sample-rate`\n\nFor more information on streaming with Amazon Transcribe, see [Transcribing streaming\naudio](https://docs.aws.amazon.com/transcribe/latest/dg/streaming.html).","ref":"AWS.TranscribeStreaming.html#start_stream_transcription/3","title":"AWS.TranscribeStreaming.start_stream_transcription/3","type":"function"},{"doc":"Transfer Family is a fully managed service that enables the transfer of files\nover the File Transfer Protocol (FTP), File Transfer Protocol over SSL (FTPS),\nor Secure Shell (SSH) File Transfer Protocol (SFTP) directly into and out of\nAmazon Simple Storage Service (Amazon S3) or Amazon EFS.\n\nAdditionally, you can use Applicability Statement 2 (AS2) to transfer files into\nand out of Amazon S3. Amazon Web Services helps you seamlessly migrate your file\ntransfer workflows to Transfer Family by integrating with existing\nauthentication systems, and providing DNS routing with Amazon Route 53 so\nnothing changes for your customers and partners, or their applications. With\nyour data in Amazon S3, you can use it with Amazon Web Services for processing,\nanalytics, machine learning, and archiving. Getting started with Transfer Family\nis easy since there is no infrastructure to buy and set up.","ref":"AWS.Transfer.html","title":"AWS.Transfer","type":"module"},{"doc":"Used by administrators to choose which groups in the directory should have\naccess to upload and download files over the enabled protocols using Transfer\nFamily.\n\nFor example, a Microsoft Active Directory might contain 50,000 users, but only a\nsmall fraction might need the ability to transfer files to the server. An\nadministrator can use `CreateAccess` to limit the access to the correct set of\nusers who need this ability.","ref":"AWS.Transfer.html#create_access/3","title":"AWS.Transfer.create_access/3","type":"function"},{"doc":"Creates an agreement.\n\nAn agreement is a bilateral trading partner agreement, or partnership, between\nan Transfer Family server and an AS2 process. The agreement defines the file and\nmessage transfer relationship between the server and the AS2 process. To define\nan agreement, Transfer Family combines a server, local profile, partner profile,\ncertificate, and other attributes.\n\nThe partner is identified with the `PartnerProfileId`, and the AS2 process is\nidentified with the `LocalProfileId`.","ref":"AWS.Transfer.html#create_agreement/3","title":"AWS.Transfer.create_agreement/3","type":"function"},{"doc":"Creates the connector, which captures the parameters for a connection for the\nAS2 or SFTP protocol.\n\nFor AS2, the connector is required for sending files to an externally hosted AS2\nserver. For SFTP, the connector is required when sending files to an SFTP server\nor receiving files from an SFTP server. For more details about connectors, see\n[Create AS2 connectors](https://docs.aws.amazon.com/transfer/latest/userguide/create-b2b-server.html#configure-as2-connector)\nand [Create SFTP connectors](https://docs.aws.amazon.com/transfer/latest/userguide/configure-sftp-connector.html).\n\nYou must specify exactly one configuration object: either for AS2 (`As2Config`)\nor SFTP (`SftpConfig`).","ref":"AWS.Transfer.html#create_connector/3","title":"AWS.Transfer.create_connector/3","type":"function"},{"doc":"Creates the local or partner profile to use for AS2 transfers.","ref":"AWS.Transfer.html#create_profile/3","title":"AWS.Transfer.create_profile/3","type":"function"},{"doc":"Instantiates an auto-scaling virtual server based on the selected file transfer\nprotocol in Amazon Web Services.\n\nWhen you make updates to your file transfer protocol-enabled server or when you\nwork with users, use the service-generated `ServerId` property that is assigned\nto the newly created server.","ref":"AWS.Transfer.html#create_server/3","title":"AWS.Transfer.create_server/3","type":"function"},{"doc":"Creates a user and associates them with an existing file transfer\nprotocol-enabled server.\n\nYou can only create and associate users with servers that have the\n`IdentityProviderType` set to `SERVICE_MANAGED`. Using parameters for\n`CreateUser`, you can specify the user name, set the home directory, store the\nuser's public key, and assign the user's Identity and Access Management (IAM)\nrole. You can also optionally add a session policy, and assign metadata with\ntags that can be used to group and search for users.","ref":"AWS.Transfer.html#create_user/3","title":"AWS.Transfer.create_user/3","type":"function"},{"doc":"Allows you to create a workflow with specified steps and step details the\nworkflow invokes after file transfer completes.\n\nAfter creating a workflow, you can associate the workflow created with any\ntransfer servers by specifying the `workflow-details` field in `CreateServer`\nand `UpdateServer` operations.","ref":"AWS.Transfer.html#create_workflow/3","title":"AWS.Transfer.create_workflow/3","type":"function"},{"doc":"Allows you to delete the access specified in the `ServerID` and `ExternalID`\nparameters.","ref":"AWS.Transfer.html#delete_access/3","title":"AWS.Transfer.delete_access/3","type":"function"},{"doc":"Delete the agreement that's specified in the provided `AgreementId`.","ref":"AWS.Transfer.html#delete_agreement/3","title":"AWS.Transfer.delete_agreement/3","type":"function"},{"doc":"Deletes the certificate that's specified in the `CertificateId` parameter.","ref":"AWS.Transfer.html#delete_certificate/3","title":"AWS.Transfer.delete_certificate/3","type":"function"},{"doc":"Deletes the connector that's specified in the provided `ConnectorId`.","ref":"AWS.Transfer.html#delete_connector/3","title":"AWS.Transfer.delete_connector/3","type":"function"},{"doc":"Deletes the host key that's specified in the `HostKeyId` parameter.","ref":"AWS.Transfer.html#delete_host_key/3","title":"AWS.Transfer.delete_host_key/3","type":"function"},{"doc":"Deletes the profile that's specified in the `ProfileId` parameter.","ref":"AWS.Transfer.html#delete_profile/3","title":"AWS.Transfer.delete_profile/3","type":"function"},{"doc":"Deletes the file transfer protocol-enabled server that you specify.\n\nNo response returns from this operation.","ref":"AWS.Transfer.html#delete_server/3","title":"AWS.Transfer.delete_server/3","type":"function"},{"doc":"Deletes a user's Secure Shell (SSH) public key.","ref":"AWS.Transfer.html#delete_ssh_public_key/3","title":"AWS.Transfer.delete_ssh_public_key/3","type":"function"},{"doc":"Deletes the user belonging to a file transfer protocol-enabled server you\nspecify.\n\nNo response returns from this operation.\n\nWhen you delete a user from a server, the user's information is lost.","ref":"AWS.Transfer.html#delete_user/3","title":"AWS.Transfer.delete_user/3","type":"function"},{"doc":"Deletes the specified workflow.","ref":"AWS.Transfer.html#delete_workflow/3","title":"AWS.Transfer.delete_workflow/3","type":"function"},{"doc":"Describes the access that is assigned to the specific file transfer\nprotocol-enabled server, as identified by its `ServerId` property and its\n`ExternalId`.\n\nThe response from this call returns the properties of the access that is\nassociated with the `ServerId` value that was specified.","ref":"AWS.Transfer.html#describe_access/3","title":"AWS.Transfer.describe_access/3","type":"function"},{"doc":"Describes the agreement that's identified by the `AgreementId`.","ref":"AWS.Transfer.html#describe_agreement/3","title":"AWS.Transfer.describe_agreement/3","type":"function"},{"doc":"Describes the certificate that's identified by the `CertificateId`.","ref":"AWS.Transfer.html#describe_certificate/3","title":"AWS.Transfer.describe_certificate/3","type":"function"},{"doc":"Describes the connector that's identified by the `ConnectorId.`","ref":"AWS.Transfer.html#describe_connector/3","title":"AWS.Transfer.describe_connector/3","type":"function"},{"doc":"You can use `DescribeExecution` to check the details of the execution of the\nspecified workflow.\n\nThis API call only returns details for in-progress workflows.\n\nIf you provide an ID for an execution that is not in progress, or if the\nexecution doesn't match the specified workflow ID, you receive a\n`ResourceNotFound` exception.","ref":"AWS.Transfer.html#describe_execution/3","title":"AWS.Transfer.describe_execution/3","type":"function"},{"doc":"Returns the details of the host key that's specified by the `HostKeyId` and\n`ServerId`.","ref":"AWS.Transfer.html#describe_host_key/3","title":"AWS.Transfer.describe_host_key/3","type":"function"},{"doc":"Returns the details of the profile that's specified by the `ProfileId`.","ref":"AWS.Transfer.html#describe_profile/3","title":"AWS.Transfer.describe_profile/3","type":"function"},{"doc":"Describes the security policy that is attached to your file transfer\nprotocol-enabled server.\n\nThe response contains a description of the security policy's properties. For\nmore information about security policies, see [Working with security policies](https://docs.aws.amazon.com/transfer/latest/userguide/security-policies.html).","ref":"AWS.Transfer.html#describe_security_policy/3","title":"AWS.Transfer.describe_security_policy/3","type":"function"},{"doc":"Describes a file transfer protocol-enabled server that you specify by passing\nthe `ServerId` parameter.\n\nThe response contains a description of a server's properties. When you set\n`EndpointType` to VPC, the response will contain the `EndpointDetails`.","ref":"AWS.Transfer.html#describe_server/3","title":"AWS.Transfer.describe_server/3","type":"function"},{"doc":"Describes the user assigned to the specific file transfer protocol-enabled\nserver, as identified by its `ServerId` property.\n\nThe response from this call returns the properties of the user associated with\nthe `ServerId` value that was specified.","ref":"AWS.Transfer.html#describe_user/3","title":"AWS.Transfer.describe_user/3","type":"function"},{"doc":"Describes the specified workflow.","ref":"AWS.Transfer.html#describe_workflow/3","title":"AWS.Transfer.describe_workflow/3","type":"function"},{"doc":"Imports the signing and encryption certificates that you need to create local\n(AS2) profiles and partner profiles.","ref":"AWS.Transfer.html#import_certificate/3","title":"AWS.Transfer.import_certificate/3","type":"function"},{"doc":"Adds a host key to the server that's specified by the `ServerId` parameter.","ref":"AWS.Transfer.html#import_host_key/3","title":"AWS.Transfer.import_host_key/3","type":"function"},{"doc":"Adds a Secure Shell (SSH) public key to a Transfer Family user identified by a\n`UserName` value assigned to the specific file transfer protocol-enabled server,\nidentified by `ServerId`.\n\nThe response returns the `UserName` value, the `ServerId` value, and the name of\nthe `SshPublicKeyId`.","ref":"AWS.Transfer.html#import_ssh_public_key/3","title":"AWS.Transfer.import_ssh_public_key/3","type":"function"},{"doc":"Lists the details for all the accesses you have on your server.","ref":"AWS.Transfer.html#list_accesses/3","title":"AWS.Transfer.list_accesses/3","type":"function"},{"doc":"Returns a list of the agreements for the server that's identified by the\n`ServerId` that you supply.\n\nIf you want to limit the results to a certain number, supply a value for the\n`MaxResults` parameter. If you ran the command previously and received a value\nfor `NextToken`, you can supply that value to continue listing agreements from\nwhere you left off.","ref":"AWS.Transfer.html#list_agreements/3","title":"AWS.Transfer.list_agreements/3","type":"function"},{"doc":"Returns a list of the current certificates that have been imported into Transfer\nFamily.\n\nIf you want to limit the results to a certain number, supply a value for the\n`MaxResults` parameter. If you ran the command previously and received a value\nfor the `NextToken` parameter, you can supply that value to continue listing\ncertificates from where you left off.","ref":"AWS.Transfer.html#list_certificates/3","title":"AWS.Transfer.list_certificates/3","type":"function"},{"doc":"Lists the connectors for the specified Region.","ref":"AWS.Transfer.html#list_connectors/3","title":"AWS.Transfer.list_connectors/3","type":"function"},{"doc":"Lists all in-progress executions for the specified workflow.\n\nIf the specified workflow ID cannot be found, `ListExecutions` returns a\n`ResourceNotFound` exception.","ref":"AWS.Transfer.html#list_executions/3","title":"AWS.Transfer.list_executions/3","type":"function"},{"doc":"Returns a list of host keys for the server that's specified by the `ServerId`\nparameter.","ref":"AWS.Transfer.html#list_host_keys/3","title":"AWS.Transfer.list_host_keys/3","type":"function"},{"doc":"Returns a list of the profiles for your system.\n\nIf you want to limit the results to a certain number, supply a value for the\n`MaxResults` parameter. If you ran the command previously and received a value\nfor `NextToken`, you can supply that value to continue listing profiles from\nwhere you left off.","ref":"AWS.Transfer.html#list_profiles/3","title":"AWS.Transfer.list_profiles/3","type":"function"},{"doc":"Lists the security policies that are attached to your file transfer\nprotocol-enabled servers.","ref":"AWS.Transfer.html#list_security_policies/3","title":"AWS.Transfer.list_security_policies/3","type":"function"},{"doc":"Lists the file transfer protocol-enabled servers that are associated with your\nAmazon Web Services account.","ref":"AWS.Transfer.html#list_servers/3","title":"AWS.Transfer.list_servers/3","type":"function"},{"doc":"Lists all of the tags associated with the Amazon Resource Name (ARN) that you\nspecify.\n\nThe resource can be a user, server, or role.","ref":"AWS.Transfer.html#list_tags_for_resource/3","title":"AWS.Transfer.list_tags_for_resource/3","type":"function"},{"doc":"Lists the users for a file transfer protocol-enabled server that you specify by\npassing the `ServerId` parameter.","ref":"AWS.Transfer.html#list_users/3","title":"AWS.Transfer.list_users/3","type":"function"},{"doc":"Lists all workflows associated with your Amazon Web Services account for your\ncurrent region.","ref":"AWS.Transfer.html#list_workflows/3","title":"AWS.Transfer.list_workflows/3","type":"function"},{"doc":"","ref":"AWS.Transfer.html#metadata/0","title":"AWS.Transfer.metadata/0","type":"function"},{"doc":"Sends a callback for asynchronous custom steps.\n\nThe `ExecutionId`, `WorkflowId`, and `Token` are passed to the target resource\nduring execution of a custom step of a workflow. You must include those with\ntheir callback as well as providing a status.","ref":"AWS.Transfer.html#send_workflow_step_state/3","title":"AWS.Transfer.send_workflow_step_state/3","type":"function"},{"doc":"Begins a file transfer between local Amazon Web Services storage and a remote\nAS2 or SFTP server.\n\n  * For an AS2 connector, you specify the `ConnectorId` and one or\nmore `SendFilePaths` to identify the files you want to transfer.\n\n  * For an SFTP connector, the file transfer can be either outbound or\ninbound. In both cases, you specify the `ConnectorId`. Depending on the\ndirection of the transfer, you also specify the following items:\n\n    * If you are transferring file from a partner's SFTP\nserver to Amazon Web Services storage, you specify one or more\n`RetreiveFilePaths` to identify the files you want to transfer, and a\n`LocalDirectoryPath` to specify the destination folder.\n\n    * If you are transferring file to a partner's SFTP\nserver from Amazon Web Services storage, you specify one or more `SendFilePaths`\nto identify the files you want to transfer, and a `RemoteDirectoryPath` to\nspecify the destination folder.","ref":"AWS.Transfer.html#start_file_transfer/3","title":"AWS.Transfer.start_file_transfer/3","type":"function"},{"doc":"Changes the state of a file transfer protocol-enabled server from `OFFLINE` to\n`ONLINE`.\n\nIt has no impact on a server that is already `ONLINE`. An `ONLINE` server can\naccept and process file transfer jobs.\n\nThe state of `STARTING` indicates that the server is in an intermediate state,\neither not fully able to respond, or not fully online. The values of\n`START_FAILED` can indicate an error condition.\n\nNo response is returned from this call.","ref":"AWS.Transfer.html#start_server/3","title":"AWS.Transfer.start_server/3","type":"function"},{"doc":"Changes the state of a file transfer protocol-enabled server from `ONLINE` to\n`OFFLINE`.\n\nAn `OFFLINE` server cannot accept and process file transfer jobs. Information\ntied to your server, such as server and user properties, are not affected by\nstopping your server.\n\nStopping the server does not reduce or impact your file transfer protocol\nendpoint billing; you must delete the server to stop being billed.\n\nThe state of `STOPPING` indicates that the server is in an intermediate state,\neither not fully able to respond, or not fully offline. The values of\n`STOP_FAILED` can indicate an error condition.\n\nNo response is returned from this call.","ref":"AWS.Transfer.html#stop_server/3","title":"AWS.Transfer.stop_server/3","type":"function"},{"doc":"Attaches a key-value pair to a resource, as identified by its Amazon Resource\nName (ARN).\n\nResources are users, servers, roles, and other entities.\n\nThere is no response returned from this call.","ref":"AWS.Transfer.html#tag_resource/3","title":"AWS.Transfer.tag_resource/3","type":"function"},{"doc":"Tests whether your SFTP connector is set up successfully.\n\nWe highly recommend that you call this operation to test your ability to\ntransfer files between local Amazon Web Services storage and a trading partner's\nSFTP server.","ref":"AWS.Transfer.html#test_connection/3","title":"AWS.Transfer.test_connection/3","type":"function"},{"doc":"If the `IdentityProviderType` of a file transfer protocol-enabled server is\n`AWS_DIRECTORY_SERVICE` or `API_Gateway`, tests whether your identity provider\nis set up successfully.\n\nWe highly recommend that you call this operation to test your authentication\nmethod as soon as you create your server. By doing so, you can troubleshoot\nissues with the identity provider integration to ensure that your users can\nsuccessfully use the service.\n\nThe `ServerId` and `UserName` parameters are required. The `ServerProtocol`,\n`SourceIp`, and `UserPassword` are all optional.\n\nNote the following:\n\n  * You cannot use `TestIdentityProvider` if the\n`IdentityProviderType` of your server is `SERVICE_MANAGED`.\n\n  * `TestIdentityProvider` does not work with keys: it only accepts\npasswords.\n\n  * `TestIdentityProvider` can test the password operation for a\ncustom Identity Provider that handles keys and passwords.\n\n  * If you provide any incorrect values for any parameters, the\n`Response` field is empty.\n\n  * If you provide a server ID for a server that uses service-managed\nusers, you get an error:\n\n` An error occurred (InvalidRequestException) when calling the\nTestIdentityProvider operation: s-*server-ID* not configured for external auth `\n\n  * If you enter a Server ID for the `--server-id` parameter that does\nnot identify an actual Transfer server, you receive the following error:\n\n`An error occurred (ResourceNotFoundException) when calling the\nTestIdentityProvider operation: Unknown server`.\n\nIt is possible your sever is in a different region. You can specify a region by\nadding the following: `--region region-code`, such as `--region us-east-2` to\nspecify a server in **US East (Ohio)**.","ref":"AWS.Transfer.html#test_identity_provider/3","title":"AWS.Transfer.test_identity_provider/3","type":"function"},{"doc":"Detaches a key-value pair from a resource, as identified by its Amazon Resource\nName (ARN).\n\nResources are users, servers, roles, and other entities.\n\nNo response is returned from this call.","ref":"AWS.Transfer.html#untag_resource/3","title":"AWS.Transfer.untag_resource/3","type":"function"},{"doc":"Allows you to update parameters for the access specified in the `ServerID` and\n`ExternalID` parameters.","ref":"AWS.Transfer.html#update_access/3","title":"AWS.Transfer.update_access/3","type":"function"},{"doc":"Updates some of the parameters for an existing agreement.\n\nProvide the `AgreementId` and the `ServerId` for the agreement that you want to\nupdate, along with the new values for the parameters to update.","ref":"AWS.Transfer.html#update_agreement/3","title":"AWS.Transfer.update_agreement/3","type":"function"},{"doc":"Updates the active and inactive dates for a certificate.","ref":"AWS.Transfer.html#update_certificate/3","title":"AWS.Transfer.update_certificate/3","type":"function"},{"doc":"Updates some of the parameters for an existing connector.\n\nProvide the `ConnectorId` for the connector that you want to update, along with\nthe new values for the parameters to update.","ref":"AWS.Transfer.html#update_connector/3","title":"AWS.Transfer.update_connector/3","type":"function"},{"doc":"Updates the description for the host key that's specified by the `ServerId` and\n`HostKeyId` parameters.","ref":"AWS.Transfer.html#update_host_key/3","title":"AWS.Transfer.update_host_key/3","type":"function"},{"doc":"Updates some of the parameters for an existing profile.\n\nProvide the `ProfileId` for the profile that you want to update, along with the\nnew values for the parameters to update.","ref":"AWS.Transfer.html#update_profile/3","title":"AWS.Transfer.update_profile/3","type":"function"},{"doc":"Updates the file transfer protocol-enabled server's properties after that server\nhas been created.\n\nThe `UpdateServer` call returns the `ServerId` of the server you updated.","ref":"AWS.Transfer.html#update_server/3","title":"AWS.Transfer.update_server/3","type":"function"},{"doc":"Assigns new properties to a user.\n\nParameters you pass modify any or all of the following: the home directory,\nrole, and policy for the `UserName` and `ServerId` you specify.\n\nThe response returns the `ServerId` and the `UserName` for the updated user.","ref":"AWS.Transfer.html#update_user/3","title":"AWS.Transfer.update_user/3","type":"function"},{"doc":"Provides translation of the input content from the source language to the target\nlanguage.","ref":"AWS.Translate.html","title":"AWS.Translate","type":"module"},{"doc":"Creates a parallel data resource in Amazon Translate by importing an input file\nfrom Amazon S3.\n\nParallel data files contain examples that show how you want segments of text to\nbe translated. By adding parallel data, you can influence the style, tone, and\nword choice in your translation output.","ref":"AWS.Translate.html#create_parallel_data/3","title":"AWS.Translate.create_parallel_data/3","type":"function"},{"doc":"Deletes a parallel data resource in Amazon Translate.","ref":"AWS.Translate.html#delete_parallel_data/3","title":"AWS.Translate.delete_parallel_data/3","type":"function"},{"doc":"A synchronous action that deletes a custom terminology.","ref":"AWS.Translate.html#delete_terminology/3","title":"AWS.Translate.delete_terminology/3","type":"function"},{"doc":"Gets the properties associated with an asynchronous batch translation job\nincluding name, ID, status, source and target languages, input/output S3\nbuckets, and so on.","ref":"AWS.Translate.html#describe_text_translation_job/3","title":"AWS.Translate.describe_text_translation_job/3","type":"function"},{"doc":"Provides information about a parallel data resource.","ref":"AWS.Translate.html#get_parallel_data/3","title":"AWS.Translate.get_parallel_data/3","type":"function"},{"doc":"Retrieves a custom terminology.","ref":"AWS.Translate.html#get_terminology/3","title":"AWS.Translate.get_terminology/3","type":"function"},{"doc":"Creates or updates a custom terminology, depending on whether one already exists\nfor the given terminology name.\n\nImporting a terminology with the same name as an existing one will merge the\nterminologies based on the chosen merge strategy. The only supported merge\nstrategy is OVERWRITE, where the imported terminology overwrites the existing\nterminology of the same name.\n\nIf you import a terminology that overwrites an existing one, the new terminology\ntakes up to 10 minutes to fully propagate. After that, translations have access\nto the new terminology.","ref":"AWS.Translate.html#import_terminology/3","title":"AWS.Translate.import_terminology/3","type":"function"},{"doc":"Provides a list of languages (RFC-5646 codes and names) that Amazon Translate\nsupports.","ref":"AWS.Translate.html#list_languages/3","title":"AWS.Translate.list_languages/3","type":"function"},{"doc":"Provides a list of your parallel data resources in Amazon Translate.","ref":"AWS.Translate.html#list_parallel_data/3","title":"AWS.Translate.list_parallel_data/3","type":"function"},{"doc":"Lists all tags associated with a given Amazon Translate resource.\n\nFor more information, see [ Tagging your resources](https://docs.aws.amazon.com/translate/latest/dg/tagging.html).","ref":"AWS.Translate.html#list_tags_for_resource/3","title":"AWS.Translate.list_tags_for_resource/3","type":"function"},{"doc":"Provides a list of custom terminologies associated with your account.","ref":"AWS.Translate.html#list_terminologies/3","title":"AWS.Translate.list_terminologies/3","type":"function"},{"doc":"Gets a list of the batch translation jobs that you have submitted.","ref":"AWS.Translate.html#list_text_translation_jobs/3","title":"AWS.Translate.list_text_translation_jobs/3","type":"function"},{"doc":"","ref":"AWS.Translate.html#metadata/0","title":"AWS.Translate.metadata/0","type":"function"},{"doc":"Starts an asynchronous batch translation job.\n\nUse batch translation jobs to translate large volumes of text across multiple\ndocuments at once. For batch translation, you can input documents with different\nsource languages (specify `auto` as the source language). You can specify one or\nmore target languages. Batch translation translates each input document into\neach of the target languages. For more information, see [Asynchronous batch processing](https://docs.aws.amazon.com/translate/latest/dg/async.html).\n\nBatch translation jobs can be described with the `DescribeTextTranslationJob`\noperation, listed with the `ListTextTranslationJobs` operation, and stopped with\nthe `StopTextTranslationJob` operation.","ref":"AWS.Translate.html#start_text_translation_job/3","title":"AWS.Translate.start_text_translation_job/3","type":"function"},{"doc":"Stops an asynchronous batch translation job that is in progress.\n\nIf the job's state is `IN_PROGRESS`, the job will be marked for termination and\nput into the `STOP_REQUESTED` state. If the job completes before it can be\nstopped, it is put into the `COMPLETED` state. Otherwise, the job is put into\nthe `STOPPED` state.\n\nAsynchronous batch translation jobs are started with the\n`StartTextTranslationJob` operation. You can use the\n`DescribeTextTranslationJob` or `ListTextTranslationJobs` operations to get a\nbatch translation job's `JobId`.","ref":"AWS.Translate.html#stop_text_translation_job/3","title":"AWS.Translate.stop_text_translation_job/3","type":"function"},{"doc":"Associates a specific tag with a resource.\n\nA tag is a key-value pair that adds as a metadata to a resource. For more\ninformation, see [ Tagging your resources](https://docs.aws.amazon.com/translate/latest/dg/tagging.html).","ref":"AWS.Translate.html#tag_resource/3","title":"AWS.Translate.tag_resource/3","type":"function"},{"doc":"Translates the input document from the source language to the target language.\n\nThis synchronous operation supports text, HTML, or Word documents as the input\ndocument. `TranslateDocument` supports translations from English to any\nsupported language, and from any supported language to English. Therefore,\nspecify either the source language code or the target language code as “en”\n(English).\n\nIf you set the `Formality` parameter, the request will fail if the target\nlanguage does not support formality. For a list of target languages that support\nformality, see [Setting formality](https://docs.aws.amazon.com/translate/latest/dg/customizing-translations-formality.html).","ref":"AWS.Translate.html#translate_document/3","title":"AWS.Translate.translate_document/3","type":"function"},{"doc":"Translates input text from the source language to the target language.\n\nFor a list of available languages and language codes, see [Supported languages](https://docs.aws.amazon.com/translate/latest/dg/what-is-languages.html).","ref":"AWS.Translate.html#translate_text/3","title":"AWS.Translate.translate_text/3","type":"function"},{"doc":"Removes a specific tag associated with an Amazon Translate resource.\n\nFor more information, see [ Tagging your resources](https://docs.aws.amazon.com/translate/latest/dg/tagging.html).","ref":"AWS.Translate.html#untag_resource/3","title":"AWS.Translate.untag_resource/3","type":"function"},{"doc":"Updates a previously created parallel data resource by importing a new input\nfile from Amazon S3.","ref":"AWS.Translate.html#update_parallel_data/3","title":"AWS.Translate.update_parallel_data/3","type":"function"},{"doc":"TrustedAdvisor Public API","ref":"AWS.TrustedAdvisor.html","title":"AWS.TrustedAdvisor","type":"module"},{"doc":"Get a specific recommendation within an AWS Organizations organization.\n\nThis API supports only prioritized recommendations.","ref":"AWS.TrustedAdvisor.html#get_organization_recommendation/3","title":"AWS.TrustedAdvisor.get_organization_recommendation/3","type":"function"},{"doc":"Get a specific Recommendation","ref":"AWS.TrustedAdvisor.html#get_recommendation/3","title":"AWS.TrustedAdvisor.get_recommendation/3","type":"function"},{"doc":"List a filterable set of Checks","ref":"AWS.TrustedAdvisor.html#list_checks/8","title":"AWS.TrustedAdvisor.list_checks/8","type":"function"},{"doc":"Lists the accounts that own the resources for an organization aggregate\nrecommendation.\n\nThis API only supports prioritized recommendations.","ref":"AWS.TrustedAdvisor.html#list_organization_recommendation_accounts/6","title":"AWS.TrustedAdvisor.list_organization_recommendation_accounts/6","type":"function"},{"doc":"List Resources of a Recommendation within an Organization.\n\nThis API only supports prioritized recommendations.","ref":"AWS.TrustedAdvisor.html#list_organization_recommendation_resources/8","title":"AWS.TrustedAdvisor.list_organization_recommendation_resources/8","type":"function"},{"doc":"List a filterable set of Recommendations within an Organization.\n\nThis API only supports prioritized recommendations.","ref":"AWS.TrustedAdvisor.html#list_organization_recommendations/12","title":"AWS.TrustedAdvisor.list_organization_recommendations/12","type":"function"},{"doc":"List Resources of a Recommendation","ref":"AWS.TrustedAdvisor.html#list_recommendation_resources/7","title":"AWS.TrustedAdvisor.list_recommendation_resources/7","type":"function"},{"doc":"List a filterable set of Recommendations","ref":"AWS.TrustedAdvisor.html#list_recommendations/12","title":"AWS.TrustedAdvisor.list_recommendations/12","type":"function"},{"doc":"","ref":"AWS.TrustedAdvisor.html#metadata/0","title":"AWS.TrustedAdvisor.metadata/0","type":"function"},{"doc":"Update the lifecyle of a Recommendation within an Organization.\n\nThis API only supports prioritized recommendations.","ref":"AWS.TrustedAdvisor.html#update_organization_recommendation_lifecycle/4","title":"AWS.TrustedAdvisor.update_organization_recommendation_lifecycle/4","type":"function"},{"doc":"Update the lifecyle of a Recommendation.\n\nThis API only supports prioritized recommendations.","ref":"AWS.TrustedAdvisor.html#update_recommendation_lifecycle/4","title":"AWS.TrustedAdvisor.update_recommendation_lifecycle/4","type":"function"},{"doc":"Amazon VPC Lattice is a fully managed application networking service that you\nuse to connect, secure, and monitor all of your services across multiple\naccounts and virtual private clouds (VPCs).\n\nAmazon VPC Lattice interconnects your microservices and legacy services within a\nlogical boundary, so that you can discover and manage them more efficiently. For\nmore information, see the [Amazon VPC Lattice User Guide](https://docs.aws.amazon.com/vpc-lattice/latest/ug/)","ref":"AWS.VPCLattice.html","title":"AWS.VPCLattice","type":"module"},{"doc":"Updates the listener rules in a batch.\n\nYou can use this operation to change the priority of listener rules. This can be\nuseful when bulk updating or swapping rule priority.","ref":"AWS.VPCLattice.html#batch_update_rule/5","title":"AWS.VPCLattice.batch_update_rule/5","type":"function"},{"doc":"Enables access logs to be sent to Amazon CloudWatch, Amazon S3, and Amazon\nKinesis Data Firehose.\n\nThe service network owner can use the access logs to audit the services in the\nnetwork. The service network owner will only see access logs from clients and\nservices that are associated with their service network. Access log entries\nrepresent traffic originated from VPCs associated with that network. For more\ninformation, see [Access logs](https://docs.aws.amazon.com/vpc-lattice/latest/ug/monitoring-access-logs.html)\nin the *Amazon VPC Lattice User Guide*.","ref":"AWS.VPCLattice.html#create_access_log_subscription/3","title":"AWS.VPCLattice.create_access_log_subscription/3","type":"function"},{"doc":"Creates a listener for a service.\n\nBefore you start using your Amazon VPC Lattice service, you must add one or more\nlisteners. A listener is a process that checks for connection requests to your\nservices. For more information, see\n[Listeners](https://docs.aws.amazon.com/vpc-lattice/latest/ug/listeners.html) in\nthe *Amazon VPC Lattice User Guide*.","ref":"AWS.VPCLattice.html#create_listener/4","title":"AWS.VPCLattice.create_listener/4","type":"function"},{"doc":"Creates a listener rule.\n\nEach listener has a default rule for checking connection requests, but you can\ndefine additional rules. Each rule consists of a priority, one or more actions,\nand one or more conditions. For more information, see [Listener rules](https://docs.aws.amazon.com/vpc-lattice/latest/ug/listeners.html#listener-rules)\nin the *Amazon VPC Lattice User Guide*.","ref":"AWS.VPCLattice.html#create_rule/5","title":"AWS.VPCLattice.create_rule/5","type":"function"},{"doc":"Creates a service.\n\nA service is any software application that can run on instances containers, or\nserverless functions within an account or virtual private cloud (VPC).\n\nFor more information, see\n[Services](https://docs.aws.amazon.com/vpc-lattice/latest/ug/services.html) in\nthe *Amazon VPC Lattice User Guide*.","ref":"AWS.VPCLattice.html#create_service/3","title":"AWS.VPCLattice.create_service/3","type":"function"},{"doc":"Creates a service network.\n\nA service network is a logical boundary for a collection of services. You can\nassociate services and VPCs with a service network.\n\nFor more information, see [Service networks](https://docs.aws.amazon.com/vpc-lattice/latest/ug/service-networks.html)\nin the *Amazon VPC Lattice User Guide*.","ref":"AWS.VPCLattice.html#create_service_network/3","title":"AWS.VPCLattice.create_service_network/3","type":"function"},{"doc":"Associates a service with a service network.\n\nYou can't use this operation if the service and service network are already\nassociated or if there is a disassociation or deletion in progress. If the\nassociation fails, you can retry the operation by deleting the association and\nrecreating it.\n\nYou cannot associate a service and service network that are shared with a\ncaller. The caller must own either the service or the service network.\n\nAs a result of this operation, the association is created in the service network\naccount and the association owner account.","ref":"AWS.VPCLattice.html#create_service_network_service_association/3","title":"AWS.VPCLattice.create_service_network_service_association/3","type":"function"},{"doc":"Associates a VPC with a service network.\n\nWhen you associate a VPC with the service network, it enables all the resources\nwithin that VPC to be clients and communicate with other services in the service\nnetwork. For more information, see [Manage VPC associations](https://docs.aws.amazon.com/vpc-lattice/latest/ug/service-network-associations.html#service-network-vpc-associations)\nin the *Amazon VPC Lattice User Guide*.\n\nYou can't use this operation if there is a disassociation in progress. If the\nassociation fails, retry by deleting the association and recreating it.\n\nAs a result of this operation, the association gets created in the service\nnetwork account and the VPC owner account.\n\nOnce a security group is added to the VPC association it cannot be removed. You\ncan add or update the security groups being used for the VPC association once a\nsecurity group is attached. To remove all security groups you must reassociate\nthe VPC.","ref":"AWS.VPCLattice.html#create_service_network_vpc_association/3","title":"AWS.VPCLattice.create_service_network_vpc_association/3","type":"function"},{"doc":"Creates a target group.\n\nA target group is a collection of targets, or compute resources, that run your\napplication or service. A target group can only be used by a single service.\n\nFor more information, see [Target groups](https://docs.aws.amazon.com/vpc-lattice/latest/ug/target-groups.html) in\nthe *Amazon VPC Lattice User Guide*.","ref":"AWS.VPCLattice.html#create_target_group/3","title":"AWS.VPCLattice.create_target_group/3","type":"function"},{"doc":"Deletes the specified access log subscription.","ref":"AWS.VPCLattice.html#delete_access_log_subscription/4","title":"AWS.VPCLattice.delete_access_log_subscription/4","type":"function"},{"doc":"Deletes the specified auth policy.\n\nIf an auth is set to `Amazon Web Services_IAM` and the auth policy is deleted,\nall requests will be denied by default. If you are trying to remove the auth\npolicy completely, you must set the auth_type to `NONE`. If auth is enabled on\nthe resource, but no auth policy is set, all requests will be denied.","ref":"AWS.VPCLattice.html#delete_auth_policy/4","title":"AWS.VPCLattice.delete_auth_policy/4","type":"function"},{"doc":"Deletes the specified listener.","ref":"AWS.VPCLattice.html#delete_listener/5","title":"AWS.VPCLattice.delete_listener/5","type":"function"},{"doc":"Deletes the specified resource policy.","ref":"AWS.VPCLattice.html#delete_resource_policy/4","title":"AWS.VPCLattice.delete_resource_policy/4","type":"function"},{"doc":"Deletes a listener rule.\n\nEach listener has a default rule for checking connection requests, but you can\ndefine additional rules. Each rule consists of a priority, one or more actions,\nand one or more conditions. You can delete additional listener rules, but you\ncannot delete the default rule.\n\nFor more information, see [Listener rules](https://docs.aws.amazon.com/vpc-lattice/latest/ug/listeners.html#listener-rules)\nin the *Amazon VPC Lattice User Guide*.","ref":"AWS.VPCLattice.html#delete_rule/6","title":"AWS.VPCLattice.delete_rule/6","type":"function"},{"doc":"Deletes a service.\n\nA service can't be deleted if it's associated with a service network. If you\ndelete a service, all resources related to the service, such as the resource\npolicy, auth policy, listeners, listener rules, and access log subscriptions,\nare also deleted. For more information, see [Delete a service](https://docs.aws.amazon.com/vpc-lattice/latest/ug/services.html#delete-service)\nin the *Amazon VPC Lattice User Guide*.","ref":"AWS.VPCLattice.html#delete_service/4","title":"AWS.VPCLattice.delete_service/4","type":"function"},{"doc":"Deletes a service network.\n\nYou can only delete the service network if there is no service or VPC associated\nwith it. If you delete a service network, all resources related to the service\nnetwork, such as the resource policy, auth policy, and access log subscriptions,\nare also deleted. For more information, see [Delete a service network](https://docs.aws.amazon.com/vpc-lattice/latest/ug/service-networks.html#delete-service-network)\nin the *Amazon VPC Lattice User Guide*.","ref":"AWS.VPCLattice.html#delete_service_network/4","title":"AWS.VPCLattice.delete_service_network/4","type":"function"},{"doc":"Deletes the association between a specified service and the specific service\nnetwork.\n\nThis request will fail if an association is still in progress.","ref":"AWS.VPCLattice.html#delete_service_network_service_association/4","title":"AWS.VPCLattice.delete_service_network_service_association/4","type":"function"},{"doc":"Disassociates the VPC from the service network.\n\nYou can't disassociate the VPC if there is a create or update association in\nprogress.","ref":"AWS.VPCLattice.html#delete_service_network_vpc_association/4","title":"AWS.VPCLattice.delete_service_network_vpc_association/4","type":"function"},{"doc":"Deletes a target group.\n\nYou can't delete a target group if it is used in a listener rule or if the\ntarget group creation is in progress.","ref":"AWS.VPCLattice.html#delete_target_group/4","title":"AWS.VPCLattice.delete_target_group/4","type":"function"},{"doc":"Deregisters the specified targets from the specified target group.","ref":"AWS.VPCLattice.html#deregister_targets/4","title":"AWS.VPCLattice.deregister_targets/4","type":"function"},{"doc":"Retrieves information about the specified access log subscription.","ref":"AWS.VPCLattice.html#get_access_log_subscription/3","title":"AWS.VPCLattice.get_access_log_subscription/3","type":"function"},{"doc":"Retrieves information about the auth policy for the specified service or service\nnetwork.","ref":"AWS.VPCLattice.html#get_auth_policy/3","title":"AWS.VPCLattice.get_auth_policy/3","type":"function"},{"doc":"Retrieves information about the specified listener for the specified service.","ref":"AWS.VPCLattice.html#get_listener/4","title":"AWS.VPCLattice.get_listener/4","type":"function"},{"doc":"Retrieves information about the resource policy.\n\nThe resource policy is an IAM policy created by AWS RAM on behalf of the\nresource owner when they share a resource.","ref":"AWS.VPCLattice.html#get_resource_policy/3","title":"AWS.VPCLattice.get_resource_policy/3","type":"function"},{"doc":"Retrieves information about listener rules.\n\nYou can also retrieve information about the default listener rule. For more\ninformation, see [Listener rules](https://docs.aws.amazon.com/vpc-lattice/latest/ug/listeners.html#listener-rules)\nin the *Amazon VPC Lattice User Guide*.","ref":"AWS.VPCLattice.html#get_rule/5","title":"AWS.VPCLattice.get_rule/5","type":"function"},{"doc":"Retrieves information about the specified service.","ref":"AWS.VPCLattice.html#get_service/3","title":"AWS.VPCLattice.get_service/3","type":"function"},{"doc":"Retrieves information about the specified service network.","ref":"AWS.VPCLattice.html#get_service_network/3","title":"AWS.VPCLattice.get_service_network/3","type":"function"},{"doc":"Retrieves information about the specified association between a service network\nand a service.","ref":"AWS.VPCLattice.html#get_service_network_service_association/3","title":"AWS.VPCLattice.get_service_network_service_association/3","type":"function"},{"doc":"Retrieves information about the association between a service network and a VPC.","ref":"AWS.VPCLattice.html#get_service_network_vpc_association/3","title":"AWS.VPCLattice.get_service_network_vpc_association/3","type":"function"},{"doc":"Retrieves information about the specified target group.","ref":"AWS.VPCLattice.html#get_target_group/3","title":"AWS.VPCLattice.get_target_group/3","type":"function"},{"doc":"Lists all access log subscriptions for the specified service network or service.","ref":"AWS.VPCLattice.html#list_access_log_subscriptions/5","title":"AWS.VPCLattice.list_access_log_subscriptions/5","type":"function"},{"doc":"Lists the listeners for the specified service.","ref":"AWS.VPCLattice.html#list_listeners/5","title":"AWS.VPCLattice.list_listeners/5","type":"function"},{"doc":"Lists the rules for the listener.","ref":"AWS.VPCLattice.html#list_rules/6","title":"AWS.VPCLattice.list_rules/6","type":"function"},{"doc":"Lists the associations between the service network and the service.\n\nYou can filter the list either by service or service network. You must provide\neither the service network identifier or the service identifier.\n\nEvery association in Amazon VPC Lattice is given a unique Amazon Resource Name\n(ARN), such as when a service network is associated with a VPC or when a service\nis associated with a service network. If the association is for a resource that\nis shared with another account, the association will include the local account\nID as the prefix in the ARN for each account the resource is shared with.","ref":"AWS.VPCLattice.html#list_service_network_service_associations/6","title":"AWS.VPCLattice.list_service_network_service_associations/6","type":"function"},{"doc":"Lists the service network and VPC associations.\n\nYou can filter the list either by VPC or service network. You must provide\neither the service network identifier or the VPC identifier.","ref":"AWS.VPCLattice.html#list_service_network_vpc_associations/6","title":"AWS.VPCLattice.list_service_network_vpc_associations/6","type":"function"},{"doc":"Lists the service networks owned by the caller account or shared with the caller\naccount.\n\nAlso includes the account ID in the ARN to show which account owns the service\nnetwork.","ref":"AWS.VPCLattice.html#list_service_networks/4","title":"AWS.VPCLattice.list_service_networks/4","type":"function"},{"doc":"Lists the services owned by the caller account or shared with the caller\naccount.","ref":"AWS.VPCLattice.html#list_services/4","title":"AWS.VPCLattice.list_services/4","type":"function"},{"doc":"Lists the tags for the specified resource.","ref":"AWS.VPCLattice.html#list_tags_for_resource/3","title":"AWS.VPCLattice.list_tags_for_resource/3","type":"function"},{"doc":"Lists your target groups.\n\nYou can narrow your search by using the filters below in your request.","ref":"AWS.VPCLattice.html#list_target_groups/6","title":"AWS.VPCLattice.list_target_groups/6","type":"function"},{"doc":"Lists the targets for the target group.\n\nBy default, all targets are included. You can use this API to check the health\nstatus of targets. You can also ﬁlter the results by target.","ref":"AWS.VPCLattice.html#list_targets/4","title":"AWS.VPCLattice.list_targets/4","type":"function"},{"doc":"","ref":"AWS.VPCLattice.html#metadata/0","title":"AWS.VPCLattice.metadata/0","type":"function"},{"doc":"Creates or updates the auth policy.","ref":"AWS.VPCLattice.html#put_auth_policy/4","title":"AWS.VPCLattice.put_auth_policy/4","type":"function"},{"doc":"Attaches a resource-based permission policy to a service or service network.\n\nThe policy must contain the same actions and condition statements as the Amazon\nWeb Services Resource Access Manager permission for sharing services and service\nnetworks.","ref":"AWS.VPCLattice.html#put_resource_policy/4","title":"AWS.VPCLattice.put_resource_policy/4","type":"function"},{"doc":"Registers the targets with the target group.\n\nIf it's a Lambda target, you can only have one target in a target group.","ref":"AWS.VPCLattice.html#register_targets/4","title":"AWS.VPCLattice.register_targets/4","type":"function"},{"doc":"Adds the specified tags to the specified resource.","ref":"AWS.VPCLattice.html#tag_resource/4","title":"AWS.VPCLattice.tag_resource/4","type":"function"},{"doc":"Removes the specified tags from the specified resource.","ref":"AWS.VPCLattice.html#untag_resource/4","title":"AWS.VPCLattice.untag_resource/4","type":"function"},{"doc":"Updates the specified access log subscription.","ref":"AWS.VPCLattice.html#update_access_log_subscription/4","title":"AWS.VPCLattice.update_access_log_subscription/4","type":"function"},{"doc":"Updates the specified listener for the specified service.","ref":"AWS.VPCLattice.html#update_listener/5","title":"AWS.VPCLattice.update_listener/5","type":"function"},{"doc":"Updates a rule for the listener.\n\nYou can't modify a default listener rule. To modify a default listener rule, use\n`UpdateListener`.","ref":"AWS.VPCLattice.html#update_rule/6","title":"AWS.VPCLattice.update_rule/6","type":"function"},{"doc":"Updates the specified service.","ref":"AWS.VPCLattice.html#update_service/4","title":"AWS.VPCLattice.update_service/4","type":"function"},{"doc":"Updates the specified service network.","ref":"AWS.VPCLattice.html#update_service_network/4","title":"AWS.VPCLattice.update_service_network/4","type":"function"},{"doc":"Updates the service network and VPC association.\n\nOnce you add a security group, it cannot be removed.","ref":"AWS.VPCLattice.html#update_service_network_vpc_association/4","title":"AWS.VPCLattice.update_service_network_vpc_association/4","type":"function"},{"doc":"Updates the specified target group.","ref":"AWS.VPCLattice.html#update_target_group/4","title":"AWS.VPCLattice.update_target_group/4","type":"function"},{"doc":"Amazon Verified Permissions is a permissions management service from Amazon Web\nServices.\n\nYou can use Verified Permissions to manage permissions for your application, and\nauthorize user access based on those permissions. Using Verified Permissions,\napplication developers can grant access based on information about the users,\nresources, and requested actions. You can also evaluate additional information\nlike group membership, attributes of the resources, and session context, such as\ntime of request and IP addresses. Verified Permissions manages these permissions\nby letting you create and store authorization policies for your applications,\nsuch as consumer-facing web sites and enterprise business systems.\n\nVerified Permissions uses Cedar as the policy language to express your\npermission requirements. Cedar supports both role-based access control (RBAC)\nand attribute-based access control (ABAC) authorization models.\n\nFor more information about configuring, administering, and using Amazon Verified\nPermissions in your applications, see the [Amazon Verified Permissions User Guide](https://docs.aws.amazon.com/verifiedpermissions/latest/userguide/).\n\nFor more information about the Cedar policy language, see the [Cedar Policy Language Guide](https://docs.cedarpolicy.com/).\n\nWhen you write Cedar policies that reference principals, resources and actions,\nyou can define the unique identifiers used for each of those elements. We\nstrongly recommend that you follow these best practices:","ref":"AWS.VerifiedPermissions.html","title":"AWS.VerifiedPermissions","type":"module"},{"doc":"principal and resource identifiers.\n\nFor example, if user `jane` leaves the company, and you later let someone else\nuse the name `jane`, then that new user automatically gets access to everything\ngranted by policies that still reference `User::\"jane\"`. Cedar can’t distinguish\nbetween the new user and the old. This applies to both principal and resource\nidentifiers. Always use identifiers that are guaranteed unique and never reused\nto ensure that you don’t unintentionally grant access because of the presence of\nan old identifier in a policy.\n\nWhere you use a UUID for an entity, we recommend that you follow it with the //\ncomment specifier and the ‘friendly’ name of your entity. This helps to make\nyour policies easier to understand. For example: principal ==\nUser::\"a1b2c3d4-e5f6-a1b2-c3d4-EXAMPLE11111\", // alice","ref":"AWS.VerifiedPermissions.html#module-use-values-like-universally-unique-identifiers-uuids-for-all","title":"Use values like universally unique identifiers (UUIDs) for all - AWS.VerifiedPermissions","type":"module"},{"doc":"information as part of the unique identifier for your principals or resources.\nThese identifiers are included in log entries shared in CloudTrail trails.\n\nSeveral operations return structures that appear similar, but have different\npurposes. As new functionality is added to the product, the structure used in a\nparameter of one operation might need to change in a way that wouldn't make\nsense for the same parameter in a different operation. To help you understand\nthe purpose of each, the following naming convention is used for the structures:\n\n  * Parameter type structures that end in `Detail` are used in `Get`\noperations.\n\n  * Parameter type structures that end in `Item` are used in `List`\noperations.\n\n  * Parameter type structures that use neither suffix are used in the\nmutating (create and update) operations.","ref":"AWS.VerifiedPermissions.html#module-do-not-include-personally-identifying-confidential-or-sensitive","title":"Do not include personally identifying, confidential, or sensitive - AWS.VerifiedPermissions","type":"module"},{"doc":"Makes a series of decisions about multiple authorization requests for one\nprincipal or resource.\n\nEach request contains the equivalent content of an `IsAuthorized` request:\nprincipal, action, resource, and context. Either the `principal` or the\n`resource` parameter must be identical across all requests. For example,\nVerified Permissions won't evaluate a pair of requests where `bob` views\n`photo1` and `alice` views `photo2`. Authorization of `bob` to view `photo1` and\n`photo2`, or `bob` and `alice` to view `photo1`, are valid batches.\n\nThe request is evaluated against all policies in the specified policy store that\nmatch the entities that you declare. The result of the decisions is a series of\n`Allow` or `Deny` responses, along with the IDs of the policies that produced\neach decision.\n\nThe `entities` of a `BatchIsAuthorized` API request can contain up to 100\nprincipals and up to 100 resources. The `requests` of a `BatchIsAuthorized` API\nrequest can contain up to 30 requests.\n\nThe `BatchIsAuthorized` operation doesn't have its own IAM permission. To\nauthorize this operation for Amazon Web Services principals, include the\npermission `verifiedpermissions:IsAuthorized` in their IAM policies.","ref":"AWS.VerifiedPermissions.html#batch_is_authorized/3","title":"AWS.VerifiedPermissions.batch_is_authorized/3","type":"function"},{"doc":"Creates a reference to an Amazon Cognito user pool as an external identity\nprovider (IdP).\n\nAfter you create an identity source, you can use the identities provided by the\nIdP as proxies for the principal in authorization queries that use the\n[IsAuthorizedWithToken](https://docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_IsAuthorizedWithToken.html) operation. These identities take the form of tokens that contain claims about\nthe user, such as IDs, attributes and group memberships. Amazon Cognito provides\nboth identity tokens and access tokens, and Verified Permissions can use either\nor both. Any combination of identity and access tokens results in the same Cedar\nprincipal. Verified Permissions automatically translates the information about\nthe identities into the standard Cedar attributes that can be evaluated by your\npolicies. Because the Amazon Cognito identity and access tokens can contain\ndifferent information, the tokens you choose to use determine which principal\nattributes are available to access when evaluating Cedar policies.\n\nIf you delete a Amazon Cognito user pool or user, tokens from that deleted pool\nor that deleted user continue to be usable until they expire.\n\nTo reference a user from this identity source in your Cedar policies, use the\nfollowing syntax.\n\n*IdentityType::\" | *\n\nWhere `IdentityType` is the string that you provide to the `PrincipalEntityType`\nparameter for this operation. The `CognitoUserPoolId` and `CognitoClientId` are\ndefined by the Amazon Cognito user pool.\n\nVerified Permissions is * [eventually\nconsistent](https://wikipedia.org/wiki/Eventual_consistency) *. It can take a\nfew seconds for a new or changed element to be propagate through the service and\nbe visible in the results of other Verified Permissions operations.","ref":"AWS.VerifiedPermissions.html#create_identity_source/3","title":"AWS.VerifiedPermissions.create_identity_source/3","type":"function"},{"doc":"Creates a Cedar policy and saves it in the specified policy store.\n\nYou can create either a static policy or a policy linked to a policy template.\n\n  * To create a static policy, provide the Cedar policy text in the\n`StaticPolicy` section of the `PolicyDefinition`.\n\n  * To create a policy that is dynamically linked to a policy\ntemplate, specify the policy template ID and the principal and resource to\nassociate with this policy in the `templateLinked` section of the\n`PolicyDefinition`. If the policy template is ever updated, any policies linked\nto the policy template automatically use the updated template.\n\nCreating a policy causes it to be validated against the schema in the policy\nstore. If the policy doesn't pass validation, the operation fails and the policy\nisn't stored.\n\nVerified Permissions is * [eventually consistent](https://wikipedia.org/wiki/Eventual_consistency) *. It can take a\nfew seconds for a new or changed element to be propagate through the service and\nbe visible in the results of other Verified Permissions operations.","ref":"AWS.VerifiedPermissions.html#create_policy/3","title":"AWS.VerifiedPermissions.create_policy/3","type":"function"},{"doc":"Creates a policy store.\n\nA policy store is a container for policy resources.\n\nAlthough [Cedar supports multiple namespaces](https://docs.cedarpolicy.com/schema/schema.html#namespace), Verified\nPermissions currently supports only one namespace per policy store.\n\nVerified Permissions is * [eventually consistent](https://wikipedia.org/wiki/Eventual_consistency) *. It can take a\nfew seconds for a new or changed element to be propagate through the service and\nbe visible in the results of other Verified Permissions operations.","ref":"AWS.VerifiedPermissions.html#create_policy_store/3","title":"AWS.VerifiedPermissions.create_policy_store/3","type":"function"},{"doc":"Creates a policy template.\n\nA template can use placeholders for the principal and resource. A template must\nbe instantiated into a policy by associating it with specific principals and\nresources to use for the placeholders. That instantiated policy can then be\nconsidered in authorization decisions. The instantiated policy works identically\nto any other policy, except that it is dynamically linked to the template. If\nthe template changes, then any policies that are linked to that template are\nimmediately updated as well.\n\nVerified Permissions is * [eventually consistent](https://wikipedia.org/wiki/Eventual_consistency) *. It can take a\nfew seconds for a new or changed element to be propagate through the service and\nbe visible in the results of other Verified Permissions operations.","ref":"AWS.VerifiedPermissions.html#create_policy_template/3","title":"AWS.VerifiedPermissions.create_policy_template/3","type":"function"},{"doc":"Deletes an identity source that references an identity provider (IdP) such as\nAmazon Cognito.\n\nAfter you delete the identity source, you can no longer use tokens for\nidentities from that identity source to represent principals in authorization\nqueries made using\n[IsAuthorizedWithToken](https://docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_IsAuthorizedWithToken.html).\noperations.","ref":"AWS.VerifiedPermissions.html#delete_identity_source/3","title":"AWS.VerifiedPermissions.delete_identity_source/3","type":"function"},{"doc":"Deletes the specified policy from the policy store.\n\nThis operation is idempotent; if you specify a policy that doesn't exist, the\nrequest response returns a successful `HTTP 200` status code.","ref":"AWS.VerifiedPermissions.html#delete_policy/3","title":"AWS.VerifiedPermissions.delete_policy/3","type":"function"},{"doc":"Deletes the specified policy store.\n\nThis operation is idempotent. If you specify a policy store that does not exist,\nthe request response will still return a successful HTTP 200 status code.","ref":"AWS.VerifiedPermissions.html#delete_policy_store/3","title":"AWS.VerifiedPermissions.delete_policy_store/3","type":"function"},{"doc":"Deletes the specified policy template from the policy store.\n\nThis operation also deletes any policies that were created from the specified\npolicy template. Those policies are immediately removed from all future API\nresponses, and are asynchronously deleted from the policy store.","ref":"AWS.VerifiedPermissions.html#delete_policy_template/3","title":"AWS.VerifiedPermissions.delete_policy_template/3","type":"function"},{"doc":"Retrieves the details about the specified identity source.","ref":"AWS.VerifiedPermissions.html#get_identity_source/3","title":"AWS.VerifiedPermissions.get_identity_source/3","type":"function"},{"doc":"Retrieves information about the specified policy.","ref":"AWS.VerifiedPermissions.html#get_policy/3","title":"AWS.VerifiedPermissions.get_policy/3","type":"function"},{"doc":"Retrieves details about a policy store.","ref":"AWS.VerifiedPermissions.html#get_policy_store/3","title":"AWS.VerifiedPermissions.get_policy_store/3","type":"function"},{"doc":"Retrieve the details for the specified policy template in the specified policy\nstore.","ref":"AWS.VerifiedPermissions.html#get_policy_template/3","title":"AWS.VerifiedPermissions.get_policy_template/3","type":"function"},{"doc":"Retrieve the details for the specified schema in the specified policy store.","ref":"AWS.VerifiedPermissions.html#get_schema/3","title":"AWS.VerifiedPermissions.get_schema/3","type":"function"},{"doc":"Makes an authorization decision about a service request described in the\nparameters.\n\nThe information in the parameters can also define additional context that\nVerified Permissions can include in the evaluation. The request is evaluated\nagainst all matching policies in the specified policy store. The result of the\ndecision is either `Allow` or `Deny`, along with a list of the policies that\nresulted in the decision.","ref":"AWS.VerifiedPermissions.html#is_authorized/3","title":"AWS.VerifiedPermissions.is_authorized/3","type":"function"},{"doc":"Makes an authorization decision about a service request described in the\nparameters.\n\nThe principal in this request comes from an external identity source in the form\nof an identity token formatted as a [JSON web token (JWT)](https://wikipedia.org/wiki/JSON_Web_Token). The information in the\nparameters can also define additional context that Verified Permissions can\ninclude in the evaluation. The request is evaluated against all matching\npolicies in the specified policy store. The result of the decision is either\n`Allow` or `Deny`, along with a list of the policies that resulted in the\ndecision.\n\nIf you specify the `identityToken` parameter, then this operation derives the\nprincipal from that token. You must not also include that principal in the\n`entities` parameter or the operation fails and reports a conflict between the\ntwo entity sources.\n\nIf you provide only an `accessToken`, then you can include the entity as part of\nthe `entities` parameter to provide additional attributes.\n\nAt this time, Verified Permissions accepts tokens from only Amazon Cognito.\n\nVerified Permissions validates each token that is specified in a request by\nchecking its expiration date and its signature.\n\nIf you delete a Amazon Cognito user pool or user, tokens from that deleted pool\nor that deleted user continue to be usable until they expire.","ref":"AWS.VerifiedPermissions.html#is_authorized_with_token/3","title":"AWS.VerifiedPermissions.is_authorized_with_token/3","type":"function"},{"doc":"Returns a paginated list of all of the identity sources defined in the specified\npolicy store.","ref":"AWS.VerifiedPermissions.html#list_identity_sources/3","title":"AWS.VerifiedPermissions.list_identity_sources/3","type":"function"},{"doc":"Returns a paginated list of all policies stored in the specified policy store.","ref":"AWS.VerifiedPermissions.html#list_policies/3","title":"AWS.VerifiedPermissions.list_policies/3","type":"function"},{"doc":"Returns a paginated list of all policy stores in the calling Amazon Web Services\naccount.","ref":"AWS.VerifiedPermissions.html#list_policy_stores/3","title":"AWS.VerifiedPermissions.list_policy_stores/3","type":"function"},{"doc":"Returns a paginated list of all policy templates in the specified policy store.","ref":"AWS.VerifiedPermissions.html#list_policy_templates/3","title":"AWS.VerifiedPermissions.list_policy_templates/3","type":"function"},{"doc":"","ref":"AWS.VerifiedPermissions.html#metadata/0","title":"AWS.VerifiedPermissions.metadata/0","type":"function"},{"doc":"Creates or updates the policy schema in the specified policy store.\n\nThe schema is used to validate any Cedar policies and policy templates submitted\nto the policy store. Any changes to the schema validate only policies and\ntemplates submitted after the schema change. Existing policies and templates are\nnot re-evaluated against the changed schema. If you later update a policy, then\nit is evaluated against the new schema at that time.\n\nVerified Permissions is * [eventually consistent](https://wikipedia.org/wiki/Eventual_consistency) *. It can take a\nfew seconds for a new or changed element to be propagate through the service and\nbe visible in the results of other Verified Permissions operations.","ref":"AWS.VerifiedPermissions.html#put_schema/3","title":"AWS.VerifiedPermissions.put_schema/3","type":"function"},{"doc":"Updates the specified identity source to use a new identity provider (IdP)\nsource, or to change the mapping of identities from the IdP to a different\nprincipal entity type.\n\nVerified Permissions is * [eventually consistent](https://wikipedia.org/wiki/Eventual_consistency) *. It can take a\nfew seconds for a new or changed element to be propagate through the service and\nbe visible in the results of other Verified Permissions operations.","ref":"AWS.VerifiedPermissions.html#update_identity_source/3","title":"AWS.VerifiedPermissions.update_identity_source/3","type":"function"},{"doc":"Modifies a Cedar static policy in the specified policy store.\n\nYou can change only certain elements of the\n[UpdatePolicyDefinition](https://docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_UpdatePolicyInput.html#amazonverifiedpermissions-UpdatePolicy-request-UpdatePolicyDefinition) parameter. You can directly update only static policies. To change a\ntemplate-linked policy, you must update the template instead, using\n[UpdatePolicyTemplate](https://docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_UpdatePolicyTemplate.html).\n\n   If policy validation is enabled in the policy store, then updating\na static policy causes Verified Permissions to validate the policy against the\nschema in the policy store. If the updated static policy doesn't pass\nvalidation, the operation fails and the update isn't stored.\n\n   When you edit a static policy, You can change only certain elements\nof a static policy:\n\n     The action referenced by the policy.\n\n     A condition clause, such as when and unless.\n\nYou can't change these elements of a static policy:\n\n     Changing a policy from a static policy to a\ntemplate-linked policy.\n\n     Changing the effect of a static policy from permit or\nforbid.\n\n     The principal referenced by a static policy.\n\n     The resource referenced by a static policy.\n\n   To update a template-linked policy, you must update the template\ninstead.\n\nVerified Permissions is * [eventually consistent](https://wikipedia.org/wiki/Eventual_consistency) *. It can take a\nfew seconds for a new or changed element to be propagate through the service and\nbe visible in the results of other Verified Permissions operations.","ref":"AWS.VerifiedPermissions.html#update_policy/3","title":"AWS.VerifiedPermissions.update_policy/3","type":"function"},{"doc":"Modifies the validation setting for a policy store.\n\nVerified Permissions is * [eventually consistent](https://wikipedia.org/wiki/Eventual_consistency) *. It can take a\nfew seconds for a new or changed element to be propagate through the service and\nbe visible in the results of other Verified Permissions operations.","ref":"AWS.VerifiedPermissions.html#update_policy_store/3","title":"AWS.VerifiedPermissions.update_policy_store/3","type":"function"},{"doc":"Updates the specified policy template.\n\nYou can update only the description and the some elements of the\n[policyBody](https://docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_UpdatePolicyTemplate.html#amazonverifiedpermissions-UpdatePolicyTemplate-request-policyBody).  Changes you make to the policy template content are immediately (within the\nconstraints of eventual consistency) reflected in authorization decisions that\ninvolve all template-linked policies instantiated from this template.\n\nVerified Permissions is * [eventually\nconsistent](https://wikipedia.org/wiki/Eventual_consistency) *. It can take a\nfew seconds for a new or changed element to be propagate through the service and\nbe visible in the results of other Verified Permissions operations.","ref":"AWS.VerifiedPermissions.html#update_policy_template/3","title":"AWS.VerifiedPermissions.update_policy_template/3","type":"function"},{"doc":"Amazon Connect Voice ID provides real-time caller authentication and fraud risk\ndetection, which make voice interactions in contact centers more secure and\nefficient.","ref":"AWS.VoiceID.html","title":"AWS.VoiceID","type":"module"},{"doc":"Associates the fraudsters with the watchlist specified in the same domain.","ref":"AWS.VoiceID.html#associate_fraudster/3","title":"AWS.VoiceID.associate_fraudster/3","type":"function"},{"doc":"Creates a domain that contains all Amazon Connect Voice ID data, such as\nspeakers, fraudsters, customer audio, and voiceprints.\n\nEvery domain is created with a default watchlist that fraudsters can be a part\nof.","ref":"AWS.VoiceID.html#create_domain/3","title":"AWS.VoiceID.create_domain/3","type":"function"},{"doc":"Creates a watchlist that fraudsters can be a part of.","ref":"AWS.VoiceID.html#create_watchlist/3","title":"AWS.VoiceID.create_watchlist/3","type":"function"},{"doc":"Deletes the specified domain from Voice ID.","ref":"AWS.VoiceID.html#delete_domain/3","title":"AWS.VoiceID.delete_domain/3","type":"function"},{"doc":"Deletes the specified fraudster from Voice ID.\n\nThis action disassociates the fraudster from any watchlists it is a part of.","ref":"AWS.VoiceID.html#delete_fraudster/3","title":"AWS.VoiceID.delete_fraudster/3","type":"function"},{"doc":"Deletes the specified speaker from Voice ID.","ref":"AWS.VoiceID.html#delete_speaker/3","title":"AWS.VoiceID.delete_speaker/3","type":"function"},{"doc":"Deletes the specified watchlist from Voice ID.\n\nThis API throws an exception when there are fraudsters in the watchlist that you\nare trying to delete. You must delete the fraudsters, and then delete the\nwatchlist. Every domain has a default watchlist which cannot be deleted.","ref":"AWS.VoiceID.html#delete_watchlist/3","title":"AWS.VoiceID.delete_watchlist/3","type":"function"},{"doc":"Describes the specified domain.","ref":"AWS.VoiceID.html#describe_domain/3","title":"AWS.VoiceID.describe_domain/3","type":"function"},{"doc":"Describes the specified fraudster.","ref":"AWS.VoiceID.html#describe_fraudster/3","title":"AWS.VoiceID.describe_fraudster/3","type":"function"},{"doc":"Describes the specified fraudster registration job.","ref":"AWS.VoiceID.html#describe_fraudster_registration_job/3","title":"AWS.VoiceID.describe_fraudster_registration_job/3","type":"function"},{"doc":"Describes the specified speaker.","ref":"AWS.VoiceID.html#describe_speaker/3","title":"AWS.VoiceID.describe_speaker/3","type":"function"},{"doc":"Describes the specified speaker enrollment job.","ref":"AWS.VoiceID.html#describe_speaker_enrollment_job/3","title":"AWS.VoiceID.describe_speaker_enrollment_job/3","type":"function"},{"doc":"Describes the specified watchlist.","ref":"AWS.VoiceID.html#describe_watchlist/3","title":"AWS.VoiceID.describe_watchlist/3","type":"function"},{"doc":"Disassociates the fraudsters from the watchlist specified.\n\nVoice ID always expects a fraudster to be a part of at least one watchlist. If\nyou try to disassociate a fraudster from its only watchlist, a\n`ValidationException` is thrown.","ref":"AWS.VoiceID.html#disassociate_fraudster/3","title":"AWS.VoiceID.disassociate_fraudster/3","type":"function"},{"doc":"Evaluates a specified session based on audio data accumulated during a streaming\nAmazon Connect Voice ID call.","ref":"AWS.VoiceID.html#evaluate_session/3","title":"AWS.VoiceID.evaluate_session/3","type":"function"},{"doc":"Lists all the domains in the Amazon Web Services account.","ref":"AWS.VoiceID.html#list_domains/3","title":"AWS.VoiceID.list_domains/3","type":"function"},{"doc":"Lists all the fraudster registration jobs in the domain with the given\n`JobStatus`.\n\nIf `JobStatus` is not provided, this lists all fraudster registration jobs in\nthe given domain.","ref":"AWS.VoiceID.html#list_fraudster_registration_jobs/3","title":"AWS.VoiceID.list_fraudster_registration_jobs/3","type":"function"},{"doc":"Lists all fraudsters in a specified watchlist or domain.","ref":"AWS.VoiceID.html#list_fraudsters/3","title":"AWS.VoiceID.list_fraudsters/3","type":"function"},{"doc":"Lists all the speaker enrollment jobs in the domain with the specified\n`JobStatus`.\n\nIf `JobStatus` is not provided, this lists all jobs with all possible speaker\nenrollment job statuses.","ref":"AWS.VoiceID.html#list_speaker_enrollment_jobs/3","title":"AWS.VoiceID.list_speaker_enrollment_jobs/3","type":"function"},{"doc":"Lists all speakers in a specified domain.","ref":"AWS.VoiceID.html#list_speakers/3","title":"AWS.VoiceID.list_speakers/3","type":"function"},{"doc":"Lists all tags associated with a specified Voice ID resource.","ref":"AWS.VoiceID.html#list_tags_for_resource/3","title":"AWS.VoiceID.list_tags_for_resource/3","type":"function"},{"doc":"Lists all watchlists in a specified domain.","ref":"AWS.VoiceID.html#list_watchlists/3","title":"AWS.VoiceID.list_watchlists/3","type":"function"},{"doc":"","ref":"AWS.VoiceID.html#metadata/0","title":"AWS.VoiceID.metadata/0","type":"function"},{"doc":"Opts out a speaker from Voice ID.\n\nA speaker can be opted out regardless of whether or not they already exist in\nVoice ID. If they don't yet exist, a new speaker is created in an opted out\nstate. If they already exist, their existing status is overridden and they are\nopted out. Enrollment and evaluation authentication requests are rejected for\nopted out speakers, and opted out speakers have no voice embeddings stored in\nVoice ID.","ref":"AWS.VoiceID.html#opt_out_speaker/3","title":"AWS.VoiceID.opt_out_speaker/3","type":"function"},{"doc":"Starts a new batch fraudster registration job using provided details.","ref":"AWS.VoiceID.html#start_fraudster_registration_job/3","title":"AWS.VoiceID.start_fraudster_registration_job/3","type":"function"},{"doc":"Starts a new batch speaker enrollment job using specified details.","ref":"AWS.VoiceID.html#start_speaker_enrollment_job/3","title":"AWS.VoiceID.start_speaker_enrollment_job/3","type":"function"},{"doc":"Tags a Voice ID resource with the provided list of tags.","ref":"AWS.VoiceID.html#tag_resource/3","title":"AWS.VoiceID.tag_resource/3","type":"function"},{"doc":"Removes specified tags from a specified Amazon Connect Voice ID resource.","ref":"AWS.VoiceID.html#untag_resource/3","title":"AWS.VoiceID.untag_resource/3","type":"function"},{"doc":"Updates the specified domain.\n\nThis API has clobber behavior, and clears and replaces all attributes. If an\noptional field, such as 'Description' is not provided, it is removed from the\ndomain.","ref":"AWS.VoiceID.html#update_domain/3","title":"AWS.VoiceID.update_domain/3","type":"function"},{"doc":"Updates the specified watchlist.\n\nEvery domain has a default watchlist which cannot be updated.","ref":"AWS.VoiceID.html#update_watchlist/3","title":"AWS.VoiceID.update_watchlist/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nThis is the *AWS WAF Classic API Reference* for using AWS WAF Classic with\nAmazon CloudFront. The AWS WAF Classic actions and data types listed in the\nreference are available for protecting Amazon CloudFront distributions. You can\nuse these actions and data types via the endpoint *waf.amazonaws.com*. This\nguide is for developers who need detailed information about the AWS WAF Classic\nAPI actions, data types, and errors. For detailed information about AWS WAF\nClassic features and an overview of how to use the AWS WAF Classic API, see the\n[AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.","ref":"AWS.WAF.html","title":"AWS.WAF","type":"module"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nCreates a `ByteMatchSet`. You then use `UpdateByteMatchSet` to identify the part\nof a web request that you want AWS WAF to inspect, such as the values of the\n`User-Agent` header or the query string. For example, you can create a\n`ByteMatchSet` that matches any requests with `User-Agent` headers that contain\nthe string `BadBot`. You can then configure AWS WAF to reject those requests.\n\nTo create and configure a `ByteMatchSet`, perform the following steps:\n\n  1. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of a `CreateByteMatchSet` request.\n\n  2. Submit a `CreateByteMatchSet` request.\n\n  3. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of an `UpdateByteMatchSet` request.\n\n  4. Submit an `UpdateByteMatchSet` request to specify the part of the\nrequest that you want AWS WAF to inspect (for example, the header or the URI)\nand the value that you want AWS WAF to watch for.\n\nFor more information about how to use the AWS WAF API to allow or block HTTP\nrequests, see the [AWS WAF Developer Guide](https://docs.aws.amazon.com/waf/latest/developerguide/).","ref":"AWS.WAF.html#create_byte_match_set/3","title":"AWS.WAF.create_byte_match_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nCreates an `GeoMatchSet`, which you use to specify which web requests you want\nto allow or block based on the country that the requests originate from. For\nexample, if you're receiving a lot of requests from one or more countries and\nyou want to block the requests, you can create an `GeoMatchSet` that contains\nthose countries and then configure AWS WAF to block the requests.\n\nTo create and configure a `GeoMatchSet`, perform the following steps:\n\n  1. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of a `CreateGeoMatchSet` request.\n\n  2. Submit a `CreateGeoMatchSet` request.\n\n  3. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of an `UpdateGeoMatchSet` request.\n\n  4. Submit an `UpdateGeoMatchSetSet` request to specify the countries\nthat you want AWS WAF to watch for.\n\nFor more information about how to use the AWS WAF API to allow or block HTTP\nrequests, see the [AWS WAF Developer Guide](https://docs.aws.amazon.com/waf/latest/developerguide/).","ref":"AWS.WAF.html#create_geo_match_set/3","title":"AWS.WAF.create_geo_match_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nCreates an `IPSet`, which you use to specify which web requests that you want to\nallow or block based on the IP addresses that the requests originate from. For\nexample, if you're receiving a lot of requests from one or more individual IP\naddresses or one or more ranges of IP addresses and you want to block the\nrequests, you can create an `IPSet` that contains those IP addresses and then\nconfigure AWS WAF to block the requests.\n\nTo create and configure an `IPSet`, perform the following steps:\n\n  1. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of a `CreateIPSet` request.\n\n  2. Submit a `CreateIPSet` request.\n\n  3. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of an `UpdateIPSet` request.\n\n  4. Submit an `UpdateIPSet` request to specify the IP addresses that\nyou want AWS WAF to watch for.\n\nFor more information about how to use the AWS WAF API to allow or block HTTP\nrequests, see the [AWS WAF Developer Guide](https://docs.aws.amazon.com/waf/latest/developerguide/).","ref":"AWS.WAF.html#create_ip_set/3","title":"AWS.WAF.create_ip_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nCreates a `RateBasedRule`. The `RateBasedRule` contains a `RateLimit`, which\nspecifies the maximum number of requests that AWS WAF allows from a specified IP\naddress in a five-minute period. The `RateBasedRule` also contains the `IPSet`\nobjects, `ByteMatchSet` objects, and other predicates that identify the requests\nthat you want to count or block if these requests exceed the `RateLimit`.\n\nIf you add more than one predicate to a `RateBasedRule`, a request not only must\nexceed the `RateLimit`, but it also must match all the conditions to be counted\nor blocked. For example, suppose you add the following to a `RateBasedRule`:\n\n  * An `IPSet` that matches the IP address `192.0.2.44/32`\n\n  * A `ByteMatchSet` that matches `BadBot` in the `User-Agent` header\n\nFurther, you specify a `RateLimit` of 1,000.\n\nYou then add the `RateBasedRule` to a `WebACL` and specify that you want to\nblock requests that meet the conditions in the rule. For a request to be\nblocked, it must come from the IP address 192.0.2.44 *and* the `User-Agent`\nheader in the request must contain the value `BadBot`. Further, requests that\nmatch these two conditions must be received at a rate of more than 1,000\nrequests every five minutes. If both conditions are met and the rate is\nexceeded, AWS WAF blocks the requests. If the rate drops below 1,000 for a\nfive-minute period, AWS WAF no longer blocks the requests.\n\nAs a second example, suppose you want to limit requests to a particular page on\nyour site. To do this, you could add the following to a `RateBasedRule`:\n\n  * A `ByteMatchSet` with `FieldToMatch` of `URI`\n\n  * A `PositionalConstraint` of `STARTS_WITH`\n\n  * A `TargetString` of `login`\n\nFurther, you specify a `RateLimit` of 1,000.\n\nBy adding this `RateBasedRule` to a `WebACL`, you could limit requests to your\nlogin page without affecting the rest of your site.\n\nTo create and configure a `RateBasedRule`, perform the following steps:\n\n  1. Create and update the predicates that you want to include in the\nrule. For more information, see `CreateByteMatchSet`, `CreateIPSet`, and\n`CreateSqlInjectionMatchSet`.\n\n  2. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of a `CreateRule` request.\n\n  3. Submit a `CreateRateBasedRule` request.\n\n  4. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of an `UpdateRule` request.\n\n  5. Submit an `UpdateRateBasedRule` request to specify the predicates\nthat you want to include in the rule.\n\n  6. Create and update a `WebACL` that contains the `RateBasedRule`.\nFor more information, see `CreateWebACL`.\n\nFor more information about how to use the AWS WAF API to allow or block HTTP\nrequests, see the [AWS WAF Developer Guide](https://docs.aws.amazon.com/waf/latest/developerguide/).","ref":"AWS.WAF.html#create_rate_based_rule/3","title":"AWS.WAF.create_rate_based_rule/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nCreates a `RegexMatchSet`. You then use `UpdateRegexMatchSet` to identify the\npart of a web request that you want AWS WAF to inspect, such as the values of\nthe `User-Agent` header or the query string. For example, you can create a\n`RegexMatchSet` that contains a `RegexMatchTuple` that looks for any requests\nwith `User-Agent` headers that match a `RegexPatternSet` with pattern\n`B[a@]dB[o0]t`. You can then configure AWS WAF to reject those requests.  To create and configure a `RegexMatchSet`, perform the following steps:\n\n  1. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of a `CreateRegexMatchSet` request.\n\n  2. Submit a `CreateRegexMatchSet` request.\n\n  3. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of an `UpdateRegexMatchSet` request.\n\n  4. Submit an `UpdateRegexMatchSet` request to specify the part of\nthe request that you want AWS WAF to inspect (for example, the header or the\nURI) and the value, using a `RegexPatternSet`, that you want AWS WAF to watch\nfor.\n\nFor more information about how to use the AWS WAF API to allow or block HTTP\nrequests, see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/).","ref":"AWS.WAF.html#create_regex_match_set/3","title":"AWS.WAF.create_regex_match_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nCreates a `RegexPatternSet`. You then use `UpdateRegexPatternSet` to specify the\nregular expression (regex) pattern that you want AWS WAF to search for, such as\n`B[a@]dB[o0]t`. You can then configure AWS WAF to reject those requests.  To create and configure a `RegexPatternSet`, perform the following steps:\n\n  1. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of a `CreateRegexPatternSet` request.\n\n  2. Submit a `CreateRegexPatternSet` request.\n\n  3. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of an `UpdateRegexPatternSet` request.\n\n  4. Submit an `UpdateRegexPatternSet` request to specify the string\nthat you want AWS WAF to watch for.\n\nFor more information about how to use the AWS WAF API to allow or block HTTP\nrequests, see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/).","ref":"AWS.WAF.html#create_regex_pattern_set/3","title":"AWS.WAF.create_regex_pattern_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nCreates a `Rule`, which contains the `IPSet` objects, `ByteMatchSet` objects,\nand other predicates that identify the requests that you want to block. If you\nadd more than one predicate to a `Rule`, a request must match all of the\nspecifications to be allowed or blocked. For example, suppose that you add the\nfollowing to a `Rule`:\n\n  * An `IPSet` that matches the IP address `192.0.2.44/32`\n\n  * A `ByteMatchSet` that matches `BadBot` in the `User-Agent` header\n\nYou then add the `Rule` to a `WebACL` and specify that you want to blocks\nrequests that satisfy the `Rule`. For a request to be blocked, it must come from\nthe IP address 192.0.2.44 *and* the `User-Agent` header in the request must\ncontain the value `BadBot`.\n\nTo create and configure a `Rule`, perform the following steps:\n\n  1. Create and update the predicates that you want to include in the\n`Rule`. For more information, see `CreateByteMatchSet`, `CreateIPSet`, and\n`CreateSqlInjectionMatchSet`.\n\n  2. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of a `CreateRule` request.\n\n  3. Submit a `CreateRule` request.\n\n  4. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of an `UpdateRule` request.\n\n  5. Submit an `UpdateRule` request to specify the predicates that you\nwant to include in the `Rule`.\n\n  6. Create and update a `WebACL` that contains the `Rule`. For more\ninformation, see `CreateWebACL`.\n\nFor more information about how to use the AWS WAF API to allow or block HTTP\nrequests, see the [AWS WAF Developer Guide](https://docs.aws.amazon.com/waf/latest/developerguide/).","ref":"AWS.WAF.html#create_rule/3","title":"AWS.WAF.create_rule/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nCreates a `RuleGroup`. A rule group is a collection of predefined rules that you\nadd to a web ACL. You use `UpdateRuleGroup` to add rules to the rule group.\n\nRule groups are subject to the following limits:\n\n  * Three rule groups per account. You can request an increase to this\nlimit by contacting customer support.\n\n  * One rule group per web ACL.\n\n  * Ten rules per rule group.\n\nFor more information about how to use the AWS WAF API to allow or block HTTP\nrequests, see the [AWS WAF Developer Guide](https://docs.aws.amazon.com/waf/latest/developerguide/).","ref":"AWS.WAF.html#create_rule_group/3","title":"AWS.WAF.create_rule_group/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nCreates a `SizeConstraintSet`. You then use `UpdateSizeConstraintSet` to\nidentify the part of a web request that you want AWS WAF to check for length,\nsuch as the length of the `User-Agent` header or the length of the query string.\nFor example, you can create a `SizeConstraintSet` that matches any requests that\nhave a query string that is longer than 100 bytes. You can then configure AWS\nWAF to reject those requests.\n\nTo create and configure a `SizeConstraintSet`, perform the following steps:\n\n  1. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of a `CreateSizeConstraintSet` request.\n\n  2. Submit a `CreateSizeConstraintSet` request.\n\n  3. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of an `UpdateSizeConstraintSet` request.\n\n  4. Submit an `UpdateSizeConstraintSet` request to specify the part\nof the request that you want AWS WAF to inspect (for example, the header or the\nURI) and the value that you want AWS WAF to watch for.\n\nFor more information about how to use the AWS WAF API to allow or block HTTP\nrequests, see the [AWS WAF Developer Guide](https://docs.aws.amazon.com/waf/latest/developerguide/).","ref":"AWS.WAF.html#create_size_constraint_set/3","title":"AWS.WAF.create_size_constraint_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nCreates a `SqlInjectionMatchSet`, which you use to allow, block, or count\nrequests that contain snippets of SQL code in a specified part of web requests.\nAWS WAF searches for character sequences that are likely to be malicious\nstrings.\n\nTo create and configure a `SqlInjectionMatchSet`, perform the following steps:\n\n  1. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of a `CreateSqlInjectionMatchSet` request.\n\n  2. Submit a `CreateSqlInjectionMatchSet` request.\n\n  3. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of an `UpdateSqlInjectionMatchSet` request.\n\n  4. Submit an `UpdateSqlInjectionMatchSet` request to specify the\nparts of web requests in which you want to allow, block, or count malicious SQL\ncode.\n\nFor more information about how to use the AWS WAF API to allow or block HTTP\nrequests, see the [AWS WAF Developer Guide](https://docs.aws.amazon.com/waf/latest/developerguide/).","ref":"AWS.WAF.html#create_sql_injection_match_set/3","title":"AWS.WAF.create_sql_injection_match_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nCreates a `WebACL`, which contains the `Rules` that identify the CloudFront web\nrequests that you want to allow, block, or count. AWS WAF evaluates `Rules` in\norder based on the value of `Priority` for each `Rule`.\n\nYou also specify a default action, either `ALLOW` or `BLOCK`. If a web request\ndoesn't match any of the `Rules` in a `WebACL`, AWS WAF responds to the request\nwith the default action.\n\nTo create and configure a `WebACL`, perform the following steps:\n\n  1. Create and update the `ByteMatchSet` objects and other predicates\nthat you want to include in `Rules`. For more information, see\n`CreateByteMatchSet`, `UpdateByteMatchSet`, `CreateIPSet`, `UpdateIPSet`,\n`CreateSqlInjectionMatchSet`, and `UpdateSqlInjectionMatchSet`.\n\n  2. Create and update the `Rules` that you want to include in the\n`WebACL`. For more information, see `CreateRule` and `UpdateRule`.\n\n  3. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of a `CreateWebACL` request.\n\n  4. Submit a `CreateWebACL` request.\n\n  5. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of an `UpdateWebACL` request.\n\n  6. Submit an `UpdateWebACL` request to specify the `Rules` that you\nwant to include in the `WebACL`, to specify the default action, and to associate\nthe `WebACL` with a CloudFront distribution.\n\nFor more information about how to use the AWS WAF API, see the [AWS WAF Developer Guide](https://docs.aws.amazon.com/waf/latest/developerguide/).","ref":"AWS.WAF.html#create_web_acl/3","title":"AWS.WAF.create_web_acl/3","type":"function"},{"doc":"Creates an AWS CloudFormation WAFV2 template for the specified web ACL in the\nspecified Amazon S3 bucket.\n\nThen, in CloudFormation, you create a stack from the template, to create the web\nACL and its resources in AWS WAFV2. Use this to migrate your AWS WAF Classic web\nACL to the latest version of AWS WAF.\n\nThis is part of a larger migration procedure for web ACLs from AWS WAF Classic\nto the latest version of AWS WAF. For the full procedure, including caveats and\nmanual steps to complete the migration and switch over to the new web ACL, see\n[Migrating your AWS WAF Classic resources to AWS WAF](https://docs.aws.amazon.com/waf/latest/developerguide/waf-migrating-from-classic.html)\nin the [AWS WAF Developer Guide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).","ref":"AWS.WAF.html#create_web_acl_migration_stack/3","title":"AWS.WAF.create_web_acl_migration_stack/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nCreates an `XssMatchSet`, which you use to allow, block, or count requests that\ncontain cross-site scripting attacks in the specified part of web requests. AWS\nWAF searches for character sequences that are likely to be malicious strings.\n\nTo create and configure an `XssMatchSet`, perform the following steps:\n\n  1. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of a `CreateXssMatchSet` request.\n\n  2. Submit a `CreateXssMatchSet` request.\n\n  3. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of an `UpdateXssMatchSet` request.\n\n  4. Submit an `UpdateXssMatchSet` request to specify the parts of web\nrequests in which you want to allow, block, or count cross-site scripting\nattacks.\n\nFor more information about how to use the AWS WAF API to allow or block HTTP\nrequests, see the [AWS WAF Developer Guide](https://docs.aws.amazon.com/waf/latest/developerguide/).","ref":"AWS.WAF.html#create_xss_match_set/3","title":"AWS.WAF.create_xss_match_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nPermanently deletes a `ByteMatchSet`. You can't delete a `ByteMatchSet` if it's\nstill used in any `Rules` or if it still includes any `ByteMatchTuple` objects\n(any filters).\n\nIf you just want to remove a `ByteMatchSet` from a `Rule`, use `UpdateRule`.\n\nTo permanently delete a `ByteMatchSet`, perform the following steps:\n\n  1. Update the `ByteMatchSet` to remove filters, if any. For more\ninformation, see `UpdateByteMatchSet`.\n\n  2. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of a `DeleteByteMatchSet` request.\n\n  3. Submit a `DeleteByteMatchSet` request.","ref":"AWS.WAF.html#delete_byte_match_set/3","title":"AWS.WAF.delete_byte_match_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nPermanently deletes a `GeoMatchSet`. You can't delete a `GeoMatchSet` if it's\nstill used in any `Rules` or if it still includes any countries.\n\nIf you just want to remove a `GeoMatchSet` from a `Rule`, use `UpdateRule`.\n\nTo permanently delete a `GeoMatchSet` from AWS WAF, perform the following steps:\n\n  1. Update the `GeoMatchSet` to remove any countries. For more\ninformation, see `UpdateGeoMatchSet`.\n\n  2. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of a `DeleteGeoMatchSet` request.\n\n  3. Submit a `DeleteGeoMatchSet` request.","ref":"AWS.WAF.html#delete_geo_match_set/3","title":"AWS.WAF.delete_geo_match_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nPermanently deletes an `IPSet`. You can't delete an `IPSet` if it's still used\nin any `Rules` or if it still includes any IP addresses.\n\nIf you just want to remove an `IPSet` from a `Rule`, use `UpdateRule`.\n\nTo permanently delete an `IPSet` from AWS WAF, perform the following steps:\n\n  1. Update the `IPSet` to remove IP address ranges, if any. For more\ninformation, see `UpdateIPSet`.\n\n  2. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of a `DeleteIPSet` request.\n\n  3. Submit a `DeleteIPSet` request.","ref":"AWS.WAF.html#delete_ip_set/3","title":"AWS.WAF.delete_ip_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nPermanently deletes the `LoggingConfiguration` from the specified web ACL.","ref":"AWS.WAF.html#delete_logging_configuration/3","title":"AWS.WAF.delete_logging_configuration/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nPermanently deletes an IAM policy from the specified RuleGroup.\n\nThe user making the request must be the owner of the RuleGroup.","ref":"AWS.WAF.html#delete_permission_policy/3","title":"AWS.WAF.delete_permission_policy/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nPermanently deletes a `RateBasedRule`. You can't delete a rule if it's still\nused in any `WebACL` objects or if it still includes any predicates, such as\n`ByteMatchSet` objects.\n\nIf you just want to remove a rule from a `WebACL`, use `UpdateWebACL`.\n\nTo permanently delete a `RateBasedRule` from AWS WAF, perform the following\nsteps:\n\n  1. Update the `RateBasedRule` to remove predicates, if any. For more\ninformation, see `UpdateRateBasedRule`.\n\n  2. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of a `DeleteRateBasedRule` request.\n\n  3. Submit a `DeleteRateBasedRule` request.","ref":"AWS.WAF.html#delete_rate_based_rule/3","title":"AWS.WAF.delete_rate_based_rule/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nPermanently deletes a `RegexMatchSet`. You can't delete a `RegexMatchSet` if\nit's still used in any `Rules` or if it still includes any `RegexMatchTuples`\nobjects (any filters).\n\nIf you just want to remove a `RegexMatchSet` from a `Rule`, use `UpdateRule`.\n\nTo permanently delete a `RegexMatchSet`, perform the following steps:\n\n  1. Update the `RegexMatchSet` to remove filters, if any. For more\ninformation, see `UpdateRegexMatchSet`.\n\n  2. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of a `DeleteRegexMatchSet` request.\n\n  3. Submit a `DeleteRegexMatchSet` request.","ref":"AWS.WAF.html#delete_regex_match_set/3","title":"AWS.WAF.delete_regex_match_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nPermanently deletes a `RegexPatternSet`. You can't delete a `RegexPatternSet` if\nit's still used in any `RegexMatchSet` or if the `RegexPatternSet` is not empty.","ref":"AWS.WAF.html#delete_regex_pattern_set/3","title":"AWS.WAF.delete_regex_pattern_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nPermanently deletes a `Rule`. You can't delete a `Rule` if it's still used in\nany `WebACL` objects or if it still includes any predicates, such as\n`ByteMatchSet` objects.\n\nIf you just want to remove a `Rule` from a `WebACL`, use `UpdateWebACL`.\n\nTo permanently delete a `Rule` from AWS WAF, perform the following steps:\n\n  1. Update the `Rule` to remove predicates, if any. For more\ninformation, see `UpdateRule`.\n\n  2. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of a `DeleteRule` request.\n\n  3. Submit a `DeleteRule` request.","ref":"AWS.WAF.html#delete_rule/3","title":"AWS.WAF.delete_rule/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nPermanently deletes a `RuleGroup`. You can't delete a `RuleGroup` if it's still\nused in any `WebACL` objects or if it still includes any rules.\n\nIf you just want to remove a `RuleGroup` from a `WebACL`, use `UpdateWebACL`.\n\nTo permanently delete a `RuleGroup` from AWS WAF, perform the following steps:\n\n  1. Update the `RuleGroup` to remove rules, if any. For more\ninformation, see `UpdateRuleGroup`.\n\n  2. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of a `DeleteRuleGroup` request.\n\n  3. Submit a `DeleteRuleGroup` request.","ref":"AWS.WAF.html#delete_rule_group/3","title":"AWS.WAF.delete_rule_group/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nPermanently deletes a `SizeConstraintSet`. You can't delete a\n`SizeConstraintSet` if it's still used in any `Rules` or if it still includes\nany `SizeConstraint` objects (any filters).\n\nIf you just want to remove a `SizeConstraintSet` from a `Rule`, use\n`UpdateRule`.\n\nTo permanently delete a `SizeConstraintSet`, perform the following steps:\n\n  1. Update the `SizeConstraintSet` to remove filters, if any. For\nmore information, see `UpdateSizeConstraintSet`.\n\n  2. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of a `DeleteSizeConstraintSet` request.\n\n  3. Submit a `DeleteSizeConstraintSet` request.","ref":"AWS.WAF.html#delete_size_constraint_set/3","title":"AWS.WAF.delete_size_constraint_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nPermanently deletes a `SqlInjectionMatchSet`. You can't delete a\n`SqlInjectionMatchSet` if it's still used in any `Rules` or if it still contains\nany `SqlInjectionMatchTuple` objects.\n\nIf you just want to remove a `SqlInjectionMatchSet` from a `Rule`, use\n`UpdateRule`.\n\nTo permanently delete a `SqlInjectionMatchSet` from AWS WAF, perform the\nfollowing steps:\n\n  1. Update the `SqlInjectionMatchSet` to remove filters, if any. For\nmore information, see `UpdateSqlInjectionMatchSet`.\n\n  2. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of a `DeleteSqlInjectionMatchSet` request.\n\n  3. Submit a `DeleteSqlInjectionMatchSet` request.","ref":"AWS.WAF.html#delete_sql_injection_match_set/3","title":"AWS.WAF.delete_sql_injection_match_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nPermanently deletes a `WebACL`. You can't delete a `WebACL` if it still contains\nany `Rules`.\n\nTo delete a `WebACL`, perform the following steps:\n\n  1. Update the `WebACL` to remove `Rules`, if any. For more\ninformation, see `UpdateWebACL`.\n\n  2. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of a `DeleteWebACL` request.\n\n  3. Submit a `DeleteWebACL` request.","ref":"AWS.WAF.html#delete_web_acl/3","title":"AWS.WAF.delete_web_acl/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nPermanently deletes an `XssMatchSet`. You can't delete an `XssMatchSet` if it's\nstill used in any `Rules` or if it still contains any `XssMatchTuple` objects.\n\nIf you just want to remove an `XssMatchSet` from a `Rule`, use `UpdateRule`.\n\nTo permanently delete an `XssMatchSet` from AWS WAF, perform the following\nsteps:\n\n  1. Update the `XssMatchSet` to remove filters, if any. For more\ninformation, see `UpdateXssMatchSet`.\n\n  2. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of a `DeleteXssMatchSet` request.\n\n  3. Submit a `DeleteXssMatchSet` request.","ref":"AWS.WAF.html#delete_xss_match_set/3","title":"AWS.WAF.delete_xss_match_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns the `ByteMatchSet` specified by `ByteMatchSetId`.","ref":"AWS.WAF.html#get_byte_match_set/3","title":"AWS.WAF.get_byte_match_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nWhen you want to create, update, or delete AWS WAF objects, get a change token\nand include the change token in the create, update, or delete request. Change\ntokens ensure that your application doesn't submit conflicting requests to AWS\nWAF.\n\nEach create, update, or delete request must use a unique change token. If your\napplication submits a `GetChangeToken` request and then submits a second\n`GetChangeToken` request before submitting a create, update, or delete request,\nthe second `GetChangeToken` request returns the same value as the first\n`GetChangeToken` request.\n\nWhen you use a change token in a create, update, or delete request, the status\nof the change token changes to `PENDING`, which indicates that AWS WAF is\npropagating the change to all AWS WAF servers. Use `GetChangeTokenStatus` to\ndetermine the status of your change token.","ref":"AWS.WAF.html#get_change_token/3","title":"AWS.WAF.get_change_token/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns the status of a `ChangeToken` that you got by calling `GetChangeToken`.\n`ChangeTokenStatus` is one of the following values:\n\n  * `PROVISIONED`: You requested the change token by calling\n`GetChangeToken`, but you haven't used it yet in a call to create, update, or\ndelete an AWS WAF object.\n\n  * `PENDING`: AWS WAF is propagating the create, update, or delete\nrequest to all AWS WAF servers.\n\n  * `INSYNC`: Propagation is complete.","ref":"AWS.WAF.html#get_change_token_status/3","title":"AWS.WAF.get_change_token_status/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns the `GeoMatchSet` that is specified by `GeoMatchSetId`.","ref":"AWS.WAF.html#get_geo_match_set/3","title":"AWS.WAF.get_geo_match_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns the `IPSet` that is specified by `IPSetId`.","ref":"AWS.WAF.html#get_ip_set/3","title":"AWS.WAF.get_ip_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns the `LoggingConfiguration` for the specified web ACL.","ref":"AWS.WAF.html#get_logging_configuration/3","title":"AWS.WAF.get_logging_configuration/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns the IAM policy attached to the RuleGroup.","ref":"AWS.WAF.html#get_permission_policy/3","title":"AWS.WAF.get_permission_policy/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns the `RateBasedRule` that is specified by the `RuleId` that you included\nin the `GetRateBasedRule` request.","ref":"AWS.WAF.html#get_rate_based_rule/3","title":"AWS.WAF.get_rate_based_rule/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns an array of IP addresses currently being blocked by the `RateBasedRule`\nthat is specified by the `RuleId`. The maximum number of managed keys that will\nbe blocked is 10,000. If more than 10,000 addresses exceed the rate limit, the\n10,000 addresses with the highest rates will be blocked.","ref":"AWS.WAF.html#get_rate_based_rule_managed_keys/3","title":"AWS.WAF.get_rate_based_rule_managed_keys/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns the `RegexMatchSet` specified by `RegexMatchSetId`.","ref":"AWS.WAF.html#get_regex_match_set/3","title":"AWS.WAF.get_regex_match_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns the `RegexPatternSet` specified by `RegexPatternSetId`.","ref":"AWS.WAF.html#get_regex_pattern_set/3","title":"AWS.WAF.get_regex_pattern_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns the `Rule` that is specified by the `RuleId` that you included in the\n`GetRule` request.","ref":"AWS.WAF.html#get_rule/3","title":"AWS.WAF.get_rule/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns the `RuleGroup` that is specified by the `RuleGroupId` that you included\nin the `GetRuleGroup` request.\n\nTo view the rules in a rule group, use `ListActivatedRulesInRuleGroup`.","ref":"AWS.WAF.html#get_rule_group/3","title":"AWS.WAF.get_rule_group/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nGets detailed information about a specified number of requests--a sample--that\nAWS WAF randomly selects from among the first 5,000 requests that your AWS\nresource received during a time range that you choose. You can specify a sample\nsize of up to 500 requests, and you can specify any time range in the previous\nthree hours.\n\n`GetSampledRequests` returns a time range, which is usually the time range that\nyou specified. However, if your resource (such as a CloudFront distribution)\nreceived 5,000 requests before the specified time range elapsed,\n`GetSampledRequests` returns an updated time range. This new time range\nindicates the actual period during which AWS WAF selected the requests in the\nsample.","ref":"AWS.WAF.html#get_sampled_requests/3","title":"AWS.WAF.get_sampled_requests/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns the `SizeConstraintSet` specified by `SizeConstraintSetId`.","ref":"AWS.WAF.html#get_size_constraint_set/3","title":"AWS.WAF.get_size_constraint_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns the `SqlInjectionMatchSet` that is specified by\n`SqlInjectionMatchSetId`.","ref":"AWS.WAF.html#get_sql_injection_match_set/3","title":"AWS.WAF.get_sql_injection_match_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns the `WebACL` that is specified by `WebACLId`.","ref":"AWS.WAF.html#get_web_acl/3","title":"AWS.WAF.get_web_acl/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns the `XssMatchSet` that is specified by `XssMatchSetId`.","ref":"AWS.WAF.html#get_xss_match_set/3","title":"AWS.WAF.get_xss_match_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns an array of `ActivatedRule` objects.","ref":"AWS.WAF.html#list_activated_rules_in_rule_group/3","title":"AWS.WAF.list_activated_rules_in_rule_group/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns an array of `ByteMatchSetSummary` objects.","ref":"AWS.WAF.html#list_byte_match_sets/3","title":"AWS.WAF.list_byte_match_sets/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns an array of `GeoMatchSetSummary` objects in the response.","ref":"AWS.WAF.html#list_geo_match_sets/3","title":"AWS.WAF.list_geo_match_sets/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns an array of `IPSetSummary` objects in the response.","ref":"AWS.WAF.html#list_ip_sets/3","title":"AWS.WAF.list_ip_sets/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns an array of `LoggingConfiguration` objects.","ref":"AWS.WAF.html#list_logging_configurations/3","title":"AWS.WAF.list_logging_configurations/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns an array of `RuleSummary` objects.","ref":"AWS.WAF.html#list_rate_based_rules/3","title":"AWS.WAF.list_rate_based_rules/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns an array of `RegexMatchSetSummary` objects.","ref":"AWS.WAF.html#list_regex_match_sets/3","title":"AWS.WAF.list_regex_match_sets/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns an array of `RegexPatternSetSummary` objects.","ref":"AWS.WAF.html#list_regex_pattern_sets/3","title":"AWS.WAF.list_regex_pattern_sets/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns an array of `RuleGroup` objects.","ref":"AWS.WAF.html#list_rule_groups/3","title":"AWS.WAF.list_rule_groups/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns an array of `RuleSummary` objects.","ref":"AWS.WAF.html#list_rules/3","title":"AWS.WAF.list_rules/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns an array of `SizeConstraintSetSummary` objects.","ref":"AWS.WAF.html#list_size_constraint_sets/3","title":"AWS.WAF.list_size_constraint_sets/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns an array of `SqlInjectionMatchSet` objects.","ref":"AWS.WAF.html#list_sql_injection_match_sets/3","title":"AWS.WAF.list_sql_injection_match_sets/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns an array of `RuleGroup` objects that you are subscribed to.","ref":"AWS.WAF.html#list_subscribed_rule_groups/3","title":"AWS.WAF.list_subscribed_rule_groups/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nRetrieves the tags associated with the specified AWS resource. Tags are\nkey:value pairs that you can use to categorize and manage your resources, for\npurposes like billing. For example, you might set the tag key to \"customer\" and\nthe value to the customer name or ID. You can specify one or more tags to add to\neach AWS resource, up to 50 tags for a resource.\n\nTagging is only available through the API, SDKs, and CLI. You can't manage or\nview tags through the AWS WAF Classic console. You can tag the AWS resources\nthat you manage through AWS WAF Classic: web ACLs, rule groups, and rules.","ref":"AWS.WAF.html#list_tags_for_resource/3","title":"AWS.WAF.list_tags_for_resource/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns an array of `WebACLSummary` objects in the response.","ref":"AWS.WAF.html#list_web_acls/3","title":"AWS.WAF.list_web_acls/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns an array of `XssMatchSet` objects.","ref":"AWS.WAF.html#list_xss_match_sets/3","title":"AWS.WAF.list_xss_match_sets/3","type":"function"},{"doc":"","ref":"AWS.WAF.html#metadata/0","title":"AWS.WAF.metadata/0","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nAssociates a `LoggingConfiguration` with a specified web ACL.\n\nYou can access information about all traffic that AWS WAF inspects using the\nfollowing steps:\n\n  1. Create an Amazon Kinesis Data Firehose.\n\nCreate the data firehose with a PUT source and in the region that you are\noperating. However, if you are capturing logs for Amazon CloudFront, always\ncreate the firehose in US East (N. Virginia).\n\nDo not create the data firehose using a `Kinesis stream` as your source.\n\n  2. Associate that firehose to your web ACL using a\n`PutLoggingConfiguration` request.\n\nWhen you successfully enable logging using a `PutLoggingConfiguration` request,\nAWS WAF will create a service linked role with the necessary permissions to\nwrite logs to the Amazon Kinesis Data Firehose. For more information, see\n[Logging Web ACL Traffic Information](https://docs.aws.amazon.com/waf/latest/developerguide/logging.html)\nin the *AWS WAF Developer Guide*.","ref":"AWS.WAF.html#put_logging_configuration/3","title":"AWS.WAF.put_logging_configuration/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nAttaches an IAM policy to the specified resource. The only supported use for\nthis action is to share a RuleGroup across accounts.\n\nThe `PutPermissionPolicy` is subject to the following restrictions:\n\n  * You can attach only one policy with each `PutPermissionPolicy`\nrequest.\n\n  * The policy must include an `Effect`, `Action` and `Principal`.\n\n  * `Effect` must specify `Allow`.\n\n  * The `Action` in the policy must be `waf:UpdateWebACL`,\n`waf-regional:UpdateWebACL`, `waf:GetRuleGroup` and `waf-regional:GetRuleGroup`\n. Any extra or wildcard actions in the policy will be rejected.\n\n  * The policy cannot include a `Resource` parameter.\n\n  * The ARN in the request must be a valid WAF RuleGroup ARN and the\nRuleGroup must exist in the same region.\n\n  * The user making the request must be the owner of the RuleGroup.\n\n  * Your policy must be composed using IAM Policy version 2012-10-17.\n\nFor more information, see [IAM Policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies.html).\n\nAn example of a valid policy parameter is shown in the Examples section below.","ref":"AWS.WAF.html#put_permission_policy/3","title":"AWS.WAF.put_permission_policy/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nAssociates tags with the specified AWS resource. Tags are key:value pairs that\nyou can use to categorize and manage your resources, for purposes like billing.\nFor example, you might set the tag key to \"customer\" and the value to the\ncustomer name or ID. You can specify one or more tags to add to each AWS\nresource, up to 50 tags for a resource.\n\nTagging is only available through the API, SDKs, and CLI. You can't manage or\nview tags through the AWS WAF Classic console. You can use this action to tag\nthe AWS resources that you manage through AWS WAF Classic: web ACLs, rule\ngroups, and rules.","ref":"AWS.WAF.html#tag_resource/3","title":"AWS.WAF.tag_resource/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.","ref":"AWS.WAF.html#untag_resource/3","title":"AWS.WAF.untag_resource/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nInserts or deletes `ByteMatchTuple` objects (filters) in a `ByteMatchSet`. For\neach `ByteMatchTuple` object, you specify the following values:\n\n  * Whether to insert or delete the object from the array. If you want\nto change a `ByteMatchSetUpdate` object, you delete the existing object and add\na new one.\n\n  * The part of a web request that you want AWS WAF to inspect, such\nas a query string or the value of the `User-Agent` header.\n\n  * The bytes (typically a string that corresponds with ASCII\ncharacters) that you want AWS WAF to look for. For more information, including\nhow you specify the values for the AWS WAF API and the AWS CLI or SDKs, see\n`TargetString` in the `ByteMatchTuple` data type.\n\n  * Where to look, such as at the beginning or the end of a query\nstring.\n\n  * Whether to perform any conversions on the request, such as\nconverting it to lowercase, before inspecting it for the specified string.\n\nFor example, you can add a `ByteMatchSetUpdate` object that matches web requests\nin which `User-Agent` headers contain the string `BadBot`. You can then\nconfigure AWS WAF to block those requests.\n\nTo create and configure a `ByteMatchSet`, perform the following steps:\n\n  1. Create a `ByteMatchSet.` For more information, see\n`CreateByteMatchSet`.\n\n  2. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of an `UpdateByteMatchSet` request.\n\n  3. Submit an `UpdateByteMatchSet` request to specify the part of the\nrequest that you want AWS WAF to inspect (for example, the header or the URI)\nand the value that you want AWS WAF to watch for.\n\nFor more information about how to use the AWS WAF API to allow or block HTTP\nrequests, see the [AWS WAF Developer Guide](https://docs.aws.amazon.com/waf/latest/developerguide/).","ref":"AWS.WAF.html#update_byte_match_set/3","title":"AWS.WAF.update_byte_match_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nInserts or deletes `GeoMatchConstraint` objects in an `GeoMatchSet`. For each\n`GeoMatchConstraint` object, you specify the following values:\n\n  * Whether to insert or delete the object from the array. If you want\nto change an `GeoMatchConstraint` object, you delete the existing object and add\na new one.\n\n  * The `Type`. The only valid value for `Type` is `Country`.\n\n  * The `Value`, which is a two character code for the country to add\nto the `GeoMatchConstraint` object. Valid codes are listed in\n`GeoMatchConstraint$Value`.\n\nTo create and configure an `GeoMatchSet`, perform the following steps:\n\n  1. Submit a `CreateGeoMatchSet` request.\n\n  2. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of an `UpdateGeoMatchSet` request.\n\n  3. Submit an `UpdateGeoMatchSet` request to specify the country that\nyou want AWS WAF to watch for.\n\nWhen you update an `GeoMatchSet`, you specify the country that you want to add\nand/or the country that you want to delete. If you want to change a country, you\ndelete the existing country and add the new one.\n\nFor more information about how to use the AWS WAF API to allow or block HTTP\nrequests, see the [AWS WAF Developer Guide](https://docs.aws.amazon.com/waf/latest/developerguide/).","ref":"AWS.WAF.html#update_geo_match_set/3","title":"AWS.WAF.update_geo_match_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nInserts or deletes `IPSetDescriptor` objects in an `IPSet`. For each\n`IPSetDescriptor` object, you specify the following values:\n\n  * Whether to insert or delete the object from the array. If you want\nto change an `IPSetDescriptor` object, you delete the existing object and add a\nnew one.\n\n  * The IP address version, `IPv4` or `IPv6`.\n\n  * The IP address in CIDR notation, for example, `192.0.2.0/24` (for\nthe range of IP addresses from `192.0.2.0` to `192.0.2.255`) or `192.0.2.44/32`\n(for the individual IP address `192.0.2.44`).\n\nAWS WAF supports IPv4 address ranges: /8 and any range between /16 through /32.\nAWS WAF supports IPv6 address ranges: /24, /32, /48, /56, /64, and /128. For\nmore information about CIDR notation, see the Wikipedia entry [Classless Inter-Domain\nRouting](https://en.wikipedia.org/wiki/Classless_Inter-Domain_Routing).\n\nIPv6 addresses can be represented using any of the following formats:\n\n  * 1111:0000:0000:0000:0000:0000:0000:0111/128\n\n  * 1111:0:0:0:0:0:0:0111/128\n\n  * 1111::0111/128\n\n  * 1111::111/128\n\nYou use an `IPSet` to specify which web requests you want to allow or block\nbased on the IP addresses that the requests originated from. For example, if\nyou're receiving a lot of requests from one or a small number of IP addresses\nand you want to block the requests, you can create an `IPSet` that specifies\nthose IP addresses, and then configure AWS WAF to block the requests.\n\nTo create and configure an `IPSet`, perform the following steps:\n\n  1. Submit a `CreateIPSet` request.\n\n  2. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of an `UpdateIPSet` request.\n\n  3. Submit an `UpdateIPSet` request to specify the IP addresses that\nyou want AWS WAF to watch for.\n\nWhen you update an `IPSet`, you specify the IP addresses that you want to add\nand/or the IP addresses that you want to delete. If you want to change an IP\naddress, you delete the existing IP address and add the new one.\n\nYou can insert a maximum of 1000 addresses in a single request.\n\nFor more information about how to use the AWS WAF API to allow or block HTTP\nrequests, see the [AWS WAF Developer Guide](https://docs.aws.amazon.com/waf/latest/developerguide/).","ref":"AWS.WAF.html#update_ip_set/3","title":"AWS.WAF.update_ip_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nInserts or deletes `Predicate` objects in a rule and updates the `RateLimit` in\nthe rule.\n\nEach `Predicate` object identifies a predicate, such as a `ByteMatchSet` or an\n`IPSet`, that specifies the web requests that you want to block or count. The\n`RateLimit` specifies the number of requests every five minutes that triggers\nthe rule.\n\nIf you add more than one predicate to a `RateBasedRule`, a request must match\nall the predicates and exceed the `RateLimit` to be counted or blocked. For\nexample, suppose you add the following to a `RateBasedRule`:\n\n  * An `IPSet` that matches the IP address `192.0.2.44/32`\n\n  * A `ByteMatchSet` that matches `BadBot` in the `User-Agent` header\n\nFurther, you specify a `RateLimit` of 1,000.\n\nYou then add the `RateBasedRule` to a `WebACL` and specify that you want to\nblock requests that satisfy the rule. For a request to be blocked, it must come\nfrom the IP address 192.0.2.44 *and* the `User-Agent` header in the request must\ncontain the value `BadBot`. Further, requests that match these two conditions\nmuch be received at a rate of more than 1,000 every five minutes. If the rate\ndrops below this limit, AWS WAF no longer blocks the requests.\n\nAs a second example, suppose you want to limit requests to a particular page on\nyour site. To do this, you could add the following to a `RateBasedRule`:\n\n  * A `ByteMatchSet` with `FieldToMatch` of `URI`\n\n  * A `PositionalConstraint` of `STARTS_WITH`\n\n  * A `TargetString` of `login`\n\nFurther, you specify a `RateLimit` of 1,000.\n\nBy adding this `RateBasedRule` to a `WebACL`, you could limit requests to your\nlogin page without affecting the rest of your site.","ref":"AWS.WAF.html#update_rate_based_rule/3","title":"AWS.WAF.update_rate_based_rule/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nInserts or deletes `RegexMatchTuple` objects (filters) in a `RegexMatchSet`. For\neach `RegexMatchSetUpdate` object, you specify the following values:\n\n  * Whether to insert or delete the object from the array. If you want\nto change a `RegexMatchSetUpdate` object, you delete the existing object and add\na new one.\n\n  * The part of a web request that you want AWS WAF to inspectupdate,\nsuch as a query string or the value of the `User-Agent` header.\n\n  * The identifier of the pattern (a regular expression) that you want\nAWS WAF to look for. For more information, see `RegexPatternSet`.\n\n  * Whether to perform any conversions on the request, such as\nconverting it to lowercase, before inspecting it for the specified string.\n\nFor example, you can create a `RegexPatternSet` that matches any requests with\n`User-Agent` headers that contain the string `B[a@]dB[o0]t`. You can then configure AWS WAF to reject those requests.\n\nTo create and configure a `RegexMatchSet`, perform the following steps:\n\n  1. Create a `RegexMatchSet.` For more information, see\n`CreateRegexMatchSet`.\n\n  2. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of an `UpdateRegexMatchSet` request.\n\n  3. Submit an `UpdateRegexMatchSet` request to specify the part of\nthe request that you want AWS WAF to inspect (for example, the header or the\nURI) and the identifier of the `RegexPatternSet` that contain the regular\nexpression patters you want AWS WAF to watch for.\n\nFor more information about how to use the AWS WAF API to allow or block HTTP\nrequests, see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/).","ref":"AWS.WAF.html#update_regex_match_set/3","title":"AWS.WAF.update_regex_match_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nInserts or deletes `RegexPatternString` objects in a `RegexPatternSet`. For each\n`RegexPatternString` object, you specify the following values:\n\n  * Whether to insert or delete the `RegexPatternString`.\n\n  * The regular expression pattern that you want to insert or delete.\nFor more information, see `RegexPatternSet`.\n\nFor example, you can create a `RegexPatternString` such as `B[a@]dB[o0]t`. AWS WAF will match this `RegexPatternString` to:\n\n  * BadBot\n\n  * BadB0t\n\n  * B@dBot\n\n  * B@dB0t\n\nTo create and configure a `RegexPatternSet`, perform the following steps:\n\n  1. Create a `RegexPatternSet.` For more information, see\n`CreateRegexPatternSet`.\n\n  2. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of an `UpdateRegexPatternSet` request.\n\n  3. Submit an `UpdateRegexPatternSet` request to specify the regular\nexpression pattern that you want AWS WAF to watch for.\n\nFor more information about how to use the AWS WAF API to allow or block HTTP\nrequests, see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/).","ref":"AWS.WAF.html#update_regex_pattern_set/3","title":"AWS.WAF.update_regex_pattern_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nInserts or deletes `Predicate` objects in a `Rule`. Each `Predicate` object\nidentifies a predicate, such as a `ByteMatchSet` or an `IPSet`, that specifies\nthe web requests that you want to allow, block, or count. If you add more than\none predicate to a `Rule`, a request must match all of the specifications to be\nallowed, blocked, or counted. For example, suppose that you add the following to\na `Rule`:\n\n  * A `ByteMatchSet` that matches the value `BadBot` in the\n`User-Agent` header\n\n  * An `IPSet` that matches the IP address `192.0.2.44`\n\nYou then add the `Rule` to a `WebACL` and specify that you want to block\nrequests that satisfy the `Rule`. For a request to be blocked, the `User-Agent`\nheader in the request must contain the value `BadBot` *and* the request must\noriginate from the IP address 192.0.2.44.\n\nTo create and configure a `Rule`, perform the following steps:\n\n  1. Create and update the predicates that you want to include in the\n`Rule`.\n\n  2. Create the `Rule`. See `CreateRule`.\n\n  3. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of an `UpdateRule` request.\n\n  4. Submit an `UpdateRule` request to add predicates to the `Rule`.\n\n  5. Create and update a `WebACL` that contains the `Rule`. See\n`CreateWebACL`.\n\nIf you want to replace one `ByteMatchSet` or `IPSet` with another, you delete\nthe existing one and add the new one.\n\nFor more information about how to use the AWS WAF API to allow or block HTTP\nrequests, see the [AWS WAF Developer Guide](https://docs.aws.amazon.com/waf/latest/developerguide/).","ref":"AWS.WAF.html#update_rule/3","title":"AWS.WAF.update_rule/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nInserts or deletes `ActivatedRule` objects in a `RuleGroup`.\n\nYou can only insert `REGULAR` rules into a rule group.\n\nYou can have a maximum of ten rules per rule group.\n\nTo create and configure a `RuleGroup`, perform the following steps:\n\n  1. Create and update the `Rules` that you want to include in the\n`RuleGroup`. See `CreateRule`.\n\n  2. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of an `UpdateRuleGroup` request.\n\n  3. Submit an `UpdateRuleGroup` request to add `Rules` to the\n`RuleGroup`.\n\n  4. Create and update a `WebACL` that contains the `RuleGroup`. See\n`CreateWebACL`.\n\nIf you want to replace one `Rule` with another, you delete the existing one and\nadd the new one.\n\nFor more information about how to use the AWS WAF API to allow or block HTTP\nrequests, see the [AWS WAF Developer Guide](https://docs.aws.amazon.com/waf/latest/developerguide/).","ref":"AWS.WAF.html#update_rule_group/3","title":"AWS.WAF.update_rule_group/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nInserts or deletes `SizeConstraint` objects (filters) in a `SizeConstraintSet`.\nFor each `SizeConstraint` object, you specify the following values:\n\n  * Whether to insert or delete the object from the array. If you want\nto change a `SizeConstraintSetUpdate` object, you delete the existing object and\nadd a new one.\n\n  * The part of a web request that you want AWS WAF to evaluate, such\nas the length of a query string or the length of the `User-Agent` header.\n\n  * Whether to perform any transformations on the request, such as\nconverting it to lowercase, before checking its length. Note that\ntransformations of the request body are not supported because the AWS resource\nforwards only the first `8192` bytes of your request to AWS WAF.\n\nYou can only specify a single type of TextTransformation.\n\n  * A `ComparisonOperator` used for evaluating the selected part of\nthe request against the specified `Size`, such as equals, greater than, less\nthan, and so on.\n\n  * The length, in bytes, that you want AWS WAF to watch for in\nselected part of the request. The length is computed after applying the\ntransformation.\n\nFor example, you can add a `SizeConstraintSetUpdate` object that matches web\nrequests in which the length of the `User-Agent` header is greater than 100\nbytes. You can then configure AWS WAF to block those requests.\n\nTo create and configure a `SizeConstraintSet`, perform the following steps:\n\n  1. Create a `SizeConstraintSet.` For more information, see\n`CreateSizeConstraintSet`.\n\n  2. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of an `UpdateSizeConstraintSet` request.\n\n  3. Submit an `UpdateSizeConstraintSet` request to specify the part\nof the request that you want AWS WAF to inspect (for example, the header or the\nURI) and the value that you want AWS WAF to watch for.\n\nFor more information about how to use the AWS WAF API to allow or block HTTP\nrequests, see the [AWS WAF Developer Guide](https://docs.aws.amazon.com/waf/latest/developerguide/).","ref":"AWS.WAF.html#update_size_constraint_set/3","title":"AWS.WAF.update_size_constraint_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nInserts or deletes `SqlInjectionMatchTuple` objects (filters) in a\n`SqlInjectionMatchSet`. For each `SqlInjectionMatchTuple` object, you specify\nthe following values:\n\n  * `Action`: Whether to insert the object into or delete the object\nfrom the array. To change a `SqlInjectionMatchTuple`, you delete the existing\nobject and add a new one.\n\n  * `FieldToMatch`: The part of web requests that you want AWS WAF to\ninspect and, if you want AWS WAF to inspect a header or custom query parameter,\nthe name of the header or parameter.\n\n  * `TextTransformation`: Which text transformation, if any, to\nperform on the web request before inspecting the request for snippets of\nmalicious SQL code.\n\nYou can only specify a single type of TextTransformation.\n\nYou use `SqlInjectionMatchSet` objects to specify which CloudFront requests that\nyou want to allow, block, or count. For example, if you're receiving requests\nthat contain snippets of SQL code in the query string and you want to block the\nrequests, you can create a `SqlInjectionMatchSet` with the applicable settings,\nand then configure AWS WAF to block the requests.\n\nTo create and configure a `SqlInjectionMatchSet`, perform the following steps:\n\n  1. Submit a `CreateSqlInjectionMatchSet` request.\n\n  2. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of an `UpdateIPSet` request.\n\n  3. Submit an `UpdateSqlInjectionMatchSet` request to specify the\nparts of web requests that you want AWS WAF to inspect for snippets of SQL code.\n\nFor more information about how to use the AWS WAF API to allow or block HTTP\nrequests, see the [AWS WAF Developer Guide](https://docs.aws.amazon.com/waf/latest/developerguide/).","ref":"AWS.WAF.html#update_sql_injection_match_set/3","title":"AWS.WAF.update_sql_injection_match_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nInserts or deletes `ActivatedRule` objects in a `WebACL`. Each `Rule` identifies\nweb requests that you want to allow, block, or count. When you update a\n`WebACL`, you specify the following values:\n\n  * A default action for the `WebACL`, either `ALLOW` or `BLOCK`. AWS\nWAF performs the default action if a request doesn't match the criteria in any\nof the `Rules` in a `WebACL`.\n\n  * The `Rules` that you want to add or delete. If you want to replace\none `Rule` with another, you delete the existing `Rule` and add the new one.\n\n  * For each `Rule`, whether you want AWS WAF to allow requests, block\nrequests, or count requests that match the conditions in the `Rule`.\n\n  * The order in which you want AWS WAF to evaluate the `Rules` in a\n`WebACL`. If you add more than one `Rule` to a `WebACL`, AWS WAF evaluates each\nrequest against the `Rules` in order based on the value of `Priority`. (The\n`Rule` that has the lowest value for `Priority` is evaluated first.) When a web\nrequest matches all the predicates (such as `ByteMatchSets` and `IPSets`) in a\n`Rule`, AWS WAF immediately takes the corresponding action, allow or block, and\ndoesn't evaluate the request against the remaining `Rules` in the `WebACL`, if\nany.\n\nTo create and configure a `WebACL`, perform the following steps:\n\n  1. Create and update the predicates that you want to include in\n`Rules`. For more information, see `CreateByteMatchSet`, `UpdateByteMatchSet`,\n`CreateIPSet`, `UpdateIPSet`, `CreateSqlInjectionMatchSet`, and\n`UpdateSqlInjectionMatchSet`.\n\n  2. Create and update the `Rules` that you want to include in the\n`WebACL`. For more information, see `CreateRule` and `UpdateRule`.\n\n  3. Create a `WebACL`. See `CreateWebACL`.\n\n  4. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of an `UpdateWebACL` request.\n\n  5. Submit an `UpdateWebACL` request to specify the `Rules` that you\nwant to include in the `WebACL`, to specify the default action, and to associate\nthe `WebACL` with a CloudFront distribution.\n\nThe `ActivatedRule` can be a rule group. If you specify a rule group as your\n`ActivatedRule` , you can exclude specific rules from that rule group.\n\nIf you already have a rule group associated with a web ACL and want to submit an\n`UpdateWebACL` request to exclude certain rules from that rule group, you must\nfirst remove the rule group from the web ACL, the re-insert it again, specifying\nthe excluded rules. For details, see `ActivatedRule$ExcludedRules` .\n\nBe aware that if you try to add a RATE_BASED rule to a web ACL without setting\nthe rule type when first creating the rule, the `UpdateWebACL` request will fail\nbecause the request tries to add a REGULAR rule (the default rule type) with the\nspecified ID, which does not exist.\n\nFor more information about how to use the AWS WAF API to allow or block HTTP\nrequests, see the [AWS WAF Developer Guide](https://docs.aws.amazon.com/waf/latest/developerguide/).","ref":"AWS.WAF.html#update_web_acl/3","title":"AWS.WAF.update_web_acl/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nInserts or deletes `XssMatchTuple` objects (filters) in an `XssMatchSet`. For\neach `XssMatchTuple` object, you specify the following values:\n\n  * `Action`: Whether to insert the object into or delete the object\nfrom the array. To change an `XssMatchTuple`, you delete the existing object and\nadd a new one.\n\n  * `FieldToMatch`: The part of web requests that you want AWS WAF to\ninspect and, if you want AWS WAF to inspect a header or custom query parameter,\nthe name of the header or parameter.\n\n  * `TextTransformation`: Which text transformation, if any, to\nperform on the web request before inspecting the request for cross-site\nscripting attacks.\n\nYou can only specify a single type of TextTransformation.\n\nYou use `XssMatchSet` objects to specify which CloudFront requests that you want\nto allow, block, or count. For example, if you're receiving requests that\ncontain cross-site scripting attacks in the request body and you want to block\nthe requests, you can create an `XssMatchSet` with the applicable settings, and\nthen configure AWS WAF to block the requests.\n\nTo create and configure an `XssMatchSet`, perform the following steps:\n\n  1. Submit a `CreateXssMatchSet` request.\n\n  2. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of an `UpdateIPSet` request.\n\n  3. Submit an `UpdateXssMatchSet` request to specify the parts of web\nrequests that you want AWS WAF to inspect for cross-site scripting attacks.\n\nFor more information about how to use the AWS WAF API to allow or block HTTP\nrequests, see the [AWS WAF Developer Guide](https://docs.aws.amazon.com/waf/latest/developerguide/).","ref":"AWS.WAF.html#update_xss_match_set/3","title":"AWS.WAF.update_xss_match_set/3","type":"function"},{"doc":"This is **AWS WAF Classic Regional** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nThis is the *AWS WAF Regional Classic API Reference* for using AWS WAF Classic\nwith the AWS resources, Elastic Load Balancing (ELB) Application Load Balancers\nand API Gateway APIs. The AWS WAF Classic actions and data types listed in the\nreference are available for protecting Elastic Load Balancing (ELB) Application\nLoad Balancers and API Gateway APIs. You can use these actions and data types by\nmeans of the endpoints listed in [AWS Regions and Endpoints](https://docs.aws.amazon.com/general/latest/gr/rande.html#waf_region).\nThis guide is for developers who need detailed information about the AWS WAF\nClassic API actions, data types, and errors. For detailed information about AWS\nWAF Classic features and an overview of how to use the AWS WAF Classic API, see\nthe [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.","ref":"AWS.WAFRegional.html","title":"AWS.WAFRegional","type":"module"},{"doc":"This is **AWS WAF Classic Regional** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nAssociates a web ACL with a resource, either an application load balancer or\nAmazon API Gateway stage.","ref":"AWS.WAFRegional.html#associate_web_acl/3","title":"AWS.WAFRegional.associate_web_acl/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nCreates a `ByteMatchSet`. You then use `UpdateByteMatchSet` to identify the part\nof a web request that you want AWS WAF to inspect, such as the values of the\n`User-Agent` header or the query string. For example, you can create a\n`ByteMatchSet` that matches any requests with `User-Agent` headers that contain\nthe string `BadBot`. You can then configure AWS WAF to reject those requests.\n\nTo create and configure a `ByteMatchSet`, perform the following steps:\n\n  1. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of a `CreateByteMatchSet` request.\n\n  2. Submit a `CreateByteMatchSet` request.\n\n  3. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of an `UpdateByteMatchSet` request.\n\n  4. Submit an `UpdateByteMatchSet` request to specify the part of the\nrequest that you want AWS WAF to inspect (for example, the header or the URI)\nand the value that you want AWS WAF to watch for.\n\nFor more information about how to use the AWS WAF API to allow or block HTTP\nrequests, see the [AWS WAF Developer Guide](https://docs.aws.amazon.com/waf/latest/developerguide/).","ref":"AWS.WAFRegional.html#create_byte_match_set/3","title":"AWS.WAFRegional.create_byte_match_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nCreates an `GeoMatchSet`, which you use to specify which web requests you want\nto allow or block based on the country that the requests originate from. For\nexample, if you're receiving a lot of requests from one or more countries and\nyou want to block the requests, you can create an `GeoMatchSet` that contains\nthose countries and then configure AWS WAF to block the requests.\n\nTo create and configure a `GeoMatchSet`, perform the following steps:\n\n  1. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of a `CreateGeoMatchSet` request.\n\n  2. Submit a `CreateGeoMatchSet` request.\n\n  3. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of an `UpdateGeoMatchSet` request.\n\n  4. Submit an `UpdateGeoMatchSetSet` request to specify the countries\nthat you want AWS WAF to watch for.\n\nFor more information about how to use the AWS WAF API to allow or block HTTP\nrequests, see the [AWS WAF Developer Guide](https://docs.aws.amazon.com/waf/latest/developerguide/).","ref":"AWS.WAFRegional.html#create_geo_match_set/3","title":"AWS.WAFRegional.create_geo_match_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nCreates an `IPSet`, which you use to specify which web requests that you want to\nallow or block based on the IP addresses that the requests originate from. For\nexample, if you're receiving a lot of requests from one or more individual IP\naddresses or one or more ranges of IP addresses and you want to block the\nrequests, you can create an `IPSet` that contains those IP addresses and then\nconfigure AWS WAF to block the requests.\n\nTo create and configure an `IPSet`, perform the following steps:\n\n  1. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of a `CreateIPSet` request.\n\n  2. Submit a `CreateIPSet` request.\n\n  3. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of an `UpdateIPSet` request.\n\n  4. Submit an `UpdateIPSet` request to specify the IP addresses that\nyou want AWS WAF to watch for.\n\nFor more information about how to use the AWS WAF API to allow or block HTTP\nrequests, see the [AWS WAF Developer Guide](https://docs.aws.amazon.com/waf/latest/developerguide/).","ref":"AWS.WAFRegional.html#create_ip_set/3","title":"AWS.WAFRegional.create_ip_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nCreates a `RateBasedRule`. The `RateBasedRule` contains a `RateLimit`, which\nspecifies the maximum number of requests that AWS WAF allows from a specified IP\naddress in a five-minute period. The `RateBasedRule` also contains the `IPSet`\nobjects, `ByteMatchSet` objects, and other predicates that identify the requests\nthat you want to count or block if these requests exceed the `RateLimit`.\n\nIf you add more than one predicate to a `RateBasedRule`, a request not only must\nexceed the `RateLimit`, but it also must match all the conditions to be counted\nor blocked. For example, suppose you add the following to a `RateBasedRule`:\n\n  * An `IPSet` that matches the IP address `192.0.2.44/32`\n\n  * A `ByteMatchSet` that matches `BadBot` in the `User-Agent` header\n\nFurther, you specify a `RateLimit` of 1,000.\n\nYou then add the `RateBasedRule` to a `WebACL` and specify that you want to\nblock requests that meet the conditions in the rule. For a request to be\nblocked, it must come from the IP address 192.0.2.44 *and* the `User-Agent`\nheader in the request must contain the value `BadBot`. Further, requests that\nmatch these two conditions must be received at a rate of more than 1,000\nrequests every five minutes. If both conditions are met and the rate is\nexceeded, AWS WAF blocks the requests. If the rate drops below 1,000 for a\nfive-minute period, AWS WAF no longer blocks the requests.\n\nAs a second example, suppose you want to limit requests to a particular page on\nyour site. To do this, you could add the following to a `RateBasedRule`:\n\n  * A `ByteMatchSet` with `FieldToMatch` of `URI`\n\n  * A `PositionalConstraint` of `STARTS_WITH`\n\n  * A `TargetString` of `login`\n\nFurther, you specify a `RateLimit` of 1,000.\n\nBy adding this `RateBasedRule` to a `WebACL`, you could limit requests to your\nlogin page without affecting the rest of your site.\n\nTo create and configure a `RateBasedRule`, perform the following steps:\n\n  1. Create and update the predicates that you want to include in the\nrule. For more information, see `CreateByteMatchSet`, `CreateIPSet`, and\n`CreateSqlInjectionMatchSet`.\n\n  2. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of a `CreateRule` request.\n\n  3. Submit a `CreateRateBasedRule` request.\n\n  4. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of an `UpdateRule` request.\n\n  5. Submit an `UpdateRateBasedRule` request to specify the predicates\nthat you want to include in the rule.\n\n  6. Create and update a `WebACL` that contains the `RateBasedRule`.\nFor more information, see `CreateWebACL`.\n\nFor more information about how to use the AWS WAF API to allow or block HTTP\nrequests, see the [AWS WAF Developer Guide](https://docs.aws.amazon.com/waf/latest/developerguide/).","ref":"AWS.WAFRegional.html#create_rate_based_rule/3","title":"AWS.WAFRegional.create_rate_based_rule/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nCreates a `RegexMatchSet`. You then use `UpdateRegexMatchSet` to identify the\npart of a web request that you want AWS WAF to inspect, such as the values of\nthe `User-Agent` header or the query string. For example, you can create a\n`RegexMatchSet` that contains a `RegexMatchTuple` that looks for any requests\nwith `User-Agent` headers that match a `RegexPatternSet` with pattern\n`B[a@]dB[o0]t`. You can then configure AWS WAF to reject those requests.  To create and configure a `RegexMatchSet`, perform the following steps:\n\n  1. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of a `CreateRegexMatchSet` request.\n\n  2. Submit a `CreateRegexMatchSet` request.\n\n  3. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of an `UpdateRegexMatchSet` request.\n\n  4. Submit an `UpdateRegexMatchSet` request to specify the part of\nthe request that you want AWS WAF to inspect (for example, the header or the\nURI) and the value, using a `RegexPatternSet`, that you want AWS WAF to watch\nfor.\n\nFor more information about how to use the AWS WAF API to allow or block HTTP\nrequests, see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/).","ref":"AWS.WAFRegional.html#create_regex_match_set/3","title":"AWS.WAFRegional.create_regex_match_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nCreates a `RegexPatternSet`. You then use `UpdateRegexPatternSet` to specify the\nregular expression (regex) pattern that you want AWS WAF to search for, such as\n`B[a@]dB[o0]t`. You can then configure AWS WAF to reject those requests.  To create and configure a `RegexPatternSet`, perform the following steps:\n\n  1. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of a `CreateRegexPatternSet` request.\n\n  2. Submit a `CreateRegexPatternSet` request.\n\n  3. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of an `UpdateRegexPatternSet` request.\n\n  4. Submit an `UpdateRegexPatternSet` request to specify the string\nthat you want AWS WAF to watch for.\n\nFor more information about how to use the AWS WAF API to allow or block HTTP\nrequests, see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/).","ref":"AWS.WAFRegional.html#create_regex_pattern_set/3","title":"AWS.WAFRegional.create_regex_pattern_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nCreates a `Rule`, which contains the `IPSet` objects, `ByteMatchSet` objects,\nand other predicates that identify the requests that you want to block. If you\nadd more than one predicate to a `Rule`, a request must match all of the\nspecifications to be allowed or blocked. For example, suppose that you add the\nfollowing to a `Rule`:\n\n  * An `IPSet` that matches the IP address `192.0.2.44/32`\n\n  * A `ByteMatchSet` that matches `BadBot` in the `User-Agent` header\n\nYou then add the `Rule` to a `WebACL` and specify that you want to blocks\nrequests that satisfy the `Rule`. For a request to be blocked, it must come from\nthe IP address 192.0.2.44 *and* the `User-Agent` header in the request must\ncontain the value `BadBot`.\n\nTo create and configure a `Rule`, perform the following steps:\n\n  1. Create and update the predicates that you want to include in the\n`Rule`. For more information, see `CreateByteMatchSet`, `CreateIPSet`, and\n`CreateSqlInjectionMatchSet`.\n\n  2. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of a `CreateRule` request.\n\n  3. Submit a `CreateRule` request.\n\n  4. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of an `UpdateRule` request.\n\n  5. Submit an `UpdateRule` request to specify the predicates that you\nwant to include in the `Rule`.\n\n  6. Create and update a `WebACL` that contains the `Rule`. For more\ninformation, see `CreateWebACL`.\n\nFor more information about how to use the AWS WAF API to allow or block HTTP\nrequests, see the [AWS WAF Developer Guide](https://docs.aws.amazon.com/waf/latest/developerguide/).","ref":"AWS.WAFRegional.html#create_rule/3","title":"AWS.WAFRegional.create_rule/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nCreates a `RuleGroup`. A rule group is a collection of predefined rules that you\nadd to a web ACL. You use `UpdateRuleGroup` to add rules to the rule group.\n\nRule groups are subject to the following limits:\n\n  * Three rule groups per account. You can request an increase to this\nlimit by contacting customer support.\n\n  * One rule group per web ACL.\n\n  * Ten rules per rule group.\n\nFor more information about how to use the AWS WAF API to allow or block HTTP\nrequests, see the [AWS WAF Developer Guide](https://docs.aws.amazon.com/waf/latest/developerguide/).","ref":"AWS.WAFRegional.html#create_rule_group/3","title":"AWS.WAFRegional.create_rule_group/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nCreates a `SizeConstraintSet`. You then use `UpdateSizeConstraintSet` to\nidentify the part of a web request that you want AWS WAF to check for length,\nsuch as the length of the `User-Agent` header or the length of the query string.\nFor example, you can create a `SizeConstraintSet` that matches any requests that\nhave a query string that is longer than 100 bytes. You can then configure AWS\nWAF to reject those requests.\n\nTo create and configure a `SizeConstraintSet`, perform the following steps:\n\n  1. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of a `CreateSizeConstraintSet` request.\n\n  2. Submit a `CreateSizeConstraintSet` request.\n\n  3. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of an `UpdateSizeConstraintSet` request.\n\n  4. Submit an `UpdateSizeConstraintSet` request to specify the part\nof the request that you want AWS WAF to inspect (for example, the header or the\nURI) and the value that you want AWS WAF to watch for.\n\nFor more information about how to use the AWS WAF API to allow or block HTTP\nrequests, see the [AWS WAF Developer Guide](https://docs.aws.amazon.com/waf/latest/developerguide/).","ref":"AWS.WAFRegional.html#create_size_constraint_set/3","title":"AWS.WAFRegional.create_size_constraint_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nCreates a `SqlInjectionMatchSet`, which you use to allow, block, or count\nrequests that contain snippets of SQL code in a specified part of web requests.\nAWS WAF searches for character sequences that are likely to be malicious\nstrings.\n\nTo create and configure a `SqlInjectionMatchSet`, perform the following steps:\n\n  1. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of a `CreateSqlInjectionMatchSet` request.\n\n  2. Submit a `CreateSqlInjectionMatchSet` request.\n\n  3. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of an `UpdateSqlInjectionMatchSet` request.\n\n  4. Submit an `UpdateSqlInjectionMatchSet` request to specify the\nparts of web requests in which you want to allow, block, or count malicious SQL\ncode.\n\nFor more information about how to use the AWS WAF API to allow or block HTTP\nrequests, see the [AWS WAF Developer Guide](https://docs.aws.amazon.com/waf/latest/developerguide/).","ref":"AWS.WAFRegional.html#create_sql_injection_match_set/3","title":"AWS.WAFRegional.create_sql_injection_match_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nCreates a `WebACL`, which contains the `Rules` that identify the CloudFront web\nrequests that you want to allow, block, or count. AWS WAF evaluates `Rules` in\norder based on the value of `Priority` for each `Rule`.\n\nYou also specify a default action, either `ALLOW` or `BLOCK`. If a web request\ndoesn't match any of the `Rules` in a `WebACL`, AWS WAF responds to the request\nwith the default action.\n\nTo create and configure a `WebACL`, perform the following steps:\n\n  1. Create and update the `ByteMatchSet` objects and other predicates\nthat you want to include in `Rules`. For more information, see\n`CreateByteMatchSet`, `UpdateByteMatchSet`, `CreateIPSet`, `UpdateIPSet`,\n`CreateSqlInjectionMatchSet`, and `UpdateSqlInjectionMatchSet`.\n\n  2. Create and update the `Rules` that you want to include in the\n`WebACL`. For more information, see `CreateRule` and `UpdateRule`.\n\n  3. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of a `CreateWebACL` request.\n\n  4. Submit a `CreateWebACL` request.\n\n  5. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of an `UpdateWebACL` request.\n\n  6. Submit an `UpdateWebACL` request to specify the `Rules` that you\nwant to include in the `WebACL`, to specify the default action, and to associate\nthe `WebACL` with a CloudFront distribution.\n\nFor more information about how to use the AWS WAF API, see the [AWS WAF Developer Guide](https://docs.aws.amazon.com/waf/latest/developerguide/).","ref":"AWS.WAFRegional.html#create_web_acl/3","title":"AWS.WAFRegional.create_web_acl/3","type":"function"},{"doc":"Creates an AWS CloudFormation WAFV2 template for the specified web ACL in the\nspecified Amazon S3 bucket.\n\nThen, in CloudFormation, you create a stack from the template, to create the web\nACL and its resources in AWS WAFV2. Use this to migrate your AWS WAF Classic web\nACL to the latest version of AWS WAF.\n\nThis is part of a larger migration procedure for web ACLs from AWS WAF Classic\nto the latest version of AWS WAF. For the full procedure, including caveats and\nmanual steps to complete the migration and switch over to the new web ACL, see\n[Migrating your AWS WAF Classic resources to AWS WAF](https://docs.aws.amazon.com/waf/latest/developerguide/waf-migrating-from-classic.html)\nin the [AWS WAF Developer Guide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).","ref":"AWS.WAFRegional.html#create_web_acl_migration_stack/3","title":"AWS.WAFRegional.create_web_acl_migration_stack/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nCreates an `XssMatchSet`, which you use to allow, block, or count requests that\ncontain cross-site scripting attacks in the specified part of web requests. AWS\nWAF searches for character sequences that are likely to be malicious strings.\n\nTo create and configure an `XssMatchSet`, perform the following steps:\n\n  1. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of a `CreateXssMatchSet` request.\n\n  2. Submit a `CreateXssMatchSet` request.\n\n  3. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of an `UpdateXssMatchSet` request.\n\n  4. Submit an `UpdateXssMatchSet` request to specify the parts of web\nrequests in which you want to allow, block, or count cross-site scripting\nattacks.\n\nFor more information about how to use the AWS WAF API to allow or block HTTP\nrequests, see the [AWS WAF Developer Guide](https://docs.aws.amazon.com/waf/latest/developerguide/).","ref":"AWS.WAFRegional.html#create_xss_match_set/3","title":"AWS.WAFRegional.create_xss_match_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nPermanently deletes a `ByteMatchSet`. You can't delete a `ByteMatchSet` if it's\nstill used in any `Rules` or if it still includes any `ByteMatchTuple` objects\n(any filters).\n\nIf you just want to remove a `ByteMatchSet` from a `Rule`, use `UpdateRule`.\n\nTo permanently delete a `ByteMatchSet`, perform the following steps:\n\n  1. Update the `ByteMatchSet` to remove filters, if any. For more\ninformation, see `UpdateByteMatchSet`.\n\n  2. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of a `DeleteByteMatchSet` request.\n\n  3. Submit a `DeleteByteMatchSet` request.","ref":"AWS.WAFRegional.html#delete_byte_match_set/3","title":"AWS.WAFRegional.delete_byte_match_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nPermanently deletes a `GeoMatchSet`. You can't delete a `GeoMatchSet` if it's\nstill used in any `Rules` or if it still includes any countries.\n\nIf you just want to remove a `GeoMatchSet` from a `Rule`, use `UpdateRule`.\n\nTo permanently delete a `GeoMatchSet` from AWS WAF, perform the following steps:\n\n  1. Update the `GeoMatchSet` to remove any countries. For more\ninformation, see `UpdateGeoMatchSet`.\n\n  2. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of a `DeleteGeoMatchSet` request.\n\n  3. Submit a `DeleteGeoMatchSet` request.","ref":"AWS.WAFRegional.html#delete_geo_match_set/3","title":"AWS.WAFRegional.delete_geo_match_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nPermanently deletes an `IPSet`. You can't delete an `IPSet` if it's still used\nin any `Rules` or if it still includes any IP addresses.\n\nIf you just want to remove an `IPSet` from a `Rule`, use `UpdateRule`.\n\nTo permanently delete an `IPSet` from AWS WAF, perform the following steps:\n\n  1. Update the `IPSet` to remove IP address ranges, if any. For more\ninformation, see `UpdateIPSet`.\n\n  2. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of a `DeleteIPSet` request.\n\n  3. Submit a `DeleteIPSet` request.","ref":"AWS.WAFRegional.html#delete_ip_set/3","title":"AWS.WAFRegional.delete_ip_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nPermanently deletes the `LoggingConfiguration` from the specified web ACL.","ref":"AWS.WAFRegional.html#delete_logging_configuration/3","title":"AWS.WAFRegional.delete_logging_configuration/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nPermanently deletes an IAM policy from the specified RuleGroup.\n\nThe user making the request must be the owner of the RuleGroup.","ref":"AWS.WAFRegional.html#delete_permission_policy/3","title":"AWS.WAFRegional.delete_permission_policy/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nPermanently deletes a `RateBasedRule`. You can't delete a rule if it's still\nused in any `WebACL` objects or if it still includes any predicates, such as\n`ByteMatchSet` objects.\n\nIf you just want to remove a rule from a `WebACL`, use `UpdateWebACL`.\n\nTo permanently delete a `RateBasedRule` from AWS WAF, perform the following\nsteps:\n\n  1. Update the `RateBasedRule` to remove predicates, if any. For more\ninformation, see `UpdateRateBasedRule`.\n\n  2. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of a `DeleteRateBasedRule` request.\n\n  3. Submit a `DeleteRateBasedRule` request.","ref":"AWS.WAFRegional.html#delete_rate_based_rule/3","title":"AWS.WAFRegional.delete_rate_based_rule/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nPermanently deletes a `RegexMatchSet`. You can't delete a `RegexMatchSet` if\nit's still used in any `Rules` or if it still includes any `RegexMatchTuples`\nobjects (any filters).\n\nIf you just want to remove a `RegexMatchSet` from a `Rule`, use `UpdateRule`.\n\nTo permanently delete a `RegexMatchSet`, perform the following steps:\n\n  1. Update the `RegexMatchSet` to remove filters, if any. For more\ninformation, see `UpdateRegexMatchSet`.\n\n  2. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of a `DeleteRegexMatchSet` request.\n\n  3. Submit a `DeleteRegexMatchSet` request.","ref":"AWS.WAFRegional.html#delete_regex_match_set/3","title":"AWS.WAFRegional.delete_regex_match_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nPermanently deletes a `RegexPatternSet`. You can't delete a `RegexPatternSet` if\nit's still used in any `RegexMatchSet` or if the `RegexPatternSet` is not empty.","ref":"AWS.WAFRegional.html#delete_regex_pattern_set/3","title":"AWS.WAFRegional.delete_regex_pattern_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nPermanently deletes a `Rule`. You can't delete a `Rule` if it's still used in\nany `WebACL` objects or if it still includes any predicates, such as\n`ByteMatchSet` objects.\n\nIf you just want to remove a `Rule` from a `WebACL`, use `UpdateWebACL`.\n\nTo permanently delete a `Rule` from AWS WAF, perform the following steps:\n\n  1. Update the `Rule` to remove predicates, if any. For more\ninformation, see `UpdateRule`.\n\n  2. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of a `DeleteRule` request.\n\n  3. Submit a `DeleteRule` request.","ref":"AWS.WAFRegional.html#delete_rule/3","title":"AWS.WAFRegional.delete_rule/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nPermanently deletes a `RuleGroup`. You can't delete a `RuleGroup` if it's still\nused in any `WebACL` objects or if it still includes any rules.\n\nIf you just want to remove a `RuleGroup` from a `WebACL`, use `UpdateWebACL`.\n\nTo permanently delete a `RuleGroup` from AWS WAF, perform the following steps:\n\n  1. Update the `RuleGroup` to remove rules, if any. For more\ninformation, see `UpdateRuleGroup`.\n\n  2. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of a `DeleteRuleGroup` request.\n\n  3. Submit a `DeleteRuleGroup` request.","ref":"AWS.WAFRegional.html#delete_rule_group/3","title":"AWS.WAFRegional.delete_rule_group/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nPermanently deletes a `SizeConstraintSet`. You can't delete a\n`SizeConstraintSet` if it's still used in any `Rules` or if it still includes\nany `SizeConstraint` objects (any filters).\n\nIf you just want to remove a `SizeConstraintSet` from a `Rule`, use\n`UpdateRule`.\n\nTo permanently delete a `SizeConstraintSet`, perform the following steps:\n\n  1. Update the `SizeConstraintSet` to remove filters, if any. For\nmore information, see `UpdateSizeConstraintSet`.\n\n  2. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of a `DeleteSizeConstraintSet` request.\n\n  3. Submit a `DeleteSizeConstraintSet` request.","ref":"AWS.WAFRegional.html#delete_size_constraint_set/3","title":"AWS.WAFRegional.delete_size_constraint_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nPermanently deletes a `SqlInjectionMatchSet`. You can't delete a\n`SqlInjectionMatchSet` if it's still used in any `Rules` or if it still contains\nany `SqlInjectionMatchTuple` objects.\n\nIf you just want to remove a `SqlInjectionMatchSet` from a `Rule`, use\n`UpdateRule`.\n\nTo permanently delete a `SqlInjectionMatchSet` from AWS WAF, perform the\nfollowing steps:\n\n  1. Update the `SqlInjectionMatchSet` to remove filters, if any. For\nmore information, see `UpdateSqlInjectionMatchSet`.\n\n  2. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of a `DeleteSqlInjectionMatchSet` request.\n\n  3. Submit a `DeleteSqlInjectionMatchSet` request.","ref":"AWS.WAFRegional.html#delete_sql_injection_match_set/3","title":"AWS.WAFRegional.delete_sql_injection_match_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nPermanently deletes a `WebACL`. You can't delete a `WebACL` if it still contains\nany `Rules`.\n\nTo delete a `WebACL`, perform the following steps:\n\n  1. Update the `WebACL` to remove `Rules`, if any. For more\ninformation, see `UpdateWebACL`.\n\n  2. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of a `DeleteWebACL` request.\n\n  3. Submit a `DeleteWebACL` request.","ref":"AWS.WAFRegional.html#delete_web_acl/3","title":"AWS.WAFRegional.delete_web_acl/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nPermanently deletes an `XssMatchSet`. You can't delete an `XssMatchSet` if it's\nstill used in any `Rules` or if it still contains any `XssMatchTuple` objects.\n\nIf you just want to remove an `XssMatchSet` from a `Rule`, use `UpdateRule`.\n\nTo permanently delete an `XssMatchSet` from AWS WAF, perform the following\nsteps:\n\n  1. Update the `XssMatchSet` to remove filters, if any. For more\ninformation, see `UpdateXssMatchSet`.\n\n  2. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of a `DeleteXssMatchSet` request.\n\n  3. Submit a `DeleteXssMatchSet` request.","ref":"AWS.WAFRegional.html#delete_xss_match_set/3","title":"AWS.WAFRegional.delete_xss_match_set/3","type":"function"},{"doc":"This is **AWS WAF Classic Regional** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nRemoves a web ACL from the specified resource, either an application load\nbalancer or Amazon API Gateway stage.","ref":"AWS.WAFRegional.html#disassociate_web_acl/3","title":"AWS.WAFRegional.disassociate_web_acl/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns the `ByteMatchSet` specified by `ByteMatchSetId`.","ref":"AWS.WAFRegional.html#get_byte_match_set/3","title":"AWS.WAFRegional.get_byte_match_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nWhen you want to create, update, or delete AWS WAF objects, get a change token\nand include the change token in the create, update, or delete request. Change\ntokens ensure that your application doesn't submit conflicting requests to AWS\nWAF.\n\nEach create, update, or delete request must use a unique change token. If your\napplication submits a `GetChangeToken` request and then submits a second\n`GetChangeToken` request before submitting a create, update, or delete request,\nthe second `GetChangeToken` request returns the same value as the first\n`GetChangeToken` request.\n\nWhen you use a change token in a create, update, or delete request, the status\nof the change token changes to `PENDING`, which indicates that AWS WAF is\npropagating the change to all AWS WAF servers. Use `GetChangeTokenStatus` to\ndetermine the status of your change token.","ref":"AWS.WAFRegional.html#get_change_token/3","title":"AWS.WAFRegional.get_change_token/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns the status of a `ChangeToken` that you got by calling `GetChangeToken`.\n`ChangeTokenStatus` is one of the following values:\n\n  * `PROVISIONED`: You requested the change token by calling\n`GetChangeToken`, but you haven't used it yet in a call to create, update, or\ndelete an AWS WAF object.\n\n  * `PENDING`: AWS WAF is propagating the create, update, or delete\nrequest to all AWS WAF servers.\n\n  * `INSYNC`: Propagation is complete.","ref":"AWS.WAFRegional.html#get_change_token_status/3","title":"AWS.WAFRegional.get_change_token_status/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns the `GeoMatchSet` that is specified by `GeoMatchSetId`.","ref":"AWS.WAFRegional.html#get_geo_match_set/3","title":"AWS.WAFRegional.get_geo_match_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns the `IPSet` that is specified by `IPSetId`.","ref":"AWS.WAFRegional.html#get_ip_set/3","title":"AWS.WAFRegional.get_ip_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns the `LoggingConfiguration` for the specified web ACL.","ref":"AWS.WAFRegional.html#get_logging_configuration/3","title":"AWS.WAFRegional.get_logging_configuration/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns the IAM policy attached to the RuleGroup.","ref":"AWS.WAFRegional.html#get_permission_policy/3","title":"AWS.WAFRegional.get_permission_policy/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns the `RateBasedRule` that is specified by the `RuleId` that you included\nin the `GetRateBasedRule` request.","ref":"AWS.WAFRegional.html#get_rate_based_rule/3","title":"AWS.WAFRegional.get_rate_based_rule/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns an array of IP addresses currently being blocked by the `RateBasedRule`\nthat is specified by the `RuleId`. The maximum number of managed keys that will\nbe blocked is 10,000. If more than 10,000 addresses exceed the rate limit, the\n10,000 addresses with the highest rates will be blocked.","ref":"AWS.WAFRegional.html#get_rate_based_rule_managed_keys/3","title":"AWS.WAFRegional.get_rate_based_rule_managed_keys/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns the `RegexMatchSet` specified by `RegexMatchSetId`.","ref":"AWS.WAFRegional.html#get_regex_match_set/3","title":"AWS.WAFRegional.get_regex_match_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns the `RegexPatternSet` specified by `RegexPatternSetId`.","ref":"AWS.WAFRegional.html#get_regex_pattern_set/3","title":"AWS.WAFRegional.get_regex_pattern_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns the `Rule` that is specified by the `RuleId` that you included in the\n`GetRule` request.","ref":"AWS.WAFRegional.html#get_rule/3","title":"AWS.WAFRegional.get_rule/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns the `RuleGroup` that is specified by the `RuleGroupId` that you included\nin the `GetRuleGroup` request.\n\nTo view the rules in a rule group, use `ListActivatedRulesInRuleGroup`.","ref":"AWS.WAFRegional.html#get_rule_group/3","title":"AWS.WAFRegional.get_rule_group/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nGets detailed information about a specified number of requests--a sample--that\nAWS WAF randomly selects from among the first 5,000 requests that your AWS\nresource received during a time range that you choose. You can specify a sample\nsize of up to 500 requests, and you can specify any time range in the previous\nthree hours.\n\n`GetSampledRequests` returns a time range, which is usually the time range that\nyou specified. However, if your resource (such as a CloudFront distribution)\nreceived 5,000 requests before the specified time range elapsed,\n`GetSampledRequests` returns an updated time range. This new time range\nindicates the actual period during which AWS WAF selected the requests in the\nsample.","ref":"AWS.WAFRegional.html#get_sampled_requests/3","title":"AWS.WAFRegional.get_sampled_requests/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns the `SizeConstraintSet` specified by `SizeConstraintSetId`.","ref":"AWS.WAFRegional.html#get_size_constraint_set/3","title":"AWS.WAFRegional.get_size_constraint_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns the `SqlInjectionMatchSet` that is specified by\n`SqlInjectionMatchSetId`.","ref":"AWS.WAFRegional.html#get_sql_injection_match_set/3","title":"AWS.WAFRegional.get_sql_injection_match_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns the `WebACL` that is specified by `WebACLId`.","ref":"AWS.WAFRegional.html#get_web_acl/3","title":"AWS.WAFRegional.get_web_acl/3","type":"function"},{"doc":"This is **AWS WAF Classic Regional** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns the web ACL for the specified resource, either an application load\nbalancer or Amazon API Gateway stage.","ref":"AWS.WAFRegional.html#get_web_acl_for_resource/3","title":"AWS.WAFRegional.get_web_acl_for_resource/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns the `XssMatchSet` that is specified by `XssMatchSetId`.","ref":"AWS.WAFRegional.html#get_xss_match_set/3","title":"AWS.WAFRegional.get_xss_match_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns an array of `ActivatedRule` objects.","ref":"AWS.WAFRegional.html#list_activated_rules_in_rule_group/3","title":"AWS.WAFRegional.list_activated_rules_in_rule_group/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns an array of `ByteMatchSetSummary` objects.","ref":"AWS.WAFRegional.html#list_byte_match_sets/3","title":"AWS.WAFRegional.list_byte_match_sets/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns an array of `GeoMatchSetSummary` objects in the response.","ref":"AWS.WAFRegional.html#list_geo_match_sets/3","title":"AWS.WAFRegional.list_geo_match_sets/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns an array of `IPSetSummary` objects in the response.","ref":"AWS.WAFRegional.html#list_ip_sets/3","title":"AWS.WAFRegional.list_ip_sets/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns an array of `LoggingConfiguration` objects.","ref":"AWS.WAFRegional.html#list_logging_configurations/3","title":"AWS.WAFRegional.list_logging_configurations/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns an array of `RuleSummary` objects.","ref":"AWS.WAFRegional.html#list_rate_based_rules/3","title":"AWS.WAFRegional.list_rate_based_rules/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns an array of `RegexMatchSetSummary` objects.","ref":"AWS.WAFRegional.html#list_regex_match_sets/3","title":"AWS.WAFRegional.list_regex_match_sets/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns an array of `RegexPatternSetSummary` objects.","ref":"AWS.WAFRegional.html#list_regex_pattern_sets/3","title":"AWS.WAFRegional.list_regex_pattern_sets/3","type":"function"},{"doc":"This is **AWS WAF Classic Regional** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns an array of resources associated with the specified web ACL.","ref":"AWS.WAFRegional.html#list_resources_for_web_acl/3","title":"AWS.WAFRegional.list_resources_for_web_acl/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns an array of `RuleGroup` objects.","ref":"AWS.WAFRegional.html#list_rule_groups/3","title":"AWS.WAFRegional.list_rule_groups/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns an array of `RuleSummary` objects.","ref":"AWS.WAFRegional.html#list_rules/3","title":"AWS.WAFRegional.list_rules/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns an array of `SizeConstraintSetSummary` objects.","ref":"AWS.WAFRegional.html#list_size_constraint_sets/3","title":"AWS.WAFRegional.list_size_constraint_sets/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns an array of `SqlInjectionMatchSet` objects.","ref":"AWS.WAFRegional.html#list_sql_injection_match_sets/3","title":"AWS.WAFRegional.list_sql_injection_match_sets/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns an array of `RuleGroup` objects that you are subscribed to.","ref":"AWS.WAFRegional.html#list_subscribed_rule_groups/3","title":"AWS.WAFRegional.list_subscribed_rule_groups/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nRetrieves the tags associated with the specified AWS resource. Tags are\nkey:value pairs that you can use to categorize and manage your resources, for\npurposes like billing. For example, you might set the tag key to \"customer\" and\nthe value to the customer name or ID. You can specify one or more tags to add to\neach AWS resource, up to 50 tags for a resource.\n\nTagging is only available through the API, SDKs, and CLI. You can't manage or\nview tags through the AWS WAF Classic console. You can tag the AWS resources\nthat you manage through AWS WAF Classic: web ACLs, rule groups, and rules.","ref":"AWS.WAFRegional.html#list_tags_for_resource/3","title":"AWS.WAFRegional.list_tags_for_resource/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns an array of `WebACLSummary` objects in the response.","ref":"AWS.WAFRegional.html#list_web_acls/3","title":"AWS.WAFRegional.list_web_acls/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nReturns an array of `XssMatchSet` objects.","ref":"AWS.WAFRegional.html#list_xss_match_sets/3","title":"AWS.WAFRegional.list_xss_match_sets/3","type":"function"},{"doc":"","ref":"AWS.WAFRegional.html#metadata/0","title":"AWS.WAFRegional.metadata/0","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nAssociates a `LoggingConfiguration` with a specified web ACL.\n\nYou can access information about all traffic that AWS WAF inspects using the\nfollowing steps:\n\n  1. Create an Amazon Kinesis Data Firehose.\n\nCreate the data firehose with a PUT source and in the region that you are\noperating. However, if you are capturing logs for Amazon CloudFront, always\ncreate the firehose in US East (N. Virginia).\n\nDo not create the data firehose using a `Kinesis stream` as your source.\n\n  2. Associate that firehose to your web ACL using a\n`PutLoggingConfiguration` request.\n\nWhen you successfully enable logging using a `PutLoggingConfiguration` request,\nAWS WAF will create a service linked role with the necessary permissions to\nwrite logs to the Amazon Kinesis Data Firehose. For more information, see\n[Logging Web ACL Traffic Information](https://docs.aws.amazon.com/waf/latest/developerguide/logging.html)\nin the *AWS WAF Developer Guide*.","ref":"AWS.WAFRegional.html#put_logging_configuration/3","title":"AWS.WAFRegional.put_logging_configuration/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nAttaches an IAM policy to the specified resource. The only supported use for\nthis action is to share a RuleGroup across accounts.\n\nThe `PutPermissionPolicy` is subject to the following restrictions:\n\n  * You can attach only one policy with each `PutPermissionPolicy`\nrequest.\n\n  * The policy must include an `Effect`, `Action` and `Principal`.\n\n  * `Effect` must specify `Allow`.\n\n  * The `Action` in the policy must be `waf:UpdateWebACL`,\n`waf-regional:UpdateWebACL`, `waf:GetRuleGroup` and `waf-regional:GetRuleGroup`\n. Any extra or wildcard actions in the policy will be rejected.\n\n  * The policy cannot include a `Resource` parameter.\n\n  * The ARN in the request must be a valid WAF RuleGroup ARN and the\nRuleGroup must exist in the same region.\n\n  * The user making the request must be the owner of the RuleGroup.\n\n  * Your policy must be composed using IAM Policy version 2012-10-17.\n\nFor more information, see [IAM Policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies.html).\n\nAn example of a valid policy parameter is shown in the Examples section below.","ref":"AWS.WAFRegional.html#put_permission_policy/3","title":"AWS.WAFRegional.put_permission_policy/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nAssociates tags with the specified AWS resource. Tags are key:value pairs that\nyou can use to categorize and manage your resources, for purposes like billing.\nFor example, you might set the tag key to \"customer\" and the value to the\ncustomer name or ID. You can specify one or more tags to add to each AWS\nresource, up to 50 tags for a resource.\n\nTagging is only available through the API, SDKs, and CLI. You can't manage or\nview tags through the AWS WAF Classic console. You can use this action to tag\nthe AWS resources that you manage through AWS WAF Classic: web ACLs, rule\ngroups, and rules.","ref":"AWS.WAFRegional.html#tag_resource/3","title":"AWS.WAFRegional.tag_resource/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.","ref":"AWS.WAFRegional.html#untag_resource/3","title":"AWS.WAFRegional.untag_resource/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nInserts or deletes `ByteMatchTuple` objects (filters) in a `ByteMatchSet`. For\neach `ByteMatchTuple` object, you specify the following values:\n\n  * Whether to insert or delete the object from the array. If you want\nto change a `ByteMatchSetUpdate` object, you delete the existing object and add\na new one.\n\n  * The part of a web request that you want AWS WAF to inspect, such\nas a query string or the value of the `User-Agent` header.\n\n  * The bytes (typically a string that corresponds with ASCII\ncharacters) that you want AWS WAF to look for. For more information, including\nhow you specify the values for the AWS WAF API and the AWS CLI or SDKs, see\n`TargetString` in the `ByteMatchTuple` data type.\n\n  * Where to look, such as at the beginning or the end of a query\nstring.\n\n  * Whether to perform any conversions on the request, such as\nconverting it to lowercase, before inspecting it for the specified string.\n\nFor example, you can add a `ByteMatchSetUpdate` object that matches web requests\nin which `User-Agent` headers contain the string `BadBot`. You can then\nconfigure AWS WAF to block those requests.\n\nTo create and configure a `ByteMatchSet`, perform the following steps:\n\n  1. Create a `ByteMatchSet.` For more information, see\n`CreateByteMatchSet`.\n\n  2. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of an `UpdateByteMatchSet` request.\n\n  3. Submit an `UpdateByteMatchSet` request to specify the part of the\nrequest that you want AWS WAF to inspect (for example, the header or the URI)\nand the value that you want AWS WAF to watch for.\n\nFor more information about how to use the AWS WAF API to allow or block HTTP\nrequests, see the [AWS WAF Developer Guide](https://docs.aws.amazon.com/waf/latest/developerguide/).","ref":"AWS.WAFRegional.html#update_byte_match_set/3","title":"AWS.WAFRegional.update_byte_match_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nInserts or deletes `GeoMatchConstraint` objects in an `GeoMatchSet`. For each\n`GeoMatchConstraint` object, you specify the following values:\n\n  * Whether to insert or delete the object from the array. If you want\nto change an `GeoMatchConstraint` object, you delete the existing object and add\na new one.\n\n  * The `Type`. The only valid value for `Type` is `Country`.\n\n  * The `Value`, which is a two character code for the country to add\nto the `GeoMatchConstraint` object. Valid codes are listed in\n`GeoMatchConstraint$Value`.\n\nTo create and configure an `GeoMatchSet`, perform the following steps:\n\n  1. Submit a `CreateGeoMatchSet` request.\n\n  2. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of an `UpdateGeoMatchSet` request.\n\n  3. Submit an `UpdateGeoMatchSet` request to specify the country that\nyou want AWS WAF to watch for.\n\nWhen you update an `GeoMatchSet`, you specify the country that you want to add\nand/or the country that you want to delete. If you want to change a country, you\ndelete the existing country and add the new one.\n\nFor more information about how to use the AWS WAF API to allow or block HTTP\nrequests, see the [AWS WAF Developer Guide](https://docs.aws.amazon.com/waf/latest/developerguide/).","ref":"AWS.WAFRegional.html#update_geo_match_set/3","title":"AWS.WAFRegional.update_geo_match_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nInserts or deletes `IPSetDescriptor` objects in an `IPSet`. For each\n`IPSetDescriptor` object, you specify the following values:\n\n  * Whether to insert or delete the object from the array. If you want\nto change an `IPSetDescriptor` object, you delete the existing object and add a\nnew one.\n\n  * The IP address version, `IPv4` or `IPv6`.\n\n  * The IP address in CIDR notation, for example, `192.0.2.0/24` (for\nthe range of IP addresses from `192.0.2.0` to `192.0.2.255`) or `192.0.2.44/32`\n(for the individual IP address `192.0.2.44`).\n\nAWS WAF supports IPv4 address ranges: /8 and any range between /16 through /32.\nAWS WAF supports IPv6 address ranges: /24, /32, /48, /56, /64, and /128. For\nmore information about CIDR notation, see the Wikipedia entry [Classless Inter-Domain\nRouting](https://en.wikipedia.org/wiki/Classless_Inter-Domain_Routing).\n\nIPv6 addresses can be represented using any of the following formats:\n\n  * 1111:0000:0000:0000:0000:0000:0000:0111/128\n\n  * 1111:0:0:0:0:0:0:0111/128\n\n  * 1111::0111/128\n\n  * 1111::111/128\n\nYou use an `IPSet` to specify which web requests you want to allow or block\nbased on the IP addresses that the requests originated from. For example, if\nyou're receiving a lot of requests from one or a small number of IP addresses\nand you want to block the requests, you can create an `IPSet` that specifies\nthose IP addresses, and then configure AWS WAF to block the requests.\n\nTo create and configure an `IPSet`, perform the following steps:\n\n  1. Submit a `CreateIPSet` request.\n\n  2. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of an `UpdateIPSet` request.\n\n  3. Submit an `UpdateIPSet` request to specify the IP addresses that\nyou want AWS WAF to watch for.\n\nWhen you update an `IPSet`, you specify the IP addresses that you want to add\nand/or the IP addresses that you want to delete. If you want to change an IP\naddress, you delete the existing IP address and add the new one.\n\nYou can insert a maximum of 1000 addresses in a single request.\n\nFor more information about how to use the AWS WAF API to allow or block HTTP\nrequests, see the [AWS WAF Developer Guide](https://docs.aws.amazon.com/waf/latest/developerguide/).","ref":"AWS.WAFRegional.html#update_ip_set/3","title":"AWS.WAFRegional.update_ip_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nInserts or deletes `Predicate` objects in a rule and updates the `RateLimit` in\nthe rule.\n\nEach `Predicate` object identifies a predicate, such as a `ByteMatchSet` or an\n`IPSet`, that specifies the web requests that you want to block or count. The\n`RateLimit` specifies the number of requests every five minutes that triggers\nthe rule.\n\nIf you add more than one predicate to a `RateBasedRule`, a request must match\nall the predicates and exceed the `RateLimit` to be counted or blocked. For\nexample, suppose you add the following to a `RateBasedRule`:\n\n  * An `IPSet` that matches the IP address `192.0.2.44/32`\n\n  * A `ByteMatchSet` that matches `BadBot` in the `User-Agent` header\n\nFurther, you specify a `RateLimit` of 1,000.\n\nYou then add the `RateBasedRule` to a `WebACL` and specify that you want to\nblock requests that satisfy the rule. For a request to be blocked, it must come\nfrom the IP address 192.0.2.44 *and* the `User-Agent` header in the request must\ncontain the value `BadBot`. Further, requests that match these two conditions\nmuch be received at a rate of more than 1,000 every five minutes. If the rate\ndrops below this limit, AWS WAF no longer blocks the requests.\n\nAs a second example, suppose you want to limit requests to a particular page on\nyour site. To do this, you could add the following to a `RateBasedRule`:\n\n  * A `ByteMatchSet` with `FieldToMatch` of `URI`\n\n  * A `PositionalConstraint` of `STARTS_WITH`\n\n  * A `TargetString` of `login`\n\nFurther, you specify a `RateLimit` of 1,000.\n\nBy adding this `RateBasedRule` to a `WebACL`, you could limit requests to your\nlogin page without affecting the rest of your site.","ref":"AWS.WAFRegional.html#update_rate_based_rule/3","title":"AWS.WAFRegional.update_rate_based_rule/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nInserts or deletes `RegexMatchTuple` objects (filters) in a `RegexMatchSet`. For\neach `RegexMatchSetUpdate` object, you specify the following values:\n\n  * Whether to insert or delete the object from the array. If you want\nto change a `RegexMatchSetUpdate` object, you delete the existing object and add\na new one.\n\n  * The part of a web request that you want AWS WAF to inspectupdate,\nsuch as a query string or the value of the `User-Agent` header.\n\n  * The identifier of the pattern (a regular expression) that you want\nAWS WAF to look for. For more information, see `RegexPatternSet`.\n\n  * Whether to perform any conversions on the request, such as\nconverting it to lowercase, before inspecting it for the specified string.\n\nFor example, you can create a `RegexPatternSet` that matches any requests with\n`User-Agent` headers that contain the string `B[a@]dB[o0]t`. You can then configure AWS WAF to reject those requests.\n\nTo create and configure a `RegexMatchSet`, perform the following steps:\n\n  1. Create a `RegexMatchSet.` For more information, see\n`CreateRegexMatchSet`.\n\n  2. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of an `UpdateRegexMatchSet` request.\n\n  3. Submit an `UpdateRegexMatchSet` request to specify the part of\nthe request that you want AWS WAF to inspect (for example, the header or the\nURI) and the identifier of the `RegexPatternSet` that contain the regular\nexpression patters you want AWS WAF to watch for.\n\nFor more information about how to use the AWS WAF API to allow or block HTTP\nrequests, see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/).","ref":"AWS.WAFRegional.html#update_regex_match_set/3","title":"AWS.WAFRegional.update_regex_match_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nInserts or deletes `RegexPatternString` objects in a `RegexPatternSet`. For each\n`RegexPatternString` object, you specify the following values:\n\n  * Whether to insert or delete the `RegexPatternString`.\n\n  * The regular expression pattern that you want to insert or delete.\nFor more information, see `RegexPatternSet`.\n\nFor example, you can create a `RegexPatternString` such as `B[a@]dB[o0]t`. AWS WAF will match this `RegexPatternString` to:\n\n  * BadBot\n\n  * BadB0t\n\n  * B@dBot\n\n  * B@dB0t\n\nTo create and configure a `RegexPatternSet`, perform the following steps:\n\n  1. Create a `RegexPatternSet.` For more information, see\n`CreateRegexPatternSet`.\n\n  2. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of an `UpdateRegexPatternSet` request.\n\n  3. Submit an `UpdateRegexPatternSet` request to specify the regular\nexpression pattern that you want AWS WAF to watch for.\n\nFor more information about how to use the AWS WAF API to allow or block HTTP\nrequests, see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/).","ref":"AWS.WAFRegional.html#update_regex_pattern_set/3","title":"AWS.WAFRegional.update_regex_pattern_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nInserts or deletes `Predicate` objects in a `Rule`. Each `Predicate` object\nidentifies a predicate, such as a `ByteMatchSet` or an `IPSet`, that specifies\nthe web requests that you want to allow, block, or count. If you add more than\none predicate to a `Rule`, a request must match all of the specifications to be\nallowed, blocked, or counted. For example, suppose that you add the following to\na `Rule`:\n\n  * A `ByteMatchSet` that matches the value `BadBot` in the\n`User-Agent` header\n\n  * An `IPSet` that matches the IP address `192.0.2.44`\n\nYou then add the `Rule` to a `WebACL` and specify that you want to block\nrequests that satisfy the `Rule`. For a request to be blocked, the `User-Agent`\nheader in the request must contain the value `BadBot` *and* the request must\noriginate from the IP address 192.0.2.44.\n\nTo create and configure a `Rule`, perform the following steps:\n\n  1. Create and update the predicates that you want to include in the\n`Rule`.\n\n  2. Create the `Rule`. See `CreateRule`.\n\n  3. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of an `UpdateRule` request.\n\n  4. Submit an `UpdateRule` request to add predicates to the `Rule`.\n\n  5. Create and update a `WebACL` that contains the `Rule`. See\n`CreateWebACL`.\n\nIf you want to replace one `ByteMatchSet` or `IPSet` with another, you delete\nthe existing one and add the new one.\n\nFor more information about how to use the AWS WAF API to allow or block HTTP\nrequests, see the [AWS WAF Developer Guide](https://docs.aws.amazon.com/waf/latest/developerguide/).","ref":"AWS.WAFRegional.html#update_rule/3","title":"AWS.WAFRegional.update_rule/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nInserts or deletes `ActivatedRule` objects in a `RuleGroup`.\n\nYou can only insert `REGULAR` rules into a rule group.\n\nYou can have a maximum of ten rules per rule group.\n\nTo create and configure a `RuleGroup`, perform the following steps:\n\n  1. Create and update the `Rules` that you want to include in the\n`RuleGroup`. See `CreateRule`.\n\n  2. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of an `UpdateRuleGroup` request.\n\n  3. Submit an `UpdateRuleGroup` request to add `Rules` to the\n`RuleGroup`.\n\n  4. Create and update a `WebACL` that contains the `RuleGroup`. See\n`CreateWebACL`.\n\nIf you want to replace one `Rule` with another, you delete the existing one and\nadd the new one.\n\nFor more information about how to use the AWS WAF API to allow or block HTTP\nrequests, see the [AWS WAF Developer Guide](https://docs.aws.amazon.com/waf/latest/developerguide/).","ref":"AWS.WAFRegional.html#update_rule_group/3","title":"AWS.WAFRegional.update_rule_group/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nInserts or deletes `SizeConstraint` objects (filters) in a `SizeConstraintSet`.\nFor each `SizeConstraint` object, you specify the following values:\n\n  * Whether to insert or delete the object from the array. If you want\nto change a `SizeConstraintSetUpdate` object, you delete the existing object and\nadd a new one.\n\n  * The part of a web request that you want AWS WAF to evaluate, such\nas the length of a query string or the length of the `User-Agent` header.\n\n  * Whether to perform any transformations on the request, such as\nconverting it to lowercase, before checking its length. Note that\ntransformations of the request body are not supported because the AWS resource\nforwards only the first `8192` bytes of your request to AWS WAF.\n\nYou can only specify a single type of TextTransformation.\n\n  * A `ComparisonOperator` used for evaluating the selected part of\nthe request against the specified `Size`, such as equals, greater than, less\nthan, and so on.\n\n  * The length, in bytes, that you want AWS WAF to watch for in\nselected part of the request. The length is computed after applying the\ntransformation.\n\nFor example, you can add a `SizeConstraintSetUpdate` object that matches web\nrequests in which the length of the `User-Agent` header is greater than 100\nbytes. You can then configure AWS WAF to block those requests.\n\nTo create and configure a `SizeConstraintSet`, perform the following steps:\n\n  1. Create a `SizeConstraintSet.` For more information, see\n`CreateSizeConstraintSet`.\n\n  2. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of an `UpdateSizeConstraintSet` request.\n\n  3. Submit an `UpdateSizeConstraintSet` request to specify the part\nof the request that you want AWS WAF to inspect (for example, the header or the\nURI) and the value that you want AWS WAF to watch for.\n\nFor more information about how to use the AWS WAF API to allow or block HTTP\nrequests, see the [AWS WAF Developer Guide](https://docs.aws.amazon.com/waf/latest/developerguide/).","ref":"AWS.WAFRegional.html#update_size_constraint_set/3","title":"AWS.WAFRegional.update_size_constraint_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nInserts or deletes `SqlInjectionMatchTuple` objects (filters) in a\n`SqlInjectionMatchSet`. For each `SqlInjectionMatchTuple` object, you specify\nthe following values:\n\n  * `Action`: Whether to insert the object into or delete the object\nfrom the array. To change a `SqlInjectionMatchTuple`, you delete the existing\nobject and add a new one.\n\n  * `FieldToMatch`: The part of web requests that you want AWS WAF to\ninspect and, if you want AWS WAF to inspect a header or custom query parameter,\nthe name of the header or parameter.\n\n  * `TextTransformation`: Which text transformation, if any, to\nperform on the web request before inspecting the request for snippets of\nmalicious SQL code.\n\nYou can only specify a single type of TextTransformation.\n\nYou use `SqlInjectionMatchSet` objects to specify which CloudFront requests that\nyou want to allow, block, or count. For example, if you're receiving requests\nthat contain snippets of SQL code in the query string and you want to block the\nrequests, you can create a `SqlInjectionMatchSet` with the applicable settings,\nand then configure AWS WAF to block the requests.\n\nTo create and configure a `SqlInjectionMatchSet`, perform the following steps:\n\n  1. Submit a `CreateSqlInjectionMatchSet` request.\n\n  2. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of an `UpdateIPSet` request.\n\n  3. Submit an `UpdateSqlInjectionMatchSet` request to specify the\nparts of web requests that you want AWS WAF to inspect for snippets of SQL code.\n\nFor more information about how to use the AWS WAF API to allow or block HTTP\nrequests, see the [AWS WAF Developer Guide](https://docs.aws.amazon.com/waf/latest/developerguide/).","ref":"AWS.WAFRegional.html#update_sql_injection_match_set/3","title":"AWS.WAFRegional.update_sql_injection_match_set/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nInserts or deletes `ActivatedRule` objects in a `WebACL`. Each `Rule` identifies\nweb requests that you want to allow, block, or count. When you update a\n`WebACL`, you specify the following values:\n\n  * A default action for the `WebACL`, either `ALLOW` or `BLOCK`. AWS\nWAF performs the default action if a request doesn't match the criteria in any\nof the `Rules` in a `WebACL`.\n\n  * The `Rules` that you want to add or delete. If you want to replace\none `Rule` with another, you delete the existing `Rule` and add the new one.\n\n  * For each `Rule`, whether you want AWS WAF to allow requests, block\nrequests, or count requests that match the conditions in the `Rule`.\n\n  * The order in which you want AWS WAF to evaluate the `Rules` in a\n`WebACL`. If you add more than one `Rule` to a `WebACL`, AWS WAF evaluates each\nrequest against the `Rules` in order based on the value of `Priority`. (The\n`Rule` that has the lowest value for `Priority` is evaluated first.) When a web\nrequest matches all the predicates (such as `ByteMatchSets` and `IPSets`) in a\n`Rule`, AWS WAF immediately takes the corresponding action, allow or block, and\ndoesn't evaluate the request against the remaining `Rules` in the `WebACL`, if\nany.\n\nTo create and configure a `WebACL`, perform the following steps:\n\n  1. Create and update the predicates that you want to include in\n`Rules`. For more information, see `CreateByteMatchSet`, `UpdateByteMatchSet`,\n`CreateIPSet`, `UpdateIPSet`, `CreateSqlInjectionMatchSet`, and\n`UpdateSqlInjectionMatchSet`.\n\n  2. Create and update the `Rules` that you want to include in the\n`WebACL`. For more information, see `CreateRule` and `UpdateRule`.\n\n  3. Create a `WebACL`. See `CreateWebACL`.\n\n  4. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of an `UpdateWebACL` request.\n\n  5. Submit an `UpdateWebACL` request to specify the `Rules` that you\nwant to include in the `WebACL`, to specify the default action, and to associate\nthe `WebACL` with a CloudFront distribution.\n\nThe `ActivatedRule` can be a rule group. If you specify a rule group as your\n`ActivatedRule` , you can exclude specific rules from that rule group.\n\nIf you already have a rule group associated with a web ACL and want to submit an\n`UpdateWebACL` request to exclude certain rules from that rule group, you must\nfirst remove the rule group from the web ACL, the re-insert it again, specifying\nthe excluded rules. For details, see `ActivatedRule$ExcludedRules` .\n\nBe aware that if you try to add a RATE_BASED rule to a web ACL without setting\nthe rule type when first creating the rule, the `UpdateWebACL` request will fail\nbecause the request tries to add a REGULAR rule (the default rule type) with the\nspecified ID, which does not exist.\n\nFor more information about how to use the AWS WAF API to allow or block HTTP\nrequests, see the [AWS WAF Developer Guide](https://docs.aws.amazon.com/waf/latest/developerguide/).","ref":"AWS.WAFRegional.html#update_web_acl/3","title":"AWS.WAFRegional.update_web_acl/3","type":"function"},{"doc":"This is **AWS WAF Classic** documentation.\n\nFor more information, see [AWS WAF Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)\nin the developer guide.\n\n**For the latest version of AWS WAF**, use the AWS WAFV2 API and see the [AWS WAF Developer\nGuide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\nWith the latest version, AWS WAF has a single set of endpoints for regional and\nglobal use.\n\nInserts or deletes `XssMatchTuple` objects (filters) in an `XssMatchSet`. For\neach `XssMatchTuple` object, you specify the following values:\n\n  * `Action`: Whether to insert the object into or delete the object\nfrom the array. To change an `XssMatchTuple`, you delete the existing object and\nadd a new one.\n\n  * `FieldToMatch`: The part of web requests that you want AWS WAF to\ninspect and, if you want AWS WAF to inspect a header or custom query parameter,\nthe name of the header or parameter.\n\n  * `TextTransformation`: Which text transformation, if any, to\nperform on the web request before inspecting the request for cross-site\nscripting attacks.\n\nYou can only specify a single type of TextTransformation.\n\nYou use `XssMatchSet` objects to specify which CloudFront requests that you want\nto allow, block, or count. For example, if you're receiving requests that\ncontain cross-site scripting attacks in the request body and you want to block\nthe requests, you can create an `XssMatchSet` with the applicable settings, and\nthen configure AWS WAF to block the requests.\n\nTo create and configure an `XssMatchSet`, perform the following steps:\n\n  1. Submit a `CreateXssMatchSet` request.\n\n  2. Use `GetChangeToken` to get the change token that you provide in\nthe `ChangeToken` parameter of an `UpdateIPSet` request.\n\n  3. Submit an `UpdateXssMatchSet` request to specify the parts of web\nrequests that you want AWS WAF to inspect for cross-site scripting attacks.\n\nFor more information about how to use the AWS WAF API to allow or block HTTP\nrequests, see the [AWS WAF Developer Guide](https://docs.aws.amazon.com/waf/latest/developerguide/).","ref":"AWS.WAFRegional.html#update_xss_match_set/3","title":"AWS.WAFRegional.update_xss_match_set/3","type":"function"},{"doc":"WAF\n\nThis is the latest version of the **WAF** API, released in November, 2019.\n\nThe names of the entities that you use to access this API, like endpoints and\nnamespaces, all have the versioning information added, like \"V2\" or \"v2\", to\ndistinguish from the prior version. We recommend migrating your resources to\nthis version, because it has a number of significant improvements.\n\nIf you used WAF prior to this release, you can't use this WAFV2 API to access\nany WAF resources that you created before. You can access your old rules, web\nACLs, and other WAF resources only through the WAF Classic APIs. The WAF Classic\nAPIs have retained the prior names, endpoints, and namespaces.\n\nFor information, including how to migrate your WAF resources to this version,\nsee the [WAF Developer Guide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).\n\nWAF is a web application firewall that lets you monitor the HTTP and HTTPS\nrequests that are forwarded to an Amazon CloudFront distribution, Amazon API\nGateway REST API, Application Load Balancer, AppSync GraphQL API, Amazon Cognito\nuser pool, App Runner service, or Amazon Web Services Verified Access instance.\nWAF also lets you control access to your content, to protect the Amazon Web\nServices resource that WAF is monitoring. Based on conditions that you specify,\nsuch as the IP addresses that requests originate from or the values of query\nstrings, the protected resource responds to requests with either the requested\ncontent, an HTTP 403 status code (Forbidden), or with a custom response.\n\nThis API guide is for developers who need detailed information about WAF API\nactions, data types, and errors. For detailed information about WAF features and\nguidance for configuring and using WAF, see the [WAF Developer Guide](https://docs.aws.amazon.com/waf/latest/developerguide/what-is-aws-waf.html).\n\nYou can make calls using the endpoints listed in [WAF endpoints and quotas](https://docs.aws.amazon.com/general/latest/gr/waf.html).\n\n  * For regional applications, you can use any of the endpoints in the\nlist. A regional application can be an Application Load Balancer (ALB), an\nAmazon API Gateway REST API, an AppSync GraphQL API, an Amazon Cognito user\npool, an App Runner service, or an Amazon Web Services Verified Access instance.\n\n  * For Amazon CloudFront applications, you must use the API endpoint\nlisted for US East (N. Virginia): us-east-1.\n\nAlternatively, you can use one of the Amazon Web Services SDKs to access an API\nthat's tailored to the programming language or platform that you're using. For\nmore information, see [Amazon Web Services SDKs](http://aws.amazon.com/tools/#SDKs).\n\nWe currently provide two versions of the WAF API: this API and the prior\nversions, the classic WAF APIs. This new API provides the same functionality as\nthe older versions, with the following major improvements:\n\n  * You use one API for both global and regional applications. Where\nyou need to distinguish the scope, you specify a `Scope` parameter and set it to\n`CLOUDFRONT` or `REGIONAL`.\n\n  * You can define a web ACL or rule group with a single call, and\nupdate it with a single call. You define all rule specifications in JSON format,\nand pass them to your rule group or web ACL calls.\n\n  * The limits WAF places on the use of rules more closely reflects\nthe cost of running each type of rule. Rule groups include capacity settings, so\nyou know the maximum cost of a rule group when you use it.","ref":"AWS.WAFV2.html","title":"AWS.WAFV2","type":"module"},{"doc":"Associates a web ACL with a regional application resource, to protect the\nresource.\n\nA regional application can be an Application Load Balancer (ALB), an Amazon API\nGateway REST API, an AppSync GraphQL API, an Amazon Cognito user pool, an App\nRunner service, or an Amazon Web Services Verified Access instance.\n\nFor Amazon CloudFront, don't use this call. Instead, use your CloudFront\ndistribution configuration. To associate a web ACL, in the CloudFront call\n`UpdateDistribution`, set the web ACL ID to the Amazon Resource Name (ARN) of\nthe web ACL. For information, see\n[UpdateDistribution](https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_UpdateDistribution.html) in the *Amazon CloudFront Developer Guide*.","ref":"AWS.WAFV2.html#associate_web_acl/3","title":"AWS.WAFV2.associate_web_acl/3","type":"function"},{"doc":"This call requires permissions that are specific to the protected resource type.\nFor details, see [Permissions for\nAssociateWebACL](https://docs.aws.amazon.com/waf/latest/developerguide/security_iam_service-with-iam.html#security_iam_action-AssociateWebACL)\nin the *WAF Developer Guide*.","ref":"AWS.WAFV2.html#associate_web_acl/3-required-permissions-for-customer-managed-iam-policies","title":"Required permissions for customer-managed IAM policies - AWS.WAFV2.associate_web_acl/3","type":"function"},{"doc":"When you create or change a web ACL or other WAF resources, the changes take a\nsmall amount of time to propagate to all areas where the resources are stored.\nThe propagation time can be from a few seconds to a number of minutes.\n\nThe following are examples of the temporary inconsistencies that you might\nnotice during change propagation:\n\n  * After you create a web ACL, if you try to associate it with a\nresource, you might get an exception indicating that the web ACL is unavailable.\n\n  * After you add a rule group to a web ACL, the new rule group rules\nmight be in effect in one area where the web ACL is used and not in another.\n\n  * After you change a rule action setting, you might see the old\naction in some places and the new action in others.\n\n  * After you add an IP address to an IP set that is in use in a\nblocking rule, the new address might be blocked in one area while still allowed\nin another.","ref":"AWS.WAFV2.html#associate_web_acl/3-temporary-inconsistencies-during-updates","title":"Temporary inconsistencies during updates - AWS.WAFV2.associate_web_acl/3","type":"function"},{"doc":"Returns the web ACL capacity unit (WCU) requirements for a specified scope and\nset of rules.\n\nYou can use this to check the capacity requirements for the rules you want to\nuse in a `RuleGroup` or `WebACL`.\n\nWAF uses WCUs to calculate and control the operating resources that are used to\nrun your rules, rule groups, and web ACLs. WAF calculates capacity differently\nfor each rule type, to reflect the relative cost of each rule. Simple rules that\ncost little to run use fewer WCUs than more complex rules that use more\nprocessing power. Rule group capacity is fixed at creation, which helps users\nplan their web ACL WCU usage when they use a rule group. For more information,\nsee [WAF web ACL capacity units (WCU)](https://docs.aws.amazon.com/waf/latest/developerguide/aws-waf-capacity-units.html)\nin the *WAF Developer Guide*.","ref":"AWS.WAFV2.html#check_capacity/3","title":"AWS.WAFV2.check_capacity/3","type":"function"},{"doc":"Creates an API key that contains a set of token domains.\n\nAPI keys are required for the integration of the CAPTCHA API in your JavaScript\nclient applications. The API lets you customize the placement and\ncharacteristics of the CAPTCHA puzzle for your end users. For more information\nabout the CAPTCHA JavaScript integration, see [WAF client application integration](https://docs.aws.amazon.com/waf/latest/developerguide/waf-application-integration.html)\nin the *WAF Developer Guide*.\n\nYou can use a single key for up to 5 domains. After you generate a key, you can\ncopy it for use in your JavaScript integration.","ref":"AWS.WAFV2.html#create_api_key/3","title":"AWS.WAFV2.create_api_key/3","type":"function"},{"doc":"Creates an `IPSet`, which you use to identify web requests that originate from\nspecific IP addresses or ranges of IP addresses.\n\nFor example, if you're receiving a lot of requests from a ranges of IP\naddresses, you can configure WAF to block them using an IPSet that lists those\nIP addresses.","ref":"AWS.WAFV2.html#create_ip_set/3","title":"AWS.WAFV2.create_ip_set/3","type":"function"},{"doc":"Creates a `RegexPatternSet`, which you reference in a\n`RegexPatternSetReferenceStatement`, to have WAF inspect a web request component\nfor the specified patterns.","ref":"AWS.WAFV2.html#create_regex_pattern_set/3","title":"AWS.WAFV2.create_regex_pattern_set/3","type":"function"},{"doc":"Creates a `RuleGroup` per the specifications provided.\n\nA rule group defines a collection of rules to inspect and control web requests\nthat you can use in a `WebACL`. When you create a rule group, you define an\nimmutable capacity limit. If you update a rule group, you must stay within the\ncapacity. This allows others to reuse the rule group with confidence in its\ncapacity requirements.","ref":"AWS.WAFV2.html#create_rule_group/3","title":"AWS.WAFV2.create_rule_group/3","type":"function"},{"doc":"Creates a `WebACL` per the specifications provided.\n\nA web ACL defines a collection of rules to use to inspect and control web\nrequests. Each rule has a statement that defines what to look for in web\nrequests and an action that WAF applies to requests that match the statement. In\nthe web ACL, you assign a default action to take (allow, block) for any request\nthat does not match any of the rules. The rules in a web ACL can be a\ncombination of the types `Rule`, `RuleGroup`, and managed rule group. You can\nassociate a web ACL with one or more Amazon Web Services resources to protect.\nThe resources can be an Amazon CloudFront distribution, an Amazon API Gateway\nREST API, an Application Load Balancer, an AppSync GraphQL API, an Amazon\nCognito user pool, an App Runner service, or an Amazon Web Services Verified\nAccess instance.","ref":"AWS.WAFV2.html#create_web_acl/3","title":"AWS.WAFV2.create_web_acl/3","type":"function"},{"doc":"Deletes the specified API key.\n\nAfter you delete a key, it can take up to 24 hours for WAF to disallow use of\nthe key in all regions.","ref":"AWS.WAFV2.html#delete_api_key/3","title":"AWS.WAFV2.delete_api_key/3","type":"function"},{"doc":"Deletes all rule groups that are managed by Firewall Manager for the specified\nweb ACL.\n\nYou can only use this if `ManagedByFirewallManager` is false in the specified\n`WebACL`.","ref":"AWS.WAFV2.html#delete_firewall_manager_rule_groups/3","title":"AWS.WAFV2.delete_firewall_manager_rule_groups/3","type":"function"},{"doc":"Deletes the specified `IPSet`.","ref":"AWS.WAFV2.html#delete_ip_set/3","title":"AWS.WAFV2.delete_ip_set/3","type":"function"},{"doc":"Deletes the `LoggingConfiguration` from the specified web ACL.","ref":"AWS.WAFV2.html#delete_logging_configuration/3","title":"AWS.WAFV2.delete_logging_configuration/3","type":"function"},{"doc":"Permanently deletes an IAM policy from the specified rule group.\n\nYou must be the owner of the rule group to perform this operation.","ref":"AWS.WAFV2.html#delete_permission_policy/3","title":"AWS.WAFV2.delete_permission_policy/3","type":"function"},{"doc":"Deletes the specified `RegexPatternSet`.","ref":"AWS.WAFV2.html#delete_regex_pattern_set/3","title":"AWS.WAFV2.delete_regex_pattern_set/3","type":"function"},{"doc":"Deletes the specified `RuleGroup`.","ref":"AWS.WAFV2.html#delete_rule_group/3","title":"AWS.WAFV2.delete_rule_group/3","type":"function"},{"doc":"Deletes the specified `WebACL`.\n\nYou can only use this if `ManagedByFirewallManager` is false in the specified\n`WebACL`.\n\nBefore deleting any web ACL, first disassociate it from all resources.\n\n   To retrieve a list of the resources that are associated with a web\nACL, use the following calls:\n\n     For regional resources, call `ListResourcesForWebACL`.\n\n     For Amazon CloudFront distributions, use the CloudFront\ncall `ListDistributionsByWebACLId`. For information, see\n[ListDistributionsByWebACLId](https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_ListDistributionsByWebACLId.html) in the *Amazon CloudFront API Reference*.\n\n   To disassociate a resource from a web ACL, use the following calls:\n\n     For regional resources, call `DisassociateWebACL`.\n\n     For Amazon CloudFront distributions, provide an empty\nweb ACL ID in the CloudFront call `UpdateDistribution`. For information, see\n[UpdateDistribution](https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_UpdateDistribution.html)\nin the *Amazon CloudFront API Reference*.","ref":"AWS.WAFV2.html#delete_web_acl/3","title":"AWS.WAFV2.delete_web_acl/3","type":"function"},{"doc":"Provides high-level information for the Amazon Web Services Managed Rules rule\ngroups and Amazon Web Services Marketplace managed rule groups.","ref":"AWS.WAFV2.html#describe_all_managed_products/3","title":"AWS.WAFV2.describe_all_managed_products/3","type":"function"},{"doc":"Provides high-level information for the managed rule groups owned by a specific\nvendor.","ref":"AWS.WAFV2.html#describe_managed_products_by_vendor/3","title":"AWS.WAFV2.describe_managed_products_by_vendor/3","type":"function"},{"doc":"Provides high-level information for a managed rule group, including descriptions\nof the rules.","ref":"AWS.WAFV2.html#describe_managed_rule_group/3","title":"AWS.WAFV2.describe_managed_rule_group/3","type":"function"},{"doc":"Disassociates the specified regional application resource from any existing web\nACL association.\n\nA resource can have at most one web ACL association. A regional application can\nbe an Application Load Balancer (ALB), an Amazon API Gateway REST API, an\nAppSync GraphQL API, an Amazon Cognito user pool, an App Runner service, or an\nAmazon Web Services Verified Access instance.\n\nFor Amazon CloudFront, don't use this call. Instead, use your CloudFront\ndistribution configuration. To disassociate a web ACL, provide an empty web ACL\nID in the CloudFront call `UpdateDistribution`. For information, see\n[UpdateDistribution](https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_UpdateDistribution.html) in the *Amazon CloudFront API Reference*.","ref":"AWS.WAFV2.html#disassociate_web_acl/3","title":"AWS.WAFV2.disassociate_web_acl/3","type":"function"},{"doc":"This call requires permissions that are specific to the protected resource type.\nFor details, see [Permissions for\nDisassociateWebACL](https://docs.aws.amazon.com/waf/latest/developerguide/security_iam_service-with-iam.html#security_iam_action-DisassociateWebACL)\nin the *WAF Developer Guide*.","ref":"AWS.WAFV2.html#disassociate_web_acl/3-required-permissions-for-customer-managed-iam-policies","title":"Required permissions for customer-managed IAM policies - AWS.WAFV2.disassociate_web_acl/3","type":"function"},{"doc":"Generates a presigned download URL for the specified release of the mobile SDK.\n\nThe mobile SDK is not generally available. Customers who have access to the\nmobile SDK can use it to establish and manage WAF tokens for use in HTTP(S)\nrequests from a mobile device to WAF. For more information, see [WAF client application\nintegration](https://docs.aws.amazon.com/waf/latest/developerguide/waf-application-integration.html)\nin the *WAF Developer Guide*.","ref":"AWS.WAFV2.html#generate_mobile_sdk_release_url/3","title":"AWS.WAFV2.generate_mobile_sdk_release_url/3","type":"function"},{"doc":"Returns your API key in decrypted form.\n\nUse this to check the token domains that you have defined for the key.\n\nAPI keys are required for the integration of the CAPTCHA API in your JavaScript\nclient applications. The API lets you customize the placement and\ncharacteristics of the CAPTCHA puzzle for your end users. For more information\nabout the CAPTCHA JavaScript integration, see [WAF client application integration](https://docs.aws.amazon.com/waf/latest/developerguide/waf-application-integration.html)\nin the *WAF Developer Guide*.","ref":"AWS.WAFV2.html#get_decrypted_api_key/3","title":"AWS.WAFV2.get_decrypted_api_key/3","type":"function"},{"doc":"Retrieves the specified `IPSet`.","ref":"AWS.WAFV2.html#get_ip_set/3","title":"AWS.WAFV2.get_ip_set/3","type":"function"},{"doc":"Returns the `LoggingConfiguration` for the specified web ACL.","ref":"AWS.WAFV2.html#get_logging_configuration/3","title":"AWS.WAFV2.get_logging_configuration/3","type":"function"},{"doc":"Retrieves the specified managed rule set.\n\nThis is intended for use only by vendors of managed rule sets. Vendors are\nAmazon Web Services and Amazon Web Services Marketplace sellers.\n\nVendors, you can use the managed rule set APIs to provide controlled rollout of\nyour versioned managed rule group offerings for your customers. The APIs are\n`ListManagedRuleSets`, `GetManagedRuleSet`, `PutManagedRuleSetVersions`, and\n`UpdateManagedRuleSetVersionExpiryDate`.","ref":"AWS.WAFV2.html#get_managed_rule_set/3","title":"AWS.WAFV2.get_managed_rule_set/3","type":"function"},{"doc":"Retrieves information for the specified mobile SDK release, including release\nnotes and tags.\n\nThe mobile SDK is not generally available. Customers who have access to the\nmobile SDK can use it to establish and manage WAF tokens for use in HTTP(S)\nrequests from a mobile device to WAF. For more information, see [WAF client application\nintegration](https://docs.aws.amazon.com/waf/latest/developerguide/waf-application-integration.html)\nin the *WAF Developer Guide*.","ref":"AWS.WAFV2.html#get_mobile_sdk_release/3","title":"AWS.WAFV2.get_mobile_sdk_release/3","type":"function"},{"doc":"Returns the IAM policy that is attached to the specified rule group.\n\nYou must be the owner of the rule group to perform this operation.","ref":"AWS.WAFV2.html#get_permission_policy/3","title":"AWS.WAFV2.get_permission_policy/3","type":"function"},{"doc":"Retrieves the IP addresses that are currently blocked by a rate-based rule\ninstance.\n\nThis is only available for rate-based rules that aggregate solely on the IP\naddress or on the forwarded IP address.\n\nThe maximum number of addresses that can be blocked for a single rate-based rule\ninstance is 10,000. If more than 10,000 addresses exceed the rate limit, those\nwith the highest rates are blocked.\n\nFor a rate-based rule that you've defined inside a rule group, provide the name\nof the rule group reference statement in your request, in addition to the\nrate-based rule name and the web ACL name.\n\nWAF monitors web requests and manages keys independently for each unique\ncombination of web ACL, optional rule group, and rate-based rule. For example,\nif you define a rate-based rule inside a rule group, and then use the rule group\nin a web ACL, WAF monitors web requests and manages keys for that web ACL, rule\ngroup reference statement, and rate-based rule instance. If you use the same\nrule group in a second web ACL, WAF monitors web requests and manages keys for\nthis second usage completely independent of your first.","ref":"AWS.WAFV2.html#get_rate_based_statement_managed_keys/3","title":"AWS.WAFV2.get_rate_based_statement_managed_keys/3","type":"function"},{"doc":"Retrieves the specified `RegexPatternSet`.","ref":"AWS.WAFV2.html#get_regex_pattern_set/3","title":"AWS.WAFV2.get_regex_pattern_set/3","type":"function"},{"doc":"Retrieves the specified `RuleGroup`.","ref":"AWS.WAFV2.html#get_rule_group/3","title":"AWS.WAFV2.get_rule_group/3","type":"function"},{"doc":"Gets detailed information about a specified number of requests--a sample--that\nWAF randomly selects from among the first 5,000 requests that your Amazon Web\nServices resource received during a time range that you choose.\n\nYou can specify a sample size of up to 500 requests, and you can specify any\ntime range in the previous three hours.\n\n`GetSampledRequests` returns a time range, which is usually the time range that\nyou specified. However, if your resource (such as a CloudFront distribution)\nreceived 5,000 requests before the specified time range elapsed,\n`GetSampledRequests` returns an updated time range. This new time range\nindicates the actual period during which WAF selected the requests in the\nsample.","ref":"AWS.WAFV2.html#get_sampled_requests/3","title":"AWS.WAFV2.get_sampled_requests/3","type":"function"},{"doc":"Retrieves the specified `WebACL`.","ref":"AWS.WAFV2.html#get_web_acl/3","title":"AWS.WAFV2.get_web_acl/3","type":"function"},{"doc":"Retrieves the `WebACL` for the specified resource.\n\nThis call uses `GetWebACL`, to verify that your account has permission to access\nthe retrieved web ACL. If you get an error that indicates that your account\nisn't authorized to perform `wafv2:GetWebACL` on the resource, that error won't\nbe included in your CloudTrail event history.\n\nFor Amazon CloudFront, don't use this call. Instead, call the CloudFront action\n`GetDistributionConfig`. For information, see\n[GetDistributionConfig](https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_GetDistributionConfig.html) in the *Amazon CloudFront API Reference*.","ref":"AWS.WAFV2.html#get_web_acl_for_resource/3","title":"AWS.WAFV2.get_web_acl_for_resource/3","type":"function"},{"doc":"This call requires permissions that are specific to the protected resource type.\nFor details, see [Permissions for\nGetWebACLForResource](https://docs.aws.amazon.com/waf/latest/developerguide/security_iam_service-with-iam.html#security_iam_action-GetWebACLForResource)\nin the *WAF Developer Guide*.","ref":"AWS.WAFV2.html#get_web_acl_for_resource/3-required-permissions-for-customer-managed-iam-policies","title":"Required permissions for customer-managed IAM policies - AWS.WAFV2.get_web_acl_for_resource/3","type":"function"},{"doc":"Retrieves a list of the API keys that you've defined for the specified scope.\n\nAPI keys are required for the integration of the CAPTCHA API in your JavaScript\nclient applications. The API lets you customize the placement and\ncharacteristics of the CAPTCHA puzzle for your end users. For more information\nabout the CAPTCHA JavaScript integration, see [WAF client application integration](https://docs.aws.amazon.com/waf/latest/developerguide/waf-application-integration.html)\nin the *WAF Developer Guide*.","ref":"AWS.WAFV2.html#list_api_keys/3","title":"AWS.WAFV2.list_api_keys/3","type":"function"},{"doc":"Returns a list of the available versions for the specified managed rule group.","ref":"AWS.WAFV2.html#list_available_managed_rule_group_versions/3","title":"AWS.WAFV2.list_available_managed_rule_group_versions/3","type":"function"},{"doc":"Retrieves an array of managed rule groups that are available for you to use.\n\nThis list includes all Amazon Web Services Managed Rules rule groups and all of\nthe Amazon Web Services Marketplace managed rule groups that you're subscribed\nto.","ref":"AWS.WAFV2.html#list_available_managed_rule_groups/3","title":"AWS.WAFV2.list_available_managed_rule_groups/3","type":"function"},{"doc":"Retrieves an array of `IPSetSummary` objects for the IP sets that you manage.","ref":"AWS.WAFV2.html#list_ip_sets/3","title":"AWS.WAFV2.list_ip_sets/3","type":"function"},{"doc":"Retrieves an array of your `LoggingConfiguration` objects.","ref":"AWS.WAFV2.html#list_logging_configurations/3","title":"AWS.WAFV2.list_logging_configurations/3","type":"function"},{"doc":"Retrieves the managed rule sets that you own.\n\nThis is intended for use only by vendors of managed rule sets. Vendors are\nAmazon Web Services and Amazon Web Services Marketplace sellers.\n\nVendors, you can use the managed rule set APIs to provide controlled rollout of\nyour versioned managed rule group offerings for your customers. The APIs are\n`ListManagedRuleSets`, `GetManagedRuleSet`, `PutManagedRuleSetVersions`, and\n`UpdateManagedRuleSetVersionExpiryDate`.","ref":"AWS.WAFV2.html#list_managed_rule_sets/3","title":"AWS.WAFV2.list_managed_rule_sets/3","type":"function"},{"doc":"Retrieves a list of the available releases for the mobile SDK and the specified\ndevice platform.\n\nThe mobile SDK is not generally available. Customers who have access to the\nmobile SDK can use it to establish and manage WAF tokens for use in HTTP(S)\nrequests from a mobile device to WAF. For more information, see [WAF client application\nintegration](https://docs.aws.amazon.com/waf/latest/developerguide/waf-application-integration.html)\nin the *WAF Developer Guide*.","ref":"AWS.WAFV2.html#list_mobile_sdk_releases/3","title":"AWS.WAFV2.list_mobile_sdk_releases/3","type":"function"},{"doc":"Retrieves an array of `RegexPatternSetSummary` objects for the regex pattern\nsets that you manage.","ref":"AWS.WAFV2.html#list_regex_pattern_sets/3","title":"AWS.WAFV2.list_regex_pattern_sets/3","type":"function"},{"doc":"Retrieves an array of the Amazon Resource Names (ARNs) for the regional\nresources that are associated with the specified web ACL.\n\nFor Amazon CloudFront, don't use this call. Instead, use the CloudFront call\n`ListDistributionsByWebACLId`. For information, see\n[ListDistributionsByWebACLId](https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_ListDistributionsByWebACLId.html) in the *Amazon CloudFront API Reference*.","ref":"AWS.WAFV2.html#list_resources_for_web_acl/3","title":"AWS.WAFV2.list_resources_for_web_acl/3","type":"function"},{"doc":"This call requires permissions that are specific to the protected resource type.\nFor details, see [Permissions for\nListResourcesForWebACL](https://docs.aws.amazon.com/waf/latest/developerguide/security_iam_service-with-iam.html#security_iam_action-ListResourcesForWebACL)\nin the *WAF Developer Guide*.","ref":"AWS.WAFV2.html#list_resources_for_web_acl/3-required-permissions-for-customer-managed-iam-policies","title":"Required permissions for customer-managed IAM policies - AWS.WAFV2.list_resources_for_web_acl/3","type":"function"},{"doc":"Retrieves an array of `RuleGroupSummary` objects for the rule groups that you\nmanage.","ref":"AWS.WAFV2.html#list_rule_groups/3","title":"AWS.WAFV2.list_rule_groups/3","type":"function"},{"doc":"Retrieves the `TagInfoForResource` for the specified resource.\n\nTags are key:value pairs that you can use to categorize and manage your\nresources, for purposes like billing. For example, you might set the tag key to\n\"customer\" and the value to the customer name or ID. You can specify one or more\ntags to add to each Amazon Web Services resource, up to 50 tags for a resource.\n\nYou can tag the Amazon Web Services resources that you manage through WAF: web\nACLs, rule groups, IP sets, and regex pattern sets. You can't manage or view\ntags through the WAF console.","ref":"AWS.WAFV2.html#list_tags_for_resource/3","title":"AWS.WAFV2.list_tags_for_resource/3","type":"function"},{"doc":"Retrieves an array of `WebACLSummary` objects for the web ACLs that you manage.","ref":"AWS.WAFV2.html#list_web_acls/3","title":"AWS.WAFV2.list_web_acls/3","type":"function"},{"doc":"","ref":"AWS.WAFV2.html#metadata/0","title":"AWS.WAFV2.metadata/0","type":"function"},{"doc":"Enables the specified `LoggingConfiguration`, to start logging from a web ACL,\naccording to the configuration provided.\n\nThis operation completely replaces any mutable specifications that you already\nhave for a logging configuration with the ones that you provide to this call.\n\nTo modify an existing logging configuration, do the following:\n\n   Retrieve it by calling `GetLoggingConfiguration`\n\n   Update its settings as needed\n\n   Provide the complete logging configuration specification to this\ncall\n\nYou can define one logging destination per web ACL.\n\nYou can access information about the traffic that WAF inspects using the\nfollowing steps:\n\n  1. Create your logging destination. You can use an Amazon CloudWatch\nLogs log group, an Amazon Simple Storage Service (Amazon S3) bucket, or an\nAmazon Kinesis Data Firehose.\n\nThe name that you give the destination must start with `aws-waf-logs-`.\nDepending on the type of destination, you might need to configure additional\nsettings or permissions.\n\nFor configuration requirements and pricing information for each destination\ntype, see [Logging web ACL traffic](https://docs.aws.amazon.com/waf/latest/developerguide/logging.html) in\nthe *WAF Developer Guide*.\n\n  2. Associate your logging destination to your web ACL using a\n`PutLoggingConfiguration` request.\n\nWhen you successfully enable logging using a `PutLoggingConfiguration` request,\nWAF creates an additional role or policy that is required to write logs to the\nlogging destination. For an Amazon CloudWatch Logs log group, WAF creates a\nresource policy on the log group. For an Amazon S3 bucket, WAF creates a bucket\npolicy. For an Amazon Kinesis Data Firehose, WAF creates a service-linked role.\n\nFor additional information about web ACL logging, see [Logging web ACL traffic information](https://docs.aws.amazon.com/waf/latest/developerguide/logging.html)\nin the *WAF Developer Guide*.","ref":"AWS.WAFV2.html#put_logging_configuration/3","title":"AWS.WAFV2.put_logging_configuration/3","type":"function"},{"doc":"Defines the versions of your managed rule set that you are offering to the\ncustomers.\n\nCustomers see your offerings as managed rule groups with versioning.\n\nThis is intended for use only by vendors of managed rule sets. Vendors are\nAmazon Web Services and Amazon Web Services Marketplace sellers.\n\nVendors, you can use the managed rule set APIs to provide controlled rollout of\nyour versioned managed rule group offerings for your customers. The APIs are\n`ListManagedRuleSets`, `GetManagedRuleSet`, `PutManagedRuleSetVersions`, and\n`UpdateManagedRuleSetVersionExpiryDate`.\n\nCustomers retrieve their managed rule group list by calling\n`ListAvailableManagedRuleGroups`. The name that you provide here for your\nmanaged rule set is the name the customer sees for the corresponding managed\nrule group. Customers can retrieve the available versions for a managed rule\ngroup by calling `ListAvailableManagedRuleGroupVersions`. You provide a rule\ngroup specification for each version. For each managed rule set, you must\nspecify a version that you recommend using.\n\nTo initiate the expiration of a managed rule group version, use\n`UpdateManagedRuleSetVersionExpiryDate`.","ref":"AWS.WAFV2.html#put_managed_rule_set_versions/3","title":"AWS.WAFV2.put_managed_rule_set_versions/3","type":"function"},{"doc":"Attaches an IAM policy to the specified resource.\n\nUse this to share a rule group across accounts.\n\nYou must be the owner of the rule group to perform this operation.\n\nThis action is subject to the following restrictions:\n\n  * You can attach only one policy with each `PutPermissionPolicy`\nrequest.\n\n  * The ARN in the request must be a valid WAF `RuleGroup` ARN and the\nrule group must exist in the same Region.\n\n  * The user making the request must be the owner of the rule group.","ref":"AWS.WAFV2.html#put_permission_policy/3","title":"AWS.WAFV2.put_permission_policy/3","type":"function"},{"doc":"Associates tags with the specified Amazon Web Services resource.\n\nTags are key:value pairs that you can use to categorize and manage your\nresources, for purposes like billing. For example, you might set the tag key to\n\"customer\" and the value to the customer name or ID. You can specify one or more\ntags to add to each Amazon Web Services resource, up to 50 tags for a resource.\n\nYou can tag the Amazon Web Services resources that you manage through WAF: web\nACLs, rule groups, IP sets, and regex pattern sets. You can't manage or view\ntags through the WAF console.","ref":"AWS.WAFV2.html#tag_resource/3","title":"AWS.WAFV2.tag_resource/3","type":"function"},{"doc":"Disassociates tags from an Amazon Web Services resource.\n\nTags are key:value pairs that you can associate with Amazon Web Services\nresources. For example, the tag key might be \"customer\" and the tag value might\nbe \"companyA.\" You can specify one or more tags to add to each container. You\ncan add up to 50 tags to each Amazon Web Services resource.","ref":"AWS.WAFV2.html#untag_resource/3","title":"AWS.WAFV2.untag_resource/3","type":"function"},{"doc":"Updates the specified `IPSet`.\n\nThis operation completely replaces the mutable specifications that you already\nhave for the IP set with the ones that you provide to this call.\n\nTo modify an IP set, do the following:\n\n   Retrieve it by calling `GetIPSet`\n\n   Update its settings as needed\n\n   Provide the complete IP set specification to this call","ref":"AWS.WAFV2.html#update_ip_set/3","title":"AWS.WAFV2.update_ip_set/3","type":"function"},{"doc":"When you create or change a web ACL or other WAF resources, the changes take a\nsmall amount of time to propagate to all areas where the resources are stored.\nThe propagation time can be from a few seconds to a number of minutes.\n\nThe following are examples of the temporary inconsistencies that you might\nnotice during change propagation:\n\n  * After you create a web ACL, if you try to associate it with a\nresource, you might get an exception indicating that the web ACL is unavailable.\n\n  * After you add a rule group to a web ACL, the new rule group rules\nmight be in effect in one area where the web ACL is used and not in another.\n\n  * After you change a rule action setting, you might see the old\naction in some places and the new action in others.\n\n  * After you add an IP address to an IP set that is in use in a\nblocking rule, the new address might be blocked in one area while still allowed\nin another.","ref":"AWS.WAFV2.html#update_ip_set/3-temporary-inconsistencies-during-updates","title":"Temporary inconsistencies during updates - AWS.WAFV2.update_ip_set/3","type":"function"},{"doc":"Updates the expiration information for your managed rule set.\n\nUse this to initiate the expiration of a managed rule group version. After you\ninitiate expiration for a version, WAF excludes it from the response to\n`ListAvailableManagedRuleGroupVersions` for the managed rule group.\n\nThis is intended for use only by vendors of managed rule sets. Vendors are\nAmazon Web Services and Amazon Web Services Marketplace sellers.\n\nVendors, you can use the managed rule set APIs to provide controlled rollout of\nyour versioned managed rule group offerings for your customers. The APIs are\n`ListManagedRuleSets`, `GetManagedRuleSet`, `PutManagedRuleSetVersions`, and\n`UpdateManagedRuleSetVersionExpiryDate`.","ref":"AWS.WAFV2.html#update_managed_rule_set_version_expiry_date/3","title":"AWS.WAFV2.update_managed_rule_set_version_expiry_date/3","type":"function"},{"doc":"Updates the specified `RegexPatternSet`.\n\nThis operation completely replaces the mutable specifications that you already\nhave for the regex pattern set with the ones that you provide to this call.\n\nTo modify a regex pattern set, do the following:\n\n   Retrieve it by calling `GetRegexPatternSet`\n\n   Update its settings as needed\n\n   Provide the complete regex pattern set specification to this call","ref":"AWS.WAFV2.html#update_regex_pattern_set/3","title":"AWS.WAFV2.update_regex_pattern_set/3","type":"function"},{"doc":"When you create or change a web ACL or other WAF resources, the changes take a\nsmall amount of time to propagate to all areas where the resources are stored.\nThe propagation time can be from a few seconds to a number of minutes.\n\nThe following are examples of the temporary inconsistencies that you might\nnotice during change propagation:\n\n  * After you create a web ACL, if you try to associate it with a\nresource, you might get an exception indicating that the web ACL is unavailable.\n\n  * After you add a rule group to a web ACL, the new rule group rules\nmight be in effect in one area where the web ACL is used and not in another.\n\n  * After you change a rule action setting, you might see the old\naction in some places and the new action in others.\n\n  * After you add an IP address to an IP set that is in use in a\nblocking rule, the new address might be blocked in one area while still allowed\nin another.","ref":"AWS.WAFV2.html#update_regex_pattern_set/3-temporary-inconsistencies-during-updates","title":"Temporary inconsistencies during updates - AWS.WAFV2.update_regex_pattern_set/3","type":"function"},{"doc":"Updates the specified `RuleGroup`.\n\nThis operation completely replaces the mutable specifications that you already\nhave for the rule group with the ones that you provide to this call.\n\nTo modify a rule group, do the following:\n\n   Retrieve it by calling `GetRuleGroup`\n\n   Update its settings as needed\n\n   Provide the complete rule group specification to this call\n\nA rule group defines a collection of rules to inspect and control web requests\nthat you can use in a `WebACL`. When you create a rule group, you define an\nimmutable capacity limit. If you update a rule group, you must stay within the\ncapacity. This allows others to reuse the rule group with confidence in its\ncapacity requirements.","ref":"AWS.WAFV2.html#update_rule_group/3","title":"AWS.WAFV2.update_rule_group/3","type":"function"},{"doc":"When you create or change a web ACL or other WAF resources, the changes take a\nsmall amount of time to propagate to all areas where the resources are stored.\nThe propagation time can be from a few seconds to a number of minutes.\n\nThe following are examples of the temporary inconsistencies that you might\nnotice during change propagation:\n\n  * After you create a web ACL, if you try to associate it with a\nresource, you might get an exception indicating that the web ACL is unavailable.\n\n  * After you add a rule group to a web ACL, the new rule group rules\nmight be in effect in one area where the web ACL is used and not in another.\n\n  * After you change a rule action setting, you might see the old\naction in some places and the new action in others.\n\n  * After you add an IP address to an IP set that is in use in a\nblocking rule, the new address might be blocked in one area while still allowed\nin another.","ref":"AWS.WAFV2.html#update_rule_group/3-temporary-inconsistencies-during-updates","title":"Temporary inconsistencies during updates - AWS.WAFV2.update_rule_group/3","type":"function"},{"doc":"Updates the specified `WebACL`.\n\nWhile updating a web ACL, WAF provides continuous coverage to the resources that\nyou have associated with the web ACL.\n\nThis operation completely replaces the mutable specifications that you already\nhave for the web ACL with the ones that you provide to this call.\n\nTo modify a web ACL, do the following:\n\n   Retrieve it by calling `GetWebACL`\n\n   Update its settings as needed\n\n   Provide the complete web ACL specification to this call\n\nA web ACL defines a collection of rules to use to inspect and control web\nrequests. Each rule has a statement that defines what to look for in web\nrequests and an action that WAF applies to requests that match the statement. In\nthe web ACL, you assign a default action to take (allow, block) for any request\nthat does not match any of the rules. The rules in a web ACL can be a\ncombination of the types `Rule`, `RuleGroup`, and managed rule group. You can\nassociate a web ACL with one or more Amazon Web Services resources to protect.\nThe resources can be an Amazon CloudFront distribution, an Amazon API Gateway\nREST API, an Application Load Balancer, an AppSync GraphQL API, an Amazon\nCognito user pool, an App Runner service, or an Amazon Web Services Verified\nAccess instance.","ref":"AWS.WAFV2.html#update_web_acl/3","title":"AWS.WAFV2.update_web_acl/3","type":"function"},{"doc":"When you create or change a web ACL or other WAF resources, the changes take a\nsmall amount of time to propagate to all areas where the resources are stored.\nThe propagation time can be from a few seconds to a number of minutes.\n\nThe following are examples of the temporary inconsistencies that you might\nnotice during change propagation:\n\n  * After you create a web ACL, if you try to associate it with a\nresource, you might get an exception indicating that the web ACL is unavailable.\n\n  * After you add a rule group to a web ACL, the new rule group rules\nmight be in effect in one area where the web ACL is used and not in another.\n\n  * After you change a rule action setting, you might see the old\naction in some places and the new action in others.\n\n  * After you add an IP address to an IP set that is in use in a\nblocking rule, the new address might be blocked in one area while still allowed\nin another.","ref":"AWS.WAFV2.html#update_web_acl/3-temporary-inconsistencies-during-updates","title":"Temporary inconsistencies during updates - AWS.WAFV2.update_web_acl/3","type":"function"},{"doc":"Well-Architected Tool\n\nThis is the *Well-Architected Tool API Reference*.\n\nThe WA Tool API provides programmatic access to the [Well-Architected Tool](http://aws.amazon.com/well-architected-tool) in the [Amazon Web Services Management Console](https://console.aws.amazon.com/wellarchitected). For\ninformation about the Well-Architected Tool, see the [Well-Architected Tool User Guide](https://docs.aws.amazon.com/wellarchitected/latest/userguide/intro.html).","ref":"AWS.WellArchitected.html","title":"AWS.WellArchitected","type":"module"},{"doc":"Associate a lens to a workload.\n\nUp to 10 lenses can be associated with a workload in a single API operation. A\nmaximum of 20 lenses can be associated with a workload.","ref":"AWS.WellArchitected.html#associate_lenses/4","title":"AWS.WellArchitected.associate_lenses/4","type":"function"},{"doc":"By accessing and/or applying custom lenses created by another Amazon Web\nServices user or account, you acknowledge that custom lenses created by other\nusers and shared with you are Third Party Content as defined in the Amazon Web\nServices Customer Agreement.","ref":"AWS.WellArchitected.html#associate_lenses/4-disclaimer","title":"Disclaimer - AWS.WellArchitected.associate_lenses/4","type":"function"},{"doc":"Associate a profile with a workload.","ref":"AWS.WellArchitected.html#associate_profiles/4","title":"AWS.WellArchitected.associate_profiles/4","type":"function"},{"doc":"Create a lens share.\n\nThe owner of a lens can share it with other Amazon Web Services accounts, users,\nan organization, and organizational units (OUs) in the same Amazon Web Services\nRegion. Lenses provided by Amazon Web Services (Amazon Web Services Official\nContent) cannot be shared.\n\nShared access to a lens is not removed until the lens invitation is deleted.\n\nIf you share a lens with an organization or OU, all accounts in the organization\nor OU are granted access to the lens.\n\nFor more information, see [Sharing a custom lens](https://docs.aws.amazon.com/wellarchitected/latest/userguide/lenses-sharing.html)\nin the *Well-Architected Tool User Guide*.","ref":"AWS.WellArchitected.html#create_lens_share/4","title":"AWS.WellArchitected.create_lens_share/4","type":"function"},{"doc":"By sharing your custom lenses with other Amazon Web Services accounts, you\nacknowledge that Amazon Web Services will make your custom lenses available to\nthose other accounts. Those other accounts may continue to access and use your\nshared custom lenses even if you delete the custom lenses from your own Amazon\nWeb Services account or terminate your Amazon Web Services account.","ref":"AWS.WellArchitected.html#create_lens_share/4-disclaimer","title":"Disclaimer - AWS.WellArchitected.create_lens_share/4","type":"function"},{"doc":"Create a new lens version.\n\nA lens can have up to 100 versions.\n\nUse this operation to publish a new lens version after you have imported a lens.\nThe `LensAlias` is used to identify the lens to be published. The owner of a\nlens can share the lens with other Amazon Web Services accounts and users in the\nsame Amazon Web Services Region. Only the owner of a lens can delete it.","ref":"AWS.WellArchitected.html#create_lens_version/4","title":"AWS.WellArchitected.create_lens_version/4","type":"function"},{"doc":"Create a milestone for an existing workload.","ref":"AWS.WellArchitected.html#create_milestone/4","title":"AWS.WellArchitected.create_milestone/4","type":"function"},{"doc":"Create a profile.","ref":"AWS.WellArchitected.html#create_profile/3","title":"AWS.WellArchitected.create_profile/3","type":"function"},{"doc":"Create a profile share.","ref":"AWS.WellArchitected.html#create_profile_share/4","title":"AWS.WellArchitected.create_profile_share/4","type":"function"},{"doc":"Create a review template.","ref":"AWS.WellArchitected.html#create_review_template/3","title":"AWS.WellArchitected.create_review_template/3","type":"function"},{"doc":"Do not include or gather personal identifiable information (PII) of end users or\nother identifiable individuals in or via your review templates. If your review\ntemplate or those shared with you and used in your account do include or collect\nPII you are responsible for: ensuring that the included PII is processed in\naccordance with applicable law, providing adequate privacy notices, and\nobtaining necessary consents for processing such data.","ref":"AWS.WellArchitected.html#create_review_template/3-disclaimer","title":"Disclaimer - AWS.WellArchitected.create_review_template/3","type":"function"},{"doc":"Create a review template share.\n\nThe owner of a review template can share it with other Amazon Web Services\naccounts, users, an organization, and organizational units (OUs) in the same\nAmazon Web Services Region.\n\nShared access to a review template is not removed until the review template\nshare invitation is deleted.\n\nIf you share a review template with an organization or OU, all accounts in the\norganization or OU are granted access to the review template.","ref":"AWS.WellArchitected.html#create_template_share/4","title":"AWS.WellArchitected.create_template_share/4","type":"function"},{"doc":"By sharing your review template with other Amazon Web Services accounts, you\nacknowledge that Amazon Web Services will make your review template available to\nthose other accounts.","ref":"AWS.WellArchitected.html#create_template_share/4-disclaimer","title":"Disclaimer - AWS.WellArchitected.create_template_share/4","type":"function"},{"doc":"Create a new workload.\n\nThe owner of a workload can share the workload with other Amazon Web Services\naccounts, users, an organization, and organizational units (OUs) in the same\nAmazon Web Services Region. Only the owner of a workload can delete it.\n\nFor more information, see [Defining a Workload](https://docs.aws.amazon.com/wellarchitected/latest/userguide/define-workload.html)\nin the *Well-Architected Tool User Guide*.\n\nEither `AwsRegions`, `NonAwsRegions`, or both must be specified when creating a\nworkload.\n\nYou also must specify `ReviewOwner`, even though the parameter is listed as not\nbeing required in the following section.\n\nWhen creating a workload using a review template, you must have the following\nIAM permissions:\n\n  * `wellarchitected:GetReviewTemplate`\n\n  * `wellarchitected:GetReviewTemplateAnswer`\n\n  * `wellarchitected:ListReviewTemplateAnswers`\n\n  * `wellarchitected:GetReviewTemplateLensReview`","ref":"AWS.WellArchitected.html#create_workload/3","title":"AWS.WellArchitected.create_workload/3","type":"function"},{"doc":"Create a workload share.\n\nThe owner of a workload can share it with other Amazon Web Services accounts and\nusers in the same Amazon Web Services Region. Shared access to a workload is not\nremoved until the workload invitation is deleted.\n\nIf you share a workload with an organization or OU, all accounts in the\norganization or OU are granted access to the workload.\n\nFor more information, see [Sharing a workload](https://docs.aws.amazon.com/wellarchitected/latest/userguide/workloads-sharing.html)\nin the *Well-Architected Tool User Guide*.","ref":"AWS.WellArchitected.html#create_workload_share/4","title":"AWS.WellArchitected.create_workload_share/4","type":"function"},{"doc":"Delete an existing lens.\n\nOnly the owner of a lens can delete it. After the lens is deleted, Amazon Web\nServices accounts and users that you shared the lens with can continue to use\nit, but they will no longer be able to apply it to new workloads.","ref":"AWS.WellArchitected.html#delete_lens/4","title":"AWS.WellArchitected.delete_lens/4","type":"function"},{"doc":"By sharing your custom lenses with other Amazon Web Services accounts, you\nacknowledge that Amazon Web Services will make your custom lenses available to\nthose other accounts. Those other accounts may continue to access and use your\nshared custom lenses even if you delete the custom lenses from your own Amazon\nWeb Services account or terminate your Amazon Web Services account.","ref":"AWS.WellArchitected.html#delete_lens/4-disclaimer","title":"Disclaimer - AWS.WellArchitected.delete_lens/4","type":"function"},{"doc":"Delete a lens share.\n\nAfter the lens share is deleted, Amazon Web Services accounts, users,\norganizations, and organizational units (OUs) that you shared the lens with can\ncontinue to use it, but they will no longer be able to apply it to new\nworkloads.","ref":"AWS.WellArchitected.html#delete_lens_share/5","title":"AWS.WellArchitected.delete_lens_share/5","type":"function"},{"doc":"By sharing your custom lenses with other Amazon Web Services accounts, you\nacknowledge that Amazon Web Services will make your custom lenses available to\nthose other accounts. Those other accounts may continue to access and use your\nshared custom lenses even if you delete the custom lenses from your own Amazon\nWeb Services account or terminate your Amazon Web Services account.","ref":"AWS.WellArchitected.html#delete_lens_share/5-disclaimer","title":"Disclaimer - AWS.WellArchitected.delete_lens_share/5","type":"function"},{"doc":"Delete a profile.","ref":"AWS.WellArchitected.html#delete_profile/4","title":"AWS.WellArchitected.delete_profile/4","type":"function"},{"doc":"By sharing your profile with other Amazon Web Services accounts, you acknowledge\nthat Amazon Web Services will make your profile available to those other\naccounts. Those other accounts may continue to access and use your shared\nprofile even if you delete the profile from your own Amazon Web Services account\nor terminate your Amazon Web Services account.","ref":"AWS.WellArchitected.html#delete_profile/4-disclaimer","title":"Disclaimer - AWS.WellArchitected.delete_profile/4","type":"function"},{"doc":"Delete a profile share.","ref":"AWS.WellArchitected.html#delete_profile_share/5","title":"AWS.WellArchitected.delete_profile_share/5","type":"function"},{"doc":"Delete a review template.\n\nOnly the owner of a review template can delete it.\n\nAfter the review template is deleted, Amazon Web Services accounts, users,\norganizations, and organizational units (OUs) that you shared the review\ntemplate with will no longer be able to apply it to new workloads.","ref":"AWS.WellArchitected.html#delete_review_template/4","title":"AWS.WellArchitected.delete_review_template/4","type":"function"},{"doc":"Delete a review template share.\n\nAfter the review template share is deleted, Amazon Web Services accounts, users,\norganizations, and organizational units (OUs) that you shared the review\ntemplate with will no longer be able to apply it to new workloads.","ref":"AWS.WellArchitected.html#delete_template_share/5","title":"AWS.WellArchitected.delete_template_share/5","type":"function"},{"doc":"Delete an existing workload.","ref":"AWS.WellArchitected.html#delete_workload/4","title":"AWS.WellArchitected.delete_workload/4","type":"function"},{"doc":"Delete a workload share.","ref":"AWS.WellArchitected.html#delete_workload_share/5","title":"AWS.WellArchitected.delete_workload_share/5","type":"function"},{"doc":"Disassociate a lens from a workload.\n\nUp to 10 lenses can be disassociated from a workload in a single API operation.\n\nThe Amazon Web Services Well-Architected Framework lens (`wellarchitected`)\ncannot be removed from a workload.","ref":"AWS.WellArchitected.html#disassociate_lenses/4","title":"AWS.WellArchitected.disassociate_lenses/4","type":"function"},{"doc":"Disassociate a profile from a workload.","ref":"AWS.WellArchitected.html#disassociate_profiles/4","title":"AWS.WellArchitected.disassociate_profiles/4","type":"function"},{"doc":"Export an existing lens.\n\nOnly the owner of a lens can export it. Lenses provided by Amazon Web Services\n(Amazon Web Services Official Content) cannot be exported.\n\nLenses are defined in JSON. For more information, see [JSON format specification](https://docs.aws.amazon.com/wellarchitected/latest/userguide/lenses-format-specification.html)\nin the *Well-Architected Tool User Guide*.","ref":"AWS.WellArchitected.html#export_lens/4","title":"AWS.WellArchitected.export_lens/4","type":"function"},{"doc":"Do not include or gather personal identifiable information (PII) of end users or\nother identifiable individuals in or via your custom lenses. If your custom lens\nor those shared with you and used in your account do include or collect PII you\nare responsible for: ensuring that the included PII is processed in accordance\nwith applicable law, providing adequate privacy notices, and obtaining necessary\nconsents for processing such data.","ref":"AWS.WellArchitected.html#export_lens/4-disclaimer","title":"Disclaimer - AWS.WellArchitected.export_lens/4","type":"function"},{"doc":"Get the answer to a specific question in a workload review.","ref":"AWS.WellArchitected.html#get_answer/6","title":"AWS.WellArchitected.get_answer/6","type":"function"},{"doc":"Get a consolidated report of your workloads.\n\nYou can optionally choose to include workloads that have been shared with you.","ref":"AWS.WellArchitected.html#get_consolidated_report/6","title":"AWS.WellArchitected.get_consolidated_report/6","type":"function"},{"doc":"Get an existing lens.","ref":"AWS.WellArchitected.html#get_lens/4","title":"AWS.WellArchitected.get_lens/4","type":"function"},{"doc":"Get lens review.","ref":"AWS.WellArchitected.html#get_lens_review/5","title":"AWS.WellArchitected.get_lens_review/5","type":"function"},{"doc":"Get lens review report.","ref":"AWS.WellArchitected.html#get_lens_review_report/5","title":"AWS.WellArchitected.get_lens_review_report/5","type":"function"},{"doc":"Get lens version differences.","ref":"AWS.WellArchitected.html#get_lens_version_difference/5","title":"AWS.WellArchitected.get_lens_version_difference/5","type":"function"},{"doc":"Get a milestone for an existing workload.","ref":"AWS.WellArchitected.html#get_milestone/4","title":"AWS.WellArchitected.get_milestone/4","type":"function"},{"doc":"Get profile information.","ref":"AWS.WellArchitected.html#get_profile/4","title":"AWS.WellArchitected.get_profile/4","type":"function"},{"doc":"Get profile template.","ref":"AWS.WellArchitected.html#get_profile_template/2","title":"AWS.WellArchitected.get_profile_template/2","type":"function"},{"doc":"Get review template.","ref":"AWS.WellArchitected.html#get_review_template/3","title":"AWS.WellArchitected.get_review_template/3","type":"function"},{"doc":"Get review template answer.","ref":"AWS.WellArchitected.html#get_review_template_answer/5","title":"AWS.WellArchitected.get_review_template_answer/5","type":"function"},{"doc":"Get a lens review associated with a review template.","ref":"AWS.WellArchitected.html#get_review_template_lens_review/4","title":"AWS.WellArchitected.get_review_template_lens_review/4","type":"function"},{"doc":"Get an existing workload.","ref":"AWS.WellArchitected.html#get_workload/3","title":"AWS.WellArchitected.get_workload/3","type":"function"},{"doc":"Import a new custom lens or update an existing custom lens.\n\nTo update an existing custom lens, specify its ARN as the `LensAlias`. If no ARN\nis specified, a new custom lens is created.\n\nThe new or updated lens will have a status of `DRAFT`. The lens cannot be\napplied to workloads or shared with other Amazon Web Services accounts until\nit's published with `CreateLensVersion`.\n\nLenses are defined in JSON. For more information, see [JSON format specification](https://docs.aws.amazon.com/wellarchitected/latest/userguide/lenses-format-specification.html)\nin the *Well-Architected Tool User Guide*.\n\nA custom lens cannot exceed 500 KB in size.","ref":"AWS.WellArchitected.html#import_lens/3","title":"AWS.WellArchitected.import_lens/3","type":"function"},{"doc":"Do not include or gather personal identifiable information (PII) of end users or\nother identifiable individuals in or via your custom lenses. If your custom lens\nor those shared with you and used in your account do include or collect PII you\nare responsible for: ensuring that the included PII is processed in accordance\nwith applicable law, providing adequate privacy notices, and obtaining necessary\nconsents for processing such data.","ref":"AWS.WellArchitected.html#import_lens/3-disclaimer","title":"Disclaimer - AWS.WellArchitected.import_lens/3","type":"function"},{"doc":"List of answers for a particular workload and lens.","ref":"AWS.WellArchitected.html#list_answers/9","title":"AWS.WellArchitected.list_answers/9","type":"function"},{"doc":"List of Trusted Advisor check details by account related to the workload.","ref":"AWS.WellArchitected.html#list_check_details/4","title":"AWS.WellArchitected.list_check_details/4","type":"function"},{"doc":"List of Trusted Advisor checks summarized for all accounts related to the\nworkload.","ref":"AWS.WellArchitected.html#list_check_summaries/4","title":"AWS.WellArchitected.list_check_summaries/4","type":"function"},{"doc":"List lens review improvements.","ref":"AWS.WellArchitected.html#list_lens_review_improvements/9","title":"AWS.WellArchitected.list_lens_review_improvements/9","type":"function"},{"doc":"List lens reviews for a particular workload.","ref":"AWS.WellArchitected.html#list_lens_reviews/6","title":"AWS.WellArchitected.list_lens_reviews/6","type":"function"},{"doc":"List the lens shares associated with the lens.","ref":"AWS.WellArchitected.html#list_lens_shares/7","title":"AWS.WellArchitected.list_lens_shares/7","type":"function"},{"doc":"List the available lenses.","ref":"AWS.WellArchitected.html#list_lenses/7","title":"AWS.WellArchitected.list_lenses/7","type":"function"},{"doc":"List all milestones for an existing workload.","ref":"AWS.WellArchitected.html#list_milestones/4","title":"AWS.WellArchitected.list_milestones/4","type":"function"},{"doc":"List lens notifications.","ref":"AWS.WellArchitected.html#list_notifications/3","title":"AWS.WellArchitected.list_notifications/3","type":"function"},{"doc":"List profile notifications.","ref":"AWS.WellArchitected.html#list_profile_notifications/5","title":"AWS.WellArchitected.list_profile_notifications/5","type":"function"},{"doc":"List profile shares.","ref":"AWS.WellArchitected.html#list_profile_shares/7","title":"AWS.WellArchitected.list_profile_shares/7","type":"function"},{"doc":"List profiles.","ref":"AWS.WellArchitected.html#list_profiles/6","title":"AWS.WellArchitected.list_profiles/6","type":"function"},{"doc":"List the answers of a review template.","ref":"AWS.WellArchitected.html#list_review_template_answers/7","title":"AWS.WellArchitected.list_review_template_answers/7","type":"function"},{"doc":"List review templates.","ref":"AWS.WellArchitected.html#list_review_templates/4","title":"AWS.WellArchitected.list_review_templates/4","type":"function"},{"doc":"List the share invitations.\n\n`WorkloadNamePrefix`, `LensNamePrefix`, `ProfileNamePrefix`, and\n`TemplateNamePrefix` are mutually exclusive. Use the parameter that matches your\n`ShareResourceType`.","ref":"AWS.WellArchitected.html#list_share_invitations/9","title":"AWS.WellArchitected.list_share_invitations/9","type":"function"},{"doc":"List the tags for a resource.\n\nThe WorkloadArn parameter can be a workload ARN, a custom lens ARN, a profile\nARN, or review template ARN.","ref":"AWS.WellArchitected.html#list_tags_for_resource/3","title":"AWS.WellArchitected.list_tags_for_resource/3","type":"function"},{"doc":"List review template shares.","ref":"AWS.WellArchitected.html#list_template_shares/7","title":"AWS.WellArchitected.list_template_shares/7","type":"function"},{"doc":"List the workload shares associated with the workload.","ref":"AWS.WellArchitected.html#list_workload_shares/7","title":"AWS.WellArchitected.list_workload_shares/7","type":"function"},{"doc":"Paginated list of workloads.","ref":"AWS.WellArchitected.html#list_workloads/3","title":"AWS.WellArchitected.list_workloads/3","type":"function"},{"doc":"","ref":"AWS.WellArchitected.html#metadata/0","title":"AWS.WellArchitected.metadata/0","type":"function"},{"doc":"Adds one or more tags to the specified resource.\n\nThe WorkloadArn parameter can be a workload ARN, a custom lens ARN, a profile\nARN, or review template ARN.","ref":"AWS.WellArchitected.html#tag_resource/4","title":"AWS.WellArchitected.tag_resource/4","type":"function"},{"doc":"Deletes specified tags from a resource.\n\nThe WorkloadArn parameter can be a workload ARN, a custom lens ARN, a profile\nARN, or review template ARN.\n\nTo specify multiple tags, use separate **tagKeys** parameters, for example:\n\n`DELETE /tags/WorkloadArn?tagKeys=key1&tagKeys=key2`","ref":"AWS.WellArchitected.html#untag_resource/4","title":"AWS.WellArchitected.untag_resource/4","type":"function"},{"doc":"Update the answer to a specific question in a workload review.","ref":"AWS.WellArchitected.html#update_answer/6","title":"AWS.WellArchitected.update_answer/6","type":"function"},{"doc":"Updates whether the Amazon Web Services account is opted into organization\nsharing and discovery integration features.","ref":"AWS.WellArchitected.html#update_global_settings/3","title":"AWS.WellArchitected.update_global_settings/3","type":"function"},{"doc":"Update lens review for a particular workload.","ref":"AWS.WellArchitected.html#update_lens_review/5","title":"AWS.WellArchitected.update_lens_review/5","type":"function"},{"doc":"Update a profile.","ref":"AWS.WellArchitected.html#update_profile/4","title":"AWS.WellArchitected.update_profile/4","type":"function"},{"doc":"Update a review template.","ref":"AWS.WellArchitected.html#update_review_template/4","title":"AWS.WellArchitected.update_review_template/4","type":"function"},{"doc":"Update a review template answer.","ref":"AWS.WellArchitected.html#update_review_template_answer/6","title":"AWS.WellArchitected.update_review_template_answer/6","type":"function"},{"doc":"Update a lens review associated with a review template.","ref":"AWS.WellArchitected.html#update_review_template_lens_review/5","title":"AWS.WellArchitected.update_review_template_lens_review/5","type":"function"},{"doc":"Update a workload or custom lens share invitation.\n\nThis API operation can be called independently of any resource. Previous\ndocumentation implied that a workload ARN must be specified.","ref":"AWS.WellArchitected.html#update_share_invitation/4","title":"AWS.WellArchitected.update_share_invitation/4","type":"function"},{"doc":"Update an existing workload.","ref":"AWS.WellArchitected.html#update_workload/4","title":"AWS.WellArchitected.update_workload/4","type":"function"},{"doc":"Update a workload share.","ref":"AWS.WellArchitected.html#update_workload_share/5","title":"AWS.WellArchitected.update_workload_share/5","type":"function"},{"doc":"Upgrade lens review for a particular workload.","ref":"AWS.WellArchitected.html#upgrade_lens_review/5","title":"AWS.WellArchitected.upgrade_lens_review/5","type":"function"},{"doc":"Upgrade a profile.","ref":"AWS.WellArchitected.html#upgrade_profile_version/5","title":"AWS.WellArchitected.upgrade_profile_version/5","type":"function"},{"doc":"Upgrade the lens review of a review template.","ref":"AWS.WellArchitected.html#upgrade_review_template_lens_review/5","title":"AWS.WellArchitected.upgrade_review_template_lens_review/5","type":"function"},{"doc":"Amazon Connect Wisdom delivers agents the information they need to solve\ncustomer issues as they're actively speaking with customers.\n\nAgents can search across connected repositories from within their agent desktop\nto find answers quickly. Use Amazon Connect Wisdom to create an assistant and a\nknowledge base, for example, or manage content by uploading custom files.","ref":"AWS.Wisdom.html","title":"AWS.Wisdom","type":"module"},{"doc":"Creates an Amazon Connect Wisdom assistant.","ref":"AWS.Wisdom.html#create_assistant/3","title":"AWS.Wisdom.create_assistant/3","type":"function"},{"doc":"Creates an association between an Amazon Connect Wisdom assistant and another\nresource.\n\nCurrently, the only supported association is with a knowledge base. An assistant\ncan have only a single association.","ref":"AWS.Wisdom.html#create_assistant_association/4","title":"AWS.Wisdom.create_assistant_association/4","type":"function"},{"doc":"Creates Wisdom content.\n\nBefore to calling this API, use\n[StartContentUpload](https://docs.aws.amazon.com/wisdom/latest/APIReference/API_StartContentUpload.html)\nto upload an asset.","ref":"AWS.Wisdom.html#create_content/4","title":"AWS.Wisdom.create_content/4","type":"function"},{"doc":"Creates a knowledge base.\n\nWhen using this API, you cannot reuse [Amazon AppIntegrations](https://docs.aws.amazon.com/appintegrations/latest/APIReference/Welcome.html)\nDataIntegrations with external knowledge bases such as Salesforce and\nServiceNow. If you do, you'll get an `InvalidRequestException` error.\n\nFor example, you're programmatically managing your external knowledge base, and\nyou want to add or remove one of the fields that is being ingested from\nSalesforce. Do the following:\n\n   Call\n[DeleteKnowledgeBase](https://docs.aws.amazon.com/wisdom/latest/APIReference/API_DeleteKnowledgeBase.html).     Call\n[DeleteDataIntegration](https://docs.aws.amazon.com/appintegrations/latest/APIReference/API_DeleteDataIntegration.html).\n\n   Call\n[CreateDataIntegration](https://docs.aws.amazon.com/appintegrations/latest/APIReference/API_CreateDataIntegration.html)\nto recreate the DataIntegration or a create different one.\n\n   Call CreateKnowledgeBase.","ref":"AWS.Wisdom.html#create_knowledge_base/3","title":"AWS.Wisdom.create_knowledge_base/3","type":"function"},{"doc":"Creates a Wisdom quick response.","ref":"AWS.Wisdom.html#create_quick_response/4","title":"AWS.Wisdom.create_quick_response/4","type":"function"},{"doc":"Creates a session.\n\nA session is a contextual container used for generating recommendations. Amazon\nConnect creates a new Wisdom session for each contact on which Wisdom is\nenabled.","ref":"AWS.Wisdom.html#create_session/4","title":"AWS.Wisdom.create_session/4","type":"function"},{"doc":"Deletes an assistant.","ref":"AWS.Wisdom.html#delete_assistant/4","title":"AWS.Wisdom.delete_assistant/4","type":"function"},{"doc":"Deletes an assistant association.","ref":"AWS.Wisdom.html#delete_assistant_association/5","title":"AWS.Wisdom.delete_assistant_association/5","type":"function"},{"doc":"Deletes the content.","ref":"AWS.Wisdom.html#delete_content/5","title":"AWS.Wisdom.delete_content/5","type":"function"},{"doc":"Deletes the quick response import job.","ref":"AWS.Wisdom.html#delete_import_job/5","title":"AWS.Wisdom.delete_import_job/5","type":"function"},{"doc":"Deletes the knowledge base.\n\nWhen you use this API to delete an external knowledge base such as Salesforce or\nServiceNow, you must also delete the [Amazon AppIntegrations](https://docs.aws.amazon.com/appintegrations/latest/APIReference/Welcome.html)\nDataIntegration. This is because you can't reuse the DataIntegration after it's\nbeen associated with an external knowledge base. However, you can delete and\nrecreate it. See\n[DeleteDataIntegration](https://docs.aws.amazon.com/appintegrations/latest/APIReference/API_DeleteDataIntegration.html) and\n[CreateDataIntegration](https://docs.aws.amazon.com/appintegrations/latest/APIReference/API_CreateDataIntegration.html)\nin the *Amazon AppIntegrations API Reference*.","ref":"AWS.Wisdom.html#delete_knowledge_base/4","title":"AWS.Wisdom.delete_knowledge_base/4","type":"function"},{"doc":"Deletes a quick response.","ref":"AWS.Wisdom.html#delete_quick_response/5","title":"AWS.Wisdom.delete_quick_response/5","type":"function"},{"doc":"Retrieves information about an assistant.","ref":"AWS.Wisdom.html#get_assistant/3","title":"AWS.Wisdom.get_assistant/3","type":"function"},{"doc":"Retrieves information about an assistant association.","ref":"AWS.Wisdom.html#get_assistant_association/4","title":"AWS.Wisdom.get_assistant_association/4","type":"function"},{"doc":"Retrieves content, including a pre-signed URL to download the content.","ref":"AWS.Wisdom.html#get_content/4","title":"AWS.Wisdom.get_content/4","type":"function"},{"doc":"Retrieves summary information about the content.","ref":"AWS.Wisdom.html#get_content_summary/4","title":"AWS.Wisdom.get_content_summary/4","type":"function"},{"doc":"Retrieves the started import job.","ref":"AWS.Wisdom.html#get_import_job/4","title":"AWS.Wisdom.get_import_job/4","type":"function"},{"doc":"Retrieves information about the knowledge base.","ref":"AWS.Wisdom.html#get_knowledge_base/3","title":"AWS.Wisdom.get_knowledge_base/3","type":"function"},{"doc":"Retrieves the quick response.","ref":"AWS.Wisdom.html#get_quick_response/4","title":"AWS.Wisdom.get_quick_response/4","type":"function"},{"doc":"Retrieves recommendations for the specified session.\n\nTo avoid retrieving the same recommendations in subsequent calls, use\n[NotifyRecommendationsReceived](https://docs.aws.amazon.com/wisdom/latest/APIReference/API_NotifyRecommendationsReceived.html). This API supports long-polling behavior with the `waitTimeSeconds` parameter.\nShort poll is the default behavior and only returns recommendations already\navailable. To perform a manual query against an assistant, use\n[QueryAssistant](https://docs.aws.amazon.com/wisdom/latest/APIReference/API_QueryAssistant.html).","ref":"AWS.Wisdom.html#get_recommendations/6","title":"AWS.Wisdom.get_recommendations/6","type":"function"},{"doc":"Retrieves information for a specified session.","ref":"AWS.Wisdom.html#get_session/4","title":"AWS.Wisdom.get_session/4","type":"function"},{"doc":"Lists information about assistant associations.","ref":"AWS.Wisdom.html#list_assistant_associations/5","title":"AWS.Wisdom.list_assistant_associations/5","type":"function"},{"doc":"Lists information about assistants.","ref":"AWS.Wisdom.html#list_assistants/4","title":"AWS.Wisdom.list_assistants/4","type":"function"},{"doc":"Lists the content.","ref":"AWS.Wisdom.html#list_contents/5","title":"AWS.Wisdom.list_contents/5","type":"function"},{"doc":"Lists information about import jobs.","ref":"AWS.Wisdom.html#list_import_jobs/5","title":"AWS.Wisdom.list_import_jobs/5","type":"function"},{"doc":"Lists the knowledge bases.","ref":"AWS.Wisdom.html#list_knowledge_bases/4","title":"AWS.Wisdom.list_knowledge_bases/4","type":"function"},{"doc":"Lists information about quick response.","ref":"AWS.Wisdom.html#list_quick_responses/5","title":"AWS.Wisdom.list_quick_responses/5","type":"function"},{"doc":"Lists the tags for the specified resource.","ref":"AWS.Wisdom.html#list_tags_for_resource/3","title":"AWS.Wisdom.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.Wisdom.html#metadata/0","title":"AWS.Wisdom.metadata/0","type":"function"},{"doc":"Removes the specified recommendations from the specified assistant's queue of\nnewly available recommendations.\n\nYou can use this API in conjunction with\n[GetRecommendations](https://docs.aws.amazon.com/wisdom/latest/APIReference/API_GetRecommendations.html)\nand a `waitTimeSeconds` input for long-polling behavior and avoiding duplicate\nrecommendations.","ref":"AWS.Wisdom.html#notify_recommendations_received/5","title":"AWS.Wisdom.notify_recommendations_received/5","type":"function"},{"doc":"Performs a manual search against the specified assistant.\n\nTo retrieve recommendations for an assistant, use\n[GetRecommendations](https://docs.aws.amazon.com/wisdom/latest/APIReference/API_GetRecommendations.html).","ref":"AWS.Wisdom.html#query_assistant/4","title":"AWS.Wisdom.query_assistant/4","type":"function"},{"doc":"Removes a URI template from a knowledge base.","ref":"AWS.Wisdom.html#remove_knowledge_base_template_uri/4","title":"AWS.Wisdom.remove_knowledge_base_template_uri/4","type":"function"},{"doc":"Searches for content in a specified knowledge base.\n\nCan be used to get a specific content resource by its name.","ref":"AWS.Wisdom.html#search_content/4","title":"AWS.Wisdom.search_content/4","type":"function"},{"doc":"Searches existing Wisdom quick responses in a Wisdom knowledge base.","ref":"AWS.Wisdom.html#search_quick_responses/4","title":"AWS.Wisdom.search_quick_responses/4","type":"function"},{"doc":"Searches for sessions.","ref":"AWS.Wisdom.html#search_sessions/4","title":"AWS.Wisdom.search_sessions/4","type":"function"},{"doc":"Get a URL to upload content to a knowledge base.\n\nTo upload content, first make a PUT request to the returned URL with your file,\nmaking sure to include the required headers. Then use\n[CreateContent](https://docs.aws.amazon.com/wisdom/latest/APIReference/API_CreateContent.html) to finalize the content creation process or\n[UpdateContent](https://docs.aws.amazon.com/wisdom/latest/APIReference/API_UpdateContent.html)\nto modify an existing resource. You can only upload content to a knowledge base\nof type CUSTOM.","ref":"AWS.Wisdom.html#start_content_upload/4","title":"AWS.Wisdom.start_content_upload/4","type":"function"},{"doc":"Start an asynchronous job to import Wisdom resources from an uploaded source\nfile.\n\nBefore calling this API, use\n[StartContentUpload](https://docs.aws.amazon.com/wisdom/latest/APIReference/API_StartContentUpload.html) to upload an asset that contains the resource data.\n\n  * For importing Wisdom quick responses, you need to upload a csv\nfile including the quick responses. For information about how to format the csv\nfile for importing quick responses, see [Import quick\nresponses](https://docs.aws.amazon.com/console/connect/quick-responses/add-data).","ref":"AWS.Wisdom.html#start_import_job/4","title":"AWS.Wisdom.start_import_job/4","type":"function"},{"doc":"Adds the specified tags to the specified resource.","ref":"AWS.Wisdom.html#tag_resource/4","title":"AWS.Wisdom.tag_resource/4","type":"function"},{"doc":"Removes the specified tags from the specified resource.","ref":"AWS.Wisdom.html#untag_resource/4","title":"AWS.Wisdom.untag_resource/4","type":"function"},{"doc":"Updates information about the content.","ref":"AWS.Wisdom.html#update_content/5","title":"AWS.Wisdom.update_content/5","type":"function"},{"doc":"Updates the template URI of a knowledge base.\n\nThis is only supported for knowledge bases of type EXTERNAL. Include a single\nvariable in `${variable}` format; this interpolated by Wisdom using ingested\ncontent. For example, if you ingest a Salesforce article, it has an `Id` value,\nand you can set the template URI to\n`https://myInstanceName.lightning.force.com/lightning/r/Knowledge__kav/*${Id}*/view`.","ref":"AWS.Wisdom.html#update_knowledge_base_template_uri/4","title":"AWS.Wisdom.update_knowledge_base_template_uri/4","type":"function"},{"doc":"Updates an existing Wisdom quick response.","ref":"AWS.Wisdom.html#update_quick_response/5","title":"AWS.Wisdom.update_quick_response/5","type":"function"},{"doc":"The Amazon WorkDocs API is designed for the following use cases:\n\n  * File Migration: File migration applications are supported for\nusers who want to migrate their files from an on-premises or off-premises file\nsystem or service.\n\nUsers can insert files into a user directory structure, as well as allow for\nbasic metadata changes, such as modifications to the permissions of files.\n\n  * Security: Support security applications are supported for users\nwho have additional security needs, such as antivirus or data loss prevention.\nThe API actions, along with CloudTrail, allow these applications to detect when\nchanges occur in Amazon WorkDocs. Then, the application can take the necessary\nactions and replace the target file. If the target file violates the policy, the\napplication can also choose to email the user.\n\n  * eDiscovery/Analytics: General administrative applications are\nsupported, such as eDiscovery and analytics. These applications can choose to\nmimic or record the actions in an Amazon WorkDocs site, along with CloudTrail,\nto replicate data for eDiscovery, backup, or analytical applications.\n\nAll Amazon WorkDocs API actions are Amazon authenticated and certificate-signed.\nThey not only require the use of the Amazon Web Services SDK, but also allow for\nthe exclusive use of IAM users and roles to help facilitate access, trust, and\npermission policies. By creating a role and allowing an IAM user to access the\nAmazon WorkDocs site, the IAM user gains full administrative visibility into the\nentire Amazon WorkDocs site (or as set in the IAM policy). This includes, but is\nnot limited to, the ability to modify file permissions and upload any file to\nany user. This allows developers to perform the three use cases above, as well\nas give users the ability to grant access on a selective basis using the IAM\nmodel.\n\nThe pricing for Amazon WorkDocs APIs varies depending on the API call type for\nthese actions:\n\n   `READ (Get*)`\n\n   `WRITE (Activate*, Add*, Create*, Deactivate*, Initiate*, Update*)`\n\n   `LIST (Describe*)`\n\n   `DELETE*, CANCEL`\n\nFor information about Amazon WorkDocs API pricing, see [Amazon WorkDocs Pricing](https://aws.amazon.com/workdocs/pricing/).","ref":"AWS.WorkDocs.html","title":"AWS.WorkDocs","type":"module"},{"doc":"Aborts the upload of the specified document version that was previously\ninitiated by `InitiateDocumentVersionUpload`.\n\nThe client should make this call only when it no longer intends to upload the\ndocument version, or fails to do so.","ref":"AWS.WorkDocs.html#abort_document_version_upload/5","title":"AWS.WorkDocs.abort_document_version_upload/5","type":"function"},{"doc":"Activates the specified user.\n\nOnly active users can access Amazon WorkDocs.","ref":"AWS.WorkDocs.html#activate_user/4","title":"AWS.WorkDocs.activate_user/4","type":"function"},{"doc":"Creates a set of permissions for the specified folder or document.\n\nThe resource permissions are overwritten if the principals already have\ndifferent permissions.","ref":"AWS.WorkDocs.html#add_resource_permissions/4","title":"AWS.WorkDocs.add_resource_permissions/4","type":"function"},{"doc":"Adds a new comment to the specified document version.","ref":"AWS.WorkDocs.html#create_comment/5","title":"AWS.WorkDocs.create_comment/5","type":"function"},{"doc":"Adds one or more custom properties to the specified resource (a folder,\ndocument, or version).","ref":"AWS.WorkDocs.html#create_custom_metadata/4","title":"AWS.WorkDocs.create_custom_metadata/4","type":"function"},{"doc":"Creates a folder with the specified name and parent folder.","ref":"AWS.WorkDocs.html#create_folder/3","title":"AWS.WorkDocs.create_folder/3","type":"function"},{"doc":"Adds the specified list of labels to the given resource (a document or folder)","ref":"AWS.WorkDocs.html#create_labels/4","title":"AWS.WorkDocs.create_labels/4","type":"function"},{"doc":"Configure Amazon WorkDocs to use Amazon SNS notifications.\n\nThe endpoint receives a confirmation message, and must confirm the subscription.\n\nFor more information, see [Setting up notifications for an IAM user or role](https://docs.aws.amazon.com/workdocs/latest/developerguide/manage-notifications.html)\nin the *Amazon WorkDocs Developer Guide*.","ref":"AWS.WorkDocs.html#create_notification_subscription/4","title":"AWS.WorkDocs.create_notification_subscription/4","type":"function"},{"doc":"Creates a user in a Simple AD or Microsoft AD directory.\n\nThe status of a newly created user is \"ACTIVE\". New users can access Amazon\nWorkDocs.","ref":"AWS.WorkDocs.html#create_user/3","title":"AWS.WorkDocs.create_user/3","type":"function"},{"doc":"Deactivates the specified user, which revokes the user's access to Amazon\nWorkDocs.","ref":"AWS.WorkDocs.html#deactivate_user/4","title":"AWS.WorkDocs.deactivate_user/4","type":"function"},{"doc":"Deletes the specified comment from the document version.","ref":"AWS.WorkDocs.html#delete_comment/6","title":"AWS.WorkDocs.delete_comment/6","type":"function"},{"doc":"Deletes custom metadata from the specified resource.","ref":"AWS.WorkDocs.html#delete_custom_metadata/4","title":"AWS.WorkDocs.delete_custom_metadata/4","type":"function"},{"doc":"Permanently deletes the specified document and its associated metadata.","ref":"AWS.WorkDocs.html#delete_document/4","title":"AWS.WorkDocs.delete_document/4","type":"function"},{"doc":"Deletes a specific version of a document.","ref":"AWS.WorkDocs.html#delete_document_version/5","title":"AWS.WorkDocs.delete_document_version/5","type":"function"},{"doc":"Permanently deletes the specified folder and its contents.","ref":"AWS.WorkDocs.html#delete_folder/4","title":"AWS.WorkDocs.delete_folder/4","type":"function"},{"doc":"Deletes the contents of the specified folder.","ref":"AWS.WorkDocs.html#delete_folder_contents/4","title":"AWS.WorkDocs.delete_folder_contents/4","type":"function"},{"doc":"Deletes the specified list of labels from a resource.","ref":"AWS.WorkDocs.html#delete_labels/4","title":"AWS.WorkDocs.delete_labels/4","type":"function"},{"doc":"Deletes the specified subscription from the specified organization.","ref":"AWS.WorkDocs.html#delete_notification_subscription/5","title":"AWS.WorkDocs.delete_notification_subscription/5","type":"function"},{"doc":"Deletes the specified user from a Simple AD or Microsoft AD directory.\n\nDeleting a user immediately and permanently deletes all content in that user's\nfolder structure. Site retention policies do NOT apply to this type of deletion.","ref":"AWS.WorkDocs.html#delete_user/4","title":"AWS.WorkDocs.delete_user/4","type":"function"},{"doc":"Describes the user activities in a specified time period.","ref":"AWS.WorkDocs.html#describe_activities/12","title":"AWS.WorkDocs.describe_activities/12","type":"function"},{"doc":"List all the comments for the specified document version.","ref":"AWS.WorkDocs.html#describe_comments/7","title":"AWS.WorkDocs.describe_comments/7","type":"function"},{"doc":"Retrieves the document versions for the specified document.\n\nBy default, only active versions are returned.","ref":"AWS.WorkDocs.html#describe_document_versions/8","title":"AWS.WorkDocs.describe_document_versions/8","type":"function"},{"doc":"Describes the contents of the specified folder, including its documents and\nsubfolders.\n\nBy default, Amazon WorkDocs returns the first 100 active document and folder\nmetadata items. If there are more results, the response includes a marker that\nyou can use to request the next set of results. You can also request initialized\ndocuments.","ref":"AWS.WorkDocs.html#describe_folder_contents/10","title":"AWS.WorkDocs.describe_folder_contents/10","type":"function"},{"doc":"Describes the groups specified by the query.\n\nGroups are defined by the underlying Active Directory.","ref":"AWS.WorkDocs.html#describe_groups/7","title":"AWS.WorkDocs.describe_groups/7","type":"function"},{"doc":"Lists the specified notification subscriptions.","ref":"AWS.WorkDocs.html#describe_notification_subscriptions/5","title":"AWS.WorkDocs.describe_notification_subscriptions/5","type":"function"},{"doc":"Describes the permissions of a specified resource.","ref":"AWS.WorkDocs.html#describe_resource_permissions/7","title":"AWS.WorkDocs.describe_resource_permissions/7","type":"function"},{"doc":"Describes the current user's special folders; the `RootFolder` and the\n`RecycleBin`.\n\n`RootFolder` is the root of user's files and folders and `RecycleBin` is the\nroot of recycled items. This is not a valid action for SigV4 (administrative\nAPI) clients.\n\nThis action requires an authentication token. To get an authentication token,\nregister an application with Amazon WorkDocs. For more information, see\n[Authentication and Access Control for User Applications](https://docs.aws.amazon.com/workdocs/latest/developerguide/wd-auth-user.html)\nin the *Amazon WorkDocs Developer Guide*.","ref":"AWS.WorkDocs.html#describe_root_folders/5","title":"AWS.WorkDocs.describe_root_folders/5","type":"function"},{"doc":"Describes the specified users.\n\nYou can describe all users or filter the results (for example, by status or\norganization).\n\nBy default, Amazon WorkDocs returns the first 24 active or pending users. If\nthere are more results, the response includes a marker that you can use to\nrequest the next set of results.","ref":"AWS.WorkDocs.html#describe_users/12","title":"AWS.WorkDocs.describe_users/12","type":"function"},{"doc":"Retrieves details of the current user for whom the authentication token was\ngenerated.\n\nThis is not a valid action for SigV4 (administrative API) clients.\n\nThis action requires an authentication token. To get an authentication token,\nregister an application with Amazon WorkDocs. For more information, see\n[Authentication and Access Control for User Applications](https://docs.aws.amazon.com/workdocs/latest/developerguide/wd-auth-user.html)\nin the *Amazon WorkDocs Developer Guide*.","ref":"AWS.WorkDocs.html#get_current_user/3","title":"AWS.WorkDocs.get_current_user/3","type":"function"},{"doc":"Retrieves details of a document.","ref":"AWS.WorkDocs.html#get_document/5","title":"AWS.WorkDocs.get_document/5","type":"function"},{"doc":"Retrieves the path information (the hierarchy from the root folder) for the\nrequested document.\n\nBy default, Amazon WorkDocs returns a maximum of 100 levels upwards from the\nrequested document and only includes the IDs of the parent folders in the path.\nYou can limit the maximum number of levels. You can also request the names of\nthe parent folders.","ref":"AWS.WorkDocs.html#get_document_path/7","title":"AWS.WorkDocs.get_document_path/7","type":"function"},{"doc":"Retrieves version metadata for the specified document.","ref":"AWS.WorkDocs.html#get_document_version/7","title":"AWS.WorkDocs.get_document_version/7","type":"function"},{"doc":"Retrieves the metadata of the specified folder.","ref":"AWS.WorkDocs.html#get_folder/5","title":"AWS.WorkDocs.get_folder/5","type":"function"},{"doc":"Retrieves the path information (the hierarchy from the root folder) for the\nspecified folder.\n\nBy default, Amazon WorkDocs returns a maximum of 100 levels upwards from the\nrequested folder and only includes the IDs of the parent folders in the path.\nYou can limit the maximum number of levels. You can also request the parent\nfolder names.","ref":"AWS.WorkDocs.html#get_folder_path/7","title":"AWS.WorkDocs.get_folder_path/7","type":"function"},{"doc":"Retrieves a collection of resources, including folders and documents.\n\nThe only `CollectionType` supported is `SHARED_WITH_ME`.","ref":"AWS.WorkDocs.html#get_resources/7","title":"AWS.WorkDocs.get_resources/7","type":"function"},{"doc":"Creates a new document object and version object.\n\nThe client specifies the parent folder ID and name of the document to upload.\nThe ID is optionally specified when creating a new version of an existing\ndocument. This is the first step to upload a document. Next, upload the document\nto the URL returned from the call, and then call `UpdateDocumentVersion`.\n\nTo cancel the document upload, call `AbortDocumentVersionUpload`.","ref":"AWS.WorkDocs.html#initiate_document_version_upload/3","title":"AWS.WorkDocs.initiate_document_version_upload/3","type":"function"},{"doc":"","ref":"AWS.WorkDocs.html#metadata/0","title":"AWS.WorkDocs.metadata/0","type":"function"},{"doc":"Removes all the permissions from the specified resource.","ref":"AWS.WorkDocs.html#remove_all_resource_permissions/4","title":"AWS.WorkDocs.remove_all_resource_permissions/4","type":"function"},{"doc":"Removes the permission for the specified principal from the specified resource.","ref":"AWS.WorkDocs.html#remove_resource_permission/5","title":"AWS.WorkDocs.remove_resource_permission/5","type":"function"},{"doc":"Recovers a deleted version of an Amazon WorkDocs document.","ref":"AWS.WorkDocs.html#restore_document_versions/4","title":"AWS.WorkDocs.restore_document_versions/4","type":"function"},{"doc":"Searches metadata and the content of folders, documents, document versions, and\ncomments.","ref":"AWS.WorkDocs.html#search_resources/3","title":"AWS.WorkDocs.search_resources/3","type":"function"},{"doc":"Updates the specified attributes of a document.\n\nThe user must have access to both the document and its parent folder, if\napplicable.","ref":"AWS.WorkDocs.html#update_document/4","title":"AWS.WorkDocs.update_document/4","type":"function"},{"doc":"Changes the status of the document version to ACTIVE.\n\nAmazon WorkDocs also sets its document container to ACTIVE. This is the last\nstep in a document upload, after the client uploads the document to an\nS3-presigned URL returned by `InitiateDocumentVersionUpload`.","ref":"AWS.WorkDocs.html#update_document_version/5","title":"AWS.WorkDocs.update_document_version/5","type":"function"},{"doc":"Updates the specified attributes of the specified folder.\n\nThe user must have access to both the folder and its parent folder, if\napplicable.","ref":"AWS.WorkDocs.html#update_folder/4","title":"AWS.WorkDocs.update_folder/4","type":"function"},{"doc":"Updates the specified attributes of the specified user, and grants or revokes\nadministrative privileges to the Amazon WorkDocs site.","ref":"AWS.WorkDocs.html#update_user/4","title":"AWS.WorkDocs.update_user/4","type":"function"},{"doc":"Amazon WorkLink is a cloud-based service that provides secure access to internal\nwebsites and web apps from iOS and Android phones.\n\nIn a single step, your users, such as employees, can access internal websites as\nefficiently as they access any other public website. They enter a URL in their\nweb browser, or choose a link to an internal website in an email. Amazon\nWorkLink authenticates the user's access and securely renders authorized\ninternal web content in a secure rendering service in the AWS cloud. Amazon\nWorkLink doesn't download or store any internal web content on mobile devices.","ref":"AWS.WorkLink.html","title":"AWS.WorkLink","type":"module"},{"doc":"Specifies a domain to be associated to Amazon WorkLink.","ref":"AWS.WorkLink.html#associate_domain/3","title":"AWS.WorkLink.associate_domain/3","type":"function"},{"doc":"Associates a website authorization provider with a specified fleet.\n\nThis is used to authorize users against associated websites in the company\nnetwork.","ref":"AWS.WorkLink.html#associate_website_authorization_provider/3","title":"AWS.WorkLink.associate_website_authorization_provider/3","type":"function"},{"doc":"Imports the root certificate of a certificate authority (CA) used to obtain TLS\ncertificates used by associated websites within the company network.","ref":"AWS.WorkLink.html#associate_website_certificate_authority/3","title":"AWS.WorkLink.associate_website_certificate_authority/3","type":"function"},{"doc":"Creates a fleet.\n\nA fleet consists of resources and the configuration that delivers associated\nwebsites to authorized users who download and set up the Amazon WorkLink app.","ref":"AWS.WorkLink.html#create_fleet/3","title":"AWS.WorkLink.create_fleet/3","type":"function"},{"doc":"Deletes a fleet.\n\nPrevents users from accessing previously associated websites.","ref":"AWS.WorkLink.html#delete_fleet/3","title":"AWS.WorkLink.delete_fleet/3","type":"function"},{"doc":"Describes the configuration for delivering audit streams to the customer\naccount.","ref":"AWS.WorkLink.html#describe_audit_stream_configuration/3","title":"AWS.WorkLink.describe_audit_stream_configuration/3","type":"function"},{"doc":"Describes the networking configuration to access the internal websites\nassociated with the specified fleet.","ref":"AWS.WorkLink.html#describe_company_network_configuration/3","title":"AWS.WorkLink.describe_company_network_configuration/3","type":"function"},{"doc":"Provides information about a user's device.","ref":"AWS.WorkLink.html#describe_device/3","title":"AWS.WorkLink.describe_device/3","type":"function"},{"doc":"Describes the device policy configuration for the specified fleet.","ref":"AWS.WorkLink.html#describe_device_policy_configuration/3","title":"AWS.WorkLink.describe_device_policy_configuration/3","type":"function"},{"doc":"Provides information about the domain.","ref":"AWS.WorkLink.html#describe_domain/3","title":"AWS.WorkLink.describe_domain/3","type":"function"},{"doc":"Provides basic information for the specified fleet, excluding identity provider,\nnetworking, and device configuration details.","ref":"AWS.WorkLink.html#describe_fleet_metadata/3","title":"AWS.WorkLink.describe_fleet_metadata/3","type":"function"},{"doc":"Describes the identity provider configuration of the specified fleet.","ref":"AWS.WorkLink.html#describe_identity_provider_configuration/3","title":"AWS.WorkLink.describe_identity_provider_configuration/3","type":"function"},{"doc":"Provides information about the certificate authority.","ref":"AWS.WorkLink.html#describe_website_certificate_authority/3","title":"AWS.WorkLink.describe_website_certificate_authority/3","type":"function"},{"doc":"Disassociates a domain from Amazon WorkLink.\n\nEnd users lose the ability to access the domain with Amazon WorkLink.","ref":"AWS.WorkLink.html#disassociate_domain/3","title":"AWS.WorkLink.disassociate_domain/3","type":"function"},{"doc":"Disassociates a website authorization provider from a specified fleet.\n\nAfter the disassociation, users can't load any associated websites that require\nthis authorization provider.","ref":"AWS.WorkLink.html#disassociate_website_authorization_provider/3","title":"AWS.WorkLink.disassociate_website_authorization_provider/3","type":"function"},{"doc":"Removes a certificate authority (CA).","ref":"AWS.WorkLink.html#disassociate_website_certificate_authority/3","title":"AWS.WorkLink.disassociate_website_certificate_authority/3","type":"function"},{"doc":"Retrieves a list of devices registered with the specified fleet.","ref":"AWS.WorkLink.html#list_devices/3","title":"AWS.WorkLink.list_devices/3","type":"function"},{"doc":"Retrieves a list of domains associated to a specified fleet.","ref":"AWS.WorkLink.html#list_domains/3","title":"AWS.WorkLink.list_domains/3","type":"function"},{"doc":"Retrieves a list of fleets for the current account and Region.","ref":"AWS.WorkLink.html#list_fleets/3","title":"AWS.WorkLink.list_fleets/3","type":"function"},{"doc":"Retrieves a list of tags for the specified resource.","ref":"AWS.WorkLink.html#list_tags_for_resource/3","title":"AWS.WorkLink.list_tags_for_resource/3","type":"function"},{"doc":"Retrieves a list of website authorization providers associated with a specified\nfleet.","ref":"AWS.WorkLink.html#list_website_authorization_providers/3","title":"AWS.WorkLink.list_website_authorization_providers/3","type":"function"},{"doc":"Retrieves a list of certificate authorities added for the current account and\nRegion.","ref":"AWS.WorkLink.html#list_website_certificate_authorities/3","title":"AWS.WorkLink.list_website_certificate_authorities/3","type":"function"},{"doc":"","ref":"AWS.WorkLink.html#metadata/0","title":"AWS.WorkLink.metadata/0","type":"function"},{"doc":"Moves a domain to ACTIVE status if it was in the INACTIVE status.","ref":"AWS.WorkLink.html#restore_domain_access/3","title":"AWS.WorkLink.restore_domain_access/3","type":"function"},{"doc":"Moves a domain to INACTIVE status if it was in the ACTIVE status.","ref":"AWS.WorkLink.html#revoke_domain_access/3","title":"AWS.WorkLink.revoke_domain_access/3","type":"function"},{"doc":"Signs the user out from all of their devices.\n\nThe user can sign in again if they have valid credentials.","ref":"AWS.WorkLink.html#sign_out_user/3","title":"AWS.WorkLink.sign_out_user/3","type":"function"},{"doc":"Adds or overwrites one or more tags for the specified resource, such as a fleet.\n\nEach tag consists of a key and an optional value. If a resource already has a\ntag with the same key, this operation updates its value.","ref":"AWS.WorkLink.html#tag_resource/4","title":"AWS.WorkLink.tag_resource/4","type":"function"},{"doc":"Removes one or more tags from the specified resource.","ref":"AWS.WorkLink.html#untag_resource/4","title":"AWS.WorkLink.untag_resource/4","type":"function"},{"doc":"Updates the audit stream configuration for the fleet.","ref":"AWS.WorkLink.html#update_audit_stream_configuration/3","title":"AWS.WorkLink.update_audit_stream_configuration/3","type":"function"},{"doc":"Updates the company network configuration for the fleet.","ref":"AWS.WorkLink.html#update_company_network_configuration/3","title":"AWS.WorkLink.update_company_network_configuration/3","type":"function"},{"doc":"Updates the device policy configuration for the fleet.","ref":"AWS.WorkLink.html#update_device_policy_configuration/3","title":"AWS.WorkLink.update_device_policy_configuration/3","type":"function"},{"doc":"Updates domain metadata, such as DisplayName.","ref":"AWS.WorkLink.html#update_domain_metadata/3","title":"AWS.WorkLink.update_domain_metadata/3","type":"function"},{"doc":"Updates fleet metadata, such as DisplayName.","ref":"AWS.WorkLink.html#update_fleet_metadata/3","title":"AWS.WorkLink.update_fleet_metadata/3","type":"function"},{"doc":"Updates the identity provider configuration for the fleet.","ref":"AWS.WorkLink.html#update_identity_provider_configuration/3","title":"AWS.WorkLink.update_identity_provider_configuration/3","type":"function"},{"doc":"WorkMail is a secure, managed business email and calendaring service with\nsupport for existing desktop and mobile email clients.\n\nYou can access your email, contacts, and calendars using Microsoft Outlook, your\nbrowser, or other native iOS and Android email applications. You can integrate\nWorkMail with your existing corporate directory and control both the keys that\nencrypt your data and the location in which your data is stored.\n\nThe WorkMail API is designed for the following scenarios:\n\n  * Listing and describing organizations\n\n  * Managing users\n\n  * Managing groups\n\n  * Managing resources\n\nAll WorkMail API operations are Amazon-authenticated and certificate-signed.\nThey not only require the use of the AWS SDK, but also allow for the exclusive\nuse of AWS Identity and Access Management users and roles to help facilitate\naccess, trust, and permission policies. By creating a role and allowing an IAM\nuser to access the WorkMail site, the IAM user gains full administrative\nvisibility into the entire WorkMail organization (or as set in the IAM policy).\nThis includes, but is not limited to, the ability to create, update, and delete\nusers, groups, and resources. This allows developers to perform the scenarios\nlisted above, as well as give users the ability to grant access on a selective\nbasis using the IAM model.","ref":"AWS.WorkMail.html","title":"AWS.WorkMail","type":"module"},{"doc":"Adds a member (user or group) to the resource's set of delegates.","ref":"AWS.WorkMail.html#associate_delegate_to_resource/3","title":"AWS.WorkMail.associate_delegate_to_resource/3","type":"function"},{"doc":"Adds a member (user or group) to the group's set.","ref":"AWS.WorkMail.html#associate_member_to_group/3","title":"AWS.WorkMail.associate_member_to_group/3","type":"function"},{"doc":"Assumes an impersonation role for the given WorkMail organization.\n\nThis method returns an authentication token you can use to make impersonated\ncalls.","ref":"AWS.WorkMail.html#assume_impersonation_role/3","title":"AWS.WorkMail.assume_impersonation_role/3","type":"function"},{"doc":"Cancels a mailbox export job.\n\nIf the mailbox export job is near completion, it might not be possible to cancel\nit.","ref":"AWS.WorkMail.html#cancel_mailbox_export_job/3","title":"AWS.WorkMail.cancel_mailbox_export_job/3","type":"function"},{"doc":"Adds an alias to the set of a given member (user or group) of WorkMail.","ref":"AWS.WorkMail.html#create_alias/3","title":"AWS.WorkMail.create_alias/3","type":"function"},{"doc":"Creates an `AvailabilityConfiguration` for the given WorkMail organization and\ndomain.","ref":"AWS.WorkMail.html#create_availability_configuration/3","title":"AWS.WorkMail.create_availability_configuration/3","type":"function"},{"doc":"Creates a group that can be used in WorkMail by calling the `RegisterToWorkMail`\noperation.","ref":"AWS.WorkMail.html#create_group/3","title":"AWS.WorkMail.create_group/3","type":"function"},{"doc":"Creates an impersonation role for the given WorkMail organization.\n\n*Idempotency* ensures that an API request completes no more than one time. With\nan idempotent request, if the original request completes successfully, any\nsubsequent retries also complete successfully without performing any further\nactions.","ref":"AWS.WorkMail.html#create_impersonation_role/3","title":"AWS.WorkMail.create_impersonation_role/3","type":"function"},{"doc":"Creates a new mobile device access rule for the specified WorkMail organization.","ref":"AWS.WorkMail.html#create_mobile_device_access_rule/3","title":"AWS.WorkMail.create_mobile_device_access_rule/3","type":"function"},{"doc":"Creates a new WorkMail organization.\n\nOptionally, you can choose to associate an existing AWS Directory Service\ndirectory with your organization. If an AWS Directory Service directory ID is\nspecified, the organization alias must match the directory alias. If you choose\nnot to associate an existing directory with your organization, then we create a\nnew WorkMail directory for you. For more information, see [Adding an organization](https://docs.aws.amazon.com/workmail/latest/adminguide/add_new_organization.html)\nin the *WorkMail Administrator Guide*.\n\nYou can associate multiple email domains with an organization, then choose your\ndefault email domain from the WorkMail console. You can also associate a domain\nthat is managed in an Amazon Route 53 public hosted zone. For more information,\nsee [Adding a domain](https://docs.aws.amazon.com/workmail/latest/adminguide/add_domain.html)\nand [Choosing the default domain](https://docs.aws.amazon.com/workmail/latest/adminguide/default_domain.html)\nin the *WorkMail Administrator Guide*.\n\nOptionally, you can use a customer managed key from AWS Key Management Service\n(AWS KMS) to encrypt email for your organization. If you don't associate an AWS\nKMS key, WorkMail creates a default, AWS managed key for you.","ref":"AWS.WorkMail.html#create_organization/3","title":"AWS.WorkMail.create_organization/3","type":"function"},{"doc":"Creates a new WorkMail resource.","ref":"AWS.WorkMail.html#create_resource/3","title":"AWS.WorkMail.create_resource/3","type":"function"},{"doc":"Creates a user who can be used in WorkMail by calling the `RegisterToWorkMail`\noperation.","ref":"AWS.WorkMail.html#create_user/3","title":"AWS.WorkMail.create_user/3","type":"function"},{"doc":"Deletes an access control rule for the specified WorkMail organization.\n\nDeleting already deleted and non-existing rules does not produce an error. In\nthose cases, the service sends back an HTTP 200 response with an empty HTTP\nbody.","ref":"AWS.WorkMail.html#delete_access_control_rule/3","title":"AWS.WorkMail.delete_access_control_rule/3","type":"function"},{"doc":"Remove one or more specified aliases from a set of aliases for a given user.","ref":"AWS.WorkMail.html#delete_alias/3","title":"AWS.WorkMail.delete_alias/3","type":"function"},{"doc":"Deletes the `AvailabilityConfiguration` for the given WorkMail organization and\ndomain.","ref":"AWS.WorkMail.html#delete_availability_configuration/3","title":"AWS.WorkMail.delete_availability_configuration/3","type":"function"},{"doc":"Deletes the email monitoring configuration for a specified organization.","ref":"AWS.WorkMail.html#delete_email_monitoring_configuration/3","title":"AWS.WorkMail.delete_email_monitoring_configuration/3","type":"function"},{"doc":"Deletes a group from WorkMail.","ref":"AWS.WorkMail.html#delete_group/3","title":"AWS.WorkMail.delete_group/3","type":"function"},{"doc":"Deletes an impersonation role for the given WorkMail organization.","ref":"AWS.WorkMail.html#delete_impersonation_role/3","title":"AWS.WorkMail.delete_impersonation_role/3","type":"function"},{"doc":"Deletes permissions granted to a member (user or group).","ref":"AWS.WorkMail.html#delete_mailbox_permissions/3","title":"AWS.WorkMail.delete_mailbox_permissions/3","type":"function"},{"doc":"Deletes the mobile device access override for the given WorkMail organization,\nuser, and device.\n\nDeleting already deleted and non-existing overrides does not produce an error.\nIn those cases, the service sends back an HTTP 200 response with an empty HTTP\nbody.","ref":"AWS.WorkMail.html#delete_mobile_device_access_override/3","title":"AWS.WorkMail.delete_mobile_device_access_override/3","type":"function"},{"doc":"Deletes a mobile device access rule for the specified WorkMail organization.\n\nDeleting already deleted and non-existing rules does not produce an error. In\nthose cases, the service sends back an HTTP 200 response with an empty HTTP\nbody.","ref":"AWS.WorkMail.html#delete_mobile_device_access_rule/3","title":"AWS.WorkMail.delete_mobile_device_access_rule/3","type":"function"},{"doc":"Deletes an WorkMail organization and all underlying AWS resources managed by\nWorkMail as part of the organization.\n\nYou can choose whether to delete the associated directory. For more information,\nsee [Removing an organization](https://docs.aws.amazon.com/workmail/latest/adminguide/remove_organization.html)\nin the *WorkMail Administrator Guide*.","ref":"AWS.WorkMail.html#delete_organization/3","title":"AWS.WorkMail.delete_organization/3","type":"function"},{"doc":"Deletes the specified resource.","ref":"AWS.WorkMail.html#delete_resource/3","title":"AWS.WorkMail.delete_resource/3","type":"function"},{"doc":"Deletes the specified retention policy from the specified organization.","ref":"AWS.WorkMail.html#delete_retention_policy/3","title":"AWS.WorkMail.delete_retention_policy/3","type":"function"},{"doc":"Deletes a user from WorkMail and all subsequent systems.\n\nBefore you can delete a user, the user state must be `DISABLED`. Use the\n`DescribeUser` action to confirm the user state.\n\nDeleting a user is permanent and cannot be undone. WorkMail archives user\nmailboxes for 30 days before they are permanently removed.","ref":"AWS.WorkMail.html#delete_user/3","title":"AWS.WorkMail.delete_user/3","type":"function"},{"doc":"Mark a user, group, or resource as no longer used in WorkMail.\n\nThis action disassociates the mailbox and schedules it for clean-up. WorkMail\nkeeps mailboxes for 30 days before they are permanently removed. The\nfunctionality in the console is *Disable*.","ref":"AWS.WorkMail.html#deregister_from_work_mail/3","title":"AWS.WorkMail.deregister_from_work_mail/3","type":"function"},{"doc":"Removes a domain from WorkMail, stops email routing to WorkMail, and removes the\nauthorization allowing WorkMail use.\n\nSES keeps the domain because other applications may use it. You must first\nremove any email address used by WorkMail entities before you remove the domain.","ref":"AWS.WorkMail.html#deregister_mail_domain/3","title":"AWS.WorkMail.deregister_mail_domain/3","type":"function"},{"doc":"Describes the current email monitoring configuration for a specified\norganization.","ref":"AWS.WorkMail.html#describe_email_monitoring_configuration/3","title":"AWS.WorkMail.describe_email_monitoring_configuration/3","type":"function"},{"doc":"Returns basic details about an entity in WorkMail.","ref":"AWS.WorkMail.html#describe_entity/3","title":"AWS.WorkMail.describe_entity/3","type":"function"},{"doc":"Returns the data available for the group.","ref":"AWS.WorkMail.html#describe_group/3","title":"AWS.WorkMail.describe_group/3","type":"function"},{"doc":"Lists the settings in a DMARC policy for a specified organization.","ref":"AWS.WorkMail.html#describe_inbound_dmarc_settings/3","title":"AWS.WorkMail.describe_inbound_dmarc_settings/3","type":"function"},{"doc":"Describes the current status of a mailbox export job.","ref":"AWS.WorkMail.html#describe_mailbox_export_job/3","title":"AWS.WorkMail.describe_mailbox_export_job/3","type":"function"},{"doc":"Provides more information regarding a given organization based on its\nidentifier.","ref":"AWS.WorkMail.html#describe_organization/3","title":"AWS.WorkMail.describe_organization/3","type":"function"},{"doc":"Returns the data available for the resource.","ref":"AWS.WorkMail.html#describe_resource/3","title":"AWS.WorkMail.describe_resource/3","type":"function"},{"doc":"Provides information regarding the user.","ref":"AWS.WorkMail.html#describe_user/3","title":"AWS.WorkMail.describe_user/3","type":"function"},{"doc":"Removes a member from the resource's set of delegates.","ref":"AWS.WorkMail.html#disassociate_delegate_from_resource/3","title":"AWS.WorkMail.disassociate_delegate_from_resource/3","type":"function"},{"doc":"Removes a member from a group.","ref":"AWS.WorkMail.html#disassociate_member_from_group/3","title":"AWS.WorkMail.disassociate_member_from_group/3","type":"function"},{"doc":"Gets the effects of an organization's access control rules as they apply to a\nspecified IPv4 address, access protocol action, and user ID or impersonation\nrole ID.\n\nYou must provide either the user ID or impersonation role ID. Impersonation role\nID can only be used with Action EWS.","ref":"AWS.WorkMail.html#get_access_control_effect/3","title":"AWS.WorkMail.get_access_control_effect/3","type":"function"},{"doc":"Gets the default retention policy details for the specified organization.","ref":"AWS.WorkMail.html#get_default_retention_policy/3","title":"AWS.WorkMail.get_default_retention_policy/3","type":"function"},{"doc":"Gets the impersonation role details for the given WorkMail organization.","ref":"AWS.WorkMail.html#get_impersonation_role/3","title":"AWS.WorkMail.get_impersonation_role/3","type":"function"},{"doc":"Tests whether the given impersonation role can impersonate a target user.","ref":"AWS.WorkMail.html#get_impersonation_role_effect/3","title":"AWS.WorkMail.get_impersonation_role_effect/3","type":"function"},{"doc":"Gets details for a mail domain, including domain records required to configure\nyour domain with recommended security.","ref":"AWS.WorkMail.html#get_mail_domain/3","title":"AWS.WorkMail.get_mail_domain/3","type":"function"},{"doc":"Requests a user's mailbox details for a specified organization and user.","ref":"AWS.WorkMail.html#get_mailbox_details/3","title":"AWS.WorkMail.get_mailbox_details/3","type":"function"},{"doc":"Simulates the effect of the mobile device access rules for the given attributes\nof a sample access event.\n\nUse this method to test the effects of the current set of mobile device access\nrules for the WorkMail organization for a particular user's attributes.","ref":"AWS.WorkMail.html#get_mobile_device_access_effect/3","title":"AWS.WorkMail.get_mobile_device_access_effect/3","type":"function"},{"doc":"Gets the mobile device access override for the given WorkMail organization,\nuser, and device.","ref":"AWS.WorkMail.html#get_mobile_device_access_override/3","title":"AWS.WorkMail.get_mobile_device_access_override/3","type":"function"},{"doc":"Lists the access control rules for the specified organization.","ref":"AWS.WorkMail.html#list_access_control_rules/3","title":"AWS.WorkMail.list_access_control_rules/3","type":"function"},{"doc":"Creates a paginated call to list the aliases associated with a given entity.","ref":"AWS.WorkMail.html#list_aliases/3","title":"AWS.WorkMail.list_aliases/3","type":"function"},{"doc":"List all the `AvailabilityConfiguration`'s for the given WorkMail organization.","ref":"AWS.WorkMail.html#list_availability_configurations/3","title":"AWS.WorkMail.list_availability_configurations/3","type":"function"},{"doc":"Returns an overview of the members of a group.\n\nUsers and groups can be members of a group.","ref":"AWS.WorkMail.html#list_group_members/3","title":"AWS.WorkMail.list_group_members/3","type":"function"},{"doc":"Returns summaries of the organization's groups.","ref":"AWS.WorkMail.html#list_groups/3","title":"AWS.WorkMail.list_groups/3","type":"function"},{"doc":"Returns all the groups to which an entity belongs.","ref":"AWS.WorkMail.html#list_groups_for_entity/3","title":"AWS.WorkMail.list_groups_for_entity/3","type":"function"},{"doc":"Lists all the impersonation roles for the given WorkMail organization.","ref":"AWS.WorkMail.html#list_impersonation_roles/3","title":"AWS.WorkMail.list_impersonation_roles/3","type":"function"},{"doc":"Lists the mail domains in a given WorkMail organization.","ref":"AWS.WorkMail.html#list_mail_domains/3","title":"AWS.WorkMail.list_mail_domains/3","type":"function"},{"doc":"Lists the mailbox export jobs started for the specified organization within the\nlast seven days.","ref":"AWS.WorkMail.html#list_mailbox_export_jobs/3","title":"AWS.WorkMail.list_mailbox_export_jobs/3","type":"function"},{"doc":"Lists the mailbox permissions associated with a user, group, or resource\nmailbox.","ref":"AWS.WorkMail.html#list_mailbox_permissions/3","title":"AWS.WorkMail.list_mailbox_permissions/3","type":"function"},{"doc":"Lists all the mobile device access overrides for any given combination of\nWorkMail organization, user, or device.","ref":"AWS.WorkMail.html#list_mobile_device_access_overrides/3","title":"AWS.WorkMail.list_mobile_device_access_overrides/3","type":"function"},{"doc":"Lists the mobile device access rules for the specified WorkMail organization.","ref":"AWS.WorkMail.html#list_mobile_device_access_rules/3","title":"AWS.WorkMail.list_mobile_device_access_rules/3","type":"function"},{"doc":"Returns summaries of the customer's organizations.","ref":"AWS.WorkMail.html#list_organizations/3","title":"AWS.WorkMail.list_organizations/3","type":"function"},{"doc":"Lists the delegates associated with a resource.\n\nUsers and groups can be resource delegates and answer requests on behalf of the\nresource.","ref":"AWS.WorkMail.html#list_resource_delegates/3","title":"AWS.WorkMail.list_resource_delegates/3","type":"function"},{"doc":"Returns summaries of the organization's resources.","ref":"AWS.WorkMail.html#list_resources/3","title":"AWS.WorkMail.list_resources/3","type":"function"},{"doc":"Lists the tags applied to an WorkMail organization resource.","ref":"AWS.WorkMail.html#list_tags_for_resource/3","title":"AWS.WorkMail.list_tags_for_resource/3","type":"function"},{"doc":"Returns summaries of the organization's users.","ref":"AWS.WorkMail.html#list_users/3","title":"AWS.WorkMail.list_users/3","type":"function"},{"doc":"","ref":"AWS.WorkMail.html#metadata/0","title":"AWS.WorkMail.metadata/0","type":"function"},{"doc":"Adds a new access control rule for the specified organization.\n\nThe rule allows or denies access to the organization for the specified IPv4\naddresses, access protocol actions, user IDs and impersonation IDs. Adding a new\nrule with the same name as an existing rule replaces the older rule.","ref":"AWS.WorkMail.html#put_access_control_rule/3","title":"AWS.WorkMail.put_access_control_rule/3","type":"function"},{"doc":"Creates or updates the email monitoring configuration for a specified\norganization.","ref":"AWS.WorkMail.html#put_email_monitoring_configuration/3","title":"AWS.WorkMail.put_email_monitoring_configuration/3","type":"function"},{"doc":"Enables or disables a DMARC policy for a given organization.","ref":"AWS.WorkMail.html#put_inbound_dmarc_settings/3","title":"AWS.WorkMail.put_inbound_dmarc_settings/3","type":"function"},{"doc":"Sets permissions for a user, group, or resource.\n\nThis replaces any pre-existing permissions.","ref":"AWS.WorkMail.html#put_mailbox_permissions/3","title":"AWS.WorkMail.put_mailbox_permissions/3","type":"function"},{"doc":"Creates or updates a mobile device access override for the given WorkMail\norganization, user, and device.","ref":"AWS.WorkMail.html#put_mobile_device_access_override/3","title":"AWS.WorkMail.put_mobile_device_access_override/3","type":"function"},{"doc":"Puts a retention policy to the specified organization.","ref":"AWS.WorkMail.html#put_retention_policy/3","title":"AWS.WorkMail.put_retention_policy/3","type":"function"},{"doc":"Registers a new domain in WorkMail and SES, and configures it for use by\nWorkMail.\n\nEmails received by SES for this domain are routed to the specified WorkMail\norganization, and WorkMail has permanent permission to use the specified domain\nfor sending your users' emails.","ref":"AWS.WorkMail.html#register_mail_domain/3","title":"AWS.WorkMail.register_mail_domain/3","type":"function"},{"doc":"Registers an existing and disabled user, group, or resource for WorkMail use by\nassociating a mailbox and calendaring capabilities.\n\nIt performs no change if the user, group, or resource is enabled and fails if\nthe user, group, or resource is deleted. This operation results in the\naccumulation of costs. For more information, see\n[Pricing](https://aws.amazon.com/workmail/pricing). The equivalent console\nfunctionality for this operation is *Enable*.\n\nUsers can either be created by calling the `CreateUser` API operation or they\ncan be synchronized from your directory. For more information, see\n`DeregisterFromWorkMail`.","ref":"AWS.WorkMail.html#register_to_work_mail/3","title":"AWS.WorkMail.register_to_work_mail/3","type":"function"},{"doc":"Allows the administrator to reset the password for a user.","ref":"AWS.WorkMail.html#reset_password/3","title":"AWS.WorkMail.reset_password/3","type":"function"},{"doc":"Starts a mailbox export job to export MIME-format email messages and calendar\nitems from the specified mailbox to the specified Amazon Simple Storage Service\n(Amazon S3) bucket.\n\nFor more information, see [Exporting mailbox content](https://docs.aws.amazon.com/workmail/latest/adminguide/mail-export.html)\nin the *WorkMail Administrator Guide*.","ref":"AWS.WorkMail.html#start_mailbox_export_job/3","title":"AWS.WorkMail.start_mailbox_export_job/3","type":"function"},{"doc":"Applies the specified tags to the specified WorkMailorganization resource.","ref":"AWS.WorkMail.html#tag_resource/3","title":"AWS.WorkMail.tag_resource/3","type":"function"},{"doc":"Performs a test on an availability provider to ensure that access is allowed.\n\nFor EWS, it verifies the provided credentials can be used to successfully log\nin. For Lambda, it verifies that the Lambda function can be invoked and that the\nresource access policy was configured to deny anonymous access. An anonymous\ninvocation is one done without providing either a `SourceArn` or `SourceAccount`\nheader.\n\nThe request must contain either one provider definition (`EwsProvider` or\n`LambdaProvider`) or the `DomainName` parameter. If the `DomainName` parameter\nis provided, the configuration stored under the `DomainName` will be tested.","ref":"AWS.WorkMail.html#test_availability_configuration/3","title":"AWS.WorkMail.test_availability_configuration/3","type":"function"},{"doc":"Untags the specified tags from the specified WorkMail organization resource.","ref":"AWS.WorkMail.html#untag_resource/3","title":"AWS.WorkMail.untag_resource/3","type":"function"},{"doc":"Updates an existing `AvailabilityConfiguration` for the given WorkMail\norganization and domain.","ref":"AWS.WorkMail.html#update_availability_configuration/3","title":"AWS.WorkMail.update_availability_configuration/3","type":"function"},{"doc":"Updates the default mail domain for an organization.\n\nThe default mail domain is used by the WorkMail AWS Console to suggest an email\naddress when enabling a mail user. You can only have one default domain.","ref":"AWS.WorkMail.html#update_default_mail_domain/3","title":"AWS.WorkMail.update_default_mail_domain/3","type":"function"},{"doc":"Updates attibutes in a group.","ref":"AWS.WorkMail.html#update_group/3","title":"AWS.WorkMail.update_group/3","type":"function"},{"doc":"Updates an impersonation role for the given WorkMail organization.","ref":"AWS.WorkMail.html#update_impersonation_role/3","title":"AWS.WorkMail.update_impersonation_role/3","type":"function"},{"doc":"Updates a user's current mailbox quota for a specified organization and user.","ref":"AWS.WorkMail.html#update_mailbox_quota/3","title":"AWS.WorkMail.update_mailbox_quota/3","type":"function"},{"doc":"Updates a mobile device access rule for the specified WorkMail organization.","ref":"AWS.WorkMail.html#update_mobile_device_access_rule/3","title":"AWS.WorkMail.update_mobile_device_access_rule/3","type":"function"},{"doc":"Updates the primary email for a user, group, or resource.\n\nThe current email is moved into the list of aliases (or swapped between an\nexisting alias and the current primary email), and the email provided in the\ninput is promoted as the primary.","ref":"AWS.WorkMail.html#update_primary_email_address/3","title":"AWS.WorkMail.update_primary_email_address/3","type":"function"},{"doc":"Updates data for the resource.\n\nTo have the latest information, it must be preceded by a `DescribeResource`\ncall. The dataset in the request should be the one expected when performing\nanother `DescribeResource` call.","ref":"AWS.WorkMail.html#update_resource/3","title":"AWS.WorkMail.update_resource/3","type":"function"},{"doc":"Updates data for the user.\n\nTo have the latest information, it must be preceded by a `DescribeUser` call.\nThe dataset in the request should be the one expected when performing another\n`DescribeUser` call.","ref":"AWS.WorkMail.html#update_user/3","title":"AWS.WorkMail.update_user/3","type":"function"},{"doc":"The WorkMail Message Flow API provides access to email messages as they are\nbeing sent and received by a WorkMail organization.","ref":"AWS.WorkMailMessageFlow.html","title":"AWS.WorkMailMessageFlow","type":"module"},{"doc":"Retrieves the raw content of an in-transit email message, in MIME format.","ref":"AWS.WorkMailMessageFlow.html#get_raw_message_content/3","title":"AWS.WorkMailMessageFlow.get_raw_message_content/3","type":"function"},{"doc":"","ref":"AWS.WorkMailMessageFlow.html#metadata/0","title":"AWS.WorkMailMessageFlow.metadata/0","type":"function"},{"doc":"Updates the raw content of an in-transit email message, in MIME format.\n\nThis example describes how to update in-transit email message. For more\ninformation and examples for using this API, see [ Updating message content with AWS\nLambda](https://docs.aws.amazon.com/workmail/latest/adminguide/update-with-lambda.html).\n\nUpdates to an in-transit message only appear when you call\n`PutRawMessageContent` from an AWS Lambda function configured with a synchronous\n[ Run Lambda](https://docs.aws.amazon.com/workmail/latest/adminguide/lambda.html#synchronous-rules)\nrule. If you call `PutRawMessageContent` on a delivered or sent message, the\nmessage remains unchanged, even though\n[GetRawMessageContent](https://docs.aws.amazon.com/workmail/latest/APIReference/API_messageflow_GetRawMessageContent.html)\nreturns an updated message.","ref":"AWS.WorkMailMessageFlow.html#put_raw_message_content/4","title":"AWS.WorkMailMessageFlow.put_raw_message_content/4","type":"function"},{"doc":"Amazon WorkSpaces Service\n\nAmazon WorkSpaces enables you to provision virtual, cloud-based Microsoft\nWindows or Amazon Linux desktops for your users, known as *WorkSpaces*.\n\nWorkSpaces eliminates the need to procure and deploy hardware or install complex\nsoftware. You can quickly add or remove users as your needs change. Users can\naccess their virtual desktops from multiple devices or web browsers.\n\nThis API Reference provides detailed information about the actions, data types,\nparameters, and errors of the WorkSpaces service. For more information about the\nsupported Amazon Web Services Regions, endpoints, and service quotas of the\nAmazon WorkSpaces service, see [WorkSpaces endpoints and quotas](https://docs.aws.amazon.com/general/latest/gr/wsp.html) in the *Amazon\nWeb Services General Reference*.\n\nYou can also manage your WorkSpaces resources using the WorkSpaces console,\nCommand Line Interface (CLI), and SDKs. For more information about administering\nWorkSpaces, see the [Amazon WorkSpaces Administration Guide](https://docs.aws.amazon.com/workspaces/latest/adminguide/). For more\ninformation about using the Amazon WorkSpaces client application or web browser\nto access provisioned WorkSpaces, see the [Amazon WorkSpaces User Guide](https://docs.aws.amazon.com/workspaces/latest/userguide/). For more\ninformation about using the CLI to manage your WorkSpaces resources, see the\n[WorkSpaces section of the CLI Reference](https://docs.aws.amazon.com/cli/latest/reference/workspaces/index.html).","ref":"AWS.WorkSpaces.html","title":"AWS.WorkSpaces","type":"module"},{"doc":"Associates the specified connection alias with the specified directory to enable\ncross-Region redirection.\n\nFor more information, see [ Cross-Region Redirection for Amazon WorkSpaces](https://docs.aws.amazon.com/workspaces/latest/adminguide/cross-region-redirection.html).\n\nBefore performing this operation, call [\nDescribeConnectionAliases](https://docs.aws.amazon.com/workspaces/latest/api/API_DescribeConnectionAliases.html)\nto make sure that the current state of the connection alias is `CREATED`.","ref":"AWS.WorkSpaces.html#associate_connection_alias/3","title":"AWS.WorkSpaces.associate_connection_alias/3","type":"function"},{"doc":"Associates the specified IP access control group with the specified directory.","ref":"AWS.WorkSpaces.html#associate_ip_groups/3","title":"AWS.WorkSpaces.associate_ip_groups/3","type":"function"},{"doc":"Associates the specified application to the specified WorkSpace.","ref":"AWS.WorkSpaces.html#associate_workspace_application/3","title":"AWS.WorkSpaces.associate_workspace_application/3","type":"function"},{"doc":"Adds one or more rules to the specified IP access control group.\n\nThis action gives users permission to access their WorkSpaces from the CIDR\naddress ranges specified in the rules.","ref":"AWS.WorkSpaces.html#authorize_ip_rules/3","title":"AWS.WorkSpaces.authorize_ip_rules/3","type":"function"},{"doc":"Copies the specified image from the specified Region to the current Region.\n\nFor more information about copying images, see [ Copy a Custom WorkSpaces Image](https://docs.aws.amazon.com/workspaces/latest/adminguide/copy-custom-image.html).\n\nIn the China (Ningxia) Region, you can copy images only within the same Region.\n\nIn Amazon Web Services GovCloud (US), to copy images to and from other Regions,\ncontact Amazon Web Services Support.\n\nBefore copying a shared image, be sure to verify that it has been shared from\nthe correct Amazon Web Services account. To determine if an image has been\nshared and to see the ID of the Amazon Web Services account that owns an image,\nuse the\n[DescribeWorkSpaceImages](https://docs.aws.amazon.com/workspaces/latest/api/API_DescribeWorkspaceImages.html) and\n[DescribeWorkspaceImagePermissions](https://docs.aws.amazon.com/workspaces/latest/api/API_DescribeWorkspaceImagePermissions.html)\nAPI operations.","ref":"AWS.WorkSpaces.html#copy_workspace_image/3","title":"AWS.WorkSpaces.copy_workspace_image/3","type":"function"},{"doc":"Creates a client-add-in for Amazon Connect within a directory.\n\nYou can create only one Amazon Connect client add-in within a directory.\n\nThis client add-in allows WorkSpaces users to seamlessly connect to Amazon\nConnect.","ref":"AWS.WorkSpaces.html#create_connect_client_add_in/3","title":"AWS.WorkSpaces.create_connect_client_add_in/3","type":"function"},{"doc":"Creates the specified connection alias for use with cross-Region redirection.\n\nFor more information, see [ Cross-Region Redirection for Amazon WorkSpaces](https://docs.aws.amazon.com/workspaces/latest/adminguide/cross-region-redirection.html).","ref":"AWS.WorkSpaces.html#create_connection_alias/3","title":"AWS.WorkSpaces.create_connection_alias/3","type":"function"},{"doc":"Creates an IP access control group.\n\nAn IP access control group provides you with the ability to control the IP\naddresses from which users are allowed to access their WorkSpaces. To specify\nthe CIDR address ranges, add rules to your IP access control group and then\nassociate the group with your directory. You can add rules when you create the\ngroup or at any time using `AuthorizeIpRules`.\n\nThere is a default IP access control group associated with your directory. If\nyou don't associate an IP access control group with your directory, the default\ngroup is used. The default group includes a default rule that allows users to\naccess their WorkSpaces from anywhere. You cannot modify the default IP access\ncontrol group for your directory.","ref":"AWS.WorkSpaces.html#create_ip_group/3","title":"AWS.WorkSpaces.create_ip_group/3","type":"function"},{"doc":"Creates a standby WorkSpace in a secondary Region.","ref":"AWS.WorkSpaces.html#create_standby_workspaces/3","title":"AWS.WorkSpaces.create_standby_workspaces/3","type":"function"},{"doc":"Creates the specified tags for the specified WorkSpaces resource.","ref":"AWS.WorkSpaces.html#create_tags/3","title":"AWS.WorkSpaces.create_tags/3","type":"function"},{"doc":"Creates a new updated WorkSpace image based on the specified source image.\n\nThe new updated WorkSpace image has the latest drivers and other updates\nrequired by the Amazon WorkSpaces components.\n\nTo determine which WorkSpace images need to be updated with the latest Amazon\nWorkSpaces requirements, use [\nDescribeWorkspaceImages](https://docs.aws.amazon.com/workspaces/latest/api/API_DescribeWorkspaceImages.html).\n\n   Only Windows 10, Windows Server 2016, and Windows Server 2019\nWorkSpace images can be programmatically updated at this time.\n\n   Microsoft Windows updates and other application updates are not\nincluded in the update process.\n\n   The source WorkSpace image is not deleted. You can delete the\nsource image after you've verified your new updated image and created a new\nbundle.","ref":"AWS.WorkSpaces.html#create_updated_workspace_image/3","title":"AWS.WorkSpaces.create_updated_workspace_image/3","type":"function"},{"doc":"Creates the specified WorkSpace bundle.\n\nFor more information about creating WorkSpace bundles, see [ Create a Custom WorkSpaces Image and\nBundle](https://docs.aws.amazon.com/workspaces/latest/adminguide/create-custom-bundle.html).","ref":"AWS.WorkSpaces.html#create_workspace_bundle/3","title":"AWS.WorkSpaces.create_workspace_bundle/3","type":"function"},{"doc":"Creates a new WorkSpace image from an existing WorkSpace.","ref":"AWS.WorkSpaces.html#create_workspace_image/3","title":"AWS.WorkSpaces.create_workspace_image/3","type":"function"},{"doc":"Creates one or more WorkSpaces.\n\nThis operation is asynchronous and returns before the WorkSpaces are created.\n\n   The `MANUAL` running mode value is only supported by Amazon\nWorkSpaces Core. Contact your account team to be allow-listed to use this value.\nFor more information, see [Amazon WorkSpaces Core](http://aws.amazon.com/workspaces/core/).\n\n   You don't need to specify the `PCOIP` protocol for Linux bundles\nbecause `WSP` is the default protocol for those bundles.","ref":"AWS.WorkSpaces.html#create_workspaces/3","title":"AWS.WorkSpaces.create_workspaces/3","type":"function"},{"doc":"Deletes customized client branding.\n\nClient branding allows you to customize your WorkSpace's client login portal.\nYou can tailor your login portal company logo, the support email address,\nsupport link, link to reset password, and a custom message for users trying to\nsign in.\n\nAfter you delete your customized client branding, your login portal reverts to\nthe default client branding.","ref":"AWS.WorkSpaces.html#delete_client_branding/3","title":"AWS.WorkSpaces.delete_client_branding/3","type":"function"},{"doc":"Deletes a client-add-in for Amazon Connect that is configured within a\ndirectory.","ref":"AWS.WorkSpaces.html#delete_connect_client_add_in/3","title":"AWS.WorkSpaces.delete_connect_client_add_in/3","type":"function"},{"doc":"Deletes the specified connection alias.\n\nFor more information, see [ Cross-Region Redirection for Amazon WorkSpaces](https://docs.aws.amazon.com/workspaces/latest/adminguide/cross-region-redirection.html).\n\n**If you will no longer be using a fully qualified domain name (FQDN) as the\nregistration code for your WorkSpaces users, you must take certain precautions\nto prevent potential security issues.** For more information, see [ Security Considerations if You Stop Using Cross-Region\nRedirection](https://docs.aws.amazon.com/workspaces/latest/adminguide/cross-region-redirection.html#cross-region-redirection-security-considerations).\n\nTo delete a connection alias that has been shared, the shared account must first\ndisassociate the connection alias from any directories it has been associated\nwith. Then you must unshare the connection alias from the account it has been\nshared with. You can delete a connection alias only after it is no longer shared\nwith any accounts or associated with any directories.","ref":"AWS.WorkSpaces.html#delete_connection_alias/3","title":"AWS.WorkSpaces.delete_connection_alias/3","type":"function"},{"doc":"Deletes the specified IP access control group.\n\nYou cannot delete an IP access control group that is associated with a\ndirectory.","ref":"AWS.WorkSpaces.html#delete_ip_group/3","title":"AWS.WorkSpaces.delete_ip_group/3","type":"function"},{"doc":"Deletes the specified tags from the specified WorkSpaces resource.","ref":"AWS.WorkSpaces.html#delete_tags/3","title":"AWS.WorkSpaces.delete_tags/3","type":"function"},{"doc":"Deletes the specified WorkSpace bundle.\n\nFor more information about deleting WorkSpace bundles, see [ Delete a Custom WorkSpaces Bundle or\nImage](https://docs.aws.amazon.com/workspaces/latest/adminguide/delete_bundle.html).","ref":"AWS.WorkSpaces.html#delete_workspace_bundle/3","title":"AWS.WorkSpaces.delete_workspace_bundle/3","type":"function"},{"doc":"Deletes the specified image from your account.\n\nTo delete an image, you must first delete any bundles that are associated with\nthe image and unshare the image if it is shared with other accounts.","ref":"AWS.WorkSpaces.html#delete_workspace_image/3","title":"AWS.WorkSpaces.delete_workspace_image/3","type":"function"},{"doc":"Deploys associated applications to the specified WorkSpace","ref":"AWS.WorkSpaces.html#deploy_workspace_applications/3","title":"AWS.WorkSpaces.deploy_workspace_applications/3","type":"function"},{"doc":"Deregisters the specified directory.\n\nThis operation is asynchronous and returns before the WorkSpace directory is\nderegistered. If any WorkSpaces are registered to this directory, you must\nremove them before you can deregister the directory.\n\nSimple AD and AD Connector are made available to you free of charge to use with\nWorkSpaces. If there are no WorkSpaces being used with your Simple AD or AD\nConnector directory for 30 consecutive days, this directory will be\nautomatically deregistered for use with Amazon WorkSpaces, and you will be\ncharged for this directory as per the [Directory Service pricing terms](http://aws.amazon.com/directoryservice/pricing/).\n\nTo delete empty directories, see [ Delete the Directory for Your WorkSpaces](https://docs.aws.amazon.com/workspaces/latest/adminguide/delete-workspaces-directory.html).\nIf you delete your Simple AD or AD Connector directory, you can always create a\nnew one when you want to start using WorkSpaces again.","ref":"AWS.WorkSpaces.html#deregister_workspace_directory/3","title":"AWS.WorkSpaces.deregister_workspace_directory/3","type":"function"},{"doc":"Retrieves a list that describes the configuration of Bring Your Own License\n(BYOL) for the specified account.","ref":"AWS.WorkSpaces.html#describe_account/3","title":"AWS.WorkSpaces.describe_account/3","type":"function"},{"doc":"Retrieves a list that describes modifications to the configuration of Bring Your\nOwn License (BYOL) for the specified account.","ref":"AWS.WorkSpaces.html#describe_account_modifications/3","title":"AWS.WorkSpaces.describe_account_modifications/3","type":"function"},{"doc":"Describes the associations between the application and the specified associated\nresources.","ref":"AWS.WorkSpaces.html#describe_application_associations/3","title":"AWS.WorkSpaces.describe_application_associations/3","type":"function"},{"doc":"Describes the specified applications by filtering based on their compute types,\nlicense availability, operating systems, and owners.","ref":"AWS.WorkSpaces.html#describe_applications/3","title":"AWS.WorkSpaces.describe_applications/3","type":"function"},{"doc":"Describes the associations between the applications and the specified bundle.","ref":"AWS.WorkSpaces.html#describe_bundle_associations/3","title":"AWS.WorkSpaces.describe_bundle_associations/3","type":"function"},{"doc":"Describes the specified client branding.\n\nClient branding allows you to customize the log in page of various device types\nfor your users. You can add your company logo, the support email address,\nsupport link, link to reset password, and a custom message for users trying to\nsign in.\n\nOnly device types that have branding information configured will be shown in the\nresponse.","ref":"AWS.WorkSpaces.html#describe_client_branding/3","title":"AWS.WorkSpaces.describe_client_branding/3","type":"function"},{"doc":"Retrieves a list that describes one or more specified Amazon WorkSpaces clients.","ref":"AWS.WorkSpaces.html#describe_client_properties/3","title":"AWS.WorkSpaces.describe_client_properties/3","type":"function"},{"doc":"Retrieves a list of Amazon Connect client add-ins that have been created.","ref":"AWS.WorkSpaces.html#describe_connect_client_add_ins/3","title":"AWS.WorkSpaces.describe_connect_client_add_ins/3","type":"function"},{"doc":"Describes the permissions that the owner of a connection alias has granted to\nanother Amazon Web Services account for the specified connection alias.\n\nFor more information, see [ Cross-Region Redirection for Amazon WorkSpaces](https://docs.aws.amazon.com/workspaces/latest/adminguide/cross-region-redirection.html).","ref":"AWS.WorkSpaces.html#describe_connection_alias_permissions/3","title":"AWS.WorkSpaces.describe_connection_alias_permissions/3","type":"function"},{"doc":"Retrieves a list that describes the connection aliases used for cross-Region\nredirection.\n\nFor more information, see [ Cross-Region Redirection for Amazon WorkSpaces](https://docs.aws.amazon.com/workspaces/latest/adminguide/cross-region-redirection.html).","ref":"AWS.WorkSpaces.html#describe_connection_aliases/3","title":"AWS.WorkSpaces.describe_connection_aliases/3","type":"function"},{"doc":"Describes the associations between the applications and the specified image.","ref":"AWS.WorkSpaces.html#describe_image_associations/3","title":"AWS.WorkSpaces.describe_image_associations/3","type":"function"},{"doc":"Describes one or more of your IP access control groups.","ref":"AWS.WorkSpaces.html#describe_ip_groups/3","title":"AWS.WorkSpaces.describe_ip_groups/3","type":"function"},{"doc":"Describes the specified tags for the specified WorkSpaces resource.","ref":"AWS.WorkSpaces.html#describe_tags/3","title":"AWS.WorkSpaces.describe_tags/3","type":"function"},{"doc":"Describes the associations betweens applications and the specified WorkSpace.","ref":"AWS.WorkSpaces.html#describe_workspace_associations/3","title":"AWS.WorkSpaces.describe_workspace_associations/3","type":"function"},{"doc":"Retrieves a list that describes the available WorkSpace bundles.\n\nYou can filter the results using either bundle ID or owner, but not both.","ref":"AWS.WorkSpaces.html#describe_workspace_bundles/3","title":"AWS.WorkSpaces.describe_workspace_bundles/3","type":"function"},{"doc":"Describes the available directories that are registered with Amazon WorkSpaces.","ref":"AWS.WorkSpaces.html#describe_workspace_directories/3","title":"AWS.WorkSpaces.describe_workspace_directories/3","type":"function"},{"doc":"Describes the permissions that the owner of an image has granted to other Amazon\nWeb Services accounts for an image.","ref":"AWS.WorkSpaces.html#describe_workspace_image_permissions/3","title":"AWS.WorkSpaces.describe_workspace_image_permissions/3","type":"function"},{"doc":"Retrieves a list that describes one or more specified images, if the image\nidentifiers are provided.\n\nOtherwise, all images in the account are described.","ref":"AWS.WorkSpaces.html#describe_workspace_images/3","title":"AWS.WorkSpaces.describe_workspace_images/3","type":"function"},{"doc":"Describes the snapshots for the specified WorkSpace.","ref":"AWS.WorkSpaces.html#describe_workspace_snapshots/3","title":"AWS.WorkSpaces.describe_workspace_snapshots/3","type":"function"},{"doc":"Describes the specified WorkSpaces.\n\nYou can filter the results by using the bundle identifier, directory identifier,\nor owner, but you can specify only one filter at a time.","ref":"AWS.WorkSpaces.html#describe_workspaces/3","title":"AWS.WorkSpaces.describe_workspaces/3","type":"function"},{"doc":"Describes the connection status of the specified WorkSpaces.","ref":"AWS.WorkSpaces.html#describe_workspaces_connection_status/3","title":"AWS.WorkSpaces.describe_workspaces_connection_status/3","type":"function"},{"doc":"Disassociates a connection alias from a directory.\n\nDisassociating a connection alias disables cross-Region redirection between two\ndirectories in different Regions. For more information, see [ Cross-Region Redirection for Amazon\nWorkSpaces](https://docs.aws.amazon.com/workspaces/latest/adminguide/cross-region-redirection.html).\n\nBefore performing this operation, call [\nDescribeConnectionAliases](https://docs.aws.amazon.com/workspaces/latest/api/API_DescribeConnectionAliases.html)\nto make sure that the current state of the connection alias is `CREATED`.","ref":"AWS.WorkSpaces.html#disassociate_connection_alias/3","title":"AWS.WorkSpaces.disassociate_connection_alias/3","type":"function"},{"doc":"Disassociates the specified IP access control group from the specified\ndirectory.","ref":"AWS.WorkSpaces.html#disassociate_ip_groups/3","title":"AWS.WorkSpaces.disassociate_ip_groups/3","type":"function"},{"doc":"Disassociates the specified application from a WorkSpace.","ref":"AWS.WorkSpaces.html#disassociate_workspace_application/3","title":"AWS.WorkSpaces.disassociate_workspace_application/3","type":"function"},{"doc":"Imports client branding.\n\nClient branding allows you to customize your WorkSpace's client login portal.\nYou can tailor your login portal company logo, the support email address,\nsupport link, link to reset password, and a custom message for users trying to\nsign in.\n\nAfter you import client branding, the default branding experience for the\nspecified platform type is replaced with the imported experience\n\n   You must specify at least one platform type when importing client\nbranding.\n\n   You can import up to 6 MB of data with each request. If your\nrequest exceeds this limit, you can import client branding for different\nplatform types using separate requests.\n\n   In each platform type, the `SupportEmail` and `SupportLink`\nparameters are mutually exclusive. You can specify only one parameter for each\nplatform type, but not both.\n\n   Imported data can take up to a minute to appear in the WorkSpaces\nclient.","ref":"AWS.WorkSpaces.html#import_client_branding/3","title":"AWS.WorkSpaces.import_client_branding/3","type":"function"},{"doc":"Imports the specified Windows 10 or 11 Bring Your Own License (BYOL) image into\nAmazon WorkSpaces.\n\nThe image must be an already licensed Amazon EC2 image that is in your Amazon\nWeb Services account, and you must own the image. For more information about\ncreating BYOL images, see [ Bring Your Own Windows Desktop Licenses](https://docs.aws.amazon.com/workspaces/latest/adminguide/byol-windows-images.html).","ref":"AWS.WorkSpaces.html#import_workspace_image/3","title":"AWS.WorkSpaces.import_workspace_image/3","type":"function"},{"doc":"Retrieves a list of IP address ranges, specified as IPv4 CIDR blocks, that you\ncan use for the network management interface when you enable Bring Your Own\nLicense (BYOL).\n\nThis operation can be run only by Amazon Web Services accounts that are enabled\nfor BYOL. If your account isn't enabled for BYOL, you'll receive an\n`AccessDeniedException` error.\n\nThe management network interface is connected to a secure Amazon WorkSpaces\nmanagement network. It is used for interactive streaming of the WorkSpace\ndesktop to Amazon WorkSpaces clients, and to allow Amazon WorkSpaces to manage\nthe WorkSpace.","ref":"AWS.WorkSpaces.html#list_available_management_cidr_ranges/3","title":"AWS.WorkSpaces.list_available_management_cidr_ranges/3","type":"function"},{"doc":"","ref":"AWS.WorkSpaces.html#metadata/0","title":"AWS.WorkSpaces.metadata/0","type":"function"},{"doc":"Migrates a WorkSpace from one operating system or bundle type to another, while\nretaining the data on the user volume.\n\nThe migration process recreates the WorkSpace by using a new root volume from\nthe target bundle image and the user volume from the last available snapshot of\nthe original WorkSpace. During migration, the original `D:Users%USERNAME%`\nuser profile folder is renamed to\n`D:Users%USERNAME%MMddyyTHHmmss%.NotMigrated`. A new `D:Users%USERNAME%`\nfolder is generated by the new OS. Certain files in the old user profile are\nmoved to the new user profile.\n\nFor available migration scenarios, details about what happens during migration,\nand best practices, see [Migrate a WorkSpace](https://docs.aws.amazon.com/workspaces/latest/adminguide/migrate-workspaces.html).","ref":"AWS.WorkSpaces.html#migrate_workspace/3","title":"AWS.WorkSpaces.migrate_workspace/3","type":"function"},{"doc":"Modifies the configuration of Bring Your Own License (BYOL) for the specified\naccount.","ref":"AWS.WorkSpaces.html#modify_account/3","title":"AWS.WorkSpaces.modify_account/3","type":"function"},{"doc":"Modifies the properties of the certificate-based authentication you want to use\nwith your WorkSpaces.","ref":"AWS.WorkSpaces.html#modify_certificate_based_auth_properties/3","title":"AWS.WorkSpaces.modify_certificate_based_auth_properties/3","type":"function"},{"doc":"Modifies the properties of the specified Amazon WorkSpaces clients.","ref":"AWS.WorkSpaces.html#modify_client_properties/3","title":"AWS.WorkSpaces.modify_client_properties/3","type":"function"},{"doc":"Modifies multiple properties related to SAML 2.0 authentication, including the\nenablement status, user access URL, and relay state parameter name that are used\nfor configuring federation with an SAML 2.0 identity provider.","ref":"AWS.WorkSpaces.html#modify_saml_properties/3","title":"AWS.WorkSpaces.modify_saml_properties/3","type":"function"},{"doc":"Modifies the self-service WorkSpace management capabilities for your users.\n\nFor more information, see [Enable Self-Service WorkSpace Management Capabilities for Your\nUsers](https://docs.aws.amazon.com/workspaces/latest/adminguide/enable-user-self-service-workspace-management.html).","ref":"AWS.WorkSpaces.html#modify_selfservice_permissions/3","title":"AWS.WorkSpaces.modify_selfservice_permissions/3","type":"function"},{"doc":"Specifies which devices and operating systems users can use to access their\nWorkSpaces.\n\nFor more information, see [ Control Device Access](https://docs.aws.amazon.com/workspaces/latest/adminguide/update-directory-details.html#control-device-access).","ref":"AWS.WorkSpaces.html#modify_workspace_access_properties/3","title":"AWS.WorkSpaces.modify_workspace_access_properties/3","type":"function"},{"doc":"Modify the default properties used to create WorkSpaces.","ref":"AWS.WorkSpaces.html#modify_workspace_creation_properties/3","title":"AWS.WorkSpaces.modify_workspace_creation_properties/3","type":"function"},{"doc":"Modifies the specified WorkSpace properties.\n\nFor important information about how to modify the size of the root and user\nvolumes, see [ Modify a WorkSpace](https://docs.aws.amazon.com/workspaces/latest/adminguide/modify-workspaces.html).\n\nThe `MANUAL` running mode value is only supported by Amazon WorkSpaces Core.\nContact your account team to be allow-listed to use this value. For more\ninformation, see [Amazon WorkSpaces Core](http://aws.amazon.com/workspaces/core/).","ref":"AWS.WorkSpaces.html#modify_workspace_properties/3","title":"AWS.WorkSpaces.modify_workspace_properties/3","type":"function"},{"doc":"Sets the state of the specified WorkSpace.\n\nTo maintain a WorkSpace without being interrupted, set the WorkSpace state to\n`ADMIN_MAINTENANCE`. WorkSpaces in this state do not respond to requests to\nreboot, stop, start, rebuild, or restore. An AutoStop WorkSpace in this state is\nnot stopped. Users cannot log into a WorkSpace in the `ADMIN_MAINTENANCE` state.","ref":"AWS.WorkSpaces.html#modify_workspace_state/3","title":"AWS.WorkSpaces.modify_workspace_state/3","type":"function"},{"doc":"Reboots the specified WorkSpaces.\n\nYou cannot reboot a WorkSpace unless its state is `AVAILABLE` or `UNHEALTHY`.\n\nThis operation is asynchronous and returns before the WorkSpaces have rebooted.","ref":"AWS.WorkSpaces.html#reboot_workspaces/3","title":"AWS.WorkSpaces.reboot_workspaces/3","type":"function"},{"doc":"Rebuilds the specified WorkSpace.\n\nYou cannot rebuild a WorkSpace unless its state is `AVAILABLE`, `ERROR`,\n`UNHEALTHY`, `STOPPED`, or `REBOOTING`.\n\nRebuilding a WorkSpace is a potentially destructive action that can result in\nthe loss of data. For more information, see [Rebuild a WorkSpace](https://docs.aws.amazon.com/workspaces/latest/adminguide/reset-workspace.html).\n\nThis operation is asynchronous and returns before the WorkSpaces have been\ncompletely rebuilt.","ref":"AWS.WorkSpaces.html#rebuild_workspaces/3","title":"AWS.WorkSpaces.rebuild_workspaces/3","type":"function"},{"doc":"Registers the specified directory.\n\nThis operation is asynchronous and returns before the WorkSpace directory is\nregistered. If this is the first time you are registering a directory, you will\nneed to create the workspaces_DefaultRole role before you can register a\ndirectory. For more information, see [ Creating the workspaces_DefaultRole Role](https://docs.aws.amazon.com/workspaces/latest/adminguide/workspaces-access-control.html#create-default-role).","ref":"AWS.WorkSpaces.html#register_workspace_directory/3","title":"AWS.WorkSpaces.register_workspace_directory/3","type":"function"},{"doc":"Restores the specified WorkSpace to its last known healthy state.\n\nYou cannot restore a WorkSpace unless its state is ` AVAILABLE`, `ERROR`,\n`UNHEALTHY`, or `STOPPED`.\n\nRestoring a WorkSpace is a potentially destructive action that can result in the\nloss of data. For more information, see [Restore a WorkSpace](https://docs.aws.amazon.com/workspaces/latest/adminguide/restore-workspace.html).\n\nThis operation is asynchronous and returns before the WorkSpace is completely\nrestored.","ref":"AWS.WorkSpaces.html#restore_workspace/3","title":"AWS.WorkSpaces.restore_workspace/3","type":"function"},{"doc":"Removes one or more rules from the specified IP access control group.","ref":"AWS.WorkSpaces.html#revoke_ip_rules/3","title":"AWS.WorkSpaces.revoke_ip_rules/3","type":"function"},{"doc":"Starts the specified WorkSpaces.\n\nYou cannot start a WorkSpace unless it has a running mode of `AutoStop` and a\nstate of `STOPPED`.","ref":"AWS.WorkSpaces.html#start_workspaces/3","title":"AWS.WorkSpaces.start_workspaces/3","type":"function"},{"doc":"Stops the specified WorkSpaces.\n\nYou cannot stop a WorkSpace unless it has a running mode of `AutoStop` and a\nstate of `AVAILABLE`, `IMPAIRED`, `UNHEALTHY`, or `ERROR`.","ref":"AWS.WorkSpaces.html#stop_workspaces/3","title":"AWS.WorkSpaces.stop_workspaces/3","type":"function"},{"doc":"Terminates the specified WorkSpaces.\n\nTerminating a WorkSpace is a permanent action and cannot be undone. The user's\ndata is destroyed. If you need to archive any user data, contact Amazon Web\nServices Support before terminating the WorkSpace.\n\nYou can terminate a WorkSpace that is in any state except `SUSPENDED`.\n\nThis operation is asynchronous and returns before the WorkSpaces have been\ncompletely terminated. After a WorkSpace is terminated, the `TERMINATED` state\nis returned only briefly before the WorkSpace directory metadata is cleaned up,\nso this state is rarely returned. To confirm that a WorkSpace is terminated,\ncheck for the WorkSpace ID by using [\nDescribeWorkSpaces](https://docs.aws.amazon.com/workspaces/latest/api/API_DescribeWorkspaces.html).\nIf the WorkSpace ID isn't returned, then the WorkSpace has been successfully\nterminated.\n\nSimple AD and AD Connector are made available to you free of charge to use with\nWorkSpaces. If there are no WorkSpaces being used with your Simple AD or AD\nConnector directory for 30 consecutive days, this directory will be\nautomatically deregistered for use with Amazon WorkSpaces, and you will be\ncharged for this directory as per the [Directory Service pricing terms](http://aws.amazon.com/directoryservice/pricing/).\n\nTo delete empty directories, see [ Delete the Directory for Your WorkSpaces](https://docs.aws.amazon.com/workspaces/latest/adminguide/delete-workspaces-directory.html).\nIf you delete your Simple AD or AD Connector directory, you can always create a\nnew one when you want to start using WorkSpaces again.","ref":"AWS.WorkSpaces.html#terminate_workspaces/3","title":"AWS.WorkSpaces.terminate_workspaces/3","type":"function"},{"doc":"Updates a Amazon Connect client add-in.\n\nUse this action to update the name and endpoint URL of a Amazon Connect client\nadd-in.","ref":"AWS.WorkSpaces.html#update_connect_client_add_in/3","title":"AWS.WorkSpaces.update_connect_client_add_in/3","type":"function"},{"doc":"Shares or unshares a connection alias with one account by specifying whether\nthat account has permission to associate the connection alias with a directory.\n\nIf the association permission is granted, the connection alias is shared with\nthat account. If the association permission is revoked, the connection alias is\nunshared with the account. For more information, see [ Cross-Region Redirection for Amazon\nWorkSpaces](https://docs.aws.amazon.com/workspaces/latest/adminguide/cross-region-redirection.html).\n\n   Before performing this operation, call [\nDescribeConnectionAliases](https://docs.aws.amazon.com/workspaces/latest/api/API_DescribeConnectionAliases.html)\nto make sure that the current state of the connection alias is `CREATED`.\n\n   To delete a connection alias that has been shared, the shared\naccount must first disassociate the connection alias from any directories it has\nbeen associated with. Then you must unshare the connection alias from the\naccount it has been shared with. You can delete a connection alias only after it\nis no longer shared with any accounts or associated with any directories.","ref":"AWS.WorkSpaces.html#update_connection_alias_permission/3","title":"AWS.WorkSpaces.update_connection_alias_permission/3","type":"function"},{"doc":"Replaces the current rules of the specified IP access control group with the\nspecified rules.","ref":"AWS.WorkSpaces.html#update_rules_of_ip_group/3","title":"AWS.WorkSpaces.update_rules_of_ip_group/3","type":"function"},{"doc":"Updates a WorkSpace bundle with a new image.\n\nFor more information about updating WorkSpace bundles, see [ Update a Custom WorkSpaces\nBundle](https://docs.aws.amazon.com/workspaces/latest/adminguide/update-custom-bundle.html).\n\nExisting WorkSpaces aren't automatically updated when you update the bundle that\nthey're based on. To update existing WorkSpaces that are based on a bundle that\nyou've updated, you must either rebuild the WorkSpaces or delete and recreate\nthem.","ref":"AWS.WorkSpaces.html#update_workspace_bundle/3","title":"AWS.WorkSpaces.update_workspace_bundle/3","type":"function"},{"doc":"Shares or unshares an image with one account in the same Amazon Web Services\nRegion by specifying whether that account has permission to copy the image.\n\nIf the copy image permission is granted, the image is shared with that account.\nIf the copy image permission is revoked, the image is unshared with the account.\n\nAfter an image has been shared, the recipient account can copy the image to\nother Regions as needed.\n\nIn the China (Ningxia) Region, you can copy images only within the same Region.\n\nIn Amazon Web Services GovCloud (US), to copy images to and from other Regions,\ncontact Amazon Web Services Support.\n\nFor more information about sharing images, see [ Share or Unshare a Custom WorkSpaces\nImage](https://docs.aws.amazon.com/workspaces/latest/adminguide/share-custom-image.html).\n\n   To delete an image that has been shared, you must unshare the image\nbefore you delete it.\n\n   Sharing Bring Your Own License (BYOL) images across Amazon Web\nServices accounts isn't supported at this time in Amazon Web Services GovCloud\n(US). To share BYOL images across accounts in Amazon Web Services GovCloud (US),\ncontact Amazon Web Services Support.","ref":"AWS.WorkSpaces.html#update_workspace_image_permission/3","title":"AWS.WorkSpaces.update_workspace_image_permission/3","type":"function"},{"doc":"Amazon WorkSpaces Thin Client is a affordable device built to work with Amazon\nWeb Services End User Computing (EUC) virtual desktops to provide users with a\ncomplete cloud desktop solution.\n\nWorkSpaces Thin Client is a compact device designed to connect up to two\nmonitors and USB devices like a keyboard, mouse, headset, and webcam. To\nmaximize endpoint security, WorkSpaces Thin Client devices do not allow local\ndata storage or installation of unapproved applications. The WorkSpaces Thin\nClient device ships preloaded with device management software.\n\nYou can use these APIs to complete WorkSpaces Thin Client tasks, such as\ncreating environments or viewing devices. For more information about WorkSpaces\nThin Client, including the required permissions to use the service, see the\n[Amazon WorkSpaces Thin Client Administrator Guide](https://docs.aws.amazon.com/workspaces-thin-client/latest/ag/). For more\ninformation about using the Command Line Interface (CLI) to manage your\nWorkSpaces Thin Client resources, see the [WorkSpaces Thin Client section of the CLI\nReference](https://docs.aws.amazon.com/cli/latest/reference/workspaces-thin-client/index.html).","ref":"AWS.WorkSpacesThinClient.html","title":"AWS.WorkSpacesThinClient","type":"module"},{"doc":"Creates an environment for your thin client devices.","ref":"AWS.WorkSpacesThinClient.html#create_environment/3","title":"AWS.WorkSpacesThinClient.create_environment/3","type":"function"},{"doc":"Deletes a thin client device.","ref":"AWS.WorkSpacesThinClient.html#delete_device/4","title":"AWS.WorkSpacesThinClient.delete_device/4","type":"function"},{"doc":"Deletes an environment.","ref":"AWS.WorkSpacesThinClient.html#delete_environment/4","title":"AWS.WorkSpacesThinClient.delete_environment/4","type":"function"},{"doc":"Deregisters a thin client device.","ref":"AWS.WorkSpacesThinClient.html#deregister_device/4","title":"AWS.WorkSpacesThinClient.deregister_device/4","type":"function"},{"doc":"Returns information for a thin client device.","ref":"AWS.WorkSpacesThinClient.html#get_device/3","title":"AWS.WorkSpacesThinClient.get_device/3","type":"function"},{"doc":"Returns information for an environment.","ref":"AWS.WorkSpacesThinClient.html#get_environment/3","title":"AWS.WorkSpacesThinClient.get_environment/3","type":"function"},{"doc":"Returns information for a software set.","ref":"AWS.WorkSpacesThinClient.html#get_software_set/3","title":"AWS.WorkSpacesThinClient.get_software_set/3","type":"function"},{"doc":"Returns a list of thin client devices.","ref":"AWS.WorkSpacesThinClient.html#list_devices/4","title":"AWS.WorkSpacesThinClient.list_devices/4","type":"function"},{"doc":"Returns a list of environments.","ref":"AWS.WorkSpacesThinClient.html#list_environments/4","title":"AWS.WorkSpacesThinClient.list_environments/4","type":"function"},{"doc":"Returns a list of software sets.","ref":"AWS.WorkSpacesThinClient.html#list_software_sets/4","title":"AWS.WorkSpacesThinClient.list_software_sets/4","type":"function"},{"doc":"Returns a list of tags for a resource.","ref":"AWS.WorkSpacesThinClient.html#list_tags_for_resource/3","title":"AWS.WorkSpacesThinClient.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.WorkSpacesThinClient.html#metadata/0","title":"AWS.WorkSpacesThinClient.metadata/0","type":"function"},{"doc":"Assigns one or more tags (key-value pairs) to the specified resource.","ref":"AWS.WorkSpacesThinClient.html#tag_resource/4","title":"AWS.WorkSpacesThinClient.tag_resource/4","type":"function"},{"doc":"Removes a tag or tags from a resource.","ref":"AWS.WorkSpacesThinClient.html#untag_resource/4","title":"AWS.WorkSpacesThinClient.untag_resource/4","type":"function"},{"doc":"Updates a thin client device.","ref":"AWS.WorkSpacesThinClient.html#update_device/4","title":"AWS.WorkSpacesThinClient.update_device/4","type":"function"},{"doc":"Updates an environment.","ref":"AWS.WorkSpacesThinClient.html#update_environment/4","title":"AWS.WorkSpacesThinClient.update_environment/4","type":"function"},{"doc":"Updates a software set.","ref":"AWS.WorkSpacesThinClient.html#update_software_set/4","title":"AWS.WorkSpacesThinClient.update_software_set/4","type":"function"},{"doc":"WorkSpaces Web is a low cost, fully managed WorkSpace built specifically to\nfacilitate secure, web-based workloads.\n\nWorkSpaces Web makes it easy for customers to safely provide their employees\nwith access to internal websites and SaaS web applications without the\nadministrative burden of appliances or specialized client software. WorkSpaces\nWeb provides simple policy tools tailored for user interactions, while\noffloading common tasks like capacity management, scaling, and maintaining\nbrowser images.","ref":"AWS.WorkSpacesWeb.html","title":"AWS.WorkSpacesWeb","type":"module"},{"doc":"Associates a browser settings resource with a web portal.","ref":"AWS.WorkSpacesWeb.html#associate_browser_settings/4","title":"AWS.WorkSpacesWeb.associate_browser_settings/4","type":"function"},{"doc":"Associates an IP access settings resource with a web portal.","ref":"AWS.WorkSpacesWeb.html#associate_ip_access_settings/4","title":"AWS.WorkSpacesWeb.associate_ip_access_settings/4","type":"function"},{"doc":"Associates a network settings resource with a web portal.","ref":"AWS.WorkSpacesWeb.html#associate_network_settings/4","title":"AWS.WorkSpacesWeb.associate_network_settings/4","type":"function"},{"doc":"Associates a trust store with a web portal.","ref":"AWS.WorkSpacesWeb.html#associate_trust_store/4","title":"AWS.WorkSpacesWeb.associate_trust_store/4","type":"function"},{"doc":"Associates a user access logging settings resource with a web portal.","ref":"AWS.WorkSpacesWeb.html#associate_user_access_logging_settings/4","title":"AWS.WorkSpacesWeb.associate_user_access_logging_settings/4","type":"function"},{"doc":"Associates a user settings resource with a web portal.","ref":"AWS.WorkSpacesWeb.html#associate_user_settings/4","title":"AWS.WorkSpacesWeb.associate_user_settings/4","type":"function"},{"doc":"Creates a browser settings resource that can be associated with a web portal.\n\nOnce associated with a web portal, browser settings control how the browser will\nbehave once a user starts a streaming session for the web portal.","ref":"AWS.WorkSpacesWeb.html#create_browser_settings/3","title":"AWS.WorkSpacesWeb.create_browser_settings/3","type":"function"},{"doc":"Creates an identity provider resource that is then associated with a web portal.","ref":"AWS.WorkSpacesWeb.html#create_identity_provider/3","title":"AWS.WorkSpacesWeb.create_identity_provider/3","type":"function"},{"doc":"Creates an IP access settings resource that can be associated with a web portal.","ref":"AWS.WorkSpacesWeb.html#create_ip_access_settings/3","title":"AWS.WorkSpacesWeb.create_ip_access_settings/3","type":"function"},{"doc":"Creates a network settings resource that can be associated with a web portal.\n\nOnce associated with a web portal, network settings define how streaming\ninstances will connect with your specified VPC.","ref":"AWS.WorkSpacesWeb.html#create_network_settings/3","title":"AWS.WorkSpacesWeb.create_network_settings/3","type":"function"},{"doc":"Creates a web portal.","ref":"AWS.WorkSpacesWeb.html#create_portal/3","title":"AWS.WorkSpacesWeb.create_portal/3","type":"function"},{"doc":"Creates a trust store that can be associated with a web portal.\n\nA trust store contains certificate authority (CA) certificates. Once associated\nwith a web portal, the browser in a streaming session will recognize\ncertificates that have been issued using any of the CAs in the trust store. If\nyour organization has internal websites that use certificates issued by private\nCAs, you should add the private CA certificate to the trust store.","ref":"AWS.WorkSpacesWeb.html#create_trust_store/3","title":"AWS.WorkSpacesWeb.create_trust_store/3","type":"function"},{"doc":"Creates a user access logging settings resource that can be associated with a\nweb portal.","ref":"AWS.WorkSpacesWeb.html#create_user_access_logging_settings/3","title":"AWS.WorkSpacesWeb.create_user_access_logging_settings/3","type":"function"},{"doc":"Creates a user settings resource that can be associated with a web portal.\n\nOnce associated with a web portal, user settings control how users can transfer\ndata between a streaming session and the their local devices.","ref":"AWS.WorkSpacesWeb.html#create_user_settings/3","title":"AWS.WorkSpacesWeb.create_user_settings/3","type":"function"},{"doc":"Deletes browser settings.","ref":"AWS.WorkSpacesWeb.html#delete_browser_settings/4","title":"AWS.WorkSpacesWeb.delete_browser_settings/4","type":"function"},{"doc":"Deletes the identity provider.","ref":"AWS.WorkSpacesWeb.html#delete_identity_provider/4","title":"AWS.WorkSpacesWeb.delete_identity_provider/4","type":"function"},{"doc":"Deletes IP access settings.","ref":"AWS.WorkSpacesWeb.html#delete_ip_access_settings/4","title":"AWS.WorkSpacesWeb.delete_ip_access_settings/4","type":"function"},{"doc":"Deletes network settings.","ref":"AWS.WorkSpacesWeb.html#delete_network_settings/4","title":"AWS.WorkSpacesWeb.delete_network_settings/4","type":"function"},{"doc":"Deletes a web portal.","ref":"AWS.WorkSpacesWeb.html#delete_portal/4","title":"AWS.WorkSpacesWeb.delete_portal/4","type":"function"},{"doc":"Deletes the trust store.","ref":"AWS.WorkSpacesWeb.html#delete_trust_store/4","title":"AWS.WorkSpacesWeb.delete_trust_store/4","type":"function"},{"doc":"Deletes user access logging settings.","ref":"AWS.WorkSpacesWeb.html#delete_user_access_logging_settings/4","title":"AWS.WorkSpacesWeb.delete_user_access_logging_settings/4","type":"function"},{"doc":"Deletes user settings.","ref":"AWS.WorkSpacesWeb.html#delete_user_settings/4","title":"AWS.WorkSpacesWeb.delete_user_settings/4","type":"function"},{"doc":"Disassociates browser settings from a web portal.","ref":"AWS.WorkSpacesWeb.html#disassociate_browser_settings/4","title":"AWS.WorkSpacesWeb.disassociate_browser_settings/4","type":"function"},{"doc":"Disassociates IP access settings from a web portal.","ref":"AWS.WorkSpacesWeb.html#disassociate_ip_access_settings/4","title":"AWS.WorkSpacesWeb.disassociate_ip_access_settings/4","type":"function"},{"doc":"Disassociates network settings from a web portal.","ref":"AWS.WorkSpacesWeb.html#disassociate_network_settings/4","title":"AWS.WorkSpacesWeb.disassociate_network_settings/4","type":"function"},{"doc":"Disassociates a trust store from a web portal.","ref":"AWS.WorkSpacesWeb.html#disassociate_trust_store/4","title":"AWS.WorkSpacesWeb.disassociate_trust_store/4","type":"function"},{"doc":"Disassociates user access logging settings from a web portal.","ref":"AWS.WorkSpacesWeb.html#disassociate_user_access_logging_settings/4","title":"AWS.WorkSpacesWeb.disassociate_user_access_logging_settings/4","type":"function"},{"doc":"Disassociates user settings from a web portal.","ref":"AWS.WorkSpacesWeb.html#disassociate_user_settings/4","title":"AWS.WorkSpacesWeb.disassociate_user_settings/4","type":"function"},{"doc":"Gets browser settings.","ref":"AWS.WorkSpacesWeb.html#get_browser_settings/3","title":"AWS.WorkSpacesWeb.get_browser_settings/3","type":"function"},{"doc":"Gets the identity provider.","ref":"AWS.WorkSpacesWeb.html#get_identity_provider/3","title":"AWS.WorkSpacesWeb.get_identity_provider/3","type":"function"},{"doc":"Gets the IP access settings.","ref":"AWS.WorkSpacesWeb.html#get_ip_access_settings/3","title":"AWS.WorkSpacesWeb.get_ip_access_settings/3","type":"function"},{"doc":"Gets the network settings.","ref":"AWS.WorkSpacesWeb.html#get_network_settings/3","title":"AWS.WorkSpacesWeb.get_network_settings/3","type":"function"},{"doc":"Gets the web portal.","ref":"AWS.WorkSpacesWeb.html#get_portal/3","title":"AWS.WorkSpacesWeb.get_portal/3","type":"function"},{"doc":"Gets the service provider metadata.","ref":"AWS.WorkSpacesWeb.html#get_portal_service_provider_metadata/3","title":"AWS.WorkSpacesWeb.get_portal_service_provider_metadata/3","type":"function"},{"doc":"Gets the trust store.","ref":"AWS.WorkSpacesWeb.html#get_trust_store/3","title":"AWS.WorkSpacesWeb.get_trust_store/3","type":"function"},{"doc":"Gets the trust store certificate.","ref":"AWS.WorkSpacesWeb.html#get_trust_store_certificate/4","title":"AWS.WorkSpacesWeb.get_trust_store_certificate/4","type":"function"},{"doc":"Gets user access logging settings.","ref":"AWS.WorkSpacesWeb.html#get_user_access_logging_settings/3","title":"AWS.WorkSpacesWeb.get_user_access_logging_settings/3","type":"function"},{"doc":"Gets user settings.","ref":"AWS.WorkSpacesWeb.html#get_user_settings/3","title":"AWS.WorkSpacesWeb.get_user_settings/3","type":"function"},{"doc":"Retrieves a list of browser settings.","ref":"AWS.WorkSpacesWeb.html#list_browser_settings/4","title":"AWS.WorkSpacesWeb.list_browser_settings/4","type":"function"},{"doc":"Retrieves a list of identity providers for a specific web portal.","ref":"AWS.WorkSpacesWeb.html#list_identity_providers/5","title":"AWS.WorkSpacesWeb.list_identity_providers/5","type":"function"},{"doc":"Retrieves a list of IP access settings.","ref":"AWS.WorkSpacesWeb.html#list_ip_access_settings/4","title":"AWS.WorkSpacesWeb.list_ip_access_settings/4","type":"function"},{"doc":"Retrieves a list of network settings.","ref":"AWS.WorkSpacesWeb.html#list_network_settings/4","title":"AWS.WorkSpacesWeb.list_network_settings/4","type":"function"},{"doc":"Retrieves a list or web portals.","ref":"AWS.WorkSpacesWeb.html#list_portals/4","title":"AWS.WorkSpacesWeb.list_portals/4","type":"function"},{"doc":"Retrieves a list of tags for a resource.","ref":"AWS.WorkSpacesWeb.html#list_tags_for_resource/3","title":"AWS.WorkSpacesWeb.list_tags_for_resource/3","type":"function"},{"doc":"Retrieves a list of trust store certificates.","ref":"AWS.WorkSpacesWeb.html#list_trust_store_certificates/5","title":"AWS.WorkSpacesWeb.list_trust_store_certificates/5","type":"function"},{"doc":"Retrieves a list of trust stores.","ref":"AWS.WorkSpacesWeb.html#list_trust_stores/4","title":"AWS.WorkSpacesWeb.list_trust_stores/4","type":"function"},{"doc":"Retrieves a list of user access logging settings.","ref":"AWS.WorkSpacesWeb.html#list_user_access_logging_settings/4","title":"AWS.WorkSpacesWeb.list_user_access_logging_settings/4","type":"function"},{"doc":"Retrieves a list of user settings.","ref":"AWS.WorkSpacesWeb.html#list_user_settings/4","title":"AWS.WorkSpacesWeb.list_user_settings/4","type":"function"},{"doc":"","ref":"AWS.WorkSpacesWeb.html#metadata/0","title":"AWS.WorkSpacesWeb.metadata/0","type":"function"},{"doc":"Adds or overwrites one or more tags for the specified resource.","ref":"AWS.WorkSpacesWeb.html#tag_resource/4","title":"AWS.WorkSpacesWeb.tag_resource/4","type":"function"},{"doc":"Removes one or more tags from the specified resource.","ref":"AWS.WorkSpacesWeb.html#untag_resource/4","title":"AWS.WorkSpacesWeb.untag_resource/4","type":"function"},{"doc":"Updates browser settings.","ref":"AWS.WorkSpacesWeb.html#update_browser_settings/4","title":"AWS.WorkSpacesWeb.update_browser_settings/4","type":"function"},{"doc":"Updates the identity provider.","ref":"AWS.WorkSpacesWeb.html#update_identity_provider/4","title":"AWS.WorkSpacesWeb.update_identity_provider/4","type":"function"},{"doc":"Updates IP access settings.","ref":"AWS.WorkSpacesWeb.html#update_ip_access_settings/4","title":"AWS.WorkSpacesWeb.update_ip_access_settings/4","type":"function"},{"doc":"Updates network settings.","ref":"AWS.WorkSpacesWeb.html#update_network_settings/4","title":"AWS.WorkSpacesWeb.update_network_settings/4","type":"function"},{"doc":"Updates a web portal.","ref":"AWS.WorkSpacesWeb.html#update_portal/4","title":"AWS.WorkSpacesWeb.update_portal/4","type":"function"},{"doc":"Updates the trust store.","ref":"AWS.WorkSpacesWeb.html#update_trust_store/4","title":"AWS.WorkSpacesWeb.update_trust_store/4","type":"function"},{"doc":"Updates the user access logging settings.","ref":"AWS.WorkSpacesWeb.html#update_user_access_logging_settings/4","title":"AWS.WorkSpacesWeb.update_user_access_logging_settings/4","type":"function"},{"doc":"Updates the user settings.","ref":"AWS.WorkSpacesWeb.html#update_user_settings/4","title":"AWS.WorkSpacesWeb.update_user_settings/4","type":"function"},{"doc":"Amazon Web Services X-Ray provides APIs for managing debug traces and retrieving\nservice maps and other data created by processing those traces.","ref":"AWS.XRay.html","title":"AWS.XRay","type":"module"},{"doc":"Retrieves a list of traces specified by ID.\n\nEach trace is a collection of segment documents that originates from a single\nrequest. Use `GetTraceSummaries` to get a list of trace IDs.","ref":"AWS.XRay.html#batch_get_traces/3","title":"AWS.XRay.batch_get_traces/3","type":"function"},{"doc":"Creates a group resource with a name and a filter expression.","ref":"AWS.XRay.html#create_group/3","title":"AWS.XRay.create_group/3","type":"function"},{"doc":"Creates a rule to control sampling behavior for instrumented applications.\n\nServices retrieve rules with\n[GetSamplingRules](https://docs.aws.amazon.com/xray/latest/api/API_GetSamplingRules.html), and evaluate each rule in ascending order of *priority* for each request. If a\nrule matches, the service records a trace, borrowing it from the reservoir size.\nAfter 10 seconds, the service reports back to X-Ray with\n[GetSamplingTargets](https://docs.aws.amazon.com/xray/latest/api/API_GetSamplingTargets.html)\nto get updated versions of each in-use rule. The updated rule contains a trace\nquota that the service can use instead of borrowing from the reservoir.","ref":"AWS.XRay.html#create_sampling_rule/3","title":"AWS.XRay.create_sampling_rule/3","type":"function"},{"doc":"Deletes a group resource.","ref":"AWS.XRay.html#delete_group/3","title":"AWS.XRay.delete_group/3","type":"function"},{"doc":"Deletes a resource policy from the target Amazon Web Services account.","ref":"AWS.XRay.html#delete_resource_policy/3","title":"AWS.XRay.delete_resource_policy/3","type":"function"},{"doc":"Deletes a sampling rule.","ref":"AWS.XRay.html#delete_sampling_rule/3","title":"AWS.XRay.delete_sampling_rule/3","type":"function"},{"doc":"Retrieves the current encryption configuration for X-Ray data.","ref":"AWS.XRay.html#get_encryption_config/3","title":"AWS.XRay.get_encryption_config/3","type":"function"},{"doc":"Retrieves group resource details.","ref":"AWS.XRay.html#get_group/3","title":"AWS.XRay.get_group/3","type":"function"},{"doc":"Retrieves all active group details.","ref":"AWS.XRay.html#get_groups/3","title":"AWS.XRay.get_groups/3","type":"function"},{"doc":"Retrieves the summary information of an insight.\n\nThis includes impact to clients and root cause services, the top anomalous\nservices, the category, the state of the insight, and the start and end time of\nthe insight.","ref":"AWS.XRay.html#get_insight/3","title":"AWS.XRay.get_insight/3","type":"function"},{"doc":"X-Ray reevaluates insights periodically until they're resolved, and records each\nintermediate state as an event.\n\nYou can review an insight's events in the Impact Timeline on the Inspect page in\nthe X-Ray console.","ref":"AWS.XRay.html#get_insight_events/3","title":"AWS.XRay.get_insight_events/3","type":"function"},{"doc":"Retrieves a service graph structure filtered by the specified insight.\n\nThe service graph is limited to only structural information. For a complete\nservice graph, use this API with the GetServiceGraph API.","ref":"AWS.XRay.html#get_insight_impact_graph/3","title":"AWS.XRay.get_insight_impact_graph/3","type":"function"},{"doc":"Retrieves the summaries of all insights in the specified group matching the\nprovided filter values.","ref":"AWS.XRay.html#get_insight_summaries/3","title":"AWS.XRay.get_insight_summaries/3","type":"function"},{"doc":"Retrieves all sampling rules.","ref":"AWS.XRay.html#get_sampling_rules/3","title":"AWS.XRay.get_sampling_rules/3","type":"function"},{"doc":"Retrieves information about recent sampling results for all sampling rules.","ref":"AWS.XRay.html#get_sampling_statistic_summaries/3","title":"AWS.XRay.get_sampling_statistic_summaries/3","type":"function"},{"doc":"Requests a sampling quota for rules that the service is using to sample\nrequests.","ref":"AWS.XRay.html#get_sampling_targets/3","title":"AWS.XRay.get_sampling_targets/3","type":"function"},{"doc":"Retrieves a document that describes services that process incoming requests, and\ndownstream services that they call as a result.\n\nRoot services process incoming requests and make calls to downstream services.\nRoot services are applications that use the [Amazon Web Services X-Ray SDK](https://docs.aws.amazon.com/xray/index.html). Downstream services can be\nother applications, Amazon Web Services resources, HTTP web APIs, or SQL\ndatabases.","ref":"AWS.XRay.html#get_service_graph/3","title":"AWS.XRay.get_service_graph/3","type":"function"},{"doc":"Get an aggregation of service statistics defined by a specific time range.","ref":"AWS.XRay.html#get_time_series_service_statistics/3","title":"AWS.XRay.get_time_series_service_statistics/3","type":"function"},{"doc":"Retrieves a service graph for one or more specific trace IDs.","ref":"AWS.XRay.html#get_trace_graph/3","title":"AWS.XRay.get_trace_graph/3","type":"function"},{"doc":"Retrieves IDs and annotations for traces available for a specified time frame\nusing an optional filter.\n\nTo get the full traces, pass the trace IDs to `BatchGetTraces`.\n\nA filter expression can target traced requests that hit specific service nodes\nor edges, have errors, or come from a known user. For example, the following\nfilter expression targets traces that pass through `api.example.com`:\n\n`service(\"api.example.com\")`\n\nThis filter expression finds traces that have an annotation named `account` with\nthe value `12345`:\n\n`annotation.account = \"12345\"`\n\nFor a full list of indexed fields and keywords that you can use in filter\nexpressions, see [Using Filter Expressions](https://docs.aws.amazon.com/xray/latest/devguide/xray-console-filters.html)\nin the *Amazon Web Services X-Ray Developer Guide*.","ref":"AWS.XRay.html#get_trace_summaries/3","title":"AWS.XRay.get_trace_summaries/3","type":"function"},{"doc":"Returns the list of resource policies in the target Amazon Web Services account.","ref":"AWS.XRay.html#list_resource_policies/3","title":"AWS.XRay.list_resource_policies/3","type":"function"},{"doc":"Returns a list of tags that are applied to the specified Amazon Web Services\nX-Ray group or sampling rule.","ref":"AWS.XRay.html#list_tags_for_resource/3","title":"AWS.XRay.list_tags_for_resource/3","type":"function"},{"doc":"","ref":"AWS.XRay.html#metadata/0","title":"AWS.XRay.metadata/0","type":"function"},{"doc":"Updates the encryption configuration for X-Ray data.","ref":"AWS.XRay.html#put_encryption_config/3","title":"AWS.XRay.put_encryption_config/3","type":"function"},{"doc":"Sets the resource policy to grant one or more Amazon Web Services services and\naccounts permissions to access X-Ray.\n\nEach resource policy will be associated with a specific Amazon Web Services\naccount. Each Amazon Web Services account can have a maximum of 5 resource\npolicies, and each policy name must be unique within that account. The maximum\nsize of each resource policy is 5KB.","ref":"AWS.XRay.html#put_resource_policy/3","title":"AWS.XRay.put_resource_policy/3","type":"function"},{"doc":"Used by the Amazon Web Services X-Ray daemon to upload telemetry.","ref":"AWS.XRay.html#put_telemetry_records/3","title":"AWS.XRay.put_telemetry_records/3","type":"function"},{"doc":"Uploads segment documents to Amazon Web Services X-Ray.\n\nThe [X-Ray SDK](https://docs.aws.amazon.com/xray/index.html) generates segment documents and sends them to the X-Ray daemon, which uploads them in batches. A\nsegment document can be a completed segment, an in-progress segment, or an array\nof subsegments.\n\nSegments must include the following fields. For the full segment document\nschema, see [Amazon Web Services X-Ray Segment\nDocuments](https://docs.aws.amazon.com/xray/latest/devguide/xray-api-segmentdocuments.html)\nin the *Amazon Web Services X-Ray Developer Guide*.","ref":"AWS.XRay.html#put_trace_segments/3","title":"AWS.XRay.put_trace_segments/3","type":"function"},{"doc":"* `name` - The name of the service that handled the request.\n\n  * `id` - A 64-bit identifier for the segment, unique among segments\nin the same trace, in 16 hexadecimal digits.\n\n  * `trace_id` - A unique identifier that connects all segments and\nsubsegments originating from a single client request.\n\n  * `start_time` - Time the segment or subsegment was created, in\nfloating point seconds in epoch time, accurate to milliseconds. For example,\n`1480615200.010` or `1.480615200010E9`.\n\n  * `end_time` - Time the segment or subsegment was closed. For\nexample, `1480615200.090` or `1.480615200090E9`. Specify either an `end_time` or\n`in_progress`.\n\n  * `in_progress` - Set to `true` instead of specifying an `end_time`\nto record that a segment has been started, but is not complete. Send an\nin-progress segment when your application receives a request that will take a\nlong time to serve, to trace that the request was received. When the response is\nsent, send the complete segment to overwrite the in-progress segment.\n\nA `trace_id` consists of three numbers separated by hyphens. For example,\n1-58406520-a006649127e371903a2de979. This includes:","ref":"AWS.XRay.html#put_trace_segments/3-required-segment-document-fields","title":"Required segment document fields - AWS.XRay.put_trace_segments/3","type":"function"},{"doc":"* The version number, for instance, `1`.\n\n  * The time of the original request, in Unix epoch time, in 8\nhexadecimal digits. For example, 10:00AM December 2nd, 2016 PST in epoch time is\n`1480615200` seconds, or `58406520` in hexadecimal.\n\n  * A 96-bit identifier for the trace, globally unique, in 24\nhexadecimal digits.","ref":"AWS.XRay.html#put_trace_segments/3-trace-id-format","title":"Trace ID Format - AWS.XRay.put_trace_segments/3","type":"function"},{"doc":"Applies tags to an existing Amazon Web Services X-Ray group or sampling rule.","ref":"AWS.XRay.html#tag_resource/3","title":"AWS.XRay.tag_resource/3","type":"function"},{"doc":"Removes tags from an Amazon Web Services X-Ray group or sampling rule.\n\nYou cannot edit or delete system tags (those with an `aws:` prefix).","ref":"AWS.XRay.html#untag_resource/3","title":"AWS.XRay.untag_resource/3","type":"function"},{"doc":"Updates a group resource.","ref":"AWS.XRay.html#update_group/3","title":"AWS.XRay.update_group/3","type":"function"},{"doc":"Modifies a sampling rule's configuration.","ref":"AWS.XRay.html#update_sampling_rule/3","title":"AWS.XRay.update_sampling_rule/3","type":"function"},{"doc":"AWS provides an API to talk with Amazon Web Services.\n\nEach module in this project corresponds with an AWS service,\nand they can be used by calling the functions of those\nmodules. For example, \"AWS DynamoDB\" operations can be found\nin `AWS.DynamoDB` module.\n\nFirst we need to setup a `AWS.Client` structure with credentials\nand details about the region we want to use.\n\n    client = %AWS.Client{\n      access_key_id: \" \",\n      secret_access_key: \" \",\n      region: \"us-east-1\"\n    }\n\nAlternatively you can create a `client` with `AWS.Client.create/3`.\nCheck more options for configuration at `AWS.Client` docs.\n\nSo we pass this client struct to our service modules:\n\n    {:ok, result, _http_response} = AWS.Kinesis.list_streams(client, %{})\n\nThe second argument in this case is the `input` which is a map with\nthe parameters for [this operation](https://docs.aws.amazon.com/kinesis/latest/APIReference/API_ListStreams.html).\n\nAnother example is the upload of a given file to `AWS.S3` using `AWS.S3.put_object/5`:\n\n    client = AWS.Client.create(\"your-access-key-id\", \"your-secret-access-key\", \"us-east-1\")\n    file =  File.read!(\"./tmp/your-file.txt\")\n    md5 = :crypto.hash(:md5, file) |> Base.encode64()\n\n    AWS.S3.put_object(client, \"your-bucket-name\", \"foo/your-file-on-s3.txt\", %{\"Body\" => file, \"ContentMD5\" => md5})\n\nYou can find more details about those parameters in the [AWS API reference](https://docs.aws.amazon.com/index.html).","ref":"AWS.html","title":"AWS","type":"module"},{"doc":"You can customize your HTTP client or the module responsible for parsing\nand encoding JSON or XML by using options for the `AWS.Client`.\n\nBy default, AWS Elixir uses hackney for the HTTP client, Jason for JSON,\nand a custom module for XML that is written on top of xmlerl.\nFor more details, check `AWS.Client` documentation.","ref":"AWS.html#module-custom-http-client-and-json-xml-parsers","title":"Custom HTTP client and JSON/XML parsers - AWS","type":"module"},{"doc":"Provides credentials and connection details for making requests to AWS services.\n\nYou can configure `access_key_id` and `secret_access_key` which are the credentials\nneeded by [IAM](https://aws.amazon.com/iam), and also the `region` for your services.\nThe list of regions can be found in the [AWS service endpoints](https://docs.aws.amazon.com/general/latest/gr/rande.html)\ndocumentation. You can also use \"local\" to make requests to your localhost.","ref":"AWS.Client.html","title":"AWS.Client","type":"module"},{"doc":"The option `http_client` accepts a tuple with a module and a list of options.\nThe module must implement the callback `c:AWS.HTTPClient.request/5`.","ref":"AWS.Client.html#module-custom-http-client","title":"Custom HTTP client - AWS.Client","type":"module"},{"doc":"You can configure a custom JSON parser by using the option `json_module`. This\noption accepts a tuple with a module and options. The given module must\nimplement the callbacks from `AWS.JSON`.\n\nSimilarly, there is a `xml_module` option that configures the XML parser. The\nXML module must implement the callbacks from `AWS.XML`.","ref":"AWS.Client.html#module-custom-json-or-xml-parsers","title":"Custom JSON or XML parsers - AWS.Client","type":"module"},{"doc":"* `:session_token` - an option to set the `X-Amz-Security-Token` when performing\n  the requests.\n* `:port` - is the port to use when making requests. Defaults to `443`.\n* `:proto` - is the protocol to use. It can be \"http\" or \"https\". Defaults to `\"https\"`.\n* `:endpoint` - the AWS endpoint. Defaults to `\"amazonaws.com\"`. You can configure this\nusing `put_endpoint/2` for AWS compatible APIs.\n\nThe `service` option is overwritten by each service with its signing name from metadata.","ref":"AWS.Client.html#module-additional-options","title":"Additional options - AWS.Client","type":"module"},{"doc":"","ref":"AWS.Client.html#create/0","title":"AWS.Client.create/0","type":"function"},{"doc":"","ref":"AWS.Client.html#create/1","title":"AWS.Client.create/1","type":"function"},{"doc":"","ref":"AWS.Client.html#create/3","title":"AWS.Client.create/3","type":"function"},{"doc":"","ref":"AWS.Client.html#create/4","title":"AWS.Client.create/4","type":"function"},{"doc":"","ref":"AWS.Client.html#decode!/3","title":"AWS.Client.decode!/3","type":"function"},{"doc":"The default endpoint.\n\nCheck `put_endpoint/2` for more details on how to configure\na custom endpoint.","ref":"AWS.Client.html#default_endpoint/0","title":"AWS.Client.default_endpoint/0","type":"function"},{"doc":"","ref":"AWS.Client.html#encode!/3","title":"AWS.Client.encode!/3","type":"function"},{"doc":"Configures the endpoint to a custom one.\n\nThis is useful to set a custom endpoint when working with AWS\ncompatible APIs.\nThe following configuration is valid:\n\n* `\"example.com\"`: this will be used as it is, without considering\nregions or endpoint prefixes or account id.\n\n* `{:keep_prefixes, \"example.com\"}`: it will keep the same rules from\nAWS to build the prefixes.\nFor example, if region is \"us-east-1\" and the service prefix is \"s3\",\nthen the final endpoint will be `\"s3.us-east-1.example.com\"`\n\n* `fn options -> \"example.com\" end`: a function that will be invoked\nwith options for that request. `options` is a map with the following\nshape:\n\n    ```\n    %{\n      endpoint: endpoint_config(),\n      region: binary() | nil,\n      service: binary(),\n      global?: boolean(),\n      endpoint_prefix: binary(),\n      account_id: binary() | nil\n    }\n    ```","ref":"AWS.Client.html#put_endpoint/2","title":"AWS.Client.put_endpoint/2","type":"function"},{"doc":"iex> put_endpoint(%Client{}, \"example.com\")\n    %Client{endpoint: \"example.com}\n\n    iex> put_endpoint(%Client{}, {:keep_prefixes, \"example.com\"})\n    %Client{endpoint: {:keep_prefixes, \"example.com}}\n\n    iex> put_endpoint(%Client{}, fn opts -> Enum.join([\"baz\", opts.region, \"foo.com\"], \".\") end)\n    %Client{endpoint: #Function<>}","ref":"AWS.Client.html#put_endpoint/2-examples","title":"Examples - AWS.Client.put_endpoint/2","type":"function"},{"doc":"Configures the HTTP client used by a given client.\n\nSwitches to a different HTTP client, defined by a `{module, opts}` tuple. See\n`AWS.HTTPClient` behavior for more details.\n\n#","ref":"AWS.Client.html#put_http_client/2","title":"AWS.Client.put_http_client/2","type":"function"},{"doc":"iex> AWS.Client.put_http_client(%AWS.Client{}, {MyHTTPClient, []})\n    %AWS.Client{http_client: {MyHTTPClient, []}}\n\n    iex> AWS.Client.put_http_client(%AWS.Client{}, {AWS.HTTPClient.Finch, finch_name: AWS.Finch})\n    %AWS.Client{http_client: {AWS.HTTPClient.Finch, finch_name: AWS.Finch}}","ref":"AWS.Client.html#put_http_client/2-examples","title":"Examples - AWS.Client.put_http_client/2","type":"function"},{"doc":"","ref":"AWS.Client.html#request/6","title":"AWS.Client.request/6","type":"function"},{"doc":"The endpoint configuration.\n\nCheck `put_endpoint/2` for more details.","ref":"AWS.Client.html#t:endpoint_config/0","title":"AWS.Client.endpoint_config/0","type":"type"},{"doc":"","ref":"AWS.Client.html#t:t/0","title":"AWS.Client.t/0","type":"type"},{"doc":"Specifies the behaviour of a HTTP Client.\n\nYou can switch the default HTTP client which uses hackney underneath\nby defining a different implementation by setting the `:http_client`\nconfiguration in `AWS.Client`:\n\n    client = %AWS.Client{http_client: {MyHttpClient, []}}\n    AWS.SNS.publish(client, \"My message\")","ref":"AWS.HTTPClient.html","title":"AWS.HTTPClient","type":"behaviour"},{"doc":"Executes a HTTP request. Either returns {:ok, map} or {:error, reason}.\n\n- `body` is already parsed into iodata. It may be in either JSON or XML format.\n- `headers` already contains required headers such as Authorization. See AWS.Request.sign_v4 for more details.","ref":"AWS.HTTPClient.html#c:request/5","title":"AWS.HTTPClient.request/5","type":"callback"},{"doc":"Finch-based HTTP client for AWS.\n\nIn order to use `Finch` API client, you must start `Finch` and provide a `:name`. In\nyour supervision tree:\n\n    children = [\n      {Finch, name: AWS.Finch}\n    ]\n\nThen build AWS client with the provided `:finch_name`:\n\n    client = %AWS.Client{http_client: {AWS.HTTPClient.Finch, [finch_name: AWS.Finch]}}\n    AWS.SNS.publish(client, \"My message\")\n\nIn case you omit `:finch_name`, it defaults to `AWS.Finch`.","ref":"AWS.HTTPClient.Finch.html","title":"AWS.HTTPClient.Finch","type":"module"},{"doc":"Default hackney-based HTTP client for AWS.","ref":"AWS.HTTPClient.Hackney.html","title":"AWS.HTTPClient.Hackney","type":"module"},{"doc":"Specifies the behaviour of a JSON parser.\n\nYou can switch the default JSON parser which uses Jason underneath\nby defining a different implementation by setting the `:json_module`\nconfiguration in AWS.Client:\n\n    client = %AWS.Client{json_module: MyCustomJSONParser}\n    AWS.SNS.publish(client, %{})","ref":"AWS.JSON.html","title":"AWS.JSON","type":"behaviour"},{"doc":"","ref":"AWS.JSON.html#decode!/2","title":"AWS.JSON.decode!/2","type":"function"},{"doc":"Decodes a JSON into a map. Raises in case of errors.","ref":"AWS.JSON.html#c:decode!/2","title":"AWS.JSON.decode!/2","type":"callback"},{"doc":"","ref":"AWS.JSON.html#encode_to_iodata!/2","title":"AWS.JSON.encode_to_iodata!/2","type":"function"},{"doc":"Encodes a map into JSON iodata. Raises in case of errors.","ref":"AWS.JSON.html#c:encode_to_iodata!/2","title":"AWS.JSON.encode_to_iodata!/2","type":"callback"},{"doc":"Specifies the behaviour of a XML parser.\n\nYou can switch the default XML parser which uses AWS.Util underneath\nby defining a different implementation by setting the `:xml_module`\nconfiguration in `AWS.Client`:\n\n    client = %AWS.Client{xml_module: MyCustomXMLParser}\n    AWS.SNS.publish(client, %{})","ref":"AWS.XML.html","title":"AWS.XML","type":"behaviour"},{"doc":"","ref":"AWS.XML.html#decode!/2","title":"AWS.XML.decode!/2","type":"function"},{"doc":"Decodes a XML into a map. Raises in case of errors.","ref":"AWS.XML.html#c:decode!/2","title":"AWS.XML.decode!/2","type":"callback"},{"doc":"","ref":"AWS.XML.html#encode_to_iodata!/2","title":"AWS.XML.encode_to_iodata!/2","type":"function"},{"doc":"Encodes a map into XML iodata. Raises in case of errors.","ref":"AWS.XML.html#c:encode_to_iodata!/2","title":"AWS.XML.encode_to_iodata!/2","type":"callback"},{"doc":"","ref":"AWS.XML.html#xmlElement/1","title":"AWS.XML.xmlElement/1","type":"macro"},{"doc":"","ref":"AWS.XML.html#xmlElement/2","title":"AWS.XML.xmlElement/2","type":"macro"},{"doc":"","ref":"AWS.XML.html#xmlText/1","title":"AWS.XML.xmlText/1","type":"macro"},{"doc":"","ref":"AWS.XML.html#xmlText/2","title":"AWS.XML.xmlText/2","type":"macro"},{"doc":"# Change Log\n\n## [v0.14.1] - 2024-02-16\n- Fix endpoints for global AWS services\n\n## [v0.14.0] - 2024-01-05\n- Add support for the ec2 protocol\n- Add docs for multipart upload to S3\n- Allow call-site specification of http client options\n\nAll notable changes to this project will be documented in this file.\n## [v0.13.3] - 2023-04-20\n- Skip signature without access_key_id and secret_access_key\n\n## [v0.13.2] - 2023-03-08\n- Fix AWS.S3.delete_objects which requires a content md5 header\n\n## [v0.13.1] - 2022-09-07\n\n#","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"- Fix the generator to commit removed files to the repository.\n  This prevents problems with renamed modules, or removed ones.\n  We also removed the modules with problems.\n\n## [v0.13.0] - 2022-09-02\n\n#","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- Fix services that need a host prefix before the endpoint prefix.\n  This makes services like \"Location\" to work properly.\n\n#","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- Update the AWS generated modules to reflect v1.44.90 of Go SDK. \n  This may cause breaking changes.\n\n## [v0.12.0] - 2022-07-18\n\n#","ref":"changelog.html#changed","title":"Changed - Changelog","type":"extras"},{"doc":"- Fix the encoding of query strings for complex values.\n\n#","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- Update the AWS generated modules to reflect v1.44.60 of Go SDK. \n  This may cause breaking changes.\n\n## [v0.11.0] - 2022-05-24\n\n#","ref":"changelog.html#changed","title":"Changed - Changelog","type":"extras"},{"doc":"- Update the AWS generated modules to reflect v1.44.21 of Go SDK. \n  This may cause breaking changes.\n- Change `aws_signature` requirement to `~> 0.3` in order to support newer versions.\n\n## [v0.10.1] - 2022-02-02\n\n#","ref":"changelog.html#changed","title":"Changed - Changelog","type":"extras"},{"doc":"- Update `AWS.Client` typespecs to accept `nil` for the `endpoint` field.\n- Isolate Hackney connection pool for requests. Now the pool is named `:aws_pool`.\n- Don't display the `:session_token` field when inspecting `AWS.Client`.\n\n## [v0.10.0] - 2021-12-03\n\n#","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- Don't display access key or secret key when inspecting `AWS.Client`.\n- Add the `region` to `AWS.Client.t`\n\n#","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- Update the APIs to the version 1.42.18 of Go SDK. There is a breaking\nchange: `AWS.API.Pricing` changed to `AWS.Pricing`. Several modules were\nadded.\n- Require Elixir ~> 1.10\n\n## [v0.9.2] - 2021-10-27\n\n#","ref":"changelog.html#changed","title":"Changed - Changelog","type":"extras"},{"doc":"- Fix decoding of UTF8 chars when parsing XML responses.\n\n## [v0.9.1] - 2021-10-26\n\n#","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- Fix encode of payload for GET/HEAD/OPTIONS requests. It shouldn't be encoded\nbecause the body should be empty. This fixes a signature error problem.\n\n## [v0.9.0] - 2021-09-01\n\n#","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- Add support for configuring the endpoint used by `AWS.Client`.\nThis change enable the usage of AWS compatible APIs.\n\n#","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"- Move functions and modules related to AWS Signature to a new package\nand add this package - [`aws_signature`](https://hex.pm/packages/aws_signature) - as a new dependency.\n\n#","ref":"changelog.html#changed","title":"Changed - Changelog","type":"extras"},{"doc":"- Fix encode of URIs to use the correct escaping rule.\n\n## [v0.8.0] - 2021-07-18\n#","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- Add support for OTP 24 by updating the usage of `:crypto` functions to the new API.\n- Add support for more services - update to be in sync with [aws-sdk-go 1.40.2](https://github.com/aws/aws-sdk-go/releases/tag/v1.40.2).\n\n#","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"- Change `AWS.Client` port value to an integer instead of string.\n- Use \"us-east-1\" as default region for global services.\n- Improve ExDocs configuration for a better documentation.\n\n#","ref":"changelog.html#changed","title":"Changed - Changelog","type":"extras"},{"doc":"- Skip decoding of \"REST\" responses when body is binary.\n- Fix HEAD requests for the default HTTP client.\n- Fix \"content-type\" for \"REST\" requests that have the body as binary. It uses\n\"application/octet-stream\" now.\n- Fix handle of HTTP status from requests - consider anything in the\nrange of 2xx as successful, but check for exact status if the service requires one.\n- Fix two signature bugs: when the headers are similar and when the canonical URL\nhas colons (:).\n\n## [v0.7.0] - 2020-12-22\n#","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- Add support for more AWS APIs. There are more than 170 new modules, which includes\nthe majority of AWS services.\n- Load AWS credentials from env if available.\n- Add header `X-Amz-Content-SHA256` required for APIs using the rest-xml protocol.\n- Handle querystring parameters.\n- Allow the user to configure the HTTP client, as well as the JSON parser.\n\n#","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"- Update structure of error response from `{:error, {exception, reason}}` to `{:error, {:unexpected_response, response}}`.\n  - You can obtained the previous `exception` and `reason` in this version by decoding the `response.body`, where `exception` is mapped to `response.body[\"__type\"]` and `reason` is mapped to `response.body[\"message\"]`.\n- Update module naming for certain AWS services. E.g.:\n  - `AWS.Cognito` is renamed to `AWS.CognitoIdentity`  \n  - `AWS.Cognito.IdentityProvider` is renamed to `AWS.CognitoIdentityProvider`\n\n#","ref":"changelog.html#backwards-incompatible-changed","title":"Backwards Incompatible Changed - Changelog","type":"extras"},{"doc":"- Improve documentation by using more markdown and removing HTML tags.\n- Rename modules and function names to consider the correct use of abbreviations, like SQS or DB.\n- Migrate to Jason (JSON parser) and hackney (HTTP client) as the default dependencies. Hackney\nis an optional dependency.\n\n#","ref":"changelog.html#changed","title":"Changed - Changelog","type":"extras"},{"doc":"- Fixed the way we send the payload to endpoints that accepts binaries as body (S3\nis an example).\n- Normalize querystring when signing.\n- Remove duplicated headers.\n\n## [v0.6.0] - 2020-08-20\n#","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- Includes support for more AWS APIs.\n\n#","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"- Pass security token for signed POST requests.\n\n## [v0.5.0] - 2017-03-07\n#","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- `AWS.APIGateway` module uses a service URL without a trailing slash\n  (apparently AWS behaviour with regard to URL signing is\n  inconsistent). Thanks Richard Foster (@zuren).\n\n## [v0.4.0] - 2017-03-06\n#","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- `AWS.AppStream` module for AWS AppStream service.\n- `AWS.Batch` module for AWS Batch service.\n- `AWS.Budgets` module for AWS Budgets service.\n- `AWS.CloudDirectory` module for AWS CloudDirectory service.\n- `AWS.CodeBuild` module for AWS CodeBuild service.\n- `AWS.CostAndUsageReport` module for AWS Cost and Usage Report service.\n- `AWS.Health` module for AWS Health service.\n- `AWS.Kinesis.Analytics` module for Kinesis Analytics service.\n- `AWS.LexRuntime` module for AWS Lex Runtime service.\n- `AWS.Lightsail` module for AWS Lightsail service.\n- `AWS.MechanicalTurk` module for AWS Mechanical Turk service.\n- `AWS.OpsWorks.ChefAutomate` module for AWS OpsWorks for Chef Automate\n  service.\n- `AWS.Organizations` module for AWS Organizations service.\n- `AWS.Polly` module for AWS Polly service.\n- `AWS.Rekognition` module for AWS Rekognition service.\n- `AWS.Shield` module for AWS Shield service.\n- `AWS.SMS` moduule for AWS Server Migration service.\n- `AWS.Snowball` module for AWS Snowball service.\n- `AWS.StepFunctions` module for AWS Step Functions service.\n- `AWS.WAF.Regional` module for WAF Regional service.\n- `AWS.XRay` module for AWS X-Ray service.\n\n#","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"- Elixir 1.4 with Erlang 19.1 are the minimally supported versions of Elixir\n  and Erlang/OTP.\n- README has been simplified and improved. Thanks Paulo Ancheta\n  (@pauloancheta).\n- Bumped `httpoison` dependency from `~> 0.10.0` to `~> 0.11.1`. Thanks Wojtek\n  Piekutowski (@wpiekutowski).\n- Bumped `poison` dependency from `~> 1.5 or ~> 2.0` to `~> 3.1`.\n- Bumped `timex` dependency from `~> 2.1` to `~> 3.1`. Thanks Christian\n  Blavier (@cblavier).\n- `AWS.APIGateway` module has updated documentation and support for managing\n  documentation parts and versions, usage plans and keys, getting SDK types\n  and importing API keys.\n- `AWS.AutoScaling` module has updated documentation.\n- `AWS.CertificateManager` module has updated documentation.\n- `AWS.CloudTrail` module has updated documentation and support for event\n  selectors.\n- `AWS.CodeCommit` module has updated documentation and support for blobs and\n  differences.\n- `AWS.CodeDeploy` module has updated documentation and support for skipping\n  wait times before terminating instances in blue/green deployments.\n- `AWS.CodePipeline` module has updated documentation and support for getting\n  pipeline executions.\n- `AWS.Cognito` module has updated documentation.\n- `AWS.Cognito.IdentityProvider` module has updated documentation and support\n  for admin operations.\n- `AWS.Config` module has updated documentation and support for evaluations\n  results.\n- `AWS.DeviceFarm` module has updated documentation and support for managing\n  remote access sessions.\n- `AWS.DirectConnect` module has updated documentation and support for\n  managing hosted connections, lag and BGP peers.\n- `AWS.DirectoryService` module has updated documentation and support for\n  managing schema extensions.\n- `AWS.Discovery` module has updated documentation and support for managing\n  application configuration and fetching summaries.\n- `AWS.DMS` module has updated documentation and support for modifying\n  replication tasks.\n- `AWS.DynamoDB` module has updated documentation and support for managing\n  resource tags and managing the lifetime of individual table items.\n- `AWS.DynamoDB.Streams` has updated documentation.\n- `AWS.ECR` module has updated documentation and support for describing\n  images.\n- `AWS.ECS` module has updated documentation and support for managing\n  attributes and updating container instance states.\n- `AWS.EFS` module has updated documentation.\n- `AWS.EMR` module has updated documentation and support for canceling steps\n  and managing security configuration and auto scaling policy.\n- `AWS.GameLift` module has updated documentation and support for managing\n  instances, game session queues and game session placement.\n- `AWS.Glacier` module has updated documentation and support for purchasing\n  provisions capacity.\n- `AWS.IoT` module has updated documentation and support for managing thing\n  types and outgoing certificates.\n- `AWS.Kinesis` module has updated documentation and support for managing\n  limits.\n- `AWS.Kinesis.Firehose` module has updated documentation.\n- `AWS.KMS` module has updated documentation and support for import parameters\n  and resource tags.\n- `AWS.Lambda` module has updated documentation and support for managing\n  account settings.\n- `AWS.Logs` module has updated documentation and support for log group tags.\n- `AWS.MachineLearning` module has updated documentation.\n- `AWS.Marketplace.CommerceAnalytics` module has updated documentation and\n  support for starting support data export.\n- `AWS.Marketplace.Metering` module has updated documentation and support for\n  batch metering and resolving customers.\n- `AWS.OpsWorks` module has updated documentation.\n- `AWS.Route53.Domains` module has updated documentation and support for\n  domain suggestions, billing and domain renewal.\n- `AWS.ServiceCatalog` module has updated documentation and support for\n  portfolios, products and constraints.\n- `AWS.SSM` module has updated documentation and support for maintenance\n  windows, parameters and patch baselines.\n- `AWS.StorageGateway` module has updated documentation and support for NFS\n  file shares.\n- `AWS.Support` module has updated documentation.\n- `AWS.WAF` module has updated documentation.\n- `AWS.Workspaces` module has updated documentation and support for workspace\n  properties and connection status.\n\n## [v0.3.0] - 2016-12-11\n#","ref":"changelog.html#changed","title":"Changed - Changelog","type":"extras"},{"doc":"- Bumped `httpoison` dependency from `~0.9.1` to `~0.10.0`.\n\n## [v0.2.0] - 2016-08-20\n#","ref":"changelog.html#changed","title":"Changed - Changelog","type":"extras"},{"doc":"- Bumped `httpoison` dependency from `~0.8.0` to `~0.9.1` to be compatible\n  with Elixir 1.3.2.\n\n## [v0.1.0] - 2016-07-13\n#","ref":"changelog.html#changed","title":"Changed - Changelog","type":"extras"},{"doc":"- `AWS.AutoScaling` module for AWS Auto Scaling service.\n- `AWS.CertificateManager` module has support for adding, listing and removing\n  tags from certificates along with updated documentation.\n- `AWS.CloudHSM` module has updated documentation.\n- `AWS.CloudTrail` module has updated documentation.\n- `AWS.CodePipeline` module has support for putting approval results, retrying\n  stage execution and updated documentation.\n- `AWS.Config` module has support to delete configuration recorders and\n  updated documentation.\n- `AWS.DirectConnect` module has support to fetch letters of authorization for\n  connections and interconnects and has updated documentation.\n- `AWS.DirectoryService` module has support to add, list and remove tags from\n  resources.\n- `AWS.Discovery` module for AWS Application Discovery Service.\n- `AWS.DMS` module has support to import, delete and describe certifications\n  and has updated documentation.\n- `AWS.DynamoDB` module has updated documentation.\n- `AWS.DyanamoDB.Streams` module has updated documentation.\n- `AWS.ECS` module has updated documentation.\n- `AWS.EFS` module has updated documentation.\n- `AWS.GameLift` module has support to describe and update a runtime\n  configuration for a fleet and has updated documentation.\n- `AWS.Inspector` module has updated documentation.\n- `AWS.IoT` module has support to list policy principals and has updated\n  documentation.\n- `AWS.Kinesis.Firehose` module has updated documentation.\n- `AWS.KMS` module has updated documentation.\n- `AWS.MachineLearning` module has support to add, describe and delete tags on\n  an object and has updated documentation.\n- `AWS.OpsWorks` module has updated documentation.\n- `AWS.Route53.Domains` module has support to get and resent contact\n  reachability status and has updated documentation.\n- `AWS.ServiceCatalog` module for AWS Service Catalog service.\n- `AWS.SSM` module has support to add, list and remove tags from resources, to\n  create, describe and delete activations, to deregister managed instances, to\n  describe and modify document permissions, to update managed instance roles\n  and has updated documentation.\n- `AWS.StorageGateway` module has support to list taps and has updated\n  documentation.\n- `AWS.Workspaces` module has support to create, describe and delete tags.\n\n#","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"- `AWS.CognitoIdentityProvider` module removes support to get JSON web keys or\n  OpenID configuration information for user pools.\n\n## [v0.0.12] - 2016-07-13\n#","ref":"changelog.html#removed","title":"Removed - Changelog","type":"extras"},{"doc":"- Bumped `poison` dependency from `~1.0` to `~1.5 or ~2.0` to be compatible\n  with the latest version of Phoenix.\n\n## [v0.0.11] - 2016-04-21\n#","ref":"changelog.html#changed","title":"Changed - Changelog","type":"extras"},{"doc":"- `AWS.CertificateManager` module for AWS Certificate Manager service.\n- `AWS.CloudWatch.Events` module for AWS CloudWatch Events service.\n- `AWS.Cognito.IdentityProvider` module for AWS Cognito Identity Provider\n  service.\n- `AWS.DMS` module for AWS Database Migration Service.\n- `AWS.ECR` module for AWS EC2 Container Registry service.\n- `AWS.Inspector` module for AWS Inspector service.\n- `AWS.IoT` module for AWS IoT service.\n- `AWS.IoT.DataPlane` module for AWS IoT Data Plane service.\n- `AWS.Kinesis.Firehose` module for AWS Kinesis Firehose service.\n- `AWS.MachineLearning` module for AWS Machine Learning service.\n- `AWS.Marketplace.Metering` module for AWS Marketplace Metering service.\n\n#","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"- `AWS.CodePipeline` module has updated documentation.\n- `AWS.Cognito` module has updated documentation.\n- `AWS.DirectoryService` module has support for creating, deleting, describing\n  and updating conditional forwarders.\n- `AWS.Kinesis` module has updated documentation and enabling and disabling\n  enhanced monitoring.\n- `AWS.MCA` module has been renamed to `AWS.Marketplace.CommerceAnalytics`.\n- `AWS.StorageGateway` module has updated documentation.\n- `AWS.WAF` module has support for creating, deleting, getting, listing and\n  updating XSS match sets.\n- Timex dependency upgrade from 1.x to 2.x (Fixes #40).\n- Bump minimum Elixir version to 1.2.\n\n#","ref":"changelog.html#changed","title":"Changed - Changelog","type":"extras"},{"doc":"- Link to `aws-codegen` added and broken AWS SDK specification links fixed in\n  README. Thanks Brenton Annan (@brentonannan).\n\n## [v0.0.10] - 2016-03-22\n#","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- `AWS.CloudHSM` module has support to add, list and remove tags on resources.\n- `AWS.CodeCommit` module has support for getting commits, and working with\n  repository triggers.\n- `AWS.CodeDeploy` module has support for batch operations related to\n  application revisions, deployment groups and deployment instances.\n- `AWS.DeviceFarm` module has support for offering status, offering\n  transactions, offerings and stopping of runs.\n- `AWS.DirectoryService` module has support managing event topics.\n- `AWS.GameLift` module has support for managing game session details and\n  scaling policies.\n- `AWS.StorageGateway` module has support for creating tapes with barcodes.\n\n#","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"- `AWS.Cognito.Sync` module uses header locations instead of parameter names\n  when making requests.\n- `AWS.Glacier` module uses header locations instead of parameter names when\n  making requests and processing responses.\n- `AWS.Lambda` module uses header locations instead of parameter names when\n  making requests and processing responses.\n- `AWS.MobileAnalytics` module uses header locations instead of parameter\n  names when making requests.\n\n## [v0.0.9] - 2016-03-22\n#","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- `AWS.CloudSearch.Domain` module has been removed because it doesn't work\n  correctly and adding support for it to the code generator not a priority.\n\n## [v0.0.8] - 2016-02-09\n#","ref":"changelog.html#removed","title":"Removed - Changelog","type":"extras"},{"doc":"- `AWS.GameLift` module for AWS GameLift service.\n- `AWS.MCA` module for AWS Marketplace Commerce Analytics service.\n- `AWS.WAF` module for AWS Web Application Firewall service.\n- Experimental/unstable support for generating v4 signatures that can be\n  embedded in query strings is taking shape in `AWS.Request.sign_v4_query`.\n\n#","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"- Requests that error now return `{:error, {exception, message}}` 2-tuples\n  instead of the `{:error, exception}` 2-tuples that were returned before.\n\n## [v0.0.7] - 2016-01-13\n#","ref":"changelog.html#changed","title":"Changed - Changelog","type":"extras"},{"doc":"- Trailing slashes that were causing signing errors in generated URLs in the\n  Lambda client have been removed. Thanks Akash Manohar aka @HashNuke.\n- REST-JSON clients, including `AWS.CloudSearchDomain`, `AWS.CognitoSync`,\n  `AWS.EFS`, `AWS.Glacier`, `AWS.Lambda`, `AWS.MobileAnalytics` and\n  `AWS.Transcoder` correctly handle responses with empty bodies. Thanks Akash\n  Manohar (@HashNuke).\n\n## [v0.0.6] - 2016-01-06\n#","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- `AWS.DirectoryService` module has new functionality for managing and\n  verifying trust relationships.\n- `AWS.Client` has new `proto` and `port` members that can be used to create a\n  client that is suitable for use with Local DynamoDB. In this situation, the\n  region should be set to `local`, the protocol to `http` and the port should\n  match the running Local DynamoDB instance.\n- `AWS.ECS` has updated documentation.\n- `AWS.Logs` has updated documentation.\n- `AWS.SSM` has updated documentation.\n\n#","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"- Services return an `{:ok, nil, response}` 3-tuple, instead of the `{:ok,\n  response}` 2-tuple that was previously returned, when an AWS service\n  endpoint returns a successful HTTP status with an empty response body.\n- Relax `Poison` dependency to 1.2.0 to maintain compatibility with\n  [ex_aws](https://hex.pm/packages/ex_aws).\n\n## [v0.0.5] - 2015-11-06\n#","ref":"changelog.html#changed","title":"Changed - Changelog","type":"extras"},{"doc":"- All services return a `{:error, reason, response}` tuple when an\n  unsuccessful HTTP status code is returned (previously the `response` was not\n  included).\n\n#","ref":"changelog.html#changed","title":"Changed - Changelog","type":"extras"},{"doc":"- An empty body returned alongside an HTTP 200 from an AWS service isn't\n  parsed by Poison (which was causing exceptions to be raised). Thanks Mike\n  Coleman (@fivebats).\n\n## [v0.0.4] - 2015-08-05\n#","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- `AWS.CloudSearch.Domain` module for Cloud Search Service.\n- `AWS.Cognito.Sync` module for Cognito Sync Service.\n- `AWS.DeviceFarm` module for DeviceFarm Service.\n- `AWS.EFS` module for Elastic File System Service.\n- `AWS.Glacier` module for Glacier Service.\n- `AWS.Lambda` module for Lambda Service.\n- `AWS.MobileAnalytics` module for Mobile Analytics Service.\n- `AWS.Transcoder` module for Elastic Transcoder Service.\n\n#","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"- `AWS.CloudHSM` module has updated documentation.\n- `AWS.CognitoIdentity` module has been renamed to `AWS.Cognito`.\n- `AWS.Logs` module has support for new `DeleteDestination`,\n  `DescribeDestinations`, `PutDestination` and `PutDestinationPolicy` actions.\n- `AWS.OpsWorks` module has updated documentation and new support for the\n  `DeregisterEcsCluster`, `DescribeEcsClusters` and `RegisterEcsCluster`\n  actions.\n- `AWS.Route53Domains` module has been renamed to `AWS.Route53.Domains`.\n- `AWS.StorageGateway` module has updated documentation.\n\n## [v0.0.3] - 2015-07-14\n#","ref":"changelog.html#changed","title":"Changed - Changelog","type":"extras"},{"doc":"- `AWS.DynamoDB.Streams` module for DynamoDB Streams Service.\n\n#","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"- `AWS.DynamoDB` module has updated documentation.\n\n## [v0.0.2] - 2015-07-09\n#","ref":"changelog.html#changed","title":"Changed - Changelog","type":"extras"},{"doc":"- `AWS.CodeCommit` module for CodeCommit Service.\n- `AWS.CodePipeline` module for CodePipeline Service.\n- `AWS.CognitoIdentity` module for Cognito Service.\n- `AWS.DirectoryService` module for Directory Service.\n- `AWS.Route53Domains` module for Route53 Domains Service.\n- `AWS.Workspaces` module for Workspaces Service.\n\n#","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"- `AWS.CodeDeploy` module has new functionality for managing on premises\n  instances.\n- `AWS.Config` module has updated documentation.\n- `AWS.DynamoDB` module has updated documentation.\n- `AWS.ECS` module has updated documentation and new support for the\n  `UpdateContainerAgent` action.\n- `AWS.Kinesis` module has updated documentation.\n- `AWS.KMS` module has updated documentation and new support for the\n  `UpdateAlias` action.\n- `AWS.Logs` module has updated documentation and new functionality for\n  managing log events and subscription filters.\n- `AWS.OpsWorks` module has updated documentation and new support for the\n  `DescribeAgentVersions` and `GrantAccess` actions.\n- `AWS.SSM` module has updated documentation.\n- `AWS.StorageGateway` module has updated documentation and new support for\n  the `ListVolumeInitiators` action.\n\n## [v0.0.1](https://github.com/jkakar/aws-elixir/tree/v0.0.1) - 2015-05-29\n#","ref":"changelog.html#changed","title":"Changed - Changelog","type":"extras"},{"doc":"- `AWS.CloudHSM` module for CloudHSM Service.\n- `AWS.CloudTrail` module for CloudTrail Service.\n- `AWS.CodeDeploy` module for CodeDeploy Service.\n- `AWS.Config` module for Config Service.\n- `AWS.DataPipeline` module for DataPipeline Service.\n- `AWS.DirectConnect` module for DirectConnect Service.\n- `AWS.DynamoDB` module for DynamoDB Service.\n- `AWS.ECS` module for EC2 Container Service.\n- `AWS.EMR` module for Elastic MapReduce Service.\n- `AWS.KMS` module for Key Management Service.\n- `AWS.Kinesis` module for Kinesis Service.\n- `AWS.Logs` module for CloudWatch Logs Service.\n- `AWS.OpsWorks` module for OpsWorks Service.\n- `AWS.SSM` module for Simple Systems Management Service.\n- `AWS.SWF` module for Simple Workflow Service.\n- `AWS.StorageGateway` module for Storage Gateway Service\n- `AWS.Support` module for Support Service.\n\n[unreleased]: https://github.com/aws-beam/aws-elixir/compare/v0.13.1...HEAD\n[v0.13.1]: https://github.com/aws-beam/aws-elixir/compare/v0.13.0...v0.13.1\n[v0.13.0]: https://github.com/aws-beam/aws-elixir/compare/v0.12.0...v0.13.0\n[v0.12.0]: https://github.com/aws-beam/aws-elixir/compare/v0.11.0...v0.12.0\n[v0.11.0]: https://github.com/aws-beam/aws-elixir/compare/v0.10.1...v0.11.0\n[v0.10.1]: https://github.com/aws-beam/aws-elixir/compare/v0.10.0...v0.10.1\n[v0.10.0]: https://github.com/aws-beam/aws-elixir/compare/v0.9.2...v0.10.0\n[v0.9.2]: https://github.com/aws-beam/aws-elixir/compare/v0.9.1...v0.9.2\n[v0.9.1]: https://github.com/aws-beam/aws-elixir/compare/v0.9.0...v0.9.1\n[v0.9.0]: https://github.com/aws-beam/aws-elixir/compare/v0.8.0...v0.9.0\n[v0.8.0]: https://github.com/aws-beam/aws-elixir/compare/v0.7.0...v0.8.0\n[v0.7.0]: https://github.com/aws-beam/aws-elixir/compare/v0.6.0...v0.7.0\n[v0.6.0]: https://github.com/aws-beam/aws-elixir/compare/v0.5.0...v0.6.0\n[v0.5.0]: https://github.com/aws-beam/aws-elixir/compare/v0.4.0...v0.5.0\n[v0.4.0]: https://github.com/aws-beam/aws-elixir/compare/v0.3.0...v0.4.0\n[v0.3.0]: https://github.com/aws-beam/aws-elixir/compare/v0.2.0...v0.3.0\n[v0.2.0]: https://github.com/aws-beam/aws-elixir/compare/v0.1.0...v0.2.0\n[v0.1.0]: https://github.com/aws-beam/aws-elixir/compare/v0.0.12...v0.1.0\n[v0.0.12]: https://github.com/aws-beam/aws-elixir/compare/v0.0.11...v0.0.12\n[v0.0.11]: https://github.com/aws-beam/aws-elixir/compare/v0.0.10...v0.0.11\n[v0.0.10]: https://github.com/aws-beam/aws-elixir/compare/v0.0.9...v0.0.10\n[v0.0.9]: https://github.com/aws-beam/aws-elixir/compare/v0.0.8...v0.0.9\n[v0.0.8]: https://github.com/aws-beam/aws-elixir/compare/v0.0.7...v0.0.8\n[v0.0.7]: https://github.com/aws-beam/aws-elixir/compare/v0.0.6...v0.0.7\n[v0.0.6]: https://github.com/aws-beam/aws-elixir/compare/v0.0.5...v0.0.6\n[v0.0.5]: https://github.com/aws-beam/aws-elixir/compare/v0.0.4...v0.0.5\n[v0.0.4]: https://github.com/aws-beam/aws-elixir/compare/v0.0.3...v0.0.4\n[v0.0.3]: https://github.com/aws-beam/aws-elixir/compare/v0.0.2...v0.0.3\n[v0.0.2]: https://github.com/aws-beam/aws-elixir/compare/v0.0.1...v0.0.2","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"Apache License\n                           Version 2.0, January 2004\n                        http://www.apache.org/licenses/\n\n   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION\n\n   1. Definitions.\n\n      \"License\" shall mean the terms and conditions for use, reproduction,\n      and distribution as defined by Sections 1 through 9 of this document.\n\n      \"Licensor\" shall mean the copyright owner or entity authorized by\n      the copyright owner that is granting the License.\n\n      \"Legal Entity\" shall mean the union of the acting entity and all\n      other entities that control, are controlled by, or are under common\n      control with that entity. For the purposes of this definition,\n      \"control\" means (i) the power, direct or indirect, to cause the\n      direction or management of such entity, whether by contract or\n      otherwise, or (ii) ownership of fifty percent (50%) or more of the\n      outstanding shares, or (iii) beneficial ownership of such entity.\n\n      \"You\" (or \"Your\") shall mean an individual or Legal Entity\n      exercising permissions granted by this License.\n\n      \"Source\" form shall mean the preferred form for making modifications,\n      including but not limited to software source code, documentation\n      source, and configuration files.\n\n      \"Object\" form shall mean any form resulting from mechanical\n      transformation or translation of a Source form, including but\n      not limited to compiled object code, generated documentation,\n      and conversions to other media types.\n\n      \"Work\" shall mean the work of authorship, whether in Source or\n      Object form, made available under the License, as indicated by a\n      copyright notice that is included in or attached to the work\n      (an example is provided in the Appendix below).\n\n      \"Derivative Works\" shall mean any work, whether in Source or Object\n      form, that is based on (or derived from) the Work and for which the\n      editorial revisions, annotations, elaborations, or other modifications\n      represent, as a whole, an original work of authorship. For the purposes\n      of this License, Derivative Works shall not include works that remain\n      separable from, or merely link (or bind by name) to the interfaces of,\n      the Work and Derivative Works thereof.\n\n      \"Contribution\" shall mean any work of authorship, including\n      the original version of the Work and any modifications or additions\n      to that Work or Derivative Works thereof, that is intentionally\n      submitted to Licensor for inclusion in the Work by the copyright owner\n      or by an individual or Legal Entity authorized to submit on behalf of\n      the copyright owner. For the purposes of this definition, \"submitted\"\n      means any form of electronic, verbal, or written communication sent\n      to the Licensor or its representatives, including but not limited to\n      communication on electronic mailing lists, source code control systems,\n      and issue tracking systems that are managed by, or on behalf of, the\n      Licensor for the purpose of discussing and improving the Work, but\n      excluding communication that is conspicuously marked or otherwise\n      designated in writing by the copyright owner as \"Not a Contribution.\"\n\n      \"Contributor\" shall mean Licensor and any individual or Legal Entity\n      on behalf of whom a Contribution has been received by Licensor and\n      subsequently incorporated within the Work.\n\n   2. Grant of Copyright License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      copyright license to reproduce, prepare Derivative Works of,\n      publicly display, publicly perform, sublicense, and distribute the\n      Work and such Derivative Works in Source or Object form.\n\n   3. Grant of Patent License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      (except as stated in this section) patent license to make, have made,\n      use, offer to sell, sell, import, and otherwise transfer the Work,\n      where such license applies only to those patent claims licensable\n      by such Contributor that are necessarily infringed by their\n      Contribution(s) alone or by combination of their Contribution(s)\n      with the Work to which such Contribution(s) was submitted. If You\n      institute patent litigation against any entity (including a\n      cross-claim or counterclaim in a lawsuit) alleging that the Work\n      or a Contribution incorporated within the Work constitutes direct\n      or contributory patent infringement, then any patent licenses\n      granted to You under this License for that Work shall terminate\n      as of the date such litigation is filed.\n\n   4. Redistribution. You may reproduce and distribute copies of the\n      Work or Derivative Works thereof in any medium, with or without\n      modifications, and in Source or Object form, provided that You\n      meet the following conditions:\n\n      (a) You must give any other recipients of the Work or\n          Derivative Works a copy of this License; and\n\n      (b) You must cause any modified files to carry prominent notices\n          stating that You changed the files; and\n\n      (c) You must retain, in the Source form of any Derivative Works\n          that You distribute, all copyright, patent, trademark, and\n          attribution notices from the Source form of the Work,\n          excluding those notices that do not pertain to any part of\n          the Derivative Works; and\n\n      (d) If the Work includes a \"NOTICE\" text file as part of its\n          distribution, then any Derivative Works that You distribute must\n          include a readable copy of the attribution notices contained\n          within such NOTICE file, excluding those notices that do not\n          pertain to any part of the Derivative Works, in at least one\n          of the following places: within a NOTICE text file distributed\n          as part of the Derivative Works; within the Source form or\n          documentation, if provided along with the Derivative Works; or,\n          within a display generated by the Derivative Works, if and\n          wherever such third-party notices normally appear. The contents\n          of the NOTICE file are for informational purposes only and\n          do not modify the License. You may add Your own attribution\n          notices within Derivative Works that You distribute, alongside\n          or as an addendum to the NOTICE text from the Work, provided\n          that such additional attribution notices cannot be construed\n          as modifying the License.\n\n      You may add Your own copyright statement to Your modifications and\n      may provide additional or different license terms and conditions\n      for use, reproduction, or distribution of Your modifications, or\n      for any such Derivative Works as a whole, provided Your use,\n      reproduction, and distribution of the Work otherwise complies with\n      the conditions stated in this License.\n\n   5. Submission of Contributions. Unless You explicitly state otherwise,\n      any Contribution intentionally submitted for inclusion in the Work\n      by You to the Licensor shall be under the terms and conditions of\n      this License, without any additional terms or conditions.\n      Notwithstanding the above, nothing herein shall supersede or modify\n      the terms of any separate license agreement you may have executed\n      with Licensor regarding such Contributions.\n\n   6. Trademarks. This License does not grant permission to use the trade\n      names, trademarks, service marks, or product names of the Licensor,\n      except as required for reasonable and customary use in describing the\n      origin of the Work and reproducing the content of the NOTICE file.\n\n   7. Disclaimer of Warranty. Unless required by applicable law or\n      agreed to in writing, Licensor provides the Work (and each\n      Contributor provides its Contributions) on an \"AS IS\" BASIS,\n      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\n      implied, including, without limitation, any warranties or conditions\n      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A\n      PARTICULAR PURPOSE. You are solely responsible for determining the\n      appropriateness of using or redistributing the Work and assume any\n      risks associated with Your exercise of permissions under this License.\n\n   8. Limitation of Liability. In no event and under no legal theory,\n      whether in tort (including negligence), contract, or otherwise,\n      unless required by applicable law (such as deliberate and grossly\n      negligent acts) or agreed to in writing, shall any Contributor be\n      liable to You for damages, including any direct, indirect, special,\n      incidental, or consequential damages of any character arising as a\n      result of this License or out of the use or inability to use the\n      Work (including but not limited to damages for loss of goodwill,\n      work stoppage, computer failure or malfunction, or any and all\n      other commercial damages or losses), even if such Contributor\n      has been advised of the possibility of such damages.\n\n   9. Accepting Warranty or Additional Liability. While redistributing\n      the Work or Derivative Works thereof, You may choose to offer,\n      and charge a fee for, acceptance of support, warranty, indemnity,\n      or other liability obligations and/or rights consistent with this\n      License. However, in accepting such obligations, You may act only\n      on Your own behalf and on Your sole responsibility, not on behalf\n      of any other Contributor, and only if You agree to indemnify,\n      defend, and hold each Contributor harmless for any liability\n      incurred by, or claims asserted against, such Contributor by reason\n      of your accepting any such warranty or additional liability.\n\n   END OF TERMS AND CONDITIONS","ref":"license.html","title":"License","type":"extras"},{"doc":"# AWS clients for Elixir\n\n[![Actions Status](https://github.com/aws-beam/aws-elixir/workflows/Build/badge.svg)](https://github.com/aws-beam/aws-elixir/actions)\n[![Module Version](https://img.shields.io/hexpm/v/aws.svg)](https://hex.pm/packages/aws)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/aws/)\n[![Total Download](https://img.shields.io/hexpm/dt/aws.svg)](https://hex.pm/packages/aws)\n[![License](https://img.shields.io/hexpm/l/aws.svg)](https://github.com/aws-beam/aws-elixir/blob/master/LICENSE.md)\n[![Last Updated](https://img.shields.io/github/last-commit/aws-beam/aws-elixir.svg)](https://github.com/aws-beam/aws-elixir/commits/master)\n\n🌳 With this library you can have access to almost all AWS services without hassle. ⚡","ref":"readme.html","title":"Overview","type":"extras"},{"doc":"* A clean API separated per service. Each module has a correspondent service.\n* Support for most of AWS services.\n* Configurable HTTP client and JSON parser.\n* Generated by [aws-codegen](https://github.com/aws-beam/aws-codegen) using the\n  same JSON descriptions of AWS services used to build the\n  [AWS SDK for Go](https://github.com/aws/aws-sdk-go/tree/master/models/apis).\n* Documentation is updated from the official AWS docs.","ref":"readme.html#features","title":"Features - Overview","type":"extras"},{"doc":"Here is an example of listing Amazon Kinesis streams. First you need to start a\nconsole with `iex -S mix`.\n\nAfter that, type the following:\n\n```elixir\niex> client = AWS.Client.create(\"your-access-key-id\", \"your-secret-access-key\", \"us-east-1\")\niex> {:ok, result, resp} = AWS.Kinesis.list_streams(client, %{})\niex> IO.inspect(result)\n%{\"HasMoreStreams\" => false, \"StreamNames\" => []}\n```\n\nIf you are using `AWS.S3`, you can upload a file with integrity check doing:\n\n```elixir\niex> client = AWS.Client.create(\"your-access-key-id\", \"your-secret-access-key\", \"us-east-1\")\niex> file = File.read!(\"./tmp/your-file.txt\")\niex> md5 = :crypto.hash(:md5, file) |> Base.encode64()\niex> AWS.S3.put_object(client, \"your-bucket-name\", \"foo/your-file-on-s3.txt\",\n  %{\"Body\" => file, \"ContentMD5\" => md5})\n```\n\nNote that you may need to specify the `ContentType` attribute when calling `AWS.S3.put_object/4`.\nThis is because S3 will use that to store the MIME type of the file.\n\nYou can also upload to S3 as multipart. If you're facing timeout issues, this strategy is\nrecommended:\n\n```elixir\nclient = AWS.Client.create(\"your-access-key-id\", \"your-secret-access-key\", \"us-east-1\")\nbucket = \"your-bucket-name\"\nfilename = \"./your-big-file.wav\"\n# AWS minimum chunk size is 5MB\nchunk_size = 5_242_880\n\n# Create the multipart request\n{:ok,\n %{\n   \"InitiateMultipartUploadResult\" => %{\n     \"UploadId\" => upload_id\n   }\n }, _} = AWS.S3.create_multipart_upload(client, bucket, filename, %{})\n\nfile = File.read!(filename)\n\n# Send the file's binary in parts\nparts =\n  file\n  |> String.codepoints()\n  |> Stream.chunk_every(chunk_size)\n  |> Stream.with_index(1)\n  |> Enum.map(fn {chunk, i} ->\n    chunk = Enum.join(chunk)\n\n    {:ok, nil, %{headers: headers, status_code: 200}} =\n      AWS.S3.upload_part(aws_client, bucket, filename, %{\n        \"Body\" => chunk,\n        \"PartNumber\" => i,\n        \"UploadId\" => upload_id\n      })\n\n    {_, etag} = Enum.find(headers, fn {header, _} -> header == \"ETag\" end)\n\n    %{\"ETag\" => etag, \"PartNumber\" => i}\n  end)\n\n\ninput = %{\"CompleteMultipartUpload\" => %{\"Part\" => parts}, \"UploadId\" => upload_id}\n\n# Complete the multipart request\nAWS.S3.complete_multipart_upload(aws_client, bucket, filename, input)\n```\n\nYou can also list objects in a bucket:\n\n```elixir\n# create the client just like the example above\niex> AWS.S3.list_objects_v2(client, \"bucket-name-here\")\n```\n\nAnd download a specific object:\n\n```elixir\n# create the client just like the example above\n# object key is the \"file path\" in the S3 bucket\niex> AWS.S3.get_object(client, \"bucket-name-here\", \"object-key-here\")\n```\n\nCheck all S3 related functions [in the docs here](https://hexdocs.pm/aws/AWS.S3.html).\n\nRemember to check the operation documentation for details:\n[https://docs.aws.amazon.com/](https://docs.aws.amazon.com/)","ref":"readme.html#usage","title":"Usage - Overview","type":"extras"},{"doc":"Add `:aws` to your list of dependencies in `mix.exs`. It also requires\n[hackney](https://github.com/benoitc/hackney) for the default HTTP client.\nOptionally, you can implement your own (Check `AWS.Client` docs).\n\n```elixir\ndef deps do\n  [\n    {:aws, \"~> 0.13.0\"},\n    {:hackney, \"~> 1.18\"}\n  ]\nend\n```\n\nRun `mix deps.get` to install.","ref":"readme.html#installation","title":"Installation - Overview","type":"extras"},{"doc":"Most of the code is generated using the\n[aws-codegen](https://github.com/aws-beam/aws-codegen) library from the JSON\ndescriptions of AWS services provided by Amazon. They can be found in\n`lib/aws/generated`.\n\nCode outside `lib/aws/generated` is manually written and used as support for\nthe generated code.","ref":"readme.html#development","title":"Development - Overview","type":"extras"},{"doc":"Online\n* [Hex Docs](https://hexdocs.pm/aws)\n\nLocal\n* Run `mix docs`\n* Open `docs/index.html`\n\n__Note:__ Arguments, errors and response structure can be found by viewing the model schemas used to generate this module at `aws-sdk-go/models/apis/ / /`.\n\nAn example is [`aws-sdk-go/models/apis/rekognition/2016-06-27/api-2.json`](https://github.com/aws/aws-sdk-go/blob/master/models/apis/rekognition/2016-06-27/api-2.json).\nAlternatively you can access the documentation for the service you want at [AWS docs page](https://docs.aws.amazon.com/).","ref":"readme.html#documentation","title":"Documentation - Overview","type":"extras"},{"doc":"```\n$ mix test\n```","ref":"readme.html#tests","title":"Tests - Overview","type":"extras"},{"doc":"* Make sure the `CHANGELOG.md` is up-to-date and and reflects the changes for\n  the new version.\n* Bump the version here in the `README.md` and in `mix.exs`.\n* Run `git tag v$VERSION` to tag the version that was just published.\n* Run `git push --tags origin master` to push tags to Github.\n* Run `mix hex.publish` to publish the new version.","ref":"readme.html#release","title":"Release - Overview","type":"extras"},{"doc":"Copyright (c) 2015 Jamshed Kakar  \n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at [http://www.apache.org/licenses/LICENSE-2.0](http://www.apache.org/licenses/LICENSE-2.0)\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.","ref":"readme.html#copyright-license","title":"Copyright & License - Overview","type":"extras"}]}